"""
analytic expressions of spherical harmonics generated with sympy file 
Marc Russwurm generated 2023-07-26

run 
python spherical_harmonics_generate_ylms.py > spherical_harmonics_ylm.py

to generate the source code
"""

import torch
from torch import cos, sin

def get_SH(m,l):
  fname = f"Yl{l}_m{m}".replace("-","_minus_")
  return globals()[fname]

def SH(m, l, phi, theta):
  Ylm = get_SH(m,l)
  return Ylm(theta, phi)



#@torch.jit.script
def Yl0_m0(theta, phi):
    return 0.886226925452758

#@torch.jit.script
def Yl1_m_minus_1(theta, phi):
    return 0.48860251190292*(1.0 - cos(theta)**2)**0.5*sin(phi)

#@torch.jit.script
def Yl1_m0(theta, phi):
    return 1.53499006191973*cos(theta)

#@torch.jit.script
def Yl1_m1(theta, phi):
    return 0.48860251190292*(1.0 - cos(theta)**2)**0.5*cos(phi)

#@torch.jit.script
def Yl2_m_minus_2(theta, phi):
    return 0.18209140509868*(3.0 - 3.0*cos(theta)**2)*sin(2*phi)

#@torch.jit.script
def Yl2_m_minus_1(theta, phi):
    return 1.09254843059208*(1.0 - cos(theta)**2)**0.5*sin(phi)*cos(theta)

#@torch.jit.script
def Yl2_m0(theta, phi):
    return 2.97249547320451*cos(theta)**2 - 0.990831824401503

#@torch.jit.script
def Yl2_m1(theta, phi):
    return 1.09254843059208*(1.0 - cos(theta)**2)**0.5*cos(phi)*cos(theta)

#@torch.jit.script
def Yl2_m2(theta, phi):
    return 0.18209140509868*(3.0 - 3.0*cos(theta)**2)*cos(2*phi)

#@torch.jit.script
def Yl3_m_minus_3(theta, phi):
    return 0.590043589926644*(1.0 - cos(theta)**2)**1.5*sin(3*phi)

#@torch.jit.script
def Yl3_m_minus_2(theta, phi):
    return 1.44530572132028*(1.0 - cos(theta)**2)*sin(2*phi)*cos(theta)

#@torch.jit.script
def Yl3_m_minus_1(theta, phi):
    return 0.304697199642977*(1.0 - cos(theta)**2)**0.5*(7.5*cos(theta)**2 - 1.5)*sin(phi)

#@torch.jit.script
def Yl3_m0(theta, phi):
    return 5.86184012479344*cos(theta)**3 - 3.51710407487606*cos(theta)

#@torch.jit.script
def Yl3_m1(theta, phi):
    return 0.304697199642977*(1.0 - cos(theta)**2)**0.5*(7.5*cos(theta)**2 - 1.5)*cos(phi)

#@torch.jit.script
def Yl3_m2(theta, phi):
    return 1.44530572132028*(1.0 - cos(theta)**2)*cos(2*phi)*cos(theta)

#@torch.jit.script
def Yl3_m3(theta, phi):
    return 0.590043589926644*(1.0 - cos(theta)**2)**1.5*cos(3*phi)

#@torch.jit.script
def Yl4_m_minus_4(theta, phi):
    return 0.625835735449176*(1.0 - cos(theta)**2)**2*sin(4*phi)

#@torch.jit.script
def Yl4_m_minus_3(theta, phi):
    return 1.77013076977993*(1.0 - cos(theta)**2)**1.5*sin(3*phi)*cos(theta)

#@torch.jit.script
def Yl4_m_minus_2(theta, phi):
    return 0.063078313050504*(1.0 - cos(theta)**2)*(52.5*cos(theta)**2 - 7.5)*sin(2*phi)

#@torch.jit.script
def Yl4_m_minus_1(theta, phi):
    return 0.267618617422916*(1.0 - cos(theta)**2)**0.5*(17.5*cos(theta)**3 - 7.5*cos(theta))*sin(phi)

#@torch.jit.script
def Yl4_m0(theta, phi):
    return 11.6317283965674*cos(theta)**4 - 9.97005291134353*cos(theta)**2 + 0.997005291134353

#@torch.jit.script
def Yl4_m1(theta, phi):
    return 0.267618617422916*(1.0 - cos(theta)**2)**0.5*(17.5*cos(theta)**3 - 7.5*cos(theta))*cos(phi)

#@torch.jit.script
def Yl4_m2(theta, phi):
    return 0.063078313050504*(1.0 - cos(theta)**2)*(52.5*cos(theta)**2 - 7.5)*cos(2*phi)

#@torch.jit.script
def Yl4_m3(theta, phi):
    return 1.77013076977993*(1.0 - cos(theta)**2)**1.5*cos(3*phi)*cos(theta)

#@torch.jit.script
def Yl4_m4(theta, phi):
    return 0.625835735449176*(1.0 - cos(theta)**2)**2*cos(4*phi)

#@torch.jit.script
def Yl5_m_minus_5(theta, phi):
    return 0.65638205684017*(1.0 - cos(theta)**2)**2.5*sin(5*phi)

#@torch.jit.script
def Yl5_m_minus_4(theta, phi):
    return 2.07566231488104*(1.0 - cos(theta)**2)**2*sin(4*phi)*cos(theta)

#@torch.jit.script
def Yl5_m_minus_3(theta, phi):
    return 0.00931882475114763*(1.0 - cos(theta)**2)**1.5*(472.5*cos(theta)**2 - 52.5)*sin(3*phi)

#@torch.jit.script
def Yl5_m_minus_2(theta, phi):
    return 0.0456527312854602*(1.0 - cos(theta)**2)*(157.5*cos(theta)**3 - 52.5*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl5_m_minus_1(theta, phi):
    return 0.241571547304372*(1.0 - cos(theta)**2)**0.5*(39.375*cos(theta)**4 - 26.25*cos(theta)**2 + 1.875)*sin(phi)

#@torch.jit.script
def Yl5_m0(theta, phi):
    return 23.1468472528419*cos(theta)**5 - 25.7187191698243*cos(theta)**3 + 5.51115410781949*cos(theta)

#@torch.jit.script
def Yl5_m1(theta, phi):
    return 0.241571547304372*(1.0 - cos(theta)**2)**0.5*(39.375*cos(theta)**4 - 26.25*cos(theta)**2 + 1.875)*cos(phi)

#@torch.jit.script
def Yl5_m2(theta, phi):
    return 0.0456527312854602*(1.0 - cos(theta)**2)*(157.5*cos(theta)**3 - 52.5*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl5_m3(theta, phi):
    return 0.00931882475114763*(1.0 - cos(theta)**2)**1.5*(472.5*cos(theta)**2 - 52.5)*cos(3*phi)

#@torch.jit.script
def Yl5_m4(theta, phi):
    return 2.07566231488104*(1.0 - cos(theta)**2)**2*cos(4*phi)*cos(theta)

#@torch.jit.script
def Yl5_m5(theta, phi):
    return 0.65638205684017*(1.0 - cos(theta)**2)**2.5*cos(5*phi)

#@torch.jit.script
def Yl6_m_minus_6(theta, phi):
    return 0.683184105191914*(1.0 - cos(theta)**2)**3*sin(6*phi)

#@torch.jit.script
def Yl6_m_minus_5(theta, phi):
    return 2.36661916223175*(1.0 - cos(theta)**2)**2.5*sin(5*phi)*cos(theta)

#@torch.jit.script
def Yl6_m_minus_4(theta, phi):
    return 0.0010678622237645*(1.0 - cos(theta)**2)**2*(5197.5*cos(theta)**2 - 472.5)*sin(4*phi)

#@torch.jit.script
def Yl6_m_minus_3(theta, phi):
    return 0.00584892228263444*(1.0 - cos(theta)**2)**1.5*(1732.5*cos(theta)**3 - 472.5*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl6_m_minus_2(theta, phi):
    return 0.0350935336958066*(1.0 - cos(theta)**2)*(433.125*cos(theta)**4 - 236.25*cos(theta)**2 + 13.125)*sin(2*phi)

#@torch.jit.script
def Yl6_m_minus_1(theta, phi):
    return 0.221950995245231*(1.0 - cos(theta)**2)**0.5*(86.625*cos(theta)**5 - 78.75*cos(theta)**3 + 13.125*cos(theta))*sin(phi)

#@torch.jit.script
def Yl6_m0(theta, phi):
    return 46.1326724717039*cos(theta)**6 - 62.9081897341417*cos(theta)**4 + 20.9693965780472*cos(theta)**2 - 0.998542694192725

#@torch.jit.script
def Yl6_m1(theta, phi):
    return 0.221950995245231*(1.0 - cos(theta)**2)**0.5*(86.625*cos(theta)**5 - 78.75*cos(theta)**3 + 13.125*cos(theta))*cos(phi)

#@torch.jit.script
def Yl6_m2(theta, phi):
    return 0.0350935336958066*(1.0 - cos(theta)**2)*(433.125*cos(theta)**4 - 236.25*cos(theta)**2 + 13.125)*cos(2*phi)

#@torch.jit.script
def Yl6_m3(theta, phi):
    return 0.00584892228263444*(1.0 - cos(theta)**2)**1.5*(1732.5*cos(theta)**3 - 472.5*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl6_m4(theta, phi):
    return 0.0010678622237645*(1.0 - cos(theta)**2)**2*(5197.5*cos(theta)**2 - 472.5)*cos(4*phi)

#@torch.jit.script
def Yl6_m5(theta, phi):
    return 2.36661916223175*(1.0 - cos(theta)**2)**2.5*cos(5*phi)*cos(theta)

#@torch.jit.script
def Yl6_m6(theta, phi):
    return 0.683184105191914*(1.0 - cos(theta)**2)**3*cos(6*phi)

#@torch.jit.script
def Yl7_m_minus_7(theta, phi):
    return 0.707162732524596*(1.0 - cos(theta)**2)**3.5*sin(7*phi)

#@torch.jit.script
def Yl7_m_minus_6(theta, phi):
    return 2.6459606618019*(1.0 - cos(theta)**2)**3*sin(6*phi)*cos(theta)

#@torch.jit.script
def Yl7_m_minus_5(theta, phi):
    return 9.98394571852353e-5*(1.0 - cos(theta)**2)**2.5*(67567.5*cos(theta)**2 - 5197.5)*sin(5*phi)

#@torch.jit.script
def Yl7_m_minus_4(theta, phi):
    return 0.000599036743111412*(1.0 - cos(theta)**2)**2*(22522.5*cos(theta)**3 - 5197.5*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl7_m_minus_3(theta, phi):
    return 0.00397356022507413*(1.0 - cos(theta)**2)**1.5*(5630.625*cos(theta)**4 - 2598.75*cos(theta)**2 + 118.125)*sin(3*phi)

#@torch.jit.script
def Yl7_m_minus_2(theta, phi):
    return 0.0280973138060306*(1.0 - cos(theta)**2)*(1126.125*cos(theta)**5 - 866.25*cos(theta)**3 + 118.125*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl7_m_minus_1(theta, phi):
    return 0.206472245902897*(1.0 - cos(theta)**2)**0.5*(187.6875*cos(theta)**6 - 216.5625*cos(theta)**4 + 59.0625*cos(theta)**2 - 2.1875)*sin(phi)

#@torch.jit.script
def Yl7_m0(theta, phi):
    return 92.0296731793493*cos(theta)**7 - 148.663318212795*cos(theta)**5 + 67.5742355512704*cos(theta)**3 - 7.5082483945856*cos(theta)

#@torch.jit.script
def Yl7_m1(theta, phi):
    return 0.206472245902897*(1.0 - cos(theta)**2)**0.5*(187.6875*cos(theta)**6 - 216.5625*cos(theta)**4 + 59.0625*cos(theta)**2 - 2.1875)*cos(phi)

#@torch.jit.script
def Yl7_m2(theta, phi):
    return 0.0280973138060306*(1.0 - cos(theta)**2)*(1126.125*cos(theta)**5 - 866.25*cos(theta)**3 + 118.125*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl7_m3(theta, phi):
    return 0.00397356022507413*(1.0 - cos(theta)**2)**1.5*(5630.625*cos(theta)**4 - 2598.75*cos(theta)**2 + 118.125)*cos(3*phi)

#@torch.jit.script
def Yl7_m4(theta, phi):
    return 0.000599036743111412*(1.0 - cos(theta)**2)**2*(22522.5*cos(theta)**3 - 5197.5*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl7_m5(theta, phi):
    return 9.98394571852353e-5*(1.0 - cos(theta)**2)**2.5*(67567.5*cos(theta)**2 - 5197.5)*cos(5*phi)

#@torch.jit.script
def Yl7_m6(theta, phi):
    return 2.6459606618019*(1.0 - cos(theta)**2)**3*cos(6*phi)*cos(theta)

#@torch.jit.script
def Yl7_m7(theta, phi):
    return 0.707162732524596*(1.0 - cos(theta)**2)**3.5*cos(7*phi)

#@torch.jit.script
def Yl8_m_minus_8(theta, phi):
    return 0.72892666017483*(1.0 - cos(theta)**2)**4*sin(8*phi)

#@torch.jit.script
def Yl8_m_minus_7(theta, phi):
    return 2.91570664069932*(1.0 - cos(theta)**2)**3.5*sin(7*phi)*cos(theta)

#@torch.jit.script
def Yl8_m_minus_6(theta, phi):
    return 7.87853281621404e-6*(1.0 - cos(theta)**2)**3*(1013512.5*cos(theta)**2 - 67567.5)*sin(6*phi)

#@torch.jit.script
def Yl8_m_minus_5(theta, phi):
    return 5.10587282657803e-5*(1.0 - cos(theta)**2)**2.5*(337837.5*cos(theta)**3 - 67567.5*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl8_m_minus_4(theta, phi):
    return 0.000368189725644507*(1.0 - cos(theta)**2)**2*(84459.375*cos(theta)**4 - 33783.75*cos(theta)**2 + 1299.375)*sin(4*phi)

#@torch.jit.script
def Yl8_m_minus_3(theta, phi):
    return 0.0028519853513317*(1.0 - cos(theta)**2)**1.5*(16891.875*cos(theta)**5 - 11261.25*cos(theta)**3 + 1299.375*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl8_m_minus_2(theta, phi):
    return 0.0231696385236779*(1.0 - cos(theta)**2)*(2815.3125*cos(theta)**6 - 2815.3125*cos(theta)**4 + 649.6875*cos(theta)**2 - 19.6875)*sin(2*phi)

#@torch.jit.script
def Yl8_m_minus_1(theta, phi):
    return 0.193851103820053*(1.0 - cos(theta)**2)**0.5*(402.1875*cos(theta)**7 - 563.0625*cos(theta)**5 + 216.5625*cos(theta)**3 - 19.6875*cos(theta))*sin(phi)

#@torch.jit.script
def Yl8_m0(theta, phi):
    return 183.699503695146*cos(theta)**8 - 342.905740230939*cos(theta)**6 + 197.830234748619*cos(theta)**4 - 35.9691335906579*cos(theta)**2 + 0.999142599740499

#@torch.jit.script
def Yl8_m1(theta, phi):
    return 0.193851103820053*(1.0 - cos(theta)**2)**0.5*(402.1875*cos(theta)**7 - 563.0625*cos(theta)**5 + 216.5625*cos(theta)**3 - 19.6875*cos(theta))*cos(phi)

#@torch.jit.script
def Yl8_m2(theta, phi):
    return 0.0231696385236779*(1.0 - cos(theta)**2)*(2815.3125*cos(theta)**6 - 2815.3125*cos(theta)**4 + 649.6875*cos(theta)**2 - 19.6875)*cos(2*phi)

#@torch.jit.script
def Yl8_m3(theta, phi):
    return 0.0028519853513317*(1.0 - cos(theta)**2)**1.5*(16891.875*cos(theta)**5 - 11261.25*cos(theta)**3 + 1299.375*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl8_m4(theta, phi):
    return 0.000368189725644507*(1.0 - cos(theta)**2)**2*(84459.375*cos(theta)**4 - 33783.75*cos(theta)**2 + 1299.375)*cos(4*phi)

#@torch.jit.script
def Yl8_m5(theta, phi):
    return 5.10587282657803e-5*(1.0 - cos(theta)**2)**2.5*(337837.5*cos(theta)**3 - 67567.5*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl8_m6(theta, phi):
    return 7.87853281621404e-6*(1.0 - cos(theta)**2)**3*(1013512.5*cos(theta)**2 - 67567.5)*cos(6*phi)

#@torch.jit.script
def Yl8_m7(theta, phi):
    return 2.91570664069932*(1.0 - cos(theta)**2)**3.5*cos(7*phi)*cos(theta)

#@torch.jit.script
def Yl8_m8(theta, phi):
    return 0.72892666017483*(1.0 - cos(theta)**2)**4*cos(8*phi)

#@torch.jit.script
def Yl9_m_minus_9(theta, phi):
    return 0.748900951853188*(1.0 - cos(theta)**2)**4.5*sin(9*phi)

#@torch.jit.script
def Yl9_m_minus_8(theta, phi):
    return 3.1773176489547*(1.0 - cos(theta)**2)**4*sin(8*phi)*cos(theta)

#@torch.jit.script
def Yl9_m_minus_7(theta, phi):
    return 5.37640612566745e-7*(1.0 - cos(theta)**2)**3.5*(17229712.5*cos(theta)**2 - 1013512.5)*sin(7*phi)

#@torch.jit.script
def Yl9_m_minus_6(theta, phi):
    return 3.72488342871223e-6*(1.0 - cos(theta)**2)**3*(5743237.5*cos(theta)**3 - 1013512.5*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl9_m_minus_5(theta, phi):
    return 2.88528229719329e-5*(1.0 - cos(theta)**2)**2.5*(1435809.375*cos(theta)**4 - 506756.25*cos(theta)**2 + 16891.875)*sin(5*phi)

#@torch.jit.script
def Yl9_m_minus_4(theta, phi):
    return 0.000241400036332803*(1.0 - cos(theta)**2)**2*(287161.875*cos(theta)**5 - 168918.75*cos(theta)**3 + 16891.875*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl9_m_minus_3(theta, phi):
    return 0.00213198739401417*(1.0 - cos(theta)**2)**1.5*(47860.3125*cos(theta)**6 - 42229.6875*cos(theta)**4 + 8445.9375*cos(theta)**2 - 216.5625)*sin(3*phi)

#@torch.jit.script
def Yl9_m_minus_2(theta, phi):
    return 0.0195399872275232*(1.0 - cos(theta)**2)*(6837.1875*cos(theta)**7 - 8445.9375*cos(theta)**5 + 2815.3125*cos(theta)**3 - 216.5625*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl9_m_minus_1(theta, phi):
    return 0.183301328077446*(1.0 - cos(theta)**2)**0.5*(854.6484375*cos(theta)**8 - 1407.65625*cos(theta)**6 + 703.828125*cos(theta)**4 - 108.28125*cos(theta)**2 + 2.4609375)*sin(phi)

#@torch.jit.script
def Yl9_m0(theta, phi):
    return 366.831595457261*cos(theta)**9 - 776.819849203611*cos(theta)**7 + 543.773894442528*cos(theta)**5 - 139.429203703212*cos(theta)**3 + 9.50653661612811*cos(theta)

#@torch.jit.script
def Yl9_m1(theta, phi):
    return 0.183301328077446*(1.0 - cos(theta)**2)**0.5*(854.6484375*cos(theta)**8 - 1407.65625*cos(theta)**6 + 703.828125*cos(theta)**4 - 108.28125*cos(theta)**2 + 2.4609375)*cos(phi)

#@torch.jit.script
def Yl9_m2(theta, phi):
    return 0.0195399872275232*(1.0 - cos(theta)**2)*(6837.1875*cos(theta)**7 - 8445.9375*cos(theta)**5 + 2815.3125*cos(theta)**3 - 216.5625*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl9_m3(theta, phi):
    return 0.00213198739401417*(1.0 - cos(theta)**2)**1.5*(47860.3125*cos(theta)**6 - 42229.6875*cos(theta)**4 + 8445.9375*cos(theta)**2 - 216.5625)*cos(3*phi)

#@torch.jit.script
def Yl9_m4(theta, phi):
    return 0.000241400036332803*(1.0 - cos(theta)**2)**2*(287161.875*cos(theta)**5 - 168918.75*cos(theta)**3 + 16891.875*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl9_m5(theta, phi):
    return 2.88528229719329e-5*(1.0 - cos(theta)**2)**2.5*(1435809.375*cos(theta)**4 - 506756.25*cos(theta)**2 + 16891.875)*cos(5*phi)

#@torch.jit.script
def Yl9_m6(theta, phi):
    return 3.72488342871223e-6*(1.0 - cos(theta)**2)**3*(5743237.5*cos(theta)**3 - 1013512.5*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl9_m7(theta, phi):
    return 5.37640612566745e-7*(1.0 - cos(theta)**2)**3.5*(17229712.5*cos(theta)**2 - 1013512.5)*cos(7*phi)

#@torch.jit.script
def Yl9_m8(theta, phi):
    return 3.1773176489547*(1.0 - cos(theta)**2)**4*cos(8*phi)*cos(theta)

#@torch.jit.script
def Yl9_m9(theta, phi):
    return 0.748900951853188*(1.0 - cos(theta)**2)**4.5*cos(9*phi)

#@torch.jit.script
def Yl10_m_minus_10(theta, phi):
    return 0.76739511822199*(1.0 - cos(theta)**2)**5*sin(10*phi)

#@torch.jit.script
def Yl10_m_minus_9(theta, phi):
    return 3.43189529989171*(1.0 - cos(theta)**2)**4.5*sin(9*phi)*cos(theta)

#@torch.jit.script
def Yl10_m_minus_8(theta, phi):
    return 3.23120268385452e-8*(1.0 - cos(theta)**2)**4*(327364537.5*cos(theta)**2 - 17229712.5)*sin(8*phi)

#@torch.jit.script
def Yl10_m_minus_7(theta, phi):
    return 2.37443934928654e-7*(1.0 - cos(theta)**2)**3.5*(109121512.5*cos(theta)**3 - 17229712.5*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl10_m_minus_6(theta, phi):
    return 1.95801284774625e-6*(1.0 - cos(theta)**2)**3*(27280378.125*cos(theta)**4 - 8614856.25*cos(theta)**2 + 253378.125)*sin(6*phi)

#@torch.jit.script
def Yl10_m_minus_5(theta, phi):
    return 1.75129993135143e-5*(1.0 - cos(theta)**2)**2.5*(5456075.625*cos(theta)**5 - 2871618.75*cos(theta)**3 + 253378.125*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl10_m_minus_4(theta, phi):
    return 0.000166142899475011*(1.0 - cos(theta)**2)**2*(909345.9375*cos(theta)**6 - 717904.6875*cos(theta)**4 + 126689.0625*cos(theta)**2 - 2815.3125)*sin(4*phi)

#@torch.jit.script
def Yl10_m_minus_3(theta, phi):
    return 0.00164473079210685*(1.0 - cos(theta)**2)**1.5*(129906.5625*cos(theta)**7 - 143580.9375*cos(theta)**5 + 42229.6875*cos(theta)**3 - 2815.3125*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl10_m_minus_2(theta, phi):
    return 0.0167730288071195*(1.0 - cos(theta)**2)*(16238.3203125*cos(theta)**8 - 23930.15625*cos(theta)**6 + 10557.421875*cos(theta)**4 - 1407.65625*cos(theta)**2 + 27.0703125)*sin(2*phi)

#@torch.jit.script
def Yl10_m_minus_1(theta, phi):
    return 0.174310428544485*(1.0 - cos(theta)**2)**0.5*(1804.2578125*cos(theta)**9 - 3418.59375*cos(theta)**7 + 2111.484375*cos(theta)**5 - 469.21875*cos(theta)**3 + 27.0703125*cos(theta))*sin(phi)

#@torch.jit.script
def Yl10_m0(theta, phi):
    return 732.745538033921*cos(theta)**10 - 1735.44995850139*cos(theta)**8 + 1429.19408347173*cos(theta)**6 - 476.398027823912*cos(theta)**4 + 54.9690032104513*cos(theta)**2 - 0.999436422008206

#@torch.jit.script
def Yl10_m1(theta, phi):
    return 0.174310428544485*(1.0 - cos(theta)**2)**0.5*(1804.2578125*cos(theta)**9 - 3418.59375*cos(theta)**7 + 2111.484375*cos(theta)**5 - 469.21875*cos(theta)**3 + 27.0703125*cos(theta))*cos(phi)

#@torch.jit.script
def Yl10_m2(theta, phi):
    return 0.0167730288071195*(1.0 - cos(theta)**2)*(16238.3203125*cos(theta)**8 - 23930.15625*cos(theta)**6 + 10557.421875*cos(theta)**4 - 1407.65625*cos(theta)**2 + 27.0703125)*cos(2*phi)

#@torch.jit.script
def Yl10_m3(theta, phi):
    return 0.00164473079210685*(1.0 - cos(theta)**2)**1.5*(129906.5625*cos(theta)**7 - 143580.9375*cos(theta)**5 + 42229.6875*cos(theta)**3 - 2815.3125*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl10_m4(theta, phi):
    return 0.000166142899475011*(1.0 - cos(theta)**2)**2*(909345.9375*cos(theta)**6 - 717904.6875*cos(theta)**4 + 126689.0625*cos(theta)**2 - 2815.3125)*cos(4*phi)

#@torch.jit.script
def Yl10_m5(theta, phi):
    return 1.75129993135143e-5*(1.0 - cos(theta)**2)**2.5*(5456075.625*cos(theta)**5 - 2871618.75*cos(theta)**3 + 253378.125*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl10_m6(theta, phi):
    return 1.95801284774625e-6*(1.0 - cos(theta)**2)**3*(27280378.125*cos(theta)**4 - 8614856.25*cos(theta)**2 + 253378.125)*cos(6*phi)

#@torch.jit.script
def Yl10_m7(theta, phi):
    return 2.37443934928654e-7*(1.0 - cos(theta)**2)**3.5*(109121512.5*cos(theta)**3 - 17229712.5*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl10_m8(theta, phi):
    return 3.23120268385452e-8*(1.0 - cos(theta)**2)**4*(327364537.5*cos(theta)**2 - 17229712.5)*cos(8*phi)

#@torch.jit.script
def Yl10_m9(theta, phi):
    return 3.43189529989171*(1.0 - cos(theta)**2)**4.5*cos(9*phi)*cos(theta)

#@torch.jit.script
def Yl10_m10(theta, phi):
    return 0.76739511822199*(1.0 - cos(theta)**2)**5*cos(10*phi)

#@torch.jit.script
def Yl11_m_minus_11(theta, phi):
    return 0.784642105787197*(1.0 - cos(theta)**2)**5.5*sin(11*phi)

#@torch.jit.script
def Yl11_m_minus_10(theta, phi):
    return 3.68029769880531*(1.0 - cos(theta)**2)**5*sin(10*phi)*cos(theta)

#@torch.jit.script
def Yl11_m_minus_9(theta, phi):
    return 1.73470916587426e-9*(1.0 - cos(theta)**2)**4.5*(6874655287.5*cos(theta)**2 - 327364537.5)*sin(9*phi)

#@torch.jit.script
def Yl11_m_minus_8(theta, phi):
    return 1.34369994198887e-8*(1.0 - cos(theta)**2)**4*(2291551762.5*cos(theta)**3 - 327364537.5*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl11_m_minus_7(theta, phi):
    return 1.17141045151419e-7*(1.0 - cos(theta)**2)**3.5*(572887940.625*cos(theta)**4 - 163682268.75*cos(theta)**2 + 4307428.125)*sin(7*phi)

#@torch.jit.script
def Yl11_m_minus_6(theta, phi):
    return 1.11129753051333e-6*(1.0 - cos(theta)**2)**3*(114577588.125*cos(theta)**5 - 54560756.25*cos(theta)**3 + 4307428.125*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl11_m_minus_5(theta, phi):
    return 1.12235548974089e-5*(1.0 - cos(theta)**2)**2.5*(19096264.6875*cos(theta)**6 - 13640189.0625*cos(theta)**4 + 2153714.0625*cos(theta)**2 - 42229.6875)*sin(5*phi)

#@torch.jit.script
def Yl11_m_minus_4(theta, phi):
    return 0.0001187789403385*(1.0 - cos(theta)**2)**2*(2728037.8125*cos(theta)**7 - 2728037.8125*cos(theta)**5 + 717904.6875*cos(theta)**3 - 42229.6875*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl11_m_minus_3(theta, phi):
    return 0.00130115809959914*(1.0 - cos(theta)**2)**1.5*(341004.7265625*cos(theta)**8 - 454672.96875*cos(theta)**6 + 179476.171875*cos(theta)**4 - 21114.84375*cos(theta)**2 + 351.9140625)*sin(3*phi)

#@torch.jit.script
def Yl11_m_minus_2(theta, phi):
    return 0.0146054634441776*(1.0 - cos(theta)**2)*(37889.4140625*cos(theta)**9 - 64953.28125*cos(theta)**7 + 35895.234375*cos(theta)**5 - 7038.28125*cos(theta)**3 + 351.9140625*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl11_m_minus_1(theta, phi):
    return 0.166527904912351*(1.0 - cos(theta)**2)**0.5*(3788.94140625*cos(theta)**10 - 8119.16015625*cos(theta)**8 + 5982.5390625*cos(theta)**6 - 1759.5703125*cos(theta)**4 + 175.95703125*cos(theta)**2 - 2.70703125)*sin(phi)

#@torch.jit.script
def Yl11_m0(theta, phi):
    return 1463.97635620462*cos(theta)**11 - 3834.22379005971*cos(theta)**9 + 3632.4225379513*cos(theta)**7 - 1495.70339797995*cos(theta)**5 + 249.283899663325*cos(theta)**3 - 11.5054107536919*cos(theta)

#@torch.jit.script
def Yl11_m1(theta, phi):
    return 0.166527904912351*(1.0 - cos(theta)**2)**0.5*(3788.94140625*cos(theta)**10 - 8119.16015625*cos(theta)**8 + 5982.5390625*cos(theta)**6 - 1759.5703125*cos(theta)**4 + 175.95703125*cos(theta)**2 - 2.70703125)*cos(phi)

#@torch.jit.script
def Yl11_m2(theta, phi):
    return 0.0146054634441776*(1.0 - cos(theta)**2)*(37889.4140625*cos(theta)**9 - 64953.28125*cos(theta)**7 + 35895.234375*cos(theta)**5 - 7038.28125*cos(theta)**3 + 351.9140625*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl11_m3(theta, phi):
    return 0.00130115809959914*(1.0 - cos(theta)**2)**1.5*(341004.7265625*cos(theta)**8 - 454672.96875*cos(theta)**6 + 179476.171875*cos(theta)**4 - 21114.84375*cos(theta)**2 + 351.9140625)*cos(3*phi)

#@torch.jit.script
def Yl11_m4(theta, phi):
    return 0.0001187789403385*(1.0 - cos(theta)**2)**2*(2728037.8125*cos(theta)**7 - 2728037.8125*cos(theta)**5 + 717904.6875*cos(theta)**3 - 42229.6875*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl11_m5(theta, phi):
    return 1.12235548974089e-5*(1.0 - cos(theta)**2)**2.5*(19096264.6875*cos(theta)**6 - 13640189.0625*cos(theta)**4 + 2153714.0625*cos(theta)**2 - 42229.6875)*cos(5*phi)

#@torch.jit.script
def Yl11_m6(theta, phi):
    return 1.11129753051333e-6*(1.0 - cos(theta)**2)**3*(114577588.125*cos(theta)**5 - 54560756.25*cos(theta)**3 + 4307428.125*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl11_m7(theta, phi):
    return 1.17141045151419e-7*(1.0 - cos(theta)**2)**3.5*(572887940.625*cos(theta)**4 - 163682268.75*cos(theta)**2 + 4307428.125)*cos(7*phi)

#@torch.jit.script
def Yl11_m8(theta, phi):
    return 1.34369994198887e-8*(1.0 - cos(theta)**2)**4*(2291551762.5*cos(theta)**3 - 327364537.5*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl11_m9(theta, phi):
    return 1.73470916587426e-9*(1.0 - cos(theta)**2)**4.5*(6874655287.5*cos(theta)**2 - 327364537.5)*cos(9*phi)

#@torch.jit.script
def Yl11_m10(theta, phi):
    return 3.68029769880531*(1.0 - cos(theta)**2)**5*cos(10*phi)*cos(theta)

#@torch.jit.script
def Yl11_m11(theta, phi):
    return 0.784642105787197*(1.0 - cos(theta)**2)**5.5*cos(11*phi)

#@torch.jit.script
def Yl12_m_minus_12(theta, phi):
    return 0.800821995783972*(1.0 - cos(theta)**2)**6*sin(12*phi)

#@torch.jit.script
def Yl12_m_minus_11(theta, phi):
    return 3.92321052893598*(1.0 - cos(theta)**2)**5.5*sin(11*phi)*cos(theta)

#@torch.jit.script
def Yl12_m_minus_10(theta, phi):
    return 8.4141794839602e-11*(1.0 - cos(theta)**2)**5*(158117071612.5*cos(theta)**2 - 6874655287.5)*sin(10*phi)

#@torch.jit.script
def Yl12_m_minus_9(theta, phi):
    return 6.83571172711927e-10*(1.0 - cos(theta)**2)**4.5*(52705690537.5*cos(theta)**3 - 6874655287.5*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl12_m_minus_8(theta, phi):
    return 6.26503328368427e-9*(1.0 - cos(theta)**2)**4*(13176422634.375*cos(theta)**4 - 3437327643.75*cos(theta)**2 + 81841134.375)*sin(8*phi)

#@torch.jit.script
def Yl12_m_minus_7(theta, phi):
    return 6.26503328368427e-8*(1.0 - cos(theta)**2)**3.5*(2635284526.875*cos(theta)**5 - 1145775881.25*cos(theta)**3 + 81841134.375*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl12_m_minus_6(theta, phi):
    return 6.68922506214776e-7*(1.0 - cos(theta)**2)**3*(439214087.8125*cos(theta)**6 - 286443970.3125*cos(theta)**4 + 40920567.1875*cos(theta)**2 - 717904.6875)*sin(6*phi)

#@torch.jit.script
def Yl12_m_minus_5(theta, phi):
    return 7.50863650967357e-6*(1.0 - cos(theta)**2)**2.5*(62744869.6875*cos(theta)**7 - 57288794.0625*cos(theta)**5 + 13640189.0625*cos(theta)**3 - 717904.6875*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl12_m_minus_4(theta, phi):
    return 8.75649965675714e-5*(1.0 - cos(theta)**2)**2*(7843108.7109375*cos(theta)**8 - 9548132.34375*cos(theta)**6 + 3410047.265625*cos(theta)**4 - 358952.34375*cos(theta)**2 + 5278.7109375)*sin(4*phi)

#@torch.jit.script
def Yl12_m_minus_3(theta, phi):
    return 0.00105077995881086*(1.0 - cos(theta)**2)**1.5*(871456.5234375*cos(theta)**9 - 1364018.90625*cos(theta)**7 + 682009.453125*cos(theta)**5 - 119650.78125*cos(theta)**3 + 5278.7109375*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl12_m_minus_2(theta, phi):
    return 0.0128693736551466*(1.0 - cos(theta)**2)*(87145.65234375*cos(theta)**10 - 170502.36328125*cos(theta)**8 + 113668.2421875*cos(theta)**6 - 29912.6953125*cos(theta)**4 + 2639.35546875*cos(theta)**2 - 35.19140625)*sin(2*phi)

#@torch.jit.script
def Yl12_m_minus_1(theta, phi):
    return 0.159704727088682*(1.0 - cos(theta)**2)**0.5*(7922.33203125*cos(theta)**11 - 18944.70703125*cos(theta)**9 + 16238.3203125*cos(theta)**7 - 5982.5390625*cos(theta)**5 + 879.78515625*cos(theta)**3 - 35.19140625*cos(theta))*sin(phi)

#@torch.jit.script
def Yl12_m0(theta, phi):
    return 2925.40998269608*cos(theta)**12 - 8394.65473295397*cos(theta)**10 + 8994.27292816496*cos(theta)**8 - 4418.23933313367*cos(theta)**6 + 974.611617603015*cos(theta)**4 - 77.9689294082412*cos(theta)**2 + 0.999601659080015

#@torch.jit.script
def Yl12_m1(theta, phi):
    return 0.159704727088682*(1.0 - cos(theta)**2)**0.5*(7922.33203125*cos(theta)**11 - 18944.70703125*cos(theta)**9 + 16238.3203125*cos(theta)**7 - 5982.5390625*cos(theta)**5 + 879.78515625*cos(theta)**3 - 35.19140625*cos(theta))*cos(phi)

#@torch.jit.script
def Yl12_m2(theta, phi):
    return 0.0128693736551466*(1.0 - cos(theta)**2)*(87145.65234375*cos(theta)**10 - 170502.36328125*cos(theta)**8 + 113668.2421875*cos(theta)**6 - 29912.6953125*cos(theta)**4 + 2639.35546875*cos(theta)**2 - 35.19140625)*cos(2*phi)

#@torch.jit.script
def Yl12_m3(theta, phi):
    return 0.00105077995881086*(1.0 - cos(theta)**2)**1.5*(871456.5234375*cos(theta)**9 - 1364018.90625*cos(theta)**7 + 682009.453125*cos(theta)**5 - 119650.78125*cos(theta)**3 + 5278.7109375*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl12_m4(theta, phi):
    return 8.75649965675714e-5*(1.0 - cos(theta)**2)**2*(7843108.7109375*cos(theta)**8 - 9548132.34375*cos(theta)**6 + 3410047.265625*cos(theta)**4 - 358952.34375*cos(theta)**2 + 5278.7109375)*cos(4*phi)

#@torch.jit.script
def Yl12_m5(theta, phi):
    return 7.50863650967357e-6*(1.0 - cos(theta)**2)**2.5*(62744869.6875*cos(theta)**7 - 57288794.0625*cos(theta)**5 + 13640189.0625*cos(theta)**3 - 717904.6875*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl12_m6(theta, phi):
    return 6.68922506214776e-7*(1.0 - cos(theta)**2)**3*(439214087.8125*cos(theta)**6 - 286443970.3125*cos(theta)**4 + 40920567.1875*cos(theta)**2 - 717904.6875)*cos(6*phi)

#@torch.jit.script
def Yl12_m7(theta, phi):
    return 6.26503328368427e-8*(1.0 - cos(theta)**2)**3.5*(2635284526.875*cos(theta)**5 - 1145775881.25*cos(theta)**3 + 81841134.375*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl12_m8(theta, phi):
    return 6.26503328368427e-9*(1.0 - cos(theta)**2)**4*(13176422634.375*cos(theta)**4 - 3437327643.75*cos(theta)**2 + 81841134.375)*cos(8*phi)

#@torch.jit.script
def Yl12_m9(theta, phi):
    return 6.83571172711927e-10*(1.0 - cos(theta)**2)**4.5*(52705690537.5*cos(theta)**3 - 6874655287.5*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl12_m10(theta, phi):
    return 8.4141794839602e-11*(1.0 - cos(theta)**2)**5*(158117071612.5*cos(theta)**2 - 6874655287.5)*cos(10*phi)

#@torch.jit.script
def Yl12_m11(theta, phi):
    return 3.92321052893598*(1.0 - cos(theta)**2)**5.5*cos(11*phi)*cos(theta)

#@torch.jit.script
def Yl12_m12(theta, phi):
    return 0.800821995783972*(1.0 - cos(theta)**2)**6*cos(12*phi)

#@torch.jit.script
def Yl13_m_minus_13(theta, phi):
    return 0.816077118837628*(1.0 - cos(theta)**2)**6.5*sin(13*phi)

#@torch.jit.script
def Yl13_m_minus_12(theta, phi):
    return 4.16119315354964*(1.0 - cos(theta)**2)**6*sin(12*phi)*cos(theta)

#@torch.jit.script
def Yl13_m_minus_11(theta, phi):
    return 3.72180924766049e-12*(1.0 - cos(theta)**2)**5.5*(3952926790312.5*cos(theta)**2 - 158117071612.5)*sin(11*phi)

#@torch.jit.script
def Yl13_m_minus_10(theta, phi):
    return 3.15805986876424e-11*(1.0 - cos(theta)**2)**5*(1317642263437.5*cos(theta)**3 - 158117071612.5*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl13_m_minus_9(theta, phi):
    return 3.02910461422567e-10*(1.0 - cos(theta)**2)**4.5*(329410565859.375*cos(theta)**4 - 79058535806.25*cos(theta)**2 + 1718663821.875)*sin(9*phi)

#@torch.jit.script
def Yl13_m_minus_8(theta, phi):
    return 3.17695172143292e-9*(1.0 - cos(theta)**2)**4*(65882113171.875*cos(theta)**5 - 26352845268.75*cos(theta)**3 + 1718663821.875*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl13_m_minus_7(theta, phi):
    return 3.5661194627771e-8*(1.0 - cos(theta)**2)**3.5*(10980352195.3125*cos(theta)**6 - 6588211317.1875*cos(theta)**4 + 859331910.9375*cos(theta)**2 - 13640189.0625)*sin(7*phi)

#@torch.jit.script
def Yl13_m_minus_6(theta, phi):
    return 4.21948945157073e-7*(1.0 - cos(theta)**2)**3*(1568621742.1875*cos(theta)**7 - 1317642263.4375*cos(theta)**5 + 286443970.3125*cos(theta)**3 - 13640189.0625*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl13_m_minus_5(theta, phi):
    return 5.2021359721285e-6*(1.0 - cos(theta)**2)**2.5*(196077717.773438*cos(theta)**8 - 219607043.90625*cos(theta)**6 + 71610992.578125*cos(theta)**4 - 6820094.53125*cos(theta)**2 + 89738.0859375)*sin(5*phi)

#@torch.jit.script
def Yl13_m_minus_4(theta, phi):
    return 6.62123812058377e-5*(1.0 - cos(theta)**2)**2*(21786413.0859375*cos(theta)**9 - 31372434.84375*cos(theta)**7 + 14322198.515625*cos(theta)**5 - 2273364.84375*cos(theta)**3 + 89738.0859375*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl13_m_minus_3(theta, phi):
    return 0.000863303829622583*(1.0 - cos(theta)**2)**1.5*(2178641.30859375*cos(theta)**10 - 3921554.35546875*cos(theta)**8 + 2387033.0859375*cos(theta)**6 - 568341.2109375*cos(theta)**4 + 44869.04296875*cos(theta)**2 - 527.87109375)*sin(3*phi)

#@torch.jit.script
def Yl13_m_minus_2(theta, phi):
    return 0.0114530195317401*(1.0 - cos(theta)**2)*(198058.30078125*cos(theta)**11 - 435728.26171875*cos(theta)**9 + 341004.7265625*cos(theta)**7 - 113668.2421875*cos(theta)**5 + 14956.34765625*cos(theta)**3 - 527.87109375*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl13_m_minus_1(theta, phi):
    return 0.153658381323621*(1.0 - cos(theta)**2)**0.5*(16504.8583984375*cos(theta)**12 - 43572.826171875*cos(theta)**10 + 42625.5908203125*cos(theta)**8 - 18944.70703125*cos(theta)**6 + 3739.0869140625*cos(theta)**4 - 263.935546875*cos(theta)**2 + 2.9326171875)*sin(phi)

#@torch.jit.script
def Yl13_m0(theta, phi):
    return 5846.49083422938*cos(theta)**13 - 18241.0514027957*cos(theta)**11 + 21809.9527642122*cos(theta)**9 - 12462.8301509784*cos(theta)**7 + 3443.67675224404*cos(theta)**5 - 405.138441440475*cos(theta)**3 + 13.5046147146825*cos(theta)

#@torch.jit.script
def Yl13_m1(theta, phi):
    return 0.153658381323621*(1.0 - cos(theta)**2)**0.5*(16504.8583984375*cos(theta)**12 - 43572.826171875*cos(theta)**10 + 42625.5908203125*cos(theta)**8 - 18944.70703125*cos(theta)**6 + 3739.0869140625*cos(theta)**4 - 263.935546875*cos(theta)**2 + 2.9326171875)*cos(phi)

#@torch.jit.script
def Yl13_m2(theta, phi):
    return 0.0114530195317401*(1.0 - cos(theta)**2)*(198058.30078125*cos(theta)**11 - 435728.26171875*cos(theta)**9 + 341004.7265625*cos(theta)**7 - 113668.2421875*cos(theta)**5 + 14956.34765625*cos(theta)**3 - 527.87109375*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl13_m3(theta, phi):
    return 0.000863303829622583*(1.0 - cos(theta)**2)**1.5*(2178641.30859375*cos(theta)**10 - 3921554.35546875*cos(theta)**8 + 2387033.0859375*cos(theta)**6 - 568341.2109375*cos(theta)**4 + 44869.04296875*cos(theta)**2 - 527.87109375)*cos(3*phi)

#@torch.jit.script
def Yl13_m4(theta, phi):
    return 6.62123812058377e-5*(1.0 - cos(theta)**2)**2*(21786413.0859375*cos(theta)**9 - 31372434.84375*cos(theta)**7 + 14322198.515625*cos(theta)**5 - 2273364.84375*cos(theta)**3 + 89738.0859375*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl13_m5(theta, phi):
    return 5.2021359721285e-6*(1.0 - cos(theta)**2)**2.5*(196077717.773438*cos(theta)**8 - 219607043.90625*cos(theta)**6 + 71610992.578125*cos(theta)**4 - 6820094.53125*cos(theta)**2 + 89738.0859375)*cos(5*phi)

#@torch.jit.script
def Yl13_m6(theta, phi):
    return 4.21948945157073e-7*(1.0 - cos(theta)**2)**3*(1568621742.1875*cos(theta)**7 - 1317642263.4375*cos(theta)**5 + 286443970.3125*cos(theta)**3 - 13640189.0625*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl13_m7(theta, phi):
    return 3.5661194627771e-8*(1.0 - cos(theta)**2)**3.5*(10980352195.3125*cos(theta)**6 - 6588211317.1875*cos(theta)**4 + 859331910.9375*cos(theta)**2 - 13640189.0625)*cos(7*phi)

#@torch.jit.script
def Yl13_m8(theta, phi):
    return 3.17695172143292e-9*(1.0 - cos(theta)**2)**4*(65882113171.875*cos(theta)**5 - 26352845268.75*cos(theta)**3 + 1718663821.875*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl13_m9(theta, phi):
    return 3.02910461422567e-10*(1.0 - cos(theta)**2)**4.5*(329410565859.375*cos(theta)**4 - 79058535806.25*cos(theta)**2 + 1718663821.875)*cos(9*phi)

#@torch.jit.script
def Yl13_m10(theta, phi):
    return 3.15805986876424e-11*(1.0 - cos(theta)**2)**5*(1317642263437.5*cos(theta)**3 - 158117071612.5*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl13_m11(theta, phi):
    return 3.72180924766049e-12*(1.0 - cos(theta)**2)**5.5*(3952926790312.5*cos(theta)**2 - 158117071612.5)*cos(11*phi)

#@torch.jit.script
def Yl13_m12(theta, phi):
    return 4.16119315354964*(1.0 - cos(theta)**2)**6*cos(12*phi)*cos(theta)

#@torch.jit.script
def Yl13_m13(theta, phi):
    return 0.816077118837628*(1.0 - cos(theta)**2)**6.5*cos(13*phi)

#@torch.jit.script
def Yl14_m_minus_14(theta, phi):
    return 0.830522083064524*(1.0 - cos(theta)**2)**7*sin(14*phi)

#@torch.jit.script
def Yl14_m_minus_13(theta, phi):
    return 4.39470978027212*(1.0 - cos(theta)**2)**6.5*sin(13*phi)*cos(theta)

#@torch.jit.script
def Yl14_m_minus_12(theta, phi):
    return 1.51291507116349e-13*(1.0 - cos(theta)**2)**6*(106729023338438.0*cos(theta)**2 - 3952926790312.5)*sin(12*phi)

#@torch.jit.script
def Yl14_m_minus_11(theta, phi):
    return 1.33617041195793e-12*(1.0 - cos(theta)**2)**5.5*(35576341112812.5*cos(theta)**3 - 3952926790312.5*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl14_m_minus_10(theta, phi):
    return 1.33617041195793e-11*(1.0 - cos(theta)**2)**5*(8894085278203.13*cos(theta)**4 - 1976463395156.25*cos(theta)**2 + 39529267903.125)*sin(10*phi)

#@torch.jit.script
def Yl14_m_minus_9(theta, phi):
    return 1.46370135060066e-10*(1.0 - cos(theta)**2)**4.5*(1778817055640.63*cos(theta)**5 - 658821131718.75*cos(theta)**3 + 39529267903.125*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl14_m_minus_8(theta, phi):
    return 1.71945976061531e-9*(1.0 - cos(theta)**2)**4*(296469509273.438*cos(theta)**6 - 164705282929.688*cos(theta)**4 + 19764633951.5625*cos(theta)**2 - 286443970.3125)*sin(8*phi)

#@torch.jit.script
def Yl14_m_minus_7(theta, phi):
    return 2.13379344766496e-8*(1.0 - cos(theta)**2)**3.5*(42352787039.0625*cos(theta)**7 - 32941056585.9375*cos(theta)**5 + 6588211317.1875*cos(theta)**3 - 286443970.3125*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl14_m_minus_6(theta, phi):
    return 2.76571240765567e-7*(1.0 - cos(theta)**2)**3*(5294098379.88281*cos(theta)**8 - 5490176097.65625*cos(theta)**6 + 1647052829.29688*cos(theta)**4 - 143221985.15625*cos(theta)**2 + 1705023.6328125)*sin(6*phi)

#@torch.jit.script
def Yl14_m_minus_5(theta, phi):
    return 3.71059256983961e-6*(1.0 - cos(theta)**2)**2.5*(588233153.320313*cos(theta)**9 - 784310871.09375*cos(theta)**7 + 329410565.859375*cos(theta)**5 - 47740661.71875*cos(theta)**3 + 1705023.6328125*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl14_m_minus_4(theta, phi):
    return 5.11469888818129e-5*(1.0 - cos(theta)**2)**2*(58823315.3320313*cos(theta)**10 - 98038858.8867188*cos(theta)**8 + 54901760.9765625*cos(theta)**6 - 11935165.4296875*cos(theta)**4 + 852511.81640625*cos(theta)**2 - 8973.80859375)*sin(4*phi)

#@torch.jit.script
def Yl14_m_minus_3(theta, phi):
    return 0.000719701928156307*(1.0 - cos(theta)**2)**1.5*(5347574.12109375*cos(theta)**11 - 10893206.5429688*cos(theta)**9 + 7843108.7109375*cos(theta)**7 - 2387033.0859375*cos(theta)**5 + 284170.60546875*cos(theta)**3 - 8973.80859375*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl14_m_minus_2(theta, phi):
    return 0.0102793996196251*(1.0 - cos(theta)**2)*(445631.176757813*cos(theta)**12 - 1089320.65429688*cos(theta)**10 + 980388.588867188*cos(theta)**8 - 397838.84765625*cos(theta)**6 + 71042.6513671875*cos(theta)**4 - 4486.904296875*cos(theta)**2 + 43.9892578125)*sin(2*phi)

#@torch.jit.script
def Yl14_m_minus_1(theta, phi):
    return 0.148251609638173*(1.0 - cos(theta)**2)**0.5*(34279.3212890625*cos(theta)**13 - 99029.150390625*cos(theta)**11 + 108932.065429688*cos(theta)**9 - 56834.12109375*cos(theta)**7 + 14208.5302734375*cos(theta)**5 - 1495.634765625*cos(theta)**3 + 43.9892578125*cos(theta))*sin(phi)

#@torch.jit.script
def Yl14_m0(theta, phi):
    return 11685.5220302715*cos(theta)**14 - 39384.5372131372*cos(theta)**12 + 51987.5891213411*cos(theta)**10 - 33904.9494269616*cos(theta)**8 + 11301.6498089872*cos(theta)**6 - 1784.47102247166*cos(theta)**4 + 104.968883674804*cos(theta)**2 - 0.99970365404575

#@torch.jit.script
def Yl14_m1(theta, phi):
    return 0.148251609638173*(1.0 - cos(theta)**2)**0.5*(34279.3212890625*cos(theta)**13 - 99029.150390625*cos(theta)**11 + 108932.065429688*cos(theta)**9 - 56834.12109375*cos(theta)**7 + 14208.5302734375*cos(theta)**5 - 1495.634765625*cos(theta)**3 + 43.9892578125*cos(theta))*cos(phi)

#@torch.jit.script
def Yl14_m2(theta, phi):
    return 0.0102793996196251*(1.0 - cos(theta)**2)*(445631.176757813*cos(theta)**12 - 1089320.65429688*cos(theta)**10 + 980388.588867188*cos(theta)**8 - 397838.84765625*cos(theta)**6 + 71042.6513671875*cos(theta)**4 - 4486.904296875*cos(theta)**2 + 43.9892578125)*cos(2*phi)

#@torch.jit.script
def Yl14_m3(theta, phi):
    return 0.000719701928156307*(1.0 - cos(theta)**2)**1.5*(5347574.12109375*cos(theta)**11 - 10893206.5429688*cos(theta)**9 + 7843108.7109375*cos(theta)**7 - 2387033.0859375*cos(theta)**5 + 284170.60546875*cos(theta)**3 - 8973.80859375*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl14_m4(theta, phi):
    return 5.11469888818129e-5*(1.0 - cos(theta)**2)**2*(58823315.3320313*cos(theta)**10 - 98038858.8867188*cos(theta)**8 + 54901760.9765625*cos(theta)**6 - 11935165.4296875*cos(theta)**4 + 852511.81640625*cos(theta)**2 - 8973.80859375)*cos(4*phi)

#@torch.jit.script
def Yl14_m5(theta, phi):
    return 3.71059256983961e-6*(1.0 - cos(theta)**2)**2.5*(588233153.320313*cos(theta)**9 - 784310871.09375*cos(theta)**7 + 329410565.859375*cos(theta)**5 - 47740661.71875*cos(theta)**3 + 1705023.6328125*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl14_m6(theta, phi):
    return 2.76571240765567e-7*(1.0 - cos(theta)**2)**3*(5294098379.88281*cos(theta)**8 - 5490176097.65625*cos(theta)**6 + 1647052829.29688*cos(theta)**4 - 143221985.15625*cos(theta)**2 + 1705023.6328125)*cos(6*phi)

#@torch.jit.script
def Yl14_m7(theta, phi):
    return 2.13379344766496e-8*(1.0 - cos(theta)**2)**3.5*(42352787039.0625*cos(theta)**7 - 32941056585.9375*cos(theta)**5 + 6588211317.1875*cos(theta)**3 - 286443970.3125*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl14_m8(theta, phi):
    return 1.71945976061531e-9*(1.0 - cos(theta)**2)**4*(296469509273.438*cos(theta)**6 - 164705282929.688*cos(theta)**4 + 19764633951.5625*cos(theta)**2 - 286443970.3125)*cos(8*phi)

#@torch.jit.script
def Yl14_m9(theta, phi):
    return 1.46370135060066e-10*(1.0 - cos(theta)**2)**4.5*(1778817055640.63*cos(theta)**5 - 658821131718.75*cos(theta)**3 + 39529267903.125*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl14_m10(theta, phi):
    return 1.33617041195793e-11*(1.0 - cos(theta)**2)**5*(8894085278203.13*cos(theta)**4 - 1976463395156.25*cos(theta)**2 + 39529267903.125)*cos(10*phi)

#@torch.jit.script
def Yl14_m11(theta, phi):
    return 1.33617041195793e-12*(1.0 - cos(theta)**2)**5.5*(35576341112812.5*cos(theta)**3 - 3952926790312.5*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl14_m12(theta, phi):
    return 1.51291507116349e-13*(1.0 - cos(theta)**2)**6*(106729023338438.0*cos(theta)**2 - 3952926790312.5)*cos(12*phi)

#@torch.jit.script
def Yl14_m13(theta, phi):
    return 4.39470978027212*(1.0 - cos(theta)**2)**6.5*cos(13*phi)*cos(theta)

#@torch.jit.script
def Yl14_m14(theta, phi):
    return 0.830522083064524*(1.0 - cos(theta)**2)**7*cos(14*phi)

#@torch.jit.script
def Yl15_m_minus_15(theta, phi):
    return 0.844250650857373*(1.0 - cos(theta)**2)**7.5*sin(15*phi)

#@torch.jit.script
def Yl15_m_minus_14(theta, phi):
    return 4.62415125663001*(1.0 - cos(theta)**2)**7*sin(14*phi)*cos(theta)

#@torch.jit.script
def Yl15_m_minus_13(theta, phi):
    return 5.68899431025918e-15*(1.0 - cos(theta)**2)**6.5*(3.09514167681469e+15*cos(theta)**2 - 106729023338438.0)*sin(13*phi)

#@torch.jit.script
def Yl15_m_minus_12(theta, phi):
    return 5.21404941098716e-14*(1.0 - cos(theta)**2)**6*(1.03171389227156e+15*cos(theta)**3 - 106729023338438.0*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl15_m_minus_11(theta, phi):
    return 5.4185990958026e-13*(1.0 - cos(theta)**2)**5.5*(257928473067891.0*cos(theta)**4 - 53364511669218.8*cos(theta)**2 + 988231697578.125)*sin(11*phi)

#@torch.jit.script
def Yl15_m_minus_10(theta, phi):
    return 6.17815352749854e-12*(1.0 - cos(theta)**2)**5*(51585694613578.1*cos(theta)**5 - 17788170556406.3*cos(theta)**3 + 988231697578.125*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl15_m_minus_9(theta, phi):
    return 7.56666184747369e-11*(1.0 - cos(theta)**2)**4.5*(8597615768929.69*cos(theta)**6 - 4447042639101.56*cos(theta)**4 + 494115848789.063*cos(theta)**2 - 6588211317.1875)*sin(9*phi)

#@torch.jit.script
def Yl15_m_minus_8(theta, phi):
    return 9.80751467720255e-10*(1.0 - cos(theta)**2)**4*(1228230824132.81*cos(theta)**7 - 889408527820.313*cos(theta)**5 + 164705282929.688*cos(theta)**3 - 6588211317.1875*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl15_m_minus_7(theta, phi):
    return 1.33035601710264e-8*(1.0 - cos(theta)**2)**3.5*(153528853016.602*cos(theta)**8 - 148234754636.719*cos(theta)**6 + 41176320732.4219*cos(theta)**4 - 3294105658.59375*cos(theta)**2 + 35805496.2890625)*sin(7*phi)

#@torch.jit.script
def Yl15_m_minus_6(theta, phi):
    return 1.87197684863824e-7*(1.0 - cos(theta)**2)**3*(17058761446.2891*cos(theta)**9 - 21176393519.5313*cos(theta)**7 + 8235264146.48438*cos(theta)**5 - 1098035219.53125*cos(theta)**3 + 35805496.2890625*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl15_m_minus_5(theta, phi):
    return 2.71275217737612e-6*(1.0 - cos(theta)**2)**2.5*(1705876144.62891*cos(theta)**10 - 2647049189.94141*cos(theta)**8 + 1372544024.41406*cos(theta)**6 - 274508804.882813*cos(theta)**4 + 17902748.1445313*cos(theta)**2 - 170502.36328125)*sin(5*phi)

#@torch.jit.script
def Yl15_m_minus_4(theta, phi):
    return 4.02366171874445e-5*(1.0 - cos(theta)**2)**2*(155079649.511719*cos(theta)**11 - 294116576.660156*cos(theta)**9 + 196077717.773438*cos(theta)**7 - 54901760.9765625*cos(theta)**5 + 5967582.71484375*cos(theta)**3 - 170502.36328125*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl15_m_minus_3(theta, phi):
    return 0.000607559596001151*(1.0 - cos(theta)**2)**1.5*(12923304.1259766*cos(theta)**12 - 29411657.6660156*cos(theta)**10 + 24509714.7216797*cos(theta)**8 - 9150293.49609375*cos(theta)**6 + 1491895.67871094*cos(theta)**4 - 85251.181640625*cos(theta)**2 + 747.8173828125)*sin(3*phi)

#@torch.jit.script
def Yl15_m_minus_2(theta, phi):
    return 0.00929387470704126*(1.0 - cos(theta)**2)*(994100.317382813*cos(theta)**13 - 2673787.06054688*cos(theta)**11 + 2723301.63574219*cos(theta)**9 - 1307184.78515625*cos(theta)**7 + 298379.135742188*cos(theta)**5 - 28417.060546875*cos(theta)**3 + 747.8173828125*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl15_m_minus_1(theta, phi):
    return 0.143378915753688*(1.0 - cos(theta)**2)**0.5*(71007.1655273438*cos(theta)**14 - 222815.588378906*cos(theta)**12 + 272330.163574219*cos(theta)**10 - 163398.098144531*cos(theta)**8 + 49729.8559570313*cos(theta)**6 - 7104.26513671875*cos(theta)**4 + 373.90869140625*cos(theta)**2 - 3.14208984375)*sin(phi)

#@torch.jit.script
def Yl15_m0(theta, phi):
    return 23358.0565385283*cos(theta)**15 - 84572.2736739818*cos(theta)**13 + 122159.950862418*cos(theta)**11 - 89583.9639657733*cos(theta)**9 + 35054.5945953026*cos(theta)**7 - 7010.91891906052*cos(theta)**5 + 614.992887636888*cos(theta)**3 - 15.5040223774005*cos(theta)

#@torch.jit.script
def Yl15_m1(theta, phi):
    return 0.143378915753688*(1.0 - cos(theta)**2)**0.5*(71007.1655273438*cos(theta)**14 - 222815.588378906*cos(theta)**12 + 272330.163574219*cos(theta)**10 - 163398.098144531*cos(theta)**8 + 49729.8559570313*cos(theta)**6 - 7104.26513671875*cos(theta)**4 + 373.90869140625*cos(theta)**2 - 3.14208984375)*cos(phi)

#@torch.jit.script
def Yl15_m2(theta, phi):
    return 0.00929387470704126*(1.0 - cos(theta)**2)*(994100.317382813*cos(theta)**13 - 2673787.06054688*cos(theta)**11 + 2723301.63574219*cos(theta)**9 - 1307184.78515625*cos(theta)**7 + 298379.135742188*cos(theta)**5 - 28417.060546875*cos(theta)**3 + 747.8173828125*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl15_m3(theta, phi):
    return 0.000607559596001151*(1.0 - cos(theta)**2)**1.5*(12923304.1259766*cos(theta)**12 - 29411657.6660156*cos(theta)**10 + 24509714.7216797*cos(theta)**8 - 9150293.49609375*cos(theta)**6 + 1491895.67871094*cos(theta)**4 - 85251.181640625*cos(theta)**2 + 747.8173828125)*cos(3*phi)

#@torch.jit.script
def Yl15_m4(theta, phi):
    return 4.02366171874445e-5*(1.0 - cos(theta)**2)**2*(155079649.511719*cos(theta)**11 - 294116576.660156*cos(theta)**9 + 196077717.773438*cos(theta)**7 - 54901760.9765625*cos(theta)**5 + 5967582.71484375*cos(theta)**3 - 170502.36328125*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl15_m5(theta, phi):
    return 2.71275217737612e-6*(1.0 - cos(theta)**2)**2.5*(1705876144.62891*cos(theta)**10 - 2647049189.94141*cos(theta)**8 + 1372544024.41406*cos(theta)**6 - 274508804.882813*cos(theta)**4 + 17902748.1445313*cos(theta)**2 - 170502.36328125)*cos(5*phi)

#@torch.jit.script
def Yl15_m6(theta, phi):
    return 1.87197684863824e-7*(1.0 - cos(theta)**2)**3*(17058761446.2891*cos(theta)**9 - 21176393519.5313*cos(theta)**7 + 8235264146.48438*cos(theta)**5 - 1098035219.53125*cos(theta)**3 + 35805496.2890625*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl15_m7(theta, phi):
    return 1.33035601710264e-8*(1.0 - cos(theta)**2)**3.5*(153528853016.602*cos(theta)**8 - 148234754636.719*cos(theta)**6 + 41176320732.4219*cos(theta)**4 - 3294105658.59375*cos(theta)**2 + 35805496.2890625)*cos(7*phi)

#@torch.jit.script
def Yl15_m8(theta, phi):
    return 9.80751467720255e-10*(1.0 - cos(theta)**2)**4*(1228230824132.81*cos(theta)**7 - 889408527820.313*cos(theta)**5 + 164705282929.688*cos(theta)**3 - 6588211317.1875*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl15_m9(theta, phi):
    return 7.56666184747369e-11*(1.0 - cos(theta)**2)**4.5*(8597615768929.69*cos(theta)**6 - 4447042639101.56*cos(theta)**4 + 494115848789.063*cos(theta)**2 - 6588211317.1875)*cos(9*phi)

#@torch.jit.script
def Yl15_m10(theta, phi):
    return 6.17815352749854e-12*(1.0 - cos(theta)**2)**5*(51585694613578.1*cos(theta)**5 - 17788170556406.3*cos(theta)**3 + 988231697578.125*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl15_m11(theta, phi):
    return 5.4185990958026e-13*(1.0 - cos(theta)**2)**5.5*(257928473067891.0*cos(theta)**4 - 53364511669218.8*cos(theta)**2 + 988231697578.125)*cos(11*phi)

#@torch.jit.script
def Yl15_m12(theta, phi):
    return 5.21404941098716e-14*(1.0 - cos(theta)**2)**6*(1.03171389227156e+15*cos(theta)**3 - 106729023338438.0*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl15_m13(theta, phi):
    return 5.68899431025918e-15*(1.0 - cos(theta)**2)**6.5*(3.09514167681469e+15*cos(theta)**2 - 106729023338438.0)*cos(13*phi)

#@torch.jit.script
def Yl15_m14(theta, phi):
    return 4.62415125663001*(1.0 - cos(theta)**2)**7*cos(14*phi)*cos(theta)

#@torch.jit.script
def Yl15_m15(theta, phi):
    return 0.844250650857373*(1.0 - cos(theta)**2)**7.5*cos(15*phi)

#@torch.jit.script
def Yl16_m_minus_16(theta, phi):
    return 0.857340588838025*(1.0 - cos(theta)**2)**8*sin(16*phi)

#@torch.jit.script
def Yl16_m_minus_15(theta, phi):
    return 4.84985075323068*(1.0 - cos(theta)**2)**7.5*sin(15*phi)*cos(theta)

#@torch.jit.script
def Yl16_m_minus_14(theta, phi):
    return 1.98999505000411e-16*(1.0 - cos(theta)**2)**7*(9.59493919812553e+16*cos(theta)**2 - 3.09514167681469e+15)*sin(14*phi)

#@torch.jit.script
def Yl16_m_minus_13(theta, phi):
    return 1.8878750671421e-15*(1.0 - cos(theta)**2)**6.5*(3.19831306604184e+16*cos(theta)**3 - 3.09514167681469e+15*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl16_m_minus_12(theta, phi):
    return 2.03330367436807e-14*(1.0 - cos(theta)**2)**6*(7.99578266510461e+15*cos(theta)**4 - 1.54757083840734e+15*cos(theta)**2 + 26682255834609.4)*sin(12*phi)

#@torch.jit.script
def Yl16_m_minus_11(theta, phi):
    return 2.40583735216622e-13*(1.0 - cos(theta)**2)**5.5*(1.59915653302092e+15*cos(theta)**5 - 515856946135781.0*cos(theta)**3 + 26682255834609.4*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl16_m_minus_10(theta, phi):
    return 3.06213103106751e-12*(1.0 - cos(theta)**2)**5*(266526088836820.0*cos(theta)**6 - 128964236533945.0*cos(theta)**4 + 13341127917304.7*cos(theta)**2 - 164705282929.688)*sin(10*phi)

#@torch.jit.script
def Yl16_m_minus_9(theta, phi):
    return 4.1310406124361e-11*(1.0 - cos(theta)**2)**4.5*(38075155548117.2*cos(theta)**7 - 25792847306789.1*cos(theta)**5 + 4447042639101.56*cos(theta)**3 - 164705282929.688*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl16_m_minus_8(theta, phi):
    return 5.84217366082119e-10*(1.0 - cos(theta)**2)**4*(4759394443514.65*cos(theta)**8 - 4298807884464.84*cos(theta)**6 + 1111760659775.39*cos(theta)**4 - 82352641464.8438*cos(theta)**2 + 823526414.648438)*sin(8*phi)

#@torch.jit.script
def Yl16_m_minus_7(theta, phi):
    return 8.58620667464373e-9*(1.0 - cos(theta)**2)**3.5*(528821604834.961*cos(theta)**9 - 614115412066.406*cos(theta)**7 + 222352131955.078*cos(theta)**5 - 27450880488.2813*cos(theta)**3 + 823526414.648438*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl16_m_minus_6(theta, phi):
    return 1.30216271501415e-7*(1.0 - cos(theta)**2)**3*(52882160483.4961*cos(theta)**10 - 76764426508.3008*cos(theta)**8 + 37058688659.1797*cos(theta)**6 - 6862720122.07031*cos(theta)**4 + 411763207.324219*cos(theta)**2 - 3580549.62890625)*sin(6*phi)

#@torch.jit.script
def Yl16_m_minus_5(theta, phi):
    return 2.02568978918854e-6*(1.0 - cos(theta)**2)**2.5*(4807469134.86328*cos(theta)**11 - 8529380723.14453*cos(theta)**9 + 5294098379.88281*cos(theta)**7 - 1372544024.41406*cos(theta)**5 + 137254402.441406*cos(theta)**3 - 3580549.62890625*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl16_m_minus_4(theta, phi):
    return 3.21568284933344e-5*(1.0 - cos(theta)**2)**2*(400622427.905273*cos(theta)**12 - 852938072.314453*cos(theta)**10 + 661762297.485352*cos(theta)**8 - 228757337.402344*cos(theta)**6 + 34313600.6103516*cos(theta)**4 - 1790274.81445313*cos(theta)**2 + 14208.5302734375)*sin(4*phi)

#@torch.jit.script
def Yl16_m_minus_3(theta, phi):
    return 0.000518513279362185*(1.0 - cos(theta)**2)**1.5*(30817109.8388672*cos(theta)**13 - 77539824.7558594*cos(theta)**11 + 73529144.1650391*cos(theta)**9 - 32679619.6289063*cos(theta)**7 + 6862720.12207031*cos(theta)**5 - 596758.271484375*cos(theta)**3 + 14208.5302734375*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl16_m_minus_2(theta, phi):
    return 0.00845669566395355*(1.0 - cos(theta)**2)*(2201222.13134766*cos(theta)**14 - 6461652.06298828*cos(theta)**12 + 7352914.41650391*cos(theta)**10 - 4084952.45361328*cos(theta)**8 + 1143786.68701172*cos(theta)**6 - 149189.567871094*cos(theta)**4 + 7104.26513671875*cos(theta)**2 - 53.41552734375)*sin(2*phi)

#@torch.jit.script
def Yl16_m_minus_1(theta, phi):
    return 0.138957689313105*(1.0 - cos(theta)**2)**0.5*(146748.142089844*cos(theta)**15 - 497050.158691406*cos(theta)**13 + 668446.765136719*cos(theta)**11 - 453883.605957031*cos(theta)**9 + 163398.098144531*cos(theta)**7 - 29837.9135742188*cos(theta)**5 + 2368.08837890625*cos(theta)**3 - 53.41552734375*cos(theta))*sin(phi)

#@torch.jit.script
def Yl16_m0(theta, phi):
    return 46693.2969032527*cos(theta)**16 - 180748.246077107*cos(theta)**14 + 283587.76539684*cos(theta)**12 - 231071.512545574*cos(theta)**10 + 103982.180645508*cos(theta)**8 - 25317.4005049933*cos(theta)**6 + 3013.97625059444*cos(theta)**4 - 135.968853410275*cos(theta)**2 + 0.999770980957908

#@torch.jit.script
def Yl16_m1(theta, phi):
    return 0.138957689313105*(1.0 - cos(theta)**2)**0.5*(146748.142089844*cos(theta)**15 - 497050.158691406*cos(theta)**13 + 668446.765136719*cos(theta)**11 - 453883.605957031*cos(theta)**9 + 163398.098144531*cos(theta)**7 - 29837.9135742188*cos(theta)**5 + 2368.08837890625*cos(theta)**3 - 53.41552734375*cos(theta))*cos(phi)

#@torch.jit.script
def Yl16_m2(theta, phi):
    return 0.00845669566395355*(1.0 - cos(theta)**2)*(2201222.13134766*cos(theta)**14 - 6461652.06298828*cos(theta)**12 + 7352914.41650391*cos(theta)**10 - 4084952.45361328*cos(theta)**8 + 1143786.68701172*cos(theta)**6 - 149189.567871094*cos(theta)**4 + 7104.26513671875*cos(theta)**2 - 53.41552734375)*cos(2*phi)

#@torch.jit.script
def Yl16_m3(theta, phi):
    return 0.000518513279362185*(1.0 - cos(theta)**2)**1.5*(30817109.8388672*cos(theta)**13 - 77539824.7558594*cos(theta)**11 + 73529144.1650391*cos(theta)**9 - 32679619.6289063*cos(theta)**7 + 6862720.12207031*cos(theta)**5 - 596758.271484375*cos(theta)**3 + 14208.5302734375*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl16_m4(theta, phi):
    return 3.21568284933344e-5*(1.0 - cos(theta)**2)**2*(400622427.905273*cos(theta)**12 - 852938072.314453*cos(theta)**10 + 661762297.485352*cos(theta)**8 - 228757337.402344*cos(theta)**6 + 34313600.6103516*cos(theta)**4 - 1790274.81445313*cos(theta)**2 + 14208.5302734375)*cos(4*phi)

#@torch.jit.script
def Yl16_m5(theta, phi):
    return 2.02568978918854e-6*(1.0 - cos(theta)**2)**2.5*(4807469134.86328*cos(theta)**11 - 8529380723.14453*cos(theta)**9 + 5294098379.88281*cos(theta)**7 - 1372544024.41406*cos(theta)**5 + 137254402.441406*cos(theta)**3 - 3580549.62890625*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl16_m6(theta, phi):
    return 1.30216271501415e-7*(1.0 - cos(theta)**2)**3*(52882160483.4961*cos(theta)**10 - 76764426508.3008*cos(theta)**8 + 37058688659.1797*cos(theta)**6 - 6862720122.07031*cos(theta)**4 + 411763207.324219*cos(theta)**2 - 3580549.62890625)*cos(6*phi)

#@torch.jit.script
def Yl16_m7(theta, phi):
    return 8.58620667464373e-9*(1.0 - cos(theta)**2)**3.5*(528821604834.961*cos(theta)**9 - 614115412066.406*cos(theta)**7 + 222352131955.078*cos(theta)**5 - 27450880488.2813*cos(theta)**3 + 823526414.648438*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl16_m8(theta, phi):
    return 5.84217366082119e-10*(1.0 - cos(theta)**2)**4*(4759394443514.65*cos(theta)**8 - 4298807884464.84*cos(theta)**6 + 1111760659775.39*cos(theta)**4 - 82352641464.8438*cos(theta)**2 + 823526414.648438)*cos(8*phi)

#@torch.jit.script
def Yl16_m9(theta, phi):
    return 4.1310406124361e-11*(1.0 - cos(theta)**2)**4.5*(38075155548117.2*cos(theta)**7 - 25792847306789.1*cos(theta)**5 + 4447042639101.56*cos(theta)**3 - 164705282929.688*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl16_m10(theta, phi):
    return 3.06213103106751e-12*(1.0 - cos(theta)**2)**5*(266526088836820.0*cos(theta)**6 - 128964236533945.0*cos(theta)**4 + 13341127917304.7*cos(theta)**2 - 164705282929.688)*cos(10*phi)

#@torch.jit.script
def Yl16_m11(theta, phi):
    return 2.40583735216622e-13*(1.0 - cos(theta)**2)**5.5*(1.59915653302092e+15*cos(theta)**5 - 515856946135781.0*cos(theta)**3 + 26682255834609.4*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl16_m12(theta, phi):
    return 2.03330367436807e-14*(1.0 - cos(theta)**2)**6*(7.99578266510461e+15*cos(theta)**4 - 1.54757083840734e+15*cos(theta)**2 + 26682255834609.4)*cos(12*phi)

#@torch.jit.script
def Yl16_m13(theta, phi):
    return 1.8878750671421e-15*(1.0 - cos(theta)**2)**6.5*(3.19831306604184e+16*cos(theta)**3 - 3.09514167681469e+15*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl16_m14(theta, phi):
    return 1.98999505000411e-16*(1.0 - cos(theta)**2)**7*(9.59493919812553e+16*cos(theta)**2 - 3.09514167681469e+15)*cos(14*phi)

#@torch.jit.script
def Yl16_m15(theta, phi):
    return 4.84985075323068*(1.0 - cos(theta)**2)**7.5*cos(15*phi)*cos(theta)

#@torch.jit.script
def Yl16_m16(theta, phi):
    return 0.857340588838025*(1.0 - cos(theta)**2)**8*cos(16*phi)

#@torch.jit.script
def Yl17_m_minus_17(theta, phi):
    return 0.869857171920628*(1.0 - cos(theta)**2)**8.5*sin(17*phi)

#@torch.jit.script
def Yl17_m_minus_16(theta, phi):
    return 5.07209532485536*(1.0 - cos(theta)**2)**8*sin(16*phi)*cos(theta)

#@torch.jit.script
def Yl17_m_minus_15(theta, phi):
    return 6.50688621401289e-18*(1.0 - cos(theta)**2)**7.5*(3.16632993538143e+18*cos(theta)**2 - 9.59493919812553e+16)*sin(15*phi)

#@torch.jit.script
def Yl17_m_minus_14(theta, phi):
    return 6.37542041547274e-17*(1.0 - cos(theta)**2)**7*(1.05544331179381e+18*cos(theta)**3 - 9.59493919812553e+16*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl17_m_minus_13(theta, phi):
    return 7.09936771746562e-16*(1.0 - cos(theta)**2)**6.5*(2.63860827948452e+17*cos(theta)**4 - 4.79746959906277e+16*cos(theta)**2 + 773785419203672.0)*sin(13*phi)

#@torch.jit.script
def Yl17_m_minus_12(theta, phi):
    return 8.69491420208903e-15*(1.0 - cos(theta)**2)**6*(5.27721655896904e+16*cos(theta)**5 - 1.59915653302092e+16*cos(theta)**3 + 773785419203672.0*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl17_m_minus_11(theta, phi):
    return 1.14693795555008e-13*(1.0 - cos(theta)**2)**5.5*(8.79536093161507e+15*cos(theta)**6 - 3.9978913325523e+15*cos(theta)**4 + 386892709601836.0*cos(theta)**2 - 4447042639101.56)*sin(11*phi)

#@torch.jit.script
def Yl17_m_minus_10(theta, phi):
    return 1.60571313777011e-12*(1.0 - cos(theta)**2)**5*(1.25648013308787e+15*cos(theta)**7 - 799578266510461.0*cos(theta)**5 + 128964236533945.0*cos(theta)**3 - 4447042639101.56*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl17_m_minus_9(theta, phi):
    return 2.35990671649205e-11*(1.0 - cos(theta)**2)**4.5*(157060016635983.0*cos(theta)**8 - 133263044418410.0*cos(theta)**6 + 32241059133486.3*cos(theta)**4 - 2223521319550.78*cos(theta)**2 + 20588160366.2109)*sin(9*phi)

#@torch.jit.script
def Yl17_m_minus_8(theta, phi):
    return 3.60996311929549e-10*(1.0 - cos(theta)**2)**4*(17451112959553.7*cos(theta)**9 - 19037577774058.6*cos(theta)**7 + 6448211826697.27*cos(theta)**5 - 741173773183.594*cos(theta)**3 + 20588160366.2109*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl17_m_minus_7(theta, phi):
    return 5.70785286308994e-9*(1.0 - cos(theta)**2)**3.5*(1745111295955.37*cos(theta)**10 - 2379697221757.32*cos(theta)**8 + 1074701971116.21*cos(theta)**6 - 185293443295.898*cos(theta)**4 + 10294080183.1055*cos(theta)**2 - 82352641.4648438)*sin(7*phi)

#@torch.jit.script
def Yl17_m_minus_6(theta, phi):
    return 9.2741631735508e-8*(1.0 - cos(theta)**2)**3*(158646481450.488*cos(theta)**11 - 264410802417.48*cos(theta)**9 + 153528853016.602*cos(theta)**7 - 37058688659.1797*cos(theta)**5 + 3431360061.03516*cos(theta)**3 - 82352641.4648438*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl17_m_minus_5(theta, phi):
    return 1.54073970252026e-6*(1.0 - cos(theta)**2)**2.5*(13220540120.874*cos(theta)**12 - 26441080241.748*cos(theta)**10 + 19191106627.0752*cos(theta)**8 - 6176448109.86328*cos(theta)**6 + 857840015.258789*cos(theta)**4 - 41176320.7324219*cos(theta)**2 + 298379.135742188)*sin(5*phi)

#@torch.jit.script
def Yl17_m_minus_4(theta, phi):
    return 2.6056272673653e-5*(1.0 - cos(theta)**2)**2*(1016964624.68262*cos(theta)**13 - 2403734567.43164*cos(theta)**11 + 2132345180.78613*cos(theta)**9 - 882349729.980469*cos(theta)**7 + 171568003.051758*cos(theta)**5 - 13725440.2441406*cos(theta)**3 + 298379.135742188*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl17_m_minus_3(theta, phi):
    return 0.000446772008544923*(1.0 - cos(theta)**2)**1.5*(72640330.3344727*cos(theta)**14 - 200311213.952637*cos(theta)**12 + 213234518.078613*cos(theta)**10 - 110293716.247559*cos(theta)**8 + 28594667.175293*cos(theta)**6 - 3431360.06103516*cos(theta)**4 + 149189.567871094*cos(theta)**2 - 1014.89501953125)*sin(3*phi)

#@torch.jit.script
def Yl17_m_minus_2(theta, phi):
    return 0.00773831818199403*(1.0 - cos(theta)**2)*(4842688.68896484*cos(theta)**15 - 15408554.9194336*cos(theta)**13 + 19384956.1889648*cos(theta)**11 - 12254857.3608398*cos(theta)**9 + 4084952.45361328*cos(theta)**7 - 686272.012207031*cos(theta)**5 + 49729.8559570313*cos(theta)**3 - 1014.89501953125*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl17_m_minus_1(theta, phi):
    return 0.134922187793101*(1.0 - cos(theta)**2)**0.5*(302668.043060303*cos(theta)**16 - 1100611.06567383*cos(theta)**14 + 1615413.01574707*cos(theta)**12 - 1225485.73608398*cos(theta)**10 + 510619.05670166*cos(theta)**8 - 114378.668701172*cos(theta)**6 + 12432.4639892578*cos(theta)**4 - 507.447509765625*cos(theta)**2 + 3.33847045898438)*sin(phi)

#@torch.jit.script
def Yl17_m0(theta, phi):
    return 93346.192942055*cos(theta)**17 - 384699.461821802*cos(theta)**15 + 651507.15308531*cos(theta)**13 - 584109.86138683*cos(theta)**11 + 297463.355335886*cos(theta)**9 - 85669.4463367351*cos(theta)**7 + 13036.6548773292*cos(theta)**5 - 886.847270566616*cos(theta)**3 + 17.5035645506569*cos(theta)

#@torch.jit.script
def Yl17_m1(theta, phi):
    return 0.134922187793101*(1.0 - cos(theta)**2)**0.5*(302668.043060303*cos(theta)**16 - 1100611.06567383*cos(theta)**14 + 1615413.01574707*cos(theta)**12 - 1225485.73608398*cos(theta)**10 + 510619.05670166*cos(theta)**8 - 114378.668701172*cos(theta)**6 + 12432.4639892578*cos(theta)**4 - 507.447509765625*cos(theta)**2 + 3.33847045898438)*cos(phi)

#@torch.jit.script
def Yl17_m2(theta, phi):
    return 0.00773831818199403*(1.0 - cos(theta)**2)*(4842688.68896484*cos(theta)**15 - 15408554.9194336*cos(theta)**13 + 19384956.1889648*cos(theta)**11 - 12254857.3608398*cos(theta)**9 + 4084952.45361328*cos(theta)**7 - 686272.012207031*cos(theta)**5 + 49729.8559570313*cos(theta)**3 - 1014.89501953125*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl17_m3(theta, phi):
    return 0.000446772008544923*(1.0 - cos(theta)**2)**1.5*(72640330.3344727*cos(theta)**14 - 200311213.952637*cos(theta)**12 + 213234518.078613*cos(theta)**10 - 110293716.247559*cos(theta)**8 + 28594667.175293*cos(theta)**6 - 3431360.06103516*cos(theta)**4 + 149189.567871094*cos(theta)**2 - 1014.89501953125)*cos(3*phi)

#@torch.jit.script
def Yl17_m4(theta, phi):
    return 2.6056272673653e-5*(1.0 - cos(theta)**2)**2*(1016964624.68262*cos(theta)**13 - 2403734567.43164*cos(theta)**11 + 2132345180.78613*cos(theta)**9 - 882349729.980469*cos(theta)**7 + 171568003.051758*cos(theta)**5 - 13725440.2441406*cos(theta)**3 + 298379.135742188*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl17_m5(theta, phi):
    return 1.54073970252026e-6*(1.0 - cos(theta)**2)**2.5*(13220540120.874*cos(theta)**12 - 26441080241.748*cos(theta)**10 + 19191106627.0752*cos(theta)**8 - 6176448109.86328*cos(theta)**6 + 857840015.258789*cos(theta)**4 - 41176320.7324219*cos(theta)**2 + 298379.135742188)*cos(5*phi)

#@torch.jit.script
def Yl17_m6(theta, phi):
    return 9.2741631735508e-8*(1.0 - cos(theta)**2)**3*(158646481450.488*cos(theta)**11 - 264410802417.48*cos(theta)**9 + 153528853016.602*cos(theta)**7 - 37058688659.1797*cos(theta)**5 + 3431360061.03516*cos(theta)**3 - 82352641.4648438*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl17_m7(theta, phi):
    return 5.70785286308994e-9*(1.0 - cos(theta)**2)**3.5*(1745111295955.37*cos(theta)**10 - 2379697221757.32*cos(theta)**8 + 1074701971116.21*cos(theta)**6 - 185293443295.898*cos(theta)**4 + 10294080183.1055*cos(theta)**2 - 82352641.4648438)*cos(7*phi)

#@torch.jit.script
def Yl17_m8(theta, phi):
    return 3.60996311929549e-10*(1.0 - cos(theta)**2)**4*(17451112959553.7*cos(theta)**9 - 19037577774058.6*cos(theta)**7 + 6448211826697.27*cos(theta)**5 - 741173773183.594*cos(theta)**3 + 20588160366.2109*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl17_m9(theta, phi):
    return 2.35990671649205e-11*(1.0 - cos(theta)**2)**4.5*(157060016635983.0*cos(theta)**8 - 133263044418410.0*cos(theta)**6 + 32241059133486.3*cos(theta)**4 - 2223521319550.78*cos(theta)**2 + 20588160366.2109)*cos(9*phi)

#@torch.jit.script
def Yl17_m10(theta, phi):
    return 1.60571313777011e-12*(1.0 - cos(theta)**2)**5*(1.25648013308787e+15*cos(theta)**7 - 799578266510461.0*cos(theta)**5 + 128964236533945.0*cos(theta)**3 - 4447042639101.56*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl17_m11(theta, phi):
    return 1.14693795555008e-13*(1.0 - cos(theta)**2)**5.5*(8.79536093161507e+15*cos(theta)**6 - 3.9978913325523e+15*cos(theta)**4 + 386892709601836.0*cos(theta)**2 - 4447042639101.56)*cos(11*phi)

#@torch.jit.script
def Yl17_m12(theta, phi):
    return 8.69491420208903e-15*(1.0 - cos(theta)**2)**6*(5.27721655896904e+16*cos(theta)**5 - 1.59915653302092e+16*cos(theta)**3 + 773785419203672.0*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl17_m13(theta, phi):
    return 7.09936771746562e-16*(1.0 - cos(theta)**2)**6.5*(2.63860827948452e+17*cos(theta)**4 - 4.79746959906277e+16*cos(theta)**2 + 773785419203672.0)*cos(13*phi)

#@torch.jit.script
def Yl17_m14(theta, phi):
    return 6.37542041547274e-17*(1.0 - cos(theta)**2)**7*(1.05544331179381e+18*cos(theta)**3 - 9.59493919812553e+16*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl17_m15(theta, phi):
    return 6.50688621401289e-18*(1.0 - cos(theta)**2)**7.5*(3.16632993538143e+18*cos(theta)**2 - 9.59493919812553e+16)*cos(15*phi)

#@torch.jit.script
def Yl17_m16(theta, phi):
    return 5.07209532485536*(1.0 - cos(theta)**2)**8*cos(16*phi)*cos(theta)

#@torch.jit.script
def Yl17_m17(theta, phi):
    return 0.869857171920628*(1.0 - cos(theta)**2)**8.5*cos(17*phi)

#@torch.jit.script
def Yl18_m_minus_18(theta, phi):
    return 0.881855768678329*(1.0 - cos(theta)**2)**9*sin(18*phi)

#@torch.jit.script
def Yl18_m_minus_17(theta, phi):
    return 5.29113461206997*(1.0 - cos(theta)**2)**8.5*sin(17*phi)*cos(theta)

#@torch.jit.script
def Yl18_m_minus_16(theta, phi):
    return 1.99730147939357e-19*(1.0 - cos(theta)**2)**8*(1.1082154773835e+20*cos(theta)**2 - 3.16632993538143e+18)*sin(16*phi)

#@torch.jit.script
def Yl18_m_minus_15(theta, phi):
    return 2.01717561545333e-18*(1.0 - cos(theta)**2)**7.5*(3.69405159127833e+19*cos(theta)**3 - 3.16632993538143e+18*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl18_m_minus_14(theta, phi):
    return 2.31755833840811e-17*(1.0 - cos(theta)**2)**7*(9.23512897819582e+18*cos(theta)**4 - 1.58316496769071e+18*cos(theta)**2 + 2.39873479953138e+16)*sin(14*phi)

#@torch.jit.script
def Yl18_m_minus_13(theta, phi):
    return 2.93150518387396e-16*(1.0 - cos(theta)**2)**6.5*(1.84702579563916e+18*cos(theta)**5 - 5.27721655896904e+17*cos(theta)**3 + 2.39873479953138e+16*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl18_m_minus_12(theta, phi):
    return 3.9980400343329e-15*(1.0 - cos(theta)**2)**6*(3.07837632606527e+17*cos(theta)**6 - 1.31930413974226e+17*cos(theta)**4 + 1.19936739976569e+16*cos(theta)**2 - 128964236533945.0)*sin(12*phi)

#@torch.jit.script
def Yl18_m_minus_11(theta, phi):
    return 5.79371043838662e-14*(1.0 - cos(theta)**2)**5.5*(4.39768046580754e+16*cos(theta)**7 - 2.63860827948452e+16*cos(theta)**5 + 3.9978913325523e+15*cos(theta)**3 - 128964236533945.0*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl18_m_minus_10(theta, phi):
    return 8.82471682796557e-13*(1.0 - cos(theta)**2)**5*(5.49710058225942e+15*cos(theta)**8 - 4.39768046580754e+15*cos(theta)**6 + 999472833138076.0*cos(theta)**4 - 64482118266972.7*cos(theta)**2 + 555880329887.695)*sin(10*phi)

#@torch.jit.script
def Yl18_m_minus_9(theta, phi):
    return 1.40088036704182e-11*(1.0 - cos(theta)**2)**4.5*(610788953584380.0*cos(theta)**9 - 628240066543934.0*cos(theta)**7 + 199894566627615.0*cos(theta)**5 - 21494039422324.2*cos(theta)**3 + 555880329887.695*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl18_m_minus_8(theta, phi):
    return 2.30188133218476e-10*(1.0 - cos(theta)**2)**4*(61078895358438.0*cos(theta)**10 - 78530008317991.7*cos(theta)**8 + 33315761104602.5*cos(theta)**6 - 5373509855581.05*cos(theta)**4 + 277940164943.848*cos(theta)**2 - 2058816036.62109)*sin(8*phi)

#@torch.jit.script
def Yl18_m_minus_7(theta, phi):
    return 3.8928345622358e-9*(1.0 - cos(theta)**2)**3.5*(5552626850767.09*cos(theta)**11 - 8725556479776.86*cos(theta)**9 + 4759394443514.65*cos(theta)**7 - 1074701971116.21*cos(theta)**5 + 92646721647.9492*cos(theta)**3 - 2058816036.62109*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl18_m_minus_6(theta, phi):
    return 6.74258724725256e-8*(1.0 - cos(theta)**2)**3*(462718904230.591*cos(theta)**12 - 872555647977.686*cos(theta)**10 + 594924305439.331*cos(theta)**8 - 179116995186.035*cos(theta)**6 + 23161680411.9873*cos(theta)**4 - 1029408018.31055*cos(theta)**2 + 6862720.12207031)*sin(6*phi)

#@torch.jit.script
def Yl18_m_minus_5(theta, phi):
    return 1.19097836376173e-6*(1.0 - cos(theta)**2)**2.5*(35593761863.8916*cos(theta)**13 - 79323240725.2441*cos(theta)**11 + 66102700604.3701*cos(theta)**9 - 25588142169.4336*cos(theta)**7 + 4632336082.39746*cos(theta)**5 - 343136006.103516*cos(theta)**3 + 6862720.12207031*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl18_m_minus_4(theta, phi):
    return 2.13713426594923e-5*(1.0 - cos(theta)**2)**2*(2542411561.70654*cos(theta)**14 - 6610270060.43701*cos(theta)**12 + 6610270060.43701*cos(theta)**10 - 3198517771.1792*cos(theta)**8 + 772056013.73291*cos(theta)**6 - 85784001.5258789*cos(theta)**4 + 3431360.06103516*cos(theta)**2 - 21312.7954101563)*sin(4*phi)

#@torch.jit.script
def Yl18_m_minus_3(theta, phi):
    return 0.000388229719023305*(1.0 - cos(theta)**2)**1.5*(169494104.11377*cos(theta)**15 - 508482312.341309*cos(theta)**13 + 600933641.85791*cos(theta)**11 - 355390863.464355*cos(theta)**9 + 110293716.247559*cos(theta)**7 - 17156800.3051758*cos(theta)**5 + 1143786.68701172*cos(theta)**3 - 21312.7954101563*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl18_m_minus_2(theta, phi):
    return 0.00711636829782292*(1.0 - cos(theta)**2)*(10593381.5071106*cos(theta)**16 - 36320165.1672363*cos(theta)**14 + 50077803.4881592*cos(theta)**12 - 35539086.3464355*cos(theta)**10 + 13786714.5309448*cos(theta)**8 - 2859466.7175293*cos(theta)**6 + 285946.67175293*cos(theta)**4 - 10656.3977050781*cos(theta)**2 + 63.4309387207031)*sin(2*phi)

#@torch.jit.script
def Yl18_m_minus_1(theta, phi):
    return 0.131219347792496*(1.0 - cos(theta)**2)**0.5*(623140.088653564*cos(theta)**17 - 2421344.34448242*cos(theta)**15 + 3852138.7298584*cos(theta)**13 - 3230826.03149414*cos(theta)**11 + 1531857.17010498*cos(theta)**9 - 408495.245361328*cos(theta)**7 + 57189.3343505859*cos(theta)**5 - 3552.13256835938*cos(theta)**3 + 63.4309387207031*cos(theta))*sin(phi)

#@torch.jit.script
def Yl18_m0(theta, phi):
    return 186620.345601326*cos(theta)**18 - 815797.51077151*cos(theta)**16 + 1483268.20140275*cos(theta)**14 - 1451369.96051236*cos(theta)**12 + 825779.460291517*cos(theta)**10 - 275259.820097172*cos(theta)**8 + 51381.8330848055*cos(theta)**6 - 4787.12730603778*cos(theta)**4 + 170.968832358492*cos(theta)**2 - 0.999817733090598

#@torch.jit.script
def Yl18_m1(theta, phi):
    return 0.131219347792496*(1.0 - cos(theta)**2)**0.5*(623140.088653564*cos(theta)**17 - 2421344.34448242*cos(theta)**15 + 3852138.7298584*cos(theta)**13 - 3230826.03149414*cos(theta)**11 + 1531857.17010498*cos(theta)**9 - 408495.245361328*cos(theta)**7 + 57189.3343505859*cos(theta)**5 - 3552.13256835938*cos(theta)**3 + 63.4309387207031*cos(theta))*cos(phi)

#@torch.jit.script
def Yl18_m2(theta, phi):
    return 0.00711636829782292*(1.0 - cos(theta)**2)*(10593381.5071106*cos(theta)**16 - 36320165.1672363*cos(theta)**14 + 50077803.4881592*cos(theta)**12 - 35539086.3464355*cos(theta)**10 + 13786714.5309448*cos(theta)**8 - 2859466.7175293*cos(theta)**6 + 285946.67175293*cos(theta)**4 - 10656.3977050781*cos(theta)**2 + 63.4309387207031)*cos(2*phi)

#@torch.jit.script
def Yl18_m3(theta, phi):
    return 0.000388229719023305*(1.0 - cos(theta)**2)**1.5*(169494104.11377*cos(theta)**15 - 508482312.341309*cos(theta)**13 + 600933641.85791*cos(theta)**11 - 355390863.464355*cos(theta)**9 + 110293716.247559*cos(theta)**7 - 17156800.3051758*cos(theta)**5 + 1143786.68701172*cos(theta)**3 - 21312.7954101563*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl18_m4(theta, phi):
    return 2.13713426594923e-5*(1.0 - cos(theta)**2)**2*(2542411561.70654*cos(theta)**14 - 6610270060.43701*cos(theta)**12 + 6610270060.43701*cos(theta)**10 - 3198517771.1792*cos(theta)**8 + 772056013.73291*cos(theta)**6 - 85784001.5258789*cos(theta)**4 + 3431360.06103516*cos(theta)**2 - 21312.7954101563)*cos(4*phi)

#@torch.jit.script
def Yl18_m5(theta, phi):
    return 1.19097836376173e-6*(1.0 - cos(theta)**2)**2.5*(35593761863.8916*cos(theta)**13 - 79323240725.2441*cos(theta)**11 + 66102700604.3701*cos(theta)**9 - 25588142169.4336*cos(theta)**7 + 4632336082.39746*cos(theta)**5 - 343136006.103516*cos(theta)**3 + 6862720.12207031*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl18_m6(theta, phi):
    return 6.74258724725256e-8*(1.0 - cos(theta)**2)**3*(462718904230.591*cos(theta)**12 - 872555647977.686*cos(theta)**10 + 594924305439.331*cos(theta)**8 - 179116995186.035*cos(theta)**6 + 23161680411.9873*cos(theta)**4 - 1029408018.31055*cos(theta)**2 + 6862720.12207031)*cos(6*phi)

#@torch.jit.script
def Yl18_m7(theta, phi):
    return 3.8928345622358e-9*(1.0 - cos(theta)**2)**3.5*(5552626850767.09*cos(theta)**11 - 8725556479776.86*cos(theta)**9 + 4759394443514.65*cos(theta)**7 - 1074701971116.21*cos(theta)**5 + 92646721647.9492*cos(theta)**3 - 2058816036.62109*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl18_m8(theta, phi):
    return 2.30188133218476e-10*(1.0 - cos(theta)**2)**4*(61078895358438.0*cos(theta)**10 - 78530008317991.7*cos(theta)**8 + 33315761104602.5*cos(theta)**6 - 5373509855581.05*cos(theta)**4 + 277940164943.848*cos(theta)**2 - 2058816036.62109)*cos(8*phi)

#@torch.jit.script
def Yl18_m9(theta, phi):
    return 1.40088036704182e-11*(1.0 - cos(theta)**2)**4.5*(610788953584380.0*cos(theta)**9 - 628240066543934.0*cos(theta)**7 + 199894566627615.0*cos(theta)**5 - 21494039422324.2*cos(theta)**3 + 555880329887.695*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl18_m10(theta, phi):
    return 8.82471682796557e-13*(1.0 - cos(theta)**2)**5*(5.49710058225942e+15*cos(theta)**8 - 4.39768046580754e+15*cos(theta)**6 + 999472833138076.0*cos(theta)**4 - 64482118266972.7*cos(theta)**2 + 555880329887.695)*cos(10*phi)

#@torch.jit.script
def Yl18_m11(theta, phi):
    return 5.79371043838662e-14*(1.0 - cos(theta)**2)**5.5*(4.39768046580754e+16*cos(theta)**7 - 2.63860827948452e+16*cos(theta)**5 + 3.9978913325523e+15*cos(theta)**3 - 128964236533945.0*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl18_m12(theta, phi):
    return 3.9980400343329e-15*(1.0 - cos(theta)**2)**6*(3.07837632606527e+17*cos(theta)**6 - 1.31930413974226e+17*cos(theta)**4 + 1.19936739976569e+16*cos(theta)**2 - 128964236533945.0)*cos(12*phi)

#@torch.jit.script
def Yl18_m13(theta, phi):
    return 2.93150518387396e-16*(1.0 - cos(theta)**2)**6.5*(1.84702579563916e+18*cos(theta)**5 - 5.27721655896904e+17*cos(theta)**3 + 2.39873479953138e+16*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl18_m14(theta, phi):
    return 2.31755833840811e-17*(1.0 - cos(theta)**2)**7*(9.23512897819582e+18*cos(theta)**4 - 1.58316496769071e+18*cos(theta)**2 + 2.39873479953138e+16)*cos(14*phi)

#@torch.jit.script
def Yl18_m15(theta, phi):
    return 2.01717561545333e-18*(1.0 - cos(theta)**2)**7.5*(3.69405159127833e+19*cos(theta)**3 - 3.16632993538143e+18*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl18_m16(theta, phi):
    return 1.99730147939357e-19*(1.0 - cos(theta)**2)**8*(1.1082154773835e+20*cos(theta)**2 - 3.16632993538143e+18)*cos(16*phi)

#@torch.jit.script
def Yl18_m17(theta, phi):
    return 5.29113461206997*(1.0 - cos(theta)**2)**8.5*cos(17*phi)*cos(theta)

#@torch.jit.script
def Yl18_m18(theta, phi):
    return 0.881855768678329*(1.0 - cos(theta)**2)**9*cos(18*phi)

#@torch.jit.script
def Yl19_m_minus_19(theta, phi):
    return 0.893383784349949*(1.0 - cos(theta)**2)**9.5*sin(19*phi)

#@torch.jit.script
def Yl19_m_minus_18(theta, phi):
    return 5.50718751027224*(1.0 - cos(theta)**2)**9*sin(18*phi)*cos(theta)

#@torch.jit.script
def Yl19_m_minus_17(theta, phi):
    return 5.77683273022057e-21*(1.0 - cos(theta)**2)**8.5*(4.10039726631895e+21*cos(theta)**2 - 1.1082154773835e+20)*sin(17*phi)

#@torch.jit.script
def Yl19_m_minus_16(theta, phi):
    return 6.00346067734132e-20*(1.0 - cos(theta)**2)**8*(1.36679908877298e+21*cos(theta)**3 - 1.1082154773835e+20*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl19_m_minus_15(theta, phi):
    return 7.1033904683705e-19*(1.0 - cos(theta)**2)**7.5*(3.41699772193245e+20*cos(theta)**4 - 5.54107738691749e+19*cos(theta)**2 + 7.91582483845356e+17)*sin(15*phi)

#@torch.jit.script
def Yl19_m_minus_14(theta, phi):
    return 9.26168804529891e-18*(1.0 - cos(theta)**2)**7*(6.83399544386491e+19*cos(theta)**5 - 1.84702579563916e+19*cos(theta)**3 + 7.91582483845356e+17*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl19_m_minus_13(theta, phi):
    return 1.30323502710715e-16*(1.0 - cos(theta)**2)**6.5*(1.13899924064415e+19*cos(theta)**6 - 4.61756448909791e+18*cos(theta)**4 + 3.95791241922678e+17*cos(theta)**2 - 3.9978913325523e+15)*sin(13*phi)

#@torch.jit.script
def Yl19_m_minus_12(theta, phi):
    return 1.9505035863512e-15*(1.0 - cos(theta)**2)**6*(1.62714177234879e+18*cos(theta)**7 - 9.23512897819582e+17*cos(theta)**5 + 1.31930413974226e+17*cos(theta)**3 - 3.9978913325523e+15*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl19_m_minus_11(theta, phi):
    return 3.07165611944352e-14*(1.0 - cos(theta)**2)**5.5*(2.03392721543598e+17*cos(theta)**8 - 1.53918816303264e+17*cos(theta)**6 + 3.29826034935565e+16*cos(theta)**4 - 1.99894566627615e+15*cos(theta)**2 + 16120529566743.2)*sin(11*phi)

#@torch.jit.script
def Yl19_m_minus_10(theta, phi):
    return 5.047246036554e-13*(1.0 - cos(theta)**2)**5*(2.25991912826221e+16*cos(theta)**9 - 2.19884023290377e+16*cos(theta)**7 + 6.5965206987113e+15*cos(theta)**5 - 666315222092051.0*cos(theta)**3 + 16120529566743.2*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl19_m_minus_9(theta, phi):
    return 8.59515028403688e-12*(1.0 - cos(theta)**2)**4.5*(2.25991912826221e+15*cos(theta)**10 - 2.74855029112971e+15*cos(theta)**8 + 1.09942011645188e+15*cos(theta)**6 - 166578805523013.0*cos(theta)**4 + 8060264783371.58*cos(theta)**2 - 55588032988.7695)*sin(9*phi)

#@torch.jit.script
def Yl19_m_minus_8(theta, phi):
    return 1.50844275293414e-10*(1.0 - cos(theta)**2)**4*(205447193478382.0*cos(theta)**11 - 305394476792190.0*cos(theta)**9 + 157060016635983.0*cos(theta)**7 - 33315761104602.5*cos(theta)**5 + 2686754927790.53*cos(theta)**3 - 55588032988.7695*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl19_m_minus_7(theta, phi):
    return 2.71519695528145e-9*(1.0 - cos(theta)**2)**3.5*(17120599456531.9*cos(theta)**12 - 30539447679219.0*cos(theta)**10 + 19632502079497.9*cos(theta)**8 - 5552626850767.09*cos(theta)**6 + 671688731947.632*cos(theta)**4 - 27794016494.3848*cos(theta)**2 + 171568003.051758)*sin(7*phi)

#@torch.jit.script
def Yl19_m_minus_6(theta, phi):
    return 4.99182886627511e-8*(1.0 - cos(theta)**2)**3*(1316969188963.99*cos(theta)**13 - 2776313425383.54*cos(theta)**11 + 2181389119944.21*cos(theta)**9 - 793232407252.441*cos(theta)**7 + 134337746389.526*cos(theta)**5 - 9264672164.79492*cos(theta)**3 + 171568003.051758*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl19_m_minus_5(theta, phi):
    return 9.33885667550482e-7*(1.0 - cos(theta)**2)**2.5*(94069227783.1421*cos(theta)**14 - 231359452115.295*cos(theta)**12 + 218138911994.421*cos(theta)**10 - 99154050906.5552*cos(theta)**8 + 22389624398.2544*cos(theta)**6 - 2316168041.19873*cos(theta)**4 + 85784001.5258789*cos(theta)**2 - 490194.294433594)*sin(5*phi)

#@torch.jit.script
def Yl19_m_minus_4(theta, phi):
    return 1.77192347018779e-5*(1.0 - cos(theta)**2)**2*(6271281852.20947*cos(theta)**15 - 17796880931.9458*cos(theta)**13 + 19830810181.311*cos(theta)**11 - 11017116767.395*cos(theta)**9 + 3198517771.1792*cos(theta)**7 - 463233608.239746*cos(theta)**5 + 28594667.175293*cos(theta)**3 - 490194.294433594*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl19_m_minus_3(theta, phi):
    return 0.000339913857408971*(1.0 - cos(theta)**2)**1.5*(391955115.763092*cos(theta)**16 - 1271205780.85327*cos(theta)**14 + 1652567515.10925*cos(theta)**12 - 1101711676.7395*cos(theta)**10 + 399814721.3974*cos(theta)**8 - 77205601.373291*cos(theta)**6 + 7148666.79382324*cos(theta)**4 - 245097.147216797*cos(theta)**2 + 1332.04971313477)*sin(3*phi)

#@torch.jit.script
def Yl19_m_minus_2(theta, phi):
    return 0.00657362114755131*(1.0 - cos(theta)**2)*(23056183.2801819*cos(theta)**17 - 84747052.0568848*cos(theta)**15 + 127120578.085327*cos(theta)**13 - 100155606.976318*cos(theta)**11 + 44423857.9330444*cos(theta)**9 - 11029371.6247559*cos(theta)**7 + 1429733.35876465*cos(theta)**5 - 81699.0490722656*cos(theta)**3 + 1332.04971313477*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl19_m_minus_1(theta, phi):
    return 0.127805802320551*(1.0 - cos(theta)**2)**0.5*(1280899.07112122*cos(theta)**18 - 5296690.7535553*cos(theta)**16 + 9080041.29180908*cos(theta)**14 - 8346300.58135986*cos(theta)**12 + 4442385.79330444*cos(theta)**10 - 1378671.45309448*cos(theta)**8 + 238288.893127441*cos(theta)**6 - 20424.7622680664*cos(theta)**4 + 666.024856567383*cos(theta)**2 - 3.52394104003906)*sin(phi)

#@torch.jit.script
def Yl19_m0(theta, phi):
    return 373111.430353337*cos(theta)**19 - 1724379.85379515*cos(theta)**17 + 3350223.71594487*cos(theta)**15 - 3553267.57751728*cos(theta)**13 + 2235119.92779313*cos(theta)**11 - 847804.110542221*cos(theta)**9 + 188400.913453827*cos(theta)**7 - 22608.1096144592*cos(theta)**5 + 1228.70160948148*cos(theta)**3 - 19.5032001504997*cos(theta)

#@torch.jit.script
def Yl19_m1(theta, phi):
    return 0.127805802320551*(1.0 - cos(theta)**2)**0.5*(1280899.07112122*cos(theta)**18 - 5296690.7535553*cos(theta)**16 + 9080041.29180908*cos(theta)**14 - 8346300.58135986*cos(theta)**12 + 4442385.79330444*cos(theta)**10 - 1378671.45309448*cos(theta)**8 + 238288.893127441*cos(theta)**6 - 20424.7622680664*cos(theta)**4 + 666.024856567383*cos(theta)**2 - 3.52394104003906)*cos(phi)

#@torch.jit.script
def Yl19_m2(theta, phi):
    return 0.00657362114755131*(1.0 - cos(theta)**2)*(23056183.2801819*cos(theta)**17 - 84747052.0568848*cos(theta)**15 + 127120578.085327*cos(theta)**13 - 100155606.976318*cos(theta)**11 + 44423857.9330444*cos(theta)**9 - 11029371.6247559*cos(theta)**7 + 1429733.35876465*cos(theta)**5 - 81699.0490722656*cos(theta)**3 + 1332.04971313477*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl19_m3(theta, phi):
    return 0.000339913857408971*(1.0 - cos(theta)**2)**1.5*(391955115.763092*cos(theta)**16 - 1271205780.85327*cos(theta)**14 + 1652567515.10925*cos(theta)**12 - 1101711676.7395*cos(theta)**10 + 399814721.3974*cos(theta)**8 - 77205601.373291*cos(theta)**6 + 7148666.79382324*cos(theta)**4 - 245097.147216797*cos(theta)**2 + 1332.04971313477)*cos(3*phi)

#@torch.jit.script
def Yl19_m4(theta, phi):
    return 1.77192347018779e-5*(1.0 - cos(theta)**2)**2*(6271281852.20947*cos(theta)**15 - 17796880931.9458*cos(theta)**13 + 19830810181.311*cos(theta)**11 - 11017116767.395*cos(theta)**9 + 3198517771.1792*cos(theta)**7 - 463233608.239746*cos(theta)**5 + 28594667.175293*cos(theta)**3 - 490194.294433594*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl19_m5(theta, phi):
    return 9.33885667550482e-7*(1.0 - cos(theta)**2)**2.5*(94069227783.1421*cos(theta)**14 - 231359452115.295*cos(theta)**12 + 218138911994.421*cos(theta)**10 - 99154050906.5552*cos(theta)**8 + 22389624398.2544*cos(theta)**6 - 2316168041.19873*cos(theta)**4 + 85784001.5258789*cos(theta)**2 - 490194.294433594)*cos(5*phi)

#@torch.jit.script
def Yl19_m6(theta, phi):
    return 4.99182886627511e-8*(1.0 - cos(theta)**2)**3*(1316969188963.99*cos(theta)**13 - 2776313425383.54*cos(theta)**11 + 2181389119944.21*cos(theta)**9 - 793232407252.441*cos(theta)**7 + 134337746389.526*cos(theta)**5 - 9264672164.79492*cos(theta)**3 + 171568003.051758*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl19_m7(theta, phi):
    return 2.71519695528145e-9*(1.0 - cos(theta)**2)**3.5*(17120599456531.9*cos(theta)**12 - 30539447679219.0*cos(theta)**10 + 19632502079497.9*cos(theta)**8 - 5552626850767.09*cos(theta)**6 + 671688731947.632*cos(theta)**4 - 27794016494.3848*cos(theta)**2 + 171568003.051758)*cos(7*phi)

#@torch.jit.script
def Yl19_m8(theta, phi):
    return 1.50844275293414e-10*(1.0 - cos(theta)**2)**4*(205447193478382.0*cos(theta)**11 - 305394476792190.0*cos(theta)**9 + 157060016635983.0*cos(theta)**7 - 33315761104602.5*cos(theta)**5 + 2686754927790.53*cos(theta)**3 - 55588032988.7695*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl19_m9(theta, phi):
    return 8.59515028403688e-12*(1.0 - cos(theta)**2)**4.5*(2.25991912826221e+15*cos(theta)**10 - 2.74855029112971e+15*cos(theta)**8 + 1.09942011645188e+15*cos(theta)**6 - 166578805523013.0*cos(theta)**4 + 8060264783371.58*cos(theta)**2 - 55588032988.7695)*cos(9*phi)

#@torch.jit.script
def Yl19_m10(theta, phi):
    return 5.047246036554e-13*(1.0 - cos(theta)**2)**5*(2.25991912826221e+16*cos(theta)**9 - 2.19884023290377e+16*cos(theta)**7 + 6.5965206987113e+15*cos(theta)**5 - 666315222092051.0*cos(theta)**3 + 16120529566743.2*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl19_m11(theta, phi):
    return 3.07165611944352e-14*(1.0 - cos(theta)**2)**5.5*(2.03392721543598e+17*cos(theta)**8 - 1.53918816303264e+17*cos(theta)**6 + 3.29826034935565e+16*cos(theta)**4 - 1.99894566627615e+15*cos(theta)**2 + 16120529566743.2)*cos(11*phi)

#@torch.jit.script
def Yl19_m12(theta, phi):
    return 1.9505035863512e-15*(1.0 - cos(theta)**2)**6*(1.62714177234879e+18*cos(theta)**7 - 9.23512897819582e+17*cos(theta)**5 + 1.31930413974226e+17*cos(theta)**3 - 3.9978913325523e+15*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl19_m13(theta, phi):
    return 1.30323502710715e-16*(1.0 - cos(theta)**2)**6.5*(1.13899924064415e+19*cos(theta)**6 - 4.61756448909791e+18*cos(theta)**4 + 3.95791241922678e+17*cos(theta)**2 - 3.9978913325523e+15)*cos(13*phi)

#@torch.jit.script
def Yl19_m14(theta, phi):
    return 9.26168804529891e-18*(1.0 - cos(theta)**2)**7*(6.83399544386491e+19*cos(theta)**5 - 1.84702579563916e+19*cos(theta)**3 + 7.91582483845356e+17*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl19_m15(theta, phi):
    return 7.1033904683705e-19*(1.0 - cos(theta)**2)**7.5*(3.41699772193245e+20*cos(theta)**4 - 5.54107738691749e+19*cos(theta)**2 + 7.91582483845356e+17)*cos(15*phi)

#@torch.jit.script
def Yl19_m16(theta, phi):
    return 6.00346067734132e-20*(1.0 - cos(theta)**2)**8*(1.36679908877298e+21*cos(theta)**3 - 1.1082154773835e+20*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl19_m17(theta, phi):
    return 5.77683273022057e-21*(1.0 - cos(theta)**2)**8.5*(4.10039726631895e+21*cos(theta)**2 - 1.1082154773835e+20)*cos(17*phi)

#@torch.jit.script
def Yl19_m18(theta, phi):
    return 5.50718751027224*(1.0 - cos(theta)**2)**9*cos(18*phi)*cos(theta)

#@torch.jit.script
def Yl19_m19(theta, phi):
    return 0.893383784349949*(1.0 - cos(theta)**2)**9.5*cos(19*phi)

#@torch.jit.script
def Yl20_m_minus_20(theta, phi):
    return 0.904482145093491*(1.0 - cos(theta)**2)**10*sin(20*phi)

#@torch.jit.script
def Yl20_m_minus_19(theta, phi):
    return 5.72044736290064*(1.0 - cos(theta)**2)**9.5*sin(19*phi)*cos(theta)

#@torch.jit.script
def Yl20_m_minus_18(theta, phi):
    return 1.57963503371958e-22*(1.0 - cos(theta)**2)**9*(1.59915493386439e+23*cos(theta)**2 - 4.10039726631895e+21)*sin(18*phi)

#@torch.jit.script
def Yl20_m_minus_17(theta, phi):
    return 1.68658868646741e-21*(1.0 - cos(theta)**2)**8.5*(5.33051644621463e+22*cos(theta)**3 - 4.10039726631895e+21*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl20_m_minus_16(theta, phi):
    return 2.05182369321377e-20*(1.0 - cos(theta)**2)**8*(1.33262911155366e+22*cos(theta)**4 - 2.05019863315947e+21*cos(theta)**2 + 2.77053869345875e+19)*sin(16*phi)

#@torch.jit.script
def Yl20_m_minus_15(theta, phi):
    return 2.7528103535224e-19*(1.0 - cos(theta)**2)**7.5*(2.66525822310731e+21*cos(theta)**5 - 6.83399544386491e+20*cos(theta)**3 + 2.77053869345875e+19*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl20_m_minus_14(theta, phi):
    return 3.9892011943704e-18*(1.0 - cos(theta)**2)**7*(4.44209703851219e+20*cos(theta)**6 - 1.70849886096623e+20*cos(theta)**4 + 1.38526934672937e+19*cos(theta)**2 - 1.31930413974226e+17)*sin(14*phi)

#@torch.jit.script
def Yl20_m_minus_13(theta, phi):
    return 6.15423986229134e-17*(1.0 - cos(theta)**2)**6.5*(6.34585291216027e+19*cos(theta)**7 - 3.41699772193245e+19*cos(theta)**5 + 4.61756448909791e+18*cos(theta)**3 - 1.31930413974226e+17*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl20_m_minus_12(theta, phi):
    return 9.99945619851927e-16*(1.0 - cos(theta)**2)**6*(7.93231614020034e+18*cos(theta)**8 - 5.69499620322076e+18*cos(theta)**6 + 1.15439112227448e+18*cos(theta)**4 - 6.5965206987113e+16*cos(theta)**2 + 499736416569038.0)*sin(12*phi)

#@torch.jit.script
def Yl20_m_minus_11(theta, phi):
    return 1.6969639886762e-14*(1.0 - cos(theta)**2)**5.5*(8.8136846002226e+17*cos(theta)**9 - 8.13570886174394e+17*cos(theta)**7 + 2.30878224454896e+17*cos(theta)**5 - 2.19884023290377e+16*cos(theta)**3 + 499736416569038.0*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl20_m_minus_10(theta, phi):
    return 2.98781341694522e-13*(1.0 - cos(theta)**2)**5*(8.8136846002226e+16*cos(theta)**10 - 1.01696360771799e+17*cos(theta)**8 + 3.84797040758159e+16*cos(theta)**6 - 5.49710058225942e+15*cos(theta)**4 + 249868208284519.0*cos(theta)**2 - 1612052956674.32)*sin(10*phi)

#@torch.jit.script
def Yl20_m_minus_9(theta, phi):
    return 5.42763260987486e-12*(1.0 - cos(theta)**2)**4.5*(8.01244054565691e+15*cos(theta)**11 - 1.1299595641311e+16*cos(theta)**9 + 5.49710058225942e+15*cos(theta)**7 - 1.09942011645188e+15*cos(theta)**5 + 83289402761506.3*cos(theta)**3 - 1612052956674.32*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl20_m_minus_8(theta, phi):
    return 1.01251173426417e-10*(1.0 - cos(theta)**2)**4*(667703378804743.0*cos(theta)**12 - 1.1299595641311e+15*cos(theta)**10 + 687137572782427.0*cos(theta)**8 - 183236686075314.0*cos(theta)**6 + 20822350690376.6*cos(theta)**4 - 806026478337.158*cos(theta)**2 + 4632336082.39746)*sin(8*phi)

#@torch.jit.script
def Yl20_m_minus_7(theta, phi):
    return 1.9317492704185e-9*(1.0 - cos(theta)**2)**3.5*(51361798369595.6*cos(theta)**13 - 102723596739191.0*cos(theta)**11 + 76348619198047.5*cos(theta)**9 - 26176669439330.6*cos(theta)**7 + 4164470138075.32*cos(theta)**5 - 268675492779.053*cos(theta)**3 + 4632336082.39746*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl20_m_minus_6(theta, phi):
    return 3.75574983477626e-8*(1.0 - cos(theta)**2)**3*(3668699883542.54*cos(theta)**14 - 8560299728265.93*cos(theta)**12 + 7634861919804.75*cos(theta)**10 - 3272083679916.32*cos(theta)**8 + 694078356345.886*cos(theta)**6 - 67168873194.7632*cos(theta)**4 + 2316168041.19873*cos(theta)**2 - 12254857.3608398)*sin(6*phi)

#@torch.jit.script
def Yl20_m_minus_5(theta, phi):
    return 7.417011635662e-7*(1.0 - cos(theta)**2)**2.5*(244579992236.169*cos(theta)**15 - 658484594481.995*cos(theta)**13 + 694078356345.886*cos(theta)**11 - 363564853324.036*cos(theta)**9 + 99154050906.5552*cos(theta)**7 - 13433774638.9526*cos(theta)**5 + 772056013.73291*cos(theta)**3 - 12254857.3608398*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl20_m_minus_4(theta, phi):
    return 1.4834023271324e-5*(1.0 - cos(theta)**2)**2*(15286249514.7606*cos(theta)**16 - 47034613891.571*cos(theta)**14 + 57839863028.8239*cos(theta)**12 - 36356485332.4036*cos(theta)**10 + 12394256363.3194*cos(theta)**8 - 2238962439.82544*cos(theta)**6 + 193014003.433228*cos(theta)**4 - 6127428.68041992*cos(theta)**2 + 30637.1434020996)*sin(4*phi)

#@torch.jit.script
def Yl20_m_minus_3(theta, phi):
    return 0.000299632582569029*(1.0 - cos(theta)**2)**1.5*(899191147.927094*cos(theta)**17 - 3135640926.10474*cos(theta)**15 + 4449220232.98645*cos(theta)**13 - 3305135030.21851*cos(theta)**11 + 1377139595.92438*cos(theta)**9 - 319851777.11792*cos(theta)**7 + 38602800.6866455*cos(theta)**5 - 2042476.22680664*cos(theta)**3 + 30637.1434020996*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl20_m_minus_2(theta, phi):
    return 0.00609662114603756*(1.0 - cos(theta)**2)*(49955063.7737274*cos(theta)**18 - 195977557.881546*cos(theta)**16 + 317801445.213318*cos(theta)**14 - 275427919.184875*cos(theta)**12 + 137713959.592438*cos(theta)**10 - 39981472.13974*cos(theta)**8 + 6433800.11444092*cos(theta)**6 - 510619.05670166*cos(theta)**4 + 15318.5717010498*cos(theta)**2 - 74.0027618408203)*sin(2*phi)

#@torch.jit.script
def Yl20_m_minus_1(theta, phi):
    return 0.12464571379913*(1.0 - cos(theta)**2)**0.5*(2629213.88282776*cos(theta)**19 - 11528091.6400909*cos(theta)**17 + 21186763.0142212*cos(theta)**15 - 21186763.0142212*cos(theta)**13 + 12519450.8720398*cos(theta)**11 - 4442385.79330444*cos(theta)**9 + 919114.302062988*cos(theta)**7 - 102123.811340332*cos(theta)**5 + 5106.1905670166*cos(theta)**3 - 74.0027618408203*cos(theta))*sin(phi)

#@torch.jit.script
def Yl20_m0(theta, phi):
    return 745989.629614649*cos(theta)**20 - 3634308.4519688*cos(theta)**18 + 7514178.28582739*cos(theta)**16 - 8587632.32665987*cos(theta)**14 + 5920261.67974279*cos(theta)**12 - 2520885.61847112*cos(theta)**10 + 651953.177190808*cos(theta)**8 - 96585.6558801197*cos(theta)**6 + 7243.92419100898*cos(theta)**4 - 209.968817130695*cos(theta)**2 + 0.999851510146167

#@torch.jit.script
def Yl20_m1(theta, phi):
    return 0.12464571379913*(1.0 - cos(theta)**2)**0.5*(2629213.88282776*cos(theta)**19 - 11528091.6400909*cos(theta)**17 + 21186763.0142212*cos(theta)**15 - 21186763.0142212*cos(theta)**13 + 12519450.8720398*cos(theta)**11 - 4442385.79330444*cos(theta)**9 + 919114.302062988*cos(theta)**7 - 102123.811340332*cos(theta)**5 + 5106.1905670166*cos(theta)**3 - 74.0027618408203*cos(theta))*cos(phi)

#@torch.jit.script
def Yl20_m2(theta, phi):
    return 0.00609662114603756*(1.0 - cos(theta)**2)*(49955063.7737274*cos(theta)**18 - 195977557.881546*cos(theta)**16 + 317801445.213318*cos(theta)**14 - 275427919.184875*cos(theta)**12 + 137713959.592438*cos(theta)**10 - 39981472.13974*cos(theta)**8 + 6433800.11444092*cos(theta)**6 - 510619.05670166*cos(theta)**4 + 15318.5717010498*cos(theta)**2 - 74.0027618408203)*cos(2*phi)

#@torch.jit.script
def Yl20_m3(theta, phi):
    return 0.000299632582569029*(1.0 - cos(theta)**2)**1.5*(899191147.927094*cos(theta)**17 - 3135640926.10474*cos(theta)**15 + 4449220232.98645*cos(theta)**13 - 3305135030.21851*cos(theta)**11 + 1377139595.92438*cos(theta)**9 - 319851777.11792*cos(theta)**7 + 38602800.6866455*cos(theta)**5 - 2042476.22680664*cos(theta)**3 + 30637.1434020996*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl20_m4(theta, phi):
    return 1.4834023271324e-5*(1.0 - cos(theta)**2)**2*(15286249514.7606*cos(theta)**16 - 47034613891.571*cos(theta)**14 + 57839863028.8239*cos(theta)**12 - 36356485332.4036*cos(theta)**10 + 12394256363.3194*cos(theta)**8 - 2238962439.82544*cos(theta)**6 + 193014003.433228*cos(theta)**4 - 6127428.68041992*cos(theta)**2 + 30637.1434020996)*cos(4*phi)

#@torch.jit.script
def Yl20_m5(theta, phi):
    return 7.417011635662e-7*(1.0 - cos(theta)**2)**2.5*(244579992236.169*cos(theta)**15 - 658484594481.995*cos(theta)**13 + 694078356345.886*cos(theta)**11 - 363564853324.036*cos(theta)**9 + 99154050906.5552*cos(theta)**7 - 13433774638.9526*cos(theta)**5 + 772056013.73291*cos(theta)**3 - 12254857.3608398*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl20_m6(theta, phi):
    return 3.75574983477626e-8*(1.0 - cos(theta)**2)**3*(3668699883542.54*cos(theta)**14 - 8560299728265.93*cos(theta)**12 + 7634861919804.75*cos(theta)**10 - 3272083679916.32*cos(theta)**8 + 694078356345.886*cos(theta)**6 - 67168873194.7632*cos(theta)**4 + 2316168041.19873*cos(theta)**2 - 12254857.3608398)*cos(6*phi)

#@torch.jit.script
def Yl20_m7(theta, phi):
    return 1.9317492704185e-9*(1.0 - cos(theta)**2)**3.5*(51361798369595.6*cos(theta)**13 - 102723596739191.0*cos(theta)**11 + 76348619198047.5*cos(theta)**9 - 26176669439330.6*cos(theta)**7 + 4164470138075.32*cos(theta)**5 - 268675492779.053*cos(theta)**3 + 4632336082.39746*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl20_m8(theta, phi):
    return 1.01251173426417e-10*(1.0 - cos(theta)**2)**4*(667703378804743.0*cos(theta)**12 - 1.1299595641311e+15*cos(theta)**10 + 687137572782427.0*cos(theta)**8 - 183236686075314.0*cos(theta)**6 + 20822350690376.6*cos(theta)**4 - 806026478337.158*cos(theta)**2 + 4632336082.39746)*cos(8*phi)

#@torch.jit.script
def Yl20_m9(theta, phi):
    return 5.42763260987486e-12*(1.0 - cos(theta)**2)**4.5*(8.01244054565691e+15*cos(theta)**11 - 1.1299595641311e+16*cos(theta)**9 + 5.49710058225942e+15*cos(theta)**7 - 1.09942011645188e+15*cos(theta)**5 + 83289402761506.3*cos(theta)**3 - 1612052956674.32*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl20_m10(theta, phi):
    return 2.98781341694522e-13*(1.0 - cos(theta)**2)**5*(8.8136846002226e+16*cos(theta)**10 - 1.01696360771799e+17*cos(theta)**8 + 3.84797040758159e+16*cos(theta)**6 - 5.49710058225942e+15*cos(theta)**4 + 249868208284519.0*cos(theta)**2 - 1612052956674.32)*cos(10*phi)

#@torch.jit.script
def Yl20_m11(theta, phi):
    return 1.6969639886762e-14*(1.0 - cos(theta)**2)**5.5*(8.8136846002226e+17*cos(theta)**9 - 8.13570886174394e+17*cos(theta)**7 + 2.30878224454896e+17*cos(theta)**5 - 2.19884023290377e+16*cos(theta)**3 + 499736416569038.0*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl20_m12(theta, phi):
    return 9.99945619851927e-16*(1.0 - cos(theta)**2)**6*(7.93231614020034e+18*cos(theta)**8 - 5.69499620322076e+18*cos(theta)**6 + 1.15439112227448e+18*cos(theta)**4 - 6.5965206987113e+16*cos(theta)**2 + 499736416569038.0)*cos(12*phi)

#@torch.jit.script
def Yl20_m13(theta, phi):
    return 6.15423986229134e-17*(1.0 - cos(theta)**2)**6.5*(6.34585291216027e+19*cos(theta)**7 - 3.41699772193245e+19*cos(theta)**5 + 4.61756448909791e+18*cos(theta)**3 - 1.31930413974226e+17*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl20_m14(theta, phi):
    return 3.9892011943704e-18*(1.0 - cos(theta)**2)**7*(4.44209703851219e+20*cos(theta)**6 - 1.70849886096623e+20*cos(theta)**4 + 1.38526934672937e+19*cos(theta)**2 - 1.31930413974226e+17)*cos(14*phi)

#@torch.jit.script
def Yl20_m15(theta, phi):
    return 2.7528103535224e-19*(1.0 - cos(theta)**2)**7.5*(2.66525822310731e+21*cos(theta)**5 - 6.83399544386491e+20*cos(theta)**3 + 2.77053869345875e+19*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl20_m16(theta, phi):
    return 2.05182369321377e-20*(1.0 - cos(theta)**2)**8*(1.33262911155366e+22*cos(theta)**4 - 2.05019863315947e+21*cos(theta)**2 + 2.77053869345875e+19)*cos(16*phi)

#@torch.jit.script
def Yl20_m17(theta, phi):
    return 1.68658868646741e-21*(1.0 - cos(theta)**2)**8.5*(5.33051644621463e+22*cos(theta)**3 - 4.10039726631895e+21*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl20_m18(theta, phi):
    return 1.57963503371958e-22*(1.0 - cos(theta)**2)**9*(1.59915493386439e+23*cos(theta)**2 - 4.10039726631895e+21)*cos(18*phi)

#@torch.jit.script
def Yl20_m19(theta, phi):
    return 5.72044736290064*(1.0 - cos(theta)**2)**9.5*cos(19*phi)*cos(theta)

#@torch.jit.script
def Yl20_m20(theta, phi):
    return 0.904482145093491*(1.0 - cos(theta)**2)**10*cos(20*phi)

#@torch.jit.script
def Yl21_m_minus_21(theta, phi):
    return 0.915186448400331*(1.0 - cos(theta)**2)**10.5*sin(21*phi)

#@torch.jit.script
def Yl21_m_minus_20(theta, phi):
    return 5.93108606277937*(1.0 - cos(theta)**2)**10*sin(20*phi)*cos(theta)

#@torch.jit.script
def Yl21_m_minus_19(theta, phi):
    return 4.09578128625229e-24*(1.0 - cos(theta)**2)**9.5*(6.55653522884399e+24*cos(theta)**2 - 1.59915493386439e+23)*sin(19*phi)

#@torch.jit.script
def Yl21_m_minus_18(theta, phi):
    return 4.48670360217581e-23*(1.0 - cos(theta)**2)**9*(2.185511742948e+24*cos(theta)**3 - 1.59915493386439e+23*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl21_m_minus_17(theta, phi):
    return 5.60389100299896e-22*(1.0 - cos(theta)**2)**8.5*(5.46377935737e+23*cos(theta)**4 - 7.99577466932194e+22*cos(theta)**2 + 1.02509931657974e+21)*sin(17*phi)

#@torch.jit.script
def Yl21_m_minus_16(theta, phi):
    return 7.72443067867375e-21*(1.0 - cos(theta)**2)**8*(1.092755871474e+23*cos(theta)**5 - 2.66525822310731e+22*cos(theta)**3 + 1.02509931657974e+21*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl21_m_minus_15(theta, phi):
    return 1.15091424992218e-19*(1.0 - cos(theta)**2)**7.5*(1.82125978579e+22*cos(theta)**6 - 6.66314555776829e+21*cos(theta)**4 + 5.12549658289868e+20*cos(theta)**2 - 4.61756448909791e+18)*sin(15*phi)

#@torch.jit.script
def Yl21_m_minus_14(theta, phi):
    return 1.82701973139271e-18*(1.0 - cos(theta)**2)**7*(2.60179969398571e+21*cos(theta)**7 - 1.33262911155366e+21*cos(theta)**5 + 1.70849886096623e+20*cos(theta)**3 - 4.61756448909791e+18*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl21_m_minus_13(theta, phi):
    return 3.05718875389061e-17*(1.0 - cos(theta)**2)**6.5*(3.25224961748214e+20*cos(theta)**8 - 2.2210485192561e+20*cos(theta)**6 + 4.27124715241557e+19*cos(theta)**4 - 2.30878224454896e+18*cos(theta)**2 + 1.64913017467783e+16)*sin(13*phi)

#@torch.jit.script
def Yl21_m_minus_12(theta, phi):
    return 5.34789616721945e-16*(1.0 - cos(theta)**2)**6*(3.61361068609127e+19*cos(theta)**9 - 3.17292645608014e+19*cos(theta)**7 + 8.54249430483114e+18*cos(theta)**5 - 7.69594081516319e+17*cos(theta)**3 + 1.64913017467783e+16*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl21_m_minus_11(theta, phi):
    return 9.71493583461516e-15*(1.0 - cos(theta)**2)**5.5*(3.61361068609127e+18*cos(theta)**10 - 3.96615807010017e+18*cos(theta)**8 + 1.42374905080519e+18*cos(theta)**6 - 1.9239852037908e+17*cos(theta)**4 + 8.24565087338913e+15*cos(theta)**2 - 49973641656903.8)*sin(11*phi)

#@torch.jit.script
def Yl21_m_minus_10(theta, phi):
    return 1.82268352577409e-13*(1.0 - cos(theta)**2)**5*(3.28510062371933e+17*cos(theta)**11 - 4.4068423001113e+17*cos(theta)**9 + 2.03392721543598e+17*cos(theta)**7 - 3.84797040758159e+16*cos(theta)**5 + 2.74855029112971e+15*cos(theta)**3 - 49973641656903.8*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl21_m_minus_9(theta, phi):
    return 3.51546467407613e-12*(1.0 - cos(theta)**2)**4.5*(2.73758385309944e+16*cos(theta)**12 - 4.4068423001113e+16*cos(theta)**10 + 2.54240901929498e+16*cos(theta)**8 - 6.41328401263599e+15*cos(theta)**6 + 687137572782427.0*cos(theta)**4 - 24986820828451.9*cos(theta)**2 + 134337746389.526)*sin(9*phi)

#@torch.jit.script
def Yl21_m_minus_8(theta, phi):
    return 6.94248646460625e-11*(1.0 - cos(theta)**2)**4*(2.10583373315342e+15*cos(theta)**13 - 4.00622027282846e+15*cos(theta)**11 + 2.82489891032776e+15*cos(theta)**9 - 916183430376570.0*cos(theta)**7 + 137427514556485.0*cos(theta)**5 - 8328940276150.63*cos(theta)**3 + 134337746389.526*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl21_m_minus_7(theta, phi):
    return 1.39887226130065e-9*(1.0 - cos(theta)**2)**3.5*(150416695225244.0*cos(theta)**14 - 333851689402371.0*cos(theta)**12 + 282489891032776.0*cos(theta)**10 - 114522928797071.0*cos(theta)**8 + 22904585759414.2*cos(theta)**6 - 2082235069037.66*cos(theta)**4 + 67168873194.7632*cos(theta)**2 - 330881148.742676)*sin(7*phi)

#@torch.jit.script
def Yl21_m_minus_6(theta, phi):
    return 2.86683503788286e-8*(1.0 - cos(theta)**2)**3*(10027779681682.9*cos(theta)**15 - 25680899184797.8*cos(theta)**13 + 25680899184797.8*cos(theta)**11 - 12724769866341.2*cos(theta)**9 + 3272083679916.32*cos(theta)**7 - 416447013807.532*cos(theta)**5 + 22389624398.2544*cos(theta)**3 - 330881148.742676*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl21_m_minus_5(theta, phi):
    return 5.95860473103812e-7*(1.0 - cos(theta)**2)**2.5*(626736230105.184*cos(theta)**16 - 1834349941771.27*cos(theta)**14 + 2140074932066.48*cos(theta)**12 - 1272476986634.12*cos(theta)**10 + 409010459989.54*cos(theta)**8 - 69407835634.5886*cos(theta)**6 + 5597406099.5636*cos(theta)**4 - 165440574.371338*cos(theta)**2 + 765928.58505249)*sin(5*phi)

#@torch.jit.script
def Yl21_m_minus_4(theta, phi):
    return 1.25272490558029e-5*(1.0 - cos(theta)**2)**2*(36866837065.0108*cos(theta)**17 - 122289996118.085*cos(theta)**15 + 164621148620.499*cos(theta)**13 - 115679726057.648*cos(theta)**11 + 45445606665.5045*cos(theta)**9 - 9915405090.65552*cos(theta)**7 + 1119481219.91272*cos(theta)**5 - 55146858.1237793*cos(theta)**3 + 765928.58505249*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl21_m_minus_3(theta, phi):
    return 0.00026574308270913*(1.0 - cos(theta)**2)**1.5*(2048157614.72282*cos(theta)**18 - 7643124757.38029*cos(theta)**16 + 11758653472.8928*cos(theta)**14 - 9639977171.47064*cos(theta)**12 + 4544560666.55045*cos(theta)**10 - 1239425636.33194*cos(theta)**8 + 186580203.318787*cos(theta)**6 - 13786714.5309448*cos(theta)**4 + 382964.292526245*cos(theta)**2 - 1702.06352233887)*sin(3*phi)

#@torch.jit.script
def Yl21_m_minus_2(theta, phi):
    return 0.00567471937804281*(1.0 - cos(theta)**2)*(107797769.195938*cos(theta)**19 - 449595573.963547*cos(theta)**17 + 783910231.526184*cos(theta)**15 - 741536705.497742*cos(theta)**13 + 413141878.777313*cos(theta)**11 - 137713959.592438*cos(theta)**9 + 26654314.7598267*cos(theta)**7 - 2757342.90618896*cos(theta)**5 + 127654.764175415*cos(theta)**3 - 1702.06352233887*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl21_m_minus_1(theta, phi):
    return 0.121709171425106*(1.0 - cos(theta)**2)**0.5*(5389888.45979691*cos(theta)**20 - 24977531.8868637*cos(theta)**18 + 48994389.4703865*cos(theta)**16 - 52966907.535553*cos(theta)**14 + 34428489.8981094*cos(theta)**12 - 13771395.9592438*cos(theta)**10 + 3331789.34497833*cos(theta)**8 - 459557.151031494*cos(theta)**6 + 31913.6910438538*cos(theta)**4 - 851.031761169434*cos(theta)**2 + 3.70013809204102)*sin(phi)

#@torch.jit.script
def Yl21_m0(theta, phi):
    return 1491556.30266255*cos(theta)**21 - 7639678.62339354*cos(theta)**19 + 16748526.2128243*cos(theta)**17 - 20520716.8012982*cos(theta)**15 + 15390537.6009737*cos(theta)**13 - 7275526.86591483*cos(theta)**11 + 2151365.47110385*cos(theta)**9 - 381522.940688367*cos(theta)**7 + 37092.5081224801*cos(theta)**5 - 1648.55591655467*cos(theta)**3 + 21.5029032594088*cos(theta)

#@torch.jit.script
def Yl21_m1(theta, phi):
    return 0.121709171425106*(1.0 - cos(theta)**2)**0.5*(5389888.45979691*cos(theta)**20 - 24977531.8868637*cos(theta)**18 + 48994389.4703865*cos(theta)**16 - 52966907.535553*cos(theta)**14 + 34428489.8981094*cos(theta)**12 - 13771395.9592438*cos(theta)**10 + 3331789.34497833*cos(theta)**8 - 459557.151031494*cos(theta)**6 + 31913.6910438538*cos(theta)**4 - 851.031761169434*cos(theta)**2 + 3.70013809204102)*cos(phi)

#@torch.jit.script
def Yl21_m2(theta, phi):
    return 0.00567471937804281*(1.0 - cos(theta)**2)*(107797769.195938*cos(theta)**19 - 449595573.963547*cos(theta)**17 + 783910231.526184*cos(theta)**15 - 741536705.497742*cos(theta)**13 + 413141878.777313*cos(theta)**11 - 137713959.592438*cos(theta)**9 + 26654314.7598267*cos(theta)**7 - 2757342.90618896*cos(theta)**5 + 127654.764175415*cos(theta)**3 - 1702.06352233887*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl21_m3(theta, phi):
    return 0.00026574308270913*(1.0 - cos(theta)**2)**1.5*(2048157614.72282*cos(theta)**18 - 7643124757.38029*cos(theta)**16 + 11758653472.8928*cos(theta)**14 - 9639977171.47064*cos(theta)**12 + 4544560666.55045*cos(theta)**10 - 1239425636.33194*cos(theta)**8 + 186580203.318787*cos(theta)**6 - 13786714.5309448*cos(theta)**4 + 382964.292526245*cos(theta)**2 - 1702.06352233887)*cos(3*phi)

#@torch.jit.script
def Yl21_m4(theta, phi):
    return 1.25272490558029e-5*(1.0 - cos(theta)**2)**2*(36866837065.0108*cos(theta)**17 - 122289996118.085*cos(theta)**15 + 164621148620.499*cos(theta)**13 - 115679726057.648*cos(theta)**11 + 45445606665.5045*cos(theta)**9 - 9915405090.65552*cos(theta)**7 + 1119481219.91272*cos(theta)**5 - 55146858.1237793*cos(theta)**3 + 765928.58505249*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl21_m5(theta, phi):
    return 5.95860473103812e-7*(1.0 - cos(theta)**2)**2.5*(626736230105.184*cos(theta)**16 - 1834349941771.27*cos(theta)**14 + 2140074932066.48*cos(theta)**12 - 1272476986634.12*cos(theta)**10 + 409010459989.54*cos(theta)**8 - 69407835634.5886*cos(theta)**6 + 5597406099.5636*cos(theta)**4 - 165440574.371338*cos(theta)**2 + 765928.58505249)*cos(5*phi)

#@torch.jit.script
def Yl21_m6(theta, phi):
    return 2.86683503788286e-8*(1.0 - cos(theta)**2)**3*(10027779681682.9*cos(theta)**15 - 25680899184797.8*cos(theta)**13 + 25680899184797.8*cos(theta)**11 - 12724769866341.2*cos(theta)**9 + 3272083679916.32*cos(theta)**7 - 416447013807.532*cos(theta)**5 + 22389624398.2544*cos(theta)**3 - 330881148.742676*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl21_m7(theta, phi):
    return 1.39887226130065e-9*(1.0 - cos(theta)**2)**3.5*(150416695225244.0*cos(theta)**14 - 333851689402371.0*cos(theta)**12 + 282489891032776.0*cos(theta)**10 - 114522928797071.0*cos(theta)**8 + 22904585759414.2*cos(theta)**6 - 2082235069037.66*cos(theta)**4 + 67168873194.7632*cos(theta)**2 - 330881148.742676)*cos(7*phi)

#@torch.jit.script
def Yl21_m8(theta, phi):
    return 6.94248646460625e-11*(1.0 - cos(theta)**2)**4*(2.10583373315342e+15*cos(theta)**13 - 4.00622027282846e+15*cos(theta)**11 + 2.82489891032776e+15*cos(theta)**9 - 916183430376570.0*cos(theta)**7 + 137427514556485.0*cos(theta)**5 - 8328940276150.63*cos(theta)**3 + 134337746389.526*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl21_m9(theta, phi):
    return 3.51546467407613e-12*(1.0 - cos(theta)**2)**4.5*(2.73758385309944e+16*cos(theta)**12 - 4.4068423001113e+16*cos(theta)**10 + 2.54240901929498e+16*cos(theta)**8 - 6.41328401263599e+15*cos(theta)**6 + 687137572782427.0*cos(theta)**4 - 24986820828451.9*cos(theta)**2 + 134337746389.526)*cos(9*phi)

#@torch.jit.script
def Yl21_m10(theta, phi):
    return 1.82268352577409e-13*(1.0 - cos(theta)**2)**5*(3.28510062371933e+17*cos(theta)**11 - 4.4068423001113e+17*cos(theta)**9 + 2.03392721543598e+17*cos(theta)**7 - 3.84797040758159e+16*cos(theta)**5 + 2.74855029112971e+15*cos(theta)**3 - 49973641656903.8*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl21_m11(theta, phi):
    return 9.71493583461516e-15*(1.0 - cos(theta)**2)**5.5*(3.61361068609127e+18*cos(theta)**10 - 3.96615807010017e+18*cos(theta)**8 + 1.42374905080519e+18*cos(theta)**6 - 1.9239852037908e+17*cos(theta)**4 + 8.24565087338913e+15*cos(theta)**2 - 49973641656903.8)*cos(11*phi)

#@torch.jit.script
def Yl21_m12(theta, phi):
    return 5.34789616721945e-16*(1.0 - cos(theta)**2)**6*(3.61361068609127e+19*cos(theta)**9 - 3.17292645608014e+19*cos(theta)**7 + 8.54249430483114e+18*cos(theta)**5 - 7.69594081516319e+17*cos(theta)**3 + 1.64913017467783e+16*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl21_m13(theta, phi):
    return 3.05718875389061e-17*(1.0 - cos(theta)**2)**6.5*(3.25224961748214e+20*cos(theta)**8 - 2.2210485192561e+20*cos(theta)**6 + 4.27124715241557e+19*cos(theta)**4 - 2.30878224454896e+18*cos(theta)**2 + 1.64913017467783e+16)*cos(13*phi)

#@torch.jit.script
def Yl21_m14(theta, phi):
    return 1.82701973139271e-18*(1.0 - cos(theta)**2)**7*(2.60179969398571e+21*cos(theta)**7 - 1.33262911155366e+21*cos(theta)**5 + 1.70849886096623e+20*cos(theta)**3 - 4.61756448909791e+18*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl21_m15(theta, phi):
    return 1.15091424992218e-19*(1.0 - cos(theta)**2)**7.5*(1.82125978579e+22*cos(theta)**6 - 6.66314555776829e+21*cos(theta)**4 + 5.12549658289868e+20*cos(theta)**2 - 4.61756448909791e+18)*cos(15*phi)

#@torch.jit.script
def Yl21_m16(theta, phi):
    return 7.72443067867375e-21*(1.0 - cos(theta)**2)**8*(1.092755871474e+23*cos(theta)**5 - 2.66525822310731e+22*cos(theta)**3 + 1.02509931657974e+21*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl21_m17(theta, phi):
    return 5.60389100299896e-22*(1.0 - cos(theta)**2)**8.5*(5.46377935737e+23*cos(theta)**4 - 7.99577466932194e+22*cos(theta)**2 + 1.02509931657974e+21)*cos(17*phi)

#@torch.jit.script
def Yl21_m18(theta, phi):
    return 4.48670360217581e-23*(1.0 - cos(theta)**2)**9*(2.185511742948e+24*cos(theta)**3 - 1.59915493386439e+23*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl21_m19(theta, phi):
    return 4.09578128625229e-24*(1.0 - cos(theta)**2)**9.5*(6.55653522884399e+24*cos(theta)**2 - 1.59915493386439e+23)*cos(19*phi)

#@torch.jit.script
def Yl21_m20(theta, phi):
    return 5.93108606277937*(1.0 - cos(theta)**2)**10*cos(20*phi)*cos(theta)

#@torch.jit.script
def Yl21_m21(theta, phi):
    return 0.915186448400331*(1.0 - cos(theta)**2)**10.5*cos(21*phi)

#@torch.jit.script
def Yl22_m_minus_22(theta, phi):
    return 0.925527866459589*(1.0 - cos(theta)**2)**11*sin(22*phi)

#@torch.jit.script
def Yl22_m_minus_21(theta, phi):
    return 6.13925733212923*(1.0 - cos(theta)**2)**10.5*sin(21*phi)*cos(theta)

#@torch.jit.script
def Yl22_m_minus_20(theta, phi):
    return 1.00969966670912e-25*(1.0 - cos(theta)**2)**10*(2.81931014840292e+26*cos(theta)**2 - 6.55653522884399e+24)*sin(20*phi)

#@torch.jit.script
def Yl22_m_minus_19(theta, phi):
    return 1.13338506490961e-24*(1.0 - cos(theta)**2)**9.5*(9.39770049467639e+25*cos(theta)**3 - 6.55653522884399e+24*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl22_m_minus_18(theta, phi):
    return 1.45144107589342e-23*(1.0 - cos(theta)**2)**9*(2.3494251236691e+25*cos(theta)**4 - 3.278267614422e+24*cos(theta)**2 + 3.99788733466097e+22)*sin(18*phi)

#@torch.jit.script
def Yl22_m_minus_17(theta, phi):
    return 2.05264765451388e-22*(1.0 - cos(theta)**2)**8.5*(4.6988502473382e+24*cos(theta)**5 - 1.092755871474e+24*cos(theta)**3 + 3.99788733466097e+22*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl22_m_minus_16(theta, phi):
    return 3.13994713346901e-21*(1.0 - cos(theta)**2)**8*(7.83141707889699e+23*cos(theta)**6 - 2.731889678685e+23*cos(theta)**4 + 1.99894366733049e+22*cos(theta)**2 - 1.70849886096623e+20)*sin(16*phi)

#@torch.jit.script
def Yl22_m_minus_15(theta, phi):
    return 5.12109879641152e-20*(1.0 - cos(theta)**2)**7.5*(1.11877386841386e+23*cos(theta)**7 - 5.46377935737e+22*cos(theta)**5 + 6.66314555776829e+21*cos(theta)**3 - 1.70849886096623e+20*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl22_m_minus_14(theta, phi):
    return 8.81067151427848e-19*(1.0 - cos(theta)**2)**7*(1.39846733551732e+22*cos(theta)**8 - 9.10629892894999e+21*cos(theta)**6 + 1.66578638944207e+21*cos(theta)**4 - 8.54249430483114e+19*cos(theta)**2 + 5.77195561137239e+17)*sin(14*phi)

#@torch.jit.script
def Yl22_m_minus_13(theta, phi):
    return 1.58592087257013e-17*(1.0 - cos(theta)**2)**6.5*(1.55385259501924e+21*cos(theta)**9 - 1.30089984699286e+21*cos(theta)**7 + 3.33157277888414e+20*cos(theta)**5 - 2.84749810161038e+19*cos(theta)**3 + 5.77195561137239e+17*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl22_m_minus_12(theta, phi):
    return 2.9669862738455e-16*(1.0 - cos(theta)**2)**6*(1.55385259501924e+20*cos(theta)**10 - 1.62612480874107e+20*cos(theta)**8 + 5.55262129814024e+19*cos(theta)**6 - 7.11874525402595e+18*cos(theta)**4 + 2.8859778056862e+17*cos(theta)**2 - 1.64913017467783e+15)*sin(12*phi)

#@torch.jit.script
def Yl22_m_minus_11(theta, phi):
    return 5.73787837392547e-15*(1.0 - cos(theta)**2)**5.5*(1.41259326819931e+19*cos(theta)**11 - 1.80680534304563e+19*cos(theta)**9 + 7.93231614020034e+18*cos(theta)**7 - 1.42374905080519e+18*cos(theta)**5 + 9.61992601895398e+16*cos(theta)**3 - 1.64913017467783e+15*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl22_m_minus_10(theta, phi):
    return 1.14182337954032e-13*(1.0 - cos(theta)**2)**5*(1.17716105683276e+18*cos(theta)**12 - 1.80680534304563e+18*cos(theta)**10 + 9.91539517525043e+17*cos(theta)**8 - 2.37291508467532e+17*cos(theta)**6 + 2.4049815047385e+16*cos(theta)**4 - 824565087338913.0*cos(theta)**2 + 4164470138075.32)*sin(10*phi)

#@torch.jit.script
def Yl22_m_minus_9(theta, phi):
    return 2.32887187734102e-12*(1.0 - cos(theta)**2)**4.5*(9.0550850525597e+16*cos(theta)**13 - 1.64255031185967e+17*cos(theta)**11 + 1.10171057502783e+17*cos(theta)**9 - 3.38987869239331e+16*cos(theta)**7 + 4.80996300947699e+15*cos(theta)**5 - 274855029112971.0*cos(theta)**3 + 4164470138075.32*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl22_m_minus_8(theta, phi):
    return 4.85166115051776e-11*(1.0 - cos(theta)**2)**4*(6.4679178946855e+15*cos(theta)**14 - 1.36879192654972e+16*cos(theta)**12 + 1.10171057502783e+16*cos(theta)**10 - 4.23734836549164e+15*cos(theta)**8 + 801660501579499.0*cos(theta)**6 - 68713757278242.7*cos(theta)**4 + 2082235069037.66*cos(theta)**2 - 9595553313.5376)*sin(8*phi)

#@torch.jit.script
def Yl22_m_minus_7(theta, phi):
    return 1.02919274986513e-9*(1.0 - cos(theta)**2)**3.5*(431194526312367.0*cos(theta)**15 - 1.05291686657671e+15*cos(theta)**13 + 1.00155506820711e+15*cos(theta)**11 - 470816485054626.0*cos(theta)**9 + 114522928797071.0*cos(theta)**7 - 13742751455648.5*cos(theta)**5 + 694078356345.886*cos(theta)**3 - 9595553313.5376*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl22_m_minus_6(theta, phi):
    return 2.21694903053267e-8*(1.0 - cos(theta)**2)**3*(26949657894522.9*cos(theta)**16 - 75208347612622.1*cos(theta)**14 + 83462922350592.8*cos(theta)**12 - 47081648505462.6*cos(theta)**10 + 14315366099633.9*cos(theta)**8 - 2290458575941.42*cos(theta)**6 + 173519589086.472*cos(theta)**4 - 4797776656.7688*cos(theta)**2 + 20680071.7964172)*sin(6*phi)

#@torch.jit.script
def Yl22_m_minus_5(theta, phi):
    return 4.83681174938034e-7*(1.0 - cos(theta)**2)**2.5*(1585273993795.47*cos(theta)**17 - 5013889840841.47*cos(theta)**15 + 6420224796199.45*cos(theta)**13 - 4280149864132.96*cos(theta)**11 + 1590596233292.66*cos(theta)**9 - 327208367991.632*cos(theta)**7 + 34703917817.2943*cos(theta)**5 - 1599258885.5896*cos(theta)**3 + 20680071.7964172*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl22_m_minus_4(theta, phi):
    return 1.06629486910923e-5*(1.0 - cos(theta)**2)**2*(88070777433.0814*cos(theta)**18 - 313368115052.592*cos(theta)**16 + 458587485442.818*cos(theta)**14 - 356679155344.414*cos(theta)**12 + 159059623329.266*cos(theta)**10 - 40901045998.954*cos(theta)**8 + 5783986302.88239*cos(theta)**6 - 399814721.3974*cos(theta)**4 + 10340035.8982086*cos(theta)**2 - 42551.5880584717)*sin(4*phi)

#@torch.jit.script
def Yl22_m_minus_3(theta, phi):
    return 0.000236995878752564*(1.0 - cos(theta)**2)**1.5*(4635304075.42534*cos(theta)**19 - 18433418532.5054*cos(theta)**17 + 30572499029.5212*cos(theta)**15 - 27436858103.4164*cos(theta)**13 + 14459965757.206*cos(theta)**11 - 4544560666.55045*cos(theta)**9 + 826283757.554626*cos(theta)**7 - 79962944.27948*cos(theta)**5 + 3446678.63273621*cos(theta)**3 - 42551.5880584717*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl22_m_minus_2(theta, phi):
    return 0.00529938895278031*(1.0 - cos(theta)**2)*(231765203.771267*cos(theta)**20 - 1024078807.36141*cos(theta)**18 + 1910781189.34507*cos(theta)**16 - 1959775578.81546*cos(theta)**14 + 1204997146.43383*cos(theta)**12 - 454456066.655045*cos(theta)**10 + 103285469.694328*cos(theta)**8 - 13327157.3799133*cos(theta)**6 + 861669.658184052*cos(theta)**4 - 21275.7940292358*cos(theta)**2 + 85.1031761169434)*sin(2*phi)

#@torch.jit.script
def Yl22_m_minus_1(theta, phi):
    return 0.118970986923352*(1.0 - cos(theta)**2)**0.5*(11036438.2748222*cos(theta)**21 - 53898884.5979691*cos(theta)**19 + 112398893.490887*cos(theta)**17 - 130651705.254364*cos(theta)**15 + 92692088.1872177*cos(theta)**13 - 41314187.8777313*cos(theta)**11 + 11476163.2993698*cos(theta)**9 - 1903879.6257019*cos(theta)**7 + 172333.93163681*cos(theta)**5 - 7091.93134307861*cos(theta)**3 + 85.1031761169434*cos(theta))*sin(phi)

#@torch.jit.script
def Yl22_m0(theta, phi):
    return 2982342.07383728*cos(theta)**22 - 16021419.0478235*cos(theta)**20 + 37122800.2327618*cos(theta)**18 - 48545200.3043808*cos(theta)**16 + 39360973.2197682*cos(theta)**14 - 20467706.0742795*cos(theta)**12 + 6822568.6914265*cos(theta)**10 - 1414818.3922313*cos(theta)**8 + 170753.943889985*cos(theta)**6 - 10540.3669067892*cos(theta)**4 + 252.96880576294*cos(theta)**2 - 0.999876702620317

#@torch.jit.script
def Yl22_m1(theta, phi):
    return 0.118970986923352*(1.0 - cos(theta)**2)**0.5*(11036438.2748222*cos(theta)**21 - 53898884.5979691*cos(theta)**19 + 112398893.490887*cos(theta)**17 - 130651705.254364*cos(theta)**15 + 92692088.1872177*cos(theta)**13 - 41314187.8777313*cos(theta)**11 + 11476163.2993698*cos(theta)**9 - 1903879.6257019*cos(theta)**7 + 172333.93163681*cos(theta)**5 - 7091.93134307861*cos(theta)**3 + 85.1031761169434*cos(theta))*cos(phi)

#@torch.jit.script
def Yl22_m2(theta, phi):
    return 0.00529938895278031*(1.0 - cos(theta)**2)*(231765203.771267*cos(theta)**20 - 1024078807.36141*cos(theta)**18 + 1910781189.34507*cos(theta)**16 - 1959775578.81546*cos(theta)**14 + 1204997146.43383*cos(theta)**12 - 454456066.655045*cos(theta)**10 + 103285469.694328*cos(theta)**8 - 13327157.3799133*cos(theta)**6 + 861669.658184052*cos(theta)**4 - 21275.7940292358*cos(theta)**2 + 85.1031761169434)*cos(2*phi)

#@torch.jit.script
def Yl22_m3(theta, phi):
    return 0.000236995878752564*(1.0 - cos(theta)**2)**1.5*(4635304075.42534*cos(theta)**19 - 18433418532.5054*cos(theta)**17 + 30572499029.5212*cos(theta)**15 - 27436858103.4164*cos(theta)**13 + 14459965757.206*cos(theta)**11 - 4544560666.55045*cos(theta)**9 + 826283757.554626*cos(theta)**7 - 79962944.27948*cos(theta)**5 + 3446678.63273621*cos(theta)**3 - 42551.5880584717*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl22_m4(theta, phi):
    return 1.06629486910923e-5*(1.0 - cos(theta)**2)**2*(88070777433.0814*cos(theta)**18 - 313368115052.592*cos(theta)**16 + 458587485442.818*cos(theta)**14 - 356679155344.414*cos(theta)**12 + 159059623329.266*cos(theta)**10 - 40901045998.954*cos(theta)**8 + 5783986302.88239*cos(theta)**6 - 399814721.3974*cos(theta)**4 + 10340035.8982086*cos(theta)**2 - 42551.5880584717)*cos(4*phi)

#@torch.jit.script
def Yl22_m5(theta, phi):
    return 4.83681174938034e-7*(1.0 - cos(theta)**2)**2.5*(1585273993795.47*cos(theta)**17 - 5013889840841.47*cos(theta)**15 + 6420224796199.45*cos(theta)**13 - 4280149864132.96*cos(theta)**11 + 1590596233292.66*cos(theta)**9 - 327208367991.632*cos(theta)**7 + 34703917817.2943*cos(theta)**5 - 1599258885.5896*cos(theta)**3 + 20680071.7964172*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl22_m6(theta, phi):
    return 2.21694903053267e-8*(1.0 - cos(theta)**2)**3*(26949657894522.9*cos(theta)**16 - 75208347612622.1*cos(theta)**14 + 83462922350592.8*cos(theta)**12 - 47081648505462.6*cos(theta)**10 + 14315366099633.9*cos(theta)**8 - 2290458575941.42*cos(theta)**6 + 173519589086.472*cos(theta)**4 - 4797776656.7688*cos(theta)**2 + 20680071.7964172)*cos(6*phi)

#@torch.jit.script
def Yl22_m7(theta, phi):
    return 1.02919274986513e-9*(1.0 - cos(theta)**2)**3.5*(431194526312367.0*cos(theta)**15 - 1.05291686657671e+15*cos(theta)**13 + 1.00155506820711e+15*cos(theta)**11 - 470816485054626.0*cos(theta)**9 + 114522928797071.0*cos(theta)**7 - 13742751455648.5*cos(theta)**5 + 694078356345.886*cos(theta)**3 - 9595553313.5376*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl22_m8(theta, phi):
    return 4.85166115051776e-11*(1.0 - cos(theta)**2)**4*(6.4679178946855e+15*cos(theta)**14 - 1.36879192654972e+16*cos(theta)**12 + 1.10171057502783e+16*cos(theta)**10 - 4.23734836549164e+15*cos(theta)**8 + 801660501579499.0*cos(theta)**6 - 68713757278242.7*cos(theta)**4 + 2082235069037.66*cos(theta)**2 - 9595553313.5376)*cos(8*phi)

#@torch.jit.script
def Yl22_m9(theta, phi):
    return 2.32887187734102e-12*(1.0 - cos(theta)**2)**4.5*(9.0550850525597e+16*cos(theta)**13 - 1.64255031185967e+17*cos(theta)**11 + 1.10171057502783e+17*cos(theta)**9 - 3.38987869239331e+16*cos(theta)**7 + 4.80996300947699e+15*cos(theta)**5 - 274855029112971.0*cos(theta)**3 + 4164470138075.32*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl22_m10(theta, phi):
    return 1.14182337954032e-13*(1.0 - cos(theta)**2)**5*(1.17716105683276e+18*cos(theta)**12 - 1.80680534304563e+18*cos(theta)**10 + 9.91539517525043e+17*cos(theta)**8 - 2.37291508467532e+17*cos(theta)**6 + 2.4049815047385e+16*cos(theta)**4 - 824565087338913.0*cos(theta)**2 + 4164470138075.32)*cos(10*phi)

#@torch.jit.script
def Yl22_m11(theta, phi):
    return 5.73787837392547e-15*(1.0 - cos(theta)**2)**5.5*(1.41259326819931e+19*cos(theta)**11 - 1.80680534304563e+19*cos(theta)**9 + 7.93231614020034e+18*cos(theta)**7 - 1.42374905080519e+18*cos(theta)**5 + 9.61992601895398e+16*cos(theta)**3 - 1.64913017467783e+15*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl22_m12(theta, phi):
    return 2.9669862738455e-16*(1.0 - cos(theta)**2)**6*(1.55385259501924e+20*cos(theta)**10 - 1.62612480874107e+20*cos(theta)**8 + 5.55262129814024e+19*cos(theta)**6 - 7.11874525402595e+18*cos(theta)**4 + 2.8859778056862e+17*cos(theta)**2 - 1.64913017467783e+15)*cos(12*phi)

#@torch.jit.script
def Yl22_m13(theta, phi):
    return 1.58592087257013e-17*(1.0 - cos(theta)**2)**6.5*(1.55385259501924e+21*cos(theta)**9 - 1.30089984699286e+21*cos(theta)**7 + 3.33157277888414e+20*cos(theta)**5 - 2.84749810161038e+19*cos(theta)**3 + 5.77195561137239e+17*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl22_m14(theta, phi):
    return 8.81067151427848e-19*(1.0 - cos(theta)**2)**7*(1.39846733551732e+22*cos(theta)**8 - 9.10629892894999e+21*cos(theta)**6 + 1.66578638944207e+21*cos(theta)**4 - 8.54249430483114e+19*cos(theta)**2 + 5.77195561137239e+17)*cos(14*phi)

#@torch.jit.script
def Yl22_m15(theta, phi):
    return 5.12109879641152e-20*(1.0 - cos(theta)**2)**7.5*(1.11877386841386e+23*cos(theta)**7 - 5.46377935737e+22*cos(theta)**5 + 6.66314555776829e+21*cos(theta)**3 - 1.70849886096623e+20*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl22_m16(theta, phi):
    return 3.13994713346901e-21*(1.0 - cos(theta)**2)**8*(7.83141707889699e+23*cos(theta)**6 - 2.731889678685e+23*cos(theta)**4 + 1.99894366733049e+22*cos(theta)**2 - 1.70849886096623e+20)*cos(16*phi)

#@torch.jit.script
def Yl22_m17(theta, phi):
    return 2.05264765451388e-22*(1.0 - cos(theta)**2)**8.5*(4.6988502473382e+24*cos(theta)**5 - 1.092755871474e+24*cos(theta)**3 + 3.99788733466097e+22*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl22_m18(theta, phi):
    return 1.45144107589342e-23*(1.0 - cos(theta)**2)**9*(2.3494251236691e+25*cos(theta)**4 - 3.278267614422e+24*cos(theta)**2 + 3.99788733466097e+22)*cos(18*phi)

#@torch.jit.script
def Yl22_m19(theta, phi):
    return 1.13338506490961e-24*(1.0 - cos(theta)**2)**9.5*(9.39770049467639e+25*cos(theta)**3 - 6.55653522884399e+24*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl22_m20(theta, phi):
    return 1.00969966670912e-25*(1.0 - cos(theta)**2)**10*(2.81931014840292e+26*cos(theta)**2 - 6.55653522884399e+24)*cos(20*phi)

#@torch.jit.script
def Yl22_m21(theta, phi):
    return 6.13925733212923*(1.0 - cos(theta)**2)**10.5*cos(21*phi)*cos(theta)

#@torch.jit.script
def Yl22_m22(theta, phi):
    return 0.925527866459589*(1.0 - cos(theta)**2)**11*cos(22*phi)

#@torch.jit.script
def Yl23_m_minus_23(theta, phi):
    return 0.935533863919911*(1.0 - cos(theta)**2)**11.5*sin(23*phi)

#@torch.jit.script
def Yl23_m_minus_22(theta, phi):
    return 6.34509937549305*(1.0 - cos(theta)**2)**11*sin(22*phi)*cos(theta)

#@torch.jit.script
def Yl23_m_minus_21(theta, phi):
    return 2.37232572869364e-27*(1.0 - cos(theta)**2)**10.5*(1.26868956678131e+28*cos(theta)**2 - 2.81931014840292e+26)*sin(21*phi)

#@torch.jit.script
def Yl23_m_minus_20(theta, phi):
    return 2.72559475329492e-26*(1.0 - cos(theta)**2)**10*(4.22896522260438e+27*cos(theta)**3 - 2.81931014840292e+26*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl23_m_minus_19(theta, phi):
    return 3.5745840073783e-25*(1.0 - cos(theta)**2)**9.5*(1.05724130565109e+27*cos(theta)**4 - 1.40965507420146e+26*cos(theta)**2 + 1.639133807211e+24)*sin(19*phi)

#@torch.jit.script
def Yl23_m_minus_18(theta, phi):
    return 5.18006435618226e-24*(1.0 - cos(theta)**2)**9*(2.11448261130219e+26*cos(theta)**5 - 4.6988502473382e+25*cos(theta)**3 + 1.639133807211e+24*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl23_m_minus_17(theta, phi):
    return 8.12461347795126e-23*(1.0 - cos(theta)**2)**8.5*(3.52413768550365e+25*cos(theta)**6 - 1.17471256183455e+25*cos(theta)**4 + 8.19566903605499e+23*cos(theta)**2 - 6.66314555776829e+21)*sin(17*phi)

#@torch.jit.script
def Yl23_m_minus_16(theta, phi):
    return 1.35950786560836e-21*(1.0 - cos(theta)**2)**8*(5.03448240786235e+24*cos(theta)**7 - 2.3494251236691e+24*cos(theta)**5 + 2.731889678685e+23*cos(theta)**3 - 6.66314555776829e+21*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl23_m_minus_15(theta, phi):
    return 2.40136967298897e-20*(1.0 - cos(theta)**2)**7.5*(6.29310300982794e+23*cos(theta)**8 - 3.9157085394485e+23*cos(theta)**6 + 6.82972419671249e+22*cos(theta)**4 - 3.33157277888414e+21*cos(theta)**2 + 2.13562357620778e+19)*sin(15*phi)

#@torch.jit.script
def Yl23_m_minus_14(theta, phi):
    return 4.44091105154346e-19*(1.0 - cos(theta)**2)**7*(6.9923366775866e+22*cos(theta)**9 - 5.59386934206928e+22*cos(theta)**7 + 1.3659448393425e+22*cos(theta)**5 - 1.11052425962805e+21*cos(theta)**3 + 2.13562357620778e+19*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl23_m_minus_13(theta, phi):
    return 8.54226296601593e-18*(1.0 - cos(theta)**2)**6.5*(6.9923366775866e+21*cos(theta)**10 - 6.9923366775866e+21*cos(theta)**8 + 2.2765747322375e+21*cos(theta)**6 - 2.77631064907012e+20*cos(theta)**4 + 1.06781178810389e+19*cos(theta)**2 - 5.77195561137239e+16)*sin(13*phi)

#@torch.jit.script
def Yl23_m_minus_12(theta, phi):
    return 1.6998888671294e-16*(1.0 - cos(theta)**2)**6*(6.35666970689691e+20*cos(theta)**11 - 7.76926297509622e+20*cos(theta)**9 + 3.25224961748214e+20*cos(theta)**7 - 5.55262129814024e+19*cos(theta)**5 + 3.55937262701297e+18*cos(theta)**3 - 5.77195561137239e+16*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl23_m_minus_11(theta, phi):
    return 3.48373550581555e-15*(1.0 - cos(theta)**2)**5.5*(5.29722475574742e+19*cos(theta)**12 - 7.76926297509622e+19*cos(theta)**10 + 4.06531202185268e+19*cos(theta)**8 - 9.25436883023373e+18*cos(theta)**6 + 8.89843156753243e+17*cos(theta)**4 - 2.88597780568619e+16*cos(theta)**2 + 137427514556485.0)*sin(11*phi)

#@torch.jit.script
def Yl23_m_minus_10(theta, phi):
    return 7.32413447372461e-14*(1.0 - cos(theta)**2)**5*(4.07478827365187e+18*cos(theta)**13 - 7.06296634099657e+18*cos(theta)**11 + 4.51701335761408e+18*cos(theta)**9 - 1.32205269003339e+18*cos(theta)**7 + 1.77968631350649e+17*cos(theta)**5 - 9.61992601895398e+15*cos(theta)**3 + 137427514556485.0*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl23_m_minus_9(theta, phi):
    return 1.57426303248889e-12*(1.0 - cos(theta)**2)**4.5*(2.91056305260848e+17*cos(theta)**14 - 5.88580528416381e+17*cos(theta)**12 + 4.51701335761408e+17*cos(theta)**10 - 1.65256586254174e+17*cos(theta)**8 + 2.96614385584414e+16*cos(theta)**6 - 2.4049815047385e+15*cos(theta)**4 + 68713757278242.7*cos(theta)**2 - 297462152719.666)*sin(9*phi)

#@torch.jit.script
def Yl23_m_minus_8(theta, phi):
    return 3.4490374973626e-11*(1.0 - cos(theta)**2)**4*(1.94037536840565e+16*cos(theta)**15 - 4.52754252627985e+16*cos(theta)**13 + 4.10637577964917e+16*cos(theta)**11 - 1.83618429171304e+16*cos(theta)**9 + 4.23734836549164e+15*cos(theta)**7 - 480996300947699.0*cos(theta)**5 + 22904585759414.2*cos(theta)**3 - 297462152719.666*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl23_m_minus_7(theta, phi):
    return 7.68137122555198e-10*(1.0 - cos(theta)**2)**3.5*(1.21273460525353e+15*cos(theta)**16 - 3.23395894734275e+15*cos(theta)**14 + 3.42197981637431e+15*cos(theta)**12 - 1.83618429171304e+15*cos(theta)**10 + 529668545686454.0*cos(theta)**8 - 80166050157949.9*cos(theta)**6 + 5726146439853.56*cos(theta)**4 - 148731076359.833*cos(theta)**2 + 599722082.0961)*sin(7*phi)

#@torch.jit.script
def Yl23_m_minus_6(theta, phi):
    return 1.73469785817059e-8*(1.0 - cos(theta)**2)**3*(71337329720796.0*cos(theta)**17 - 215597263156183.0*cos(theta)**15 + 263229216644177.0*cos(theta)**13 - 166925844701186.0*cos(theta)**11 + 58852060631828.3*cos(theta)**9 - 11452292879707.1*cos(theta)**7 + 1145229287970.71*cos(theta)**5 - 49577025453.2776*cos(theta)**3 + 599722082.0961*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl23_m_minus_5(theta, phi):
    return 3.96331958851659e-7*(1.0 - cos(theta)**2)**2.5*(3963184984488.66*cos(theta)**18 - 13474828947261.5*cos(theta)**16 + 18802086903155.5*cos(theta)**14 - 13910487058432.1*cos(theta)**12 + 5885206063182.83*cos(theta)**10 - 1431536609963.39*cos(theta)**8 + 190871547995.119*cos(theta)**6 - 12394256363.3194*cos(theta)**4 + 299861041.04805*cos(theta)**2 - 1148892.87757874)*sin(5*phi)

#@torch.jit.script
def Yl23_m_minus_4(theta, phi):
    return 9.1414462474505e-6*(1.0 - cos(theta)**2)**2*(208588683394.14*cos(theta)**19 - 792636996897.733*cos(theta)**17 + 1253472460210.37*cos(theta)**15 - 1070037466033.24*cos(theta)**13 + 535018733016.621*cos(theta)**11 - 159059623329.266*cos(theta)**9 + 27267363999.3027*cos(theta)**7 - 2478851272.66388*cos(theta)**5 + 99953680.34935*cos(theta)**3 - 1148892.87757874*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl23_m_minus_3(theta, phi):
    return 0.000212428014459756*(1.0 - cos(theta)**2)**1.5*(10429434169.707*cos(theta)**20 - 44035388716.5407*cos(theta)**18 + 78342028763.148*cos(theta)**16 - 76431247573.8029*cos(theta)**14 + 44584894418.0517*cos(theta)**12 - 15905962332.9266*cos(theta)**10 + 3408420499.91283*cos(theta)**8 - 413141878.777313*cos(theta)**6 + 24988420.0873375*cos(theta)**4 - 574446.438789368*cos(theta)**2 + 2127.57940292358)*sin(3*phi)

#@torch.jit.script
def Yl23_m_minus_2(theta, phi):
    return 0.00496372955394567*(1.0 - cos(theta)**2)*(496639722.367001*cos(theta)**21 - 2317652037.71267*cos(theta)**19 + 4608354633.12635*cos(theta)**17 - 5095416504.9202*cos(theta)**15 + 3429607262.92706*cos(theta)**13 - 1445996575.7206*cos(theta)**11 + 378713388.879204*cos(theta)**9 - 59020268.396759*cos(theta)**7 + 4997684.0174675*cos(theta)**5 - 191482.146263123*cos(theta)**3 + 2127.57940292358*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl23_m_minus_1(theta, phi):
    return 0.116409776636641*(1.0 - cos(theta)**2)**0.5*(22574532.8348637*cos(theta)**22 - 115882601.885633*cos(theta)**20 + 256019701.840353*cos(theta)**18 - 318463531.557512*cos(theta)**16 + 244971947.351933*cos(theta)**14 - 120499714.643383*cos(theta)**12 + 37871338.8879204*cos(theta)**10 - 7377533.54959488*cos(theta)**8 + 832947.336244583*cos(theta)**6 - 47870.5365657806*cos(theta)**4 + 1063.78970146179*cos(theta)**2 - 3.86832618713379)*sin(phi)

#@torch.jit.script
def Yl23_m0(theta, phi):
    return 5963274.55669477*cos(theta)**23 - 33526854.7298617*cos(theta)**21 + 81867901.084546*cos(theta)**19 - 113816350.288271*cos(theta)**17 + 99224510.5077237*cos(theta)**15 - 56316614.0719513*cos(theta)**13 + 20917599.5124391*cos(theta)**11 - 4980380.83629501*cos(theta)**9 + 722958.508494437*cos(theta)**7 - 58169.0753961042*cos(theta)**5 + 2154.41019985571*cos(theta)**3 - 23.5026567256986*cos(theta)

#@torch.jit.script
def Yl23_m1(theta, phi):
    return 0.116409776636641*(1.0 - cos(theta)**2)**0.5*(22574532.8348637*cos(theta)**22 - 115882601.885633*cos(theta)**20 + 256019701.840353*cos(theta)**18 - 318463531.557512*cos(theta)**16 + 244971947.351933*cos(theta)**14 - 120499714.643383*cos(theta)**12 + 37871338.8879204*cos(theta)**10 - 7377533.54959488*cos(theta)**8 + 832947.336244583*cos(theta)**6 - 47870.5365657806*cos(theta)**4 + 1063.78970146179*cos(theta)**2 - 3.86832618713379)*cos(phi)

#@torch.jit.script
def Yl23_m2(theta, phi):
    return 0.00496372955394567*(1.0 - cos(theta)**2)*(496639722.367001*cos(theta)**21 - 2317652037.71267*cos(theta)**19 + 4608354633.12635*cos(theta)**17 - 5095416504.9202*cos(theta)**15 + 3429607262.92706*cos(theta)**13 - 1445996575.7206*cos(theta)**11 + 378713388.879204*cos(theta)**9 - 59020268.396759*cos(theta)**7 + 4997684.0174675*cos(theta)**5 - 191482.146263123*cos(theta)**3 + 2127.57940292358*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl23_m3(theta, phi):
    return 0.000212428014459756*(1.0 - cos(theta)**2)**1.5*(10429434169.707*cos(theta)**20 - 44035388716.5407*cos(theta)**18 + 78342028763.148*cos(theta)**16 - 76431247573.8029*cos(theta)**14 + 44584894418.0517*cos(theta)**12 - 15905962332.9266*cos(theta)**10 + 3408420499.91283*cos(theta)**8 - 413141878.777313*cos(theta)**6 + 24988420.0873375*cos(theta)**4 - 574446.438789368*cos(theta)**2 + 2127.57940292358)*cos(3*phi)

#@torch.jit.script
def Yl23_m4(theta, phi):
    return 9.1414462474505e-6*(1.0 - cos(theta)**2)**2*(208588683394.14*cos(theta)**19 - 792636996897.733*cos(theta)**17 + 1253472460210.37*cos(theta)**15 - 1070037466033.24*cos(theta)**13 + 535018733016.621*cos(theta)**11 - 159059623329.266*cos(theta)**9 + 27267363999.3027*cos(theta)**7 - 2478851272.66388*cos(theta)**5 + 99953680.34935*cos(theta)**3 - 1148892.87757874*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl23_m5(theta, phi):
    return 3.96331958851659e-7*(1.0 - cos(theta)**2)**2.5*(3963184984488.66*cos(theta)**18 - 13474828947261.5*cos(theta)**16 + 18802086903155.5*cos(theta)**14 - 13910487058432.1*cos(theta)**12 + 5885206063182.83*cos(theta)**10 - 1431536609963.39*cos(theta)**8 + 190871547995.119*cos(theta)**6 - 12394256363.3194*cos(theta)**4 + 299861041.04805*cos(theta)**2 - 1148892.87757874)*cos(5*phi)

#@torch.jit.script
def Yl23_m6(theta, phi):
    return 1.73469785817059e-8*(1.0 - cos(theta)**2)**3*(71337329720796.0*cos(theta)**17 - 215597263156183.0*cos(theta)**15 + 263229216644177.0*cos(theta)**13 - 166925844701186.0*cos(theta)**11 + 58852060631828.3*cos(theta)**9 - 11452292879707.1*cos(theta)**7 + 1145229287970.71*cos(theta)**5 - 49577025453.2776*cos(theta)**3 + 599722082.0961*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl23_m7(theta, phi):
    return 7.68137122555198e-10*(1.0 - cos(theta)**2)**3.5*(1.21273460525353e+15*cos(theta)**16 - 3.23395894734275e+15*cos(theta)**14 + 3.42197981637431e+15*cos(theta)**12 - 1.83618429171304e+15*cos(theta)**10 + 529668545686454.0*cos(theta)**8 - 80166050157949.9*cos(theta)**6 + 5726146439853.56*cos(theta)**4 - 148731076359.833*cos(theta)**2 + 599722082.0961)*cos(7*phi)

#@torch.jit.script
def Yl23_m8(theta, phi):
    return 3.4490374973626e-11*(1.0 - cos(theta)**2)**4*(1.94037536840565e+16*cos(theta)**15 - 4.52754252627985e+16*cos(theta)**13 + 4.10637577964917e+16*cos(theta)**11 - 1.83618429171304e+16*cos(theta)**9 + 4.23734836549164e+15*cos(theta)**7 - 480996300947699.0*cos(theta)**5 + 22904585759414.2*cos(theta)**3 - 297462152719.666*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl23_m9(theta, phi):
    return 1.57426303248889e-12*(1.0 - cos(theta)**2)**4.5*(2.91056305260848e+17*cos(theta)**14 - 5.88580528416381e+17*cos(theta)**12 + 4.51701335761408e+17*cos(theta)**10 - 1.65256586254174e+17*cos(theta)**8 + 2.96614385584414e+16*cos(theta)**6 - 2.4049815047385e+15*cos(theta)**4 + 68713757278242.7*cos(theta)**2 - 297462152719.666)*cos(9*phi)

#@torch.jit.script
def Yl23_m10(theta, phi):
    return 7.32413447372461e-14*(1.0 - cos(theta)**2)**5*(4.07478827365187e+18*cos(theta)**13 - 7.06296634099657e+18*cos(theta)**11 + 4.51701335761408e+18*cos(theta)**9 - 1.32205269003339e+18*cos(theta)**7 + 1.77968631350649e+17*cos(theta)**5 - 9.61992601895398e+15*cos(theta)**3 + 137427514556485.0*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl23_m11(theta, phi):
    return 3.48373550581555e-15*(1.0 - cos(theta)**2)**5.5*(5.29722475574742e+19*cos(theta)**12 - 7.76926297509622e+19*cos(theta)**10 + 4.06531202185268e+19*cos(theta)**8 - 9.25436883023373e+18*cos(theta)**6 + 8.89843156753243e+17*cos(theta)**4 - 2.88597780568619e+16*cos(theta)**2 + 137427514556485.0)*cos(11*phi)

#@torch.jit.script
def Yl23_m12(theta, phi):
    return 1.6998888671294e-16*(1.0 - cos(theta)**2)**6*(6.35666970689691e+20*cos(theta)**11 - 7.76926297509622e+20*cos(theta)**9 + 3.25224961748214e+20*cos(theta)**7 - 5.55262129814024e+19*cos(theta)**5 + 3.55937262701297e+18*cos(theta)**3 - 5.77195561137239e+16*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl23_m13(theta, phi):
    return 8.54226296601593e-18*(1.0 - cos(theta)**2)**6.5*(6.9923366775866e+21*cos(theta)**10 - 6.9923366775866e+21*cos(theta)**8 + 2.2765747322375e+21*cos(theta)**6 - 2.77631064907012e+20*cos(theta)**4 + 1.06781178810389e+19*cos(theta)**2 - 5.77195561137239e+16)*cos(13*phi)

#@torch.jit.script
def Yl23_m14(theta, phi):
    return 4.44091105154346e-19*(1.0 - cos(theta)**2)**7*(6.9923366775866e+22*cos(theta)**9 - 5.59386934206928e+22*cos(theta)**7 + 1.3659448393425e+22*cos(theta)**5 - 1.11052425962805e+21*cos(theta)**3 + 2.13562357620778e+19*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl23_m15(theta, phi):
    return 2.40136967298897e-20*(1.0 - cos(theta)**2)**7.5*(6.29310300982794e+23*cos(theta)**8 - 3.9157085394485e+23*cos(theta)**6 + 6.82972419671249e+22*cos(theta)**4 - 3.33157277888414e+21*cos(theta)**2 + 2.13562357620778e+19)*cos(15*phi)

#@torch.jit.script
def Yl23_m16(theta, phi):
    return 1.35950786560836e-21*(1.0 - cos(theta)**2)**8*(5.03448240786235e+24*cos(theta)**7 - 2.3494251236691e+24*cos(theta)**5 + 2.731889678685e+23*cos(theta)**3 - 6.66314555776829e+21*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl23_m17(theta, phi):
    return 8.12461347795126e-23*(1.0 - cos(theta)**2)**8.5*(3.52413768550365e+25*cos(theta)**6 - 1.17471256183455e+25*cos(theta)**4 + 8.19566903605499e+23*cos(theta)**2 - 6.66314555776829e+21)*cos(17*phi)

#@torch.jit.script
def Yl23_m18(theta, phi):
    return 5.18006435618226e-24*(1.0 - cos(theta)**2)**9*(2.11448261130219e+26*cos(theta)**5 - 4.6988502473382e+25*cos(theta)**3 + 1.639133807211e+24*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl23_m19(theta, phi):
    return 3.5745840073783e-25*(1.0 - cos(theta)**2)**9.5*(1.05724130565109e+27*cos(theta)**4 - 1.40965507420146e+26*cos(theta)**2 + 1.639133807211e+24)*cos(19*phi)

#@torch.jit.script
def Yl23_m20(theta, phi):
    return 2.72559475329492e-26*(1.0 - cos(theta)**2)**10*(4.22896522260438e+27*cos(theta)**3 - 2.81931014840292e+26*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl23_m21(theta, phi):
    return 2.37232572869364e-27*(1.0 - cos(theta)**2)**10.5*(1.26868956678131e+28*cos(theta)**2 - 2.81931014840292e+26)*cos(21*phi)

#@torch.jit.script
def Yl23_m22(theta, phi):
    return 6.34509937549305*(1.0 - cos(theta)**2)**11*cos(22*phi)*cos(theta)

#@torch.jit.script
def Yl23_m23(theta, phi):
    return 0.935533863919911*(1.0 - cos(theta)**2)**11.5*cos(23*phi)

#@torch.jit.script
def Yl24_m_minus_24(theta, phi):
    return 0.9452287742978*(1.0 - cos(theta)**2)**12*sin(24*phi)

#@torch.jit.script
def Yl24_m_minus_23(theta, phi):
    return 6.54873704743938*(1.0 - cos(theta)**2)**11.5*sin(23*phi)*cos(theta)

#@torch.jit.script
def Yl24_m_minus_22(theta, phi):
    return 5.3240025801011e-29*(1.0 - cos(theta)**2)**11*(5.96284096387217e+29*cos(theta)**2 - 1.26868956678131e+28)*sin(22*phi)

#@torch.jit.script
def Yl24_m_minus_21(theta, phi):
    return 6.25428691320073e-28*(1.0 - cos(theta)**2)**10.5*(1.98761365462406e+29*cos(theta)**3 - 1.26868956678131e+28*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl24_m_minus_20(theta, phi):
    return 8.39100641322249e-27*(1.0 - cos(theta)**2)**10*(4.96903413656014e+28*cos(theta)**4 - 6.34344783390656e+27*cos(theta)**2 + 7.04827537100729e+25)*sin(20*phi)

#@torch.jit.script
def Yl24_m_minus_19(theta, phi):
    return 1.24458738133901e-25*(1.0 - cos(theta)**2)**9.5*(9.93806827312028e+27*cos(theta)**5 - 2.11448261130219e+27*cos(theta)**3 + 7.04827537100729e+25*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl24_m_minus_18(theta, phi):
    return 1.99910334761708e-24*(1.0 - cos(theta)**2)**9*(1.65634471218671e+27*cos(theta)**6 - 5.28620652825547e+26*cos(theta)**4 + 3.52413768550365e+25*cos(theta)**2 - 2.731889678685e+23)*sin(18*phi)

#@torch.jit.script
def Yl24_m_minus_17(theta, phi):
    return 3.42774820132609e-23*(1.0 - cos(theta)**2)**8.5*(2.36620673169531e+26*cos(theta)**7 - 1.05724130565109e+26*cos(theta)**5 + 1.17471256183455e+25*cos(theta)**3 - 2.731889678685e+23*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl24_m_minus_16(theta, phi):
    return 6.2079160239131e-22*(1.0 - cos(theta)**2)**8*(2.95775841461913e+25*cos(theta)**8 - 1.76206884275182e+25*cos(theta)**6 + 2.93678140458637e+24*cos(theta)**4 - 1.3659448393425e+23*cos(theta)**2 + 8.32893194721036e+20)*sin(16*phi)

#@torch.jit.script
def Yl24_m_minus_15(theta, phi):
    return 1.1778692495173e-20*(1.0 - cos(theta)**2)**7.5*(3.2863982384657e+24*cos(theta)**9 - 2.51724120393118e+24*cos(theta)**7 + 5.87356280917274e+23*cos(theta)**5 - 4.553149464475e+22*cos(theta)**3 + 8.32893194721036e+20*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl24_m_minus_14(theta, phi):
    return 2.32610538861376e-19*(1.0 - cos(theta)**2)**7*(3.2863982384657e+23*cos(theta)**10 - 3.14655150491397e+23*cos(theta)**8 + 9.78927134862124e+22*cos(theta)**6 - 1.13828736611875e+22*cos(theta)**4 + 4.16446597360518e+20*cos(theta)**2 - 2.13562357620778e+18)*sin(14*phi)

#@torch.jit.script
def Yl24_m_minus_13(theta, phi):
    return 4.75573370217054e-18*(1.0 - cos(theta)**2)**6.5*(2.98763476224155e+22*cos(theta)**11 - 3.4961683387933e+22*cos(theta)**9 + 1.39846733551732e+22*cos(theta)**7 - 2.2765747322375e+21*cos(theta)**5 + 1.38815532453506e+20*cos(theta)**3 - 2.13562357620778e+18*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl24_m_minus_12(theta, phi):
    return 1.00209527253683e-16*(1.0 - cos(theta)**2)**6*(2.48969563520129e+21*cos(theta)**12 - 3.4961683387933e+21*cos(theta)**10 + 1.74808416939665e+21*cos(theta)**8 - 3.79429122039583e+20*cos(theta)**6 + 3.47038831133765e+19*cos(theta)**4 - 1.06781178810389e+18*cos(theta)**2 + 4.80996300947699e+15)*sin(12*phi)

#@torch.jit.script
def Yl24_m_minus_11(theta, phi):
    return 2.16786353281895e-15*(1.0 - cos(theta)**2)**5.5*(1.91515048861638e+20*cos(theta)**13 - 3.17833485344846e+20*cos(theta)**11 + 1.94231574377406e+20*cos(theta)**9 - 5.4204160291369e+19*cos(theta)**7 + 6.9407766226753e+18*cos(theta)**5 - 3.55937262701297e+17*cos(theta)**3 + 4.80996300947699e+15*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl24_m_minus_10(theta, phi):
    return 4.79877049408895e-14*(1.0 - cos(theta)**2)**5*(1.36796463472598e+19*cos(theta)**14 - 2.64861237787371e+19*cos(theta)**12 + 1.94231574377406e+19*cos(theta)**10 - 6.77552003642113e+18*cos(theta)**8 + 1.15679610377922e+18*cos(theta)**6 - 8.89843156753244e+16*cos(theta)**4 + 2.4049815047385e+15*cos(theta)**2 - 9816251039748.96)*sin(10*phi)

#@torch.jit.script
def Yl24_m_minus_9(theta, phi):
    return 1.08371495837322e-12*(1.0 - cos(theta)**2)**4.5*(9.11976423150656e+17*cos(theta)**15 - 2.03739413682593e+18*cos(theta)**13 + 1.76574158524914e+18*cos(theta)**11 - 7.52835559602347e+17*cos(theta)**9 + 1.65256586254174e+17*cos(theta)**7 - 1.77968631350649e+16*cos(theta)**5 + 801660501579499.0*cos(theta)**3 - 9816251039748.96*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl24_m_minus_8(theta, phi):
    return 2.49018738774613e-11*(1.0 - cos(theta)**2)**4*(5.6998526446916e+16*cos(theta)**16 - 1.45528152630424e+17*cos(theta)**14 + 1.47145132104095e+17*cos(theta)**12 - 7.52835559602347e+16*cos(theta)**10 + 2.06570732817717e+16*cos(theta)**8 - 2.96614385584415e+15*cos(theta)**6 + 200415125394875.0*cos(theta)**4 - 4908125519874.48*cos(theta)**2 + 18591384544.9791)*sin(8*phi)

#@torch.jit.script
def Yl24_m_minus_7(theta, phi):
    return 5.80806514683927e-10*(1.0 - cos(theta)**2)**3.5*(3.35285449687741e+15*cos(theta)**17 - 9.70187684202825e+15*cos(theta)**15 + 1.13188563156996e+16*cos(theta)**13 - 6.84395963274861e+15*cos(theta)**11 + 2.2952303646413e+15*cos(theta)**9 - 423734836549164.0*cos(theta)**7 + 40083025078974.9*cos(theta)**5 - 1636041839958.16*cos(theta)**3 + 18591384544.9791*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl24_m_minus_6(theta, phi):
    return 1.37198252096958e-8*(1.0 - cos(theta)**2)**3*(186269694270967.0*cos(theta)**18 - 606367302626766.0*cos(theta)**16 + 808489736835688.0*cos(theta)**14 - 570329969395718.0*cos(theta)**12 + 229523036464130.0*cos(theta)**10 - 52966854568645.4*cos(theta)**8 + 6680504179829.16*cos(theta)**6 - 409010459989.54*cos(theta)**4 + 9295692272.48955*cos(theta)**2 - 33317893.4497833)*sin(6*phi)

#@torch.jit.script
def Yl24_m_minus_5(theta, phi):
    return 3.27556337379121e-7*(1.0 - cos(theta)**2)**2.5*(9803668119524.59*cos(theta)**19 - 35668664860398.0*cos(theta)**17 + 53899315789045.8*cos(theta)**15 - 43871536107362.9*cos(theta)**13 + 20865730587648.2*cos(theta)**11 - 5885206063182.83*cos(theta)**9 + 954357739975.594*cos(theta)**7 - 81802091997.908*cos(theta)**5 + 3098564090.82985*cos(theta)**3 - 33317893.4497833*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl24_m_minus_4(theta, phi):
    return 7.88860123286696e-6*(1.0 - cos(theta)**2)**2*(490183405976.23*cos(theta)**20 - 1981592492244.33*cos(theta)**18 + 3368707236815.36*cos(theta)**16 - 3133681150525.92*cos(theta)**14 + 1738810882304.02*cos(theta)**12 - 588520606318.283*cos(theta)**10 + 119294717496.949*cos(theta)**8 - 13633681999.6513*cos(theta)**6 + 774641022.707462*cos(theta)**4 - 16658946.7248917*cos(theta)**2 + 57444.6438789368)*sin(4*phi)

#@torch.jit.script
def Yl24_m_minus_3(theta, phi):
    return 0.000191288413903665*(1.0 - cos(theta)**2)**1.5*(23342066951.249*cos(theta)**21 - 104294341697.07*cos(theta)**19 + 198159249224.433*cos(theta)**17 - 208912076701.728*cos(theta)**15 + 133754683254.155*cos(theta)**13 - 53501873301.6621*cos(theta)**11 + 13254968610.7721*cos(theta)**9 - 1947668857.09305*cos(theta)**7 + 154928204.541492*cos(theta)**5 - 5552982.24163055*cos(theta)**3 + 57444.6438789368*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl24_m_minus_2(theta, phi):
    return 0.00466210326274582*(1.0 - cos(theta)**2)*(1061003043.23859*cos(theta)**22 - 5214717084.85351*cos(theta)**20 + 11008847179.1352*cos(theta)**18 - 13057004793.858*cos(theta)**16 + 9553905946.72537*cos(theta)**14 - 4458489441.80517*cos(theta)**12 + 1325496861.07721*cos(theta)**10 - 243458607.136631*cos(theta)**8 + 25821367.4235821*cos(theta)**6 - 1388245.56040764*cos(theta)**4 + 28722.3219394684*cos(theta)**2 - 96.7081546783447)*sin(2*phi)

#@torch.jit.script
def Yl24_m_minus_1(theta, phi):
    return 0.114007252777348*(1.0 - cos(theta)**2)**0.5*(46130567.0973301*cos(theta)**23 - 248319861.1835*cos(theta)**21 + 579413009.428167*cos(theta)**19 - 768059105.521059*cos(theta)**17 + 636927063.115025*cos(theta)**15 - 342960726.292706*cos(theta)**13 + 120499714.643383*cos(theta)**11 - 27050956.3485146*cos(theta)**9 + 3688766.77479744*cos(theta)**7 - 277649.112081528*cos(theta)**5 + 9574.10731315613*cos(theta)**3 - 96.7081546783447*cos(theta))*sin(phi)

#@torch.jit.script
def Yl24_m0(theta, phi):
    return 11923960.6056839*cos(theta)**24 - 70021555.8972075*cos(theta)**22 + 179721993.469499*cos(theta)**20 - 264706812.086859*cos(theta)**18 + 246952086.885911*cos(theta)**16 - 151970515.006715*cos(theta)**14 + 62294220.115365*cos(theta)**12 - 16781300.1127106*cos(theta)**10 + 2860448.88284839*cos(theta)**8 - 287070.138780484*cos(theta)**6 + 14848.455454163*cos(theta)**4 - 299.968797053797*cos(theta)**2 + 0.999895990179324

#@torch.jit.script
def Yl24_m1(theta, phi):
    return 0.114007252777348*(1.0 - cos(theta)**2)**0.5*(46130567.0973301*cos(theta)**23 - 248319861.1835*cos(theta)**21 + 579413009.428167*cos(theta)**19 - 768059105.521059*cos(theta)**17 + 636927063.115025*cos(theta)**15 - 342960726.292706*cos(theta)**13 + 120499714.643383*cos(theta)**11 - 27050956.3485146*cos(theta)**9 + 3688766.77479744*cos(theta)**7 - 277649.112081528*cos(theta)**5 + 9574.10731315613*cos(theta)**3 - 96.7081546783447*cos(theta))*cos(phi)

#@torch.jit.script
def Yl24_m2(theta, phi):
    return 0.00466210326274582*(1.0 - cos(theta)**2)*(1061003043.23859*cos(theta)**22 - 5214717084.85351*cos(theta)**20 + 11008847179.1352*cos(theta)**18 - 13057004793.858*cos(theta)**16 + 9553905946.72537*cos(theta)**14 - 4458489441.80517*cos(theta)**12 + 1325496861.07721*cos(theta)**10 - 243458607.136631*cos(theta)**8 + 25821367.4235821*cos(theta)**6 - 1388245.56040764*cos(theta)**4 + 28722.3219394684*cos(theta)**2 - 96.7081546783447)*cos(2*phi)

#@torch.jit.script
def Yl24_m3(theta, phi):
    return 0.000191288413903665*(1.0 - cos(theta)**2)**1.5*(23342066951.249*cos(theta)**21 - 104294341697.07*cos(theta)**19 + 198159249224.433*cos(theta)**17 - 208912076701.728*cos(theta)**15 + 133754683254.155*cos(theta)**13 - 53501873301.6621*cos(theta)**11 + 13254968610.7721*cos(theta)**9 - 1947668857.09305*cos(theta)**7 + 154928204.541492*cos(theta)**5 - 5552982.24163055*cos(theta)**3 + 57444.6438789368*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl24_m4(theta, phi):
    return 7.88860123286696e-6*(1.0 - cos(theta)**2)**2*(490183405976.23*cos(theta)**20 - 1981592492244.33*cos(theta)**18 + 3368707236815.36*cos(theta)**16 - 3133681150525.92*cos(theta)**14 + 1738810882304.02*cos(theta)**12 - 588520606318.283*cos(theta)**10 + 119294717496.949*cos(theta)**8 - 13633681999.6513*cos(theta)**6 + 774641022.707462*cos(theta)**4 - 16658946.7248917*cos(theta)**2 + 57444.6438789368)*cos(4*phi)

#@torch.jit.script
def Yl24_m5(theta, phi):
    return 3.27556337379121e-7*(1.0 - cos(theta)**2)**2.5*(9803668119524.59*cos(theta)**19 - 35668664860398.0*cos(theta)**17 + 53899315789045.8*cos(theta)**15 - 43871536107362.9*cos(theta)**13 + 20865730587648.2*cos(theta)**11 - 5885206063182.83*cos(theta)**9 + 954357739975.594*cos(theta)**7 - 81802091997.908*cos(theta)**5 + 3098564090.82985*cos(theta)**3 - 33317893.4497833*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl24_m6(theta, phi):
    return 1.37198252096958e-8*(1.0 - cos(theta)**2)**3*(186269694270967.0*cos(theta)**18 - 606367302626766.0*cos(theta)**16 + 808489736835688.0*cos(theta)**14 - 570329969395718.0*cos(theta)**12 + 229523036464130.0*cos(theta)**10 - 52966854568645.4*cos(theta)**8 + 6680504179829.16*cos(theta)**6 - 409010459989.54*cos(theta)**4 + 9295692272.48955*cos(theta)**2 - 33317893.4497833)*cos(6*phi)

#@torch.jit.script
def Yl24_m7(theta, phi):
    return 5.80806514683927e-10*(1.0 - cos(theta)**2)**3.5*(3.35285449687741e+15*cos(theta)**17 - 9.70187684202825e+15*cos(theta)**15 + 1.13188563156996e+16*cos(theta)**13 - 6.84395963274861e+15*cos(theta)**11 + 2.2952303646413e+15*cos(theta)**9 - 423734836549164.0*cos(theta)**7 + 40083025078974.9*cos(theta)**5 - 1636041839958.16*cos(theta)**3 + 18591384544.9791*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl24_m8(theta, phi):
    return 2.49018738774613e-11*(1.0 - cos(theta)**2)**4*(5.6998526446916e+16*cos(theta)**16 - 1.45528152630424e+17*cos(theta)**14 + 1.47145132104095e+17*cos(theta)**12 - 7.52835559602347e+16*cos(theta)**10 + 2.06570732817717e+16*cos(theta)**8 - 2.96614385584415e+15*cos(theta)**6 + 200415125394875.0*cos(theta)**4 - 4908125519874.48*cos(theta)**2 + 18591384544.9791)*cos(8*phi)

#@torch.jit.script
def Yl24_m9(theta, phi):
    return 1.08371495837322e-12*(1.0 - cos(theta)**2)**4.5*(9.11976423150656e+17*cos(theta)**15 - 2.03739413682593e+18*cos(theta)**13 + 1.76574158524914e+18*cos(theta)**11 - 7.52835559602347e+17*cos(theta)**9 + 1.65256586254174e+17*cos(theta)**7 - 1.77968631350649e+16*cos(theta)**5 + 801660501579499.0*cos(theta)**3 - 9816251039748.96*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl24_m10(theta, phi):
    return 4.79877049408895e-14*(1.0 - cos(theta)**2)**5*(1.36796463472598e+19*cos(theta)**14 - 2.64861237787371e+19*cos(theta)**12 + 1.94231574377406e+19*cos(theta)**10 - 6.77552003642113e+18*cos(theta)**8 + 1.15679610377922e+18*cos(theta)**6 - 8.89843156753244e+16*cos(theta)**4 + 2.4049815047385e+15*cos(theta)**2 - 9816251039748.96)*cos(10*phi)

#@torch.jit.script
def Yl24_m11(theta, phi):
    return 2.16786353281895e-15*(1.0 - cos(theta)**2)**5.5*(1.91515048861638e+20*cos(theta)**13 - 3.17833485344846e+20*cos(theta)**11 + 1.94231574377406e+20*cos(theta)**9 - 5.4204160291369e+19*cos(theta)**7 + 6.9407766226753e+18*cos(theta)**5 - 3.55937262701297e+17*cos(theta)**3 + 4.80996300947699e+15*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl24_m12(theta, phi):
    return 1.00209527253683e-16*(1.0 - cos(theta)**2)**6*(2.48969563520129e+21*cos(theta)**12 - 3.4961683387933e+21*cos(theta)**10 + 1.74808416939665e+21*cos(theta)**8 - 3.79429122039583e+20*cos(theta)**6 + 3.47038831133765e+19*cos(theta)**4 - 1.06781178810389e+18*cos(theta)**2 + 4.80996300947699e+15)*cos(12*phi)

#@torch.jit.script
def Yl24_m13(theta, phi):
    return 4.75573370217054e-18*(1.0 - cos(theta)**2)**6.5*(2.98763476224155e+22*cos(theta)**11 - 3.4961683387933e+22*cos(theta)**9 + 1.39846733551732e+22*cos(theta)**7 - 2.2765747322375e+21*cos(theta)**5 + 1.38815532453506e+20*cos(theta)**3 - 2.13562357620778e+18*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl24_m14(theta, phi):
    return 2.32610538861376e-19*(1.0 - cos(theta)**2)**7*(3.2863982384657e+23*cos(theta)**10 - 3.14655150491397e+23*cos(theta)**8 + 9.78927134862124e+22*cos(theta)**6 - 1.13828736611875e+22*cos(theta)**4 + 4.16446597360518e+20*cos(theta)**2 - 2.13562357620778e+18)*cos(14*phi)

#@torch.jit.script
def Yl24_m15(theta, phi):
    return 1.1778692495173e-20*(1.0 - cos(theta)**2)**7.5*(3.2863982384657e+24*cos(theta)**9 - 2.51724120393118e+24*cos(theta)**7 + 5.87356280917274e+23*cos(theta)**5 - 4.553149464475e+22*cos(theta)**3 + 8.32893194721036e+20*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl24_m16(theta, phi):
    return 6.2079160239131e-22*(1.0 - cos(theta)**2)**8*(2.95775841461913e+25*cos(theta)**8 - 1.76206884275182e+25*cos(theta)**6 + 2.93678140458637e+24*cos(theta)**4 - 1.3659448393425e+23*cos(theta)**2 + 8.32893194721036e+20)*cos(16*phi)

#@torch.jit.script
def Yl24_m17(theta, phi):
    return 3.42774820132609e-23*(1.0 - cos(theta)**2)**8.5*(2.36620673169531e+26*cos(theta)**7 - 1.05724130565109e+26*cos(theta)**5 + 1.17471256183455e+25*cos(theta)**3 - 2.731889678685e+23*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl24_m18(theta, phi):
    return 1.99910334761708e-24*(1.0 - cos(theta)**2)**9*(1.65634471218671e+27*cos(theta)**6 - 5.28620652825547e+26*cos(theta)**4 + 3.52413768550365e+25*cos(theta)**2 - 2.731889678685e+23)*cos(18*phi)

#@torch.jit.script
def Yl24_m19(theta, phi):
    return 1.24458738133901e-25*(1.0 - cos(theta)**2)**9.5*(9.93806827312028e+27*cos(theta)**5 - 2.11448261130219e+27*cos(theta)**3 + 7.04827537100729e+25*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl24_m20(theta, phi):
    return 8.39100641322249e-27*(1.0 - cos(theta)**2)**10*(4.96903413656014e+28*cos(theta)**4 - 6.34344783390656e+27*cos(theta)**2 + 7.04827537100729e+25)*cos(20*phi)

#@torch.jit.script
def Yl24_m21(theta, phi):
    return 6.25428691320073e-28*(1.0 - cos(theta)**2)**10.5*(1.98761365462406e+29*cos(theta)**3 - 1.26868956678131e+28*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl24_m22(theta, phi):
    return 5.3240025801011e-29*(1.0 - cos(theta)**2)**11*(5.96284096387217e+29*cos(theta)**2 - 1.26868956678131e+28)*cos(22*phi)

#@torch.jit.script
def Yl24_m23(theta, phi):
    return 6.54873704743938*(1.0 - cos(theta)**2)**11.5*cos(23*phi)*cos(theta)

#@torch.jit.script
def Yl24_m24(theta, phi):
    return 0.9452287742978*(1.0 - cos(theta)**2)**12*cos(24*phi)

#@torch.jit.script
def Yl25_m_minus_25(theta, phi):
    return 0.954634267390256*(1.0 - cos(theta)**2)**12.5*sin(25*phi)

#@torch.jit.script
def Yl25_m_minus_24(theta, phi):
    return 6.75028364024702*(1.0 - cos(theta)**2)**12*sin(24*phi)*cos(theta)

#@torch.jit.script
def Yl25_m_minus_23(theta, phi):
    return 1.14355157834306e-30*(1.0 - cos(theta)**2)**11.5*(2.92179207229736e+31*cos(theta)**2 - 5.96284096387217e+29)*sin(23*phi)

#@torch.jit.script
def Yl25_m_minus_22(theta, phi):
    return 1.37226189401167e-29*(1.0 - cos(theta)**2)**11*(9.73930690765788e+30*cos(theta)**3 - 5.96284096387217e+29*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl25_m_minus_21(theta, phi):
    return 1.88155071332724e-28*(1.0 - cos(theta)**2)**10.5*(2.43482672691447e+30*cos(theta)**4 - 2.98142048193609e+29*cos(theta)**2 + 3.17172391695328e+27)*sin(21*phi)

#@torch.jit.script
def Yl25_m_minus_20(theta, phi):
    return 2.85351294016536e-27*(1.0 - cos(theta)**2)**10*(4.86965345382894e+29*cos(theta)**5 - 9.93806827312028e+28*cos(theta)**3 + 3.17172391695328e+27*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl25_m_minus_19(theta, phi):
    return 4.68880021638437e-26*(1.0 - cos(theta)**2)**9.5*(8.1160890897149e+28*cos(theta)**6 - 2.48451706828007e+28*cos(theta)**4 + 1.58586195847664e+27*cos(theta)**2 - 1.17471256183455e+25)*sin(19*phi)

#@torch.jit.script
def Yl25_m_minus_18(theta, phi):
    return 8.22881098367386e-25*(1.0 - cos(theta)**2)**9*(1.1594412985307e+28*cos(theta)**7 - 4.96903413656014e+27*cos(theta)**5 + 5.28620652825547e+26*cos(theta)**3 - 1.17471256183455e+25*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl25_m_minus_17(theta, phi):
    return 1.52621707468272e-23*(1.0 - cos(theta)**2)**8.5*(1.44930162316337e+27*cos(theta)**8 - 8.28172356093357e+26*cos(theta)**6 + 1.32155163206387e+26*cos(theta)**4 - 5.87356280917274e+24*cos(theta)**2 + 3.41486209835625e+22)*sin(17*phi)

#@torch.jit.script
def Yl25_m_minus_16(theta, phi):
    return 2.96730513315039e-22*(1.0 - cos(theta)**2)**8*(1.61033513684819e+26*cos(theta)**9 - 1.18310336584765e+26*cos(theta)**7 + 2.64310326412774e+25*cos(theta)**5 - 1.95785426972425e+24*cos(theta)**3 + 3.41486209835625e+22*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl25_m_minus_15(theta, phi):
    return 6.00833495972093e-21*(1.0 - cos(theta)**2)**7.5*(1.61033513684819e+25*cos(theta)**10 - 1.47887920730957e+25*cos(theta)**8 + 4.40517210687956e+24*cos(theta)**6 - 4.89463567431062e+23*cos(theta)**4 + 1.70743104917812e+22*cos(theta)**2 - 8.32893194721036e+19)*sin(15*phi)

#@torch.jit.script
def Yl25_m_minus_14(theta, phi):
    return 1.26031897370507e-19*(1.0 - cos(theta)**2)**7*(1.46394103349836e+24*cos(theta)**11 - 1.64319911923285e+24*cos(theta)**9 + 6.29310300982794e+23*cos(theta)**7 - 9.78927134862124e+22*cos(theta)**5 + 5.69143683059375e+21*cos(theta)**3 - 8.32893194721036e+19*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl25_m_minus_13(theta, phi):
    return 2.72648680988027e-18*(1.0 - cos(theta)**2)**6.5*(1.21995086124863e+23*cos(theta)**12 - 1.64319911923285e+23*cos(theta)**10 + 7.86637876228493e+22*cos(theta)**8 - 1.63154522477021e+22*cos(theta)**6 + 1.42285920764844e+21*cos(theta)**4 - 4.16446597360518e+19*cos(theta)**2 + 1.77968631350649e+17)*sin(13*phi)

#@torch.jit.script
def Yl25_m_minus_12(theta, phi):
    return 6.05991978517773e-17*(1.0 - cos(theta)**2)**6*(9.38423739422025e+21*cos(theta)**13 - 1.49381738112077e+22*cos(theta)**11 + 8.74042084698325e+21*cos(theta)**9 - 2.33077889252887e+21*cos(theta)**7 + 2.84571841529687e+20*cos(theta)**5 - 1.38815532453506e+19*cos(theta)**3 + 1.77968631350649e+17*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl25_m_minus_11(theta, phi):
    return 1.37921431263761e-15*(1.0 - cos(theta)**2)**5.5*(6.70302671015732e+20*cos(theta)**14 - 1.24484781760064e+21*cos(theta)**12 + 8.74042084698325e+20*cos(theta)**10 - 2.91347361566108e+20*cos(theta)**8 + 4.74286402549479e+19*cos(theta)**6 - 3.47038831133765e+18*cos(theta)**4 + 8.89843156753244e+16*cos(theta)**2 - 343568786391214.0)*sin(11*phi)

#@torch.jit.script
def Yl25_m_minus_10(theta, phi):
    return 3.20500443821783e-14*(1.0 - cos(theta)**2)**5*(4.46868447343821e+19*cos(theta)**15 - 9.57575244308188e+19*cos(theta)**13 + 7.94583713362114e+19*cos(theta)**11 - 3.23719290629009e+19*cos(theta)**9 + 6.77552003642113e+18*cos(theta)**7 - 6.9407766226753e+17*cos(theta)**5 + 2.96614385584414e+16*cos(theta)**3 - 343568786391214.0*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl25_m_minus_9(theta, phi):
    return 7.58442478467402e-13*(1.0 - cos(theta)**2)**4.5*(2.79292779589888e+18*cos(theta)**16 - 6.83982317362992e+18*cos(theta)**14 + 6.62153094468428e+18*cos(theta)**12 - 3.23719290629009e+18*cos(theta)**10 + 8.46940004552641e+17*cos(theta)**8 - 1.15679610377922e+17*cos(theta)**6 + 7.41535963961036e+15*cos(theta)**4 - 171784393195607.0*cos(theta)**2 + 613515689984.31)*sin(9*phi)

#@torch.jit.script
def Yl25_m_minus_8(theta, phi):
    return 1.82341938685839e-11*(1.0 - cos(theta)**2)**4*(1.64289870346993e+17*cos(theta)**17 - 4.55988211575328e+17*cos(theta)**15 + 5.09348534206483e+17*cos(theta)**13 - 2.9429026420819e+17*cos(theta)**11 + 9.41044449502934e+16*cos(theta)**9 - 1.65256586254174e+16*cos(theta)**7 + 1.48307192792207e+15*cos(theta)**5 - 57261464398535.6*cos(theta)**3 + 613515689984.31*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl25_m_minus_7(theta, phi):
    return 4.44405873797859e-10*(1.0 - cos(theta)**2)**3.5*(9.12721501927739e+15*cos(theta)**18 - 2.8499263223458e+16*cos(theta)**16 + 3.63820381576059e+16*cos(theta)**14 - 2.45241886840159e+16*cos(theta)**12 + 9.41044449502934e+15*cos(theta)**10 - 2.06570732817717e+15*cos(theta)**8 + 247178654653679.0*cos(theta)**6 - 14315366099633.9*cos(theta)**4 + 306757844992.155*cos(theta)**2 - 1032854696.94328)*sin(7*phi)

#@torch.jit.script
def Yl25_m_minus_6(theta, phi):
    return 1.09580071657648e-8*(1.0 - cos(theta)**2)**3*(480379737856705.0*cos(theta)**19 - 1.67642724843871e+15*cos(theta)**17 + 2.42546921050706e+15*cos(theta)**15 - 1.8864760526166e+15*cos(theta)**13 + 855494954093576.0*cos(theta)**11 - 229523036464130.0*cos(theta)**9 + 35311236379097.0*cos(theta)**7 - 2863073219926.78*cos(theta)**5 + 102252614997.385*cos(theta)**3 - 1032854696.94328*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl25_m_minus_5(theta, phi):
    return 2.72852178015624e-7*(1.0 - cos(theta)**2)**2.5*(24018986892835.3*cos(theta)**20 - 93134847135483.6*cos(theta)**18 + 151591825656691.0*cos(theta)**16 - 134748289472615.0*cos(theta)**14 + 71291246174464.7*cos(theta)**12 - 22952303646413.0*cos(theta)**10 + 4413904547387.12*cos(theta)**8 - 477178869987.797*cos(theta)**6 + 25563153749.3463*cos(theta)**4 - 516427348.471642*cos(theta)**2 + 1665894.67248917)*sin(5*phi)

#@torch.jit.script
def Yl25_m_minus_4(theta, phi):
    return 6.84853531495298e-6*(1.0 - cos(theta)**2)**2*(1143761280611.2*cos(theta)**21 - 4901834059762.3*cos(theta)**19 + 8917166215099.5*cos(theta)**17 - 8983219298174.31*cos(theta)**15 + 5483942013420.36*cos(theta)**13 - 2086573058764.82*cos(theta)**11 + 490433838598.569*cos(theta)**9 - 68168409998.2567*cos(theta)**7 + 5112630749.86925*cos(theta)**5 - 172142449.490547*cos(theta)**3 + 1665894.67248917*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl25_m_minus_3(theta, phi):
    return 0.000172984837897952*(1.0 - cos(theta)**2)**1.5*(51989149118.691*cos(theta)**22 - 245091702988.115*cos(theta)**20 + 495398123061.083*cos(theta)**18 - 561451206135.894*cos(theta)**16 + 391710143815.74*cos(theta)**14 - 173881088230.402*cos(theta)**12 + 49043383859.8569*cos(theta)**10 - 8521051249.78209*cos(theta)**8 + 852105124.978209*cos(theta)**6 - 43035612.3726368*cos(theta)**4 + 832947.336244583*cos(theta)**2 - 2611.12017631531)*sin(3*phi)

#@torch.jit.script
def Yl25_m_minus_2(theta, phi):
    return 0.00438986305798052*(1.0 - cos(theta)**2)*(2260397787.76917*cos(theta)**23 - 11671033475.6245*cos(theta)**21 + 26073585424.2675*cos(theta)**19 - 33026541537.4055*cos(theta)**17 + 26114009587.716*cos(theta)**15 - 13375468325.4155*cos(theta)**13 + 4458489441.80517*cos(theta)**11 - 946783472.198009*cos(theta)**9 + 121729303.568316*cos(theta)**7 - 8607122.47452736*cos(theta)**5 + 277649.112081528*cos(theta)**3 - 2611.12017631531*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl25_m_minus_1(theta, phi):
    return 0.11174766972402*(1.0 - cos(theta)**2)**0.5*(94183241.1570489*cos(theta)**24 - 530501521.619296*cos(theta)**22 + 1303679271.21338*cos(theta)**20 - 1834807863.1892*cos(theta)**18 + 1632125599.23225*cos(theta)**16 - 955390594.672537*cos(theta)**14 + 371540786.817098*cos(theta)**12 - 94678347.2198009*cos(theta)**10 + 15216162.9460394*cos(theta)**8 - 1434520.41242123*cos(theta)**6 + 69412.2780203819*cos(theta)**4 - 1305.56008815765*cos(theta)**2 + 4.02950644493103)*sin(phi)

#@torch.jit.script
def Yl25_m0(theta, phi):
    return 23843151.1500716*cos(theta)**25 - 145978476.42901*cos(theta)**23 + 392899516.346165*cos(theta)**21 - 611177025.427368*cos(theta)**19 + 607623670.628372*cos(theta)**17 - 403106435.148578*cos(theta)**15 + 180881092.694875*cos(theta)**13 - 54473842.5876457*cos(theta)**11 + 10700219.0797161*cos(theta)**9 - 1296996.2520868*cos(theta)**7 + 87861.0364316867*cos(theta)**5 - 2754.26446494316*cos(theta)**3 + 25.5024487494737*cos(theta)

#@torch.jit.script
def Yl25_m1(theta, phi):
    return 0.11174766972402*(1.0 - cos(theta)**2)**0.5*(94183241.1570489*cos(theta)**24 - 530501521.619296*cos(theta)**22 + 1303679271.21338*cos(theta)**20 - 1834807863.1892*cos(theta)**18 + 1632125599.23225*cos(theta)**16 - 955390594.672537*cos(theta)**14 + 371540786.817098*cos(theta)**12 - 94678347.2198009*cos(theta)**10 + 15216162.9460394*cos(theta)**8 - 1434520.41242123*cos(theta)**6 + 69412.2780203819*cos(theta)**4 - 1305.56008815765*cos(theta)**2 + 4.02950644493103)*cos(phi)

#@torch.jit.script
def Yl25_m2(theta, phi):
    return 0.00438986305798052*(1.0 - cos(theta)**2)*(2260397787.76917*cos(theta)**23 - 11671033475.6245*cos(theta)**21 + 26073585424.2675*cos(theta)**19 - 33026541537.4055*cos(theta)**17 + 26114009587.716*cos(theta)**15 - 13375468325.4155*cos(theta)**13 + 4458489441.80517*cos(theta)**11 - 946783472.198009*cos(theta)**9 + 121729303.568316*cos(theta)**7 - 8607122.47452736*cos(theta)**5 + 277649.112081528*cos(theta)**3 - 2611.12017631531*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl25_m3(theta, phi):
    return 0.000172984837897952*(1.0 - cos(theta)**2)**1.5*(51989149118.691*cos(theta)**22 - 245091702988.115*cos(theta)**20 + 495398123061.083*cos(theta)**18 - 561451206135.894*cos(theta)**16 + 391710143815.74*cos(theta)**14 - 173881088230.402*cos(theta)**12 + 49043383859.8569*cos(theta)**10 - 8521051249.78209*cos(theta)**8 + 852105124.978209*cos(theta)**6 - 43035612.3726368*cos(theta)**4 + 832947.336244583*cos(theta)**2 - 2611.12017631531)*cos(3*phi)

#@torch.jit.script
def Yl25_m4(theta, phi):
    return 6.84853531495298e-6*(1.0 - cos(theta)**2)**2*(1143761280611.2*cos(theta)**21 - 4901834059762.3*cos(theta)**19 + 8917166215099.5*cos(theta)**17 - 8983219298174.31*cos(theta)**15 + 5483942013420.36*cos(theta)**13 - 2086573058764.82*cos(theta)**11 + 490433838598.569*cos(theta)**9 - 68168409998.2567*cos(theta)**7 + 5112630749.86925*cos(theta)**5 - 172142449.490547*cos(theta)**3 + 1665894.67248917*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl25_m5(theta, phi):
    return 2.72852178015624e-7*(1.0 - cos(theta)**2)**2.5*(24018986892835.3*cos(theta)**20 - 93134847135483.6*cos(theta)**18 + 151591825656691.0*cos(theta)**16 - 134748289472615.0*cos(theta)**14 + 71291246174464.7*cos(theta)**12 - 22952303646413.0*cos(theta)**10 + 4413904547387.12*cos(theta)**8 - 477178869987.797*cos(theta)**6 + 25563153749.3463*cos(theta)**4 - 516427348.471642*cos(theta)**2 + 1665894.67248917)*cos(5*phi)

#@torch.jit.script
def Yl25_m6(theta, phi):
    return 1.09580071657648e-8*(1.0 - cos(theta)**2)**3*(480379737856705.0*cos(theta)**19 - 1.67642724843871e+15*cos(theta)**17 + 2.42546921050706e+15*cos(theta)**15 - 1.8864760526166e+15*cos(theta)**13 + 855494954093576.0*cos(theta)**11 - 229523036464130.0*cos(theta)**9 + 35311236379097.0*cos(theta)**7 - 2863073219926.78*cos(theta)**5 + 102252614997.385*cos(theta)**3 - 1032854696.94328*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl25_m7(theta, phi):
    return 4.44405873797859e-10*(1.0 - cos(theta)**2)**3.5*(9.12721501927739e+15*cos(theta)**18 - 2.8499263223458e+16*cos(theta)**16 + 3.63820381576059e+16*cos(theta)**14 - 2.45241886840159e+16*cos(theta)**12 + 9.41044449502934e+15*cos(theta)**10 - 2.06570732817717e+15*cos(theta)**8 + 247178654653679.0*cos(theta)**6 - 14315366099633.9*cos(theta)**4 + 306757844992.155*cos(theta)**2 - 1032854696.94328)*cos(7*phi)

#@torch.jit.script
def Yl25_m8(theta, phi):
    return 1.82341938685839e-11*(1.0 - cos(theta)**2)**4*(1.64289870346993e+17*cos(theta)**17 - 4.55988211575328e+17*cos(theta)**15 + 5.09348534206483e+17*cos(theta)**13 - 2.9429026420819e+17*cos(theta)**11 + 9.41044449502934e+16*cos(theta)**9 - 1.65256586254174e+16*cos(theta)**7 + 1.48307192792207e+15*cos(theta)**5 - 57261464398535.6*cos(theta)**3 + 613515689984.31*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl25_m9(theta, phi):
    return 7.58442478467402e-13*(1.0 - cos(theta)**2)**4.5*(2.79292779589888e+18*cos(theta)**16 - 6.83982317362992e+18*cos(theta)**14 + 6.62153094468428e+18*cos(theta)**12 - 3.23719290629009e+18*cos(theta)**10 + 8.46940004552641e+17*cos(theta)**8 - 1.15679610377922e+17*cos(theta)**6 + 7.41535963961036e+15*cos(theta)**4 - 171784393195607.0*cos(theta)**2 + 613515689984.31)*cos(9*phi)

#@torch.jit.script
def Yl25_m10(theta, phi):
    return 3.20500443821783e-14*(1.0 - cos(theta)**2)**5*(4.46868447343821e+19*cos(theta)**15 - 9.57575244308188e+19*cos(theta)**13 + 7.94583713362114e+19*cos(theta)**11 - 3.23719290629009e+19*cos(theta)**9 + 6.77552003642113e+18*cos(theta)**7 - 6.9407766226753e+17*cos(theta)**5 + 2.96614385584414e+16*cos(theta)**3 - 343568786391214.0*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl25_m11(theta, phi):
    return 1.37921431263761e-15*(1.0 - cos(theta)**2)**5.5*(6.70302671015732e+20*cos(theta)**14 - 1.24484781760064e+21*cos(theta)**12 + 8.74042084698325e+20*cos(theta)**10 - 2.91347361566108e+20*cos(theta)**8 + 4.74286402549479e+19*cos(theta)**6 - 3.47038831133765e+18*cos(theta)**4 + 8.89843156753244e+16*cos(theta)**2 - 343568786391214.0)*cos(11*phi)

#@torch.jit.script
def Yl25_m12(theta, phi):
    return 6.05991978517773e-17*(1.0 - cos(theta)**2)**6*(9.38423739422025e+21*cos(theta)**13 - 1.49381738112077e+22*cos(theta)**11 + 8.74042084698325e+21*cos(theta)**9 - 2.33077889252887e+21*cos(theta)**7 + 2.84571841529687e+20*cos(theta)**5 - 1.38815532453506e+19*cos(theta)**3 + 1.77968631350649e+17*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl25_m13(theta, phi):
    return 2.72648680988027e-18*(1.0 - cos(theta)**2)**6.5*(1.21995086124863e+23*cos(theta)**12 - 1.64319911923285e+23*cos(theta)**10 + 7.86637876228493e+22*cos(theta)**8 - 1.63154522477021e+22*cos(theta)**6 + 1.42285920764844e+21*cos(theta)**4 - 4.16446597360518e+19*cos(theta)**2 + 1.77968631350649e+17)*cos(13*phi)

#@torch.jit.script
def Yl25_m14(theta, phi):
    return 1.26031897370507e-19*(1.0 - cos(theta)**2)**7*(1.46394103349836e+24*cos(theta)**11 - 1.64319911923285e+24*cos(theta)**9 + 6.29310300982794e+23*cos(theta)**7 - 9.78927134862124e+22*cos(theta)**5 + 5.69143683059375e+21*cos(theta)**3 - 8.32893194721036e+19*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl25_m15(theta, phi):
    return 6.00833495972093e-21*(1.0 - cos(theta)**2)**7.5*(1.61033513684819e+25*cos(theta)**10 - 1.47887920730957e+25*cos(theta)**8 + 4.40517210687956e+24*cos(theta)**6 - 4.89463567431062e+23*cos(theta)**4 + 1.70743104917812e+22*cos(theta)**2 - 8.32893194721036e+19)*cos(15*phi)

#@torch.jit.script
def Yl25_m16(theta, phi):
    return 2.96730513315039e-22*(1.0 - cos(theta)**2)**8*(1.61033513684819e+26*cos(theta)**9 - 1.18310336584765e+26*cos(theta)**7 + 2.64310326412774e+25*cos(theta)**5 - 1.95785426972425e+24*cos(theta)**3 + 3.41486209835625e+22*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl25_m17(theta, phi):
    return 1.52621707468272e-23*(1.0 - cos(theta)**2)**8.5*(1.44930162316337e+27*cos(theta)**8 - 8.28172356093357e+26*cos(theta)**6 + 1.32155163206387e+26*cos(theta)**4 - 5.87356280917274e+24*cos(theta)**2 + 3.41486209835625e+22)*cos(17*phi)

#@torch.jit.script
def Yl25_m18(theta, phi):
    return 8.22881098367386e-25*(1.0 - cos(theta)**2)**9*(1.1594412985307e+28*cos(theta)**7 - 4.96903413656014e+27*cos(theta)**5 + 5.28620652825547e+26*cos(theta)**3 - 1.17471256183455e+25*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl25_m19(theta, phi):
    return 4.68880021638437e-26*(1.0 - cos(theta)**2)**9.5*(8.1160890897149e+28*cos(theta)**6 - 2.48451706828007e+28*cos(theta)**4 + 1.58586195847664e+27*cos(theta)**2 - 1.17471256183455e+25)*cos(19*phi)

#@torch.jit.script
def Yl25_m20(theta, phi):
    return 2.85351294016536e-27*(1.0 - cos(theta)**2)**10*(4.86965345382894e+29*cos(theta)**5 - 9.93806827312028e+28*cos(theta)**3 + 3.17172391695328e+27*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl25_m21(theta, phi):
    return 1.88155071332724e-28*(1.0 - cos(theta)**2)**10.5*(2.43482672691447e+30*cos(theta)**4 - 2.98142048193609e+29*cos(theta)**2 + 3.17172391695328e+27)*cos(21*phi)

#@torch.jit.script
def Yl25_m22(theta, phi):
    return 1.37226189401167e-29*(1.0 - cos(theta)**2)**11*(9.73930690765788e+30*cos(theta)**3 - 5.96284096387217e+29*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl25_m23(theta, phi):
    return 1.14355157834306e-30*(1.0 - cos(theta)**2)**11.5*(2.92179207229736e+31*cos(theta)**2 - 5.96284096387217e+29)*cos(23*phi)

#@torch.jit.script
def Yl25_m24(theta, phi):
    return 6.75028364024702*(1.0 - cos(theta)**2)**12*cos(24*phi)*cos(theta)

#@torch.jit.script
def Yl25_m25(theta, phi):
    return 0.954634267390256*(1.0 - cos(theta)**2)**12.5*cos(25*phi)

#@torch.jit.script
def Yl26_m_minus_26(theta, phi):
    return 0.963769731686801*(1.0 - cos(theta)**2)**13*sin(26*phi)

#@torch.jit.script
def Yl26_m_minus_25(theta, phi):
    return 6.94984237067387*(1.0 - cos(theta)**2)**12.5*sin(25*phi)*cos(theta)

#@torch.jit.script
def Yl26_m_minus_24(theta, phi):
    return 2.35518790424645e-32*(1.0 - cos(theta)**2)**12*(1.49011395687166e+33*cos(theta)**2 - 2.92179207229736e+31)*sin(24*phi)

#@torch.jit.script
def Yl26_m_minus_23(theta, phi):
    return 2.88450430688934e-31*(1.0 - cos(theta)**2)**11.5*(4.96704652290552e+32*cos(theta)**3 - 2.92179207229736e+31*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl26_m_minus_22(theta, phi):
    return 4.03830602964508e-30*(1.0 - cos(theta)**2)**11*(1.24176163072638e+32*cos(theta)**4 - 1.46089603614868e+31*cos(theta)**2 + 1.49071024096804e+29)*sin(22*phi)

#@torch.jit.script
def Yl26_m_minus_21(theta, phi):
    return 6.25611679988175e-29*(1.0 - cos(theta)**2)**10.5*(2.48352326145276e+31*cos(theta)**5 - 4.86965345382894e+30*cos(theta)**3 + 1.49071024096804e+29*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl26_m_minus_20(theta, phi):
    return 1.0505806618571e-27*(1.0 - cos(theta)**2)**10*(4.1392054357546e+30*cos(theta)**6 - 1.21741336345723e+30*cos(theta)**4 + 7.45355120484021e+28*cos(theta)**2 - 5.28620652825547e+26)*sin(20*phi)

#@torch.jit.script
def Yl26_m_minus_19(theta, phi):
    return 1.88519959716718e-26*(1.0 - cos(theta)**2)**9.5*(5.91315062250657e+29*cos(theta)**7 - 2.43482672691447e+29*cos(theta)**5 + 2.48451706828007e+28*cos(theta)**3 - 5.28620652825547e+26*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl26_m_minus_18(theta, phi):
    return 3.57691474264813e-25*(1.0 - cos(theta)**2)**9*(7.39143827813321e+28*cos(theta)**8 - 4.05804454485745e+28*cos(theta)**6 + 6.21129267070018e+27*cos(theta)**4 - 2.64310326412774e+26*cos(theta)**2 + 1.46839070229319e+24)*sin(18*phi)

#@torch.jit.script
def Yl26_m_minus_17(theta, phi):
    return 7.11797046507269e-24*(1.0 - cos(theta)**2)**8.5*(8.21270919792579e+27*cos(theta)**9 - 5.7972064926535e+27*cos(theta)**7 + 1.24225853414004e+27*cos(theta)**5 - 8.81034421375912e+25*cos(theta)**3 + 1.46839070229319e+24*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl26_m_minus_16(theta, phi):
    return 1.47601377103699e-22*(1.0 - cos(theta)**2)**8*(8.21270919792579e+26*cos(theta)**10 - 7.24650811581687e+26*cos(theta)**8 + 2.07043089023339e+26*cos(theta)**6 - 2.20258605343978e+25*cos(theta)**4 + 7.34195351146593e+23*cos(theta)**2 - 3.41486209835625e+21)*sin(16*phi)

#@torch.jit.script
def Yl26_m_minus_15(theta, phi):
    return 3.17257134412823e-21*(1.0 - cos(theta)**2)**7.5*(7.46609927084163e+25*cos(theta)**11 - 8.05167568424097e+25*cos(theta)**9 + 2.95775841461913e+25*cos(theta)**7 - 4.40517210687956e+24*cos(theta)**5 + 2.44731783715531e+23*cos(theta)**3 - 3.41486209835625e+21*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl26_m_minus_14(theta, phi):
    return 7.03710366224851e-20*(1.0 - cos(theta)**2)**7*(6.22174939236802e+24*cos(theta)**12 - 8.05167568424097e+24*cos(theta)**10 + 3.69719801827392e+24*cos(theta)**8 - 7.34195351146593e+23*cos(theta)**6 + 6.11829459288828e+22*cos(theta)**4 - 1.70743104917812e+21*cos(theta)**2 + 6.9407766226753e+18)*sin(14*phi)

#@torch.jit.script
def Yl26_m_minus_13(theta, phi):
    return 1.60470653191418e-18*(1.0 - cos(theta)**2)**6.5*(4.78596107105233e+23*cos(theta)**13 - 7.31970516749179e+23*cos(theta)**11 + 4.10799779808213e+23*cos(theta)**9 - 1.04885050163799e+23*cos(theta)**7 + 1.22365891857766e+22*cos(theta)**5 - 5.69143683059374e+20*cos(theta)**3 + 6.9407766226753e+18*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl26_m_minus_12(theta, phi):
    return 3.74966044762475e-17*(1.0 - cos(theta)**2)**6*(3.41854362218023e+22*cos(theta)**14 - 6.09975430624316e+22*cos(theta)**12 + 4.10799779808213e+22*cos(theta)**10 - 1.31106312704749e+22*cos(theta)**8 + 2.03943153096276e+21*cos(theta)**6 - 1.42285920764844e+20*cos(theta)**4 + 3.47038831133765e+18*cos(theta)**2 - 1.27120450964749e+16)*sin(12*phi)

#@torch.jit.script
def Yl26_m_minus_11(theta, phi):
    return 8.95219161955017e-16*(1.0 - cos(theta)**2)**5.5*(2.27902908145349e+21*cos(theta)**15 - 4.69211869711012e+21*cos(theta)**13 + 3.73454345280193e+21*cos(theta)**11 - 1.45673680783054e+21*cos(theta)**9 + 2.91347361566108e+20*cos(theta)**7 - 2.84571841529687e+19*cos(theta)**5 + 1.15679610377922e+18*cos(theta)**3 - 1.27120450964749e+16*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl26_m_minus_10(theta, phi):
    return 2.17816222989798e-14*(1.0 - cos(theta)**2)**5*(1.42439317590843e+20*cos(theta)**16 - 3.35151335507866e+20*cos(theta)**14 + 3.11211954400161e+20*cos(theta)**12 - 1.45673680783054e+20*cos(theta)**10 + 3.64184201957635e+19*cos(theta)**8 - 4.74286402549479e+18*cos(theta)**6 + 2.89199025944804e+17*cos(theta)**4 - 6.35602254823745e+15*cos(theta)**2 + 21473049149450.9)*sin(10*phi)

#@torch.jit.script
def Yl26_m_minus_9(theta, phi):
    return 5.38847576616016e-13*(1.0 - cos(theta)**2)**4.5*(8.37878338769665e+18*cos(theta)**17 - 2.23434223671911e+19*cos(theta)**15 + 2.39393811077047e+19*cos(theta)**13 - 1.32430618893686e+19*cos(theta)**11 + 4.04649113286262e+18*cos(theta)**9 - 6.77552003642113e+17*cos(theta)**7 + 5.78398051889608e+16*cos(theta)**5 - 2.11867418274582e+15*cos(theta)**3 + 21473049149450.9*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl26_m_minus_8(theta, phi):
    return 1.35249668324814e-11*(1.0 - cos(theta)**2)**4*(4.65487965983147e+17*cos(theta)**18 - 1.39646389794944e+18*cos(theta)**16 + 1.70995579340748e+18*cos(theta)**14 - 1.10358849078071e+18*cos(theta)**12 + 4.04649113286262e+17*cos(theta)**10 - 8.46940004552641e+16*cos(theta)**8 + 9.63996753149347e+15*cos(theta)**6 - 529668545686454.0*cos(theta)**4 + 10736524574725.4*cos(theta)**2 - 34084204999.1283)*sin(8*phi)

#@torch.jit.script
def Yl26_m_minus_7(theta, phi):
    return 3.43757725980871e-10*(1.0 - cos(theta)**2)**3.5*(2.4499366630692e+16*cos(theta)**19 - 8.21449351734965e+16*cos(theta)**17 + 1.13997052893832e+17*cos(theta)**15 - 8.48914223677472e+16*cos(theta)**13 + 3.67862830260238e+16*cos(theta)**11 - 9.41044449502934e+15*cos(theta)**9 + 1.37713821878478e+15*cos(theta)**7 - 105933709137291.0*cos(theta)**5 + 3578841524908.48*cos(theta)**3 - 34084204999.1283*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl26_m_minus_6(theta, phi):
    return 8.83129588187465e-9*(1.0 - cos(theta)**2)**3*(1.2249683315346e+15*cos(theta)**20 - 4.5636075096387e+15*cos(theta)**18 + 7.1248158058645e+15*cos(theta)**16 - 6.06367302626766e+15*cos(theta)**14 + 3.06552358550198e+15*cos(theta)**12 - 941044449502934.0*cos(theta)**10 + 172142277348098.0*cos(theta)**8 - 17655618189548.5*cos(theta)**6 + 894710381227.119*cos(theta)**4 - 17042102499.5642*cos(theta)**2 + 51642734.8471642)*sin(6*phi)

#@torch.jit.script
def Yl26_m_minus_5(theta, phi):
    return 2.28933354565387e-7*(1.0 - cos(theta)**2)**2.5*(58331825311171.3*cos(theta)**21 - 240189868928353.0*cos(theta)**19 + 419106812109676.0*cos(theta)**17 - 404244868417844.0*cos(theta)**15 + 235809506577076.0*cos(theta)**13 - 85549495409357.6*cos(theta)**11 + 19126919705344.2*cos(theta)**9 - 2522231169935.5*cos(theta)**7 + 178942076245.424*cos(theta)**5 - 5680700833.18806*cos(theta)**3 + 51642734.8471642*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl26_m_minus_4(theta, phi):
    return 5.97862425042808e-6*(1.0 - cos(theta)**2)**2*(2651446605053.24*cos(theta)**22 - 12009493446417.6*cos(theta)**20 + 23283711783870.9*cos(theta)**18 - 25265304276115.2*cos(theta)**16 + 16843536184076.8*cos(theta)**14 - 7129124617446.47*cos(theta)**12 + 1912691970534.42*cos(theta)**10 - 315278896241.937*cos(theta)**8 + 29823679374.2373*cos(theta)**6 - 1420175208.29701*cos(theta)**4 + 25821367.4235821*cos(theta)**2 - 75722.4851131439)*sin(4*phi)

#@torch.jit.script
def Yl26_m_minus_3(theta, phi):
    return 0.000157045611432433*(1.0 - cos(theta)**2)**1.5*(115280287176.228*cos(theta)**23 - 571880640305.601*cos(theta)**21 + 1225458514940.57*cos(theta)**19 - 1486194369183.25*cos(theta)**17 + 1122902412271.79*cos(theta)**15 - 548394201342.036*cos(theta)**13 + 173881088230.402*cos(theta)**11 - 35030988471.3264*cos(theta)**9 + 4260525624.89104*cos(theta)**7 - 284035041.659403*cos(theta)**5 + 8607122.47452736*cos(theta)**3 - 75722.4851131439*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl26_m_minus_2(theta, phi):
    return 0.00414314778312938*(1.0 - cos(theta)**2)*(4803345299.0095*cos(theta)**24 - 25994574559.3455*cos(theta)**22 + 61272925747.0287*cos(theta)**20 - 82566353843.5138*cos(theta)**18 + 70181400766.9868*cos(theta)**16 - 39171014381.574*cos(theta)**14 + 14490090685.8668*cos(theta)**12 - 3503098847.13264*cos(theta)**10 + 532565703.11138*cos(theta)**8 - 47339173.6099005*cos(theta)**6 + 2151780.61863184*cos(theta)**4 - 37861.242556572*cos(theta)**2 + 108.796674013138)*sin(2*phi)

#@torch.jit.script
def Yl26_m_minus_1(theta, phi):
    return 0.109617386791489*(1.0 - cos(theta)**2)**0.5*(192133811.96038*cos(theta)**25 - 1130198893.88459*cos(theta)**23 + 2917758368.90613*cos(theta)**21 - 4345597570.71126*cos(theta)**19 + 4128317692.17569*cos(theta)**17 - 2611400958.7716*cos(theta)**15 + 1114622360.45129*cos(theta)**13 - 318463531.557512*cos(theta)**11 + 59173967.0123756*cos(theta)**9 - 6762739.08712864*cos(theta)**7 + 430356.123726368*cos(theta)**5 - 12620.414185524*cos(theta)**3 + 108.796674013138*cos(theta))*sin(phi)

#@torch.jit.script
def Yl26_m0(theta, phi):
    return 47677483.75133*cos(theta)**26 - 303827102.336907*cos(theta)**24 + 855676329.030472*cos(theta)**22 - 1401852709.26269*cos(theta)**20 + 1479733415.33284*cos(theta)**18 - 1053019593.23686*cos(theta)**16 + 513668094.261881*cos(theta)**14 - 171222698.087294*cos(theta)**12 + 38178034.0329777*cos(theta)**10 - 5454004.86185395*cos(theta)**8 + 462764.048884578*cos(theta)**6 - 20356.1898336325*cos(theta)**4 + 350.968790235042*cos(theta)**2 - 0.999911083290719

#@torch.jit.script
def Yl26_m1(theta, phi):
    return 0.109617386791489*(1.0 - cos(theta)**2)**0.5*(192133811.96038*cos(theta)**25 - 1130198893.88459*cos(theta)**23 + 2917758368.90613*cos(theta)**21 - 4345597570.71126*cos(theta)**19 + 4128317692.17569*cos(theta)**17 - 2611400958.7716*cos(theta)**15 + 1114622360.45129*cos(theta)**13 - 318463531.557512*cos(theta)**11 + 59173967.0123756*cos(theta)**9 - 6762739.08712864*cos(theta)**7 + 430356.123726368*cos(theta)**5 - 12620.414185524*cos(theta)**3 + 108.796674013138*cos(theta))*cos(phi)

#@torch.jit.script
def Yl26_m2(theta, phi):
    return 0.00414314778312938*(1.0 - cos(theta)**2)*(4803345299.0095*cos(theta)**24 - 25994574559.3455*cos(theta)**22 + 61272925747.0287*cos(theta)**20 - 82566353843.5138*cos(theta)**18 + 70181400766.9868*cos(theta)**16 - 39171014381.574*cos(theta)**14 + 14490090685.8668*cos(theta)**12 - 3503098847.13264*cos(theta)**10 + 532565703.11138*cos(theta)**8 - 47339173.6099005*cos(theta)**6 + 2151780.61863184*cos(theta)**4 - 37861.242556572*cos(theta)**2 + 108.796674013138)*cos(2*phi)

#@torch.jit.script
def Yl26_m3(theta, phi):
    return 0.000157045611432433*(1.0 - cos(theta)**2)**1.5*(115280287176.228*cos(theta)**23 - 571880640305.601*cos(theta)**21 + 1225458514940.57*cos(theta)**19 - 1486194369183.25*cos(theta)**17 + 1122902412271.79*cos(theta)**15 - 548394201342.036*cos(theta)**13 + 173881088230.402*cos(theta)**11 - 35030988471.3264*cos(theta)**9 + 4260525624.89104*cos(theta)**7 - 284035041.659403*cos(theta)**5 + 8607122.47452736*cos(theta)**3 - 75722.4851131439*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl26_m4(theta, phi):
    return 5.97862425042808e-6*(1.0 - cos(theta)**2)**2*(2651446605053.24*cos(theta)**22 - 12009493446417.6*cos(theta)**20 + 23283711783870.9*cos(theta)**18 - 25265304276115.2*cos(theta)**16 + 16843536184076.8*cos(theta)**14 - 7129124617446.47*cos(theta)**12 + 1912691970534.42*cos(theta)**10 - 315278896241.937*cos(theta)**8 + 29823679374.2373*cos(theta)**6 - 1420175208.29701*cos(theta)**4 + 25821367.4235821*cos(theta)**2 - 75722.4851131439)*cos(4*phi)

#@torch.jit.script
def Yl26_m5(theta, phi):
    return 2.28933354565387e-7*(1.0 - cos(theta)**2)**2.5*(58331825311171.3*cos(theta)**21 - 240189868928353.0*cos(theta)**19 + 419106812109676.0*cos(theta)**17 - 404244868417844.0*cos(theta)**15 + 235809506577076.0*cos(theta)**13 - 85549495409357.6*cos(theta)**11 + 19126919705344.2*cos(theta)**9 - 2522231169935.5*cos(theta)**7 + 178942076245.424*cos(theta)**5 - 5680700833.18806*cos(theta)**3 + 51642734.8471642*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl26_m6(theta, phi):
    return 8.83129588187465e-9*(1.0 - cos(theta)**2)**3*(1.2249683315346e+15*cos(theta)**20 - 4.5636075096387e+15*cos(theta)**18 + 7.1248158058645e+15*cos(theta)**16 - 6.06367302626766e+15*cos(theta)**14 + 3.06552358550198e+15*cos(theta)**12 - 941044449502934.0*cos(theta)**10 + 172142277348098.0*cos(theta)**8 - 17655618189548.5*cos(theta)**6 + 894710381227.119*cos(theta)**4 - 17042102499.5642*cos(theta)**2 + 51642734.8471642)*cos(6*phi)

#@torch.jit.script
def Yl26_m7(theta, phi):
    return 3.43757725980871e-10*(1.0 - cos(theta)**2)**3.5*(2.4499366630692e+16*cos(theta)**19 - 8.21449351734965e+16*cos(theta)**17 + 1.13997052893832e+17*cos(theta)**15 - 8.48914223677472e+16*cos(theta)**13 + 3.67862830260238e+16*cos(theta)**11 - 9.41044449502934e+15*cos(theta)**9 + 1.37713821878478e+15*cos(theta)**7 - 105933709137291.0*cos(theta)**5 + 3578841524908.48*cos(theta)**3 - 34084204999.1283*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl26_m8(theta, phi):
    return 1.35249668324814e-11*(1.0 - cos(theta)**2)**4*(4.65487965983147e+17*cos(theta)**18 - 1.39646389794944e+18*cos(theta)**16 + 1.70995579340748e+18*cos(theta)**14 - 1.10358849078071e+18*cos(theta)**12 + 4.04649113286262e+17*cos(theta)**10 - 8.46940004552641e+16*cos(theta)**8 + 9.63996753149347e+15*cos(theta)**6 - 529668545686454.0*cos(theta)**4 + 10736524574725.4*cos(theta)**2 - 34084204999.1283)*cos(8*phi)

#@torch.jit.script
def Yl26_m9(theta, phi):
    return 5.38847576616016e-13*(1.0 - cos(theta)**2)**4.5*(8.37878338769665e+18*cos(theta)**17 - 2.23434223671911e+19*cos(theta)**15 + 2.39393811077047e+19*cos(theta)**13 - 1.32430618893686e+19*cos(theta)**11 + 4.04649113286262e+18*cos(theta)**9 - 6.77552003642113e+17*cos(theta)**7 + 5.78398051889608e+16*cos(theta)**5 - 2.11867418274582e+15*cos(theta)**3 + 21473049149450.9*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl26_m10(theta, phi):
    return 2.17816222989798e-14*(1.0 - cos(theta)**2)**5*(1.42439317590843e+20*cos(theta)**16 - 3.35151335507866e+20*cos(theta)**14 + 3.11211954400161e+20*cos(theta)**12 - 1.45673680783054e+20*cos(theta)**10 + 3.64184201957635e+19*cos(theta)**8 - 4.74286402549479e+18*cos(theta)**6 + 2.89199025944804e+17*cos(theta)**4 - 6.35602254823745e+15*cos(theta)**2 + 21473049149450.9)*cos(10*phi)

#@torch.jit.script
def Yl26_m11(theta, phi):
    return 8.95219161955017e-16*(1.0 - cos(theta)**2)**5.5*(2.27902908145349e+21*cos(theta)**15 - 4.69211869711012e+21*cos(theta)**13 + 3.73454345280193e+21*cos(theta)**11 - 1.45673680783054e+21*cos(theta)**9 + 2.91347361566108e+20*cos(theta)**7 - 2.84571841529687e+19*cos(theta)**5 + 1.15679610377922e+18*cos(theta)**3 - 1.27120450964749e+16*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl26_m12(theta, phi):
    return 3.74966044762475e-17*(1.0 - cos(theta)**2)**6*(3.41854362218023e+22*cos(theta)**14 - 6.09975430624316e+22*cos(theta)**12 + 4.10799779808213e+22*cos(theta)**10 - 1.31106312704749e+22*cos(theta)**8 + 2.03943153096276e+21*cos(theta)**6 - 1.42285920764844e+20*cos(theta)**4 + 3.47038831133765e+18*cos(theta)**2 - 1.27120450964749e+16)*cos(12*phi)

#@torch.jit.script
def Yl26_m13(theta, phi):
    return 1.60470653191418e-18*(1.0 - cos(theta)**2)**6.5*(4.78596107105233e+23*cos(theta)**13 - 7.31970516749179e+23*cos(theta)**11 + 4.10799779808213e+23*cos(theta)**9 - 1.04885050163799e+23*cos(theta)**7 + 1.22365891857766e+22*cos(theta)**5 - 5.69143683059374e+20*cos(theta)**3 + 6.9407766226753e+18*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl26_m14(theta, phi):
    return 7.03710366224851e-20*(1.0 - cos(theta)**2)**7*(6.22174939236802e+24*cos(theta)**12 - 8.05167568424097e+24*cos(theta)**10 + 3.69719801827392e+24*cos(theta)**8 - 7.34195351146593e+23*cos(theta)**6 + 6.11829459288828e+22*cos(theta)**4 - 1.70743104917812e+21*cos(theta)**2 + 6.9407766226753e+18)*cos(14*phi)

#@torch.jit.script
def Yl26_m15(theta, phi):
    return 3.17257134412823e-21*(1.0 - cos(theta)**2)**7.5*(7.46609927084163e+25*cos(theta)**11 - 8.05167568424097e+25*cos(theta)**9 + 2.95775841461913e+25*cos(theta)**7 - 4.40517210687956e+24*cos(theta)**5 + 2.44731783715531e+23*cos(theta)**3 - 3.41486209835625e+21*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl26_m16(theta, phi):
    return 1.47601377103699e-22*(1.0 - cos(theta)**2)**8*(8.21270919792579e+26*cos(theta)**10 - 7.24650811581687e+26*cos(theta)**8 + 2.07043089023339e+26*cos(theta)**6 - 2.20258605343978e+25*cos(theta)**4 + 7.34195351146593e+23*cos(theta)**2 - 3.41486209835625e+21)*cos(16*phi)

#@torch.jit.script
def Yl26_m17(theta, phi):
    return 7.11797046507269e-24*(1.0 - cos(theta)**2)**8.5*(8.21270919792579e+27*cos(theta)**9 - 5.7972064926535e+27*cos(theta)**7 + 1.24225853414004e+27*cos(theta)**5 - 8.81034421375912e+25*cos(theta)**3 + 1.46839070229319e+24*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl26_m18(theta, phi):
    return 3.57691474264813e-25*(1.0 - cos(theta)**2)**9*(7.39143827813321e+28*cos(theta)**8 - 4.05804454485745e+28*cos(theta)**6 + 6.21129267070018e+27*cos(theta)**4 - 2.64310326412774e+26*cos(theta)**2 + 1.46839070229319e+24)*cos(18*phi)

#@torch.jit.script
def Yl26_m19(theta, phi):
    return 1.88519959716718e-26*(1.0 - cos(theta)**2)**9.5*(5.91315062250657e+29*cos(theta)**7 - 2.43482672691447e+29*cos(theta)**5 + 2.48451706828007e+28*cos(theta)**3 - 5.28620652825547e+26*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl26_m20(theta, phi):
    return 1.0505806618571e-27*(1.0 - cos(theta)**2)**10*(4.1392054357546e+30*cos(theta)**6 - 1.21741336345723e+30*cos(theta)**4 + 7.45355120484021e+28*cos(theta)**2 - 5.28620652825547e+26)*cos(20*phi)

#@torch.jit.script
def Yl26_m21(theta, phi):
    return 6.25611679988175e-29*(1.0 - cos(theta)**2)**10.5*(2.48352326145276e+31*cos(theta)**5 - 4.86965345382894e+30*cos(theta)**3 + 1.49071024096804e+29*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl26_m22(theta, phi):
    return 4.03830602964508e-30*(1.0 - cos(theta)**2)**11*(1.24176163072638e+32*cos(theta)**4 - 1.46089603614868e+31*cos(theta)**2 + 1.49071024096804e+29)*cos(22*phi)

#@torch.jit.script
def Yl26_m23(theta, phi):
    return 2.88450430688934e-31*(1.0 - cos(theta)**2)**11.5*(4.96704652290552e+32*cos(theta)**3 - 2.92179207229736e+31*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl26_m24(theta, phi):
    return 2.35518790424645e-32*(1.0 - cos(theta)**2)**12*(1.49011395687166e+33*cos(theta)**2 - 2.92179207229736e+31)*cos(24*phi)

#@torch.jit.script
def Yl26_m25(theta, phi):
    return 6.94984237067387*(1.0 - cos(theta)**2)**12.5*cos(25*phi)*cos(theta)

#@torch.jit.script
def Yl26_m26(theta, phi):
    return 0.963769731686801*(1.0 - cos(theta)**2)**13*cos(26*phi)

#@torch.jit.script
def Yl27_m_minus_27(theta, phi):
    return 0.97265258980333*(1.0 - cos(theta)**2)**13.5*sin(27*phi)

#@torch.jit.script
def Yl27_m_minus_26(theta, phi):
    return 7.14750762604425*(1.0 - cos(theta)**2)**13*sin(26*phi)*cos(theta)

#@torch.jit.script
def Yl27_m_minus_25(theta, phi):
    return 4.65888737989014e-34*(1.0 - cos(theta)**2)**12.5*(7.89760397141977e+34*cos(theta)**2 - 1.49011395687166e+33)*sin(25*phi)

#@torch.jit.script
def Yl27_m_minus_24(theta, phi):
    return 5.81894847243549e-33*(1.0 - cos(theta)**2)**12*(2.63253465713992e+34*cos(theta)**3 - 1.49011395687166e+33*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl27_m_minus_23(theta, phi):
    return 8.31112080905536e-32*(1.0 - cos(theta)**2)**11.5*(6.58133664284981e+33*cos(theta)**4 - 7.45056978435828e+32*cos(theta)**2 + 7.30448018074341e+30)*sin(23*phi)

#@torch.jit.script
def Yl27_m_minus_22(theta, phi):
    return 1.31410358327182e-30*(1.0 - cos(theta)**2)**11*(1.31626732856996e+33*cos(theta)**5 - 2.48352326145276e+32*cos(theta)**3 + 7.30448018074341e+30*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl27_m_minus_21(theta, phi):
    return 2.25321827372525e-29*(1.0 - cos(theta)**2)**10.5*(2.19377888094994e+32*cos(theta)**6 - 6.2088081536319e+31*cos(theta)**4 + 3.6522400903717e+30*cos(theta)**2 - 2.48451706828007e+28)*sin(21*phi)

#@torch.jit.script
def Yl27_m_minus_20(theta, phi):
    return 4.13021731864148e-28*(1.0 - cos(theta)**2)**10*(3.13396982992848e+31*cos(theta)**7 - 1.24176163072638e+31*cos(theta)**5 + 1.21741336345723e+30*cos(theta)**3 - 2.48451706828007e+28*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl27_m_minus_19(theta, phi):
    return 8.00878852093215e-27*(1.0 - cos(theta)**2)**9.5*(3.9174622874106e+30*cos(theta)**8 - 2.0696027178773e+30*cos(theta)**6 + 3.04353340864309e+29*cos(theta)**4 - 1.24225853414004e+28*cos(theta)**2 + 6.60775816031934e+25)*sin(19*phi)

#@torch.jit.script
def Yl27_m_minus_18(theta, phi):
    return 1.62954739542083e-25*(1.0 - cos(theta)**2)**9*(4.35273587490067e+29*cos(theta)**9 - 2.95657531125328e+29*cos(theta)**7 + 6.08706681728617e+28*cos(theta)**5 - 4.14086178046679e+27*cos(theta)**3 + 6.60775816031934e+25*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl27_m_minus_17(theta, phi):
    return 3.45679204070083e-24*(1.0 - cos(theta)**2)**8.5*(4.35273587490067e+28*cos(theta)**10 - 3.69571913906661e+28*cos(theta)**8 + 1.01451113621436e+28*cos(theta)**6 - 1.0352154451167e+27*cos(theta)**4 + 3.30387908015967e+25*cos(theta)**2 - 1.46839070229319e+23)*sin(17*phi)

#@torch.jit.script
def Yl27_m_minus_16(theta, phi):
    return 7.60494248954183e-23*(1.0 - cos(theta)**2)**8*(3.95703261354606e+27*cos(theta)**11 - 4.1063545989629e+27*cos(theta)**9 + 1.44930162316337e+27*cos(theta)**7 - 2.07043089023339e+26*cos(theta)**5 + 1.10129302671989e+25*cos(theta)**3 - 1.46839070229319e+23*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl27_m_minus_15(theta, phi):
    return 1.72751085492761e-21*(1.0 - cos(theta)**2)**7.5*(3.29752717795505e+26*cos(theta)**12 - 4.1063545989629e+26*cos(theta)**10 + 1.81162702895422e+26*cos(theta)**8 - 3.45071815038899e+25*cos(theta)**6 + 2.75323256679972e+24*cos(theta)**4 - 7.34195351146593e+22*cos(theta)**2 + 2.84571841529687e+20)*sin(15*phi)

#@torch.jit.script
def Yl27_m_minus_14(theta, phi):
    return 4.03661292375851e-20*(1.0 - cos(theta)**2)**7*(2.53655936765773e+25*cos(theta)**13 - 3.73304963542081e+25*cos(theta)**11 + 2.01291892106024e+25*cos(theta)**9 - 4.92959735769855e+24*cos(theta)**7 + 5.50646513359945e+23*cos(theta)**5 - 2.44731783715531e+22*cos(theta)**3 + 2.84571841529687e+20*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl27_m_minus_13(theta, phi):
    return 9.67103717108456e-19*(1.0 - cos(theta)**2)**6.5*(1.81182811975552e+24*cos(theta)**14 - 3.11087469618401e+24*cos(theta)**12 + 2.01291892106024e+24*cos(theta)**10 - 6.16199669712319e+23*cos(theta)**8 + 9.17744188933241e+22*cos(theta)**6 - 6.11829459288828e+21*cos(theta)**4 + 1.42285920764844e+20*cos(theta)**2 - 4.95769758762521e+17)*sin(13*phi)

#@torch.jit.script
def Yl27_m_minus_12(theta, phi):
    return 2.36891063526465e-17*(1.0 - cos(theta)**2)**6*(1.20788541317035e+23*cos(theta)**15 - 2.39298053552616e+23*cos(theta)**13 + 1.82992629187295e+23*cos(theta)**11 - 6.84666299680355e+22*cos(theta)**9 + 1.31106312704749e+22*cos(theta)**7 - 1.22365891857766e+21*cos(theta)**5 + 4.74286402549479e+19*cos(theta)**3 - 4.95769758762521e+17*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl27_m_minus_11(theta, phi):
    return 5.91753687024496e-16*(1.0 - cos(theta)**2)**5.5*(7.54928383231468e+21*cos(theta)**16 - 1.70927181109012e+22*cos(theta)**14 + 1.52493857656079e+22*cos(theta)**12 - 6.84666299680355e+21*cos(theta)**10 + 1.63882890880936e+21*cos(theta)**8 - 2.03943153096276e+20*cos(theta)**6 + 1.1857160063737e+19*cos(theta)**4 - 2.47884879381261e+17*cos(theta)**2 + 794502818529682.0)*sin(11*phi)

#@torch.jit.script
def Yl27_m_minus_10(theta, phi):
    return 1.50403253709877e-14*(1.0 - cos(theta)**2)**5*(4.44075519547922e+20*cos(theta)**17 - 1.13951454072674e+21*cos(theta)**15 + 1.17302967427753e+21*cos(theta)**13 - 6.22423908800322e+20*cos(theta)**11 + 1.82092100978818e+20*cos(theta)**9 - 2.91347361566108e+19*cos(theta)**7 + 2.37143201274739e+18*cos(theta)**5 - 8.26282931270869e+16*cos(theta)**3 + 794502818529682.0*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl27_m_minus_9(theta, phi):
    return 3.8814531289017e-13*(1.0 - cos(theta)**2)**4.5*(2.46708621971068e+19*cos(theta)**18 - 7.12196587954215e+19*cos(theta)**16 + 8.37878338769665e+19*cos(theta)**14 - 5.18686590666935e+19*cos(theta)**12 + 1.82092100978818e+19*cos(theta)**10 - 3.64184201957635e+18*cos(theta)**8 + 3.95238668791232e+17*cos(theta)**6 - 2.06570732817717e+16*cos(theta)**4 + 397251409264841.0*cos(theta)**2 - 1192947174969.49)*sin(9*phi)

#@torch.jit.script
def Yl27_m_minus_8(theta, phi):
    return 1.01513171657834e-11*(1.0 - cos(theta)**2)**4*(1.29846643142667e+18*cos(theta)**19 - 4.18939169384832e+18*cos(theta)**17 + 5.58585559179777e+18*cos(theta)**15 - 3.98989685128412e+18*cos(theta)**13 + 1.65538273617107e+18*cos(theta)**11 - 4.04649113286262e+17*cos(theta)**9 + 5.6462666970176e+16*cos(theta)**7 - 4.13141465635434e+15*cos(theta)**5 + 132417136421614.0*cos(theta)**3 - 1192947174969.49*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl27_m_minus_7(theta, phi):
    return 2.68578607004038e-10*(1.0 - cos(theta)**2)**3.5*(6.49233215713337e+16*cos(theta)**20 - 2.32743982991574e+17*cos(theta)**18 + 3.4911597448736e+17*cos(theta)**16 - 2.8499263223458e+17*cos(theta)**14 + 1.37948561347589e+17*cos(theta)**12 - 4.04649113286262e+16*cos(theta)**10 + 7.05783337127201e+15*cos(theta)**8 - 688569109392391.0*cos(theta)**6 + 33104284105403.4*cos(theta)**4 - 596473587484.746*cos(theta)**2 + 1704210249.95642)*sin(7*phi)

#@torch.jit.script
def Yl27_m_minus_6(theta, phi):
    return 7.17662944926961e-9*(1.0 - cos(theta)**2)**3*(3.09158674149208e+15*cos(theta)**21 - 1.2249683315346e+16*cos(theta)**19 + 2.05362337933741e+16*cos(theta)**17 - 1.89995088156387e+16*cos(theta)**15 + 1.06114277959684e+16*cos(theta)**13 - 3.67862830260238e+15*cos(theta)**11 + 784203707919112.0*cos(theta)**9 - 98367015627484.4*cos(theta)**7 + 6620856821080.68*cos(theta)**5 - 198824529161.582*cos(theta)**3 + 1704210249.95642*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl27_m_minus_5(theta, phi):
    return 1.93369882461158e-7*(1.0 - cos(theta)**2)**2.5*(140526670067822.0*cos(theta)**22 - 612484165767299.0*cos(theta)**20 + 1.14090187740967e+15*cos(theta)**18 - 1.18746930097742e+15*cos(theta)**16 + 757959128283457.0*cos(theta)**14 - 306552358550198.0*cos(theta)**12 + 78420370791911.2*cos(theta)**10 - 12295876953435.5*cos(theta)**8 + 1103476136846.78*cos(theta)**6 - 49706132290.3955*cos(theta)**4 + 852105124.978209*cos(theta)**2 - 2347397.03850746)*sin(5*phi)

#@torch.jit.script
def Yl27_m_minus_4(theta, phi):
    return 5.24599340659887e-6*(1.0 - cos(theta)**2)**2*(6109855220340.08*cos(theta)**23 - 29165912655585.7*cos(theta)**21 + 60047467232088.1*cos(theta)**19 - 69851135351612.7*cos(theta)**17 + 50530608552230.5*cos(theta)**15 - 23580950657707.6*cos(theta)**13 + 7129124617446.47*cos(theta)**11 - 1366208550381.73*cos(theta)**9 + 157639448120.969*cos(theta)**7 - 9941226458.0791*cos(theta)**5 + 284035041.659403*cos(theta)**3 - 2347397.03850746*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl27_m_minus_3(theta, phi):
    return 0.00014309162252077*(1.0 - cos(theta)**2)**1.5*(254577300847.503*cos(theta)**24 - 1325723302526.62*cos(theta)**22 + 3002373361604.41*cos(theta)**20 - 3880618630645.15*cos(theta)**18 + 3158163034514.4*cos(theta)**16 - 1684353618407.68*cos(theta)**14 + 594093718120.539*cos(theta)**12 - 136620855038.173*cos(theta)**10 + 19704931015.1211*cos(theta)**8 - 1656871076.34652*cos(theta)**6 + 71008760.4148507*cos(theta)**4 - 1173698.51925373*cos(theta)**2 + 3155.103546381)*sin(3*phi)

#@torch.jit.script
def Yl27_m_minus_2(theta, phi):
    return 0.00391872547223201*(1.0 - cos(theta)**2)*(10183092033.9001*cos(theta)**25 - 57640143588.114*cos(theta)**23 + 142970160076.4*cos(theta)**21 - 204243085823.429*cos(theta)**19 + 185774296147.906*cos(theta)**17 - 112290241227.179*cos(theta)**15 + 45699516778.503*cos(theta)**13 - 12420077730.743*cos(theta)**11 + 2189436779.4579*cos(theta)**9 - 236695868.049502*cos(theta)**7 + 14201752.0829701*cos(theta)**5 - 391232.839751244*cos(theta)**3 + 3155.103546381*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl27_m_minus_1(theta, phi):
    return 0.107604519572121*(1.0 - cos(theta)**2)**0.5*(391657385.919236*cos(theta)**26 - 2401672649.50475*cos(theta)**24 + 6498643639.83638*cos(theta)**22 - 10212154291.1714*cos(theta)**20 + 10320794230.4392*cos(theta)**18 - 7018140076.69868*cos(theta)**16 + 3264251198.4645*cos(theta)**14 - 1035006477.56191*cos(theta)**12 + 218943677.94579*cos(theta)**10 - 29586983.5061878*cos(theta)**8 + 2366958.68049502*cos(theta)**6 - 97808.2099378109*cos(theta)**4 + 1577.5517731905*cos(theta)**2 - 4.18448746204376)*sin(phi)

#@torch.jit.script
def Yl27_m0(theta, phi):
    return 95338615.7975749*cos(theta)**27 - 631393474.432996*cos(theta)**25 + 1857039630.68528*cos(theta)**23 - 3196129432.40392*cos(theta)**21 + 3570144578.74906*cos(theta)**19 - 2713309879.84929*cos(theta)**17 + 1430271874.64924*cos(theta)**15 - 523270198.042403*cos(theta)**13 + 130817549.510601*cos(theta)**11 - 21606502.1714206*cos(theta)**9 + 2222383.08048897*cos(theta)**7 - 128567.616226635*cos(theta)**5 + 3456.11871576975*cos(theta)**3 - 27.5022709477699*cos(theta)

#@torch.jit.script
def Yl27_m1(theta, phi):
    return 0.107604519572121*(1.0 - cos(theta)**2)**0.5*(391657385.919236*cos(theta)**26 - 2401672649.50475*cos(theta)**24 + 6498643639.83638*cos(theta)**22 - 10212154291.1714*cos(theta)**20 + 10320794230.4392*cos(theta)**18 - 7018140076.69868*cos(theta)**16 + 3264251198.4645*cos(theta)**14 - 1035006477.56191*cos(theta)**12 + 218943677.94579*cos(theta)**10 - 29586983.5061878*cos(theta)**8 + 2366958.68049502*cos(theta)**6 - 97808.2099378109*cos(theta)**4 + 1577.5517731905*cos(theta)**2 - 4.18448746204376)*cos(phi)

#@torch.jit.script
def Yl27_m2(theta, phi):
    return 0.00391872547223201*(1.0 - cos(theta)**2)*(10183092033.9001*cos(theta)**25 - 57640143588.114*cos(theta)**23 + 142970160076.4*cos(theta)**21 - 204243085823.429*cos(theta)**19 + 185774296147.906*cos(theta)**17 - 112290241227.179*cos(theta)**15 + 45699516778.503*cos(theta)**13 - 12420077730.743*cos(theta)**11 + 2189436779.4579*cos(theta)**9 - 236695868.049502*cos(theta)**7 + 14201752.0829701*cos(theta)**5 - 391232.839751244*cos(theta)**3 + 3155.103546381*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl27_m3(theta, phi):
    return 0.00014309162252077*(1.0 - cos(theta)**2)**1.5*(254577300847.503*cos(theta)**24 - 1325723302526.62*cos(theta)**22 + 3002373361604.41*cos(theta)**20 - 3880618630645.15*cos(theta)**18 + 3158163034514.4*cos(theta)**16 - 1684353618407.68*cos(theta)**14 + 594093718120.539*cos(theta)**12 - 136620855038.173*cos(theta)**10 + 19704931015.1211*cos(theta)**8 - 1656871076.34652*cos(theta)**6 + 71008760.4148507*cos(theta)**4 - 1173698.51925373*cos(theta)**2 + 3155.103546381)*cos(3*phi)

#@torch.jit.script
def Yl27_m4(theta, phi):
    return 5.24599340659887e-6*(1.0 - cos(theta)**2)**2*(6109855220340.08*cos(theta)**23 - 29165912655585.7*cos(theta)**21 + 60047467232088.1*cos(theta)**19 - 69851135351612.7*cos(theta)**17 + 50530608552230.5*cos(theta)**15 - 23580950657707.6*cos(theta)**13 + 7129124617446.47*cos(theta)**11 - 1366208550381.73*cos(theta)**9 + 157639448120.969*cos(theta)**7 - 9941226458.0791*cos(theta)**5 + 284035041.659403*cos(theta)**3 - 2347397.03850746*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl27_m5(theta, phi):
    return 1.93369882461158e-7*(1.0 - cos(theta)**2)**2.5*(140526670067822.0*cos(theta)**22 - 612484165767299.0*cos(theta)**20 + 1.14090187740967e+15*cos(theta)**18 - 1.18746930097742e+15*cos(theta)**16 + 757959128283457.0*cos(theta)**14 - 306552358550198.0*cos(theta)**12 + 78420370791911.2*cos(theta)**10 - 12295876953435.5*cos(theta)**8 + 1103476136846.78*cos(theta)**6 - 49706132290.3955*cos(theta)**4 + 852105124.978209*cos(theta)**2 - 2347397.03850746)*cos(5*phi)

#@torch.jit.script
def Yl27_m6(theta, phi):
    return 7.17662944926961e-9*(1.0 - cos(theta)**2)**3*(3.09158674149208e+15*cos(theta)**21 - 1.2249683315346e+16*cos(theta)**19 + 2.05362337933741e+16*cos(theta)**17 - 1.89995088156387e+16*cos(theta)**15 + 1.06114277959684e+16*cos(theta)**13 - 3.67862830260238e+15*cos(theta)**11 + 784203707919112.0*cos(theta)**9 - 98367015627484.4*cos(theta)**7 + 6620856821080.68*cos(theta)**5 - 198824529161.582*cos(theta)**3 + 1704210249.95642*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl27_m7(theta, phi):
    return 2.68578607004038e-10*(1.0 - cos(theta)**2)**3.5*(6.49233215713337e+16*cos(theta)**20 - 2.32743982991574e+17*cos(theta)**18 + 3.4911597448736e+17*cos(theta)**16 - 2.8499263223458e+17*cos(theta)**14 + 1.37948561347589e+17*cos(theta)**12 - 4.04649113286262e+16*cos(theta)**10 + 7.05783337127201e+15*cos(theta)**8 - 688569109392391.0*cos(theta)**6 + 33104284105403.4*cos(theta)**4 - 596473587484.746*cos(theta)**2 + 1704210249.95642)*cos(7*phi)

#@torch.jit.script
def Yl27_m8(theta, phi):
    return 1.01513171657834e-11*(1.0 - cos(theta)**2)**4*(1.29846643142667e+18*cos(theta)**19 - 4.18939169384832e+18*cos(theta)**17 + 5.58585559179777e+18*cos(theta)**15 - 3.98989685128412e+18*cos(theta)**13 + 1.65538273617107e+18*cos(theta)**11 - 4.04649113286262e+17*cos(theta)**9 + 5.6462666970176e+16*cos(theta)**7 - 4.13141465635434e+15*cos(theta)**5 + 132417136421614.0*cos(theta)**3 - 1192947174969.49*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl27_m9(theta, phi):
    return 3.8814531289017e-13*(1.0 - cos(theta)**2)**4.5*(2.46708621971068e+19*cos(theta)**18 - 7.12196587954215e+19*cos(theta)**16 + 8.37878338769665e+19*cos(theta)**14 - 5.18686590666935e+19*cos(theta)**12 + 1.82092100978818e+19*cos(theta)**10 - 3.64184201957635e+18*cos(theta)**8 + 3.95238668791232e+17*cos(theta)**6 - 2.06570732817717e+16*cos(theta)**4 + 397251409264841.0*cos(theta)**2 - 1192947174969.49)*cos(9*phi)

#@torch.jit.script
def Yl27_m10(theta, phi):
    return 1.50403253709877e-14*(1.0 - cos(theta)**2)**5*(4.44075519547922e+20*cos(theta)**17 - 1.13951454072674e+21*cos(theta)**15 + 1.17302967427753e+21*cos(theta)**13 - 6.22423908800322e+20*cos(theta)**11 + 1.82092100978818e+20*cos(theta)**9 - 2.91347361566108e+19*cos(theta)**7 + 2.37143201274739e+18*cos(theta)**5 - 8.26282931270869e+16*cos(theta)**3 + 794502818529682.0*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl27_m11(theta, phi):
    return 5.91753687024496e-16*(1.0 - cos(theta)**2)**5.5*(7.54928383231468e+21*cos(theta)**16 - 1.70927181109012e+22*cos(theta)**14 + 1.52493857656079e+22*cos(theta)**12 - 6.84666299680355e+21*cos(theta)**10 + 1.63882890880936e+21*cos(theta)**8 - 2.03943153096276e+20*cos(theta)**6 + 1.1857160063737e+19*cos(theta)**4 - 2.47884879381261e+17*cos(theta)**2 + 794502818529682.0)*cos(11*phi)

#@torch.jit.script
def Yl27_m12(theta, phi):
    return 2.36891063526465e-17*(1.0 - cos(theta)**2)**6*(1.20788541317035e+23*cos(theta)**15 - 2.39298053552616e+23*cos(theta)**13 + 1.82992629187295e+23*cos(theta)**11 - 6.84666299680355e+22*cos(theta)**9 + 1.31106312704749e+22*cos(theta)**7 - 1.22365891857766e+21*cos(theta)**5 + 4.74286402549479e+19*cos(theta)**3 - 4.95769758762521e+17*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl27_m13(theta, phi):
    return 9.67103717108456e-19*(1.0 - cos(theta)**2)**6.5*(1.81182811975552e+24*cos(theta)**14 - 3.11087469618401e+24*cos(theta)**12 + 2.01291892106024e+24*cos(theta)**10 - 6.16199669712319e+23*cos(theta)**8 + 9.17744188933241e+22*cos(theta)**6 - 6.11829459288828e+21*cos(theta)**4 + 1.42285920764844e+20*cos(theta)**2 - 4.95769758762521e+17)*cos(13*phi)

#@torch.jit.script
def Yl27_m14(theta, phi):
    return 4.03661292375851e-20*(1.0 - cos(theta)**2)**7*(2.53655936765773e+25*cos(theta)**13 - 3.73304963542081e+25*cos(theta)**11 + 2.01291892106024e+25*cos(theta)**9 - 4.92959735769855e+24*cos(theta)**7 + 5.50646513359945e+23*cos(theta)**5 - 2.44731783715531e+22*cos(theta)**3 + 2.84571841529687e+20*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl27_m15(theta, phi):
    return 1.72751085492761e-21*(1.0 - cos(theta)**2)**7.5*(3.29752717795505e+26*cos(theta)**12 - 4.1063545989629e+26*cos(theta)**10 + 1.81162702895422e+26*cos(theta)**8 - 3.45071815038899e+25*cos(theta)**6 + 2.75323256679972e+24*cos(theta)**4 - 7.34195351146593e+22*cos(theta)**2 + 2.84571841529687e+20)*cos(15*phi)

#@torch.jit.script
def Yl27_m16(theta, phi):
    return 7.60494248954183e-23*(1.0 - cos(theta)**2)**8*(3.95703261354606e+27*cos(theta)**11 - 4.1063545989629e+27*cos(theta)**9 + 1.44930162316337e+27*cos(theta)**7 - 2.07043089023339e+26*cos(theta)**5 + 1.10129302671989e+25*cos(theta)**3 - 1.46839070229319e+23*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl27_m17(theta, phi):
    return 3.45679204070083e-24*(1.0 - cos(theta)**2)**8.5*(4.35273587490067e+28*cos(theta)**10 - 3.69571913906661e+28*cos(theta)**8 + 1.01451113621436e+28*cos(theta)**6 - 1.0352154451167e+27*cos(theta)**4 + 3.30387908015967e+25*cos(theta)**2 - 1.46839070229319e+23)*cos(17*phi)

#@torch.jit.script
def Yl27_m18(theta, phi):
    return 1.62954739542083e-25*(1.0 - cos(theta)**2)**9*(4.35273587490067e+29*cos(theta)**9 - 2.95657531125328e+29*cos(theta)**7 + 6.08706681728617e+28*cos(theta)**5 - 4.14086178046679e+27*cos(theta)**3 + 6.60775816031934e+25*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl27_m19(theta, phi):
    return 8.00878852093215e-27*(1.0 - cos(theta)**2)**9.5*(3.9174622874106e+30*cos(theta)**8 - 2.0696027178773e+30*cos(theta)**6 + 3.04353340864309e+29*cos(theta)**4 - 1.24225853414004e+28*cos(theta)**2 + 6.60775816031934e+25)*cos(19*phi)

#@torch.jit.script
def Yl27_m20(theta, phi):
    return 4.13021731864148e-28*(1.0 - cos(theta)**2)**10*(3.13396982992848e+31*cos(theta)**7 - 1.24176163072638e+31*cos(theta)**5 + 1.21741336345723e+30*cos(theta)**3 - 2.48451706828007e+28*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl27_m21(theta, phi):
    return 2.25321827372525e-29*(1.0 - cos(theta)**2)**10.5*(2.19377888094994e+32*cos(theta)**6 - 6.2088081536319e+31*cos(theta)**4 + 3.6522400903717e+30*cos(theta)**2 - 2.48451706828007e+28)*cos(21*phi)

#@torch.jit.script
def Yl27_m22(theta, phi):
    return 1.31410358327182e-30*(1.0 - cos(theta)**2)**11*(1.31626732856996e+33*cos(theta)**5 - 2.48352326145276e+32*cos(theta)**3 + 7.30448018074341e+30*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl27_m23(theta, phi):
    return 8.31112080905536e-32*(1.0 - cos(theta)**2)**11.5*(6.58133664284981e+33*cos(theta)**4 - 7.45056978435828e+32*cos(theta)**2 + 7.30448018074341e+30)*cos(23*phi)

#@torch.jit.script
def Yl27_m24(theta, phi):
    return 5.81894847243549e-33*(1.0 - cos(theta)**2)**12*(2.63253465713992e+34*cos(theta)**3 - 1.49011395687166e+33*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl27_m25(theta, phi):
    return 4.65888737989014e-34*(1.0 - cos(theta)**2)**12.5*(7.89760397141977e+34*cos(theta)**2 - 1.49011395687166e+33)*cos(25*phi)

#@torch.jit.script
def Yl27_m26(theta, phi):
    return 7.14750762604425*(1.0 - cos(theta)**2)**13*cos(26*phi)*cos(theta)

#@torch.jit.script
def Yl27_m27(theta, phi):
    return 0.97265258980333*(1.0 - cos(theta)**2)**13.5*cos(27*phi)

#@torch.jit.script
def Yl28_m_minus_28(theta, phi):
    return 0.981298560633835*(1.0 - cos(theta)**2)**14*sin(28*phi)

#@torch.jit.script
def Yl28_m_minus_27(theta, phi):
    return 7.34336601605245*(1.0 - cos(theta)**2)**13.5*sin(27*phi)*cos(theta)

#@torch.jit.script
def Yl28_m_minus_26(theta, phi):
    return 8.86550503264189e-36*(1.0 - cos(theta)**2)**13*(4.34368218428088e+36*cos(theta)**2 - 7.89760397141977e+34)*sin(26*phi)

#@torch.jit.script
def Yl28_m_minus_25(theta, phi):
    return 1.12839457090042e-34*(1.0 - cos(theta)**2)**12.5*(1.44789406142696e+36*cos(theta)**3 - 7.89760397141977e+34*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl28_m_minus_24(theta, phi):
    return 1.64296729492452e-33*(1.0 - cos(theta)**2)**12*(3.6197351535674e+35*cos(theta)**4 - 3.94880198570989e+34*cos(theta)**2 + 3.72528489217914e+32)*sin(24*phi)

#@torch.jit.script
def Yl28_m_minus_23(theta, phi):
    return 2.64920516074126e-32*(1.0 - cos(theta)**2)**11.5*(7.23947030713479e+34*cos(theta)**5 - 1.31626732856996e+34*cos(theta)**3 + 3.72528489217914e+32*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl28_m_minus_22(theta, phi):
    return 4.63421635555746e-31*(1.0 - cos(theta)**2)**11*(1.20657838452247e+34*cos(theta)**6 - 3.29066832142491e+33*cos(theta)**4 + 1.86264244608957e+32*cos(theta)**2 - 1.21741336345723e+30)*sin(22*phi)

#@torch.jit.script
def Yl28_m_minus_21(theta, phi):
    return 8.66982492934009e-30*(1.0 - cos(theta)**2)**10.5*(1.72368340646067e+33*cos(theta)**7 - 6.58133664284981e+32*cos(theta)**5 + 6.2088081536319e+31*cos(theta)**3 - 1.21741336345723e+30*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl28_m_minus_20(theta, phi):
    return 1.71653775978624e-28*(1.0 - cos(theta)**2)**10*(2.15460425807583e+32*cos(theta)**8 - 1.09688944047497e+32*cos(theta)**6 + 1.55220203840797e+31*cos(theta)**4 - 6.08706681728617e+29*cos(theta)**2 + 3.10564633535009e+27)*sin(20*phi)

#@torch.jit.script
def Yl28_m_minus_19(theta, phi):
    return 3.56775673567227e-27*(1.0 - cos(theta)**2)**9.5*(2.39400473119537e+31*cos(theta)**9 - 1.56698491496424e+31*cos(theta)**7 + 3.10440407681595e+30*cos(theta)**5 - 2.02902227242872e+29*cos(theta)**3 + 3.10564633535009e+27*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl28_m_minus_18(theta, phi):
    return 7.73471228858538e-26*(1.0 - cos(theta)**2)**9*(2.39400473119537e+30*cos(theta)**10 - 1.9587311437053e+30*cos(theta)**8 + 5.17400679469325e+29*cos(theta)**6 - 5.07255568107181e+28*cos(theta)**4 + 1.55282316767504e+27*cos(theta)**2 - 6.60775816031934e+24)*sin(18*phi)

#@torch.jit.script
def Yl28_m_minus_17(theta, phi):
    return 1.7398805056302e-24*(1.0 - cos(theta)**2)**8.5*(2.17636793745033e+29*cos(theta)**11 - 2.17636793745033e+29*cos(theta)**9 + 7.39143827813321e+28*cos(theta)**7 - 1.01451113621436e+28*cos(theta)**5 + 5.17607722558348e+26*cos(theta)**3 - 6.60775816031934e+24*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl28_m_minus_16(theta, phi):
    return 4.04311693361802e-23*(1.0 - cos(theta)**2)**8*(1.81363994787528e+28*cos(theta)**12 - 2.17636793745033e+28*cos(theta)**10 + 9.23929784766651e+27*cos(theta)**8 - 1.6908518936906e+27*cos(theta)**6 + 1.29401930639587e+26*cos(theta)**4 - 3.30387908015967e+24*cos(theta)**2 + 1.22365891857766e+22)*sin(16*phi)

#@torch.jit.script
def Yl28_m_minus_15(theta, phi):
    return 9.66972930141058e-22*(1.0 - cos(theta)**2)**7.5*(1.39510765221175e+27*cos(theta)**13 - 1.97851630677303e+27*cos(theta)**11 + 1.02658864974072e+27*cos(theta)**9 - 2.41550270527229e+26*cos(theta)**7 + 2.58803861279174e+25*cos(theta)**5 - 1.10129302671989e+24*cos(theta)**3 + 1.22365891857766e+22*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl28_m_minus_14(theta, phi):
    return 2.3725346401488e-20*(1.0 - cos(theta)**2)**7*(9.96505465865538e+25*cos(theta)**14 - 1.64876358897753e+26*cos(theta)**12 + 1.02658864974072e+26*cos(theta)**10 - 3.01937838159036e+25*cos(theta)**8 + 4.31339768798623e+24*cos(theta)**6 - 2.75323256679972e+23*cos(theta)**4 + 6.11829459288828e+21*cos(theta)**2 - 2.03265601092634e+19)*sin(14*phi)

#@torch.jit.script
def Yl28_m_minus_13(theta, phi):
    return 5.95501468493973e-19*(1.0 - cos(theta)**2)**6.5*(6.64336977243692e+24*cos(theta)**15 - 1.26827968382887e+25*cos(theta)**13 + 9.33262408855204e+24*cos(theta)**11 - 3.35486486843374e+24*cos(theta)**9 + 6.16199669712319e+23*cos(theta)**7 - 5.50646513359945e+22*cos(theta)**5 + 2.03943153096276e+21*cos(theta)**3 - 2.03265601092634e+19*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl28_m_minus_12(theta, phi):
    return 1.52522795453625e-17*(1.0 - cos(theta)**2)**6*(4.15210610777307e+23*cos(theta)**16 - 9.05914059877762e+23*cos(theta)**14 + 7.77718674046003e+23*cos(theta)**12 - 3.35486486843374e+23*cos(theta)**10 + 7.70249587140399e+22*cos(theta)**8 - 9.17744188933241e+21*cos(theta)**6 + 5.0985788274069e+20*cos(theta)**4 - 1.01632800546317e+19*cos(theta)**2 + 3.09856099226576e+16)*sin(12*phi)

#@torch.jit.script
def Yl28_m_minus_11(theta, phi):
    return 3.977307899878e-16*(1.0 - cos(theta)**2)**5.5*(2.44241535751357e+22*cos(theta)**17 - 6.03942706585174e+22*cos(theta)**15 + 5.98245133881541e+22*cos(theta)**13 - 3.04987715312158e+22*cos(theta)**11 + 8.55832874600443e+21*cos(theta)**9 - 1.31106312704749e+21*cos(theta)**7 + 1.01971576548138e+20*cos(theta)**5 - 3.38776001821056e+18*cos(theta)**3 + 3.09856099226576e+16*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl28_m_minus_10(theta, phi):
    return 1.05379896790437e-14*(1.0 - cos(theta)**2)**5*(1.35689742084087e+21*cos(theta)**18 - 3.77464191615734e+21*cos(theta)**16 + 4.27317952772529e+21*cos(theta)**14 - 2.54156429426798e+21*cos(theta)**12 + 8.55832874600443e+20*cos(theta)**10 - 1.63882890880936e+20*cos(theta)**8 + 1.6995262758023e+19*cos(theta)**6 - 8.46940004552641e+17*cos(theta)**4 + 1.54928049613288e+16*cos(theta)**2 - 44139045473871.2)*sin(10*phi)

#@torch.jit.script
def Yl28_m_minus_9(theta, phi):
    return 2.83156390560776e-13*(1.0 - cos(theta)**2)**4.5*(7.1415653728467e+19*cos(theta)**19 - 2.22037759773961e+20*cos(theta)**17 + 2.84878635181686e+20*cos(theta)**15 - 1.95504945712922e+20*cos(theta)**13 + 7.78029886000403e+19*cos(theta)**11 - 1.82092100978818e+19*cos(theta)**9 + 2.42789467971757e+18*cos(theta)**7 - 1.69388000910528e+17*cos(theta)**5 + 5.16426832044293e+15*cos(theta)**3 - 44139045473871.2*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl28_m_minus_8(theta, phi):
    return 7.70268659114473e-12*(1.0 - cos(theta)**2)**4*(3.57078268642335e+18*cos(theta)**20 - 1.23354310985534e+19*cos(theta)**18 + 1.78049146988554e+19*cos(theta)**16 - 1.39646389794944e+19*cos(theta)**14 + 6.48358238333669e+18*cos(theta)**12 - 1.82092100978818e+18*cos(theta)**10 + 3.03486834964696e+17*cos(theta)**8 - 2.8231333485088e+16*cos(theta)**6 + 1.29106708011073e+15*cos(theta)**4 - 22069522736935.6*cos(theta)**2 + 59647358748.4746)*sin(8*phi)

#@torch.jit.script
def Yl28_m_minus_7(theta, phi):
    return 2.11788866150653e-10*(1.0 - cos(theta)**2)**3.5*(1.70037270782064e+17*cos(theta)**21 - 6.49233215713337e+17*cos(theta)**19 + 1.04734792346208e+18*cos(theta)**17 - 9.30975931966294e+17*cos(theta)**15 + 4.98737106410515e+17*cos(theta)**13 - 1.65538273617107e+17*cos(theta)**11 + 3.37207594405218e+16*cos(theta)**9 - 4.03304764072686e+15*cos(theta)**7 + 258213416022147.0*cos(theta)**5 - 7356507578978.53*cos(theta)**3 + 59647358748.4746*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl28_m_minus_6(theta, phi):
    return 5.8769025298657e-9*(1.0 - cos(theta)**2)**3*(7.7289668537302e+15*cos(theta)**22 - 3.24616607856668e+16*cos(theta)**20 + 5.81859957478934e+16*cos(theta)**18 - 5.81859957478934e+16*cos(theta)**16 + 3.56240790293225e+16*cos(theta)**14 - 1.37948561347589e+16*cos(theta)**12 + 3.37207594405218e+15*cos(theta)**10 - 504130955090858.0*cos(theta)**8 + 43035569337024.4*cos(theta)**6 - 1839126894744.63*cos(theta)**4 + 29823679374.2373*cos(theta)**2 - 77464102.2707462)*sin(6*phi)

#@torch.jit.script
def Yl28_m_minus_5(theta, phi):
    return 1.64343247431143e-7*(1.0 - cos(theta)**2)**2.5*(336042037118704.0*cos(theta)**23 - 1.54579337074604e+15*cos(theta)**21 + 3.06242082883649e+15*cos(theta)**19 - 3.42270563222902e+15*cos(theta)**17 + 2.37493860195483e+15*cos(theta)**15 - 1.06114277959684e+15*cos(theta)**13 + 306552358550198.0*cos(theta)**11 - 56014550565650.8*cos(theta)**9 + 6147938476717.77*cos(theta)**7 - 367825378948.927*cos(theta)**5 + 9941226458.0791*cos(theta)**3 - 77464102.2707462*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl28_m_minus_4(theta, phi):
    return 4.62502894662956e-6*(1.0 - cos(theta)**2)**2*(14001751546612.7*cos(theta)**24 - 70263335033910.9*cos(theta)**22 + 153121041441825.0*cos(theta)**20 - 190150312901612.0*cos(theta)**18 + 148433662622177.0*cos(theta)**16 - 75795912828345.7*cos(theta)**14 + 25546029879183.2*cos(theta)**12 - 5601455056565.08*cos(theta)**10 + 768492309589.722*cos(theta)**8 - 61304229824.8211*cos(theta)**6 + 2485306614.51977*cos(theta)**4 - 38732051.1353731*cos(theta)**2 + 97808.2099378109)*sin(4*phi)

#@torch.jit.script
def Yl28_m_minus_3(theta, phi):
    return 0.000130815573253833*(1.0 - cos(theta)**2)**1.5*(560070061864.507*cos(theta)**25 - 3054927610170.04*cos(theta)**23 + 7291478163896.42*cos(theta)**21 - 10007911205348.0*cos(theta)**19 + 8731391918951.59*cos(theta)**17 - 5053060855223.05*cos(theta)**15 + 1965079221475.63*cos(theta)**13 - 509223186960.462*cos(theta)**11 + 85388034398.858*cos(theta)**9 - 8757747117.83159*cos(theta)**7 + 497061322.903955*cos(theta)**5 - 12910683.711791*cos(theta)**3 + 97808.2099378109*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl28_m_minus_2(theta, phi):
    return 0.00371387232545999*(1.0 - cos(theta)**2)*(21541156225.558*cos(theta)**26 - 127288650423.752*cos(theta)**24 + 331430825631.655*cos(theta)**22 - 500395560267.401*cos(theta)**20 + 485077328830.644*cos(theta)**18 - 315816303451.44*cos(theta)**16 + 140362801533.974*cos(theta)**14 - 42435265580.0385*cos(theta)**12 + 8538803439.8858*cos(theta)**10 - 1094718389.72895*cos(theta)**8 + 82843553.8173258*cos(theta)**6 - 3227670.92794776*cos(theta)**4 + 48904.1049689054*cos(theta)**2 - 121.350136399269)*sin(2*phi)

#@torch.jit.script
def Yl28_m_minus_1(theta, phi):
    return 0.105698659387677*(1.0 - cos(theta)**2)**0.5*(797820600.946591*cos(theta)**27 - 5091546016.95007*cos(theta)**25 + 14410035897.0285*cos(theta)**23 - 23828360012.7334*cos(theta)**21 + 25530385727.9286*cos(theta)**19 - 18577429614.7906*cos(theta)**17 + 9357520102.2649*cos(theta)**15 - 3264251198.4645*cos(theta)**13 + 776254858.171436*cos(theta)**11 - 121635376.63655*cos(theta)**9 + 11834793.4024751*cos(theta)**7 - 645534.185589552*cos(theta)**5 + 16301.3683229685*cos(theta)**3 - 121.350136399269*cos(theta))*sin(phi)

#@torch.jit.script
def Yl28_m0(theta, phi):
    return 190646827.826863*cos(theta)**28 - 1310263653.06463*cos(theta)**26 + 4017317804.20758*cos(theta)**24 - 7246926235.04112*cos(theta)**22 + 8541020205.58418*cos(theta)**20 - 6905505698.13189*cos(theta)**18 + 3913119895.60807*cos(theta)**16 - 1560047798.91352*cos(theta)**14 + 432818139.332713*cos(theta)**12 - 81384607.3958948*cos(theta)**10 + 9898127.92652775*cos(theta)**8 - 719863.849202018*cos(theta)**6 + 27267.570045531*cos(theta)**4 - 405.968784796988*cos(theta)**2 + 0.999923115263516

#@torch.jit.script
def Yl28_m1(theta, phi):
    return 0.105698659387677*(1.0 - cos(theta)**2)**0.5*(797820600.946591*cos(theta)**27 - 5091546016.95007*cos(theta)**25 + 14410035897.0285*cos(theta)**23 - 23828360012.7334*cos(theta)**21 + 25530385727.9286*cos(theta)**19 - 18577429614.7906*cos(theta)**17 + 9357520102.2649*cos(theta)**15 - 3264251198.4645*cos(theta)**13 + 776254858.171436*cos(theta)**11 - 121635376.63655*cos(theta)**9 + 11834793.4024751*cos(theta)**7 - 645534.185589552*cos(theta)**5 + 16301.3683229685*cos(theta)**3 - 121.350136399269*cos(theta))*cos(phi)

#@torch.jit.script
def Yl28_m2(theta, phi):
    return 0.00371387232545999*(1.0 - cos(theta)**2)*(21541156225.558*cos(theta)**26 - 127288650423.752*cos(theta)**24 + 331430825631.655*cos(theta)**22 - 500395560267.401*cos(theta)**20 + 485077328830.644*cos(theta)**18 - 315816303451.44*cos(theta)**16 + 140362801533.974*cos(theta)**14 - 42435265580.0385*cos(theta)**12 + 8538803439.8858*cos(theta)**10 - 1094718389.72895*cos(theta)**8 + 82843553.8173258*cos(theta)**6 - 3227670.92794776*cos(theta)**4 + 48904.1049689054*cos(theta)**2 - 121.350136399269)*cos(2*phi)

#@torch.jit.script
def Yl28_m3(theta, phi):
    return 0.000130815573253833*(1.0 - cos(theta)**2)**1.5*(560070061864.507*cos(theta)**25 - 3054927610170.04*cos(theta)**23 + 7291478163896.42*cos(theta)**21 - 10007911205348.0*cos(theta)**19 + 8731391918951.59*cos(theta)**17 - 5053060855223.05*cos(theta)**15 + 1965079221475.63*cos(theta)**13 - 509223186960.462*cos(theta)**11 + 85388034398.858*cos(theta)**9 - 8757747117.83159*cos(theta)**7 + 497061322.903955*cos(theta)**5 - 12910683.711791*cos(theta)**3 + 97808.2099378109*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl28_m4(theta, phi):
    return 4.62502894662956e-6*(1.0 - cos(theta)**2)**2*(14001751546612.7*cos(theta)**24 - 70263335033910.9*cos(theta)**22 + 153121041441825.0*cos(theta)**20 - 190150312901612.0*cos(theta)**18 + 148433662622177.0*cos(theta)**16 - 75795912828345.7*cos(theta)**14 + 25546029879183.2*cos(theta)**12 - 5601455056565.08*cos(theta)**10 + 768492309589.722*cos(theta)**8 - 61304229824.8211*cos(theta)**6 + 2485306614.51977*cos(theta)**4 - 38732051.1353731*cos(theta)**2 + 97808.2099378109)*cos(4*phi)

#@torch.jit.script
def Yl28_m5(theta, phi):
    return 1.64343247431143e-7*(1.0 - cos(theta)**2)**2.5*(336042037118704.0*cos(theta)**23 - 1.54579337074604e+15*cos(theta)**21 + 3.06242082883649e+15*cos(theta)**19 - 3.42270563222902e+15*cos(theta)**17 + 2.37493860195483e+15*cos(theta)**15 - 1.06114277959684e+15*cos(theta)**13 + 306552358550198.0*cos(theta)**11 - 56014550565650.8*cos(theta)**9 + 6147938476717.77*cos(theta)**7 - 367825378948.927*cos(theta)**5 + 9941226458.0791*cos(theta)**3 - 77464102.2707462*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl28_m6(theta, phi):
    return 5.8769025298657e-9*(1.0 - cos(theta)**2)**3*(7.7289668537302e+15*cos(theta)**22 - 3.24616607856668e+16*cos(theta)**20 + 5.81859957478934e+16*cos(theta)**18 - 5.81859957478934e+16*cos(theta)**16 + 3.56240790293225e+16*cos(theta)**14 - 1.37948561347589e+16*cos(theta)**12 + 3.37207594405218e+15*cos(theta)**10 - 504130955090858.0*cos(theta)**8 + 43035569337024.4*cos(theta)**6 - 1839126894744.63*cos(theta)**4 + 29823679374.2373*cos(theta)**2 - 77464102.2707462)*cos(6*phi)

#@torch.jit.script
def Yl28_m7(theta, phi):
    return 2.11788866150653e-10*(1.0 - cos(theta)**2)**3.5*(1.70037270782064e+17*cos(theta)**21 - 6.49233215713337e+17*cos(theta)**19 + 1.04734792346208e+18*cos(theta)**17 - 9.30975931966294e+17*cos(theta)**15 + 4.98737106410515e+17*cos(theta)**13 - 1.65538273617107e+17*cos(theta)**11 + 3.37207594405218e+16*cos(theta)**9 - 4.03304764072686e+15*cos(theta)**7 + 258213416022147.0*cos(theta)**5 - 7356507578978.53*cos(theta)**3 + 59647358748.4746*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl28_m8(theta, phi):
    return 7.70268659114473e-12*(1.0 - cos(theta)**2)**4*(3.57078268642335e+18*cos(theta)**20 - 1.23354310985534e+19*cos(theta)**18 + 1.78049146988554e+19*cos(theta)**16 - 1.39646389794944e+19*cos(theta)**14 + 6.48358238333669e+18*cos(theta)**12 - 1.82092100978818e+18*cos(theta)**10 + 3.03486834964696e+17*cos(theta)**8 - 2.8231333485088e+16*cos(theta)**6 + 1.29106708011073e+15*cos(theta)**4 - 22069522736935.6*cos(theta)**2 + 59647358748.4746)*cos(8*phi)

#@torch.jit.script
def Yl28_m9(theta, phi):
    return 2.83156390560776e-13*(1.0 - cos(theta)**2)**4.5*(7.1415653728467e+19*cos(theta)**19 - 2.22037759773961e+20*cos(theta)**17 + 2.84878635181686e+20*cos(theta)**15 - 1.95504945712922e+20*cos(theta)**13 + 7.78029886000403e+19*cos(theta)**11 - 1.82092100978818e+19*cos(theta)**9 + 2.42789467971757e+18*cos(theta)**7 - 1.69388000910528e+17*cos(theta)**5 + 5.16426832044293e+15*cos(theta)**3 - 44139045473871.2*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl28_m10(theta, phi):
    return 1.05379896790437e-14*(1.0 - cos(theta)**2)**5*(1.35689742084087e+21*cos(theta)**18 - 3.77464191615734e+21*cos(theta)**16 + 4.27317952772529e+21*cos(theta)**14 - 2.54156429426798e+21*cos(theta)**12 + 8.55832874600443e+20*cos(theta)**10 - 1.63882890880936e+20*cos(theta)**8 + 1.6995262758023e+19*cos(theta)**6 - 8.46940004552641e+17*cos(theta)**4 + 1.54928049613288e+16*cos(theta)**2 - 44139045473871.2)*cos(10*phi)

#@torch.jit.script
def Yl28_m11(theta, phi):
    return 3.977307899878e-16*(1.0 - cos(theta)**2)**5.5*(2.44241535751357e+22*cos(theta)**17 - 6.03942706585174e+22*cos(theta)**15 + 5.98245133881541e+22*cos(theta)**13 - 3.04987715312158e+22*cos(theta)**11 + 8.55832874600443e+21*cos(theta)**9 - 1.31106312704749e+21*cos(theta)**7 + 1.01971576548138e+20*cos(theta)**5 - 3.38776001821056e+18*cos(theta)**3 + 3.09856099226576e+16*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl28_m12(theta, phi):
    return 1.52522795453625e-17*(1.0 - cos(theta)**2)**6*(4.15210610777307e+23*cos(theta)**16 - 9.05914059877762e+23*cos(theta)**14 + 7.77718674046003e+23*cos(theta)**12 - 3.35486486843374e+23*cos(theta)**10 + 7.70249587140399e+22*cos(theta)**8 - 9.17744188933241e+21*cos(theta)**6 + 5.0985788274069e+20*cos(theta)**4 - 1.01632800546317e+19*cos(theta)**2 + 3.09856099226576e+16)*cos(12*phi)

#@torch.jit.script
def Yl28_m13(theta, phi):
    return 5.95501468493973e-19*(1.0 - cos(theta)**2)**6.5*(6.64336977243692e+24*cos(theta)**15 - 1.26827968382887e+25*cos(theta)**13 + 9.33262408855204e+24*cos(theta)**11 - 3.35486486843374e+24*cos(theta)**9 + 6.16199669712319e+23*cos(theta)**7 - 5.50646513359945e+22*cos(theta)**5 + 2.03943153096276e+21*cos(theta)**3 - 2.03265601092634e+19*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl28_m14(theta, phi):
    return 2.3725346401488e-20*(1.0 - cos(theta)**2)**7*(9.96505465865538e+25*cos(theta)**14 - 1.64876358897753e+26*cos(theta)**12 + 1.02658864974072e+26*cos(theta)**10 - 3.01937838159036e+25*cos(theta)**8 + 4.31339768798623e+24*cos(theta)**6 - 2.75323256679972e+23*cos(theta)**4 + 6.11829459288828e+21*cos(theta)**2 - 2.03265601092634e+19)*cos(14*phi)

#@torch.jit.script
def Yl28_m15(theta, phi):
    return 9.66972930141058e-22*(1.0 - cos(theta)**2)**7.5*(1.39510765221175e+27*cos(theta)**13 - 1.97851630677303e+27*cos(theta)**11 + 1.02658864974072e+27*cos(theta)**9 - 2.41550270527229e+26*cos(theta)**7 + 2.58803861279174e+25*cos(theta)**5 - 1.10129302671989e+24*cos(theta)**3 + 1.22365891857766e+22*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl28_m16(theta, phi):
    return 4.04311693361802e-23*(1.0 - cos(theta)**2)**8*(1.81363994787528e+28*cos(theta)**12 - 2.17636793745033e+28*cos(theta)**10 + 9.23929784766651e+27*cos(theta)**8 - 1.6908518936906e+27*cos(theta)**6 + 1.29401930639587e+26*cos(theta)**4 - 3.30387908015967e+24*cos(theta)**2 + 1.22365891857766e+22)*cos(16*phi)

#@torch.jit.script
def Yl28_m17(theta, phi):
    return 1.7398805056302e-24*(1.0 - cos(theta)**2)**8.5*(2.17636793745033e+29*cos(theta)**11 - 2.17636793745033e+29*cos(theta)**9 + 7.39143827813321e+28*cos(theta)**7 - 1.01451113621436e+28*cos(theta)**5 + 5.17607722558348e+26*cos(theta)**3 - 6.60775816031934e+24*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl28_m18(theta, phi):
    return 7.73471228858538e-26*(1.0 - cos(theta)**2)**9*(2.39400473119537e+30*cos(theta)**10 - 1.9587311437053e+30*cos(theta)**8 + 5.17400679469325e+29*cos(theta)**6 - 5.07255568107181e+28*cos(theta)**4 + 1.55282316767504e+27*cos(theta)**2 - 6.60775816031934e+24)*cos(18*phi)

#@torch.jit.script
def Yl28_m19(theta, phi):
    return 3.56775673567227e-27*(1.0 - cos(theta)**2)**9.5*(2.39400473119537e+31*cos(theta)**9 - 1.56698491496424e+31*cos(theta)**7 + 3.10440407681595e+30*cos(theta)**5 - 2.02902227242872e+29*cos(theta)**3 + 3.10564633535009e+27*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl28_m20(theta, phi):
    return 1.71653775978624e-28*(1.0 - cos(theta)**2)**10*(2.15460425807583e+32*cos(theta)**8 - 1.09688944047497e+32*cos(theta)**6 + 1.55220203840797e+31*cos(theta)**4 - 6.08706681728617e+29*cos(theta)**2 + 3.10564633535009e+27)*cos(20*phi)

#@torch.jit.script
def Yl28_m21(theta, phi):
    return 8.66982492934009e-30*(1.0 - cos(theta)**2)**10.5*(1.72368340646067e+33*cos(theta)**7 - 6.58133664284981e+32*cos(theta)**5 + 6.2088081536319e+31*cos(theta)**3 - 1.21741336345723e+30*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl28_m22(theta, phi):
    return 4.63421635555746e-31*(1.0 - cos(theta)**2)**11*(1.20657838452247e+34*cos(theta)**6 - 3.29066832142491e+33*cos(theta)**4 + 1.86264244608957e+32*cos(theta)**2 - 1.21741336345723e+30)*cos(22*phi)

#@torch.jit.script
def Yl28_m23(theta, phi):
    return 2.64920516074126e-32*(1.0 - cos(theta)**2)**11.5*(7.23947030713479e+34*cos(theta)**5 - 1.31626732856996e+34*cos(theta)**3 + 3.72528489217914e+32*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl28_m24(theta, phi):
    return 1.64296729492452e-33*(1.0 - cos(theta)**2)**12*(3.6197351535674e+35*cos(theta)**4 - 3.94880198570989e+34*cos(theta)**2 + 3.72528489217914e+32)*cos(24*phi)

#@torch.jit.script
def Yl28_m25(theta, phi):
    return 1.12839457090042e-34*(1.0 - cos(theta)**2)**12.5*(1.44789406142696e+36*cos(theta)**3 - 7.89760397141977e+34*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl28_m26(theta, phi):
    return 8.86550503264189e-36*(1.0 - cos(theta)**2)**13*(4.34368218428088e+36*cos(theta)**2 - 7.89760397141977e+34)*cos(26*phi)

#@torch.jit.script
def Yl28_m27(theta, phi):
    return 7.34336601605245*(1.0 - cos(theta)**2)**13.5*cos(27*phi)*cos(theta)

#@torch.jit.script
def Yl28_m28(theta, phi):
    return 0.981298560633835*(1.0 - cos(theta)**2)**14*cos(28*phi)

#@torch.jit.script
def Yl29_m_minus_29(theta, phi):
    return 0.989721878741179*(1.0 - cos(theta)**2)**14.5*sin(29*phi)

#@torch.jit.script
def Yl29_m_minus_28(theta, phi):
    return 7.53749726640217*(1.0 - cos(theta)**2)**14*sin(28*phi)*cos(theta)

#@torch.jit.script
def Yl29_m_minus_27(theta, phi):
    return 1.62523699825355e-37*(1.0 - cos(theta)**2)**13.5*(2.4758988450401e+38*cos(theta)**2 - 4.34368218428088e+36)*sin(27*phi)

#@torch.jit.script
def Yl29_m_minus_26(theta, phi):
    return 2.106547911828e-36*(1.0 - cos(theta)**2)**13*(8.25299615013366e+37*cos(theta)**3 - 4.34368218428088e+36*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl29_m_minus_25(theta, phi):
    return 3.12451548733867e-35*(1.0 - cos(theta)**2)**12.5*(2.06324903753342e+37*cos(theta)**4 - 2.17184109214044e+36*cos(theta)**2 + 1.97440099285494e+34)*sin(25*phi)

#@torch.jit.script
def Yl29_m_minus_24(theta, phi):
    return 5.13410284106891e-34*(1.0 - cos(theta)**2)**12*(4.12649807506683e+36*cos(theta)**5 - 7.23947030713479e+35*cos(theta)**3 + 1.97440099285494e+34*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl29_m_minus_23(theta, phi):
    return 9.15541687226183e-33*(1.0 - cos(theta)**2)**11.5*(6.87749679177805e+35*cos(theta)**6 - 1.8098675767837e+35*cos(theta)**4 + 9.87200496427472e+33*cos(theta)**2 - 6.2088081536319e+31)*sin(23*phi)

#@torch.jit.script
def Yl29_m_minus_22(theta, phi):
    return 1.74674221195294e-31*(1.0 - cos(theta)**2)**11*(9.82499541682579e+34*cos(theta)**7 - 3.6197351535674e+34*cos(theta)**5 + 3.29066832142491e+33*cos(theta)**3 - 6.2088081536319e+31*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl29_m_minus_21(theta, phi):
    return 3.52824631913283e-30*(1.0 - cos(theta)**2)**10.5*(1.22812442710322e+34*cos(theta)**8 - 6.03289192261233e+33*cos(theta)**6 + 8.22667080356226e+32*cos(theta)**4 - 3.10440407681595e+31*cos(theta)**2 + 1.52176670432154e+29)*sin(21*phi)

#@torch.jit.script
def Yl29_m_minus_20(theta, phi):
    return 7.48454069386591e-29*(1.0 - cos(theta)**2)**10*(1.36458269678136e+33*cos(theta)**9 - 8.61841703230333e+32*cos(theta)**7 + 1.64533416071245e+32*cos(theta)**5 - 1.03480135893865e+31*cos(theta)**3 + 1.52176670432154e+29*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl29_m_minus_19(theta, phi):
    return 1.65677370829833e-27*(1.0 - cos(theta)**2)**9.5*(1.36458269678136e+32*cos(theta)**10 - 1.07730212903792e+32*cos(theta)**8 + 2.74222360118742e+31*cos(theta)**6 - 2.58700339734662e+30*cos(theta)**4 + 7.60883352160772e+28*cos(theta)**2 - 3.10564633535009e+26)*sin(19*phi)

#@torch.jit.script
def Yl29_m_minus_18(theta, phi):
    return 3.80697614338276e-26*(1.0 - cos(theta)**2)**9*(1.24052972434669e+31*cos(theta)**11 - 1.19700236559768e+31*cos(theta)**9 + 3.9174622874106e+30*cos(theta)**7 - 5.17400679469325e+29*cos(theta)**5 + 2.53627784053591e+28*cos(theta)**3 - 3.10564633535009e+26*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl29_m_minus_17(theta, phi):
    return 9.04106740874383e-25*(1.0 - cos(theta)**2)**8.5*(1.03377477028891e+30*cos(theta)**12 - 1.19700236559768e+30*cos(theta)**10 + 4.89682785926325e+29*cos(theta)**8 - 8.62334465782208e+28*cos(theta)**6 + 6.34069460133976e+27*cos(theta)**4 - 1.55282316767504e+26*cos(theta)**2 + 5.50646513359945e+23)*sin(17*phi)

#@torch.jit.script
def Yl29_m_minus_16(theta, phi):
    return 2.21090610686865e-23*(1.0 - cos(theta)**2)**8*(7.95211361760699e+28*cos(theta)**13 - 1.08818396872517e+29*cos(theta)**11 + 5.44091984362584e+28*cos(theta)**9 - 1.23190637968887e+28*cos(theta)**7 + 1.26813892026795e+27*cos(theta)**5 - 5.17607722558348e+25*cos(theta)**3 + 5.50646513359945e+23*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl29_m_minus_15(theta, phi):
    return 5.54933028611123e-22*(1.0 - cos(theta)**2)**7.5*(5.68008115543357e+27*cos(theta)**14 - 9.06819973937639e+27*cos(theta)**12 + 5.44091984362584e+27*cos(theta)**10 - 1.53988297461109e+27*cos(theta)**8 + 2.11356486711325e+26*cos(theta)**6 - 1.29401930639587e+25*cos(theta)**4 + 2.75323256679972e+23*cos(theta)**2 - 8.74042084698325e+20)*sin(15*phi)

#@torch.jit.script
def Yl29_m_minus_14(theta, phi):
    return 1.42564876361858e-20*(1.0 - cos(theta)**2)**7*(3.78672077028904e+26*cos(theta)**15 - 6.97553826105876e+26*cos(theta)**13 + 4.94629076693258e+26*cos(theta)**11 - 1.71098108290121e+26*cos(theta)**9 + 3.01937838159036e+25*cos(theta)**7 - 2.58803861279174e+24*cos(theta)**5 + 9.17744188933241e+22*cos(theta)**3 - 8.74042084698325e+20*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl29_m_minus_13(theta, phi):
    return 3.7394416498704e-19*(1.0 - cos(theta)**2)**6.5*(2.36670048143065e+25*cos(theta)**16 - 4.98252732932769e+25*cos(theta)**14 + 4.12190897244381e+25*cos(theta)**12 - 1.71098108290121e+25*cos(theta)**10 + 3.77422297698796e+24*cos(theta)**8 - 4.31339768798623e+23*cos(theta)**6 + 2.2943604723331e+22*cos(theta)**4 - 4.37021042349163e+20*cos(theta)**2 + 1.27041000682896e+18)*sin(13*phi)

#@torch.jit.script
def Yl29_m_minus_12(theta, phi):
    return 9.99207917847372e-18*(1.0 - cos(theta)**2)**6*(1.39217675378274e+24*cos(theta)**17 - 3.32168488621846e+24*cos(theta)**15 + 3.17069920957217e+24*cos(theta)**13 - 1.55543734809201e+24*cos(theta)**11 + 4.19358108554217e+23*cos(theta)**9 - 6.16199669712319e+22*cos(theta)**7 + 4.58872094466621e+21*cos(theta)**5 - 1.45673680783054e+20*cos(theta)**3 + 1.27041000682896e+18*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl29_m_minus_11(theta, phi):
    return 2.7144637587553e-16*(1.0 - cos(theta)**2)**5.5*(7.73431529879298e+22*cos(theta)**18 - 2.07605305388654e+23*cos(theta)**16 + 2.2647851496944e+23*cos(theta)**14 - 1.29619779007667e+23*cos(theta)**12 + 4.19358108554217e+22*cos(theta)**10 - 7.70249587140399e+21*cos(theta)**8 + 7.64786824111034e+20*cos(theta)**6 - 3.64184201957635e+19*cos(theta)**4 + 6.35205003414481e+17*cos(theta)**2 - 1.72142277348098e+15)*sin(11*phi)

#@torch.jit.script
def Yl29_m_minus_10(theta, phi):
    return 7.48326015729302e-15*(1.0 - cos(theta)**2)**5*(4.07069226252262e+21*cos(theta)**19 - 1.22120767875679e+22*cos(theta)**17 + 1.50985676646294e+22*cos(theta)**15 - 9.97075223135901e+21*cos(theta)**13 + 3.81234644140198e+21*cos(theta)**11 - 8.55832874600443e+20*cos(theta)**9 + 1.09255260587291e+20*cos(theta)**7 - 7.28368403915271e+18*cos(theta)**5 + 2.1173500113816e+17*cos(theta)**3 - 1.72142277348098e+15*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl29_m_minus_9(theta, phi):
    return 2.08996082292824e-13*(1.0 - cos(theta)**2)**4.5*(2.03534613126131e+20*cos(theta)**20 - 6.78448710420437e+20*cos(theta)**18 + 9.43660479039335e+20*cos(theta)**16 - 7.12196587954215e+20*cos(theta)**14 + 3.17695536783498e+20*cos(theta)**12 - 8.55832874600443e+19*cos(theta)**10 + 1.36569075734113e+19*cos(theta)**8 - 1.21394733985879e+18*cos(theta)**6 + 5.293375028454e+16*cos(theta)**4 - 860711386740489.0*cos(theta)**2 + 2206952273693.56)*sin(9*phi)

#@torch.jit.script
def Yl29_m_minus_8(theta, phi):
    return 5.90390812988918e-12*(1.0 - cos(theta)**2)**4*(9.69212443457767e+18*cos(theta)**21 - 3.57078268642335e+19*cos(theta)**19 + 5.55094399434903e+19*cos(theta)**17 - 4.7479772530281e+19*cos(theta)**15 + 2.44381182141152e+19*cos(theta)**13 - 7.78029886000403e+18*cos(theta)**11 + 1.51743417482348e+18*cos(theta)**9 - 1.73421048551255e+17*cos(theta)**7 + 1.0586750056908e+16*cos(theta)**5 - 286903795580163.0*cos(theta)**3 + 2206952273693.56*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl29_m_minus_7(theta, phi):
    return 1.68442544512435e-10*(1.0 - cos(theta)**2)**3.5*(4.40551110662621e+17*cos(theta)**22 - 1.78539134321168e+18*cos(theta)**20 + 3.08385777463835e+18*cos(theta)**18 - 2.96748578314256e+18*cos(theta)**16 + 1.7455798724368e+18*cos(theta)**14 - 6.48358238333669e+17*cos(theta)**12 + 1.51743417482348e+17*cos(theta)**10 - 2.16776310689069e+16*cos(theta)**8 + 1.764458342818e+15*cos(theta)**6 - 71725948895040.7*cos(theta)**4 + 1103476136846.78*cos(theta)**2 - 2711243579.47612)*sin(7*phi)

#@torch.jit.script
def Yl29_m_minus_6(theta, phi):
    return 4.84693238903845e-9*(1.0 - cos(theta)**2)**3*(1.91543961157661e+16*cos(theta)**23 - 8.50186353910322e+16*cos(theta)**21 + 1.62308303928334e+17*cos(theta)**19 - 1.7455798724368e+17*cos(theta)**17 + 1.16371991495787e+17*cos(theta)**15 - 4.98737106410515e+16*cos(theta)**13 + 1.37948561347589e+16*cos(theta)**11 - 2.40862567432299e+15*cos(theta)**9 + 252065477545429.0*cos(theta)**7 - 14345189779008.1*cos(theta)**5 + 367825378948.927*cos(theta)**3 - 2711243579.47612*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl29_m_minus_5(theta, phi):
    return 1.40477446625728e-7*(1.0 - cos(theta)**2)**2.5*(798099838156923.0*cos(theta)**24 - 3.8644834268651e+15*cos(theta)**22 + 8.11541519641671e+15*cos(theta)**20 - 9.69766595798223e+15*cos(theta)**18 + 7.27324946848667e+15*cos(theta)**16 - 3.56240790293225e+15*cos(theta)**14 + 1.14957134456324e+15*cos(theta)**12 - 240862567432299.0*cos(theta)**10 + 31508184693178.6*cos(theta)**8 - 2390864963168.02*cos(theta)**6 + 91956344737.2317*cos(theta)**4 - 1355621789.73806*cos(theta)**2 + 3227670.92794776)*sin(5*phi)

#@torch.jit.script
def Yl29_m_minus_4(theta, phi):
    return 4.0955861679266e-6*(1.0 - cos(theta)**2)**2*(31923993526276.9*cos(theta)**25 - 168021018559352.0*cos(theta)**23 + 386448342686510.0*cos(theta)**21 - 510403471472749.0*cos(theta)**19 + 427838204028628.0*cos(theta)**17 - 237493860195483.0*cos(theta)**15 + 88428564966403.3*cos(theta)**13 - 21896597039299.9*cos(theta)**11 + 3500909410353.18*cos(theta)**9 - 341552137595.432*cos(theta)**7 + 18391268947.4463*cos(theta)**5 - 451873929.912686*cos(theta)**3 + 3227670.92794776*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl29_m_minus_3(theta, phi):
    return 0.000119966423463177*(1.0 - cos(theta)**2)**1.5*(1227845904856.8*cos(theta)**26 - 7000875773306.34*cos(theta)**24 + 17565833758477.7*cos(theta)**22 - 25520173573637.5*cos(theta)**20 + 23768789112701.5*cos(theta)**18 - 14843366262217.7*cos(theta)**16 + 6316326069028.81*cos(theta)**14 - 1824716419941.66*cos(theta)**12 + 350090941035.318*cos(theta)**10 - 42694017199.429*cos(theta)**8 + 3065211491.24106*cos(theta)**6 - 112968482.478172*cos(theta)**4 + 1613835.46397388*cos(theta)**2 - 3761.85422837734)*sin(3*phi)

#@torch.jit.script
def Yl29_m_minus_2(theta, phi):
    return 0.00352627828501722*(1.0 - cos(theta)**2)*(45475774253.9557*cos(theta)**27 - 280035030932.254*cos(theta)**25 + 763731902542.51*cos(theta)**23 - 1215246360649.4*cos(theta)**21 + 1250988900668.5*cos(theta)**19 - 873139191895.159*cos(theta)**17 + 421088404601.921*cos(theta)**15 - 140362801533.974*cos(theta)**13 + 31826449185.0289*cos(theta)**11 - 4743779688.82544*cos(theta)**9 + 437887355.891579*cos(theta)**7 - 22593696.4956343*cos(theta)**5 + 537945.15465796*cos(theta)**3 - 3761.85422837734*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl29_m_minus_1(theta, phi):
    return 0.103890645660027*(1.0 - cos(theta)**2)**0.5*(1624134794.78413*cos(theta)**28 - 10770578112.779*cos(theta)**26 + 31822162605.9379*cos(theta)**24 - 55238470938.6092*cos(theta)**22 + 62549445033.4251*cos(theta)**20 - 48507732883.0644*cos(theta)**18 + 26318025287.62*cos(theta)**16 - 10025914395.2838*cos(theta)**14 + 2652204098.75241*cos(theta)**12 - 474377968.882544*cos(theta)**10 + 54735919.4864474*cos(theta)**8 - 3765616.08260572*cos(theta)**6 + 134486.28866449*cos(theta)**4 - 1880.92711418867*cos(theta)**2 + 4.33393344283104)*sin(phi)

#@torch.jit.script
def Yl29_m0(theta, phi):
    return 381236978.781522*cos(theta)**29 - 2715477427.81224*cos(theta)**27 + 8664841610.56452*cos(theta)**25 - 16348757755.7821*cos(theta)**23 + 20275665255.9455*cos(theta)**21 - 17379141647.9533*cos(theta)**19 + 10538415680.1419*cos(theta)**17 - 4549919150.79141*cos(theta)**15 + 1388783461.72412*cos(theta)**13 - 293563983.779083*cos(theta)**11 + 41400048.994486*cos(theta)**9 - 3661920.79558107*cos(theta)**7 + 183096.039779054*cos(theta)**5 - 4267.9729552227*cos(theta)**3 + 29.5021172020002*cos(theta)

#@torch.jit.script
def Yl29_m1(theta, phi):
    return 0.103890645660027*(1.0 - cos(theta)**2)**0.5*(1624134794.78413*cos(theta)**28 - 10770578112.779*cos(theta)**26 + 31822162605.9379*cos(theta)**24 - 55238470938.6092*cos(theta)**22 + 62549445033.4251*cos(theta)**20 - 48507732883.0644*cos(theta)**18 + 26318025287.62*cos(theta)**16 - 10025914395.2838*cos(theta)**14 + 2652204098.75241*cos(theta)**12 - 474377968.882544*cos(theta)**10 + 54735919.4864474*cos(theta)**8 - 3765616.08260572*cos(theta)**6 + 134486.28866449*cos(theta)**4 - 1880.92711418867*cos(theta)**2 + 4.33393344283104)*cos(phi)

#@torch.jit.script
def Yl29_m2(theta, phi):
    return 0.00352627828501722*(1.0 - cos(theta)**2)*(45475774253.9557*cos(theta)**27 - 280035030932.254*cos(theta)**25 + 763731902542.51*cos(theta)**23 - 1215246360649.4*cos(theta)**21 + 1250988900668.5*cos(theta)**19 - 873139191895.159*cos(theta)**17 + 421088404601.921*cos(theta)**15 - 140362801533.974*cos(theta)**13 + 31826449185.0289*cos(theta)**11 - 4743779688.82544*cos(theta)**9 + 437887355.891579*cos(theta)**7 - 22593696.4956343*cos(theta)**5 + 537945.15465796*cos(theta)**3 - 3761.85422837734*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl29_m3(theta, phi):
    return 0.000119966423463177*(1.0 - cos(theta)**2)**1.5*(1227845904856.8*cos(theta)**26 - 7000875773306.34*cos(theta)**24 + 17565833758477.7*cos(theta)**22 - 25520173573637.5*cos(theta)**20 + 23768789112701.5*cos(theta)**18 - 14843366262217.7*cos(theta)**16 + 6316326069028.81*cos(theta)**14 - 1824716419941.66*cos(theta)**12 + 350090941035.318*cos(theta)**10 - 42694017199.429*cos(theta)**8 + 3065211491.24106*cos(theta)**6 - 112968482.478172*cos(theta)**4 + 1613835.46397388*cos(theta)**2 - 3761.85422837734)*cos(3*phi)

#@torch.jit.script
def Yl29_m4(theta, phi):
    return 4.0955861679266e-6*(1.0 - cos(theta)**2)**2*(31923993526276.9*cos(theta)**25 - 168021018559352.0*cos(theta)**23 + 386448342686510.0*cos(theta)**21 - 510403471472749.0*cos(theta)**19 + 427838204028628.0*cos(theta)**17 - 237493860195483.0*cos(theta)**15 + 88428564966403.3*cos(theta)**13 - 21896597039299.9*cos(theta)**11 + 3500909410353.18*cos(theta)**9 - 341552137595.432*cos(theta)**7 + 18391268947.4463*cos(theta)**5 - 451873929.912686*cos(theta)**3 + 3227670.92794776*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl29_m5(theta, phi):
    return 1.40477446625728e-7*(1.0 - cos(theta)**2)**2.5*(798099838156923.0*cos(theta)**24 - 3.8644834268651e+15*cos(theta)**22 + 8.11541519641671e+15*cos(theta)**20 - 9.69766595798223e+15*cos(theta)**18 + 7.27324946848667e+15*cos(theta)**16 - 3.56240790293225e+15*cos(theta)**14 + 1.14957134456324e+15*cos(theta)**12 - 240862567432299.0*cos(theta)**10 + 31508184693178.6*cos(theta)**8 - 2390864963168.02*cos(theta)**6 + 91956344737.2317*cos(theta)**4 - 1355621789.73806*cos(theta)**2 + 3227670.92794776)*cos(5*phi)

#@torch.jit.script
def Yl29_m6(theta, phi):
    return 4.84693238903845e-9*(1.0 - cos(theta)**2)**3*(1.91543961157661e+16*cos(theta)**23 - 8.50186353910322e+16*cos(theta)**21 + 1.62308303928334e+17*cos(theta)**19 - 1.7455798724368e+17*cos(theta)**17 + 1.16371991495787e+17*cos(theta)**15 - 4.98737106410515e+16*cos(theta)**13 + 1.37948561347589e+16*cos(theta)**11 - 2.40862567432299e+15*cos(theta)**9 + 252065477545429.0*cos(theta)**7 - 14345189779008.1*cos(theta)**5 + 367825378948.927*cos(theta)**3 - 2711243579.47612*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl29_m7(theta, phi):
    return 1.68442544512435e-10*(1.0 - cos(theta)**2)**3.5*(4.40551110662621e+17*cos(theta)**22 - 1.78539134321168e+18*cos(theta)**20 + 3.08385777463835e+18*cos(theta)**18 - 2.96748578314256e+18*cos(theta)**16 + 1.7455798724368e+18*cos(theta)**14 - 6.48358238333669e+17*cos(theta)**12 + 1.51743417482348e+17*cos(theta)**10 - 2.16776310689069e+16*cos(theta)**8 + 1.764458342818e+15*cos(theta)**6 - 71725948895040.7*cos(theta)**4 + 1103476136846.78*cos(theta)**2 - 2711243579.47612)*cos(7*phi)

#@torch.jit.script
def Yl29_m8(theta, phi):
    return 5.90390812988918e-12*(1.0 - cos(theta)**2)**4*(9.69212443457767e+18*cos(theta)**21 - 3.57078268642335e+19*cos(theta)**19 + 5.55094399434903e+19*cos(theta)**17 - 4.7479772530281e+19*cos(theta)**15 + 2.44381182141152e+19*cos(theta)**13 - 7.78029886000403e+18*cos(theta)**11 + 1.51743417482348e+18*cos(theta)**9 - 1.73421048551255e+17*cos(theta)**7 + 1.0586750056908e+16*cos(theta)**5 - 286903795580163.0*cos(theta)**3 + 2206952273693.56*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl29_m9(theta, phi):
    return 2.08996082292824e-13*(1.0 - cos(theta)**2)**4.5*(2.03534613126131e+20*cos(theta)**20 - 6.78448710420437e+20*cos(theta)**18 + 9.43660479039335e+20*cos(theta)**16 - 7.12196587954215e+20*cos(theta)**14 + 3.17695536783498e+20*cos(theta)**12 - 8.55832874600443e+19*cos(theta)**10 + 1.36569075734113e+19*cos(theta)**8 - 1.21394733985879e+18*cos(theta)**6 + 5.293375028454e+16*cos(theta)**4 - 860711386740489.0*cos(theta)**2 + 2206952273693.56)*cos(9*phi)

#@torch.jit.script
def Yl29_m10(theta, phi):
    return 7.48326015729302e-15*(1.0 - cos(theta)**2)**5*(4.07069226252262e+21*cos(theta)**19 - 1.22120767875679e+22*cos(theta)**17 + 1.50985676646294e+22*cos(theta)**15 - 9.97075223135901e+21*cos(theta)**13 + 3.81234644140198e+21*cos(theta)**11 - 8.55832874600443e+20*cos(theta)**9 + 1.09255260587291e+20*cos(theta)**7 - 7.28368403915271e+18*cos(theta)**5 + 2.1173500113816e+17*cos(theta)**3 - 1.72142277348098e+15*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl29_m11(theta, phi):
    return 2.7144637587553e-16*(1.0 - cos(theta)**2)**5.5*(7.73431529879298e+22*cos(theta)**18 - 2.07605305388654e+23*cos(theta)**16 + 2.2647851496944e+23*cos(theta)**14 - 1.29619779007667e+23*cos(theta)**12 + 4.19358108554217e+22*cos(theta)**10 - 7.70249587140399e+21*cos(theta)**8 + 7.64786824111034e+20*cos(theta)**6 - 3.64184201957635e+19*cos(theta)**4 + 6.35205003414481e+17*cos(theta)**2 - 1.72142277348098e+15)*cos(11*phi)

#@torch.jit.script
def Yl29_m12(theta, phi):
    return 9.99207917847372e-18*(1.0 - cos(theta)**2)**6*(1.39217675378274e+24*cos(theta)**17 - 3.32168488621846e+24*cos(theta)**15 + 3.17069920957217e+24*cos(theta)**13 - 1.55543734809201e+24*cos(theta)**11 + 4.19358108554217e+23*cos(theta)**9 - 6.16199669712319e+22*cos(theta)**7 + 4.58872094466621e+21*cos(theta)**5 - 1.45673680783054e+20*cos(theta)**3 + 1.27041000682896e+18*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl29_m13(theta, phi):
    return 3.7394416498704e-19*(1.0 - cos(theta)**2)**6.5*(2.36670048143065e+25*cos(theta)**16 - 4.98252732932769e+25*cos(theta)**14 + 4.12190897244381e+25*cos(theta)**12 - 1.71098108290121e+25*cos(theta)**10 + 3.77422297698796e+24*cos(theta)**8 - 4.31339768798623e+23*cos(theta)**6 + 2.2943604723331e+22*cos(theta)**4 - 4.37021042349163e+20*cos(theta)**2 + 1.27041000682896e+18)*cos(13*phi)

#@torch.jit.script
def Yl29_m14(theta, phi):
    return 1.42564876361858e-20*(1.0 - cos(theta)**2)**7*(3.78672077028904e+26*cos(theta)**15 - 6.97553826105876e+26*cos(theta)**13 + 4.94629076693258e+26*cos(theta)**11 - 1.71098108290121e+26*cos(theta)**9 + 3.01937838159036e+25*cos(theta)**7 - 2.58803861279174e+24*cos(theta)**5 + 9.17744188933241e+22*cos(theta)**3 - 8.74042084698325e+20*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl29_m15(theta, phi):
    return 5.54933028611123e-22*(1.0 - cos(theta)**2)**7.5*(5.68008115543357e+27*cos(theta)**14 - 9.06819973937639e+27*cos(theta)**12 + 5.44091984362584e+27*cos(theta)**10 - 1.53988297461109e+27*cos(theta)**8 + 2.11356486711325e+26*cos(theta)**6 - 1.29401930639587e+25*cos(theta)**4 + 2.75323256679972e+23*cos(theta)**2 - 8.74042084698325e+20)*cos(15*phi)

#@torch.jit.script
def Yl29_m16(theta, phi):
    return 2.21090610686865e-23*(1.0 - cos(theta)**2)**8*(7.95211361760699e+28*cos(theta)**13 - 1.08818396872517e+29*cos(theta)**11 + 5.44091984362584e+28*cos(theta)**9 - 1.23190637968887e+28*cos(theta)**7 + 1.26813892026795e+27*cos(theta)**5 - 5.17607722558348e+25*cos(theta)**3 + 5.50646513359945e+23*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl29_m17(theta, phi):
    return 9.04106740874383e-25*(1.0 - cos(theta)**2)**8.5*(1.03377477028891e+30*cos(theta)**12 - 1.19700236559768e+30*cos(theta)**10 + 4.89682785926325e+29*cos(theta)**8 - 8.62334465782208e+28*cos(theta)**6 + 6.34069460133976e+27*cos(theta)**4 - 1.55282316767504e+26*cos(theta)**2 + 5.50646513359945e+23)*cos(17*phi)

#@torch.jit.script
def Yl29_m18(theta, phi):
    return 3.80697614338276e-26*(1.0 - cos(theta)**2)**9*(1.24052972434669e+31*cos(theta)**11 - 1.19700236559768e+31*cos(theta)**9 + 3.9174622874106e+30*cos(theta)**7 - 5.17400679469325e+29*cos(theta)**5 + 2.53627784053591e+28*cos(theta)**3 - 3.10564633535009e+26*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl29_m19(theta, phi):
    return 1.65677370829833e-27*(1.0 - cos(theta)**2)**9.5*(1.36458269678136e+32*cos(theta)**10 - 1.07730212903792e+32*cos(theta)**8 + 2.74222360118742e+31*cos(theta)**6 - 2.58700339734662e+30*cos(theta)**4 + 7.60883352160772e+28*cos(theta)**2 - 3.10564633535009e+26)*cos(19*phi)

#@torch.jit.script
def Yl29_m20(theta, phi):
    return 7.48454069386591e-29*(1.0 - cos(theta)**2)**10*(1.36458269678136e+33*cos(theta)**9 - 8.61841703230333e+32*cos(theta)**7 + 1.64533416071245e+32*cos(theta)**5 - 1.03480135893865e+31*cos(theta)**3 + 1.52176670432154e+29*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl29_m21(theta, phi):
    return 3.52824631913283e-30*(1.0 - cos(theta)**2)**10.5*(1.22812442710322e+34*cos(theta)**8 - 6.03289192261233e+33*cos(theta)**6 + 8.22667080356226e+32*cos(theta)**4 - 3.10440407681595e+31*cos(theta)**2 + 1.52176670432154e+29)*cos(21*phi)

#@torch.jit.script
def Yl29_m22(theta, phi):
    return 1.74674221195294e-31*(1.0 - cos(theta)**2)**11*(9.82499541682579e+34*cos(theta)**7 - 3.6197351535674e+34*cos(theta)**5 + 3.29066832142491e+33*cos(theta)**3 - 6.2088081536319e+31*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl29_m23(theta, phi):
    return 9.15541687226183e-33*(1.0 - cos(theta)**2)**11.5*(6.87749679177805e+35*cos(theta)**6 - 1.8098675767837e+35*cos(theta)**4 + 9.87200496427472e+33*cos(theta)**2 - 6.2088081536319e+31)*cos(23*phi)

#@torch.jit.script
def Yl29_m24(theta, phi):
    return 5.13410284106891e-34*(1.0 - cos(theta)**2)**12*(4.12649807506683e+36*cos(theta)**5 - 7.23947030713479e+35*cos(theta)**3 + 1.97440099285494e+34*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl29_m25(theta, phi):
    return 3.12451548733867e-35*(1.0 - cos(theta)**2)**12.5*(2.06324903753342e+37*cos(theta)**4 - 2.17184109214044e+36*cos(theta)**2 + 1.97440099285494e+34)*cos(25*phi)

#@torch.jit.script
def Yl29_m26(theta, phi):
    return 2.106547911828e-36*(1.0 - cos(theta)**2)**13*(8.25299615013366e+37*cos(theta)**3 - 4.34368218428088e+36*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl29_m27(theta, phi):
    return 1.62523699825355e-37*(1.0 - cos(theta)**2)**13.5*(2.4758988450401e+38*cos(theta)**2 - 4.34368218428088e+36)*cos(27*phi)

#@torch.jit.script
def Yl29_m28(theta, phi):
    return 7.53749726640217*(1.0 - cos(theta)**2)**14*cos(28*phi)*cos(theta)

#@torch.jit.script
def Yl29_m29(theta, phi):
    return 0.989721878741179*(1.0 - cos(theta)**2)**14.5*cos(29*phi)

#@torch.jit.script
def Yl30_m_minus_30(theta, phi):
    return 0.997935479150139*(1.0 - cos(theta)**2)**15*sin(30*phi)

#@torch.jit.script
def Yl30_m_minus_29(theta, phi):
    return 7.72997498267602*(1.0 - cos(theta)**2)**14.5*sin(29*phi)*cos(theta)

#@torch.jit.script
def Yl30_m_minus_28(theta, phi):
    return 2.87411530575892e-39*(1.0 - cos(theta)**2)**14*(1.46078031857366e+40*cos(theta)**2 - 2.4758988450401e+38)*sin(28*phi)

#@torch.jit.script
def Yl30_m_minus_27(theta, phi):
    return 3.79121847114987e-38*(1.0 - cos(theta)**2)**13.5*(4.86926772857886e+39*cos(theta)**3 - 2.4758988450401e+38*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl30_m_minus_26(theta, phi):
    return 5.72461435302436e-37*(1.0 - cos(theta)**2)**13*(1.21731693214472e+39*cos(theta)**4 - 1.23794942252005e+38*cos(theta)**2 + 1.08592054607022e+36)*sin(26*phi)

#@torch.jit.script
def Yl30_m_minus_25(theta, phi):
    return 9.57911199299742e-36*(1.0 - cos(theta)**2)**12.5*(2.43463386428943e+38*cos(theta)**5 - 4.12649807506683e+37*cos(theta)**3 + 1.08592054607022e+36*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl30_m_minus_24(theta, phi):
    return 1.74013210905229e-34*(1.0 - cos(theta)**2)**12*(4.05772310714905e+37*cos(theta)**6 - 1.03162451876671e+37*cos(theta)**4 + 5.42960273035109e+35*cos(theta)**2 - 3.29066832142491e+33)*sin(24*phi)

#@torch.jit.script
def Yl30_m_minus_23(theta, phi):
    return 3.38320349392245e-33*(1.0 - cos(theta)**2)**11.5*(5.79674729592722e+36*cos(theta)**7 - 2.06324903753342e+36*cos(theta)**5 + 1.8098675767837e+35*cos(theta)**3 - 3.29066832142491e+33*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl30_m_minus_22(theta, phi):
    return 6.96644237302409e-32*(1.0 - cos(theta)**2)**11*(7.24593411990902e+35*cos(theta)**8 - 3.43874839588903e+35*cos(theta)**6 + 4.52466894195925e+34*cos(theta)**4 - 1.64533416071245e+33*cos(theta)**2 + 7.76101019203987e+30)*sin(22*phi)

#@torch.jit.script
def Yl30_m_minus_21(theta, phi):
    return 1.5070719110102e-30*(1.0 - cos(theta)**2)**10.5*(8.05103791101002e+34*cos(theta)**9 - 4.9124977084129e+34*cos(theta)**7 + 9.04933788391849e+33*cos(theta)**5 - 5.48444720237484e+32*cos(theta)**3 + 7.76101019203987e+30*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl30_m_minus_20(theta, phi):
    return 3.40344756082348e-29*(1.0 - cos(theta)**2)**10*(8.05103791101002e+33*cos(theta)**10 - 6.14062213551612e+33*cos(theta)**8 + 1.50822298065308e+33*cos(theta)**6 - 1.37111180059371e+32*cos(theta)**4 + 3.88050509601994e+30*cos(theta)**2 - 1.52176670432154e+28)*sin(20*phi)

#@torch.jit.script
def Yl30_m_minus_19(theta, phi):
    return 7.98179203850954e-28*(1.0 - cos(theta)**2)**9.5*(7.31912537364547e+32*cos(theta)**11 - 6.8229134839068e+32*cos(theta)**9 + 2.15460425807583e+32*cos(theta)**7 - 2.74222360118742e+31*cos(theta)**5 + 1.29350169867331e+30*cos(theta)**3 - 1.52176670432154e+28*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl30_m_minus_18(theta, phi):
    return 1.93548170846062e-26*(1.0 - cos(theta)**2)**9*(6.09927114470456e+31*cos(theta)**12 - 6.8229134839068e+31*cos(theta)**10 + 2.69325532259479e+31*cos(theta)**8 - 4.5703726686457e+30*cos(theta)**6 + 3.23375424668328e+29*cos(theta)**4 - 7.60883352160772e+27*cos(theta)**2 + 2.58803861279174e+25)*sin(18*phi)

#@torch.jit.script
def Yl30_m_minus_17(theta, phi):
    return 4.83483175810931e-25*(1.0 - cos(theta)**2)**8.5*(4.69174703438813e+30*cos(theta)**13 - 6.20264862173345e+30*cos(theta)**11 + 2.99250591399421e+30*cos(theta)**9 - 6.529103812351e+29*cos(theta)**7 + 6.46750849336656e+28*cos(theta)**5 - 2.53627784053591e+27*cos(theta)**3 + 2.58803861279174e+25*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl30_m_minus_16(theta, phi):
    return 1.24020738463486e-23*(1.0 - cos(theta)**2)**8*(3.3512478817058e+29*cos(theta)**14 - 5.16887385144454e+29*cos(theta)**12 + 2.99250591399421e+29*cos(theta)**10 - 8.16137976543875e+28*cos(theta)**8 + 1.07791808222776e+28*cos(theta)**6 - 6.34069460133976e+26*cos(theta)**4 + 1.29401930639587e+25*cos(theta)**2 - 3.93318938114246e+22)*sin(16*phi)

#@torch.jit.script
def Yl30_m_minus_15(theta, phi):
    return 3.25775828793813e-22*(1.0 - cos(theta)**2)**7.5*(2.23416525447054e+28*cos(theta)**15 - 3.9760568088035e+28*cos(theta)**13 + 2.72045992181292e+28*cos(theta)**11 - 9.06819973937639e+27*cos(theta)**9 + 1.53988297461109e+27*cos(theta)**7 - 1.26813892026795e+26*cos(theta)**5 + 4.31339768798623e+24*cos(theta)**3 - 3.93318938114246e+22*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl30_m_minus_14(theta, phi):
    return 8.74148278331158e-21*(1.0 - cos(theta)**2)**7*(1.39635328404408e+27*cos(theta)**16 - 2.84004057771678e+27*cos(theta)**14 + 2.2670499348441e+27*cos(theta)**12 - 9.06819973937639e+26*cos(theta)**10 + 1.92485371826386e+26*cos(theta)**8 - 2.11356486711326e+25*cos(theta)**6 + 1.07834942199656e+24*cos(theta)**4 - 1.96659469057123e+22*cos(theta)**2 + 5.46276302936453e+19)*sin(14*phi)

#@torch.jit.script
def Yl30_m_minus_13(theta, phi):
    return 2.39075958422627e-19*(1.0 - cos(theta)**2)**6.5*(8.21384284731815e+25*cos(theta)**17 - 1.89336038514452e+26*cos(theta)**15 + 1.74388456526469e+26*cos(theta)**13 - 8.24381794488763e+25*cos(theta)**11 + 2.13872635362651e+25*cos(theta)**9 - 3.01937838159036e+24*cos(theta)**7 + 2.15669884399312e+23*cos(theta)**5 - 6.55531563523744e+21*cos(theta)**3 + 5.46276302936453e+19*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl30_m_minus_12(theta, phi):
    return 6.65129768956931e-18*(1.0 - cos(theta)**2)**6*(4.56324602628786e+24*cos(theta)**18 - 1.18335024071533e+25*cos(theta)**16 + 1.24563183233192e+25*cos(theta)**14 - 6.86984828740636e+24*cos(theta)**12 + 2.13872635362651e+24*cos(theta)**10 - 3.77422297698795e+23*cos(theta)**8 + 3.59449807332186e+22*cos(theta)**6 - 1.63882890880936e+21*cos(theta)**4 + 2.73138151468227e+19*cos(theta)**2 - 7.05783337127201e+16)*sin(12*phi)

#@torch.jit.script
def Yl30_m_minus_11(theta, phi):
    return 1.87891801956087e-16*(1.0 - cos(theta)**2)**5.5*(2.40170843488835e+23*cos(theta)**19 - 6.96088376891368e+23*cos(theta)**17 + 8.30421221554615e+23*cos(theta)**15 - 5.28449868262028e+23*cos(theta)**13 + 1.94429668511501e+23*cos(theta)**11 - 4.19358108554217e+22*cos(theta)**9 + 5.13499724760266e+21*cos(theta)**7 - 3.27765781761872e+20*cos(theta)**5 + 9.10460504894089e+18*cos(theta)**3 - 7.05783337127201e+16*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl30_m_minus_10(theta, phi):
    return 5.38040239932763e-15*(1.0 - cos(theta)**2)**5*(1.20085421744417e+22*cos(theta)**20 - 3.86715764939649e+22*cos(theta)**18 + 5.19013263471634e+22*cos(theta)**16 - 3.77464191615734e+22*cos(theta)**14 + 1.62024723759584e+22*cos(theta)**12 - 4.19358108554217e+21*cos(theta)**10 + 6.41874655950332e+20*cos(theta)**8 - 5.46276302936453e+19*cos(theta)**6 + 2.27615126223522e+18*cos(theta)**4 - 3.528916685636e+16*cos(theta)**2 + 86071138674048.8)*sin(10*phi)

#@torch.jit.script
def Yl30_m_minus_9(theta, phi):
    return 1.55938876429517e-13*(1.0 - cos(theta)**2)**4.5*(5.71835341640083e+20*cos(theta)**21 - 2.03534613126131e+21*cos(theta)**19 + 3.05301919689197e+21*cos(theta)**17 - 2.51642794410489e+21*cos(theta)**15 + 1.24634402891988e+21*cos(theta)**13 - 3.81234644140197e+20*cos(theta)**11 + 7.13194062167036e+19*cos(theta)**9 - 7.80394718480647e+18*cos(theta)**7 + 4.55230252447044e+17*cos(theta)**5 - 1.17630556187867e+16*cos(theta)**3 + 86071138674048.8*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl30_m_minus_8(theta, phi):
    return 4.56770496751288e-12*(1.0 - cos(theta)**2)**4*(2.59925155290947e+19*cos(theta)**22 - 1.01767306563066e+20*cos(theta)**20 + 1.69612177605109e+20*cos(theta)**18 - 1.57276746506556e+20*cos(theta)**16 + 8.90245734942769e+19*cos(theta)**14 - 3.17695536783498e+19*cos(theta)**12 + 7.13194062167036e+18*cos(theta)**10 - 9.75493398100809e+17*cos(theta)**8 + 7.58717087411741e+16*cos(theta)**6 - 2.94076390469667e+15*cos(theta)**4 + 43035569337024.4*cos(theta)**2 - 100316012440.616)*sin(8*phi)

#@torch.jit.script
def Yl30_m_minus_7(theta, phi):
    return 1.3503730468945e-10*(1.0 - cos(theta)**2)**3.5*(1.1301093708302e+18*cos(theta)**23 - 4.84606221728884e+18*cos(theta)**21 + 8.92695671605838e+18*cos(theta)**19 - 9.25157332391505e+18*cos(theta)**17 + 5.93497156628513e+18*cos(theta)**15 - 2.44381182141152e+18*cos(theta)**13 + 6.48358238333669e+17*cos(theta)**11 - 1.08388155344534e+17*cos(theta)**9 + 1.08388155344534e+16*cos(theta)**7 - 588152780939334.0*cos(theta)**5 + 14345189779008.1*cos(theta)**3 - 100316012440.616*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl30_m_minus_6(theta, phi):
    return 4.02402104966148e-9*(1.0 - cos(theta)**2)**3*(4.70878904512584e+16*cos(theta)**24 - 2.20275555331311e+17*cos(theta)**22 + 4.46347835802919e+17*cos(theta)**20 - 5.13976295773058e+17*cos(theta)**18 + 3.7093572289282e+17*cos(theta)**16 - 1.7455798724368e+17*cos(theta)**14 + 5.40298531944724e+16*cos(theta)**12 - 1.08388155344534e+16*cos(theta)**10 + 1.35485194180668e+15*cos(theta)**8 - 98025463489889.0*cos(theta)**6 + 3586297444752.04*cos(theta)**4 - 50158006220.3082*cos(theta)**2 + 112968482.478172)*sin(6*phi)

#@torch.jit.script
def Yl30_m_minus_5(theta, phi):
    return 1.20720631489845e-7*(1.0 - cos(theta)**2)**2.5*(1.88351561805034e+15*cos(theta)**25 - 9.57719805788307e+15*cos(theta)**23 + 2.1254658847758e+16*cos(theta)**21 - 2.70513839880557e+16*cos(theta)**19 + 2.181974840546e+16*cos(theta)**17 - 1.16371991495787e+16*cos(theta)**15 + 4.15614255342096e+15*cos(theta)**13 - 985346866768494.0*cos(theta)**11 + 150539104645187.0*cos(theta)**9 - 14003637641412.7*cos(theta)**7 + 717259488950.407*cos(theta)**5 - 16719335406.7694*cos(theta)**3 + 112968482.478172*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl30_m_minus_4(theta, phi):
    return 3.64168346911826e-6*(1.0 - cos(theta)**2)**2*(72442908386551.5*cos(theta)**26 - 399049919078461.0*cos(theta)**24 + 966120856716275.0*cos(theta)**22 - 1.35256919940279e+15*cos(theta)**20 + 1.21220824474778e+15*cos(theta)**18 - 727324946848667.0*cos(theta)**16 + 296867325244354.0*cos(theta)**14 - 82112238897374.5*cos(theta)**12 + 15053910464518.7*cos(theta)**10 - 1750454705176.59*cos(theta)**8 + 119543248158.401*cos(theta)**6 - 4179833851.69235*cos(theta)**4 + 56484241.2390858*cos(theta)**2 - 124141.189536452)*sin(4*phi)

#@torch.jit.script
def Yl30_m_minus_3(theta, phi):
    return 0.000110337600540934*(1.0 - cos(theta)**2)**1.5*(2683070680983.39*cos(theta)**27 - 15961996763138.5*cos(theta)**25 + 42005254639838.0*cos(theta)**23 - 64408057114418.3*cos(theta)**21 + 63800433934093.6*cos(theta)**19 - 42783820402862.8*cos(theta)**17 + 19791155016290.3*cos(theta)**15 - 6316326069028.81*cos(theta)**13 + 1368537314956.24*cos(theta)**11 - 194494967241.843*cos(theta)**9 + 17077606879.7716*cos(theta)**7 - 835966770.33847*cos(theta)**5 + 18828080.4130286*cos(theta)**3 - 124141.189536452*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl30_m_minus_2(theta, phi):
    return 0.00335397268176902*(1.0 - cos(theta)**2)*(95823952892.2638*cos(theta)**28 - 613922952428.402*cos(theta)**26 + 1750218943326.59*cos(theta)**24 - 2927638959746.29*cos(theta)**22 + 3190021696704.68*cos(theta)**20 - 2376878911270.15*cos(theta)**18 + 1236947188518.14*cos(theta)**16 - 451166147787.772*cos(theta)**14 + 114044776246.354*cos(theta)**12 - 19449496724.1843*cos(theta)**10 + 2134700859.97145*cos(theta)**8 - 139327795.056412*cos(theta)**6 + 4707020.10325715*cos(theta)**4 - 62070.5947682261*cos(theta)**2 + 134.351936727762)*sin(2*phi)

#@torch.jit.script
def Yl30_m_minus_1(theta, phi):
    return 0.102172379790475*(1.0 - cos(theta)**2)**0.5*(3304274237.66427*cos(theta)**29 - 22737887126.9779*cos(theta)**27 + 70008757733.0634*cos(theta)**25 - 127288650423.752*cos(theta)**23 + 151905795081.175*cos(theta)**21 - 125098890066.85*cos(theta)**19 + 72761599324.5966*cos(theta)**17 - 30077743185.8515*cos(theta)**15 + 8772675095.87335*cos(theta)**13 - 1768136065.83494*cos(theta)**11 + 237188984.441272*cos(theta)**9 - 19903970.7223445*cos(theta)**7 + 941404.02065143*cos(theta)**5 - 20690.1982560754*cos(theta)**3 + 134.351936727762*cos(theta))*sin(phi)

#@torch.jit.script
def Yl30_m0(theta, phi):
    return 762368051.047141*cos(theta)**30 - 5620849189.92384*cos(theta)**28 + 18637552577.1159*cos(theta)**26 - 36710330833.7131*cos(theta)**24 + 47792694858.985*cos(theta)**22 - 43294558872.257*cos(theta)**20 + 27979476822.2069*cos(theta)**18 - 13011732382.3637*cos(theta)**16 + 4337244127.45456*cos(theta)**14 - 1019868774.15598*cos(theta)**12 + 164173997.790963*cos(theta)**10 - 17221048.7193318*cos(theta)**8 + 1086012.0813993*cos(theta)**6 - 35802.5960900869*cos(theta)**4 + 464.968780390739*cos(theta)**2 - 0.999932861055352

#@torch.jit.script
def Yl30_m1(theta, phi):
    return 0.102172379790475*(1.0 - cos(theta)**2)**0.5*(3304274237.66427*cos(theta)**29 - 22737887126.9779*cos(theta)**27 + 70008757733.0634*cos(theta)**25 - 127288650423.752*cos(theta)**23 + 151905795081.175*cos(theta)**21 - 125098890066.85*cos(theta)**19 + 72761599324.5966*cos(theta)**17 - 30077743185.8515*cos(theta)**15 + 8772675095.87335*cos(theta)**13 - 1768136065.83494*cos(theta)**11 + 237188984.441272*cos(theta)**9 - 19903970.7223445*cos(theta)**7 + 941404.02065143*cos(theta)**5 - 20690.1982560754*cos(theta)**3 + 134.351936727762*cos(theta))*cos(phi)

#@torch.jit.script
def Yl30_m2(theta, phi):
    return 0.00335397268176902*(1.0 - cos(theta)**2)*(95823952892.2638*cos(theta)**28 - 613922952428.402*cos(theta)**26 + 1750218943326.59*cos(theta)**24 - 2927638959746.29*cos(theta)**22 + 3190021696704.68*cos(theta)**20 - 2376878911270.15*cos(theta)**18 + 1236947188518.14*cos(theta)**16 - 451166147787.772*cos(theta)**14 + 114044776246.354*cos(theta)**12 - 19449496724.1843*cos(theta)**10 + 2134700859.97145*cos(theta)**8 - 139327795.056412*cos(theta)**6 + 4707020.10325715*cos(theta)**4 - 62070.5947682261*cos(theta)**2 + 134.351936727762)*cos(2*phi)

#@torch.jit.script
def Yl30_m3(theta, phi):
    return 0.000110337600540934*(1.0 - cos(theta)**2)**1.5*(2683070680983.39*cos(theta)**27 - 15961996763138.5*cos(theta)**25 + 42005254639838.0*cos(theta)**23 - 64408057114418.3*cos(theta)**21 + 63800433934093.6*cos(theta)**19 - 42783820402862.8*cos(theta)**17 + 19791155016290.3*cos(theta)**15 - 6316326069028.81*cos(theta)**13 + 1368537314956.24*cos(theta)**11 - 194494967241.843*cos(theta)**9 + 17077606879.7716*cos(theta)**7 - 835966770.33847*cos(theta)**5 + 18828080.4130286*cos(theta)**3 - 124141.189536452*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl30_m4(theta, phi):
    return 3.64168346911826e-6*(1.0 - cos(theta)**2)**2*(72442908386551.5*cos(theta)**26 - 399049919078461.0*cos(theta)**24 + 966120856716275.0*cos(theta)**22 - 1.35256919940279e+15*cos(theta)**20 + 1.21220824474778e+15*cos(theta)**18 - 727324946848667.0*cos(theta)**16 + 296867325244354.0*cos(theta)**14 - 82112238897374.5*cos(theta)**12 + 15053910464518.7*cos(theta)**10 - 1750454705176.59*cos(theta)**8 + 119543248158.401*cos(theta)**6 - 4179833851.69235*cos(theta)**4 + 56484241.2390858*cos(theta)**2 - 124141.189536452)*cos(4*phi)

#@torch.jit.script
def Yl30_m5(theta, phi):
    return 1.20720631489845e-7*(1.0 - cos(theta)**2)**2.5*(1.88351561805034e+15*cos(theta)**25 - 9.57719805788307e+15*cos(theta)**23 + 2.1254658847758e+16*cos(theta)**21 - 2.70513839880557e+16*cos(theta)**19 + 2.181974840546e+16*cos(theta)**17 - 1.16371991495787e+16*cos(theta)**15 + 4.15614255342096e+15*cos(theta)**13 - 985346866768494.0*cos(theta)**11 + 150539104645187.0*cos(theta)**9 - 14003637641412.7*cos(theta)**7 + 717259488950.407*cos(theta)**5 - 16719335406.7694*cos(theta)**3 + 112968482.478172*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl30_m6(theta, phi):
    return 4.02402104966148e-9*(1.0 - cos(theta)**2)**3*(4.70878904512584e+16*cos(theta)**24 - 2.20275555331311e+17*cos(theta)**22 + 4.46347835802919e+17*cos(theta)**20 - 5.13976295773058e+17*cos(theta)**18 + 3.7093572289282e+17*cos(theta)**16 - 1.7455798724368e+17*cos(theta)**14 + 5.40298531944724e+16*cos(theta)**12 - 1.08388155344534e+16*cos(theta)**10 + 1.35485194180668e+15*cos(theta)**8 - 98025463489889.0*cos(theta)**6 + 3586297444752.04*cos(theta)**4 - 50158006220.3082*cos(theta)**2 + 112968482.478172)*cos(6*phi)

#@torch.jit.script
def Yl30_m7(theta, phi):
    return 1.3503730468945e-10*(1.0 - cos(theta)**2)**3.5*(1.1301093708302e+18*cos(theta)**23 - 4.84606221728884e+18*cos(theta)**21 + 8.92695671605838e+18*cos(theta)**19 - 9.25157332391505e+18*cos(theta)**17 + 5.93497156628513e+18*cos(theta)**15 - 2.44381182141152e+18*cos(theta)**13 + 6.48358238333669e+17*cos(theta)**11 - 1.08388155344534e+17*cos(theta)**9 + 1.08388155344534e+16*cos(theta)**7 - 588152780939334.0*cos(theta)**5 + 14345189779008.1*cos(theta)**3 - 100316012440.616*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl30_m8(theta, phi):
    return 4.56770496751288e-12*(1.0 - cos(theta)**2)**4*(2.59925155290947e+19*cos(theta)**22 - 1.01767306563066e+20*cos(theta)**20 + 1.69612177605109e+20*cos(theta)**18 - 1.57276746506556e+20*cos(theta)**16 + 8.90245734942769e+19*cos(theta)**14 - 3.17695536783498e+19*cos(theta)**12 + 7.13194062167036e+18*cos(theta)**10 - 9.75493398100809e+17*cos(theta)**8 + 7.58717087411741e+16*cos(theta)**6 - 2.94076390469667e+15*cos(theta)**4 + 43035569337024.4*cos(theta)**2 - 100316012440.616)*cos(8*phi)

#@torch.jit.script
def Yl30_m9(theta, phi):
    return 1.55938876429517e-13*(1.0 - cos(theta)**2)**4.5*(5.71835341640083e+20*cos(theta)**21 - 2.03534613126131e+21*cos(theta)**19 + 3.05301919689197e+21*cos(theta)**17 - 2.51642794410489e+21*cos(theta)**15 + 1.24634402891988e+21*cos(theta)**13 - 3.81234644140197e+20*cos(theta)**11 + 7.13194062167036e+19*cos(theta)**9 - 7.80394718480647e+18*cos(theta)**7 + 4.55230252447044e+17*cos(theta)**5 - 1.17630556187867e+16*cos(theta)**3 + 86071138674048.8*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl30_m10(theta, phi):
    return 5.38040239932763e-15*(1.0 - cos(theta)**2)**5*(1.20085421744417e+22*cos(theta)**20 - 3.86715764939649e+22*cos(theta)**18 + 5.19013263471634e+22*cos(theta)**16 - 3.77464191615734e+22*cos(theta)**14 + 1.62024723759584e+22*cos(theta)**12 - 4.19358108554217e+21*cos(theta)**10 + 6.41874655950332e+20*cos(theta)**8 - 5.46276302936453e+19*cos(theta)**6 + 2.27615126223522e+18*cos(theta)**4 - 3.528916685636e+16*cos(theta)**2 + 86071138674048.8)*cos(10*phi)

#@torch.jit.script
def Yl30_m11(theta, phi):
    return 1.87891801956087e-16*(1.0 - cos(theta)**2)**5.5*(2.40170843488835e+23*cos(theta)**19 - 6.96088376891368e+23*cos(theta)**17 + 8.30421221554615e+23*cos(theta)**15 - 5.28449868262028e+23*cos(theta)**13 + 1.94429668511501e+23*cos(theta)**11 - 4.19358108554217e+22*cos(theta)**9 + 5.13499724760266e+21*cos(theta)**7 - 3.27765781761872e+20*cos(theta)**5 + 9.10460504894089e+18*cos(theta)**3 - 7.05783337127201e+16*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl30_m12(theta, phi):
    return 6.65129768956931e-18*(1.0 - cos(theta)**2)**6*(4.56324602628786e+24*cos(theta)**18 - 1.18335024071533e+25*cos(theta)**16 + 1.24563183233192e+25*cos(theta)**14 - 6.86984828740636e+24*cos(theta)**12 + 2.13872635362651e+24*cos(theta)**10 - 3.77422297698795e+23*cos(theta)**8 + 3.59449807332186e+22*cos(theta)**6 - 1.63882890880936e+21*cos(theta)**4 + 2.73138151468227e+19*cos(theta)**2 - 7.05783337127201e+16)*cos(12*phi)

#@torch.jit.script
def Yl30_m13(theta, phi):
    return 2.39075958422627e-19*(1.0 - cos(theta)**2)**6.5*(8.21384284731815e+25*cos(theta)**17 - 1.89336038514452e+26*cos(theta)**15 + 1.74388456526469e+26*cos(theta)**13 - 8.24381794488763e+25*cos(theta)**11 + 2.13872635362651e+25*cos(theta)**9 - 3.01937838159036e+24*cos(theta)**7 + 2.15669884399312e+23*cos(theta)**5 - 6.55531563523744e+21*cos(theta)**3 + 5.46276302936453e+19*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl30_m14(theta, phi):
    return 8.74148278331158e-21*(1.0 - cos(theta)**2)**7*(1.39635328404408e+27*cos(theta)**16 - 2.84004057771678e+27*cos(theta)**14 + 2.2670499348441e+27*cos(theta)**12 - 9.06819973937639e+26*cos(theta)**10 + 1.92485371826386e+26*cos(theta)**8 - 2.11356486711326e+25*cos(theta)**6 + 1.07834942199656e+24*cos(theta)**4 - 1.96659469057123e+22*cos(theta)**2 + 5.46276302936453e+19)*cos(14*phi)

#@torch.jit.script
def Yl30_m15(theta, phi):
    return 3.25775828793813e-22*(1.0 - cos(theta)**2)**7.5*(2.23416525447054e+28*cos(theta)**15 - 3.9760568088035e+28*cos(theta)**13 + 2.72045992181292e+28*cos(theta)**11 - 9.06819973937639e+27*cos(theta)**9 + 1.53988297461109e+27*cos(theta)**7 - 1.26813892026795e+26*cos(theta)**5 + 4.31339768798623e+24*cos(theta)**3 - 3.93318938114246e+22*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl30_m16(theta, phi):
    return 1.24020738463486e-23*(1.0 - cos(theta)**2)**8*(3.3512478817058e+29*cos(theta)**14 - 5.16887385144454e+29*cos(theta)**12 + 2.99250591399421e+29*cos(theta)**10 - 8.16137976543875e+28*cos(theta)**8 + 1.07791808222776e+28*cos(theta)**6 - 6.34069460133976e+26*cos(theta)**4 + 1.29401930639587e+25*cos(theta)**2 - 3.93318938114246e+22)*cos(16*phi)

#@torch.jit.script
def Yl30_m17(theta, phi):
    return 4.83483175810931e-25*(1.0 - cos(theta)**2)**8.5*(4.69174703438813e+30*cos(theta)**13 - 6.20264862173345e+30*cos(theta)**11 + 2.99250591399421e+30*cos(theta)**9 - 6.529103812351e+29*cos(theta)**7 + 6.46750849336656e+28*cos(theta)**5 - 2.53627784053591e+27*cos(theta)**3 + 2.58803861279174e+25*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl30_m18(theta, phi):
    return 1.93548170846062e-26*(1.0 - cos(theta)**2)**9*(6.09927114470456e+31*cos(theta)**12 - 6.8229134839068e+31*cos(theta)**10 + 2.69325532259479e+31*cos(theta)**8 - 4.5703726686457e+30*cos(theta)**6 + 3.23375424668328e+29*cos(theta)**4 - 7.60883352160772e+27*cos(theta)**2 + 2.58803861279174e+25)*cos(18*phi)

#@torch.jit.script
def Yl30_m19(theta, phi):
    return 7.98179203850954e-28*(1.0 - cos(theta)**2)**9.5*(7.31912537364547e+32*cos(theta)**11 - 6.8229134839068e+32*cos(theta)**9 + 2.15460425807583e+32*cos(theta)**7 - 2.74222360118742e+31*cos(theta)**5 + 1.29350169867331e+30*cos(theta)**3 - 1.52176670432154e+28*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl30_m20(theta, phi):
    return 3.40344756082348e-29*(1.0 - cos(theta)**2)**10*(8.05103791101002e+33*cos(theta)**10 - 6.14062213551612e+33*cos(theta)**8 + 1.50822298065308e+33*cos(theta)**6 - 1.37111180059371e+32*cos(theta)**4 + 3.88050509601994e+30*cos(theta)**2 - 1.52176670432154e+28)*cos(20*phi)

#@torch.jit.script
def Yl30_m21(theta, phi):
    return 1.5070719110102e-30*(1.0 - cos(theta)**2)**10.5*(8.05103791101002e+34*cos(theta)**9 - 4.9124977084129e+34*cos(theta)**7 + 9.04933788391849e+33*cos(theta)**5 - 5.48444720237484e+32*cos(theta)**3 + 7.76101019203987e+30*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl30_m22(theta, phi):
    return 6.96644237302409e-32*(1.0 - cos(theta)**2)**11*(7.24593411990902e+35*cos(theta)**8 - 3.43874839588903e+35*cos(theta)**6 + 4.52466894195925e+34*cos(theta)**4 - 1.64533416071245e+33*cos(theta)**2 + 7.76101019203987e+30)*cos(22*phi)

#@torch.jit.script
def Yl30_m23(theta, phi):
    return 3.38320349392245e-33*(1.0 - cos(theta)**2)**11.5*(5.79674729592722e+36*cos(theta)**7 - 2.06324903753342e+36*cos(theta)**5 + 1.8098675767837e+35*cos(theta)**3 - 3.29066832142491e+33*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl30_m24(theta, phi):
    return 1.74013210905229e-34*(1.0 - cos(theta)**2)**12*(4.05772310714905e+37*cos(theta)**6 - 1.03162451876671e+37*cos(theta)**4 + 5.42960273035109e+35*cos(theta)**2 - 3.29066832142491e+33)*cos(24*phi)

#@torch.jit.script
def Yl30_m25(theta, phi):
    return 9.57911199299742e-36*(1.0 - cos(theta)**2)**12.5*(2.43463386428943e+38*cos(theta)**5 - 4.12649807506683e+37*cos(theta)**3 + 1.08592054607022e+36*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl30_m26(theta, phi):
    return 5.72461435302436e-37*(1.0 - cos(theta)**2)**13*(1.21731693214472e+39*cos(theta)**4 - 1.23794942252005e+38*cos(theta)**2 + 1.08592054607022e+36)*cos(26*phi)

#@torch.jit.script
def Yl30_m27(theta, phi):
    return 3.79121847114987e-38*(1.0 - cos(theta)**2)**13.5*(4.86926772857886e+39*cos(theta)**3 - 2.4758988450401e+38*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl30_m28(theta, phi):
    return 2.87411530575892e-39*(1.0 - cos(theta)**2)**14*(1.46078031857366e+40*cos(theta)**2 - 2.4758988450401e+38)*cos(28*phi)

#@torch.jit.script
def Yl30_m29(theta, phi):
    return 7.72997498267602*(1.0 - cos(theta)**2)**14.5*cos(29*phi)*cos(theta)

#@torch.jit.script
def Yl30_m30(theta, phi):
    return 0.997935479150139*(1.0 - cos(theta)**2)**15*cos(30*phi)

#@torch.jit.script
def Yl31_m_minus_31(theta, phi):
    return 1.00595115393533*(1.0 - cos(theta)**2)**15.5*sin(31*phi)

#@torch.jit.script
def Yl31_m_minus_30(theta, phi):
    return 7.92086730695805*(1.0 - cos(theta)**2)**15*sin(30*phi)*cos(theta)

#@torch.jit.script
def Yl31_m_minus_29(theta, phi):
    return 4.90916821524168e-41*(1.0 - cos(theta)**2)**14.5*(8.91075994329932e+41*cos(theta)**2 - 1.46078031857366e+40)*sin(29*phi)

#@torch.jit.script
def Yl31_m_minus_28(theta, phi):
    return 6.58634030535703e-40*(1.0 - cos(theta)**2)**14*(2.97025331443311e+41*cos(theta)**3 - 1.46078031857366e+40*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl31_m_minus_27(theta, phi):
    return 1.01181279661018e-38*(1.0 - cos(theta)**2)**13.5*(7.42563328608276e+40*cos(theta)**4 - 7.30390159286829e+39*cos(theta)**2 + 6.18974711260025e+37)*sin(27*phi)

#@torch.jit.script
def Yl31_m_minus_26(theta, phi):
    return 1.72305510434632e-37*(1.0 - cos(theta)**2)**13*(1.48512665721655e+40*cos(theta)**5 - 2.43463386428943e+39*cos(theta)**3 + 6.18974711260025e+37*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl31_m_minus_25(theta, phi):
    return 3.18648750393588e-36*(1.0 - cos(theta)**2)**12.5*(2.47521109536092e+39*cos(theta)**6 - 6.08658466072358e+38*cos(theta)**4 + 3.09487355630012e+37*cos(theta)**2 - 1.8098675767837e+35)*sin(25*phi)

#@torch.jit.script
def Yl31_m_minus_24(theta, phi):
    return 6.30892338215793e-35*(1.0 - cos(theta)**2)**12*(3.5360158505156e+38*cos(theta)**7 - 1.21731693214472e+38*cos(theta)**5 + 1.03162451876671e+37*cos(theta)**3 - 1.8098675767837e+35*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl31_m_minus_23(theta, phi):
    return 1.32337093312696e-33*(1.0 - cos(theta)**2)**11.5*(4.4200198131445e+37*cos(theta)**8 - 2.02886155357453e+37*cos(theta)**6 + 2.57906129691677e+36*cos(theta)**4 - 9.04933788391849e+34*cos(theta)**2 + 4.11333540178113e+32)*sin(23*phi)

#@torch.jit.script
def Yl31_m_minus_22(theta, phi):
    return 2.9174251739327e-32*(1.0 - cos(theta)**2)**11*(4.91113312571611e+36*cos(theta)**9 - 2.89837364796361e+36*cos(theta)**7 + 5.15812259383354e+35*cos(theta)**5 - 3.01644596130616e+34*cos(theta)**3 + 4.11333540178113e+32*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl31_m_minus_21(theta, phi):
    return 6.7164171342413e-31*(1.0 - cos(theta)**2)**10.5*(4.91113312571611e+35*cos(theta)**10 - 3.62296705995451e+35*cos(theta)**8 + 8.59687098972257e+34*cos(theta)**6 - 7.54111490326541e+33*cos(theta)**4 + 2.05666770089057e+32*cos(theta)**2 - 7.76101019203987e+29)*sin(21*phi)

#@torch.jit.script
def Yl31_m_minus_20(theta, phi):
    return 1.60633334701383e-29*(1.0 - cos(theta)**2)**10*(4.46466647792374e+34*cos(theta)**11 - 4.02551895550501e+34*cos(theta)**9 + 1.22812442710322e+34*cos(theta)**7 - 1.50822298065308e+33*cos(theta)**5 + 6.85555900296855e+31*cos(theta)**3 - 7.76101019203987e+29*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl31_m_minus_19(theta, phi):
    return 3.97384923581397e-28*(1.0 - cos(theta)**2)**9.5*(3.72055539826978e+33*cos(theta)**12 - 4.02551895550501e+33*cos(theta)**10 + 1.53515553387903e+33*cos(theta)**8 - 2.51370496775514e+32*cos(theta)**6 + 1.71388975074214e+31*cos(theta)**4 - 3.88050509601994e+29*cos(theta)**2 + 1.26813892026795e+27)*sin(19*phi)

#@torch.jit.script
def Yl31_m_minus_18(theta, phi):
    return 1.01313673987456e-26*(1.0 - cos(theta)**2)**9*(2.86196569097676e+32*cos(theta)**13 - 3.65956268682274e+32*cos(theta)**11 + 1.7057283709767e+32*cos(theta)**9 - 3.59100709679305e+31*cos(theta)**7 + 3.42777950148428e+30*cos(theta)**5 - 1.29350169867331e+29*cos(theta)**3 + 1.26813892026795e+27*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl31_m_minus_17(theta, phi):
    return 2.6535673965946e-25*(1.0 - cos(theta)**2)**8.5*(2.04426120784054e+31*cos(theta)**14 - 3.04963557235228e+31*cos(theta)**12 + 1.7057283709767e+31*cos(theta)**10 - 4.48875887099132e+30*cos(theta)**8 + 5.71296583580713e+29*cos(theta)**6 - 3.23375424668328e+28*cos(theta)**4 + 6.34069460133976e+26*cos(theta)**2 - 1.84859900913696e+24)*sin(17*phi)

#@torch.jit.script
def Yl31_m_minus_16(theta, phi):
    return 7.12026849799521e-24*(1.0 - cos(theta)**2)**8*(1.36284080522703e+30*cos(theta)**15 - 2.34587351719406e+30*cos(theta)**13 + 1.55066215543336e+30*cos(theta)**11 - 4.98750985665702e+29*cos(theta)**9 + 8.16137976543875e+28*cos(theta)**7 - 6.46750849336656e+27*cos(theta)**5 + 2.11356486711325e+26*cos(theta)**3 - 1.84859900913696e+24*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl31_m_minus_15(theta, phi):
    return 1.95256405937486e-22*(1.0 - cos(theta)**2)**7.5*(8.51775503266892e+28*cos(theta)**16 - 1.6756239408529e+29*cos(theta)**14 + 1.29221846286114e+29*cos(theta)**12 - 4.98750985665702e+28*cos(theta)**10 + 1.02017247067984e+28*cos(theta)**8 - 1.07791808222776e+27*cos(theta)**6 + 5.28391216778314e+25*cos(theta)**4 - 9.24299504568479e+23*cos(theta)**2 + 2.45824336321404e+21)*sin(15*phi)

#@torch.jit.script
def Yl31_m_minus_14(theta, phi):
    return 5.46020147014982e-21*(1.0 - cos(theta)**2)**7*(5.01044413686407e+27*cos(theta)**17 - 1.11708262723527e+28*cos(theta)**15 + 9.94014202200874e+27*cos(theta)**13 - 4.5340998696882e+27*cos(theta)**11 + 1.13352496742205e+27*cos(theta)**9 - 1.53988297461109e+26*cos(theta)**7 + 1.05678243355663e+25*cos(theta)**5 - 3.0809983485616e+23*cos(theta)**3 + 2.45824336321404e+21*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl31_m_minus_13(theta, phi):
    return 1.5540005816166e-19*(1.0 - cos(theta)**2)**6.5*(2.78358007603559e+26*cos(theta)**18 - 6.98176642022042e+26*cos(theta)**16 + 7.10010144429196e+26*cos(theta)**14 - 3.7784165580735e+26*cos(theta)**12 + 1.13352496742205e+26*cos(theta)**10 - 1.92485371826386e+25*cos(theta)**8 + 1.76130405592771e+24*cos(theta)**6 - 7.70249587140399e+22*cos(theta)**4 + 1.22912168160702e+21*cos(theta)**2 - 3.03486834964696e+18)*sin(13*phi)

#@torch.jit.script
def Yl31_m_minus_12(theta, phi):
    return 4.49318515889086e-18*(1.0 - cos(theta)**2)**6*(1.46504214528189e+25*cos(theta)**19 - 4.10692142365907e+25*cos(theta)**17 + 4.7334009628613e+25*cos(theta)**15 - 2.90647427544115e+25*cos(theta)**13 + 1.03047724311095e+25*cos(theta)**11 - 2.13872635362651e+24*cos(theta)**9 + 2.5161486513253e+23*cos(theta)**7 - 1.5404991742808e+22*cos(theta)**5 + 4.0970722720234e+20*cos(theta)**3 - 3.03486834964696e+18*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl31_m_minus_11(theta, phi):
    return 1.31766054315921e-16*(1.0 - cos(theta)**2)**5.5*(7.32521072640946e+23*cos(theta)**20 - 2.28162301314393e+24*cos(theta)**18 + 2.95837560178832e+24*cos(theta)**16 - 2.07605305388654e+24*cos(theta)**14 + 8.58731035925795e+23*cos(theta)**12 - 2.13872635362651e+23*cos(theta)**10 + 3.14518581415663e+22*cos(theta)**8 - 2.56749862380133e+21*cos(theta)**6 + 1.02426806800585e+20*cos(theta)**4 - 1.51743417482348e+18*cos(theta)**2 + 3.528916685636e+15)*sin(11*phi)

#@torch.jit.script
def Yl31_m_minus_10(theta, phi):
    return 3.91325216255328e-15*(1.0 - cos(theta)**2)**5*(3.4881955840045e+22*cos(theta)**21 - 1.20085421744417e+23*cos(theta)**19 + 1.74022094222842e+23*cos(theta)**17 - 1.38403536925769e+23*cos(theta)**15 + 6.60562335327535e+22*cos(theta)**13 - 1.94429668511501e+22*cos(theta)**11 + 3.49465090461848e+21*cos(theta)**9 - 3.66785517685904e+20*cos(theta)**7 + 2.0485361360117e+19*cos(theta)**5 - 5.05811391607827e+17*cos(theta)**3 + 3.528916685636e+15*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl31_m_minus_9(theta, phi):
    return 1.17527934228125e-13*(1.0 - cos(theta)**2)**4.5*(1.58554344727477e+21*cos(theta)**22 - 6.00427108722087e+21*cos(theta)**20 + 9.66789412349123e+21*cos(theta)**18 - 8.65022105786057e+21*cos(theta)**16 + 4.71830239519667e+21*cos(theta)**14 - 1.62024723759584e+21*cos(theta)**12 + 3.49465090461848e+20*cos(theta)**10 - 4.5848189710738e+19*cos(theta)**8 + 3.41422689335283e+18*cos(theta)**6 - 1.26452847901957e+17*cos(theta)**4 + 1.764458342818e+15*cos(theta)**2 - 3912324485184.04)*sin(9*phi)

#@torch.jit.script
def Yl31_m_minus_8(theta, phi):
    return 3.56479874579423e-12*(1.0 - cos(theta)**2)**4*(6.89366716206424e+19*cos(theta)**23 - 2.85917670820041e+20*cos(theta)**21 + 5.08836532815328e+20*cos(theta)**19 - 5.08836532815328e+20*cos(theta)**17 + 3.14553493013112e+20*cos(theta)**15 - 1.24634402891988e+20*cos(theta)**13 + 3.17695536783498e+19*cos(theta)**11 - 5.09424330119312e+18*cos(theta)**9 + 4.87746699050405e+17*cos(theta)**7 - 2.52905695803914e+16*cos(theta)**5 + 588152780939334.0*cos(theta)**3 - 3912324485184.04*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl31_m_minus_7(theta, phi):
    return 1.09061870201015e-10*(1.0 - cos(theta)**2)**3.5*(2.87236131752677e+18*cos(theta)**24 - 1.29962577645473e+19*cos(theta)**22 + 2.54418266407664e+19*cos(theta)**20 - 2.82686962675182e+19*cos(theta)**18 + 1.96595933133195e+19*cos(theta)**16 - 8.90245734942769e+18*cos(theta)**14 + 2.64746280652915e+18*cos(theta)**12 - 5.09424330119312e+17*cos(theta)**10 + 6.09683373813006e+16*cos(theta)**8 - 4.21509493006523e+15*cos(theta)**6 + 147038195234833.0*cos(theta)**4 - 1956162242592.02*cos(theta)**2 + 4179833851.69235)*sin(7*phi)

#@torch.jit.script
def Yl31_m_minus_6(theta, phi):
    return 3.36151259928562e-9*(1.0 - cos(theta)**2)**3*(1.14894452701071e+17*cos(theta)**25 - 5.65054685415101e+17*cos(theta)**23 + 1.21151555432221e+18*cos(theta)**21 - 1.48782611934306e+18*cos(theta)**19 + 1.15644666548938e+18*cos(theta)**17 - 5.93497156628513e+17*cos(theta)**15 + 2.03650985117627e+17*cos(theta)**13 - 4.63113027381192e+16*cos(theta)**11 + 6.7742597090334e+15*cos(theta)**9 - 602156418580747.0*cos(theta)**7 + 29407639046966.7*cos(theta)**5 - 652054080864.006*cos(theta)**3 + 4179833851.69235*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl31_m_minus_5(theta, phi):
    return 1.04261094425773e-7*(1.0 - cos(theta)**2)**2.5*(4.41901741157964e+15*cos(theta)**26 - 2.35439452256292e+16*cos(theta)**24 + 5.50688888328277e+16*cos(theta)**22 - 7.43913059671532e+16*cos(theta)**20 + 6.42470369716323e+16*cos(theta)**18 - 3.7093572289282e+16*cos(theta)**16 + 1.45464989369733e+16*cos(theta)**14 - 3.8592752281766e+15*cos(theta)**12 + 677425970903340.0*cos(theta)**10 - 75269552322593.3*cos(theta)**8 + 4901273174494.45*cos(theta)**6 - 163013520216.002*cos(theta)**4 + 2089916925.84617*cos(theta)**2 - 4344941.63377583)*sin(5*phi)

#@torch.jit.script
def Yl31_m_minus_4(theta, phi):
    return 3.25053923036716e-6*(1.0 - cos(theta)**2)**2*(163667311539987.0*cos(theta)**27 - 941757809025169.0*cos(theta)**25 + 2.39429951447077e+15*cos(theta)**23 - 3.54244314129301e+15*cos(theta)**21 + 3.38142299850696e+15*cos(theta)**19 - 2.181974840546e+15*cos(theta)**17 + 969766595798223.0*cos(theta)**15 - 296867325244354.0*cos(theta)**13 + 61584179173030.9*cos(theta)**11 - 8363283591399.26*cos(theta)**9 + 700181882070.635*cos(theta)**7 - 32602704043.2003*cos(theta)**5 + 696638975.282058*cos(theta)**3 - 4344941.63377583*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl31_m_minus_3(theta, phi):
    return 0.000101757973556832*(1.0 - cos(theta)**2)**1.5*(5845261126428.09*cos(theta)**28 - 36221454193275.7*cos(theta)**26 + 99762479769615.3*cos(theta)**24 - 161020142786046.0*cos(theta)**22 + 169071149925348.0*cos(theta)**20 - 121220824474778.0*cos(theta)**18 + 60610412237388.9*cos(theta)**16 - 21204808946025.3*cos(theta)**14 + 5132014931085.91*cos(theta)**12 - 836328359139.926*cos(theta)**10 + 87522735258.8294*cos(theta)**8 - 5433784007.20005*cos(theta)**6 + 174159743.820515*cos(theta)**4 - 2172470.81688792*cos(theta)**2 + 4433.61391201615)*sin(3*phi)

#@torch.jit.script
def Yl31_m_minus_2(theta, phi):
    return 0.00319526518302305*(1.0 - cos(theta)**2)*(201560728497.52*cos(theta)**29 - 1341535340491.69*cos(theta)**27 + 3990499190784.61*cos(theta)**25 - 7000875773306.34*cos(theta)**23 + 8051007139302.29*cos(theta)**21 - 6380043393409.36*cos(theta)**19 + 3565318366905.23*cos(theta)**17 - 1413653929735.02*cos(theta)**15 + 394770379314.301*cos(theta)**13 - 76029850830.9023*cos(theta)**11 + 9724748362.09216*cos(theta)**9 - 776254858.171436*cos(theta)**7 + 34831948.7641029*cos(theta)**5 - 724156.938962638*cos(theta)**3 + 4433.61391201615*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl31_m_minus_1(theta, phi):
    return 0.100536671886138*(1.0 - cos(theta)**2)**0.5*(6718690949.91735*cos(theta)**30 - 47911976446.1319*cos(theta)**28 + 153480738107.101*cos(theta)**26 - 291703157221.098*cos(theta)**24 + 365954869968.286*cos(theta)**22 - 319002169670.468*cos(theta)**20 + 198073242605.846*cos(theta)**18 - 88353370608.4387*cos(theta)**16 + 28197884236.7358*cos(theta)**14 - 6335820902.57519*cos(theta)**12 + 972474836.209216*cos(theta)**10 - 97031857.2714295*cos(theta)**8 + 5805324.79401715*cos(theta)**6 - 181039.23474066*cos(theta)**4 + 2216.80695600808*cos(theta)**2 - 4.47839789092541)*sin(phi)

#@torch.jit.script
def Yl31_m0(theta, phi):
    return 1524537762.43789*cos(theta)**31 - 11621476385.797*cos(theta)**29 + 39985757734.1829*cos(theta)**27 - 82076029033.3228*cos(theta)**25 + 111921857772.713*cos(theta)**23 - 106853698175.458*cos(theta)**21 + 73330969336.0986*cos(theta)**19 - 36558588211.2912*cos(theta)**17 + 13223319140.2542*cos(theta)**15 - 3428267925.2511*cos(theta)**13 + 621871856.208339*cos(theta)**11 - 75838031.2449194*cos(theta)**9 + 5833694.71114765*cos(theta)**7 - 254693.532087527*cos(theta)**5 + 5197.82718545974*cos(theta)**3 - 31.5019829421802*cos(theta)

#@torch.jit.script
def Yl31_m1(theta, phi):
    return 0.100536671886138*(1.0 - cos(theta)**2)**0.5*(6718690949.91735*cos(theta)**30 - 47911976446.1319*cos(theta)**28 + 153480738107.101*cos(theta)**26 - 291703157221.098*cos(theta)**24 + 365954869968.286*cos(theta)**22 - 319002169670.468*cos(theta)**20 + 198073242605.846*cos(theta)**18 - 88353370608.4387*cos(theta)**16 + 28197884236.7358*cos(theta)**14 - 6335820902.57519*cos(theta)**12 + 972474836.209216*cos(theta)**10 - 97031857.2714295*cos(theta)**8 + 5805324.79401715*cos(theta)**6 - 181039.23474066*cos(theta)**4 + 2216.80695600808*cos(theta)**2 - 4.47839789092541)*cos(phi)

#@torch.jit.script
def Yl31_m2(theta, phi):
    return 0.00319526518302305*(1.0 - cos(theta)**2)*(201560728497.52*cos(theta)**29 - 1341535340491.69*cos(theta)**27 + 3990499190784.61*cos(theta)**25 - 7000875773306.34*cos(theta)**23 + 8051007139302.29*cos(theta)**21 - 6380043393409.36*cos(theta)**19 + 3565318366905.23*cos(theta)**17 - 1413653929735.02*cos(theta)**15 + 394770379314.301*cos(theta)**13 - 76029850830.9023*cos(theta)**11 + 9724748362.09216*cos(theta)**9 - 776254858.171436*cos(theta)**7 + 34831948.7641029*cos(theta)**5 - 724156.938962638*cos(theta)**3 + 4433.61391201615*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl31_m3(theta, phi):
    return 0.000101757973556832*(1.0 - cos(theta)**2)**1.5*(5845261126428.09*cos(theta)**28 - 36221454193275.7*cos(theta)**26 + 99762479769615.3*cos(theta)**24 - 161020142786046.0*cos(theta)**22 + 169071149925348.0*cos(theta)**20 - 121220824474778.0*cos(theta)**18 + 60610412237388.9*cos(theta)**16 - 21204808946025.3*cos(theta)**14 + 5132014931085.91*cos(theta)**12 - 836328359139.926*cos(theta)**10 + 87522735258.8294*cos(theta)**8 - 5433784007.20005*cos(theta)**6 + 174159743.820515*cos(theta)**4 - 2172470.81688792*cos(theta)**2 + 4433.61391201615)*cos(3*phi)

#@torch.jit.script
def Yl31_m4(theta, phi):
    return 3.25053923036716e-6*(1.0 - cos(theta)**2)**2*(163667311539987.0*cos(theta)**27 - 941757809025169.0*cos(theta)**25 + 2.39429951447077e+15*cos(theta)**23 - 3.54244314129301e+15*cos(theta)**21 + 3.38142299850696e+15*cos(theta)**19 - 2.181974840546e+15*cos(theta)**17 + 969766595798223.0*cos(theta)**15 - 296867325244354.0*cos(theta)**13 + 61584179173030.9*cos(theta)**11 - 8363283591399.26*cos(theta)**9 + 700181882070.635*cos(theta)**7 - 32602704043.2003*cos(theta)**5 + 696638975.282058*cos(theta)**3 - 4344941.63377583*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl31_m5(theta, phi):
    return 1.04261094425773e-7*(1.0 - cos(theta)**2)**2.5*(4.41901741157964e+15*cos(theta)**26 - 2.35439452256292e+16*cos(theta)**24 + 5.50688888328277e+16*cos(theta)**22 - 7.43913059671532e+16*cos(theta)**20 + 6.42470369716323e+16*cos(theta)**18 - 3.7093572289282e+16*cos(theta)**16 + 1.45464989369733e+16*cos(theta)**14 - 3.8592752281766e+15*cos(theta)**12 + 677425970903340.0*cos(theta)**10 - 75269552322593.3*cos(theta)**8 + 4901273174494.45*cos(theta)**6 - 163013520216.002*cos(theta)**4 + 2089916925.84617*cos(theta)**2 - 4344941.63377583)*cos(5*phi)

#@torch.jit.script
def Yl31_m6(theta, phi):
    return 3.36151259928562e-9*(1.0 - cos(theta)**2)**3*(1.14894452701071e+17*cos(theta)**25 - 5.65054685415101e+17*cos(theta)**23 + 1.21151555432221e+18*cos(theta)**21 - 1.48782611934306e+18*cos(theta)**19 + 1.15644666548938e+18*cos(theta)**17 - 5.93497156628513e+17*cos(theta)**15 + 2.03650985117627e+17*cos(theta)**13 - 4.63113027381192e+16*cos(theta)**11 + 6.7742597090334e+15*cos(theta)**9 - 602156418580747.0*cos(theta)**7 + 29407639046966.7*cos(theta)**5 - 652054080864.006*cos(theta)**3 + 4179833851.69235*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl31_m7(theta, phi):
    return 1.09061870201015e-10*(1.0 - cos(theta)**2)**3.5*(2.87236131752677e+18*cos(theta)**24 - 1.29962577645473e+19*cos(theta)**22 + 2.54418266407664e+19*cos(theta)**20 - 2.82686962675182e+19*cos(theta)**18 + 1.96595933133195e+19*cos(theta)**16 - 8.90245734942769e+18*cos(theta)**14 + 2.64746280652915e+18*cos(theta)**12 - 5.09424330119312e+17*cos(theta)**10 + 6.09683373813006e+16*cos(theta)**8 - 4.21509493006523e+15*cos(theta)**6 + 147038195234833.0*cos(theta)**4 - 1956162242592.02*cos(theta)**2 + 4179833851.69235)*cos(7*phi)

#@torch.jit.script
def Yl31_m8(theta, phi):
    return 3.56479874579423e-12*(1.0 - cos(theta)**2)**4*(6.89366716206424e+19*cos(theta)**23 - 2.85917670820041e+20*cos(theta)**21 + 5.08836532815328e+20*cos(theta)**19 - 5.08836532815328e+20*cos(theta)**17 + 3.14553493013112e+20*cos(theta)**15 - 1.24634402891988e+20*cos(theta)**13 + 3.17695536783498e+19*cos(theta)**11 - 5.09424330119312e+18*cos(theta)**9 + 4.87746699050405e+17*cos(theta)**7 - 2.52905695803914e+16*cos(theta)**5 + 588152780939334.0*cos(theta)**3 - 3912324485184.04*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl31_m9(theta, phi):
    return 1.17527934228125e-13*(1.0 - cos(theta)**2)**4.5*(1.58554344727477e+21*cos(theta)**22 - 6.00427108722087e+21*cos(theta)**20 + 9.66789412349123e+21*cos(theta)**18 - 8.65022105786057e+21*cos(theta)**16 + 4.71830239519667e+21*cos(theta)**14 - 1.62024723759584e+21*cos(theta)**12 + 3.49465090461848e+20*cos(theta)**10 - 4.5848189710738e+19*cos(theta)**8 + 3.41422689335283e+18*cos(theta)**6 - 1.26452847901957e+17*cos(theta)**4 + 1.764458342818e+15*cos(theta)**2 - 3912324485184.04)*cos(9*phi)

#@torch.jit.script
def Yl31_m10(theta, phi):
    return 3.91325216255328e-15*(1.0 - cos(theta)**2)**5*(3.4881955840045e+22*cos(theta)**21 - 1.20085421744417e+23*cos(theta)**19 + 1.74022094222842e+23*cos(theta)**17 - 1.38403536925769e+23*cos(theta)**15 + 6.60562335327535e+22*cos(theta)**13 - 1.94429668511501e+22*cos(theta)**11 + 3.49465090461848e+21*cos(theta)**9 - 3.66785517685904e+20*cos(theta)**7 + 2.0485361360117e+19*cos(theta)**5 - 5.05811391607827e+17*cos(theta)**3 + 3.528916685636e+15*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl31_m11(theta, phi):
    return 1.31766054315921e-16*(1.0 - cos(theta)**2)**5.5*(7.32521072640946e+23*cos(theta)**20 - 2.28162301314393e+24*cos(theta)**18 + 2.95837560178832e+24*cos(theta)**16 - 2.07605305388654e+24*cos(theta)**14 + 8.58731035925795e+23*cos(theta)**12 - 2.13872635362651e+23*cos(theta)**10 + 3.14518581415663e+22*cos(theta)**8 - 2.56749862380133e+21*cos(theta)**6 + 1.02426806800585e+20*cos(theta)**4 - 1.51743417482348e+18*cos(theta)**2 + 3.528916685636e+15)*cos(11*phi)

#@torch.jit.script
def Yl31_m12(theta, phi):
    return 4.49318515889086e-18*(1.0 - cos(theta)**2)**6*(1.46504214528189e+25*cos(theta)**19 - 4.10692142365907e+25*cos(theta)**17 + 4.7334009628613e+25*cos(theta)**15 - 2.90647427544115e+25*cos(theta)**13 + 1.03047724311095e+25*cos(theta)**11 - 2.13872635362651e+24*cos(theta)**9 + 2.5161486513253e+23*cos(theta)**7 - 1.5404991742808e+22*cos(theta)**5 + 4.0970722720234e+20*cos(theta)**3 - 3.03486834964696e+18*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl31_m13(theta, phi):
    return 1.5540005816166e-19*(1.0 - cos(theta)**2)**6.5*(2.78358007603559e+26*cos(theta)**18 - 6.98176642022042e+26*cos(theta)**16 + 7.10010144429196e+26*cos(theta)**14 - 3.7784165580735e+26*cos(theta)**12 + 1.13352496742205e+26*cos(theta)**10 - 1.92485371826386e+25*cos(theta)**8 + 1.76130405592771e+24*cos(theta)**6 - 7.70249587140399e+22*cos(theta)**4 + 1.22912168160702e+21*cos(theta)**2 - 3.03486834964696e+18)*cos(13*phi)

#@torch.jit.script
def Yl31_m14(theta, phi):
    return 5.46020147014982e-21*(1.0 - cos(theta)**2)**7*(5.01044413686407e+27*cos(theta)**17 - 1.11708262723527e+28*cos(theta)**15 + 9.94014202200874e+27*cos(theta)**13 - 4.5340998696882e+27*cos(theta)**11 + 1.13352496742205e+27*cos(theta)**9 - 1.53988297461109e+26*cos(theta)**7 + 1.05678243355663e+25*cos(theta)**5 - 3.0809983485616e+23*cos(theta)**3 + 2.45824336321404e+21*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl31_m15(theta, phi):
    return 1.95256405937486e-22*(1.0 - cos(theta)**2)**7.5*(8.51775503266892e+28*cos(theta)**16 - 1.6756239408529e+29*cos(theta)**14 + 1.29221846286114e+29*cos(theta)**12 - 4.98750985665702e+28*cos(theta)**10 + 1.02017247067984e+28*cos(theta)**8 - 1.07791808222776e+27*cos(theta)**6 + 5.28391216778314e+25*cos(theta)**4 - 9.24299504568479e+23*cos(theta)**2 + 2.45824336321404e+21)*cos(15*phi)

#@torch.jit.script
def Yl31_m16(theta, phi):
    return 7.12026849799521e-24*(1.0 - cos(theta)**2)**8*(1.36284080522703e+30*cos(theta)**15 - 2.34587351719406e+30*cos(theta)**13 + 1.55066215543336e+30*cos(theta)**11 - 4.98750985665702e+29*cos(theta)**9 + 8.16137976543875e+28*cos(theta)**7 - 6.46750849336656e+27*cos(theta)**5 + 2.11356486711325e+26*cos(theta)**3 - 1.84859900913696e+24*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl31_m17(theta, phi):
    return 2.6535673965946e-25*(1.0 - cos(theta)**2)**8.5*(2.04426120784054e+31*cos(theta)**14 - 3.04963557235228e+31*cos(theta)**12 + 1.7057283709767e+31*cos(theta)**10 - 4.48875887099132e+30*cos(theta)**8 + 5.71296583580713e+29*cos(theta)**6 - 3.23375424668328e+28*cos(theta)**4 + 6.34069460133976e+26*cos(theta)**2 - 1.84859900913696e+24)*cos(17*phi)

#@torch.jit.script
def Yl31_m18(theta, phi):
    return 1.01313673987456e-26*(1.0 - cos(theta)**2)**9*(2.86196569097676e+32*cos(theta)**13 - 3.65956268682274e+32*cos(theta)**11 + 1.7057283709767e+32*cos(theta)**9 - 3.59100709679305e+31*cos(theta)**7 + 3.42777950148428e+30*cos(theta)**5 - 1.29350169867331e+29*cos(theta)**3 + 1.26813892026795e+27*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl31_m19(theta, phi):
    return 3.97384923581397e-28*(1.0 - cos(theta)**2)**9.5*(3.72055539826978e+33*cos(theta)**12 - 4.02551895550501e+33*cos(theta)**10 + 1.53515553387903e+33*cos(theta)**8 - 2.51370496775514e+32*cos(theta)**6 + 1.71388975074214e+31*cos(theta)**4 - 3.88050509601994e+29*cos(theta)**2 + 1.26813892026795e+27)*cos(19*phi)

#@torch.jit.script
def Yl31_m20(theta, phi):
    return 1.60633334701383e-29*(1.0 - cos(theta)**2)**10*(4.46466647792374e+34*cos(theta)**11 - 4.02551895550501e+34*cos(theta)**9 + 1.22812442710322e+34*cos(theta)**7 - 1.50822298065308e+33*cos(theta)**5 + 6.85555900296855e+31*cos(theta)**3 - 7.76101019203987e+29*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl31_m21(theta, phi):
    return 6.7164171342413e-31*(1.0 - cos(theta)**2)**10.5*(4.91113312571611e+35*cos(theta)**10 - 3.62296705995451e+35*cos(theta)**8 + 8.59687098972257e+34*cos(theta)**6 - 7.54111490326541e+33*cos(theta)**4 + 2.05666770089057e+32*cos(theta)**2 - 7.76101019203987e+29)*cos(21*phi)

#@torch.jit.script
def Yl31_m22(theta, phi):
    return 2.9174251739327e-32*(1.0 - cos(theta)**2)**11*(4.91113312571611e+36*cos(theta)**9 - 2.89837364796361e+36*cos(theta)**7 + 5.15812259383354e+35*cos(theta)**5 - 3.01644596130616e+34*cos(theta)**3 + 4.11333540178113e+32*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl31_m23(theta, phi):
    return 1.32337093312696e-33*(1.0 - cos(theta)**2)**11.5*(4.4200198131445e+37*cos(theta)**8 - 2.02886155357453e+37*cos(theta)**6 + 2.57906129691677e+36*cos(theta)**4 - 9.04933788391849e+34*cos(theta)**2 + 4.11333540178113e+32)*cos(23*phi)

#@torch.jit.script
def Yl31_m24(theta, phi):
    return 6.30892338215793e-35*(1.0 - cos(theta)**2)**12*(3.5360158505156e+38*cos(theta)**7 - 1.21731693214472e+38*cos(theta)**5 + 1.03162451876671e+37*cos(theta)**3 - 1.8098675767837e+35*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl31_m25(theta, phi):
    return 3.18648750393588e-36*(1.0 - cos(theta)**2)**12.5*(2.47521109536092e+39*cos(theta)**6 - 6.08658466072358e+38*cos(theta)**4 + 3.09487355630012e+37*cos(theta)**2 - 1.8098675767837e+35)*cos(25*phi)

#@torch.jit.script
def Yl31_m26(theta, phi):
    return 1.72305510434632e-37*(1.0 - cos(theta)**2)**13*(1.48512665721655e+40*cos(theta)**5 - 2.43463386428943e+39*cos(theta)**3 + 6.18974711260025e+37*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl31_m27(theta, phi):
    return 1.01181279661018e-38*(1.0 - cos(theta)**2)**13.5*(7.42563328608276e+40*cos(theta)**4 - 7.30390159286829e+39*cos(theta)**2 + 6.18974711260025e+37)*cos(27*phi)

#@torch.jit.script
def Yl31_m28(theta, phi):
    return 6.58634030535703e-40*(1.0 - cos(theta)**2)**14*(2.97025331443311e+41*cos(theta)**3 - 1.46078031857366e+40*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl31_m29(theta, phi):
    return 4.90916821524168e-41*(1.0 - cos(theta)**2)**14.5*(8.91075994329932e+41*cos(theta)**2 - 1.46078031857366e+40)*cos(29*phi)

#@torch.jit.script
def Yl31_m30(theta, phi):
    return 7.92086730695805*(1.0 - cos(theta)**2)**15*cos(30*phi)*cos(theta)

#@torch.jit.script
def Yl31_m31(theta, phi):
    return 1.00595115393533*(1.0 - cos(theta)**2)**15.5*cos(31*phi)

#@torch.jit.script
def Yl32_m_minus_32(theta, phi):
    return 1.01377968565312*(1.0 - cos(theta)**2)**16*sin(32*phi)

#@torch.jit.script
def Yl32_m_minus_31(theta, phi):
    return 8.11023748522498*(1.0 - cos(theta)**2)**15.5*sin(31*phi)*cos(theta)

#@torch.jit.script
def Yl32_m_minus_30(theta, phi):
    return 8.10836994187712e-43*(1.0 - cos(theta)**2)**15*(5.61377876427857e+43*cos(theta)**2 - 8.91075994329932e+41)*sin(30*phi)

#@torch.jit.script
def Yl32_m_minus_29(theta, phi):
    return 1.10583422533699e-41*(1.0 - cos(theta)**2)**14.5*(1.87125958809286e+43*cos(theta)**3 - 8.91075994329932e+41*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl32_m_minus_28(theta, phi):
    return 1.72736828000894e-40*(1.0 - cos(theta)**2)**14*(4.67814897023214e+42*cos(theta)**4 - 4.45537997164966e+41*cos(theta)**2 + 3.65195079643415e+39)*sin(28*phi)

#@torch.jit.script
def Yl32_m_minus_27(theta, phi):
    return 2.99188962435835e-39*(1.0 - cos(theta)**2)**13.5*(9.35629794046428e+41*cos(theta)**5 - 1.48512665721655e+41*cos(theta)**3 + 3.65195079643415e+39*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl32_m_minus_26(theta, phi):
    return 5.62920673595975e-38*(1.0 - cos(theta)**2)**13*(1.55938299007738e+41*cos(theta)**6 - 3.71281664304138e+40*cos(theta)**4 + 1.82597539821707e+39*cos(theta)**2 - 1.03162451876671e+37)*sin(26*phi)

#@torch.jit.script
def Yl32_m_minus_25(theta, phi):
    return 1.13425372828688e-36*(1.0 - cos(theta)**2)**12.5*(2.22768998582483e+40*cos(theta)**7 - 7.42563328608276e+39*cos(theta)**5 + 6.08658466072358e+38*cos(theta)**3 - 1.03162451876671e+37*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl32_m_minus_24(theta, phi):
    return 2.42210316291546e-35*(1.0 - cos(theta)**2)**12*(2.78461248228104e+39*cos(theta)**8 - 1.23760554768046e+39*cos(theta)**6 + 1.52164616518089e+38*cos(theta)**4 - 5.15812259383354e+36*cos(theta)**2 + 2.26233447097962e+34)*sin(24*phi)

#@torch.jit.script
def Yl32_m_minus_23(theta, phi):
    return 5.43760811463069e-34*(1.0 - cos(theta)**2)**11.5*(3.09401386920115e+38*cos(theta)**9 - 1.7680079252578e+38*cos(theta)**7 + 3.04329233036179e+37*cos(theta)**5 - 1.71937419794451e+36*cos(theta)**3 + 2.26233447097962e+34*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl32_m_minus_22(theta, phi):
    return 1.27523213983038e-32*(1.0 - cos(theta)**2)**11*(3.09401386920115e+37*cos(theta)**10 - 2.21000990657225e+37*cos(theta)**8 + 5.07215388393631e+36*cos(theta)**6 - 4.29843549486128e+35*cos(theta)**4 + 1.13116723548981e+34*cos(theta)**2 - 4.11333540178113e+31)*sin(22*phi)

#@torch.jit.script
def Yl32_m_minus_21(theta, phi):
    return 3.10801046364243e-31*(1.0 - cos(theta)**2)**10.5*(2.81273988109196e+36*cos(theta)**11 - 2.45556656285806e+36*cos(theta)**9 + 7.24593411990902e+35*cos(theta)**7 - 8.59687098972257e+34*cos(theta)**5 + 3.7705574516327e+33*cos(theta)**3 - 4.11333540178113e+31*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl32_m_minus_20(theta, phi):
    return 7.83810415265227e-30*(1.0 - cos(theta)**2)**10*(2.34394990090996e+35*cos(theta)**12 - 2.45556656285806e+35*cos(theta)**10 + 9.05741764988628e+34*cos(theta)**8 - 1.43281183162043e+34*cos(theta)**6 + 9.42639362908176e+32*cos(theta)**4 - 2.05666770089057e+31*cos(theta)**2 + 6.46750849336656e+28)*sin(20*phi)

#@torch.jit.script
def Yl32_m_minus_19(theta, phi):
    return 2.03790707968959e-28*(1.0 - cos(theta)**2)**9.5*(1.80303838531536e+34*cos(theta)**13 - 2.23233323896187e+34*cos(theta)**11 + 1.00637973887625e+34*cos(theta)**9 - 2.04687404517204e+33*cos(theta)**7 + 1.88527872581635e+32*cos(theta)**5 - 6.85555900296855e+30*cos(theta)**3 + 6.46750849336656e+28*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl32_m_minus_18(theta, phi):
    return 5.44544635409307e-27*(1.0 - cos(theta)**2)**9*(1.28788456093954e+33*cos(theta)**14 - 1.86027769913489e+33*cos(theta)**12 + 1.00637973887625e+33*cos(theta)**10 - 2.55859255646505e+32*cos(theta)**8 + 3.14213120969392e+31*cos(theta)**6 - 1.71388975074214e+30*cos(theta)**4 + 3.23375424668328e+28*cos(theta)**2 - 9.05813514477109e+25)*sin(18*phi)

#@torch.jit.script
def Yl32_m_minus_17(theta, phi):
    return 1.49129690191052e-25*(1.0 - cos(theta)**2)**8.5*(8.58589707293027e+31*cos(theta)**15 - 1.43098284548838e+32*cos(theta)**13 + 9.14890671705684e+31*cos(theta)**11 - 2.8428806182945e+31*cos(theta)**9 + 4.48875887099132e+30*cos(theta)**7 - 3.42777950148428e+29*cos(theta)**5 + 1.07791808222776e+28*cos(theta)**3 - 9.05813514477109e+25*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl32_m_minus_16(theta, phi):
    return 4.17563132534946e-24*(1.0 - cos(theta)**2)**8*(5.36618567058142e+30*cos(theta)**16 - 1.02213060392027e+31*cos(theta)**14 + 7.6240889308807e+30*cos(theta)**12 - 2.8428806182945e+30*cos(theta)**10 + 5.61094858873914e+29*cos(theta)**8 - 5.71296583580713e+28*cos(theta)**6 + 2.6947952055694e+27*cos(theta)**4 - 4.52906757238555e+25*cos(theta)**2 + 1.1553743807106e+23)*sin(16*phi)

#@torch.jit.script
def Yl32_m_minus_15(theta, phi):
    return 1.19279889015859e-22*(1.0 - cos(theta)**2)**7.5*(3.15657980622436e+29*cos(theta)**17 - 6.81420402613513e+29*cos(theta)**15 + 5.86468379298516e+29*cos(theta)**13 - 2.58443692572227e+29*cos(theta)**11 + 6.23438732082127e+28*cos(theta)**9 - 8.16137976543875e+27*cos(theta)**7 + 5.3895904111388e+26*cos(theta)**5 - 1.50968919079518e+25*cos(theta)**3 + 1.1553743807106e+23*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl32_m_minus_14(theta, phi):
    return 3.4693842922622e-21*(1.0 - cos(theta)**2)**7*(1.75365544790242e+28*cos(theta)**18 - 4.25887751633446e+28*cos(theta)**16 + 4.18905985213225e+28*cos(theta)**14 - 2.15369743810189e+28*cos(theta)**12 + 6.23438732082127e+27*cos(theta)**10 - 1.02017247067984e+27*cos(theta)**8 + 8.98265068523133e+25*cos(theta)**6 - 3.77422297698796e+24*cos(theta)**4 + 5.77687190355299e+22*cos(theta)**2 - 1.36569075734113e+20)*sin(14*phi)

#@torch.jit.script
def Yl32_m_minus_13(theta, phi):
    return 1.02567111293552e-19*(1.0 - cos(theta)**2)**6.5*(9.22976551527592e+26*cos(theta)**19 - 2.50522206843203e+27*cos(theta)**17 + 2.79270656808817e+27*cos(theta)**15 - 1.65669033700146e+27*cos(theta)**13 + 5.66762483711025e+26*cos(theta)**11 - 1.13352496742205e+26*cos(theta)**9 + 1.2832358121759e+25*cos(theta)**7 - 7.54844595397591e+23*cos(theta)**5 + 1.925623967851e+22*cos(theta)**3 - 1.36569075734113e+20*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl32_m_minus_12(theta, phi):
    return 3.07701333880655e-18*(1.0 - cos(theta)**2)**6*(4.61488275763796e+25*cos(theta)**20 - 1.3917900380178e+26*cos(theta)**18 + 1.74544160505511e+26*cos(theta)**16 - 1.18335024071533e+26*cos(theta)**14 + 4.72302069759187e+25*cos(theta)**12 - 1.13352496742205e+25*cos(theta)**10 + 1.60404476521988e+24*cos(theta)**8 - 1.25807432566265e+23*cos(theta)**6 + 4.81405991962749e+21*cos(theta)**4 - 6.82845378670567e+19*cos(theta)**2 + 1.51743417482348e+17)*sin(12*phi)

#@torch.jit.script
def Yl32_m_minus_11(theta, phi):
    return 9.35331077456894e-17*(1.0 - cos(theta)**2)**5.5*(2.19756321792284e+24*cos(theta)**21 - 7.32521072640946e+24*cos(theta)**19 + 1.02673035591477e+25*cos(theta)**17 - 7.88900160476884e+24*cos(theta)**15 + 3.63309284430144e+24*cos(theta)**13 - 1.03047724311095e+24*cos(theta)**11 + 1.78227196135542e+23*cos(theta)**9 - 1.79724903666093e+22*cos(theta)**7 + 9.62811983925499e+20*cos(theta)**5 - 2.27615126223522e+19*cos(theta)**3 + 1.51743417482348e+17*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl32_m_minus_10(theta, phi):
    return 2.87680836403125e-15*(1.0 - cos(theta)**2)**5*(9.98892371783108e+22*cos(theta)**22 - 3.66260536320473e+23*cos(theta)**20 + 5.70405753285982e+23*cos(theta)**18 - 4.93062600298053e+23*cos(theta)**16 + 2.59506631735817e+23*cos(theta)**14 - 8.58731035925795e+22*cos(theta)**12 + 1.78227196135542e+22*cos(theta)**10 - 2.24656129582616e+21*cos(theta)**8 + 1.60468663987583e+20*cos(theta)**6 - 5.69037815558805e+18*cos(theta)**4 + 7.58717087411741e+16*cos(theta)**2 - 160405303892546.0)*sin(10*phi)

#@torch.jit.script
def Yl32_m_minus_9(theta, phi):
    return 8.9412758972117e-14*(1.0 - cos(theta)**2)**4.5*(4.34301031210047e+21*cos(theta)**23 - 1.74409779200225e+22*cos(theta)**21 + 3.00213554361043e+22*cos(theta)**19 - 2.90036823704737e+22*cos(theta)**17 + 1.73004421157211e+22*cos(theta)**15 - 6.60562335327535e+21*cos(theta)**13 + 1.62024723759584e+21*cos(theta)**11 - 2.49617921758463e+20*cos(theta)**9 + 2.2924094855369e+19*cos(theta)**7 - 1.13807563111761e+18*cos(theta)**5 + 2.52905695803914e+16*cos(theta)**3 - 160405303892546.0*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl32_m_minus_8(theta, phi):
    return 2.80476865419125e-12*(1.0 - cos(theta)**2)**4*(1.80958763004186e+20*cos(theta)**24 - 7.92771723637387e+20*cos(theta)**22 + 1.50106777180522e+21*cos(theta)**20 - 1.61131568724854e+21*cos(theta)**18 + 1.08127763223257e+21*cos(theta)**16 - 4.71830239519668e+20*cos(theta)**14 + 1.35020603132987e+20*cos(theta)**12 - 2.49617921758463e+19*cos(theta)**10 + 2.86551185692113e+18*cos(theta)**8 - 1.89679271852935e+17*cos(theta)**6 + 6.32264239509784e+15*cos(theta)**4 - 80202651946272.8*cos(theta)**2 + 163013520216.002)*sin(8*phi)

#@torch.jit.script
def Yl32_m_minus_7(theta, phi):
    return 8.86945725708952e-11*(1.0 - cos(theta)**2)**3.5*(7.23835052016745e+18*cos(theta)**25 - 3.44683358103212e+19*cos(theta)**23 + 7.14794177050103e+19*cos(theta)**21 - 8.48060888025546e+19*cos(theta)**19 + 6.3604566601916e+19*cos(theta)**17 - 3.14553493013112e+19*cos(theta)**15 + 1.0386200240999e+19*cos(theta)**13 - 2.26925383416784e+18*cos(theta)**11 + 3.1839020632457e+17*cos(theta)**9 - 2.70970388361336e+16*cos(theta)**7 + 1.26452847901957e+15*cos(theta)**5 - 26734217315424.3*cos(theta)**3 + 163013520216.002*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl32_m_minus_6(theta, phi):
    return 2.8243337947883e-9*(1.0 - cos(theta)**2)**3*(2.78398096929517e+17*cos(theta)**26 - 1.43618065876338e+18*cos(theta)**24 + 3.24906444113683e+18*cos(theta)**22 - 4.24030444012773e+18*cos(theta)**20 + 3.53358703343978e+18*cos(theta)**18 - 1.96595933133195e+18*cos(theta)**16 + 7.41871445785641e+17*cos(theta)**14 - 1.89104486180654e+17*cos(theta)**12 + 3.1839020632457e+16*cos(theta)**10 - 3.3871298545167e+15*cos(theta)**8 + 210754746503261.0*cos(theta)**6 - 6683554328856.07*cos(theta)**4 + 81506760108.0008*cos(theta)**2 - 160762840.449706)*sin(6*phi)

#@torch.jit.script
def Yl32_m_minus_5(theta, phi):
    return 9.04668988104336e-8*(1.0 - cos(theta)**2)**2.5*(1.03110406270192e+16*cos(theta)**27 - 5.74472263505353e+16*cos(theta)**25 + 1.41263671353775e+17*cos(theta)**23 - 2.01919259053701e+17*cos(theta)**21 + 1.85978264917883e+17*cos(theta)**19 - 1.15644666548938e+17*cos(theta)**17 + 4.94580963857094e+16*cos(theta)**15 - 1.45464989369733e+16*cos(theta)**13 + 2.89445642113245e+15*cos(theta)**11 - 376347761612967.0*cos(theta)**9 + 30107820929037.3*cos(theta)**7 - 1336710865771.21*cos(theta)**5 + 27168920036.0003*cos(theta)**3 - 160762840.449706*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl32_m_minus_4(theta, phi):
    return 2.91185389957512e-6*(1.0 - cos(theta)**2)**2*(368251450964970.0*cos(theta)**28 - 2.20950870578982e+15*cos(theta)**26 + 5.88598630640731e+15*cos(theta)**24 - 9.17814813880461e+15*cos(theta)**22 + 9.29891324589415e+15*cos(theta)**20 - 6.42470369716323e+15*cos(theta)**18 + 3.09113102410684e+15*cos(theta)**16 - 1.03903563835524e+15*cos(theta)**14 + 241204701761038.0*cos(theta)**12 - 37634776161296.7*cos(theta)**10 + 3763477616129.67*cos(theta)**8 - 222785144295.202*cos(theta)**6 + 6792230009.00007*cos(theta)**4 - 80381420.2248529*cos(theta)**2 + 155176.486920565)*sin(4*phi)

#@torch.jit.script
def Yl32_m_minus_3(theta, phi):
    return 9.40848788610558e-5*(1.0 - cos(theta)**2)**1.5*(12698325895343.8*cos(theta)**29 - 81833655769993.3*cos(theta)**27 + 235439452256292.0*cos(theta)**25 - 399049919078461.0*cos(theta)**23 + 442805392661626.0*cos(theta)**21 - 338142299850696.0*cos(theta)**19 + 181831236712167.0*cos(theta)**17 - 69269042557015.9*cos(theta)**15 + 18554207827772.1*cos(theta)**13 - 3421343287390.6*cos(theta)**11 + 418164179569.963*cos(theta)**9 - 31826449185.0289*cos(theta)**7 + 1358446001.80001*cos(theta)**5 - 26793806.7416176*cos(theta)**3 + 155176.486920565*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl32_m_minus_2(theta, phi):
    return 0.00304869851769809*(1.0 - cos(theta)**2)*(423277529844.793*cos(theta)**30 - 2922630563214.05*cos(theta)**28 + 9055363548318.93*cos(theta)**26 - 16627079961602.6*cos(theta)**24 + 20127517848255.7*cos(theta)**22 - 16907114992534.8*cos(theta)**20 + 10101735372898.2*cos(theta)**18 - 4329315159813.5*cos(theta)**16 + 1325300559126.58*cos(theta)**14 - 285111940615.884*cos(theta)**12 + 41816417956.9963*cos(theta)**10 - 3978306148.12861*cos(theta)**8 + 226407666.966669*cos(theta)**6 - 6698451.6854044*cos(theta)**4 + 77588.2434602827*cos(theta)**2 - 147.787130400538)*sin(2*phi)

#@torch.jit.script
def Yl32_m_minus_1(theta, phi):
    return 0.0989771136930781*(1.0 - cos(theta)**2)**0.5*(13654113865.9611*cos(theta)**31 - 100780364248.76*cos(theta)**29 + 335383835122.923*cos(theta)**27 - 665083198464.102*cos(theta)**25 + 875109471663.293*cos(theta)**23 - 805100713930.229*cos(theta)**21 + 531670282784.114*cos(theta)**19 - 254665597636.088*cos(theta)**17 + 88353370608.4387*cos(theta)**15 - 21931687739.6834*cos(theta)**13 + 3801492541.54512*cos(theta)**11 - 442034016.458735*cos(theta)**9 + 32343952.4238098*cos(theta)**7 - 1339690.33708088*cos(theta)**5 + 25862.7478200942*cos(theta)**3 - 147.787130400538*cos(theta))*sin(phi)

#@torch.jit.script
def Yl32_m0(theta, phi):
    return 3048703300.55346*cos(theta)**32 - 24002489477.3733*cos(theta)**30 + 85582646907.0276*cos(theta)**28 - 182769720513.313*cos(theta)**26 + 260527013889.591*cos(theta)**24 - 261474384849.19*cos(theta)**22 + 189938939937.619*cos(theta)**20 - 101087951227.304*cos(theta)**18 + 39455246269.8407*cos(theta)**16 - 11192977665.203*cos(theta)**14 + 2263468816.74106*cos(theta)**12 - 315832858.149915*cos(theta)**10 + 28887151.6600532*cos(theta)**8 - 1595345.65380964*cos(theta)**6 + 46197.2679674607*cos(theta)**4 - 527.96877677098*cos(theta)**2 + 0.999940865096552

#@torch.jit.script
def Yl32_m1(theta, phi):
    return 0.0989771136930781*(1.0 - cos(theta)**2)**0.5*(13654113865.9611*cos(theta)**31 - 100780364248.76*cos(theta)**29 + 335383835122.923*cos(theta)**27 - 665083198464.102*cos(theta)**25 + 875109471663.293*cos(theta)**23 - 805100713930.229*cos(theta)**21 + 531670282784.114*cos(theta)**19 - 254665597636.088*cos(theta)**17 + 88353370608.4387*cos(theta)**15 - 21931687739.6834*cos(theta)**13 + 3801492541.54512*cos(theta)**11 - 442034016.458735*cos(theta)**9 + 32343952.4238098*cos(theta)**7 - 1339690.33708088*cos(theta)**5 + 25862.7478200942*cos(theta)**3 - 147.787130400538*cos(theta))*cos(phi)

#@torch.jit.script
def Yl32_m2(theta, phi):
    return 0.00304869851769809*(1.0 - cos(theta)**2)*(423277529844.793*cos(theta)**30 - 2922630563214.05*cos(theta)**28 + 9055363548318.93*cos(theta)**26 - 16627079961602.6*cos(theta)**24 + 20127517848255.7*cos(theta)**22 - 16907114992534.8*cos(theta)**20 + 10101735372898.2*cos(theta)**18 - 4329315159813.5*cos(theta)**16 + 1325300559126.58*cos(theta)**14 - 285111940615.884*cos(theta)**12 + 41816417956.9963*cos(theta)**10 - 3978306148.12861*cos(theta)**8 + 226407666.966669*cos(theta)**6 - 6698451.6854044*cos(theta)**4 + 77588.2434602827*cos(theta)**2 - 147.787130400538)*cos(2*phi)

#@torch.jit.script
def Yl32_m3(theta, phi):
    return 9.40848788610558e-5*(1.0 - cos(theta)**2)**1.5*(12698325895343.8*cos(theta)**29 - 81833655769993.3*cos(theta)**27 + 235439452256292.0*cos(theta)**25 - 399049919078461.0*cos(theta)**23 + 442805392661626.0*cos(theta)**21 - 338142299850696.0*cos(theta)**19 + 181831236712167.0*cos(theta)**17 - 69269042557015.9*cos(theta)**15 + 18554207827772.1*cos(theta)**13 - 3421343287390.6*cos(theta)**11 + 418164179569.963*cos(theta)**9 - 31826449185.0289*cos(theta)**7 + 1358446001.80001*cos(theta)**5 - 26793806.7416176*cos(theta)**3 + 155176.486920565*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl32_m4(theta, phi):
    return 2.91185389957512e-6*(1.0 - cos(theta)**2)**2*(368251450964970.0*cos(theta)**28 - 2.20950870578982e+15*cos(theta)**26 + 5.88598630640731e+15*cos(theta)**24 - 9.17814813880461e+15*cos(theta)**22 + 9.29891324589415e+15*cos(theta)**20 - 6.42470369716323e+15*cos(theta)**18 + 3.09113102410684e+15*cos(theta)**16 - 1.03903563835524e+15*cos(theta)**14 + 241204701761038.0*cos(theta)**12 - 37634776161296.7*cos(theta)**10 + 3763477616129.67*cos(theta)**8 - 222785144295.202*cos(theta)**6 + 6792230009.00007*cos(theta)**4 - 80381420.2248529*cos(theta)**2 + 155176.486920565)*cos(4*phi)

#@torch.jit.script
def Yl32_m5(theta, phi):
    return 9.04668988104336e-8*(1.0 - cos(theta)**2)**2.5*(1.03110406270192e+16*cos(theta)**27 - 5.74472263505353e+16*cos(theta)**25 + 1.41263671353775e+17*cos(theta)**23 - 2.01919259053701e+17*cos(theta)**21 + 1.85978264917883e+17*cos(theta)**19 - 1.15644666548938e+17*cos(theta)**17 + 4.94580963857094e+16*cos(theta)**15 - 1.45464989369733e+16*cos(theta)**13 + 2.89445642113245e+15*cos(theta)**11 - 376347761612967.0*cos(theta)**9 + 30107820929037.3*cos(theta)**7 - 1336710865771.21*cos(theta)**5 + 27168920036.0003*cos(theta)**3 - 160762840.449706*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl32_m6(theta, phi):
    return 2.8243337947883e-9*(1.0 - cos(theta)**2)**3*(2.78398096929517e+17*cos(theta)**26 - 1.43618065876338e+18*cos(theta)**24 + 3.24906444113683e+18*cos(theta)**22 - 4.24030444012773e+18*cos(theta)**20 + 3.53358703343978e+18*cos(theta)**18 - 1.96595933133195e+18*cos(theta)**16 + 7.41871445785641e+17*cos(theta)**14 - 1.89104486180654e+17*cos(theta)**12 + 3.1839020632457e+16*cos(theta)**10 - 3.3871298545167e+15*cos(theta)**8 + 210754746503261.0*cos(theta)**6 - 6683554328856.07*cos(theta)**4 + 81506760108.0008*cos(theta)**2 - 160762840.449706)*cos(6*phi)

#@torch.jit.script
def Yl32_m7(theta, phi):
    return 8.86945725708952e-11*(1.0 - cos(theta)**2)**3.5*(7.23835052016745e+18*cos(theta)**25 - 3.44683358103212e+19*cos(theta)**23 + 7.14794177050103e+19*cos(theta)**21 - 8.48060888025546e+19*cos(theta)**19 + 6.3604566601916e+19*cos(theta)**17 - 3.14553493013112e+19*cos(theta)**15 + 1.0386200240999e+19*cos(theta)**13 - 2.26925383416784e+18*cos(theta)**11 + 3.1839020632457e+17*cos(theta)**9 - 2.70970388361336e+16*cos(theta)**7 + 1.26452847901957e+15*cos(theta)**5 - 26734217315424.3*cos(theta)**3 + 163013520216.002*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl32_m8(theta, phi):
    return 2.80476865419125e-12*(1.0 - cos(theta)**2)**4*(1.80958763004186e+20*cos(theta)**24 - 7.92771723637387e+20*cos(theta)**22 + 1.50106777180522e+21*cos(theta)**20 - 1.61131568724854e+21*cos(theta)**18 + 1.08127763223257e+21*cos(theta)**16 - 4.71830239519668e+20*cos(theta)**14 + 1.35020603132987e+20*cos(theta)**12 - 2.49617921758463e+19*cos(theta)**10 + 2.86551185692113e+18*cos(theta)**8 - 1.89679271852935e+17*cos(theta)**6 + 6.32264239509784e+15*cos(theta)**4 - 80202651946272.8*cos(theta)**2 + 163013520216.002)*cos(8*phi)

#@torch.jit.script
def Yl32_m9(theta, phi):
    return 8.9412758972117e-14*(1.0 - cos(theta)**2)**4.5*(4.34301031210047e+21*cos(theta)**23 - 1.74409779200225e+22*cos(theta)**21 + 3.00213554361043e+22*cos(theta)**19 - 2.90036823704737e+22*cos(theta)**17 + 1.73004421157211e+22*cos(theta)**15 - 6.60562335327535e+21*cos(theta)**13 + 1.62024723759584e+21*cos(theta)**11 - 2.49617921758463e+20*cos(theta)**9 + 2.2924094855369e+19*cos(theta)**7 - 1.13807563111761e+18*cos(theta)**5 + 2.52905695803914e+16*cos(theta)**3 - 160405303892546.0*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl32_m10(theta, phi):
    return 2.87680836403125e-15*(1.0 - cos(theta)**2)**5*(9.98892371783108e+22*cos(theta)**22 - 3.66260536320473e+23*cos(theta)**20 + 5.70405753285982e+23*cos(theta)**18 - 4.93062600298053e+23*cos(theta)**16 + 2.59506631735817e+23*cos(theta)**14 - 8.58731035925795e+22*cos(theta)**12 + 1.78227196135542e+22*cos(theta)**10 - 2.24656129582616e+21*cos(theta)**8 + 1.60468663987583e+20*cos(theta)**6 - 5.69037815558805e+18*cos(theta)**4 + 7.58717087411741e+16*cos(theta)**2 - 160405303892546.0)*cos(10*phi)

#@torch.jit.script
def Yl32_m11(theta, phi):
    return 9.35331077456894e-17*(1.0 - cos(theta)**2)**5.5*(2.19756321792284e+24*cos(theta)**21 - 7.32521072640946e+24*cos(theta)**19 + 1.02673035591477e+25*cos(theta)**17 - 7.88900160476884e+24*cos(theta)**15 + 3.63309284430144e+24*cos(theta)**13 - 1.03047724311095e+24*cos(theta)**11 + 1.78227196135542e+23*cos(theta)**9 - 1.79724903666093e+22*cos(theta)**7 + 9.62811983925499e+20*cos(theta)**5 - 2.27615126223522e+19*cos(theta)**3 + 1.51743417482348e+17*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl32_m12(theta, phi):
    return 3.07701333880655e-18*(1.0 - cos(theta)**2)**6*(4.61488275763796e+25*cos(theta)**20 - 1.3917900380178e+26*cos(theta)**18 + 1.74544160505511e+26*cos(theta)**16 - 1.18335024071533e+26*cos(theta)**14 + 4.72302069759187e+25*cos(theta)**12 - 1.13352496742205e+25*cos(theta)**10 + 1.60404476521988e+24*cos(theta)**8 - 1.25807432566265e+23*cos(theta)**6 + 4.81405991962749e+21*cos(theta)**4 - 6.82845378670567e+19*cos(theta)**2 + 1.51743417482348e+17)*cos(12*phi)

#@torch.jit.script
def Yl32_m13(theta, phi):
    return 1.02567111293552e-19*(1.0 - cos(theta)**2)**6.5*(9.22976551527592e+26*cos(theta)**19 - 2.50522206843203e+27*cos(theta)**17 + 2.79270656808817e+27*cos(theta)**15 - 1.65669033700146e+27*cos(theta)**13 + 5.66762483711025e+26*cos(theta)**11 - 1.13352496742205e+26*cos(theta)**9 + 1.2832358121759e+25*cos(theta)**7 - 7.54844595397591e+23*cos(theta)**5 + 1.925623967851e+22*cos(theta)**3 - 1.36569075734113e+20*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl32_m14(theta, phi):
    return 3.4693842922622e-21*(1.0 - cos(theta)**2)**7*(1.75365544790242e+28*cos(theta)**18 - 4.25887751633446e+28*cos(theta)**16 + 4.18905985213225e+28*cos(theta)**14 - 2.15369743810189e+28*cos(theta)**12 + 6.23438732082127e+27*cos(theta)**10 - 1.02017247067984e+27*cos(theta)**8 + 8.98265068523133e+25*cos(theta)**6 - 3.77422297698796e+24*cos(theta)**4 + 5.77687190355299e+22*cos(theta)**2 - 1.36569075734113e+20)*cos(14*phi)

#@torch.jit.script
def Yl32_m15(theta, phi):
    return 1.19279889015859e-22*(1.0 - cos(theta)**2)**7.5*(3.15657980622436e+29*cos(theta)**17 - 6.81420402613513e+29*cos(theta)**15 + 5.86468379298516e+29*cos(theta)**13 - 2.58443692572227e+29*cos(theta)**11 + 6.23438732082127e+28*cos(theta)**9 - 8.16137976543875e+27*cos(theta)**7 + 5.3895904111388e+26*cos(theta)**5 - 1.50968919079518e+25*cos(theta)**3 + 1.1553743807106e+23*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl32_m16(theta, phi):
    return 4.17563132534946e-24*(1.0 - cos(theta)**2)**8*(5.36618567058142e+30*cos(theta)**16 - 1.02213060392027e+31*cos(theta)**14 + 7.6240889308807e+30*cos(theta)**12 - 2.8428806182945e+30*cos(theta)**10 + 5.61094858873914e+29*cos(theta)**8 - 5.71296583580713e+28*cos(theta)**6 + 2.6947952055694e+27*cos(theta)**4 - 4.52906757238555e+25*cos(theta)**2 + 1.1553743807106e+23)*cos(16*phi)

#@torch.jit.script
def Yl32_m17(theta, phi):
    return 1.49129690191052e-25*(1.0 - cos(theta)**2)**8.5*(8.58589707293027e+31*cos(theta)**15 - 1.43098284548838e+32*cos(theta)**13 + 9.14890671705684e+31*cos(theta)**11 - 2.8428806182945e+31*cos(theta)**9 + 4.48875887099132e+30*cos(theta)**7 - 3.42777950148428e+29*cos(theta)**5 + 1.07791808222776e+28*cos(theta)**3 - 9.05813514477109e+25*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl32_m18(theta, phi):
    return 5.44544635409307e-27*(1.0 - cos(theta)**2)**9*(1.28788456093954e+33*cos(theta)**14 - 1.86027769913489e+33*cos(theta)**12 + 1.00637973887625e+33*cos(theta)**10 - 2.55859255646505e+32*cos(theta)**8 + 3.14213120969392e+31*cos(theta)**6 - 1.71388975074214e+30*cos(theta)**4 + 3.23375424668328e+28*cos(theta)**2 - 9.05813514477109e+25)*cos(18*phi)

#@torch.jit.script
def Yl32_m19(theta, phi):
    return 2.03790707968959e-28*(1.0 - cos(theta)**2)**9.5*(1.80303838531536e+34*cos(theta)**13 - 2.23233323896187e+34*cos(theta)**11 + 1.00637973887625e+34*cos(theta)**9 - 2.04687404517204e+33*cos(theta)**7 + 1.88527872581635e+32*cos(theta)**5 - 6.85555900296855e+30*cos(theta)**3 + 6.46750849336656e+28*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl32_m20(theta, phi):
    return 7.83810415265227e-30*(1.0 - cos(theta)**2)**10*(2.34394990090996e+35*cos(theta)**12 - 2.45556656285806e+35*cos(theta)**10 + 9.05741764988628e+34*cos(theta)**8 - 1.43281183162043e+34*cos(theta)**6 + 9.42639362908176e+32*cos(theta)**4 - 2.05666770089057e+31*cos(theta)**2 + 6.46750849336656e+28)*cos(20*phi)

#@torch.jit.script
def Yl32_m21(theta, phi):
    return 3.10801046364243e-31*(1.0 - cos(theta)**2)**10.5*(2.81273988109196e+36*cos(theta)**11 - 2.45556656285806e+36*cos(theta)**9 + 7.24593411990902e+35*cos(theta)**7 - 8.59687098972257e+34*cos(theta)**5 + 3.7705574516327e+33*cos(theta)**3 - 4.11333540178113e+31*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl32_m22(theta, phi):
    return 1.27523213983038e-32*(1.0 - cos(theta)**2)**11*(3.09401386920115e+37*cos(theta)**10 - 2.21000990657225e+37*cos(theta)**8 + 5.07215388393631e+36*cos(theta)**6 - 4.29843549486128e+35*cos(theta)**4 + 1.13116723548981e+34*cos(theta)**2 - 4.11333540178113e+31)*cos(22*phi)

#@torch.jit.script
def Yl32_m23(theta, phi):
    return 5.43760811463069e-34*(1.0 - cos(theta)**2)**11.5*(3.09401386920115e+38*cos(theta)**9 - 1.7680079252578e+38*cos(theta)**7 + 3.04329233036179e+37*cos(theta)**5 - 1.71937419794451e+36*cos(theta)**3 + 2.26233447097962e+34*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl32_m24(theta, phi):
    return 2.42210316291546e-35*(1.0 - cos(theta)**2)**12*(2.78461248228104e+39*cos(theta)**8 - 1.23760554768046e+39*cos(theta)**6 + 1.52164616518089e+38*cos(theta)**4 - 5.15812259383354e+36*cos(theta)**2 + 2.26233447097962e+34)*cos(24*phi)

#@torch.jit.script
def Yl32_m25(theta, phi):
    return 1.13425372828688e-36*(1.0 - cos(theta)**2)**12.5*(2.22768998582483e+40*cos(theta)**7 - 7.42563328608276e+39*cos(theta)**5 + 6.08658466072358e+38*cos(theta)**3 - 1.03162451876671e+37*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl32_m26(theta, phi):
    return 5.62920673595975e-38*(1.0 - cos(theta)**2)**13*(1.55938299007738e+41*cos(theta)**6 - 3.71281664304138e+40*cos(theta)**4 + 1.82597539821707e+39*cos(theta)**2 - 1.03162451876671e+37)*cos(26*phi)

#@torch.jit.script
def Yl32_m27(theta, phi):
    return 2.99188962435835e-39*(1.0 - cos(theta)**2)**13.5*(9.35629794046428e+41*cos(theta)**5 - 1.48512665721655e+41*cos(theta)**3 + 3.65195079643415e+39*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl32_m28(theta, phi):
    return 1.72736828000894e-40*(1.0 - cos(theta)**2)**14*(4.67814897023214e+42*cos(theta)**4 - 4.45537997164966e+41*cos(theta)**2 + 3.65195079643415e+39)*cos(28*phi)

#@torch.jit.script
def Yl32_m29(theta, phi):
    return 1.10583422533699e-41*(1.0 - cos(theta)**2)**14.5*(1.87125958809286e+43*cos(theta)**3 - 8.91075994329932e+41*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl32_m30(theta, phi):
    return 8.10836994187712e-43*(1.0 - cos(theta)**2)**15*(5.61377876427857e+43*cos(theta)**2 - 8.91075994329932e+41)*cos(30*phi)

#@torch.jit.script
def Yl32_m31(theta, phi):
    return 8.11023748522498*(1.0 - cos(theta)**2)**15.5*cos(31*phi)*cos(theta)

#@torch.jit.script
def Yl32_m32(theta, phi):
    return 1.01377968565312*(1.0 - cos(theta)**2)**16*cos(32*phi)

#@torch.jit.script
def Yl33_m_minus_33(theta, phi):
    return 1.02143096163768*(1.0 - cos(theta)**2)**16.5*sin(33*phi)

#@torch.jit.script
def Yl33_m_minus_32(theta, phi):
    return 8.29814436002877*(1.0 - cos(theta)**2)**16*sin(32*phi)*cos(theta)

#@torch.jit.script
def Yl33_m_minus_31(theta, phi):
    return 1.29644475885681e-44*(1.0 - cos(theta)**2)**15.5*(3.64895619678107e+45*cos(theta)**2 - 5.61377876427857e+43)*sin(31*phi)

#@torch.jit.script
def Yl33_m_minus_30(theta, phi):
    return 1.7964065532371e-43*(1.0 - cos(theta)**2)**15*(1.21631873226036e+45*cos(theta)**3 - 5.61377876427857e+43*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl33_m_minus_29(theta, phi):
    return 2.85170699605925e-42*(1.0 - cos(theta)**2)**14.5*(3.04079683065089e+44*cos(theta)**4 - 2.80688938213928e+43*cos(theta)**2 + 2.22768998582483e+41)*sin(29*phi)

#@torch.jit.script
def Yl33_m_minus_28(theta, phi):
    return 5.02094828227271e-41*(1.0 - cos(theta)**2)**14*(6.08159366130178e+43*cos(theta)**5 - 9.35629794046428e+42*cos(theta)**3 + 2.22768998582483e+41*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl33_m_minus_27(theta, phi):
    return 9.60563965860272e-40*(1.0 - cos(theta)**2)**13.5*(1.0135989435503e+43*cos(theta)**6 - 2.33907448511607e+42*cos(theta)**4 + 1.11384499291241e+41*cos(theta)**2 - 6.08658466072358e+38)*sin(27*phi)

#@torch.jit.script
def Yl33_m_minus_26(theta, phi):
    return 1.96857033314502e-38*(1.0 - cos(theta)**2)**13*(1.44799849078614e+42*cos(theta)**7 - 4.67814897023214e+41*cos(theta)**5 + 3.71281664304138e+40*cos(theta)**3 - 6.08658466072358e+38*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl33_m_minus_25(theta, phi):
    return 4.27682948208865e-37*(1.0 - cos(theta)**2)**12.5*(1.80999811348267e+41*cos(theta)**8 - 7.7969149503869e+40*cos(theta)**6 + 9.28204160760346e+39*cos(theta)**4 - 3.04329233036179e+38*cos(theta)**2 + 1.28953064845838e+36)*sin(25*phi)

#@torch.jit.script
def Yl33_m_minus_24(theta, phi):
    return 9.77140888441698e-36*(1.0 - cos(theta)**2)**12*(2.01110901498075e+40*cos(theta)**9 - 1.11384499291241e+40*cos(theta)**7 + 1.85640832152069e+39*cos(theta)**5 - 1.01443077678726e+38*cos(theta)**3 + 1.28953064845838e+36*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl33_m_minus_23(theta, phi):
    return 2.33289189642992e-34*(1.0 - cos(theta)**2)**11.5*(2.01110901498075e+39*cos(theta)**10 - 1.39230624114052e+39*cos(theta)**8 + 3.09401386920115e+38*cos(theta)**6 - 2.53607694196816e+37*cos(theta)**4 + 6.44765324229192e+35*cos(theta)**2 - 2.26233447097962e+33)*sin(23*phi)

#@torch.jit.script
def Yl33_m_minus_22(theta, phi):
    return 5.79008541721441e-33*(1.0 - cos(theta)**2)**11*(1.82828092270977e+38*cos(theta)**11 - 1.54700693460058e+38*cos(theta)**9 + 4.4200198131445e+37*cos(theta)**7 - 5.07215388393631e+36*cos(theta)**5 + 2.14921774743064e+35*cos(theta)**3 - 2.26233447097962e+33*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl33_m_minus_21(theta, phi):
    return 1.48749987668913e-31*(1.0 - cos(theta)**2)**10.5*(1.52356743559148e+37*cos(theta)**12 - 1.54700693460058e+37*cos(theta)**10 + 5.52502476643063e+36*cos(theta)**8 - 8.45358980656052e+35*cos(theta)**6 + 5.3730443685766e+34*cos(theta)**4 - 1.13116723548981e+33*cos(theta)**2 + 3.42777950148428e+30)*sin(21*phi)

#@torch.jit.script
def Yl33_m_minus_20(theta, phi):
    return 3.94117295988316e-30*(1.0 - cos(theta)**2)**10*(1.17197495045498e+36*cos(theta)**13 - 1.40636994054598e+36*cos(theta)**11 + 6.13891640714514e+35*cos(theta)**9 - 1.2076556866515e+35*cos(theta)**7 + 1.07460887371532e+34*cos(theta)**5 - 3.7705574516327e+32*cos(theta)**3 + 3.42777950148428e+30*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl33_m_minus_19(theta, phi):
    return 1.0735627820667e-28*(1.0 - cos(theta)**2)**9.5*(8.37124964610701e+34*cos(theta)**14 - 1.17197495045498e+35*cos(theta)**12 + 6.13891640714514e+34*cos(theta)**10 - 1.50956960831438e+34*cos(theta)**8 + 1.79101478952553e+33*cos(theta)**6 - 9.42639362908176e+31*cos(theta)**4 + 1.71388975074214e+30*cos(theta)**2 - 4.61964892383326e+27)*sin(19*phi)

#@torch.jit.script
def Yl33_m_minus_18(theta, phi):
    return 2.99829767816716e-27*(1.0 - cos(theta)**2)**9*(5.58083309740467e+33*cos(theta)**15 - 9.01519192657678e+33*cos(theta)**13 + 5.58083309740467e+33*cos(theta)**11 - 1.67729956479375e+33*cos(theta)**9 + 2.55859255646505e+32*cos(theta)**7 - 1.88527872581635e+31*cos(theta)**5 + 5.71296583580713e+29*cos(theta)**3 - 4.61964892383326e+27*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl33_m_minus_17(theta, phi):
    return 8.56485131043879e-26*(1.0 - cos(theta)**2)**8.5*(3.48802068587792e+32*cos(theta)**16 - 6.4394228046977e+32*cos(theta)**14 + 4.65069424783723e+32*cos(theta)**12 - 1.67729956479375e+32*cos(theta)**10 + 3.19824069558131e+31*cos(theta)**8 - 3.14213120969392e+30*cos(theta)**6 + 1.42824145895178e+29*cos(theta)**4 - 2.30982446191663e+27*cos(theta)**2 + 5.66133446548193e+24)*sin(17*phi)

#@torch.jit.script
def Yl33_m_minus_16(theta, phi):
    return 2.49706179888357e-24*(1.0 - cos(theta)**2)**8*(2.05177687404584e+31*cos(theta)**17 - 4.29294853646513e+31*cos(theta)**15 + 3.57745711372095e+31*cos(theta)**13 - 1.52481778617614e+31*cos(theta)**11 + 3.55360077286812e+30*cos(theta)**9 - 4.48875887099131e+29*cos(theta)**7 + 2.85648291790356e+28*cos(theta)**5 - 7.69941487305543e+26*cos(theta)**3 + 5.66133446548193e+24*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl33_m_minus_15(theta, phi):
    return 7.41589519033628e-23*(1.0 - cos(theta)**2)**7.5*(1.13987604113658e+30*cos(theta)**18 - 2.68309283529071e+30*cos(theta)**16 + 2.55532650980068e+30*cos(theta)**14 - 1.27068148848012e+30*cos(theta)**12 + 3.55360077286812e+29*cos(theta)**10 - 5.61094858873914e+28*cos(theta)**8 + 4.76080486317261e+27*cos(theta)**6 - 1.92485371826386e+26*cos(theta)**4 + 2.83066723274097e+24*cos(theta)**2 - 6.41874655950333e+21)*sin(15*phi)

#@torch.jit.script
def Yl33_m_minus_14(theta, phi):
    return 2.23955123505438e-21*(1.0 - cos(theta)**2)**7*(5.99934758492935e+28*cos(theta)**19 - 1.57828990311218e+29*cos(theta)**17 + 1.70355100653378e+29*cos(theta)**15 - 9.77447298830859e+28*cos(theta)**13 + 3.23054615715284e+28*cos(theta)**11 - 6.23438732082127e+27*cos(theta)**9 + 6.80114980453229e+26*cos(theta)**7 - 3.84970743652771e+25*cos(theta)**5 + 9.43555744246989e+23*cos(theta)**3 - 6.41874655950333e+21*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl33_m_minus_13(theta, phi):
    return 6.86633406583717e-20*(1.0 - cos(theta)**2)**6.5*(2.99967379246467e+27*cos(theta)**20 - 8.76827723951212e+27*cos(theta)**18 + 1.06471937908361e+28*cos(theta)**16 - 6.98176642022042e+27*cos(theta)**14 + 2.69212179762737e+27*cos(theta)**12 - 6.23438732082127e+26*cos(theta)**10 + 8.50143725566537e+25*cos(theta)**8 - 6.41617906087952e+24*cos(theta)**6 + 2.35888936061747e+23*cos(theta)**4 - 3.20937327975166e+21*cos(theta)**2 + 6.82845378670567e+18)*sin(13*phi)

#@torch.jit.script
def Yl33_m_minus_12(theta, phi):
    return 2.13409374265872e-18*(1.0 - cos(theta)**2)**6*(1.42841609164984e+26*cos(theta)**21 - 4.61488275763796e+26*cos(theta)**19 + 6.26305517108009e+26*cos(theta)**17 - 4.65451094681362e+26*cos(theta)**15 + 2.07086292125182e+26*cos(theta)**13 - 5.66762483711025e+25*cos(theta)**11 + 9.44604139518374e+24*cos(theta)**9 - 9.16597008697075e+23*cos(theta)**7 + 4.71777872123494e+22*cos(theta)**5 - 1.06979109325055e+21*cos(theta)**3 + 6.82845378670567e+18*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl33_m_minus_11(theta, phi):
    return 6.71476920037506e-17*(1.0 - cos(theta)**2)**5.5*(6.4928004165902e+24*cos(theta)**22 - 2.30744137881898e+25*cos(theta)**20 + 3.47947509504449e+25*cos(theta)**18 - 2.90906934175851e+25*cos(theta)**16 + 1.47918780089416e+25*cos(theta)**14 - 4.72302069759187e+24*cos(theta)**12 + 9.44604139518374e+23*cos(theta)**10 - 1.14574626087134e+23*cos(theta)**8 + 7.86296453539157e+21*cos(theta)**6 - 2.67447773312639e+20*cos(theta)**4 + 3.41422689335283e+18*cos(theta)**2 - 6.89742806737946e+15)*sin(11*phi)

#@torch.jit.script
def Yl33_m_minus_10(theta, phi):
    return 2.13609884881944e-15*(1.0 - cos(theta)**2)**5*(2.8229567028653e+23*cos(theta)**23 - 1.09878160896142e+24*cos(theta)**21 + 1.83130268160236e+24*cos(theta)**19 - 1.71121725985795e+24*cos(theta)**17 + 9.86125200596105e+23*cos(theta)**15 - 3.63309284430144e+23*cos(theta)**13 + 8.58731035925795e+22*cos(theta)**11 - 1.27305140096816e+22*cos(theta)**9 + 1.12328064791308e+21*cos(theta)**7 - 5.34895546625277e+19*cos(theta)**5 + 1.13807563111761e+18*cos(theta)**3 - 6.89742806737946e+15*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl33_m_minus_9(theta, phi):
    return 6.86216560370661e-14*(1.0 - cos(theta)**2)**4.5*(1.17623195952721e+22*cos(theta)**24 - 4.99446185891554e+22*cos(theta)**22 + 9.15651340801182e+22*cos(theta)**20 - 9.50676255476637e+22*cos(theta)**18 + 6.16328250372566e+22*cos(theta)**16 - 2.59506631735817e+22*cos(theta)**14 + 7.15609196604829e+21*cos(theta)**12 - 1.27305140096816e+21*cos(theta)**10 + 1.40410080989135e+20*cos(theta)**8 - 8.91492577708795e+18*cos(theta)**6 + 2.84518907779403e+17*cos(theta)**4 - 3.44871403368973e+15*cos(theta)**2 + 6683554328856.07)*sin(9*phi)

#@torch.jit.script
def Yl33_m_minus_8(theta, phi):
    return 2.2235957953578e-12*(1.0 - cos(theta)**2)**4*(4.70492783810884e+20*cos(theta)**25 - 2.17150515605023e+21*cos(theta)**23 + 4.36024448000563e+21*cos(theta)**21 - 5.00355923935072e+21*cos(theta)**19 + 3.62546029630921e+21*cos(theta)**17 - 1.73004421157211e+21*cos(theta)**15 + 5.50468612772945e+20*cos(theta)**13 - 1.1573194554256e+20*cos(theta)**11 + 1.56011201099039e+19*cos(theta)**9 - 1.27356082529828e+18*cos(theta)**7 + 5.69037815558805e+16*cos(theta)**5 - 1.14957134456324e+15*cos(theta)**3 + 6683554328856.07*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl33_m_minus_7(theta, phi):
    return 7.25996365443219e-11*(1.0 - cos(theta)**2)**3.5*(1.80958763004186e+19*cos(theta)**26 - 9.04793815020931e+19*cos(theta)**24 + 1.98192930909347e+20*cos(theta)**22 - 2.50177961967536e+20*cos(theta)**20 + 2.01414460906067e+20*cos(theta)**18 - 1.08127763223257e+20*cos(theta)**16 + 3.9319186626639e+19*cos(theta)**14 - 9.64432879521333e+18*cos(theta)**12 + 1.56011201099039e+18*cos(theta)**10 - 1.59195103162285e+17*cos(theta)**8 + 9.48396359264676e+15*cos(theta)**6 - 287392836140811.0*cos(theta)**4 + 3341777164428.03*cos(theta)**2 - 6269750777.53852)*sin(7*phi)

#@torch.jit.script
def Yl33_m_minus_6(theta, phi):
    return 2.38586751612009e-9*(1.0 - cos(theta)**2)**3*(6.70217640756245e+17*cos(theta)**27 - 3.61917526008372e+18*cos(theta)**25 + 8.6170839525803e+18*cos(theta)**23 - 1.19132362841684e+19*cos(theta)**21 + 1.06007611003193e+19*cos(theta)**19 - 6.3604566601916e+18*cos(theta)**17 + 2.6212791084426e+18*cos(theta)**15 - 7.41871445785641e+17*cos(theta)**13 + 1.4182836463549e+17*cos(theta)**11 - 1.76883447958094e+16*cos(theta)**9 + 1.35485194180668e+15*cos(theta)**7 - 57478567228162.2*cos(theta)**5 + 1113925721476.01*cos(theta)**3 - 6269750777.53852*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl33_m_minus_5(theta, phi):
    return 7.8842001969058e-8*(1.0 - cos(theta)**2)**2.5*(2.3936344312723e+16*cos(theta)**28 - 1.39199048464759e+17*cos(theta)**26 + 3.59045164690846e+17*cos(theta)**24 - 5.41510740189472e+17*cos(theta)**22 + 5.30038055015966e+17*cos(theta)**20 - 3.53358703343978e+17*cos(theta)**18 + 1.63829944277662e+17*cos(theta)**16 - 5.29908175561172e+16*cos(theta)**14 + 1.18190303862908e+16*cos(theta)**12 - 1.76883447958094e+15*cos(theta)**10 + 169356492725835.0*cos(theta)**8 - 9579761204693.69*cos(theta)**6 + 278481430369.003*cos(theta)**4 - 3134875388.76926*cos(theta)**2 + 5741530.01606092)*sin(5*phi)

#@torch.jit.script
def Yl33_m_minus_4(theta, phi):
    return 2.61726947876729e-6*(1.0 - cos(theta)**2)**2*(825391183197346.0*cos(theta)**29 - 5.15552031350958e+15*cos(theta)**27 + 1.43618065876338e+16*cos(theta)**25 - 2.35439452256292e+16*cos(theta)**23 + 2.52399073817127e+16*cos(theta)**21 - 1.85978264917883e+16*cos(theta)**19 + 9.63705554574484e+15*cos(theta)**17 - 3.53272117040781e+15*cos(theta)**15 + 909156183560834.0*cos(theta)**13 - 160803134507358.0*cos(theta)**11 + 18817388080648.3*cos(theta)**9 - 1368537314956.24*cos(theta)**7 + 55696286073.8005*cos(theta)**5 - 1044958462.92309*cos(theta)**3 + 5741530.01606092*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl33_m_minus_3(theta, phi):
    return 8.71986838901848e-5*(1.0 - cos(theta)**2)**1.5*(27513039439911.5*cos(theta)**30 - 184125725482485.0*cos(theta)**28 + 552377176447455.0*cos(theta)**26 - 980997717734551.0*cos(theta)**24 + 1.14726851735058e+15*cos(theta)**22 - 929891324589415.0*cos(theta)**20 + 535391974763602.0*cos(theta)**18 - 220795073150488.0*cos(theta)**16 + 64939727397202.4*cos(theta)**14 - 13400261208946.5*cos(theta)**12 + 1881738808064.83*cos(theta)**10 - 171067164369.53*cos(theta)**8 + 9282714345.63342*cos(theta)**6 - 261239615.730772*cos(theta)**4 + 2870765.00803046*cos(theta)**2 - 5172.54956401885)*sin(3*phi)

#@torch.jit.script
def Yl33_m_minus_2(theta, phi):
    return 0.00291301034789671*(1.0 - cos(theta)**2)*(887517401287.469*cos(theta)**31 - 6349162947671.89*cos(theta)**29 + 20458413942498.3*cos(theta)**27 - 39239908709382.0*cos(theta)**25 + 49881239884807.7*cos(theta)**23 - 44280539266162.6*cos(theta)**21 + 28178524987558.0*cos(theta)**19 - 12987945479440.5*cos(theta)**17 + 4329315159813.5*cos(theta)**15 - 1030789323765.12*cos(theta)**13 + 171067164369.53*cos(theta)**11 - 19007462707.7256*cos(theta)**9 + 1326102049.3762*cos(theta)**7 - 52247923.1461544*cos(theta)**5 + 956921.669343486*cos(theta)**3 - 5172.54956401885*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl33_m_minus_1(theta, phi):
    return 0.0974879725986118*(1.0 - cos(theta)**2)**0.5*(27734918790.2334*cos(theta)**32 - 211638764922.396*cos(theta)**30 + 730657640803.512*cos(theta)**28 - 1509227258053.16*cos(theta)**26 + 2078384995200.32*cos(theta)**24 - 2012751784825.57*cos(theta)**22 + 1408926249377.9*cos(theta)**20 - 721552526635.583*cos(theta)**18 + 270582197488.344*cos(theta)**16 - 73627808840.3656*cos(theta)**14 + 14255597030.7942*cos(theta)**12 - 1900746270.77256*cos(theta)**10 + 165762756.172025*cos(theta)**8 - 8707987.19102573*cos(theta)**6 + 239230.417335872*cos(theta)**4 - 2586.27478200942*cos(theta)**2 + 4.61834782501683)*sin(phi)

#@torch.jit.script
def Yl33_m0(theta, phi):
    return 6096706674.96088*cos(theta)**33 - 49524017298.1438*cos(theta)**31 + 182767206695.531*cos(theta)**29 - 405483529608.663*cos(theta)**27 + 603070842765.427*cos(theta)**25 - 634811413437.292*cos(theta)**23 + 486688750301.924*cos(theta)**21 - 275484198284.108*cos(theta)**19 + 115460288986.722*cos(theta)**17 - 35606801138.7622*cos(theta)**15 + 7954710892.7022*cos(theta)**13 - 1253469595.21368*cos(theta)**11 + 133606255.303784*cos(theta)**9 - 9024062.27192536*cos(theta)**7 + 347079.318150975*cos(theta)**5 - 6253.68140812568*cos(theta)**3 + 33.5018646863876*cos(theta)

#@torch.jit.script
def Yl33_m1(theta, phi):
    return 0.0974879725986118*(1.0 - cos(theta)**2)**0.5*(27734918790.2334*cos(theta)**32 - 211638764922.396*cos(theta)**30 + 730657640803.512*cos(theta)**28 - 1509227258053.16*cos(theta)**26 + 2078384995200.32*cos(theta)**24 - 2012751784825.57*cos(theta)**22 + 1408926249377.9*cos(theta)**20 - 721552526635.583*cos(theta)**18 + 270582197488.344*cos(theta)**16 - 73627808840.3656*cos(theta)**14 + 14255597030.7942*cos(theta)**12 - 1900746270.77256*cos(theta)**10 + 165762756.172025*cos(theta)**8 - 8707987.19102573*cos(theta)**6 + 239230.417335872*cos(theta)**4 - 2586.27478200942*cos(theta)**2 + 4.61834782501683)*cos(phi)

#@torch.jit.script
def Yl33_m2(theta, phi):
    return 0.00291301034789671*(1.0 - cos(theta)**2)*(887517401287.469*cos(theta)**31 - 6349162947671.89*cos(theta)**29 + 20458413942498.3*cos(theta)**27 - 39239908709382.0*cos(theta)**25 + 49881239884807.7*cos(theta)**23 - 44280539266162.6*cos(theta)**21 + 28178524987558.0*cos(theta)**19 - 12987945479440.5*cos(theta)**17 + 4329315159813.5*cos(theta)**15 - 1030789323765.12*cos(theta)**13 + 171067164369.53*cos(theta)**11 - 19007462707.7256*cos(theta)**9 + 1326102049.3762*cos(theta)**7 - 52247923.1461544*cos(theta)**5 + 956921.669343486*cos(theta)**3 - 5172.54956401885*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl33_m3(theta, phi):
    return 8.71986838901848e-5*(1.0 - cos(theta)**2)**1.5*(27513039439911.5*cos(theta)**30 - 184125725482485.0*cos(theta)**28 + 552377176447455.0*cos(theta)**26 - 980997717734551.0*cos(theta)**24 + 1.14726851735058e+15*cos(theta)**22 - 929891324589415.0*cos(theta)**20 + 535391974763602.0*cos(theta)**18 - 220795073150488.0*cos(theta)**16 + 64939727397202.4*cos(theta)**14 - 13400261208946.5*cos(theta)**12 + 1881738808064.83*cos(theta)**10 - 171067164369.53*cos(theta)**8 + 9282714345.63342*cos(theta)**6 - 261239615.730772*cos(theta)**4 + 2870765.00803046*cos(theta)**2 - 5172.54956401885)*cos(3*phi)

#@torch.jit.script
def Yl33_m4(theta, phi):
    return 2.61726947876729e-6*(1.0 - cos(theta)**2)**2*(825391183197346.0*cos(theta)**29 - 5.15552031350958e+15*cos(theta)**27 + 1.43618065876338e+16*cos(theta)**25 - 2.35439452256292e+16*cos(theta)**23 + 2.52399073817127e+16*cos(theta)**21 - 1.85978264917883e+16*cos(theta)**19 + 9.63705554574484e+15*cos(theta)**17 - 3.53272117040781e+15*cos(theta)**15 + 909156183560834.0*cos(theta)**13 - 160803134507358.0*cos(theta)**11 + 18817388080648.3*cos(theta)**9 - 1368537314956.24*cos(theta)**7 + 55696286073.8005*cos(theta)**5 - 1044958462.92309*cos(theta)**3 + 5741530.01606092*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl33_m5(theta, phi):
    return 7.8842001969058e-8*(1.0 - cos(theta)**2)**2.5*(2.3936344312723e+16*cos(theta)**28 - 1.39199048464759e+17*cos(theta)**26 + 3.59045164690846e+17*cos(theta)**24 - 5.41510740189472e+17*cos(theta)**22 + 5.30038055015966e+17*cos(theta)**20 - 3.53358703343978e+17*cos(theta)**18 + 1.63829944277662e+17*cos(theta)**16 - 5.29908175561172e+16*cos(theta)**14 + 1.18190303862908e+16*cos(theta)**12 - 1.76883447958094e+15*cos(theta)**10 + 169356492725835.0*cos(theta)**8 - 9579761204693.69*cos(theta)**6 + 278481430369.003*cos(theta)**4 - 3134875388.76926*cos(theta)**2 + 5741530.01606092)*cos(5*phi)

#@torch.jit.script
def Yl33_m6(theta, phi):
    return 2.38586751612009e-9*(1.0 - cos(theta)**2)**3*(6.70217640756245e+17*cos(theta)**27 - 3.61917526008372e+18*cos(theta)**25 + 8.6170839525803e+18*cos(theta)**23 - 1.19132362841684e+19*cos(theta)**21 + 1.06007611003193e+19*cos(theta)**19 - 6.3604566601916e+18*cos(theta)**17 + 2.6212791084426e+18*cos(theta)**15 - 7.41871445785641e+17*cos(theta)**13 + 1.4182836463549e+17*cos(theta)**11 - 1.76883447958094e+16*cos(theta)**9 + 1.35485194180668e+15*cos(theta)**7 - 57478567228162.2*cos(theta)**5 + 1113925721476.01*cos(theta)**3 - 6269750777.53852*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl33_m7(theta, phi):
    return 7.25996365443219e-11*(1.0 - cos(theta)**2)**3.5*(1.80958763004186e+19*cos(theta)**26 - 9.04793815020931e+19*cos(theta)**24 + 1.98192930909347e+20*cos(theta)**22 - 2.50177961967536e+20*cos(theta)**20 + 2.01414460906067e+20*cos(theta)**18 - 1.08127763223257e+20*cos(theta)**16 + 3.9319186626639e+19*cos(theta)**14 - 9.64432879521333e+18*cos(theta)**12 + 1.56011201099039e+18*cos(theta)**10 - 1.59195103162285e+17*cos(theta)**8 + 9.48396359264676e+15*cos(theta)**6 - 287392836140811.0*cos(theta)**4 + 3341777164428.03*cos(theta)**2 - 6269750777.53852)*cos(7*phi)

#@torch.jit.script
def Yl33_m8(theta, phi):
    return 2.2235957953578e-12*(1.0 - cos(theta)**2)**4*(4.70492783810884e+20*cos(theta)**25 - 2.17150515605023e+21*cos(theta)**23 + 4.36024448000563e+21*cos(theta)**21 - 5.00355923935072e+21*cos(theta)**19 + 3.62546029630921e+21*cos(theta)**17 - 1.73004421157211e+21*cos(theta)**15 + 5.50468612772945e+20*cos(theta)**13 - 1.1573194554256e+20*cos(theta)**11 + 1.56011201099039e+19*cos(theta)**9 - 1.27356082529828e+18*cos(theta)**7 + 5.69037815558805e+16*cos(theta)**5 - 1.14957134456324e+15*cos(theta)**3 + 6683554328856.07*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl33_m9(theta, phi):
    return 6.86216560370661e-14*(1.0 - cos(theta)**2)**4.5*(1.17623195952721e+22*cos(theta)**24 - 4.99446185891554e+22*cos(theta)**22 + 9.15651340801182e+22*cos(theta)**20 - 9.50676255476637e+22*cos(theta)**18 + 6.16328250372566e+22*cos(theta)**16 - 2.59506631735817e+22*cos(theta)**14 + 7.15609196604829e+21*cos(theta)**12 - 1.27305140096816e+21*cos(theta)**10 + 1.40410080989135e+20*cos(theta)**8 - 8.91492577708795e+18*cos(theta)**6 + 2.84518907779403e+17*cos(theta)**4 - 3.44871403368973e+15*cos(theta)**2 + 6683554328856.07)*cos(9*phi)

#@torch.jit.script
def Yl33_m10(theta, phi):
    return 2.13609884881944e-15*(1.0 - cos(theta)**2)**5*(2.8229567028653e+23*cos(theta)**23 - 1.09878160896142e+24*cos(theta)**21 + 1.83130268160236e+24*cos(theta)**19 - 1.71121725985795e+24*cos(theta)**17 + 9.86125200596105e+23*cos(theta)**15 - 3.63309284430144e+23*cos(theta)**13 + 8.58731035925795e+22*cos(theta)**11 - 1.27305140096816e+22*cos(theta)**9 + 1.12328064791308e+21*cos(theta)**7 - 5.34895546625277e+19*cos(theta)**5 + 1.13807563111761e+18*cos(theta)**3 - 6.89742806737946e+15*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl33_m11(theta, phi):
    return 6.71476920037506e-17*(1.0 - cos(theta)**2)**5.5*(6.4928004165902e+24*cos(theta)**22 - 2.30744137881898e+25*cos(theta)**20 + 3.47947509504449e+25*cos(theta)**18 - 2.90906934175851e+25*cos(theta)**16 + 1.47918780089416e+25*cos(theta)**14 - 4.72302069759187e+24*cos(theta)**12 + 9.44604139518374e+23*cos(theta)**10 - 1.14574626087134e+23*cos(theta)**8 + 7.86296453539157e+21*cos(theta)**6 - 2.67447773312639e+20*cos(theta)**4 + 3.41422689335283e+18*cos(theta)**2 - 6.89742806737946e+15)*cos(11*phi)

#@torch.jit.script
def Yl33_m12(theta, phi):
    return 2.13409374265872e-18*(1.0 - cos(theta)**2)**6*(1.42841609164984e+26*cos(theta)**21 - 4.61488275763796e+26*cos(theta)**19 + 6.26305517108009e+26*cos(theta)**17 - 4.65451094681362e+26*cos(theta)**15 + 2.07086292125182e+26*cos(theta)**13 - 5.66762483711025e+25*cos(theta)**11 + 9.44604139518374e+24*cos(theta)**9 - 9.16597008697075e+23*cos(theta)**7 + 4.71777872123494e+22*cos(theta)**5 - 1.06979109325055e+21*cos(theta)**3 + 6.82845378670567e+18*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl33_m13(theta, phi):
    return 6.86633406583717e-20*(1.0 - cos(theta)**2)**6.5*(2.99967379246467e+27*cos(theta)**20 - 8.76827723951212e+27*cos(theta)**18 + 1.06471937908361e+28*cos(theta)**16 - 6.98176642022042e+27*cos(theta)**14 + 2.69212179762737e+27*cos(theta)**12 - 6.23438732082127e+26*cos(theta)**10 + 8.50143725566537e+25*cos(theta)**8 - 6.41617906087952e+24*cos(theta)**6 + 2.35888936061747e+23*cos(theta)**4 - 3.20937327975166e+21*cos(theta)**2 + 6.82845378670567e+18)*cos(13*phi)

#@torch.jit.script
def Yl33_m14(theta, phi):
    return 2.23955123505438e-21*(1.0 - cos(theta)**2)**7*(5.99934758492935e+28*cos(theta)**19 - 1.57828990311218e+29*cos(theta)**17 + 1.70355100653378e+29*cos(theta)**15 - 9.77447298830859e+28*cos(theta)**13 + 3.23054615715284e+28*cos(theta)**11 - 6.23438732082127e+27*cos(theta)**9 + 6.80114980453229e+26*cos(theta)**7 - 3.84970743652771e+25*cos(theta)**5 + 9.43555744246989e+23*cos(theta)**3 - 6.41874655950333e+21*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl33_m15(theta, phi):
    return 7.41589519033628e-23*(1.0 - cos(theta)**2)**7.5*(1.13987604113658e+30*cos(theta)**18 - 2.68309283529071e+30*cos(theta)**16 + 2.55532650980068e+30*cos(theta)**14 - 1.27068148848012e+30*cos(theta)**12 + 3.55360077286812e+29*cos(theta)**10 - 5.61094858873914e+28*cos(theta)**8 + 4.76080486317261e+27*cos(theta)**6 - 1.92485371826386e+26*cos(theta)**4 + 2.83066723274097e+24*cos(theta)**2 - 6.41874655950333e+21)*cos(15*phi)

#@torch.jit.script
def Yl33_m16(theta, phi):
    return 2.49706179888357e-24*(1.0 - cos(theta)**2)**8*(2.05177687404584e+31*cos(theta)**17 - 4.29294853646513e+31*cos(theta)**15 + 3.57745711372095e+31*cos(theta)**13 - 1.52481778617614e+31*cos(theta)**11 + 3.55360077286812e+30*cos(theta)**9 - 4.48875887099131e+29*cos(theta)**7 + 2.85648291790356e+28*cos(theta)**5 - 7.69941487305543e+26*cos(theta)**3 + 5.66133446548193e+24*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl33_m17(theta, phi):
    return 8.56485131043879e-26*(1.0 - cos(theta)**2)**8.5*(3.48802068587792e+32*cos(theta)**16 - 6.4394228046977e+32*cos(theta)**14 + 4.65069424783723e+32*cos(theta)**12 - 1.67729956479375e+32*cos(theta)**10 + 3.19824069558131e+31*cos(theta)**8 - 3.14213120969392e+30*cos(theta)**6 + 1.42824145895178e+29*cos(theta)**4 - 2.30982446191663e+27*cos(theta)**2 + 5.66133446548193e+24)*cos(17*phi)

#@torch.jit.script
def Yl33_m18(theta, phi):
    return 2.99829767816716e-27*(1.0 - cos(theta)**2)**9*(5.58083309740467e+33*cos(theta)**15 - 9.01519192657678e+33*cos(theta)**13 + 5.58083309740467e+33*cos(theta)**11 - 1.67729956479375e+33*cos(theta)**9 + 2.55859255646505e+32*cos(theta)**7 - 1.88527872581635e+31*cos(theta)**5 + 5.71296583580713e+29*cos(theta)**3 - 4.61964892383326e+27*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl33_m19(theta, phi):
    return 1.0735627820667e-28*(1.0 - cos(theta)**2)**9.5*(8.37124964610701e+34*cos(theta)**14 - 1.17197495045498e+35*cos(theta)**12 + 6.13891640714514e+34*cos(theta)**10 - 1.50956960831438e+34*cos(theta)**8 + 1.79101478952553e+33*cos(theta)**6 - 9.42639362908176e+31*cos(theta)**4 + 1.71388975074214e+30*cos(theta)**2 - 4.61964892383326e+27)*cos(19*phi)

#@torch.jit.script
def Yl33_m20(theta, phi):
    return 3.94117295988316e-30*(1.0 - cos(theta)**2)**10*(1.17197495045498e+36*cos(theta)**13 - 1.40636994054598e+36*cos(theta)**11 + 6.13891640714514e+35*cos(theta)**9 - 1.2076556866515e+35*cos(theta)**7 + 1.07460887371532e+34*cos(theta)**5 - 3.7705574516327e+32*cos(theta)**3 + 3.42777950148428e+30*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl33_m21(theta, phi):
    return 1.48749987668913e-31*(1.0 - cos(theta)**2)**10.5*(1.52356743559148e+37*cos(theta)**12 - 1.54700693460058e+37*cos(theta)**10 + 5.52502476643063e+36*cos(theta)**8 - 8.45358980656052e+35*cos(theta)**6 + 5.3730443685766e+34*cos(theta)**4 - 1.13116723548981e+33*cos(theta)**2 + 3.42777950148428e+30)*cos(21*phi)

#@torch.jit.script
def Yl33_m22(theta, phi):
    return 5.79008541721441e-33*(1.0 - cos(theta)**2)**11*(1.82828092270977e+38*cos(theta)**11 - 1.54700693460058e+38*cos(theta)**9 + 4.4200198131445e+37*cos(theta)**7 - 5.07215388393631e+36*cos(theta)**5 + 2.14921774743064e+35*cos(theta)**3 - 2.26233447097962e+33*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl33_m23(theta, phi):
    return 2.33289189642992e-34*(1.0 - cos(theta)**2)**11.5*(2.01110901498075e+39*cos(theta)**10 - 1.39230624114052e+39*cos(theta)**8 + 3.09401386920115e+38*cos(theta)**6 - 2.53607694196816e+37*cos(theta)**4 + 6.44765324229192e+35*cos(theta)**2 - 2.26233447097962e+33)*cos(23*phi)

#@torch.jit.script
def Yl33_m24(theta, phi):
    return 9.77140888441698e-36*(1.0 - cos(theta)**2)**12*(2.01110901498075e+40*cos(theta)**9 - 1.11384499291241e+40*cos(theta)**7 + 1.85640832152069e+39*cos(theta)**5 - 1.01443077678726e+38*cos(theta)**3 + 1.28953064845838e+36*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl33_m25(theta, phi):
    return 4.27682948208865e-37*(1.0 - cos(theta)**2)**12.5*(1.80999811348267e+41*cos(theta)**8 - 7.7969149503869e+40*cos(theta)**6 + 9.28204160760346e+39*cos(theta)**4 - 3.04329233036179e+38*cos(theta)**2 + 1.28953064845838e+36)*cos(25*phi)

#@torch.jit.script
def Yl33_m26(theta, phi):
    return 1.96857033314502e-38*(1.0 - cos(theta)**2)**13*(1.44799849078614e+42*cos(theta)**7 - 4.67814897023214e+41*cos(theta)**5 + 3.71281664304138e+40*cos(theta)**3 - 6.08658466072358e+38*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl33_m27(theta, phi):
    return 9.60563965860272e-40*(1.0 - cos(theta)**2)**13.5*(1.0135989435503e+43*cos(theta)**6 - 2.33907448511607e+42*cos(theta)**4 + 1.11384499291241e+41*cos(theta)**2 - 6.08658466072358e+38)*cos(27*phi)

#@torch.jit.script
def Yl33_m28(theta, phi):
    return 5.02094828227271e-41*(1.0 - cos(theta)**2)**14*(6.08159366130178e+43*cos(theta)**5 - 9.35629794046428e+42*cos(theta)**3 + 2.22768998582483e+41*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl33_m29(theta, phi):
    return 2.85170699605925e-42*(1.0 - cos(theta)**2)**14.5*(3.04079683065089e+44*cos(theta)**4 - 2.80688938213928e+43*cos(theta)**2 + 2.22768998582483e+41)*cos(29*phi)

#@torch.jit.script
def Yl33_m30(theta, phi):
    return 1.7964065532371e-43*(1.0 - cos(theta)**2)**15*(1.21631873226036e+45*cos(theta)**3 - 5.61377876427857e+43*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl33_m31(theta, phi):
    return 1.29644475885681e-44*(1.0 - cos(theta)**2)**15.5*(3.64895619678107e+45*cos(theta)**2 - 5.61377876427857e+43)*cos(31*phi)

#@torch.jit.script
def Yl33_m32(theta, phi):
    return 8.29814436002877*(1.0 - cos(theta)**2)**16*cos(32*phi)*cos(theta)

#@torch.jit.script
def Yl33_m33(theta, phi):
    return 1.02143096163768*(1.0 - cos(theta)**2)**16.5*cos(33*phi)

#@torch.jit.script
def Yl34_m_minus_34(theta, phi):
    return 1.0289140723859*(1.0 - cos(theta)**2)**17*sin(34*phi)

#@torch.jit.script
def Yl34_m_minus_33(theta, phi):
    return 8.48464280026292*(1.0 - cos(theta)**2)**16.5*sin(33*phi)*cos(theta)

#@torch.jit.script
def Yl34_m_minus_32(theta, phi):
    return 2.0086881349656e-46*(1.0 - cos(theta)**2)**16*(2.44480065184332e+47*cos(theta)**2 - 3.64895619678107e+45)*sin(32*phi)

#@torch.jit.script
def Yl34_m_minus_31(theta, phi):
    return 2.8264747454439e-45*(1.0 - cos(theta)**2)**15.5*(8.14933550614439e+46*cos(theta)**3 - 3.64895619678107e+45*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl34_m_minus_30(theta, phi):
    return 4.55755358336505e-44*(1.0 - cos(theta)**2)**15*(2.0373338765361e+46*cos(theta)**4 - 1.82447809839054e+45*cos(theta)**2 + 1.40344469106964e+43)*sin(30*phi)

#@torch.jit.script
def Yl34_m_minus_29(theta, phi):
    return 8.15279969880161e-43*(1.0 - cos(theta)**2)**14.5*(4.0746677530722e+45*cos(theta)**5 - 6.08159366130178e+44*cos(theta)**3 + 1.40344469106964e+43*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl34_m_minus_28(theta, phi):
    return 1.58508542441973e-41*(1.0 - cos(theta)**2)**14*(6.79111292178699e+44*cos(theta)**6 - 1.52039841532545e+44*cos(theta)**4 + 7.01722345534821e+42*cos(theta)**2 - 3.71281664304138e+40)*sin(28*phi)

#@torch.jit.script
def Yl34_m_minus_27(theta, phi):
    return 3.30215562682199e-40*(1.0 - cos(theta)**2)**13.5*(9.70158988826713e+43*cos(theta)**7 - 3.04079683065089e+43*cos(theta)**5 + 2.33907448511607e+42*cos(theta)**3 - 3.71281664304138e+40*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl34_m_minus_26(theta, phi):
    return 7.29470020663704e-39*(1.0 - cos(theta)**2)**13*(1.21269873603339e+43*cos(theta)**8 - 5.06799471775149e+42*cos(theta)**6 + 5.84768621279018e+41*cos(theta)**4 - 1.85640832152069e+40*cos(theta)**2 + 7.60823082590447e+37)*sin(26*phi)

#@torch.jit.script
def Yl34_m_minus_25(theta, phi):
    return 1.69513514495286e-37*(1.0 - cos(theta)**2)**12.5*(1.3474430400371e+42*cos(theta)**9 - 7.23999245393069e+41*cos(theta)**7 + 1.16953724255804e+41*cos(theta)**5 - 6.1880277384023e+39*cos(theta)**3 + 7.60823082590447e+37*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl34_m_minus_24(theta, phi):
    return 4.11746896065541e-36*(1.0 - cos(theta)**2)**12*(1.3474430400371e+41*cos(theta)**10 - 9.04999056741337e+40*cos(theta)**8 + 1.94922873759673e+40*cos(theta)**6 - 1.54700693460058e+39*cos(theta)**4 + 3.80411541295224e+37*cos(theta)**2 - 1.28953064845838e+35)*sin(24*phi)

#@torch.jit.script
def Yl34_m_minus_23(theta, phi):
    return 1.04001756281185e-34*(1.0 - cos(theta)**2)**11.5*(1.22494821821555e+40*cos(theta)**11 - 1.00555450749037e+40*cos(theta)**9 + 2.78461248228104e+39*cos(theta)**7 - 3.09401386920115e+38*cos(theta)**5 + 1.26803847098408e+37*cos(theta)**3 - 1.28953064845838e+35*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl34_m_minus_22(theta, phi):
    return 2.71999887348259e-33*(1.0 - cos(theta)**2)**11*(1.02079018184629e+39*cos(theta)**12 - 1.00555450749037e+39*cos(theta)**10 + 3.4807656028513e+38*cos(theta)**8 - 5.15668978200192e+37*cos(theta)**6 + 3.1700961774602e+36*cos(theta)**4 - 6.44765324229192e+34*cos(theta)**2 + 1.88527872581635e+32)*sin(22*phi)

#@torch.jit.script
def Yl34_m_minus_21(theta, phi):
    return 7.33895819488808e-32*(1.0 - cos(theta)**2)**10.5*(7.85223216804838e+37*cos(theta)**13 - 9.14140461354886e+37*cos(theta)**11 + 3.86751733650144e+37*cos(theta)**9 - 7.36669968857417e+36*cos(theta)**7 + 6.34019235492039e+35*cos(theta)**5 - 2.14921774743064e+34*cos(theta)**3 + 1.88527872581635e+32*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl34_m_minus_20(theta, phi):
    return 2.03647825147882e-30*(1.0 - cos(theta)**2)**10*(5.6087372628917e+36*cos(theta)**14 - 7.61783717795738e+36*cos(theta)**12 + 3.86751733650144e+36*cos(theta)**10 - 9.20837461071771e+35*cos(theta)**8 + 1.05669872582007e+35*cos(theta)**6 - 5.3730443685766e+33*cos(theta)**4 + 9.42639362908176e+31*cos(theta)**2 - 2.44841392963163e+29)*sin(20*phi)

#@torch.jit.script
def Yl34_m_minus_19(theta, phi):
    return 5.79591871206322e-29*(1.0 - cos(theta)**2)**9.5*(3.73915817526113e+35*cos(theta)**15 - 5.85987475227491e+35*cos(theta)**13 + 3.51592485136495e+35*cos(theta)**11 - 1.02315273452419e+35*cos(theta)**9 + 1.50956960831438e+34*cos(theta)**7 - 1.07460887371532e+33*cos(theta)**5 + 3.14213120969392e+31*cos(theta)**3 - 2.44841392963163e+29*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl34_m_minus_18(theta, phi):
    return 1.6877970053263e-27*(1.0 - cos(theta)**2)**9*(2.33697385953821e+34*cos(theta)**16 - 4.18562482305351e+34*cos(theta)**14 + 2.92993737613745e+34*cos(theta)**12 - 1.02315273452419e+34*cos(theta)**10 + 1.88696201039297e+33*cos(theta)**8 - 1.79101478952553e+32*cos(theta)**6 + 7.8553280242348e+30*cos(theta)**4 - 1.22420696481581e+29*cos(theta)**2 + 2.88728057739579e+26)*sin(18*phi)

#@torch.jit.script
def Yl34_m_minus_17(theta, phi):
    return 5.01818126253981e-26*(1.0 - cos(theta)**2)**8.5*(1.37469050561071e+33*cos(theta)**17 - 2.79041654870234e+33*cos(theta)**15 + 2.2537979816442e+33*cos(theta)**13 - 9.30138849567446e+32*cos(theta)**11 + 2.09662445599219e+32*cos(theta)**9 - 2.55859255646505e+31*cos(theta)**7 + 1.57106560484696e+30*cos(theta)**5 - 4.08068988271938e+28*cos(theta)**3 + 2.88728057739579e+26*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl34_m_minus_16(theta, phi):
    return 1.52043439327851e-24*(1.0 - cos(theta)**2)**8*(7.63716947561506e+31*cos(theta)**18 - 1.74401034293896e+32*cos(theta)**16 + 1.60985570117443e+32*cos(theta)**14 - 7.75115707972871e+31*cos(theta)**12 + 2.09662445599219e+31*cos(theta)**10 - 3.19824069558131e+30*cos(theta)**8 + 2.61844267474493e+29*cos(theta)**6 - 1.02017247067984e+28*cos(theta)**4 + 1.44364028869789e+26*cos(theta)**2 - 3.14518581415663e+23)*sin(16*phi)

#@torch.jit.script
def Yl34_m_minus_15(theta, phi):
    return 4.68629353226083e-23*(1.0 - cos(theta)**2)**7.5*(4.01956288190266e+30*cos(theta)**19 - 1.02588843702292e+31*cos(theta)**17 + 1.07323713411628e+31*cos(theta)**15 - 5.96242852286824e+30*cos(theta)**13 + 1.90602223272018e+30*cos(theta)**11 - 3.55360077286812e+29*cos(theta)**9 + 3.74063239249276e+28*cos(theta)**7 - 2.04034494135969e+27*cos(theta)**5 + 4.81213429565964e+25*cos(theta)**3 - 3.14518581415663e+23*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl34_m_minus_14(theta, phi):
    return 1.46704192609139e-21*(1.0 - cos(theta)**2)**7*(2.00978144095133e+29*cos(theta)**20 - 5.69938020568288e+29*cos(theta)**18 + 6.70773208822677e+29*cos(theta)**16 - 4.25887751633446e+29*cos(theta)**14 + 1.58835186060015e+29*cos(theta)**12 - 3.55360077286812e+28*cos(theta)**10 + 4.67579049061595e+27*cos(theta)**8 - 3.40057490226615e+26*cos(theta)**6 + 1.20303357391491e+25*cos(theta)**4 - 1.57259290707831e+23*cos(theta)**2 + 3.20937327975166e+20)*sin(14*phi)

#@torch.jit.script
def Yl34_m_minus_13(theta, phi):
    return 4.65771371921163e-20*(1.0 - cos(theta)**2)**6.5*(9.57038781405396e+27*cos(theta)**21 - 2.99967379246467e+28*cos(theta)**19 + 3.94572475778045e+28*cos(theta)**17 - 2.83925167755631e+28*cos(theta)**15 + 1.22180912353857e+28*cos(theta)**13 - 3.23054615715284e+27*cos(theta)**11 + 5.19532276735106e+26*cos(theta)**9 - 4.8579641460945e+25*cos(theta)**7 + 2.40606714782982e+24*cos(theta)**5 - 5.24197635692772e+22*cos(theta)**3 + 3.20937327975166e+20*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl34_m_minus_12(theta, phi):
    return 1.49772838629695e-18*(1.0 - cos(theta)**2)**6*(4.35017627911543e+26*cos(theta)**22 - 1.49983689623234e+27*cos(theta)**20 + 2.19206930987803e+27*cos(theta)**18 - 1.77453229847269e+27*cos(theta)**16 + 8.72720802527553e+26*cos(theta)**14 - 2.69212179762737e+26*cos(theta)**12 + 5.19532276735106e+25*cos(theta)**10 - 6.07245518261812e+24*cos(theta)**8 + 4.0101119130497e+23*cos(theta)**6 - 1.31049408923193e+22*cos(theta)**4 + 1.60468663987583e+20*cos(theta)**2 - 3.10384263032076e+17)*sin(12*phi)

#@torch.jit.script
def Yl34_m_minus_11(theta, phi):
    return 4.87164793230034e-17*(1.0 - cos(theta)**2)**5.5*(1.89138099091975e+25*cos(theta)**23 - 7.14208045824922e+25*cos(theta)**21 + 1.15372068940949e+26*cos(theta)**19 - 1.04384252851335e+26*cos(theta)**17 + 5.81813868351702e+25*cos(theta)**15 - 2.07086292125182e+25*cos(theta)**13 + 4.72302069759187e+24*cos(theta)**11 - 6.74717242513125e+23*cos(theta)**9 + 5.72873130435672e+22*cos(theta)**7 - 2.62098817846386e+21*cos(theta)**5 + 5.34895546625277e+19*cos(theta)**3 - 3.10384263032076e+17*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl34_m_minus_10(theta, phi):
    return 1.60098687884658e-15*(1.0 - cos(theta)**2)**5*(7.88075412883231e+23*cos(theta)**24 - 3.2464002082951e+24*cos(theta)**22 + 5.76860344704745e+24*cos(theta)**20 - 5.79912515840749e+24*cos(theta)**18 + 3.63633667719814e+24*cos(theta)**16 - 1.47918780089416e+24*cos(theta)**14 + 3.93585058132656e+23*cos(theta)**12 - 6.74717242513125e+22*cos(theta)**10 + 7.1609141304459e+21*cos(theta)**8 - 4.3683136307731e+20*cos(theta)**6 + 1.33723886656319e+19*cos(theta)**4 - 1.55192131516038e+17*cos(theta)**2 + 287392836140811.0)*sin(10*phi)

#@torch.jit.script
def Yl34_m_minus_9(theta, phi):
    return 5.30987277141628e-14*(1.0 - cos(theta)**2)**4.5*(3.15230165153292e+22*cos(theta)**25 - 1.41147835143265e+23*cos(theta)**23 + 2.74695402240355e+23*cos(theta)**21 - 3.05217113600394e+23*cos(theta)**19 + 2.13902157482243e+23*cos(theta)**17 - 9.86125200596105e+22*cos(theta)**15 + 3.0275773702512e+22*cos(theta)**13 - 6.13379311375568e+21*cos(theta)**11 + 7.956571256051e+20*cos(theta)**9 - 6.24044804396157e+19*cos(theta)**7 + 2.67447773312639e+18*cos(theta)**5 - 5.17307105053459e+16*cos(theta)**3 + 287392836140811.0*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl34_m_minus_8(theta, phi):
    return 1.77543598061902e-12*(1.0 - cos(theta)**2)**4*(1.21242371212805e+21*cos(theta)**26 - 5.88115979763605e+21*cos(theta)**24 + 1.24861546472888e+22*cos(theta)**22 - 1.52608556800197e+22*cos(theta)**20 + 1.1883453193458e+22*cos(theta)**18 - 6.16328250372566e+21*cos(theta)**16 + 2.16255526446514e+21*cos(theta)**14 - 5.11149426146306e+20*cos(theta)**12 + 7.956571256051e+19*cos(theta)**10 - 7.80056005495196e+18*cos(theta)**8 + 4.45746288854398e+17*cos(theta)**6 - 1.29326776263365e+16*cos(theta)**4 + 143696418070405.0*cos(theta)**2 - 257059781879.079)*sin(8*phi)

#@torch.jit.script
def Yl34_m_minus_7(theta, phi):
    return 5.97876583646464e-11*(1.0 - cos(theta)**2)**3.5*(4.49045819306684e+19*cos(theta)**27 - 2.35246391905442e+20*cos(theta)**25 + 5.42876289012559e+20*cos(theta)**23 - 7.26707413334272e+20*cos(theta)**21 + 6.2544490491884e+20*cos(theta)**19 - 3.62546029630921e+20*cos(theta)**17 + 1.44170350964343e+20*cos(theta)**15 - 3.9319186626639e+19*cos(theta)**13 + 7.23324659641e+18*cos(theta)**11 - 8.66728894994662e+17*cos(theta)**9 + 6.36780412649139e+16*cos(theta)**7 - 2.5865355252673e+15*cos(theta)**5 + 47898806023468.5*cos(theta)**3 - 257059781879.079*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl34_m_minus_6(theta, phi):
    return 2.0257343306691e-9*(1.0 - cos(theta)**2)**3*(1.60373506895244e+18*cos(theta)**28 - 9.04793815020931e+18*cos(theta)**26 + 2.26198453755233e+19*cos(theta)**24 - 3.30321551515578e+19*cos(theta)**22 + 3.1272245245942e+19*cos(theta)**20 - 2.01414460906067e+19*cos(theta)**18 + 9.01064693527143e+18*cos(theta)**16 - 2.80851333047421e+18*cos(theta)**14 + 6.02770549700833e+17*cos(theta)**12 - 8.66728894994662e+16*cos(theta)**10 + 7.95975515811424e+15*cos(theta)**8 - 431089254211216.0*cos(theta)**6 + 11974701505867.1*cos(theta)**4 - 128529890939.54*cos(theta)**2 + 223919670.626376)*sin(6*phi)

#@torch.jit.script
def Yl34_m_minus_5(theta, phi):
    return 6.89940251833707e-8*(1.0 - cos(theta)**2)**2.5*(5.53012092742222e+16*cos(theta)**29 - 3.35108820378123e+17*cos(theta)**27 + 9.04793815020931e+17*cos(theta)**25 - 1.43618065876338e+18*cos(theta)**23 + 1.48915453552105e+18*cos(theta)**21 - 1.06007611003193e+18*cos(theta)**19 + 5.30038055015966e+17*cos(theta)**17 - 1.87234222031614e+17*cos(theta)**15 + 4.63669653616025e+16*cos(theta)**13 - 7.87935359086056e+15*cos(theta)**11 + 884417239790471.0*cos(theta)**9 - 61584179173030.9*cos(theta)**7 + 2394940301173.42*cos(theta)**5 - 42843296979.8466*cos(theta)**3 + 223919670.626376*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl34_m_minus_4(theta, phi):
    return 2.35995875978251e-6*(1.0 - cos(theta)**2)**2*(1.84337364247407e+15*cos(theta)**30 - 1.19681721563615e+16*cos(theta)**28 + 3.47997621161897e+16*cos(theta)**26 - 5.98408607818076e+16*cos(theta)**24 + 6.7688842523684e+16*cos(theta)**22 - 5.30038055015966e+16*cos(theta)**20 + 2.94465586119981e+16*cos(theta)**18 - 1.17021388769759e+16*cos(theta)**16 + 3.31192609725732e+15*cos(theta)**14 - 656612799238380.0*cos(theta)**12 + 88441723979047.1*cos(theta)**10 - 7698022396628.86*cos(theta)**8 + 399156716862.237*cos(theta)**6 - 10710824244.9616*cos(theta)**4 + 111959835.313188*cos(theta)**2 - 191384.333868697)*sin(4*phi)

#@torch.jit.script
def Yl34_m_minus_3(theta, phi):
    return 8.09985154172335e-5*(1.0 - cos(theta)**2)**1.5*(59463665886260.4*cos(theta)**31 - 412695591598673.0*cos(theta)**29 + 1.28888007837739e+15*cos(theta)**27 - 2.3936344312723e+15*cos(theta)**25 + 2.94299315320365e+15*cos(theta)**23 - 2.52399073817127e+15*cos(theta)**21 + 1.54981887431569e+15*cos(theta)**19 - 688361110410346.0*cos(theta)**17 + 220795073150488.0*cos(theta)**15 - 50508676864490.8*cos(theta)**13 + 8040156725367.92*cos(theta)**11 - 855335821847.651*cos(theta)**9 + 57022388123.1768*cos(theta)**7 - 2142164848.99233*cos(theta)**5 + 37319945.104396*cos(theta)**3 - 191384.333868697*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl34_m_minus_2(theta, phi):
    return 0.00278710230306644*(1.0 - cos(theta)**2)*(1858239558945.64*cos(theta)**32 - 13756519719955.8*cos(theta)**30 + 46031431370621.2*cos(theta)**28 - 92062862741242.5*cos(theta)**26 + 122624714716819.0*cos(theta)**24 - 114726851735058.0*cos(theta)**22 + 77490943715784.6*cos(theta)**20 - 38242283911685.9*cos(theta)**18 + 13799692071905.5*cos(theta)**16 - 3607762633177.91*cos(theta)**14 + 670013060447.327*cos(theta)**12 - 85533582184.7651*cos(theta)**10 + 7127798515.39709*cos(theta)**8 - 357027474.832055*cos(theta)**6 + 9329986.27609899*cos(theta)**4 - 95692.1669343486*cos(theta)**2 + 161.642173875589)*sin(2*phi)

#@torch.jit.script
def Yl34_m_minus_1(theta, phi):
    return 0.0960641026936534*(1.0 - cos(theta)**2)**0.5*(56310289665.0193*cos(theta)**33 - 443758700643.735*cos(theta)**31 + 1587290736917.97*cos(theta)**29 - 3409735657083.05*cos(theta)**27 + 4904988588672.75*cos(theta)**25 - 4988123988480.77*cos(theta)**23 + 3690044938846.88*cos(theta)**21 - 2012751784825.57*cos(theta)**19 + 811746592465.031*cos(theta)**17 - 240517508878.528*cos(theta)**15 + 51539466188.2559*cos(theta)**13 - 7775780198.61501*cos(theta)**11 + 791977612.821899*cos(theta)**9 - 51003924.9760078*cos(theta)**7 + 1865997.2552198*cos(theta)**5 - 31897.3889781162*cos(theta)**3 + 161.642173875589*cos(theta))*sin(phi)

#@torch.jit.script
def Yl34_m0(theta, phi):
    return 12192094786.7008*cos(theta)**34 - 102086047393.122*cos(theta)**32 + 389497534669.142*cos(theta)**30 - 896462579794.057*cos(theta)**28 + 1388782193287.51*cos(theta)**26 - 1530014280740.48*cos(theta)**24 + 1234748366913.37*cos(theta)**22 - 740849020148.023*cos(theta)**20 + 331984230726.708*cos(theta)**18 - 110661410242.236*cos(theta)**16 + 27100753528.7109*cos(theta)**14 - 4770151975.0729*cos(theta)**12 + 583018574.731132*cos(theta)**10 - 46933516.7493756*cos(theta)**8 + 2289439.84143296*cos(theta)**6 - 58703.5856777681*cos(theta)**4 + 594.968773761163*cos(theta)**2 - 0.999947518926325

#@torch.jit.script
def Yl34_m1(theta, phi):
    return 0.0960641026936534*(1.0 - cos(theta)**2)**0.5*(56310289665.0193*cos(theta)**33 - 443758700643.735*cos(theta)**31 + 1587290736917.97*cos(theta)**29 - 3409735657083.05*cos(theta)**27 + 4904988588672.75*cos(theta)**25 - 4988123988480.77*cos(theta)**23 + 3690044938846.88*cos(theta)**21 - 2012751784825.57*cos(theta)**19 + 811746592465.031*cos(theta)**17 - 240517508878.528*cos(theta)**15 + 51539466188.2559*cos(theta)**13 - 7775780198.61501*cos(theta)**11 + 791977612.821899*cos(theta)**9 - 51003924.9760078*cos(theta)**7 + 1865997.2552198*cos(theta)**5 - 31897.3889781162*cos(theta)**3 + 161.642173875589*cos(theta))*cos(phi)

#@torch.jit.script
def Yl34_m2(theta, phi):
    return 0.00278710230306644*(1.0 - cos(theta)**2)*(1858239558945.64*cos(theta)**32 - 13756519719955.8*cos(theta)**30 + 46031431370621.2*cos(theta)**28 - 92062862741242.5*cos(theta)**26 + 122624714716819.0*cos(theta)**24 - 114726851735058.0*cos(theta)**22 + 77490943715784.6*cos(theta)**20 - 38242283911685.9*cos(theta)**18 + 13799692071905.5*cos(theta)**16 - 3607762633177.91*cos(theta)**14 + 670013060447.327*cos(theta)**12 - 85533582184.7651*cos(theta)**10 + 7127798515.39709*cos(theta)**8 - 357027474.832055*cos(theta)**6 + 9329986.27609899*cos(theta)**4 - 95692.1669343486*cos(theta)**2 + 161.642173875589)*cos(2*phi)

#@torch.jit.script
def Yl34_m3(theta, phi):
    return 8.09985154172335e-5*(1.0 - cos(theta)**2)**1.5*(59463665886260.4*cos(theta)**31 - 412695591598673.0*cos(theta)**29 + 1.28888007837739e+15*cos(theta)**27 - 2.3936344312723e+15*cos(theta)**25 + 2.94299315320365e+15*cos(theta)**23 - 2.52399073817127e+15*cos(theta)**21 + 1.54981887431569e+15*cos(theta)**19 - 688361110410346.0*cos(theta)**17 + 220795073150488.0*cos(theta)**15 - 50508676864490.8*cos(theta)**13 + 8040156725367.92*cos(theta)**11 - 855335821847.651*cos(theta)**9 + 57022388123.1768*cos(theta)**7 - 2142164848.99233*cos(theta)**5 + 37319945.104396*cos(theta)**3 - 191384.333868697*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl34_m4(theta, phi):
    return 2.35995875978251e-6*(1.0 - cos(theta)**2)**2*(1.84337364247407e+15*cos(theta)**30 - 1.19681721563615e+16*cos(theta)**28 + 3.47997621161897e+16*cos(theta)**26 - 5.98408607818076e+16*cos(theta)**24 + 6.7688842523684e+16*cos(theta)**22 - 5.30038055015966e+16*cos(theta)**20 + 2.94465586119981e+16*cos(theta)**18 - 1.17021388769759e+16*cos(theta)**16 + 3.31192609725732e+15*cos(theta)**14 - 656612799238380.0*cos(theta)**12 + 88441723979047.1*cos(theta)**10 - 7698022396628.86*cos(theta)**8 + 399156716862.237*cos(theta)**6 - 10710824244.9616*cos(theta)**4 + 111959835.313188*cos(theta)**2 - 191384.333868697)*cos(4*phi)

#@torch.jit.script
def Yl34_m5(theta, phi):
    return 6.89940251833707e-8*(1.0 - cos(theta)**2)**2.5*(5.53012092742222e+16*cos(theta)**29 - 3.35108820378123e+17*cos(theta)**27 + 9.04793815020931e+17*cos(theta)**25 - 1.43618065876338e+18*cos(theta)**23 + 1.48915453552105e+18*cos(theta)**21 - 1.06007611003193e+18*cos(theta)**19 + 5.30038055015966e+17*cos(theta)**17 - 1.87234222031614e+17*cos(theta)**15 + 4.63669653616025e+16*cos(theta)**13 - 7.87935359086056e+15*cos(theta)**11 + 884417239790471.0*cos(theta)**9 - 61584179173030.9*cos(theta)**7 + 2394940301173.42*cos(theta)**5 - 42843296979.8466*cos(theta)**3 + 223919670.626376*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl34_m6(theta, phi):
    return 2.0257343306691e-9*(1.0 - cos(theta)**2)**3*(1.60373506895244e+18*cos(theta)**28 - 9.04793815020931e+18*cos(theta)**26 + 2.26198453755233e+19*cos(theta)**24 - 3.30321551515578e+19*cos(theta)**22 + 3.1272245245942e+19*cos(theta)**20 - 2.01414460906067e+19*cos(theta)**18 + 9.01064693527143e+18*cos(theta)**16 - 2.80851333047421e+18*cos(theta)**14 + 6.02770549700833e+17*cos(theta)**12 - 8.66728894994662e+16*cos(theta)**10 + 7.95975515811424e+15*cos(theta)**8 - 431089254211216.0*cos(theta)**6 + 11974701505867.1*cos(theta)**4 - 128529890939.54*cos(theta)**2 + 223919670.626376)*cos(6*phi)

#@torch.jit.script
def Yl34_m7(theta, phi):
    return 5.97876583646464e-11*(1.0 - cos(theta)**2)**3.5*(4.49045819306684e+19*cos(theta)**27 - 2.35246391905442e+20*cos(theta)**25 + 5.42876289012559e+20*cos(theta)**23 - 7.26707413334272e+20*cos(theta)**21 + 6.2544490491884e+20*cos(theta)**19 - 3.62546029630921e+20*cos(theta)**17 + 1.44170350964343e+20*cos(theta)**15 - 3.9319186626639e+19*cos(theta)**13 + 7.23324659641e+18*cos(theta)**11 - 8.66728894994662e+17*cos(theta)**9 + 6.36780412649139e+16*cos(theta)**7 - 2.5865355252673e+15*cos(theta)**5 + 47898806023468.5*cos(theta)**3 - 257059781879.079*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl34_m8(theta, phi):
    return 1.77543598061902e-12*(1.0 - cos(theta)**2)**4*(1.21242371212805e+21*cos(theta)**26 - 5.88115979763605e+21*cos(theta)**24 + 1.24861546472888e+22*cos(theta)**22 - 1.52608556800197e+22*cos(theta)**20 + 1.1883453193458e+22*cos(theta)**18 - 6.16328250372566e+21*cos(theta)**16 + 2.16255526446514e+21*cos(theta)**14 - 5.11149426146306e+20*cos(theta)**12 + 7.956571256051e+19*cos(theta)**10 - 7.80056005495196e+18*cos(theta)**8 + 4.45746288854398e+17*cos(theta)**6 - 1.29326776263365e+16*cos(theta)**4 + 143696418070405.0*cos(theta)**2 - 257059781879.079)*cos(8*phi)

#@torch.jit.script
def Yl34_m9(theta, phi):
    return 5.30987277141628e-14*(1.0 - cos(theta)**2)**4.5*(3.15230165153292e+22*cos(theta)**25 - 1.41147835143265e+23*cos(theta)**23 + 2.74695402240355e+23*cos(theta)**21 - 3.05217113600394e+23*cos(theta)**19 + 2.13902157482243e+23*cos(theta)**17 - 9.86125200596105e+22*cos(theta)**15 + 3.0275773702512e+22*cos(theta)**13 - 6.13379311375568e+21*cos(theta)**11 + 7.956571256051e+20*cos(theta)**9 - 6.24044804396157e+19*cos(theta)**7 + 2.67447773312639e+18*cos(theta)**5 - 5.17307105053459e+16*cos(theta)**3 + 287392836140811.0*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl34_m10(theta, phi):
    return 1.60098687884658e-15*(1.0 - cos(theta)**2)**5*(7.88075412883231e+23*cos(theta)**24 - 3.2464002082951e+24*cos(theta)**22 + 5.76860344704745e+24*cos(theta)**20 - 5.79912515840749e+24*cos(theta)**18 + 3.63633667719814e+24*cos(theta)**16 - 1.47918780089416e+24*cos(theta)**14 + 3.93585058132656e+23*cos(theta)**12 - 6.74717242513125e+22*cos(theta)**10 + 7.1609141304459e+21*cos(theta)**8 - 4.3683136307731e+20*cos(theta)**6 + 1.33723886656319e+19*cos(theta)**4 - 1.55192131516038e+17*cos(theta)**2 + 287392836140811.0)*cos(10*phi)

#@torch.jit.script
def Yl34_m11(theta, phi):
    return 4.87164793230034e-17*(1.0 - cos(theta)**2)**5.5*(1.89138099091975e+25*cos(theta)**23 - 7.14208045824922e+25*cos(theta)**21 + 1.15372068940949e+26*cos(theta)**19 - 1.04384252851335e+26*cos(theta)**17 + 5.81813868351702e+25*cos(theta)**15 - 2.07086292125182e+25*cos(theta)**13 + 4.72302069759187e+24*cos(theta)**11 - 6.74717242513125e+23*cos(theta)**9 + 5.72873130435672e+22*cos(theta)**7 - 2.62098817846386e+21*cos(theta)**5 + 5.34895546625277e+19*cos(theta)**3 - 3.10384263032076e+17*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl34_m12(theta, phi):
    return 1.49772838629695e-18*(1.0 - cos(theta)**2)**6*(4.35017627911543e+26*cos(theta)**22 - 1.49983689623234e+27*cos(theta)**20 + 2.19206930987803e+27*cos(theta)**18 - 1.77453229847269e+27*cos(theta)**16 + 8.72720802527553e+26*cos(theta)**14 - 2.69212179762737e+26*cos(theta)**12 + 5.19532276735106e+25*cos(theta)**10 - 6.07245518261812e+24*cos(theta)**8 + 4.0101119130497e+23*cos(theta)**6 - 1.31049408923193e+22*cos(theta)**4 + 1.60468663987583e+20*cos(theta)**2 - 3.10384263032076e+17)*cos(12*phi)

#@torch.jit.script
def Yl34_m13(theta, phi):
    return 4.65771371921163e-20*(1.0 - cos(theta)**2)**6.5*(9.57038781405396e+27*cos(theta)**21 - 2.99967379246467e+28*cos(theta)**19 + 3.94572475778045e+28*cos(theta)**17 - 2.83925167755631e+28*cos(theta)**15 + 1.22180912353857e+28*cos(theta)**13 - 3.23054615715284e+27*cos(theta)**11 + 5.19532276735106e+26*cos(theta)**9 - 4.8579641460945e+25*cos(theta)**7 + 2.40606714782982e+24*cos(theta)**5 - 5.24197635692772e+22*cos(theta)**3 + 3.20937327975166e+20*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl34_m14(theta, phi):
    return 1.46704192609139e-21*(1.0 - cos(theta)**2)**7*(2.00978144095133e+29*cos(theta)**20 - 5.69938020568288e+29*cos(theta)**18 + 6.70773208822677e+29*cos(theta)**16 - 4.25887751633446e+29*cos(theta)**14 + 1.58835186060015e+29*cos(theta)**12 - 3.55360077286812e+28*cos(theta)**10 + 4.67579049061595e+27*cos(theta)**8 - 3.40057490226615e+26*cos(theta)**6 + 1.20303357391491e+25*cos(theta)**4 - 1.57259290707831e+23*cos(theta)**2 + 3.20937327975166e+20)*cos(14*phi)

#@torch.jit.script
def Yl34_m15(theta, phi):
    return 4.68629353226083e-23*(1.0 - cos(theta)**2)**7.5*(4.01956288190266e+30*cos(theta)**19 - 1.02588843702292e+31*cos(theta)**17 + 1.07323713411628e+31*cos(theta)**15 - 5.96242852286824e+30*cos(theta)**13 + 1.90602223272018e+30*cos(theta)**11 - 3.55360077286812e+29*cos(theta)**9 + 3.74063239249276e+28*cos(theta)**7 - 2.04034494135969e+27*cos(theta)**5 + 4.81213429565964e+25*cos(theta)**3 - 3.14518581415663e+23*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl34_m16(theta, phi):
    return 1.52043439327851e-24*(1.0 - cos(theta)**2)**8*(7.63716947561506e+31*cos(theta)**18 - 1.74401034293896e+32*cos(theta)**16 + 1.60985570117443e+32*cos(theta)**14 - 7.75115707972871e+31*cos(theta)**12 + 2.09662445599219e+31*cos(theta)**10 - 3.19824069558131e+30*cos(theta)**8 + 2.61844267474493e+29*cos(theta)**6 - 1.02017247067984e+28*cos(theta)**4 + 1.44364028869789e+26*cos(theta)**2 - 3.14518581415663e+23)*cos(16*phi)

#@torch.jit.script
def Yl34_m17(theta, phi):
    return 5.01818126253981e-26*(1.0 - cos(theta)**2)**8.5*(1.37469050561071e+33*cos(theta)**17 - 2.79041654870234e+33*cos(theta)**15 + 2.2537979816442e+33*cos(theta)**13 - 9.30138849567446e+32*cos(theta)**11 + 2.09662445599219e+32*cos(theta)**9 - 2.55859255646505e+31*cos(theta)**7 + 1.57106560484696e+30*cos(theta)**5 - 4.08068988271938e+28*cos(theta)**3 + 2.88728057739579e+26*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl34_m18(theta, phi):
    return 1.6877970053263e-27*(1.0 - cos(theta)**2)**9*(2.33697385953821e+34*cos(theta)**16 - 4.18562482305351e+34*cos(theta)**14 + 2.92993737613745e+34*cos(theta)**12 - 1.02315273452419e+34*cos(theta)**10 + 1.88696201039297e+33*cos(theta)**8 - 1.79101478952553e+32*cos(theta)**6 + 7.8553280242348e+30*cos(theta)**4 - 1.22420696481581e+29*cos(theta)**2 + 2.88728057739579e+26)*cos(18*phi)

#@torch.jit.script
def Yl34_m19(theta, phi):
    return 5.79591871206322e-29*(1.0 - cos(theta)**2)**9.5*(3.73915817526113e+35*cos(theta)**15 - 5.85987475227491e+35*cos(theta)**13 + 3.51592485136495e+35*cos(theta)**11 - 1.02315273452419e+35*cos(theta)**9 + 1.50956960831438e+34*cos(theta)**7 - 1.07460887371532e+33*cos(theta)**5 + 3.14213120969392e+31*cos(theta)**3 - 2.44841392963163e+29*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl34_m20(theta, phi):
    return 2.03647825147882e-30*(1.0 - cos(theta)**2)**10*(5.6087372628917e+36*cos(theta)**14 - 7.61783717795738e+36*cos(theta)**12 + 3.86751733650144e+36*cos(theta)**10 - 9.20837461071771e+35*cos(theta)**8 + 1.05669872582007e+35*cos(theta)**6 - 5.3730443685766e+33*cos(theta)**4 + 9.42639362908176e+31*cos(theta)**2 - 2.44841392963163e+29)*cos(20*phi)

#@torch.jit.script
def Yl34_m21(theta, phi):
    return 7.33895819488808e-32*(1.0 - cos(theta)**2)**10.5*(7.85223216804838e+37*cos(theta)**13 - 9.14140461354886e+37*cos(theta)**11 + 3.86751733650144e+37*cos(theta)**9 - 7.36669968857417e+36*cos(theta)**7 + 6.34019235492039e+35*cos(theta)**5 - 2.14921774743064e+34*cos(theta)**3 + 1.88527872581635e+32*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl34_m22(theta, phi):
    return 2.71999887348259e-33*(1.0 - cos(theta)**2)**11*(1.02079018184629e+39*cos(theta)**12 - 1.00555450749037e+39*cos(theta)**10 + 3.4807656028513e+38*cos(theta)**8 - 5.15668978200192e+37*cos(theta)**6 + 3.1700961774602e+36*cos(theta)**4 - 6.44765324229192e+34*cos(theta)**2 + 1.88527872581635e+32)*cos(22*phi)

#@torch.jit.script
def Yl34_m23(theta, phi):
    return 1.04001756281185e-34*(1.0 - cos(theta)**2)**11.5*(1.22494821821555e+40*cos(theta)**11 - 1.00555450749037e+40*cos(theta)**9 + 2.78461248228104e+39*cos(theta)**7 - 3.09401386920115e+38*cos(theta)**5 + 1.26803847098408e+37*cos(theta)**3 - 1.28953064845838e+35*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl34_m24(theta, phi):
    return 4.11746896065541e-36*(1.0 - cos(theta)**2)**12*(1.3474430400371e+41*cos(theta)**10 - 9.04999056741337e+40*cos(theta)**8 + 1.94922873759673e+40*cos(theta)**6 - 1.54700693460058e+39*cos(theta)**4 + 3.80411541295224e+37*cos(theta)**2 - 1.28953064845838e+35)*cos(24*phi)

#@torch.jit.script
def Yl34_m25(theta, phi):
    return 1.69513514495286e-37*(1.0 - cos(theta)**2)**12.5*(1.3474430400371e+42*cos(theta)**9 - 7.23999245393069e+41*cos(theta)**7 + 1.16953724255804e+41*cos(theta)**5 - 6.1880277384023e+39*cos(theta)**3 + 7.60823082590447e+37*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl34_m26(theta, phi):
    return 7.29470020663704e-39*(1.0 - cos(theta)**2)**13*(1.21269873603339e+43*cos(theta)**8 - 5.06799471775149e+42*cos(theta)**6 + 5.84768621279018e+41*cos(theta)**4 - 1.85640832152069e+40*cos(theta)**2 + 7.60823082590447e+37)*cos(26*phi)

#@torch.jit.script
def Yl34_m27(theta, phi):
    return 3.30215562682199e-40*(1.0 - cos(theta)**2)**13.5*(9.70158988826713e+43*cos(theta)**7 - 3.04079683065089e+43*cos(theta)**5 + 2.33907448511607e+42*cos(theta)**3 - 3.71281664304138e+40*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl34_m28(theta, phi):
    return 1.58508542441973e-41*(1.0 - cos(theta)**2)**14*(6.79111292178699e+44*cos(theta)**6 - 1.52039841532545e+44*cos(theta)**4 + 7.01722345534821e+42*cos(theta)**2 - 3.71281664304138e+40)*cos(28*phi)

#@torch.jit.script
def Yl34_m29(theta, phi):
    return 8.15279969880161e-43*(1.0 - cos(theta)**2)**14.5*(4.0746677530722e+45*cos(theta)**5 - 6.08159366130178e+44*cos(theta)**3 + 1.40344469106964e+43*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl34_m30(theta, phi):
    return 4.55755358336505e-44*(1.0 - cos(theta)**2)**15*(2.0373338765361e+46*cos(theta)**4 - 1.82447809839054e+45*cos(theta)**2 + 1.40344469106964e+43)*cos(30*phi)

#@torch.jit.script
def Yl34_m31(theta, phi):
    return 2.8264747454439e-45*(1.0 - cos(theta)**2)**15.5*(8.14933550614439e+46*cos(theta)**3 - 3.64895619678107e+45*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl34_m32(theta, phi):
    return 2.0086881349656e-46*(1.0 - cos(theta)**2)**16*(2.44480065184332e+47*cos(theta)**2 - 3.64895619678107e+45)*cos(32*phi)

#@torch.jit.script
def Yl34_m33(theta, phi):
    return 8.48464280026292*(1.0 - cos(theta)**2)**16.5*cos(33*phi)*cos(theta)

#@torch.jit.script
def Yl34_m34(theta, phi):
    return 1.0289140723859*(1.0 - cos(theta)**2)**17*cos(34*phi)

#@torch.jit.script
def Yl35_m_minus_35(theta, phi):
    return 1.03623739663619*(1.0 - cos(theta)**2)**17.5*sin(35*phi)

#@torch.jit.script
def Yl35_m_minus_34(theta, phi):
    return 8.66978407765238*(1.0 - cos(theta)**2)**17*sin(34*phi)*cos(theta)

#@torch.jit.script
def Yl35_m_minus_33(theta, phi):
    return 3.01873705359384e-48*(1.0 - cos(theta)**2)**16.5*(1.68691244977189e+49*cos(theta)**2 - 2.44480065184332e+47)*sin(33*phi)

#@torch.jit.script
def Yl35_m_minus_32(theta, phi):
    return 4.31161892256615e-47*(1.0 - cos(theta)**2)**16*(5.62304149923963e+48*cos(theta)**3 - 2.44480065184332e+47*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl35_m_minus_31(theta, phi):
    return 7.05842437981691e-46*(1.0 - cos(theta)**2)**15.5*(1.40576037480991e+48*cos(theta)**4 - 1.22240032592166e+47*cos(theta)**2 + 9.12239049195268e+44)*sin(31*phi)

#@torch.jit.script
def Yl35_m_minus_30(theta, phi):
    return 1.28222646437538e-44*(1.0 - cos(theta)**2)**15*(2.81152074961981e+47*cos(theta)**5 - 4.0746677530722e+46*cos(theta)**3 + 9.12239049195268e+44*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl35_m_minus_29(theta, phi):
    return 2.53219437507943e-43*(1.0 - cos(theta)**2)**14.5*(4.68586791603302e+46*cos(theta)**6 - 1.01866693826805e+46*cos(theta)**4 + 4.56119524597634e+44*cos(theta)**2 - 2.33907448511607e+42)*sin(29*phi)

#@torch.jit.script
def Yl35_m_minus_28(theta, phi):
    return 5.35964527018943e-42*(1.0 - cos(theta)**2)**14*(6.69409702290432e+45*cos(theta)**7 - 2.0373338765361e+45*cos(theta)**5 + 1.52039841532545e+44*cos(theta)**3 - 2.33907448511607e+42*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl35_m_minus_27(theta, phi):
    return 1.20323737894154e-40*(1.0 - cos(theta)**2)**13.5*(8.3676212786304e+44*cos(theta)**8 - 3.3955564608935e+44*cos(theta)**6 + 3.80099603831361e+43*cos(theta)**4 - 1.16953724255804e+42*cos(theta)**2 + 4.64102080380173e+39)*sin(27*phi)

#@torch.jit.script
def Yl35_m_minus_26(theta, phi):
    return 2.8422901788273e-39*(1.0 - cos(theta)**2)**13*(9.297356976256e+43*cos(theta)**9 - 4.85079494413357e+43*cos(theta)**7 + 7.60199207662723e+42*cos(theta)**5 - 3.89845747519345e+41*cos(theta)**3 + 4.64102080380173e+39*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl35_m_minus_25(theta, phi):
    return 7.01993889645875e-38*(1.0 - cos(theta)**2)**12.5*(9.297356976256e+42*cos(theta)**10 - 6.06349368016696e+42*cos(theta)**8 + 1.26699867943787e+42*cos(theta)**6 - 9.74614368798363e+40*cos(theta)**4 + 2.32051040190086e+39*cos(theta)**2 - 7.60823082590447e+36)*sin(25*phi)

#@torch.jit.script
def Yl35_m_minus_24(theta, phi):
    return 1.80345495626061e-36*(1.0 - cos(theta)**2)**12*(8.45214270568727e+41*cos(theta)**11 - 6.73721520018551e+41*cos(theta)**9 + 1.80999811348267e+41*cos(theta)**7 - 1.94922873759673e+40*cos(theta)**5 + 7.73503467300288e+38*cos(theta)**3 - 7.60823082590447e+36*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl35_m_minus_23(theta, phi):
    return 4.79868153112577e-35*(1.0 - cos(theta)**2)**11.5*(7.04345225473939e+40*cos(theta)**12 - 6.73721520018551e+40*cos(theta)**10 + 2.26249764185334e+40*cos(theta)**8 - 3.24871456266121e+39*cos(theta)**6 + 1.93375866825072e+38*cos(theta)**4 - 3.80411541295224e+36*cos(theta)**2 + 1.07460887371532e+34)*sin(23*phi)

#@torch.jit.script
def Yl35_m_minus_22(theta, phi):
    return 1.31767286173862e-33*(1.0 - cos(theta)**2)**11*(5.41804019595338e+39*cos(theta)**13 - 6.12474109107773e+39*cos(theta)**11 + 2.51388626872594e+39*cos(theta)**9 - 4.64102080380173e+38*cos(theta)**7 + 3.86751733650144e+37*cos(theta)**5 - 1.26803847098408e+36*cos(theta)**3 + 1.07460887371532e+34*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl35_m_minus_21(theta, phi):
    return 3.72228007128537e-32*(1.0 - cos(theta)**2)**10.5*(3.87002871139527e+38*cos(theta)**14 - 5.10395090923145e+38*cos(theta)**12 + 2.51388626872594e+38*cos(theta)**10 - 5.80127600475216e+37*cos(theta)**8 + 6.4458622275024e+36*cos(theta)**6 - 3.1700961774602e+35*cos(theta)**4 + 5.3730443685766e+33*cos(theta)**2 - 1.34662766129739e+31)*sin(21*phi)

#@torch.jit.script
def Yl35_m_minus_20(theta, phi):
    return 1.07881925735658e-30*(1.0 - cos(theta)**2)**10*(2.58001914093018e+37*cos(theta)**15 - 3.92611608402419e+37*cos(theta)**13 + 2.28535115338721e+37*cos(theta)**11 - 6.4458622275024e+36*cos(theta)**9 + 9.20837461071771e+35*cos(theta)**7 - 6.34019235492039e+34*cos(theta)**5 + 1.79101478952553e+33*cos(theta)**3 - 1.34662766129739e+31*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl35_m_minus_19(theta, phi):
    return 3.20029509770303e-29*(1.0 - cos(theta)**2)**9.5*(1.61251196308136e+36*cos(theta)**16 - 2.80436863144585e+36*cos(theta)**14 + 1.90445929448935e+36*cos(theta)**12 - 6.4458622275024e+35*cos(theta)**10 + 1.15104682633971e+35*cos(theta)**8 - 1.05669872582007e+34*cos(theta)**6 + 4.47753697381384e+32*cos(theta)**4 - 6.73313830648697e+30*cos(theta)**2 + 1.53025870601977e+28)*sin(19*phi)

#@torch.jit.script
def Yl35_m_minus_18(theta, phi):
    return 9.6964188430403e-28*(1.0 - cos(theta)**2)**9*(9.4853644887139e+34*cos(theta)**17 - 1.86957908763057e+35*cos(theta)**15 + 1.46496868806873e+35*cos(theta)**13 - 5.85987475227491e+34*cos(theta)**11 + 1.27894091815524e+34*cos(theta)**9 - 1.50956960831438e+33*cos(theta)**7 + 8.95507394762767e+31*cos(theta)**5 - 2.24437943549566e+30*cos(theta)**3 + 1.53025870601977e+28*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl35_m_minus_17(theta, phi):
    return 2.9949222630012e-26*(1.0 - cos(theta)**2)**8.5*(5.26964693817439e+33*cos(theta)**18 - 1.1684869297691e+34*cos(theta)**16 + 1.04640620576338e+34*cos(theta)**14 - 4.88322896022909e+33*cos(theta)**12 + 1.27894091815524e+33*cos(theta)**10 - 1.88696201039297e+32*cos(theta)**8 + 1.49251232460461e+31*cos(theta)**6 - 5.61094858873914e+29*cos(theta)**4 + 7.65129353009883e+27*cos(theta)**2 - 1.60404476521988e+25)*sin(17*phi)

#@torch.jit.script
def Yl35_m_minus_16(theta, phi):
    return 9.41377960708832e-25*(1.0 - cos(theta)**2)**8*(2.77349838851284e+32*cos(theta)**19 - 6.87345252805355e+32*cos(theta)**17 + 6.97604137175584e+32*cos(theta)**15 - 3.75632996940699e+32*cos(theta)**13 + 1.16267356195931e+32*cos(theta)**11 - 2.09662445599219e+31*cos(theta)**9 + 2.13216046372087e+30*cos(theta)**7 - 1.12218971774783e+29*cos(theta)**5 + 2.55043117669961e+27*cos(theta)**3 - 1.60404476521988e+25*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl35_m_minus_15(theta, phi):
    return 3.00652010504917e-23*(1.0 - cos(theta)**2)**7.5*(1.38674919425642e+31*cos(theta)**20 - 3.81858473780753e+31*cos(theta)**18 + 4.3600258573474e+31*cos(theta)**16 - 2.68309283529071e+31*cos(theta)**14 + 9.68894634966089e+30*cos(theta)**12 - 2.09662445599219e+30*cos(theta)**10 + 2.66520057965109e+29*cos(theta)**8 - 1.87031619624638e+28*cos(theta)**6 + 6.37607794174903e+26*cos(theta)**4 - 8.02022382609941e+24*cos(theta)**2 + 1.57259290707831e+22)*sin(15*phi)

#@torch.jit.script
def Yl35_m_minus_14(theta, phi):
    return 9.74223860268681e-22*(1.0 - cos(theta)**2)**7*(6.60356759169723e+29*cos(theta)**21 - 2.00978144095133e+30*cos(theta)**19 + 2.5647210925573e+30*cos(theta)**17 - 1.78872855686047e+30*cos(theta)**15 + 7.4530356535853e+29*cos(theta)**13 - 1.90602223272018e+29*cos(theta)**11 + 2.9613339773901e+28*cos(theta)**9 - 2.67188028035197e+27*cos(theta)**7 + 1.27521558834981e+26*cos(theta)**5 - 2.67340794203313e+24*cos(theta)**3 + 1.57259290707831e+22*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl35_m_minus_13(theta, phi):
    return 3.19866046346017e-20*(1.0 - cos(theta)**2)**6.5*(3.00162163258965e+28*cos(theta)**22 - 1.00489072047567e+29*cos(theta)**20 + 1.42484505142072e+29*cos(theta)**18 - 1.1179553480378e+29*cos(theta)**16 + 5.32359689541807e+28*cos(theta)**14 - 1.58835186060015e+28*cos(theta)**12 + 2.9613339773901e+27*cos(theta)**10 - 3.33985035043997e+26*cos(theta)**8 + 2.12535931391634e+25*cos(theta)**6 - 6.68351985508284e+23*cos(theta)**4 + 7.86296453539157e+21*cos(theta)**2 - 1.45880603625076e+19)*sin(13*phi)

#@torch.jit.script
def Yl35_m_minus_12(theta, phi):
    return 1.06280277340603e-18*(1.0 - cos(theta)**2)**6*(1.30505288373463e+27*cos(theta)**23 - 4.78519390702698e+27*cos(theta)**21 + 7.49918448116168e+27*cos(theta)**19 - 6.57620792963409e+27*cos(theta)**17 + 3.54906459694538e+27*cos(theta)**15 - 1.22180912353857e+27*cos(theta)**13 + 2.69212179762737e+26*cos(theta)**11 - 3.71094483382218e+25*cos(theta)**9 + 3.03622759130906e+24*cos(theta)**7 - 1.33670397101657e+23*cos(theta)**5 + 2.62098817846386e+21*cos(theta)**3 - 1.45880603625076e+19*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl35_m_minus_11(theta, phi):
    return 3.56949870606501e-17*(1.0 - cos(theta)**2)**5.5*(5.43772034889429e+25*cos(theta)**24 - 2.17508813955772e+26*cos(theta)**22 + 3.74959224058084e+26*cos(theta)**20 - 3.65344884979672e+26*cos(theta)**18 + 2.21816537309086e+26*cos(theta)**16 - 8.72720802527553e+25*cos(theta)**14 + 2.24343483135614e+25*cos(theta)**12 - 3.71094483382219e+24*cos(theta)**10 + 3.79528448913633e+23*cos(theta)**8 - 2.22783995169428e+22*cos(theta)**6 + 6.55247044615964e+20*cos(theta)**4 - 7.29403018125378e+18*cos(theta)**2 + 1.29326776263365e+16)*sin(11*phi)

#@torch.jit.script
def Yl35_m_minus_10(theta, phi):
    return 1.21047590494358e-15*(1.0 - cos(theta)**2)**5*(2.17508813955772e+24*cos(theta)**25 - 9.45690495459877e+24*cos(theta)**23 + 1.78552011456231e+25*cos(theta)**21 - 1.92286781568248e+25*cos(theta)**19 + 1.30480316064168e+25*cos(theta)**17 - 5.81813868351702e+24*cos(theta)**15 + 1.72571910104318e+24*cos(theta)**13 - 3.37358621256562e+23*cos(theta)**11 + 4.21698276570703e+22*cos(theta)**9 - 3.1826285024204e+21*cos(theta)**7 + 1.31049408923193e+20*cos(theta)**5 - 2.43134339375126e+18*cos(theta)**3 + 1.29326776263365e+16*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl35_m_minus_9(theta, phi):
    return 4.14046463847392e-14*(1.0 - cos(theta)**2)**4.5*(8.36572361368353e+22*cos(theta)**26 - 3.94037706441615e+23*cos(theta)**24 + 8.11600052073775e+23*cos(theta)**22 - 9.61433907841241e+23*cos(theta)**20 + 7.24890644800936e+23*cos(theta)**18 - 3.63633667719814e+23*cos(theta)**16 + 1.23265650074513e+23*cos(theta)**14 - 2.81132184380469e+22*cos(theta)**12 + 4.21698276570703e+21*cos(theta)**10 - 3.9782856280255e+20*cos(theta)**8 + 2.18415681538655e+19*cos(theta)**6 - 6.07835848437815e+17*cos(theta)**4 + 6.46633881316824e+15*cos(theta)**2 - 11053570620800.4)*sin(9*phi)

#@torch.jit.script
def Yl35_m_minus_8(theta, phi):
    return 1.42710951008933e-12*(1.0 - cos(theta)**2)**4*(3.09841615321612e+21*cos(theta)**27 - 1.57615082576646e+22*cos(theta)**25 + 3.52869587858163e+22*cos(theta)**23 - 4.57825670400591e+22*cos(theta)**21 + 3.81521392000493e+22*cos(theta)**19 - 2.13902157482243e+22*cos(theta)**17 + 8.21771000496754e+21*cos(theta)**15 - 2.16255526446514e+21*cos(theta)**13 + 3.8336206960973e+20*cos(theta)**11 - 4.42031736447278e+19*cos(theta)**9 + 3.12022402198078e+18*cos(theta)**7 - 1.21567169687563e+17*cos(theta)**5 + 2.15544627105608e+15*cos(theta)**3 - 11053570620800.4*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl35_m_minus_7(theta, phi):
    return 4.95188492471306e-11*(1.0 - cos(theta)**2)**3.5*(1.10657719757719e+20*cos(theta)**28 - 6.06211856064024e+20*cos(theta)**26 + 1.47028994940901e+21*cos(theta)**24 - 2.08102577454814e+21*cos(theta)**22 + 1.90760696000246e+21*cos(theta)**20 - 1.1883453193458e+21*cos(theta)**18 + 5.13606875310471e+20*cos(theta)**16 - 1.54468233176082e+20*cos(theta)**14 + 3.19468391341442e+19*cos(theta)**12 - 4.42031736447278e+18*cos(theta)**10 + 3.90028002747598e+17*cos(theta)**8 - 2.02611949479272e+16*cos(theta)**6 + 538861567764020.0*cos(theta)**4 - 5526785310400.21*cos(theta)**2 + 9180706495.68141)*sin(7*phi)

#@torch.jit.script
def Yl35_m_minus_6(theta, phi):
    return 1.72820074431929e-9*(1.0 - cos(theta)**2)**3*(3.81578343992133e+18*cos(theta)**29 - 2.24522909653342e+19*cos(theta)**27 + 5.88115979763605e+19*cos(theta)**25 - 9.04793815020931e+19*cos(theta)**23 + 9.08384266667839e+19*cos(theta)**21 - 6.2544490491884e+19*cos(theta)**19 + 3.02121691359101e+19*cos(theta)**17 - 1.02978822117388e+19*cos(theta)**15 + 2.45744916416494e+18*cos(theta)**13 - 4.01847033133889e+17*cos(theta)**11 + 4.33364447497331e+16*cos(theta)**9 - 2.89445642113245e+15*cos(theta)**7 + 107772313552804.0*cos(theta)**5 - 1842261770133.4*cos(theta)**3 + 9180706495.68141*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl35_m_minus_5(theta, phi):
    return 6.06103432557419e-8*(1.0 - cos(theta)**2)**2.5*(1.27192781330711e+17*cos(theta)**30 - 8.01867534476222e+17*cos(theta)**28 + 2.26198453755233e+18*cos(theta)**26 - 3.76997422925388e+18*cos(theta)**24 + 4.12901939394472e+18*cos(theta)**22 - 3.1272245245942e+18*cos(theta)**20 + 1.67845384088389e+18*cos(theta)**18 - 6.43617638233673e+17*cos(theta)**16 + 1.75532083154638e+17*cos(theta)**14 - 3.34872527611574e+16*cos(theta)**12 + 4.33364447497331e+15*cos(theta)**10 - 361807052641557.0*cos(theta)**8 + 17962052258800.7*cos(theta)**6 - 460565442533.351*cos(theta)**4 + 4590353247.8407*cos(theta)**2 - 7463989.02087919)*sin(5*phi)

#@torch.jit.script
def Yl35_m_minus_4(theta, phi):
    return 2.13431042725227e-6*(1.0 - cos(theta)**2)**2*(4.10299294615197e+15*cos(theta)**31 - 2.76506046371111e+16*cos(theta)**29 + 8.37772050945307e+16*cos(theta)**27 - 1.50798969170155e+17*cos(theta)**25 + 1.79522582345423e+17*cos(theta)**23 - 1.48915453552105e+17*cos(theta)**21 + 8.83396758359944e+16*cos(theta)**19 - 3.7859861072569e+16*cos(theta)**17 + 1.17021388769759e+16*cos(theta)**15 - 2.57594252008903e+15*cos(theta)**13 + 393967679543028.0*cos(theta)**11 - 40200783626839.6*cos(theta)**9 + 2566007465542.95*cos(theta)**7 - 92113088506.6701*cos(theta)**5 + 1530117749.28023*cos(theta)**3 - 7463989.02087919*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl35_m_minus_3(theta, phi):
    return 7.53988772320084e-5*(1.0 - cos(theta)**2)**1.5*(128218529567249.0*cos(theta)**32 - 921686821237037.0*cos(theta)**30 + 2.99204303909038e+15*cos(theta)**28 - 5.79996035269828e+15*cos(theta)**26 + 7.48010759772595e+15*cos(theta)**24 - 6.7688842523684e+15*cos(theta)**22 + 4.41698379179972e+15*cos(theta)**20 - 2.10332561514272e+15*cos(theta)**18 + 731383679810993.0*cos(theta)**16 - 183995894292074.0*cos(theta)**14 + 32830639961919.0*cos(theta)**12 - 4020078362683.96*cos(theta)**10 + 320750933192.869*cos(theta)**8 - 15352181417.7784*cos(theta)**6 + 382529437.320059*cos(theta)**4 - 3731994.5104396*cos(theta)**2 + 5980.76043339679)*sin(3*phi)

#@torch.jit.script
def Yl35_m_minus_2(theta, phi):
    return 0.00267001466710592*(1.0 - cos(theta)**2)*(3885409986886.33*cos(theta)**33 - 29731832943130.2*cos(theta)**31 + 103173897899668.0*cos(theta)**29 - 214813346396232.0*cos(theta)**27 + 299204303909038.0*cos(theta)**25 - 294299315320365.0*cos(theta)**23 + 210332561514272.0*cos(theta)**21 - 110701348165407.0*cos(theta)**19 + 43022569400646.6*cos(theta)**17 - 12266392952804.9*cos(theta)**15 + 2525433843224.54*cos(theta)**13 - 365461669334.906*cos(theta)**11 + 35638992576.9855*cos(theta)**9 - 2193168773.96834*cos(theta)**7 + 76505887.4640117*cos(theta)**5 - 1243998.17014653*cos(theta)**3 + 5980.76043339679*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl35_m_minus_1(theta, phi):
    return 0.09470086974142*(1.0 - cos(theta)**2)**0.5*(114276764320.186*cos(theta)**34 - 929119779472.819*cos(theta)**32 + 3439129929988.94*cos(theta)**30 - 7671905228436.87*cos(theta)**28 + 11507857842655.3*cos(theta)**26 - 12262471471681.9*cos(theta)**24 + 9560570977921.47*cos(theta)**22 - 5535067408270.33*cos(theta)**20 + 2390142744480.37*cos(theta)**18 - 766649559550.307*cos(theta)**16 + 180388131658.896*cos(theta)**14 - 30455139111.2421*cos(theta)**12 + 3563899257.69855*cos(theta)**10 - 274146096.746042*cos(theta)**8 + 12750981.244002*cos(theta)**6 - 310999.542536633*cos(theta)**4 + 2990.3802166984*cos(theta)**2 - 4.75418158457614)*sin(phi)

#@torch.jit.script
def Yl35_m0(theta, phi):
    return 24381701263.8311*cos(theta)**35 - 210248003651.877*cos(theta)**33 + 828439894986.499*cos(theta)**31 - 1975510518813.96*cos(theta)**29 + 3182766946978.05*cos(theta)**27 - 3662790814391.13*cos(theta)**25 + 3104060012195.87*cos(theta)**23 - 1968238554099.14*cos(theta)**21 + 939386582638.224*cos(theta)**19 - 336761227738.231*cos(theta)**17 + 89802994063.5284*cos(theta)**15 - 17494089752.6354*cos(theta)**13 + 2419395391.32192*cos(theta)**11 - 227464523.970437*cos(theta)**9 + 13602529.6726507*cos(theta)**7 - 464476.62296856*cos(theta)**5 + 7443.53562449616*cos(theta)**3 - 35.5017597352758*cos(theta)

#@torch.jit.script
def Yl35_m1(theta, phi):
    return 0.09470086974142*(1.0 - cos(theta)**2)**0.5*(114276764320.186*cos(theta)**34 - 929119779472.819*cos(theta)**32 + 3439129929988.94*cos(theta)**30 - 7671905228436.87*cos(theta)**28 + 11507857842655.3*cos(theta)**26 - 12262471471681.9*cos(theta)**24 + 9560570977921.47*cos(theta)**22 - 5535067408270.33*cos(theta)**20 + 2390142744480.37*cos(theta)**18 - 766649559550.307*cos(theta)**16 + 180388131658.896*cos(theta)**14 - 30455139111.2421*cos(theta)**12 + 3563899257.69855*cos(theta)**10 - 274146096.746042*cos(theta)**8 + 12750981.244002*cos(theta)**6 - 310999.542536633*cos(theta)**4 + 2990.3802166984*cos(theta)**2 - 4.75418158457614)*cos(phi)

#@torch.jit.script
def Yl35_m2(theta, phi):
    return 0.00267001466710592*(1.0 - cos(theta)**2)*(3885409986886.33*cos(theta)**33 - 29731832943130.2*cos(theta)**31 + 103173897899668.0*cos(theta)**29 - 214813346396232.0*cos(theta)**27 + 299204303909038.0*cos(theta)**25 - 294299315320365.0*cos(theta)**23 + 210332561514272.0*cos(theta)**21 - 110701348165407.0*cos(theta)**19 + 43022569400646.6*cos(theta)**17 - 12266392952804.9*cos(theta)**15 + 2525433843224.54*cos(theta)**13 - 365461669334.906*cos(theta)**11 + 35638992576.9855*cos(theta)**9 - 2193168773.96834*cos(theta)**7 + 76505887.4640117*cos(theta)**5 - 1243998.17014653*cos(theta)**3 + 5980.76043339679*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl35_m3(theta, phi):
    return 7.53988772320084e-5*(1.0 - cos(theta)**2)**1.5*(128218529567249.0*cos(theta)**32 - 921686821237037.0*cos(theta)**30 + 2.99204303909038e+15*cos(theta)**28 - 5.79996035269828e+15*cos(theta)**26 + 7.48010759772595e+15*cos(theta)**24 - 6.7688842523684e+15*cos(theta)**22 + 4.41698379179972e+15*cos(theta)**20 - 2.10332561514272e+15*cos(theta)**18 + 731383679810993.0*cos(theta)**16 - 183995894292074.0*cos(theta)**14 + 32830639961919.0*cos(theta)**12 - 4020078362683.96*cos(theta)**10 + 320750933192.869*cos(theta)**8 - 15352181417.7784*cos(theta)**6 + 382529437.320059*cos(theta)**4 - 3731994.5104396*cos(theta)**2 + 5980.76043339679)*cos(3*phi)

#@torch.jit.script
def Yl35_m4(theta, phi):
    return 2.13431042725227e-6*(1.0 - cos(theta)**2)**2*(4.10299294615197e+15*cos(theta)**31 - 2.76506046371111e+16*cos(theta)**29 + 8.37772050945307e+16*cos(theta)**27 - 1.50798969170155e+17*cos(theta)**25 + 1.79522582345423e+17*cos(theta)**23 - 1.48915453552105e+17*cos(theta)**21 + 8.83396758359944e+16*cos(theta)**19 - 3.7859861072569e+16*cos(theta)**17 + 1.17021388769759e+16*cos(theta)**15 - 2.57594252008903e+15*cos(theta)**13 + 393967679543028.0*cos(theta)**11 - 40200783626839.6*cos(theta)**9 + 2566007465542.95*cos(theta)**7 - 92113088506.6701*cos(theta)**5 + 1530117749.28023*cos(theta)**3 - 7463989.02087919*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl35_m5(theta, phi):
    return 6.06103432557419e-8*(1.0 - cos(theta)**2)**2.5*(1.27192781330711e+17*cos(theta)**30 - 8.01867534476222e+17*cos(theta)**28 + 2.26198453755233e+18*cos(theta)**26 - 3.76997422925388e+18*cos(theta)**24 + 4.12901939394472e+18*cos(theta)**22 - 3.1272245245942e+18*cos(theta)**20 + 1.67845384088389e+18*cos(theta)**18 - 6.43617638233673e+17*cos(theta)**16 + 1.75532083154638e+17*cos(theta)**14 - 3.34872527611574e+16*cos(theta)**12 + 4.33364447497331e+15*cos(theta)**10 - 361807052641557.0*cos(theta)**8 + 17962052258800.7*cos(theta)**6 - 460565442533.351*cos(theta)**4 + 4590353247.8407*cos(theta)**2 - 7463989.02087919)*cos(5*phi)

#@torch.jit.script
def Yl35_m6(theta, phi):
    return 1.72820074431929e-9*(1.0 - cos(theta)**2)**3*(3.81578343992133e+18*cos(theta)**29 - 2.24522909653342e+19*cos(theta)**27 + 5.88115979763605e+19*cos(theta)**25 - 9.04793815020931e+19*cos(theta)**23 + 9.08384266667839e+19*cos(theta)**21 - 6.2544490491884e+19*cos(theta)**19 + 3.02121691359101e+19*cos(theta)**17 - 1.02978822117388e+19*cos(theta)**15 + 2.45744916416494e+18*cos(theta)**13 - 4.01847033133889e+17*cos(theta)**11 + 4.33364447497331e+16*cos(theta)**9 - 2.89445642113245e+15*cos(theta)**7 + 107772313552804.0*cos(theta)**5 - 1842261770133.4*cos(theta)**3 + 9180706495.68141*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl35_m7(theta, phi):
    return 4.95188492471306e-11*(1.0 - cos(theta)**2)**3.5*(1.10657719757719e+20*cos(theta)**28 - 6.06211856064024e+20*cos(theta)**26 + 1.47028994940901e+21*cos(theta)**24 - 2.08102577454814e+21*cos(theta)**22 + 1.90760696000246e+21*cos(theta)**20 - 1.1883453193458e+21*cos(theta)**18 + 5.13606875310471e+20*cos(theta)**16 - 1.54468233176082e+20*cos(theta)**14 + 3.19468391341442e+19*cos(theta)**12 - 4.42031736447278e+18*cos(theta)**10 + 3.90028002747598e+17*cos(theta)**8 - 2.02611949479272e+16*cos(theta)**6 + 538861567764020.0*cos(theta)**4 - 5526785310400.21*cos(theta)**2 + 9180706495.68141)*cos(7*phi)

#@torch.jit.script
def Yl35_m8(theta, phi):
    return 1.42710951008933e-12*(1.0 - cos(theta)**2)**4*(3.09841615321612e+21*cos(theta)**27 - 1.57615082576646e+22*cos(theta)**25 + 3.52869587858163e+22*cos(theta)**23 - 4.57825670400591e+22*cos(theta)**21 + 3.81521392000493e+22*cos(theta)**19 - 2.13902157482243e+22*cos(theta)**17 + 8.21771000496754e+21*cos(theta)**15 - 2.16255526446514e+21*cos(theta)**13 + 3.8336206960973e+20*cos(theta)**11 - 4.42031736447278e+19*cos(theta)**9 + 3.12022402198078e+18*cos(theta)**7 - 1.21567169687563e+17*cos(theta)**5 + 2.15544627105608e+15*cos(theta)**3 - 11053570620800.4*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl35_m9(theta, phi):
    return 4.14046463847392e-14*(1.0 - cos(theta)**2)**4.5*(8.36572361368353e+22*cos(theta)**26 - 3.94037706441615e+23*cos(theta)**24 + 8.11600052073775e+23*cos(theta)**22 - 9.61433907841241e+23*cos(theta)**20 + 7.24890644800936e+23*cos(theta)**18 - 3.63633667719814e+23*cos(theta)**16 + 1.23265650074513e+23*cos(theta)**14 - 2.81132184380469e+22*cos(theta)**12 + 4.21698276570703e+21*cos(theta)**10 - 3.9782856280255e+20*cos(theta)**8 + 2.18415681538655e+19*cos(theta)**6 - 6.07835848437815e+17*cos(theta)**4 + 6.46633881316824e+15*cos(theta)**2 - 11053570620800.4)*cos(9*phi)

#@torch.jit.script
def Yl35_m10(theta, phi):
    return 1.21047590494358e-15*(1.0 - cos(theta)**2)**5*(2.17508813955772e+24*cos(theta)**25 - 9.45690495459877e+24*cos(theta)**23 + 1.78552011456231e+25*cos(theta)**21 - 1.92286781568248e+25*cos(theta)**19 + 1.30480316064168e+25*cos(theta)**17 - 5.81813868351702e+24*cos(theta)**15 + 1.72571910104318e+24*cos(theta)**13 - 3.37358621256562e+23*cos(theta)**11 + 4.21698276570703e+22*cos(theta)**9 - 3.1826285024204e+21*cos(theta)**7 + 1.31049408923193e+20*cos(theta)**5 - 2.43134339375126e+18*cos(theta)**3 + 1.29326776263365e+16*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl35_m11(theta, phi):
    return 3.56949870606501e-17*(1.0 - cos(theta)**2)**5.5*(5.43772034889429e+25*cos(theta)**24 - 2.17508813955772e+26*cos(theta)**22 + 3.74959224058084e+26*cos(theta)**20 - 3.65344884979672e+26*cos(theta)**18 + 2.21816537309086e+26*cos(theta)**16 - 8.72720802527553e+25*cos(theta)**14 + 2.24343483135614e+25*cos(theta)**12 - 3.71094483382219e+24*cos(theta)**10 + 3.79528448913633e+23*cos(theta)**8 - 2.22783995169428e+22*cos(theta)**6 + 6.55247044615964e+20*cos(theta)**4 - 7.29403018125378e+18*cos(theta)**2 + 1.29326776263365e+16)*cos(11*phi)

#@torch.jit.script
def Yl35_m12(theta, phi):
    return 1.06280277340603e-18*(1.0 - cos(theta)**2)**6*(1.30505288373463e+27*cos(theta)**23 - 4.78519390702698e+27*cos(theta)**21 + 7.49918448116168e+27*cos(theta)**19 - 6.57620792963409e+27*cos(theta)**17 + 3.54906459694538e+27*cos(theta)**15 - 1.22180912353857e+27*cos(theta)**13 + 2.69212179762737e+26*cos(theta)**11 - 3.71094483382218e+25*cos(theta)**9 + 3.03622759130906e+24*cos(theta)**7 - 1.33670397101657e+23*cos(theta)**5 + 2.62098817846386e+21*cos(theta)**3 - 1.45880603625076e+19*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl35_m13(theta, phi):
    return 3.19866046346017e-20*(1.0 - cos(theta)**2)**6.5*(3.00162163258965e+28*cos(theta)**22 - 1.00489072047567e+29*cos(theta)**20 + 1.42484505142072e+29*cos(theta)**18 - 1.1179553480378e+29*cos(theta)**16 + 5.32359689541807e+28*cos(theta)**14 - 1.58835186060015e+28*cos(theta)**12 + 2.9613339773901e+27*cos(theta)**10 - 3.33985035043997e+26*cos(theta)**8 + 2.12535931391634e+25*cos(theta)**6 - 6.68351985508284e+23*cos(theta)**4 + 7.86296453539157e+21*cos(theta)**2 - 1.45880603625076e+19)*cos(13*phi)

#@torch.jit.script
def Yl35_m14(theta, phi):
    return 9.74223860268681e-22*(1.0 - cos(theta)**2)**7*(6.60356759169723e+29*cos(theta)**21 - 2.00978144095133e+30*cos(theta)**19 + 2.5647210925573e+30*cos(theta)**17 - 1.78872855686047e+30*cos(theta)**15 + 7.4530356535853e+29*cos(theta)**13 - 1.90602223272018e+29*cos(theta)**11 + 2.9613339773901e+28*cos(theta)**9 - 2.67188028035197e+27*cos(theta)**7 + 1.27521558834981e+26*cos(theta)**5 - 2.67340794203313e+24*cos(theta)**3 + 1.57259290707831e+22*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl35_m15(theta, phi):
    return 3.00652010504917e-23*(1.0 - cos(theta)**2)**7.5*(1.38674919425642e+31*cos(theta)**20 - 3.81858473780753e+31*cos(theta)**18 + 4.3600258573474e+31*cos(theta)**16 - 2.68309283529071e+31*cos(theta)**14 + 9.68894634966089e+30*cos(theta)**12 - 2.09662445599219e+30*cos(theta)**10 + 2.66520057965109e+29*cos(theta)**8 - 1.87031619624638e+28*cos(theta)**6 + 6.37607794174903e+26*cos(theta)**4 - 8.02022382609941e+24*cos(theta)**2 + 1.57259290707831e+22)*cos(15*phi)

#@torch.jit.script
def Yl35_m16(theta, phi):
    return 9.41377960708832e-25*(1.0 - cos(theta)**2)**8*(2.77349838851284e+32*cos(theta)**19 - 6.87345252805355e+32*cos(theta)**17 + 6.97604137175584e+32*cos(theta)**15 - 3.75632996940699e+32*cos(theta)**13 + 1.16267356195931e+32*cos(theta)**11 - 2.09662445599219e+31*cos(theta)**9 + 2.13216046372087e+30*cos(theta)**7 - 1.12218971774783e+29*cos(theta)**5 + 2.55043117669961e+27*cos(theta)**3 - 1.60404476521988e+25*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl35_m17(theta, phi):
    return 2.9949222630012e-26*(1.0 - cos(theta)**2)**8.5*(5.26964693817439e+33*cos(theta)**18 - 1.1684869297691e+34*cos(theta)**16 + 1.04640620576338e+34*cos(theta)**14 - 4.88322896022909e+33*cos(theta)**12 + 1.27894091815524e+33*cos(theta)**10 - 1.88696201039297e+32*cos(theta)**8 + 1.49251232460461e+31*cos(theta)**6 - 5.61094858873914e+29*cos(theta)**4 + 7.65129353009883e+27*cos(theta)**2 - 1.60404476521988e+25)*cos(17*phi)

#@torch.jit.script
def Yl35_m18(theta, phi):
    return 9.6964188430403e-28*(1.0 - cos(theta)**2)**9*(9.4853644887139e+34*cos(theta)**17 - 1.86957908763057e+35*cos(theta)**15 + 1.46496868806873e+35*cos(theta)**13 - 5.85987475227491e+34*cos(theta)**11 + 1.27894091815524e+34*cos(theta)**9 - 1.50956960831438e+33*cos(theta)**7 + 8.95507394762767e+31*cos(theta)**5 - 2.24437943549566e+30*cos(theta)**3 + 1.53025870601977e+28*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl35_m19(theta, phi):
    return 3.20029509770303e-29*(1.0 - cos(theta)**2)**9.5*(1.61251196308136e+36*cos(theta)**16 - 2.80436863144585e+36*cos(theta)**14 + 1.90445929448935e+36*cos(theta)**12 - 6.4458622275024e+35*cos(theta)**10 + 1.15104682633971e+35*cos(theta)**8 - 1.05669872582007e+34*cos(theta)**6 + 4.47753697381384e+32*cos(theta)**4 - 6.73313830648697e+30*cos(theta)**2 + 1.53025870601977e+28)*cos(19*phi)

#@torch.jit.script
def Yl35_m20(theta, phi):
    return 1.07881925735658e-30*(1.0 - cos(theta)**2)**10*(2.58001914093018e+37*cos(theta)**15 - 3.92611608402419e+37*cos(theta)**13 + 2.28535115338721e+37*cos(theta)**11 - 6.4458622275024e+36*cos(theta)**9 + 9.20837461071771e+35*cos(theta)**7 - 6.34019235492039e+34*cos(theta)**5 + 1.79101478952553e+33*cos(theta)**3 - 1.34662766129739e+31*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl35_m21(theta, phi):
    return 3.72228007128537e-32*(1.0 - cos(theta)**2)**10.5*(3.87002871139527e+38*cos(theta)**14 - 5.10395090923145e+38*cos(theta)**12 + 2.51388626872594e+38*cos(theta)**10 - 5.80127600475216e+37*cos(theta)**8 + 6.4458622275024e+36*cos(theta)**6 - 3.1700961774602e+35*cos(theta)**4 + 5.3730443685766e+33*cos(theta)**2 - 1.34662766129739e+31)*cos(21*phi)

#@torch.jit.script
def Yl35_m22(theta, phi):
    return 1.31767286173862e-33*(1.0 - cos(theta)**2)**11*(5.41804019595338e+39*cos(theta)**13 - 6.12474109107773e+39*cos(theta)**11 + 2.51388626872594e+39*cos(theta)**9 - 4.64102080380173e+38*cos(theta)**7 + 3.86751733650144e+37*cos(theta)**5 - 1.26803847098408e+36*cos(theta)**3 + 1.07460887371532e+34*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl35_m23(theta, phi):
    return 4.79868153112577e-35*(1.0 - cos(theta)**2)**11.5*(7.04345225473939e+40*cos(theta)**12 - 6.73721520018551e+40*cos(theta)**10 + 2.26249764185334e+40*cos(theta)**8 - 3.24871456266121e+39*cos(theta)**6 + 1.93375866825072e+38*cos(theta)**4 - 3.80411541295224e+36*cos(theta)**2 + 1.07460887371532e+34)*cos(23*phi)

#@torch.jit.script
def Yl35_m24(theta, phi):
    return 1.80345495626061e-36*(1.0 - cos(theta)**2)**12*(8.45214270568727e+41*cos(theta)**11 - 6.73721520018551e+41*cos(theta)**9 + 1.80999811348267e+41*cos(theta)**7 - 1.94922873759673e+40*cos(theta)**5 + 7.73503467300288e+38*cos(theta)**3 - 7.60823082590447e+36*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl35_m25(theta, phi):
    return 7.01993889645875e-38*(1.0 - cos(theta)**2)**12.5*(9.297356976256e+42*cos(theta)**10 - 6.06349368016696e+42*cos(theta)**8 + 1.26699867943787e+42*cos(theta)**6 - 9.74614368798363e+40*cos(theta)**4 + 2.32051040190086e+39*cos(theta)**2 - 7.60823082590447e+36)*cos(25*phi)

#@torch.jit.script
def Yl35_m26(theta, phi):
    return 2.8422901788273e-39*(1.0 - cos(theta)**2)**13*(9.297356976256e+43*cos(theta)**9 - 4.85079494413357e+43*cos(theta)**7 + 7.60199207662723e+42*cos(theta)**5 - 3.89845747519345e+41*cos(theta)**3 + 4.64102080380173e+39*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl35_m27(theta, phi):
    return 1.20323737894154e-40*(1.0 - cos(theta)**2)**13.5*(8.3676212786304e+44*cos(theta)**8 - 3.3955564608935e+44*cos(theta)**6 + 3.80099603831361e+43*cos(theta)**4 - 1.16953724255804e+42*cos(theta)**2 + 4.64102080380173e+39)*cos(27*phi)

#@torch.jit.script
def Yl35_m28(theta, phi):
    return 5.35964527018943e-42*(1.0 - cos(theta)**2)**14*(6.69409702290432e+45*cos(theta)**7 - 2.0373338765361e+45*cos(theta)**5 + 1.52039841532545e+44*cos(theta)**3 - 2.33907448511607e+42*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl35_m29(theta, phi):
    return 2.53219437507943e-43*(1.0 - cos(theta)**2)**14.5*(4.68586791603302e+46*cos(theta)**6 - 1.01866693826805e+46*cos(theta)**4 + 4.56119524597634e+44*cos(theta)**2 - 2.33907448511607e+42)*cos(29*phi)

#@torch.jit.script
def Yl35_m30(theta, phi):
    return 1.28222646437538e-44*(1.0 - cos(theta)**2)**15*(2.81152074961981e+47*cos(theta)**5 - 4.0746677530722e+46*cos(theta)**3 + 9.12239049195268e+44*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl35_m31(theta, phi):
    return 7.05842437981691e-46*(1.0 - cos(theta)**2)**15.5*(1.40576037480991e+48*cos(theta)**4 - 1.22240032592166e+47*cos(theta)**2 + 9.12239049195268e+44)*cos(31*phi)

#@torch.jit.script
def Yl35_m32(theta, phi):
    return 4.31161892256615e-47*(1.0 - cos(theta)**2)**16*(5.62304149923963e+48*cos(theta)**3 - 2.44480065184332e+47*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl35_m33(theta, phi):
    return 3.01873705359384e-48*(1.0 - cos(theta)**2)**16.5*(1.68691244977189e+49*cos(theta)**2 - 2.44480065184332e+47)*cos(33*phi)

#@torch.jit.script
def Yl35_m34(theta, phi):
    return 8.66978407765238*(1.0 - cos(theta)**2)**17*cos(34*phi)*cos(theta)

#@torch.jit.script
def Yl35_m35(theta, phi):
    return 1.03623739663619*(1.0 - cos(theta)**2)**17.5*cos(35*phi)

#@torch.jit.script
def Yl36_m_minus_36(theta, phi):
    return 1.04340867525942*(1.0 - cos(theta)**2)**18*sin(36*phi)

#@torch.jit.script
def Yl36_m_minus_35(theta, phi):
    return 8.85361619789771*(1.0 - cos(theta)**2)**17.5*sin(35*phi)*cos(theta)

#@torch.jit.script
def Yl36_m_minus_34(theta, phi):
    return 4.40437182605064e-50*(1.0 - cos(theta)**2)**17*(1.19770783933804e+51*cos(theta)**2 - 1.68691244977189e+49)*sin(34*phi)

#@torch.jit.script
def Yl36_m_minus_33(theta, phi):
    return 6.38254114616021e-49*(1.0 - cos(theta)**2)**16.5*(3.99235946446014e+50*cos(theta)**3 - 1.68691244977189e+49*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl36_m_minus_32(theta, phi):
    return 1.06034737181502e-47*(1.0 - cos(theta)**2)**16*(9.98089866115034e+49*cos(theta)**4 - 8.43456224885944e+48*cos(theta)**2 + 6.11200162960829e+46)*sin(32*phi)

#@torch.jit.script
def Yl36_m_minus_31(theta, phi):
    return 1.95518394692445e-46*(1.0 - cos(theta)**2)**15.5*(1.99617973223007e+49*cos(theta)**5 - 2.81152074961981e+48*cos(theta)**3 + 6.11200162960829e+46*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl36_m_minus_30(theta, phi):
    return 3.92013162413846e-45*(1.0 - cos(theta)**2)**15*(3.32696622038345e+48*cos(theta)**6 - 7.02880187404954e+47*cos(theta)**4 + 3.05600081480415e+46*cos(theta)**2 - 1.52039841532545e+44)*sin(30*phi)

#@torch.jit.script
def Yl36_m_minus_29(theta, phi):
    return 8.42600353736191e-44*(1.0 - cos(theta)**2)**14.5*(4.75280888626207e+47*cos(theta)**7 - 1.40576037480991e+47*cos(theta)**5 + 1.01866693826805e+46*cos(theta)**3 - 1.52039841532545e+44*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl36_m_minus_28(theta, phi):
    return 1.92142443301969e-42*(1.0 - cos(theta)**2)**14*(5.94101110782758e+46*cos(theta)**8 - 2.34293395801651e+46*cos(theta)**6 + 2.54666734567012e+45*cos(theta)**4 - 7.60199207662723e+43*cos(theta)**2 + 2.92384310639509e+41)*sin(28*phi)

#@torch.jit.script
def Yl36_m_minus_27(theta, phi):
    return 4.61141863924726e-41*(1.0 - cos(theta)**2)**13.5*(6.60112345314176e+45*cos(theta)**9 - 3.34704851145216e+45*cos(theta)**7 + 5.09333469134024e+44*cos(theta)**5 - 2.53399735887574e+43*cos(theta)**3 + 2.92384310639509e+41*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl36_m_minus_26(theta, phi):
    return 1.1574568923217e-39*(1.0 - cos(theta)**2)**13*(6.60112345314176e+44*cos(theta)**10 - 4.1838106393152e+44*cos(theta)**8 + 8.48889115223374e+43*cos(theta)**6 - 6.33499339718936e+42*cos(theta)**4 + 1.46192155319754e+41*cos(theta)**2 - 4.64102080380173e+38)*sin(26*phi)

#@torch.jit.script
def Yl36_m_minus_25(theta, phi):
    return 3.0227136881809e-38*(1.0 - cos(theta)**2)**12.5*(6.00102132103796e+43*cos(theta)**11 - 4.648678488128e+43*cos(theta)**9 + 1.21269873603339e+43*cos(theta)**7 - 1.26699867943787e+42*cos(theta)**5 + 4.87307184399181e+40*cos(theta)**3 - 4.64102080380173e+38*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl36_m_minus_24(theta, phi):
    return 8.17810257077045e-37*(1.0 - cos(theta)**2)**12*(5.00085110086497e+42*cos(theta)**12 - 4.648678488128e+42*cos(theta)**10 + 1.51587342004174e+42*cos(theta)**8 - 2.11166446572979e+41*cos(theta)**6 + 1.21826796099795e+40*cos(theta)**4 - 2.32051040190086e+38*cos(theta)**2 + 6.34019235492039e+35)*sin(24*phi)

#@torch.jit.script
def Yl36_m_minus_23(theta, phi):
    return 2.28401974801605e-35*(1.0 - cos(theta)**2)**11.5*(3.8468085391269e+41*cos(theta)**13 - 4.22607135284364e+41*cos(theta)**11 + 1.68430380004638e+41*cos(theta)**9 - 3.01666352247112e+40*cos(theta)**7 + 2.43653592199591e+39*cos(theta)**5 - 7.73503467300288e+37*cos(theta)**3 + 6.34019235492039e+35*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl36_m_minus_22(theta, phi):
    return 6.56432202813386e-34*(1.0 - cos(theta)**2)**11*(2.74772038509064e+40*cos(theta)**14 - 3.5217261273697e+40*cos(theta)**12 + 1.68430380004638e+40*cos(theta)**10 - 3.7708294030889e+39*cos(theta)**8 + 4.06089320332651e+38*cos(theta)**6 - 1.93375866825072e+37*cos(theta)**4 + 3.1700961774602e+35*cos(theta)**2 - 7.67577766939515e+32)*sin(22*phi)

#@torch.jit.script
def Yl36_m_minus_21(theta, phi):
    return 1.93619682908189e-32*(1.0 - cos(theta)**2)**10.5*(1.83181359006043e+39*cos(theta)**15 - 2.70902009797669e+39*cos(theta)**13 + 1.53118527276943e+39*cos(theta)**11 - 4.18981044787656e+38*cos(theta)**9 + 5.80127600475216e+37*cos(theta)**7 - 3.86751733650144e+36*cos(theta)**5 + 1.05669872582007e+35*cos(theta)**3 - 7.67577766939515e+32*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl36_m_minus_20(theta, phi):
    return 5.84718619746581e-31*(1.0 - cos(theta)**2)**10*(1.14488349378777e+38*cos(theta)**16 - 1.93501435569764e+38*cos(theta)**14 + 1.27598772730786e+38*cos(theta)**12 - 4.18981044787656e+37*cos(theta)**10 + 7.2515950059402e+36*cos(theta)**8 - 6.4458622275024e+35*cos(theta)**6 + 2.64174681455016e+34*cos(theta)**4 - 3.83788883469757e+32*cos(theta)**2 + 8.41642288310872e+29)*sin(20*phi)

#@torch.jit.script
def Yl36_m_minus_19(theta, phi):
    return 1.80411990397808e-29*(1.0 - cos(theta)**2)**9.5*(6.73460878698687e+36*cos(theta)**17 - 1.29000957046509e+37*cos(theta)**15 + 9.81529021006047e+36*cos(theta)**13 - 3.80891858897869e+36*cos(theta)**11 + 8.057327784378e+35*cos(theta)**9 - 9.20837461071771e+34*cos(theta)**7 + 5.28349362910033e+33*cos(theta)**5 - 1.27929627823252e+32*cos(theta)**3 + 8.41642288310872e+29*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl36_m_minus_18(theta, phi):
    return 5.67653075535627e-28*(1.0 - cos(theta)**2)**9*(3.74144932610382e+35*cos(theta)**18 - 8.06255981540682e+35*cos(theta)**16 + 7.01092157861462e+35*cos(theta)**14 - 3.17409882414891e+35*cos(theta)**12 + 8.057327784378e+34*cos(theta)**10 - 1.15104682633971e+34*cos(theta)**8 + 8.80582271516721e+32*cos(theta)**6 - 3.19824069558131e+31*cos(theta)**4 + 4.20821144155436e+29*cos(theta)**2 - 8.50143725566537e+26)*sin(18*phi)

#@torch.jit.script
def Yl36_m_minus_17(theta, phi):
    return 1.81826289225004e-26*(1.0 - cos(theta)**2)**8.5*(1.96918385584411e+34*cos(theta)**19 - 4.74268224435695e+34*cos(theta)**17 + 4.67394771907641e+34*cos(theta)**15 - 2.44161448011455e+34*cos(theta)**13 + 7.32484344034364e+33*cos(theta)**11 - 1.27894091815524e+33*cos(theta)**9 + 1.25797467359532e+32*cos(theta)**7 - 6.39648139116262e+30*cos(theta)**5 + 1.40273714718479e+29*cos(theta)**3 - 8.50143725566537e+26*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl36_m_minus_16(theta, phi):
    return 5.91983508389675e-25*(1.0 - cos(theta)**2)**8*(9.84591927922057e+32*cos(theta)**20 - 2.63482346908719e+33*cos(theta)**18 + 2.92121732442276e+33*cos(theta)**16 - 1.74401034293896e+33*cos(theta)**14 + 6.10403620028636e+32*cos(theta)**12 - 1.27894091815524e+32*cos(theta)**10 + 1.57246834199415e+31*cos(theta)**8 - 1.06608023186044e+30*cos(theta)**6 + 3.50684286796196e+28*cos(theta)**4 - 4.25071862783268e+26*cos(theta)**2 + 8.0202238260994e+23)*sin(16*phi)

#@torch.jit.script
def Yl36_m_minus_15(theta, phi):
    return 1.95623456117164e-23*(1.0 - cos(theta)**2)**7.5*(4.68853299010503e+31*cos(theta)**21 - 1.38674919425642e+32*cos(theta)**19 + 1.71836313201339e+32*cos(theta)**17 - 1.16267356195931e+32*cos(theta)**15 + 4.69541246175874e+31*cos(theta)**13 - 1.16267356195931e+31*cos(theta)**11 + 1.74718704666016e+30*cos(theta)**9 - 1.52297175980062e+29*cos(theta)**7 + 7.01368573592393e+27*cos(theta)**5 - 1.41690620927756e+26*cos(theta)**3 + 8.0202238260994e+23*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl36_m_minus_14(theta, phi):
    return 6.55265580099988e-22*(1.0 - cos(theta)**2)**7*(2.13115135913865e+30*cos(theta)**22 - 6.93374597128209e+30*cos(theta)**20 + 9.54646184451882e+30*cos(theta)**18 - 7.26670976224567e+30*cos(theta)**16 + 3.35386604411339e+30*cos(theta)**14 - 9.68894634966089e+29*cos(theta)**12 + 1.74718704666016e+29*cos(theta)**10 - 1.90371469975078e+28*cos(theta)**8 + 1.16894762265399e+27*cos(theta)**6 - 3.5422655231939e+25*cos(theta)**4 + 4.0101119130497e+23*cos(theta)**2 - 7.1481495776287e+20)*sin(14*phi)

#@torch.jit.script
def Yl36_m_minus_13(theta, phi):
    return 2.22211369541106e-20*(1.0 - cos(theta)**2)**6.5*(9.26587547451588e+28*cos(theta)**23 - 3.30178379584861e+29*cos(theta)**21 + 5.02445360237833e+29*cos(theta)**19 - 4.27453515426216e+29*cos(theta)**17 + 2.23591069607559e+29*cos(theta)**15 - 7.4530356535853e+28*cos(theta)**13 + 1.58835186060015e+28*cos(theta)**11 - 2.11523855527865e+27*cos(theta)**9 + 1.66992517521998e+26*cos(theta)**7 - 7.08453104638781e+24*cos(theta)**5 + 1.33670397101657e+23*cos(theta)**3 - 7.1481495776287e+20*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl36_m_minus_12(theta, phi):
    return 7.62026258589038e-19*(1.0 - cos(theta)**2)**6*(3.86078144771495e+27*cos(theta)**24 - 1.50081081629482e+28*cos(theta)**22 + 2.51222680118916e+28*cos(theta)**20 - 2.37474175236787e+28*cos(theta)**18 + 1.39744418504724e+28*cos(theta)**16 - 5.32359689541807e+27*cos(theta)**14 + 1.32362655050012e+27*cos(theta)**12 - 2.11523855527865e+26*cos(theta)**10 + 2.08740646902498e+25*cos(theta)**8 - 1.18075517439797e+24*cos(theta)**6 + 3.34175992754142e+22*cos(theta)**4 - 3.57407478881435e+20*cos(theta)**2 + 6.07835848437815e+17)*sin(12*phi)

#@torch.jit.script
def Yl36_m_minus_11(theta, phi):
    return 2.63973639315567e-17*(1.0 - cos(theta)**2)**5.5*(1.54431257908598e+26*cos(theta)**25 - 6.52526441867315e+26*cos(theta)**23 + 1.19629847675674e+27*cos(theta)**21 - 1.24986408019361e+27*cos(theta)**19 + 8.22025991204261e+26*cos(theta)**17 - 3.54906459694538e+26*cos(theta)**15 + 1.01817426961548e+26*cos(theta)**13 - 1.92294414116241e+25*cos(theta)**11 + 2.31934052113887e+24*cos(theta)**9 - 1.68679310628281e+23*cos(theta)**7 + 6.68351985508284e+21*cos(theta)**5 - 1.19135826293812e+20*cos(theta)**3 + 6.07835848437815e+17*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl36_m_minus_10(theta, phi):
    return 9.22775728515781e-16*(1.0 - cos(theta)**2)**5*(5.9396637657153e+24*cos(theta)**26 - 2.71886017444715e+25*cos(theta)**24 + 5.43772034889429e+25*cos(theta)**22 - 6.24932040096807e+25*cos(theta)**20 + 4.5668110622459e+25*cos(theta)**18 - 2.21816537309086e+25*cos(theta)**16 + 7.27267335439627e+24*cos(theta)**14 - 1.60245345096867e+24*cos(theta)**12 + 2.31934052113887e+23*cos(theta)**10 - 2.10849138285351e+22*cos(theta)**8 + 1.11391997584714e+21*cos(theta)**6 - 2.97839565734529e+19*cos(theta)**4 + 3.03917924218907e+17*cos(theta)**2 - 497410677936019.0)*sin(10*phi)

#@torch.jit.script
def Yl36_m_minus_9(theta, phi):
    return 3.25204810244434e-14*(1.0 - cos(theta)**2)**4.5*(2.19987546878345e+23*cos(theta)**27 - 1.08754406977886e+24*cos(theta)**25 + 2.36422623864969e+24*cos(theta)**23 - 2.97586685760384e+24*cos(theta)**21 + 2.4035847696031e+24*cos(theta)**19 - 1.30480316064168e+24*cos(theta)**17 + 4.84844890293085e+23*cos(theta)**15 - 1.23265650074513e+23*cos(theta)**13 + 2.10849138285351e+22*cos(theta)**11 - 2.34276820317057e+21*cos(theta)**9 + 1.5913142512102e+20*cos(theta)**7 - 5.95679131469059e+18*cos(theta)**5 + 1.01305974739636e+17*cos(theta)**3 - 497410677936019.0*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl36_m_minus_8(theta, phi):
    return 1.15436256195231e-12*(1.0 - cos(theta)**2)**4*(7.85669810279802e+21*cos(theta)**28 - 4.18286180684176e+22*cos(theta)**26 + 9.85094266104039e+22*cos(theta)**24 - 1.35266675345629e+23*cos(theta)**22 + 1.20179238480155e+23*cos(theta)**20 - 7.24890644800936e+22*cos(theta)**18 + 3.03028056433178e+22*cos(theta)**16 - 8.80468929103665e+21*cos(theta)**14 + 1.75707615237793e+21*cos(theta)**12 - 2.34276820317057e+20*cos(theta)**10 + 1.98914281401275e+19*cos(theta)**8 - 9.92798552448431e+17*cos(theta)**6 + 2.5326493684909e+16*cos(theta)**4 - 248705338968009.0*cos(theta)**2 + 394770379314.301)*sin(8*phi)

#@torch.jit.script
def Yl36_m_minus_7(theta, phi):
    return 4.12351492246812e-11*(1.0 - cos(theta)**2)**3.5*(2.70920624234415e+20*cos(theta)**29 - 1.54920807660806e+21*cos(theta)**27 + 3.94037706441615e+21*cos(theta)**25 - 5.88115979763605e+21*cos(theta)**23 + 5.72282088000739e+21*cos(theta)**21 - 3.81521392000493e+21*cos(theta)**19 + 1.78251797901869e+21*cos(theta)**17 - 5.8697928606911e+20*cos(theta)**15 + 1.35159704029071e+20*cos(theta)**13 - 2.12978927560961e+19*cos(theta)**11 + 2.21015868223639e+18*cos(theta)**9 - 1.4182836463549e+17*cos(theta)**7 + 5.06529873698179e+15*cos(theta)**5 - 82901779656003.1*cos(theta)**3 + 394770379314.301*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl36_m_minus_6(theta, phi):
    return 1.48102512326443e-9*(1.0 - cos(theta)**2)**3*(9.03068747448049e+18*cos(theta)**30 - 5.53288598788593e+19*cos(theta)**28 + 1.51552964016006e+20*cos(theta)**26 - 2.45048324901502e+20*cos(theta)**24 + 2.60128221818518e+20*cos(theta)**22 - 1.90760696000246e+20*cos(theta)**20 + 9.90287766121497e+19*cos(theta)**18 - 3.66862053793194e+19*cos(theta)**16 + 9.6542645735051e+18*cos(theta)**14 - 1.77482439634134e+18*cos(theta)**12 + 2.21015868223639e+17*cos(theta)**10 - 1.77285455794363e+16*cos(theta)**8 + 844216456163632.0*cos(theta)**6 - 20725444914000.8*cos(theta)**4 + 197385189657.15*cos(theta)**2 - 306023549.856047)*sin(6*phi)

#@torch.jit.script
def Yl36_m_minus_5(theta, phi):
    return 5.34401806817122e-8*(1.0 - cos(theta)**2)**2.5*(2.9131249917679e+17*cos(theta)**31 - 1.90789171996067e+18*cos(theta)**29 + 5.61307274133355e+18*cos(theta)**27 - 9.80193299606009e+18*cos(theta)**25 + 1.13099226877616e+19*cos(theta)**23 - 9.08384266667839e+18*cos(theta)**21 + 5.21204087432367e+18*cos(theta)**19 - 2.15801208113643e+18*cos(theta)**17 + 6.43617638233673e+17*cos(theta)**15 - 1.36524953564719e+17*cos(theta)**13 + 2.00923516566944e+16*cos(theta)**11 - 1.96983839771514e+15*cos(theta)**9 + 120602350880519.0*cos(theta)**7 - 4145088982800.16*cos(theta)**5 + 65795063219.0501*cos(theta)**3 - 306023549.856047*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl36_m_minus_4(theta, phi):
    return 1.93568567169822e-6*(1.0 - cos(theta)**2)**2*(9.10351559927468e+15*cos(theta)**32 - 6.35963906653555e+16*cos(theta)**30 + 2.00466883619055e+17*cos(theta)**28 - 3.76997422925388e+17*cos(theta)**26 + 4.71246778656735e+17*cos(theta)**24 - 4.12901939394473e+17*cos(theta)**22 + 2.60602043716183e+17*cos(theta)**20 - 1.19889560063135e+17*cos(theta)**18 + 4.02261023896046e+16*cos(theta)**16 - 9.7517823974799e+15*cos(theta)**14 + 1.67436263805787e+15*cos(theta)**12 - 196983839771514.0*cos(theta)**10 + 15075293860064.9*cos(theta)**8 - 690848163800.026*cos(theta)**6 + 16448765804.7625*cos(theta)**4 - 153011774.928023*cos(theta)**2 + 233249.656902475)*sin(4*phi)

#@torch.jit.script
def Yl36_m_minus_3(theta, phi):
    return 7.03269529120626e-5*(1.0 - cos(theta)**2)**1.5*(275864109068930.0*cos(theta)**33 - 2.05149647307599e+15*cos(theta)**31 + 6.91265115927778e+15*cos(theta)**29 - 1.39628675157551e+16*cos(theta)**27 + 1.88498711462694e+16*cos(theta)**25 - 1.79522582345423e+16*cos(theta)**23 + 1.24096211293421e+16*cos(theta)**21 - 6.30997684542817e+15*cos(theta)**19 + 2.36624131703556e+15*cos(theta)**17 - 650118826498660.0*cos(theta)**15 + 128797126004452.0*cos(theta)**13 - 17907621797410.4*cos(theta)**11 + 1675032651118.32*cos(theta)**9 - 98692594828.5751*cos(theta)**7 + 3289753160.9525*cos(theta)**5 - 51003924.9760078*cos(theta)**3 + 233249.656902475*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl36_m_minus_2(theta, phi):
    return 0.00256090555968341*(1.0 - cos(theta)**2)*(8113650266733.23*cos(theta)**34 - 64109264783624.5*cos(theta)**32 + 230421705309259.0*cos(theta)**30 - 498673839848397.0*cos(theta)**28 + 724995044087285.0*cos(theta)**26 - 748010759772595.0*cos(theta)**24 + 564073687697367.0*cos(theta)**22 - 315498842271409.0*cos(theta)**20 + 131457850946420.0*cos(theta)**18 - 40632426656166.3*cos(theta)**16 + 9199794714603.68*cos(theta)**14 - 1492301816450.86*cos(theta)**12 + 167503265111.832*cos(theta)**10 - 12336574353.5719*cos(theta)**8 + 548292193.492084*cos(theta)**6 - 12750981.244002*cos(theta)**4 + 116624.828451237*cos(theta)**2 - 175.904718629317)*sin(2*phi)

#@torch.jit.script
def Yl36_m_minus_1(theta, phi):
    return 0.0933940875530734*(1.0 - cos(theta)**2)**0.5*(231818579049.521*cos(theta)**35 - 1942704993443.17*cos(theta)**33 + 7432958235782.55*cos(theta)**31 - 17195649649944.7*cos(theta)**29 + 26851668299529.1*cos(theta)**27 - 29920430390903.8*cos(theta)**25 + 24524942943363.8*cos(theta)**23 - 15023754393876.6*cos(theta)**21 + 6918834260337.91*cos(theta)**19 - 2390142744480.37*cos(theta)**17 + 613319647640.245*cos(theta)**15 - 114792447419.297*cos(theta)**13 + 15227569555.6211*cos(theta)**11 - 1370730483.73021*cos(theta)**9 + 78327456.2131549*cos(theta)**7 - 2550196.24880039*cos(theta)**5 + 38874.9428170791*cos(theta)**3 - 175.904718629317*cos(theta))*sin(phi)

#@torch.jit.script
def Yl36_m0(theta, phi):
    return 48758699040.5494*cos(theta)**36 - 432647611204.875*cos(theta)**34 + 1758806593376.34*cos(theta)**32 - 4340139653306.79*cos(theta)**30 + 7261387496878.67*cos(theta)**28 - 8713664996254.4*cos(theta)**26 + 7737544054051.04*cos(theta)**24 - 5170852685031.69*cos(theta)**22 + 2619445110180.53*cos(theta)**20 - 1005443577645.05*cos(theta)**18 + 290250693169.232*cos(theta)**16 - 62085709768.8196*cos(theta)**14 + 9608502702.31732*cos(theta)**12 - 1037907002.21431*cos(theta)**10 + 74136214.4438792*cos(theta)**8 - 3218316.28593584*cos(theta)**6 + 73589.549221094*cos(theta)**4 - 665.96877123162*cos(theta)**2 + 0.999953109957387

#@torch.jit.script
def Yl36_m1(theta, phi):
    return 0.0933940875530734*(1.0 - cos(theta)**2)**0.5*(231818579049.521*cos(theta)**35 - 1942704993443.17*cos(theta)**33 + 7432958235782.55*cos(theta)**31 - 17195649649944.7*cos(theta)**29 + 26851668299529.1*cos(theta)**27 - 29920430390903.8*cos(theta)**25 + 24524942943363.8*cos(theta)**23 - 15023754393876.6*cos(theta)**21 + 6918834260337.91*cos(theta)**19 - 2390142744480.37*cos(theta)**17 + 613319647640.245*cos(theta)**15 - 114792447419.297*cos(theta)**13 + 15227569555.6211*cos(theta)**11 - 1370730483.73021*cos(theta)**9 + 78327456.2131549*cos(theta)**7 - 2550196.24880039*cos(theta)**5 + 38874.9428170791*cos(theta)**3 - 175.904718629317*cos(theta))*cos(phi)

#@torch.jit.script
def Yl36_m2(theta, phi):
    return 0.00256090555968341*(1.0 - cos(theta)**2)*(8113650266733.23*cos(theta)**34 - 64109264783624.5*cos(theta)**32 + 230421705309259.0*cos(theta)**30 - 498673839848397.0*cos(theta)**28 + 724995044087285.0*cos(theta)**26 - 748010759772595.0*cos(theta)**24 + 564073687697367.0*cos(theta)**22 - 315498842271409.0*cos(theta)**20 + 131457850946420.0*cos(theta)**18 - 40632426656166.3*cos(theta)**16 + 9199794714603.68*cos(theta)**14 - 1492301816450.86*cos(theta)**12 + 167503265111.832*cos(theta)**10 - 12336574353.5719*cos(theta)**8 + 548292193.492084*cos(theta)**6 - 12750981.244002*cos(theta)**4 + 116624.828451237*cos(theta)**2 - 175.904718629317)*cos(2*phi)

#@torch.jit.script
def Yl36_m3(theta, phi):
    return 7.03269529120626e-5*(1.0 - cos(theta)**2)**1.5*(275864109068930.0*cos(theta)**33 - 2.05149647307599e+15*cos(theta)**31 + 6.91265115927778e+15*cos(theta)**29 - 1.39628675157551e+16*cos(theta)**27 + 1.88498711462694e+16*cos(theta)**25 - 1.79522582345423e+16*cos(theta)**23 + 1.24096211293421e+16*cos(theta)**21 - 6.30997684542817e+15*cos(theta)**19 + 2.36624131703556e+15*cos(theta)**17 - 650118826498660.0*cos(theta)**15 + 128797126004452.0*cos(theta)**13 - 17907621797410.4*cos(theta)**11 + 1675032651118.32*cos(theta)**9 - 98692594828.5751*cos(theta)**7 + 3289753160.9525*cos(theta)**5 - 51003924.9760078*cos(theta)**3 + 233249.656902475*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl36_m4(theta, phi):
    return 1.93568567169822e-6*(1.0 - cos(theta)**2)**2*(9.10351559927468e+15*cos(theta)**32 - 6.35963906653555e+16*cos(theta)**30 + 2.00466883619055e+17*cos(theta)**28 - 3.76997422925388e+17*cos(theta)**26 + 4.71246778656735e+17*cos(theta)**24 - 4.12901939394473e+17*cos(theta)**22 + 2.60602043716183e+17*cos(theta)**20 - 1.19889560063135e+17*cos(theta)**18 + 4.02261023896046e+16*cos(theta)**16 - 9.7517823974799e+15*cos(theta)**14 + 1.67436263805787e+15*cos(theta)**12 - 196983839771514.0*cos(theta)**10 + 15075293860064.9*cos(theta)**8 - 690848163800.026*cos(theta)**6 + 16448765804.7625*cos(theta)**4 - 153011774.928023*cos(theta)**2 + 233249.656902475)*cos(4*phi)

#@torch.jit.script
def Yl36_m5(theta, phi):
    return 5.34401806817122e-8*(1.0 - cos(theta)**2)**2.5*(2.9131249917679e+17*cos(theta)**31 - 1.90789171996067e+18*cos(theta)**29 + 5.61307274133355e+18*cos(theta)**27 - 9.80193299606009e+18*cos(theta)**25 + 1.13099226877616e+19*cos(theta)**23 - 9.08384266667839e+18*cos(theta)**21 + 5.21204087432367e+18*cos(theta)**19 - 2.15801208113643e+18*cos(theta)**17 + 6.43617638233673e+17*cos(theta)**15 - 1.36524953564719e+17*cos(theta)**13 + 2.00923516566944e+16*cos(theta)**11 - 1.96983839771514e+15*cos(theta)**9 + 120602350880519.0*cos(theta)**7 - 4145088982800.16*cos(theta)**5 + 65795063219.0501*cos(theta)**3 - 306023549.856047*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl36_m6(theta, phi):
    return 1.48102512326443e-9*(1.0 - cos(theta)**2)**3*(9.03068747448049e+18*cos(theta)**30 - 5.53288598788593e+19*cos(theta)**28 + 1.51552964016006e+20*cos(theta)**26 - 2.45048324901502e+20*cos(theta)**24 + 2.60128221818518e+20*cos(theta)**22 - 1.90760696000246e+20*cos(theta)**20 + 9.90287766121497e+19*cos(theta)**18 - 3.66862053793194e+19*cos(theta)**16 + 9.6542645735051e+18*cos(theta)**14 - 1.77482439634134e+18*cos(theta)**12 + 2.21015868223639e+17*cos(theta)**10 - 1.77285455794363e+16*cos(theta)**8 + 844216456163632.0*cos(theta)**6 - 20725444914000.8*cos(theta)**4 + 197385189657.15*cos(theta)**2 - 306023549.856047)*cos(6*phi)

#@torch.jit.script
def Yl36_m7(theta, phi):
    return 4.12351492246812e-11*(1.0 - cos(theta)**2)**3.5*(2.70920624234415e+20*cos(theta)**29 - 1.54920807660806e+21*cos(theta)**27 + 3.94037706441615e+21*cos(theta)**25 - 5.88115979763605e+21*cos(theta)**23 + 5.72282088000739e+21*cos(theta)**21 - 3.81521392000493e+21*cos(theta)**19 + 1.78251797901869e+21*cos(theta)**17 - 5.8697928606911e+20*cos(theta)**15 + 1.35159704029071e+20*cos(theta)**13 - 2.12978927560961e+19*cos(theta)**11 + 2.21015868223639e+18*cos(theta)**9 - 1.4182836463549e+17*cos(theta)**7 + 5.06529873698179e+15*cos(theta)**5 - 82901779656003.1*cos(theta)**3 + 394770379314.301*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl36_m8(theta, phi):
    return 1.15436256195231e-12*(1.0 - cos(theta)**2)**4*(7.85669810279802e+21*cos(theta)**28 - 4.18286180684176e+22*cos(theta)**26 + 9.85094266104039e+22*cos(theta)**24 - 1.35266675345629e+23*cos(theta)**22 + 1.20179238480155e+23*cos(theta)**20 - 7.24890644800936e+22*cos(theta)**18 + 3.03028056433178e+22*cos(theta)**16 - 8.80468929103665e+21*cos(theta)**14 + 1.75707615237793e+21*cos(theta)**12 - 2.34276820317057e+20*cos(theta)**10 + 1.98914281401275e+19*cos(theta)**8 - 9.92798552448431e+17*cos(theta)**6 + 2.5326493684909e+16*cos(theta)**4 - 248705338968009.0*cos(theta)**2 + 394770379314.301)*cos(8*phi)

#@torch.jit.script
def Yl36_m9(theta, phi):
    return 3.25204810244434e-14*(1.0 - cos(theta)**2)**4.5*(2.19987546878345e+23*cos(theta)**27 - 1.08754406977886e+24*cos(theta)**25 + 2.36422623864969e+24*cos(theta)**23 - 2.97586685760384e+24*cos(theta)**21 + 2.4035847696031e+24*cos(theta)**19 - 1.30480316064168e+24*cos(theta)**17 + 4.84844890293085e+23*cos(theta)**15 - 1.23265650074513e+23*cos(theta)**13 + 2.10849138285351e+22*cos(theta)**11 - 2.34276820317057e+21*cos(theta)**9 + 1.5913142512102e+20*cos(theta)**7 - 5.95679131469059e+18*cos(theta)**5 + 1.01305974739636e+17*cos(theta)**3 - 497410677936019.0*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl36_m10(theta, phi):
    return 9.22775728515781e-16*(1.0 - cos(theta)**2)**5*(5.9396637657153e+24*cos(theta)**26 - 2.71886017444715e+25*cos(theta)**24 + 5.43772034889429e+25*cos(theta)**22 - 6.24932040096807e+25*cos(theta)**20 + 4.5668110622459e+25*cos(theta)**18 - 2.21816537309086e+25*cos(theta)**16 + 7.27267335439627e+24*cos(theta)**14 - 1.60245345096867e+24*cos(theta)**12 + 2.31934052113887e+23*cos(theta)**10 - 2.10849138285351e+22*cos(theta)**8 + 1.11391997584714e+21*cos(theta)**6 - 2.97839565734529e+19*cos(theta)**4 + 3.03917924218907e+17*cos(theta)**2 - 497410677936019.0)*cos(10*phi)

#@torch.jit.script
def Yl36_m11(theta, phi):
    return 2.63973639315567e-17*(1.0 - cos(theta)**2)**5.5*(1.54431257908598e+26*cos(theta)**25 - 6.52526441867315e+26*cos(theta)**23 + 1.19629847675674e+27*cos(theta)**21 - 1.24986408019361e+27*cos(theta)**19 + 8.22025991204261e+26*cos(theta)**17 - 3.54906459694538e+26*cos(theta)**15 + 1.01817426961548e+26*cos(theta)**13 - 1.92294414116241e+25*cos(theta)**11 + 2.31934052113887e+24*cos(theta)**9 - 1.68679310628281e+23*cos(theta)**7 + 6.68351985508284e+21*cos(theta)**5 - 1.19135826293812e+20*cos(theta)**3 + 6.07835848437815e+17*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl36_m12(theta, phi):
    return 7.62026258589038e-19*(1.0 - cos(theta)**2)**6*(3.86078144771495e+27*cos(theta)**24 - 1.50081081629482e+28*cos(theta)**22 + 2.51222680118916e+28*cos(theta)**20 - 2.37474175236787e+28*cos(theta)**18 + 1.39744418504724e+28*cos(theta)**16 - 5.32359689541807e+27*cos(theta)**14 + 1.32362655050012e+27*cos(theta)**12 - 2.11523855527865e+26*cos(theta)**10 + 2.08740646902498e+25*cos(theta)**8 - 1.18075517439797e+24*cos(theta)**6 + 3.34175992754142e+22*cos(theta)**4 - 3.57407478881435e+20*cos(theta)**2 + 6.07835848437815e+17)*cos(12*phi)

#@torch.jit.script
def Yl36_m13(theta, phi):
    return 2.22211369541106e-20*(1.0 - cos(theta)**2)**6.5*(9.26587547451588e+28*cos(theta)**23 - 3.30178379584861e+29*cos(theta)**21 + 5.02445360237833e+29*cos(theta)**19 - 4.27453515426216e+29*cos(theta)**17 + 2.23591069607559e+29*cos(theta)**15 - 7.4530356535853e+28*cos(theta)**13 + 1.58835186060015e+28*cos(theta)**11 - 2.11523855527865e+27*cos(theta)**9 + 1.66992517521998e+26*cos(theta)**7 - 7.08453104638781e+24*cos(theta)**5 + 1.33670397101657e+23*cos(theta)**3 - 7.1481495776287e+20*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl36_m14(theta, phi):
    return 6.55265580099988e-22*(1.0 - cos(theta)**2)**7*(2.13115135913865e+30*cos(theta)**22 - 6.93374597128209e+30*cos(theta)**20 + 9.54646184451882e+30*cos(theta)**18 - 7.26670976224567e+30*cos(theta)**16 + 3.35386604411339e+30*cos(theta)**14 - 9.68894634966089e+29*cos(theta)**12 + 1.74718704666016e+29*cos(theta)**10 - 1.90371469975078e+28*cos(theta)**8 + 1.16894762265399e+27*cos(theta)**6 - 3.5422655231939e+25*cos(theta)**4 + 4.0101119130497e+23*cos(theta)**2 - 7.1481495776287e+20)*cos(14*phi)

#@torch.jit.script
def Yl36_m15(theta, phi):
    return 1.95623456117164e-23*(1.0 - cos(theta)**2)**7.5*(4.68853299010503e+31*cos(theta)**21 - 1.38674919425642e+32*cos(theta)**19 + 1.71836313201339e+32*cos(theta)**17 - 1.16267356195931e+32*cos(theta)**15 + 4.69541246175874e+31*cos(theta)**13 - 1.16267356195931e+31*cos(theta)**11 + 1.74718704666016e+30*cos(theta)**9 - 1.52297175980062e+29*cos(theta)**7 + 7.01368573592393e+27*cos(theta)**5 - 1.41690620927756e+26*cos(theta)**3 + 8.0202238260994e+23*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl36_m16(theta, phi):
    return 5.91983508389675e-25*(1.0 - cos(theta)**2)**8*(9.84591927922057e+32*cos(theta)**20 - 2.63482346908719e+33*cos(theta)**18 + 2.92121732442276e+33*cos(theta)**16 - 1.74401034293896e+33*cos(theta)**14 + 6.10403620028636e+32*cos(theta)**12 - 1.27894091815524e+32*cos(theta)**10 + 1.57246834199415e+31*cos(theta)**8 - 1.06608023186044e+30*cos(theta)**6 + 3.50684286796196e+28*cos(theta)**4 - 4.25071862783268e+26*cos(theta)**2 + 8.0202238260994e+23)*cos(16*phi)

#@torch.jit.script
def Yl36_m17(theta, phi):
    return 1.81826289225004e-26*(1.0 - cos(theta)**2)**8.5*(1.96918385584411e+34*cos(theta)**19 - 4.74268224435695e+34*cos(theta)**17 + 4.67394771907641e+34*cos(theta)**15 - 2.44161448011455e+34*cos(theta)**13 + 7.32484344034364e+33*cos(theta)**11 - 1.27894091815524e+33*cos(theta)**9 + 1.25797467359532e+32*cos(theta)**7 - 6.39648139116262e+30*cos(theta)**5 + 1.40273714718479e+29*cos(theta)**3 - 8.50143725566537e+26*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl36_m18(theta, phi):
    return 5.67653075535627e-28*(1.0 - cos(theta)**2)**9*(3.74144932610382e+35*cos(theta)**18 - 8.06255981540682e+35*cos(theta)**16 + 7.01092157861462e+35*cos(theta)**14 - 3.17409882414891e+35*cos(theta)**12 + 8.057327784378e+34*cos(theta)**10 - 1.15104682633971e+34*cos(theta)**8 + 8.80582271516721e+32*cos(theta)**6 - 3.19824069558131e+31*cos(theta)**4 + 4.20821144155436e+29*cos(theta)**2 - 8.50143725566537e+26)*cos(18*phi)

#@torch.jit.script
def Yl36_m19(theta, phi):
    return 1.80411990397808e-29*(1.0 - cos(theta)**2)**9.5*(6.73460878698687e+36*cos(theta)**17 - 1.29000957046509e+37*cos(theta)**15 + 9.81529021006047e+36*cos(theta)**13 - 3.80891858897869e+36*cos(theta)**11 + 8.057327784378e+35*cos(theta)**9 - 9.20837461071771e+34*cos(theta)**7 + 5.28349362910033e+33*cos(theta)**5 - 1.27929627823252e+32*cos(theta)**3 + 8.41642288310872e+29*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl36_m20(theta, phi):
    return 5.84718619746581e-31*(1.0 - cos(theta)**2)**10*(1.14488349378777e+38*cos(theta)**16 - 1.93501435569764e+38*cos(theta)**14 + 1.27598772730786e+38*cos(theta)**12 - 4.18981044787656e+37*cos(theta)**10 + 7.2515950059402e+36*cos(theta)**8 - 6.4458622275024e+35*cos(theta)**6 + 2.64174681455016e+34*cos(theta)**4 - 3.83788883469757e+32*cos(theta)**2 + 8.41642288310872e+29)*cos(20*phi)

#@torch.jit.script
def Yl36_m21(theta, phi):
    return 1.93619682908189e-32*(1.0 - cos(theta)**2)**10.5*(1.83181359006043e+39*cos(theta)**15 - 2.70902009797669e+39*cos(theta)**13 + 1.53118527276943e+39*cos(theta)**11 - 4.18981044787656e+38*cos(theta)**9 + 5.80127600475216e+37*cos(theta)**7 - 3.86751733650144e+36*cos(theta)**5 + 1.05669872582007e+35*cos(theta)**3 - 7.67577766939515e+32*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl36_m22(theta, phi):
    return 6.56432202813386e-34*(1.0 - cos(theta)**2)**11*(2.74772038509064e+40*cos(theta)**14 - 3.5217261273697e+40*cos(theta)**12 + 1.68430380004638e+40*cos(theta)**10 - 3.7708294030889e+39*cos(theta)**8 + 4.06089320332651e+38*cos(theta)**6 - 1.93375866825072e+37*cos(theta)**4 + 3.1700961774602e+35*cos(theta)**2 - 7.67577766939515e+32)*cos(22*phi)

#@torch.jit.script
def Yl36_m23(theta, phi):
    return 2.28401974801605e-35*(1.0 - cos(theta)**2)**11.5*(3.8468085391269e+41*cos(theta)**13 - 4.22607135284364e+41*cos(theta)**11 + 1.68430380004638e+41*cos(theta)**9 - 3.01666352247112e+40*cos(theta)**7 + 2.43653592199591e+39*cos(theta)**5 - 7.73503467300288e+37*cos(theta)**3 + 6.34019235492039e+35*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl36_m24(theta, phi):
    return 8.17810257077045e-37*(1.0 - cos(theta)**2)**12*(5.00085110086497e+42*cos(theta)**12 - 4.648678488128e+42*cos(theta)**10 + 1.51587342004174e+42*cos(theta)**8 - 2.11166446572979e+41*cos(theta)**6 + 1.21826796099795e+40*cos(theta)**4 - 2.32051040190086e+38*cos(theta)**2 + 6.34019235492039e+35)*cos(24*phi)

#@torch.jit.script
def Yl36_m25(theta, phi):
    return 3.0227136881809e-38*(1.0 - cos(theta)**2)**12.5*(6.00102132103796e+43*cos(theta)**11 - 4.648678488128e+43*cos(theta)**9 + 1.21269873603339e+43*cos(theta)**7 - 1.26699867943787e+42*cos(theta)**5 + 4.87307184399181e+40*cos(theta)**3 - 4.64102080380173e+38*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl36_m26(theta, phi):
    return 1.1574568923217e-39*(1.0 - cos(theta)**2)**13*(6.60112345314176e+44*cos(theta)**10 - 4.1838106393152e+44*cos(theta)**8 + 8.48889115223374e+43*cos(theta)**6 - 6.33499339718936e+42*cos(theta)**4 + 1.46192155319754e+41*cos(theta)**2 - 4.64102080380173e+38)*cos(26*phi)

#@torch.jit.script
def Yl36_m27(theta, phi):
    return 4.61141863924726e-41*(1.0 - cos(theta)**2)**13.5*(6.60112345314176e+45*cos(theta)**9 - 3.34704851145216e+45*cos(theta)**7 + 5.09333469134024e+44*cos(theta)**5 - 2.53399735887574e+43*cos(theta)**3 + 2.92384310639509e+41*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl36_m28(theta, phi):
    return 1.92142443301969e-42*(1.0 - cos(theta)**2)**14*(5.94101110782758e+46*cos(theta)**8 - 2.34293395801651e+46*cos(theta)**6 + 2.54666734567012e+45*cos(theta)**4 - 7.60199207662723e+43*cos(theta)**2 + 2.92384310639509e+41)*cos(28*phi)

#@torch.jit.script
def Yl36_m29(theta, phi):
    return 8.42600353736191e-44*(1.0 - cos(theta)**2)**14.5*(4.75280888626207e+47*cos(theta)**7 - 1.40576037480991e+47*cos(theta)**5 + 1.01866693826805e+46*cos(theta)**3 - 1.52039841532545e+44*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl36_m30(theta, phi):
    return 3.92013162413846e-45*(1.0 - cos(theta)**2)**15*(3.32696622038345e+48*cos(theta)**6 - 7.02880187404954e+47*cos(theta)**4 + 3.05600081480415e+46*cos(theta)**2 - 1.52039841532545e+44)*cos(30*phi)

#@torch.jit.script
def Yl36_m31(theta, phi):
    return 1.95518394692445e-46*(1.0 - cos(theta)**2)**15.5*(1.99617973223007e+49*cos(theta)**5 - 2.81152074961981e+48*cos(theta)**3 + 6.11200162960829e+46*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl36_m32(theta, phi):
    return 1.06034737181502e-47*(1.0 - cos(theta)**2)**16*(9.98089866115034e+49*cos(theta)**4 - 8.43456224885944e+48*cos(theta)**2 + 6.11200162960829e+46)*cos(32*phi)

#@torch.jit.script
def Yl36_m33(theta, phi):
    return 6.38254114616021e-49*(1.0 - cos(theta)**2)**16.5*(3.99235946446014e+50*cos(theta)**3 - 1.68691244977189e+49*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl36_m34(theta, phi):
    return 4.40437182605064e-50*(1.0 - cos(theta)**2)**17*(1.19770783933804e+51*cos(theta)**2 - 1.68691244977189e+49)*cos(34*phi)

#@torch.jit.script
def Yl36_m35(theta, phi):
    return 8.85361619789771*(1.0 - cos(theta)**2)**17.5*cos(35*phi)*cos(theta)

#@torch.jit.script
def Yl36_m36(theta, phi):
    return 1.04340867525942*(1.0 - cos(theta)**2)**18*cos(36*phi)

#@torch.jit.script
def Yl37_m_minus_37(theta, phi):
    return 1.05043507569481*(1.0 - cos(theta)**2)**18.5*sin(37*phi)

#@torch.jit.script
def Yl37_m_minus_36(theta, phi):
    return 9.03618419303727*(1.0 - cos(theta)**2)**18*sin(36*phi)*cos(theta)

#@torch.jit.script
def Yl37_m_minus_35(theta, phi):
    return 6.24392610871321e-52*(1.0 - cos(theta)**2)**17.5*(8.7432672271677e+52*cos(theta)**2 - 1.19770783933804e+51)*sin(35*phi)

#@torch.jit.script
def Yl37_m_minus_34(theta, phi):
    return 9.17665977479345e-51*(1.0 - cos(theta)**2)**17*(2.9144224090559e+52*cos(theta)**3 - 1.19770783933804e+51*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl37_m_minus_33(theta, phi):
    return 1.54647819359785e-49*(1.0 - cos(theta)**2)**16.5*(7.28605602263975e+51*cos(theta)**4 - 5.98853919669021e+50*cos(theta)**2 + 4.21728112442972e+48)*sin(33*phi)

#@torch.jit.script
def Yl37_m_minus_32(theta, phi):
    return 2.89319577828011e-48*(1.0 - cos(theta)**2)**16*(1.45721120452795e+51*cos(theta)**5 - 1.99617973223007e+50*cos(theta)**3 + 4.21728112442972e+48*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl37_m_minus_31(theta, phi):
    return 5.88678254222418e-47*(1.0 - cos(theta)**2)**15.5*(2.42868534087992e+50*cos(theta)**6 - 4.99044933057517e+49*cos(theta)**4 + 2.10864056221486e+48*cos(theta)**2 - 1.01866693826805e+46)*sin(31*phi)

#@torch.jit.script
def Yl37_m_minus_30(theta, phi):
    return 1.28434432069174e-45*(1.0 - cos(theta)**2)**15*(3.46955048697131e+49*cos(theta)**7 - 9.98089866115034e+48*cos(theta)**5 + 7.02880187404954e+47*cos(theta)**3 - 1.01866693826805e+46*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl37_m_minus_29(theta, phi):
    return 2.9734720766705e-44*(1.0 - cos(theta)**2)**14.5*(4.33693810871414e+48*cos(theta)**8 - 1.66348311019172e+48*cos(theta)**6 + 1.75720046851238e+47*cos(theta)**4 - 5.09333469134024e+45*cos(theta)**2 + 1.90049801915681e+43)*sin(29*phi)

#@torch.jit.script
def Yl37_m_minus_28(theta, phi):
    return 7.24698040379513e-43*(1.0 - cos(theta)**2)**14*(4.81882012079349e+47*cos(theta)**9 - 2.37640444313103e+47*cos(theta)**7 + 3.51440093702477e+46*cos(theta)**5 - 1.69777823044675e+45*cos(theta)**3 + 1.90049801915681e+43*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl37_m_minus_27(theta, phi):
    return 1.84762472467879e-41*(1.0 - cos(theta)**2)**13.5*(4.81882012079349e+46*cos(theta)**10 - 2.97050555391379e+46*cos(theta)**8 + 5.85733489504128e+45*cos(theta)**6 - 4.24444557611687e+44*cos(theta)**4 + 9.50249009578404e+42*cos(theta)**2 - 2.92384310639509e+40)*sin(27*phi)

#@torch.jit.script
def Yl37_m_minus_26(theta, phi):
    return 4.90230237211461e-40*(1.0 - cos(theta)**2)**13*(4.38074556435771e+45*cos(theta)**11 - 3.30056172657088e+45*cos(theta)**9 + 8.3676212786304e+44*cos(theta)**7 - 8.48889115223374e+43*cos(theta)**5 + 3.16749669859468e+42*cos(theta)**3 - 2.92384310639509e+40*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl37_m_minus_25(theta, phi):
    return 1.34791030198661e-38*(1.0 - cos(theta)**2)**12.5*(3.65062130363143e+44*cos(theta)**12 - 3.30056172657088e+44*cos(theta)**10 + 1.0459526598288e+44*cos(theta)**8 - 1.41481519203896e+43*cos(theta)**6 + 7.9187417464867e+41*cos(theta)**4 - 1.46192155319754e+40*cos(theta)**2 + 3.86751733650144e+37)*sin(25*phi)

#@torch.jit.script
def Yl37_m_minus_24(theta, phi):
    return 3.82673610124151e-37*(1.0 - cos(theta)**2)**12*(2.80817023356264e+43*cos(theta)**13 - 3.00051066051898e+43*cos(theta)**11 + 1.162169622032e+43*cos(theta)**9 - 2.02116456005565e+42*cos(theta)**7 + 1.58374834929734e+41*cos(theta)**5 - 4.87307184399181e+39*cos(theta)**3 + 3.86751733650144e+37*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl37_m_minus_23(theta, phi):
    return 1.11829774420847e-35*(1.0 - cos(theta)**2)**11.5*(2.00583588111617e+42*cos(theta)**14 - 2.50042555043248e+42*cos(theta)**12 + 1.162169622032e+42*cos(theta)**10 - 2.52645570006957e+41*cos(theta)**8 + 2.63958058216223e+40*cos(theta)**6 - 1.21826796099795e+39*cos(theta)**4 + 1.93375866825072e+37*cos(theta)**2 - 4.52870882494314e+34)*sin(23*phi)

#@torch.jit.script
def Yl37_m_minus_22(theta, phi):
    return 3.3548932326254e-34*(1.0 - cos(theta)**2)**11*(1.33722392074411e+41*cos(theta)**15 - 1.92340426956345e+41*cos(theta)**13 + 1.05651783821091e+41*cos(theta)**11 - 2.80717300007729e+40*cos(theta)**9 + 3.7708294030889e+39*cos(theta)**7 - 2.43653592199591e+38*cos(theta)**5 + 6.4458622275024e+36*cos(theta)**3 - 4.52870882494314e+34*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl37_m_minus_21(theta, phi):
    return 1.03077695553335e-32*(1.0 - cos(theta)**2)**10.5*(8.35764950465071e+39*cos(theta)**16 - 1.37386019254532e+40*cos(theta)**14 + 8.80431531842424e+39*cos(theta)**12 - 2.80717300007729e+39*cos(theta)**10 + 4.71353675386113e+38*cos(theta)**8 - 4.06089320332651e+37*cos(theta)**6 + 1.6114655568756e+36*cos(theta)**4 - 2.26435441247157e+34*cos(theta)**2 + 4.79736104337197e+31)*sin(21*phi)

#@torch.jit.script
def Yl37_m_minus_20(theta, phi):
    return 3.236705294292e-31*(1.0 - cos(theta)**2)**10*(4.91626441450041e+38*cos(theta)**17 - 9.15906795030214e+38*cos(theta)**15 + 6.77255024494173e+38*cos(theta)**13 - 2.55197545461572e+38*cos(theta)**11 + 5.2372630598457e+37*cos(theta)**9 - 5.80127600475216e+36*cos(theta)**7 + 3.2229311137512e+35*cos(theta)**5 - 7.5478480415719e+33*cos(theta)**3 + 4.79736104337197e+31*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl37_m_minus_19(theta, phi):
    return 1.03675667117759e-29*(1.0 - cos(theta)**2)**9.5*(2.73125800805579e+37*cos(theta)**18 - 5.72441746893884e+37*cos(theta)**16 + 4.83753588924409e+37*cos(theta)**14 - 2.12664621217977e+37*cos(theta)**12 + 5.2372630598457e+36*cos(theta)**10 - 7.2515950059402e+35*cos(theta)**8 + 5.371551856252e+34*cos(theta)**6 - 1.88696201039297e+33*cos(theta)**4 + 2.39868052168598e+31*cos(theta)**2 - 4.67579049061595e+28)*sin(19*phi)

#@torch.jit.script
def Yl37_m_minus_18(theta, phi):
    return 3.38179791904549e-28*(1.0 - cos(theta)**2)**9*(1.4375042147662e+36*cos(theta)**19 - 3.36730439349343e+36*cos(theta)**17 + 3.22502392616273e+36*cos(theta)**15 - 1.63588170167675e+36*cos(theta)**13 + 4.76114823622336e+35*cos(theta)**11 - 8.057327784378e+34*cos(theta)**9 + 7.67364550893143e+33*cos(theta)**7 - 3.77392402078595e+32*cos(theta)**5 + 7.99560173895328e+30*cos(theta)**3 - 4.67579049061595e+28*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl37_m_minus_17(theta, phi):
    return 1.12161548142786e-26*(1.0 - cos(theta)**2)**8.5*(7.18752107383102e+34*cos(theta)**20 - 1.87072466305191e+35*cos(theta)**18 + 2.0156399538517e+35*cos(theta)**16 - 1.1684869297691e+35*cos(theta)**14 + 3.96762353018614e+34*cos(theta)**12 - 8.057327784378e+33*cos(theta)**10 + 9.59205688616428e+32*cos(theta)**8 - 6.28987336797658e+31*cos(theta)**6 + 1.99890043473832e+30*cos(theta)**4 - 2.33789524530798e+28*cos(theta)**2 + 4.25071862783268e+25)*sin(17*phi)

#@torch.jit.script
def Yl37_m_minus_16(theta, phi):
    return 3.7770307660841e-25*(1.0 - cos(theta)**2)**8*(3.42262908277667e+33*cos(theta)**21 - 9.84591927922057e+33*cos(theta)**19 + 1.18567056108924e+34*cos(theta)**17 - 7.78991286512736e+33*cos(theta)**15 + 3.05201810014318e+33*cos(theta)**13 - 7.32484344034364e+32*cos(theta)**11 + 1.0657840984627e+32*cos(theta)**9 - 8.98553338282369e+30*cos(theta)**7 + 3.99780086947664e+29*cos(theta)**5 - 7.79298415102659e+27*cos(theta)**3 + 4.25071862783268e+25*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl37_m_minus_15(theta, phi):
    return 1.28973295692034e-23*(1.0 - cos(theta)**2)**7.5*(1.55574049217122e+32*cos(theta)**22 - 4.92295963961028e+32*cos(theta)**20 + 6.58705867271799e+32*cos(theta)**18 - 4.8686955407046e+32*cos(theta)**16 + 2.1800129286737e+32*cos(theta)**14 - 6.10403620028636e+31*cos(theta)**12 + 1.0657840984627e+31*cos(theta)**10 - 1.12319167285296e+30*cos(theta)**8 + 6.66300144912773e+28*cos(theta)**6 - 1.94824603775665e+27*cos(theta)**4 + 2.12535931391634e+25*cos(theta)**2 - 3.64555628459064e+22)*sin(15*phi)

#@torch.jit.script
def Yl37_m_minus_14(theta, phi):
    return 4.4603135268713e-22*(1.0 - cos(theta)**2)**7*(6.76408909639659e+30*cos(theta)**23 - 2.34426649505252e+31*cos(theta)**21 + 3.46687298564105e+31*cos(theta)**19 - 2.86393855335565e+31*cos(theta)**17 + 1.45334195244913e+31*cos(theta)**15 - 4.69541246175874e+30*cos(theta)**13 + 9.68894634966089e+29*cos(theta)**11 - 1.2479907476144e+29*cos(theta)**9 + 9.5185734987539e+27*cos(theta)**7 - 3.89649207551329e+26*cos(theta)**5 + 7.08453104638781e+24*cos(theta)**3 - 3.64555628459064e+22*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl37_m_minus_13(theta, phi):
    return 1.56047241666686e-20*(1.0 - cos(theta)**2)**6.5*(2.81837045683191e+29*cos(theta)**24 - 1.06557567956933e+30*cos(theta)**22 + 1.73343649282052e+30*cos(theta)**20 - 1.59107697408647e+30*cos(theta)**18 + 9.08338720280709e+29*cos(theta)**16 - 3.35386604411339e+29*cos(theta)**14 + 8.07412195805074e+28*cos(theta)**12 - 1.2479907476144e+28*cos(theta)**10 + 1.18982168734424e+27*cos(theta)**8 - 6.49415345918882e+25*cos(theta)**6 + 1.77113276159695e+24*cos(theta)**4 - 1.82277814229532e+22*cos(theta)**2 + 2.97839565734529e+19)*sin(13*phi)

#@torch.jit.script
def Yl37_m_minus_12(theta, phi):
    return 5.51710313839849e-19*(1.0 - cos(theta)**2)**6*(1.12734818273276e+28*cos(theta)**25 - 4.63293773725794e+28*cos(theta)**23 + 8.25445948962154e+28*cos(theta)**21 - 8.37408933729721e+28*cos(theta)**19 + 5.3431689428277e+28*cos(theta)**17 - 2.23591069607559e+28*cos(theta)**15 + 6.21086304465442e+27*cos(theta)**13 - 1.13453704328582e+27*cos(theta)**11 + 1.32202409704915e+26*cos(theta)**9 - 9.27736208455546e+24*cos(theta)**7 + 3.5422655231939e+23*cos(theta)**5 - 6.0759271409844e+21*cos(theta)**3 + 2.97839565734529e+19*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl37_m_minus_11(theta, phi):
    return 1.96922715928385e-17*(1.0 - cos(theta)**2)**5.5*(4.33595454897217e+26*cos(theta)**26 - 1.93039072385747e+27*cos(theta)**24 + 3.75202704073706e+27*cos(theta)**22 - 4.18704466864861e+27*cos(theta)**20 + 2.96842719045983e+27*cos(theta)**18 - 1.39744418504724e+27*cos(theta)**16 + 4.43633074618173e+26*cos(theta)**14 - 9.45447536071516e+25*cos(theta)**12 + 1.32202409704915e+25*cos(theta)**10 - 1.15967026056943e+24*cos(theta)**8 + 5.90377587198984e+22*cos(theta)**6 - 1.5189817852461e+21*cos(theta)**4 + 1.48919782867265e+19*cos(theta)**2 - 2.33783018629929e+16)*sin(11*phi)

#@torch.jit.script
def Yl37_m_minus_10(theta, phi):
    return 7.08921777342186e-16*(1.0 - cos(theta)**2)**5*(1.60590909221192e+25*cos(theta)**27 - 7.7215628954299e+25*cos(theta)**25 + 1.63131610466829e+26*cos(theta)**23 - 1.99383079459457e+26*cos(theta)**21 + 1.56233010024202e+26*cos(theta)**19 - 8.22025991204261e+25*cos(theta)**17 + 2.95755383078782e+25*cos(theta)**15 - 7.27267335439627e+24*cos(theta)**13 + 1.2018400882265e+24*cos(theta)**11 - 1.28852251174381e+23*cos(theta)**9 + 8.43396553141406e+21*cos(theta)**7 - 3.0379635704922e+20*cos(theta)**5 + 4.96399276224215e+18*cos(theta)**3 - 2.33783018629929e+16*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl37_m_minus_9(theta, phi):
    return 2.57173527737449e-14*(1.0 - cos(theta)**2)**4.5*(5.73538961504256e+23*cos(theta)**28 - 2.96983188285765e+24*cos(theta)**26 + 6.79715043611787e+24*cos(theta)**24 - 9.06286724815716e+24*cos(theta)**22 + 7.81165050121009e+24*cos(theta)**20 - 4.5668110622459e+24*cos(theta)**18 + 1.84847114424239e+24*cos(theta)**16 - 5.19476668171163e+23*cos(theta)**14 + 1.00153340685542e+23*cos(theta)**12 - 1.28852251174381e+22*cos(theta)**10 + 1.05424569142676e+21*cos(theta)**8 - 5.063272617487e+19*cos(theta)**6 + 1.24099819056054e+18*cos(theta)**4 - 1.16891509314964e+16*cos(theta)**2 + 17764667069143.5)*sin(9*phi)

#@torch.jit.script
def Yl37_m_minus_8(theta, phi):
    return 9.39299685798656e-13*(1.0 - cos(theta)**2)**4*(1.97772055691123e+22*cos(theta)**29 - 1.09993773439172e+23*cos(theta)**27 + 2.71886017444715e+23*cos(theta)**25 - 3.94037706441615e+23*cos(theta)**23 + 3.7198335720048e+23*cos(theta)**21 - 2.4035847696031e+23*cos(theta)**19 + 1.0873359672014e+23*cos(theta)**17 - 3.46317778780775e+22*cos(theta)**15 + 7.70410312965707e+21*cos(theta)**13 - 1.17138410158529e+21*cos(theta)**11 + 1.17138410158529e+20*cos(theta)**9 - 7.23324659641e+18*cos(theta)**7 + 2.48199638112108e+17*cos(theta)**5 - 3.89638364383215e+15*cos(theta)**3 + 17764667069143.5*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl37_m_minus_7(theta, phi):
    return 3.45120741864491e-11*(1.0 - cos(theta)**2)**3.5*(6.59240185637075e+20*cos(theta)**30 - 3.92834905139901e+21*cos(theta)**28 + 1.04571545171044e+22*cos(theta)**26 - 1.64182377684006e+22*cos(theta)**24 + 1.69083344182036e+22*cos(theta)**22 - 1.20179238480155e+22*cos(theta)**20 + 6.04075537334113e+21*cos(theta)**18 - 2.16448611737984e+21*cos(theta)**16 + 5.50293080689791e+20*cos(theta)**14 - 9.76153417987738e+19*cos(theta)**12 + 1.17138410158529e+19*cos(theta)**10 - 9.0415582455125e+17*cos(theta)**8 + 4.1366606352018e+16*cos(theta)**6 - 974095910958037.0*cos(theta)**4 + 8882333534571.76*cos(theta)**2 - 13159012643.81)*sin(7*phi)

#@torch.jit.script
def Yl37_m_minus_6(theta, phi):
    return 1.27461271489967e-9*(1.0 - cos(theta)**2)**3*(2.12658124399057e+19*cos(theta)**31 - 1.35460312117207e+20*cos(theta)**29 + 3.87302019152015e+20*cos(theta)**27 - 6.56729510736026e+20*cos(theta)**25 + 7.35144974704506e+20*cos(theta)**23 - 5.72282088000739e+20*cos(theta)**21 + 3.17934493333744e+20*cos(theta)**19 - 1.2732271278705e+20*cos(theta)**17 + 3.66862053793194e+19*cos(theta)**15 - 7.50887244605952e+18*cos(theta)**13 + 1.06489463780481e+18*cos(theta)**11 - 1.00461758283472e+17*cos(theta)**9 + 5.90951519314542e+15*cos(theta)**7 - 194819182191607.0*cos(theta)**5 + 2960777844857.25*cos(theta)**3 - 13159012643.81*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl37_m_minus_5(theta, phi):
    return 4.72810881899504e-8*(1.0 - cos(theta)**2)**2.5*(6.64556638747052e+17*cos(theta)**32 - 4.51534373724024e+18*cos(theta)**30 + 1.38322149697148e+19*cos(theta)**28 - 2.5258827336001e+19*cos(theta)**26 + 3.06310406126878e+19*cos(theta)**24 - 2.60128221818518e+19*cos(theta)**22 + 1.58967246666872e+19*cos(theta)**20 - 7.07348404372498e+18*cos(theta)**18 + 2.29288783620746e+18*cos(theta)**16 - 5.36348031861394e+17*cos(theta)**14 + 8.87412198170671e+16*cos(theta)**12 - 1.00461758283472e+16*cos(theta)**10 + 738689399143178.0*cos(theta)**8 - 32469863698601.2*cos(theta)**6 + 740194461214.314*cos(theta)**4 - 6579506321.90501*cos(theta)**2 + 9563235.93300147)*sin(5*phi)

#@torch.jit.script
def Yl37_m_minus_4(theta, phi):
    return 1.76022862219379e-6*(1.0 - cos(theta)**2)**2*(2.01380799620319e+16*cos(theta)**33 - 1.45656249588395e+17*cos(theta)**31 + 4.76972929990167e+17*cos(theta)**29 - 9.35512123555592e+17*cos(theta)**27 + 1.22524162450751e+18*cos(theta)**25 - 1.13099226877616e+18*cos(theta)**23 + 7.56986888889866e+17*cos(theta)**21 - 3.72288633880262e+17*cos(theta)**19 + 1.34875755071027e+17*cos(theta)**17 - 3.57565354574263e+16*cos(theta)**15 + 6.82624767823593e+15*cos(theta)**13 - 913288711667929.0*cos(theta)**11 + 82076599904797.5*cos(theta)**9 - 4638551956943.03*cos(theta)**7 + 148038892242.863*cos(theta)**5 - 2193168773.96834*cos(theta)**3 + 9563235.93300147*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl37_m_minus_3(theta, phi):
    return 6.57204404620968e-5*(1.0 - cos(theta)**2)**1.5*(592296469471526.0*cos(theta)**34 - 4.55175779963734e+15*cos(theta)**32 + 1.58990976663389e+16*cos(theta)**30 - 3.34111472698426e+16*cos(theta)**28 + 4.71246778656735e+16*cos(theta)**26 - 4.71246778656735e+16*cos(theta)**24 + 3.44084949495394e+16*cos(theta)**22 - 1.86144316940131e+16*cos(theta)**20 + 7.49309750394595e+15*cos(theta)**18 - 2.23478346608914e+15*cos(theta)**16 + 487589119873995.0*cos(theta)**14 - 76107392638994.1*cos(theta)**12 + 8207659990479.75*cos(theta)**10 - 579818994617.879*cos(theta)**8 + 24673148707.1438*cos(theta)**6 - 548292193.492084*cos(theta)**4 + 4781617.96650073*cos(theta)**2 - 6860.28402654338)*sin(3*phi)

#@torch.jit.script
def Yl37_m_minus_2(theta, phi):
    return 0.00245903371517041*(1.0 - cos(theta)**2)*(16922756270615.0*cos(theta)**35 - 137932054534465.0*cos(theta)**33 + 512874118268996.0*cos(theta)**31 - 1.1521085265463e+15*cos(theta)**29 + 1.74535843946939e+15*cos(theta)**27 - 1.88498711462694e+15*cos(theta)**25 + 1.49602151954519e+15*cos(theta)**23 - 886401509238719.0*cos(theta)**21 + 394373552839261.0*cos(theta)**19 - 131457850946420.0*cos(theta)**17 + 32505941324933.0*cos(theta)**15 - 5854414818384.16*cos(theta)**13 + 746150908225.432*cos(theta)**11 - 64424332735.3199*cos(theta)**9 + 3524735529.59197*cos(theta)**7 - 109658438.698417*cos(theta)**5 + 1593872.65550024*cos(theta)**3 - 6860.28402654338*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl37_m_minus_1(theta, phi):
    return 0.0921399637754005*(1.0 - cos(theta)**2)**0.5*(470076563072.639*cos(theta)**36 - 4056825133366.61*cos(theta)**34 + 16027316195906.1*cos(theta)**32 - 38403617551543.2*cos(theta)**30 + 62334229981049.6*cos(theta)**28 - 72499504408728.5*cos(theta)**26 + 62334229981049.6*cos(theta)**24 - 40290977692669.1*cos(theta)**22 + 19718677641963.0*cos(theta)**20 - 7303213941467.79*cos(theta)**18 + 2031621332808.31*cos(theta)**16 - 418172487027.44*cos(theta)**14 + 62179242352.1193*cos(theta)**12 - 6442433273.53199*cos(theta)**10 + 440591941.198996*cos(theta)**8 - 18276406.4497361*cos(theta)**6 + 398468.163875061*cos(theta)**4 - 3430.14201327169*cos(theta)**2 + 4.8862421841477)*sin(phi)

#@torch.jit.script
def Yl37_m0(theta, phi):
    return 97508493602.417*cos(theta)**37 - 889598037523.421*cos(theta)**35 + 3727541072721.38*cos(theta)**33 - 9507930852158.88*cos(theta)**31 + 16496969575574.2*cos(theta)**29 - 20608521992871.1*cos(theta)**27 + 19136484707666.0*cos(theta)**25 - 13444837031147.1*cos(theta)**23 + 7206660527288.59*cos(theta)**21 - 2950094952691.24*cos(theta)**19 + 917211339836.73*cos(theta)**17 - 213963537251.793*cos(theta)**15 + 36709430410.8468*cos(theta)**13 - 4495032295.20573*cos(theta)**11 + 375724583.945768*cos(theta)**9 - 20038644.4771076*cos(theta)**7 + 611644.671539622*cos(theta)**5 - 8775.38983557564*cos(theta)**3 + 37.5016659639985*cos(theta)

#@torch.jit.script
def Yl37_m1(theta, phi):
    return 0.0921399637754005*(1.0 - cos(theta)**2)**0.5*(470076563072.639*cos(theta)**36 - 4056825133366.61*cos(theta)**34 + 16027316195906.1*cos(theta)**32 - 38403617551543.2*cos(theta)**30 + 62334229981049.6*cos(theta)**28 - 72499504408728.5*cos(theta)**26 + 62334229981049.6*cos(theta)**24 - 40290977692669.1*cos(theta)**22 + 19718677641963.0*cos(theta)**20 - 7303213941467.79*cos(theta)**18 + 2031621332808.31*cos(theta)**16 - 418172487027.44*cos(theta)**14 + 62179242352.1193*cos(theta)**12 - 6442433273.53199*cos(theta)**10 + 440591941.198996*cos(theta)**8 - 18276406.4497361*cos(theta)**6 + 398468.163875061*cos(theta)**4 - 3430.14201327169*cos(theta)**2 + 4.8862421841477)*cos(phi)

#@torch.jit.script
def Yl37_m2(theta, phi):
    return 0.00245903371517041*(1.0 - cos(theta)**2)*(16922756270615.0*cos(theta)**35 - 137932054534465.0*cos(theta)**33 + 512874118268996.0*cos(theta)**31 - 1.1521085265463e+15*cos(theta)**29 + 1.74535843946939e+15*cos(theta)**27 - 1.88498711462694e+15*cos(theta)**25 + 1.49602151954519e+15*cos(theta)**23 - 886401509238719.0*cos(theta)**21 + 394373552839261.0*cos(theta)**19 - 131457850946420.0*cos(theta)**17 + 32505941324933.0*cos(theta)**15 - 5854414818384.16*cos(theta)**13 + 746150908225.432*cos(theta)**11 - 64424332735.3199*cos(theta)**9 + 3524735529.59197*cos(theta)**7 - 109658438.698417*cos(theta)**5 + 1593872.65550024*cos(theta)**3 - 6860.28402654338*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl37_m3(theta, phi):
    return 6.57204404620968e-5*(1.0 - cos(theta)**2)**1.5*(592296469471526.0*cos(theta)**34 - 4.55175779963734e+15*cos(theta)**32 + 1.58990976663389e+16*cos(theta)**30 - 3.34111472698426e+16*cos(theta)**28 + 4.71246778656735e+16*cos(theta)**26 - 4.71246778656735e+16*cos(theta)**24 + 3.44084949495394e+16*cos(theta)**22 - 1.86144316940131e+16*cos(theta)**20 + 7.49309750394595e+15*cos(theta)**18 - 2.23478346608914e+15*cos(theta)**16 + 487589119873995.0*cos(theta)**14 - 76107392638994.1*cos(theta)**12 + 8207659990479.75*cos(theta)**10 - 579818994617.879*cos(theta)**8 + 24673148707.1438*cos(theta)**6 - 548292193.492084*cos(theta)**4 + 4781617.96650073*cos(theta)**2 - 6860.28402654338)*cos(3*phi)

#@torch.jit.script
def Yl37_m4(theta, phi):
    return 1.76022862219379e-6*(1.0 - cos(theta)**2)**2*(2.01380799620319e+16*cos(theta)**33 - 1.45656249588395e+17*cos(theta)**31 + 4.76972929990167e+17*cos(theta)**29 - 9.35512123555592e+17*cos(theta)**27 + 1.22524162450751e+18*cos(theta)**25 - 1.13099226877616e+18*cos(theta)**23 + 7.56986888889866e+17*cos(theta)**21 - 3.72288633880262e+17*cos(theta)**19 + 1.34875755071027e+17*cos(theta)**17 - 3.57565354574263e+16*cos(theta)**15 + 6.82624767823593e+15*cos(theta)**13 - 913288711667929.0*cos(theta)**11 + 82076599904797.5*cos(theta)**9 - 4638551956943.03*cos(theta)**7 + 148038892242.863*cos(theta)**5 - 2193168773.96834*cos(theta)**3 + 9563235.93300147*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl37_m5(theta, phi):
    return 4.72810881899504e-8*(1.0 - cos(theta)**2)**2.5*(6.64556638747052e+17*cos(theta)**32 - 4.51534373724024e+18*cos(theta)**30 + 1.38322149697148e+19*cos(theta)**28 - 2.5258827336001e+19*cos(theta)**26 + 3.06310406126878e+19*cos(theta)**24 - 2.60128221818518e+19*cos(theta)**22 + 1.58967246666872e+19*cos(theta)**20 - 7.07348404372498e+18*cos(theta)**18 + 2.29288783620746e+18*cos(theta)**16 - 5.36348031861394e+17*cos(theta)**14 + 8.87412198170671e+16*cos(theta)**12 - 1.00461758283472e+16*cos(theta)**10 + 738689399143178.0*cos(theta)**8 - 32469863698601.2*cos(theta)**6 + 740194461214.314*cos(theta)**4 - 6579506321.90501*cos(theta)**2 + 9563235.93300147)*cos(5*phi)

#@torch.jit.script
def Yl37_m6(theta, phi):
    return 1.27461271489967e-9*(1.0 - cos(theta)**2)**3*(2.12658124399057e+19*cos(theta)**31 - 1.35460312117207e+20*cos(theta)**29 + 3.87302019152015e+20*cos(theta)**27 - 6.56729510736026e+20*cos(theta)**25 + 7.35144974704506e+20*cos(theta)**23 - 5.72282088000739e+20*cos(theta)**21 + 3.17934493333744e+20*cos(theta)**19 - 1.2732271278705e+20*cos(theta)**17 + 3.66862053793194e+19*cos(theta)**15 - 7.50887244605952e+18*cos(theta)**13 + 1.06489463780481e+18*cos(theta)**11 - 1.00461758283472e+17*cos(theta)**9 + 5.90951519314542e+15*cos(theta)**7 - 194819182191607.0*cos(theta)**5 + 2960777844857.25*cos(theta)**3 - 13159012643.81*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl37_m7(theta, phi):
    return 3.45120741864491e-11*(1.0 - cos(theta)**2)**3.5*(6.59240185637075e+20*cos(theta)**30 - 3.92834905139901e+21*cos(theta)**28 + 1.04571545171044e+22*cos(theta)**26 - 1.64182377684006e+22*cos(theta)**24 + 1.69083344182036e+22*cos(theta)**22 - 1.20179238480155e+22*cos(theta)**20 + 6.04075537334113e+21*cos(theta)**18 - 2.16448611737984e+21*cos(theta)**16 + 5.50293080689791e+20*cos(theta)**14 - 9.76153417987738e+19*cos(theta)**12 + 1.17138410158529e+19*cos(theta)**10 - 9.0415582455125e+17*cos(theta)**8 + 4.1366606352018e+16*cos(theta)**6 - 974095910958037.0*cos(theta)**4 + 8882333534571.76*cos(theta)**2 - 13159012643.81)*cos(7*phi)

#@torch.jit.script
def Yl37_m8(theta, phi):
    return 9.39299685798656e-13*(1.0 - cos(theta)**2)**4*(1.97772055691123e+22*cos(theta)**29 - 1.09993773439172e+23*cos(theta)**27 + 2.71886017444715e+23*cos(theta)**25 - 3.94037706441615e+23*cos(theta)**23 + 3.7198335720048e+23*cos(theta)**21 - 2.4035847696031e+23*cos(theta)**19 + 1.0873359672014e+23*cos(theta)**17 - 3.46317778780775e+22*cos(theta)**15 + 7.70410312965707e+21*cos(theta)**13 - 1.17138410158529e+21*cos(theta)**11 + 1.17138410158529e+20*cos(theta)**9 - 7.23324659641e+18*cos(theta)**7 + 2.48199638112108e+17*cos(theta)**5 - 3.89638364383215e+15*cos(theta)**3 + 17764667069143.5*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl37_m9(theta, phi):
    return 2.57173527737449e-14*(1.0 - cos(theta)**2)**4.5*(5.73538961504256e+23*cos(theta)**28 - 2.96983188285765e+24*cos(theta)**26 + 6.79715043611787e+24*cos(theta)**24 - 9.06286724815716e+24*cos(theta)**22 + 7.81165050121009e+24*cos(theta)**20 - 4.5668110622459e+24*cos(theta)**18 + 1.84847114424239e+24*cos(theta)**16 - 5.19476668171163e+23*cos(theta)**14 + 1.00153340685542e+23*cos(theta)**12 - 1.28852251174381e+22*cos(theta)**10 + 1.05424569142676e+21*cos(theta)**8 - 5.063272617487e+19*cos(theta)**6 + 1.24099819056054e+18*cos(theta)**4 - 1.16891509314964e+16*cos(theta)**2 + 17764667069143.5)*cos(9*phi)

#@torch.jit.script
def Yl37_m10(theta, phi):
    return 7.08921777342186e-16*(1.0 - cos(theta)**2)**5*(1.60590909221192e+25*cos(theta)**27 - 7.7215628954299e+25*cos(theta)**25 + 1.63131610466829e+26*cos(theta)**23 - 1.99383079459457e+26*cos(theta)**21 + 1.56233010024202e+26*cos(theta)**19 - 8.22025991204261e+25*cos(theta)**17 + 2.95755383078782e+25*cos(theta)**15 - 7.27267335439627e+24*cos(theta)**13 + 1.2018400882265e+24*cos(theta)**11 - 1.28852251174381e+23*cos(theta)**9 + 8.43396553141406e+21*cos(theta)**7 - 3.0379635704922e+20*cos(theta)**5 + 4.96399276224215e+18*cos(theta)**3 - 2.33783018629929e+16*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl37_m11(theta, phi):
    return 1.96922715928385e-17*(1.0 - cos(theta)**2)**5.5*(4.33595454897217e+26*cos(theta)**26 - 1.93039072385747e+27*cos(theta)**24 + 3.75202704073706e+27*cos(theta)**22 - 4.18704466864861e+27*cos(theta)**20 + 2.96842719045983e+27*cos(theta)**18 - 1.39744418504724e+27*cos(theta)**16 + 4.43633074618173e+26*cos(theta)**14 - 9.45447536071516e+25*cos(theta)**12 + 1.32202409704915e+25*cos(theta)**10 - 1.15967026056943e+24*cos(theta)**8 + 5.90377587198984e+22*cos(theta)**6 - 1.5189817852461e+21*cos(theta)**4 + 1.48919782867265e+19*cos(theta)**2 - 2.33783018629929e+16)*cos(11*phi)

#@torch.jit.script
def Yl37_m12(theta, phi):
    return 5.51710313839849e-19*(1.0 - cos(theta)**2)**6*(1.12734818273276e+28*cos(theta)**25 - 4.63293773725794e+28*cos(theta)**23 + 8.25445948962154e+28*cos(theta)**21 - 8.37408933729721e+28*cos(theta)**19 + 5.3431689428277e+28*cos(theta)**17 - 2.23591069607559e+28*cos(theta)**15 + 6.21086304465442e+27*cos(theta)**13 - 1.13453704328582e+27*cos(theta)**11 + 1.32202409704915e+26*cos(theta)**9 - 9.27736208455546e+24*cos(theta)**7 + 3.5422655231939e+23*cos(theta)**5 - 6.0759271409844e+21*cos(theta)**3 + 2.97839565734529e+19*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl37_m13(theta, phi):
    return 1.56047241666686e-20*(1.0 - cos(theta)**2)**6.5*(2.81837045683191e+29*cos(theta)**24 - 1.06557567956933e+30*cos(theta)**22 + 1.73343649282052e+30*cos(theta)**20 - 1.59107697408647e+30*cos(theta)**18 + 9.08338720280709e+29*cos(theta)**16 - 3.35386604411339e+29*cos(theta)**14 + 8.07412195805074e+28*cos(theta)**12 - 1.2479907476144e+28*cos(theta)**10 + 1.18982168734424e+27*cos(theta)**8 - 6.49415345918882e+25*cos(theta)**6 + 1.77113276159695e+24*cos(theta)**4 - 1.82277814229532e+22*cos(theta)**2 + 2.97839565734529e+19)*cos(13*phi)

#@torch.jit.script
def Yl37_m14(theta, phi):
    return 4.4603135268713e-22*(1.0 - cos(theta)**2)**7*(6.76408909639659e+30*cos(theta)**23 - 2.34426649505252e+31*cos(theta)**21 + 3.46687298564105e+31*cos(theta)**19 - 2.86393855335565e+31*cos(theta)**17 + 1.45334195244913e+31*cos(theta)**15 - 4.69541246175874e+30*cos(theta)**13 + 9.68894634966089e+29*cos(theta)**11 - 1.2479907476144e+29*cos(theta)**9 + 9.5185734987539e+27*cos(theta)**7 - 3.89649207551329e+26*cos(theta)**5 + 7.08453104638781e+24*cos(theta)**3 - 3.64555628459064e+22*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl37_m15(theta, phi):
    return 1.28973295692034e-23*(1.0 - cos(theta)**2)**7.5*(1.55574049217122e+32*cos(theta)**22 - 4.92295963961028e+32*cos(theta)**20 + 6.58705867271799e+32*cos(theta)**18 - 4.8686955407046e+32*cos(theta)**16 + 2.1800129286737e+32*cos(theta)**14 - 6.10403620028636e+31*cos(theta)**12 + 1.0657840984627e+31*cos(theta)**10 - 1.12319167285296e+30*cos(theta)**8 + 6.66300144912773e+28*cos(theta)**6 - 1.94824603775665e+27*cos(theta)**4 + 2.12535931391634e+25*cos(theta)**2 - 3.64555628459064e+22)*cos(15*phi)

#@torch.jit.script
def Yl37_m16(theta, phi):
    return 3.7770307660841e-25*(1.0 - cos(theta)**2)**8*(3.42262908277667e+33*cos(theta)**21 - 9.84591927922057e+33*cos(theta)**19 + 1.18567056108924e+34*cos(theta)**17 - 7.78991286512736e+33*cos(theta)**15 + 3.05201810014318e+33*cos(theta)**13 - 7.32484344034364e+32*cos(theta)**11 + 1.0657840984627e+32*cos(theta)**9 - 8.98553338282369e+30*cos(theta)**7 + 3.99780086947664e+29*cos(theta)**5 - 7.79298415102659e+27*cos(theta)**3 + 4.25071862783268e+25*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl37_m17(theta, phi):
    return 1.12161548142786e-26*(1.0 - cos(theta)**2)**8.5*(7.18752107383102e+34*cos(theta)**20 - 1.87072466305191e+35*cos(theta)**18 + 2.0156399538517e+35*cos(theta)**16 - 1.1684869297691e+35*cos(theta)**14 + 3.96762353018614e+34*cos(theta)**12 - 8.057327784378e+33*cos(theta)**10 + 9.59205688616428e+32*cos(theta)**8 - 6.28987336797658e+31*cos(theta)**6 + 1.99890043473832e+30*cos(theta)**4 - 2.33789524530798e+28*cos(theta)**2 + 4.25071862783268e+25)*cos(17*phi)

#@torch.jit.script
def Yl37_m18(theta, phi):
    return 3.38179791904549e-28*(1.0 - cos(theta)**2)**9*(1.4375042147662e+36*cos(theta)**19 - 3.36730439349343e+36*cos(theta)**17 + 3.22502392616273e+36*cos(theta)**15 - 1.63588170167675e+36*cos(theta)**13 + 4.76114823622336e+35*cos(theta)**11 - 8.057327784378e+34*cos(theta)**9 + 7.67364550893143e+33*cos(theta)**7 - 3.77392402078595e+32*cos(theta)**5 + 7.99560173895328e+30*cos(theta)**3 - 4.67579049061595e+28*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl37_m19(theta, phi):
    return 1.03675667117759e-29*(1.0 - cos(theta)**2)**9.5*(2.73125800805579e+37*cos(theta)**18 - 5.72441746893884e+37*cos(theta)**16 + 4.83753588924409e+37*cos(theta)**14 - 2.12664621217977e+37*cos(theta)**12 + 5.2372630598457e+36*cos(theta)**10 - 7.2515950059402e+35*cos(theta)**8 + 5.371551856252e+34*cos(theta)**6 - 1.88696201039297e+33*cos(theta)**4 + 2.39868052168598e+31*cos(theta)**2 - 4.67579049061595e+28)*cos(19*phi)

#@torch.jit.script
def Yl37_m20(theta, phi):
    return 3.236705294292e-31*(1.0 - cos(theta)**2)**10*(4.91626441450041e+38*cos(theta)**17 - 9.15906795030214e+38*cos(theta)**15 + 6.77255024494173e+38*cos(theta)**13 - 2.55197545461572e+38*cos(theta)**11 + 5.2372630598457e+37*cos(theta)**9 - 5.80127600475216e+36*cos(theta)**7 + 3.2229311137512e+35*cos(theta)**5 - 7.5478480415719e+33*cos(theta)**3 + 4.79736104337197e+31*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl37_m21(theta, phi):
    return 1.03077695553335e-32*(1.0 - cos(theta)**2)**10.5*(8.35764950465071e+39*cos(theta)**16 - 1.37386019254532e+40*cos(theta)**14 + 8.80431531842424e+39*cos(theta)**12 - 2.80717300007729e+39*cos(theta)**10 + 4.71353675386113e+38*cos(theta)**8 - 4.06089320332651e+37*cos(theta)**6 + 1.6114655568756e+36*cos(theta)**4 - 2.26435441247157e+34*cos(theta)**2 + 4.79736104337197e+31)*cos(21*phi)

#@torch.jit.script
def Yl37_m22(theta, phi):
    return 3.3548932326254e-34*(1.0 - cos(theta)**2)**11*(1.33722392074411e+41*cos(theta)**15 - 1.92340426956345e+41*cos(theta)**13 + 1.05651783821091e+41*cos(theta)**11 - 2.80717300007729e+40*cos(theta)**9 + 3.7708294030889e+39*cos(theta)**7 - 2.43653592199591e+38*cos(theta)**5 + 6.4458622275024e+36*cos(theta)**3 - 4.52870882494314e+34*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl37_m23(theta, phi):
    return 1.11829774420847e-35*(1.0 - cos(theta)**2)**11.5*(2.00583588111617e+42*cos(theta)**14 - 2.50042555043248e+42*cos(theta)**12 + 1.162169622032e+42*cos(theta)**10 - 2.52645570006957e+41*cos(theta)**8 + 2.63958058216223e+40*cos(theta)**6 - 1.21826796099795e+39*cos(theta)**4 + 1.93375866825072e+37*cos(theta)**2 - 4.52870882494314e+34)*cos(23*phi)

#@torch.jit.script
def Yl37_m24(theta, phi):
    return 3.82673610124151e-37*(1.0 - cos(theta)**2)**12*(2.80817023356264e+43*cos(theta)**13 - 3.00051066051898e+43*cos(theta)**11 + 1.162169622032e+43*cos(theta)**9 - 2.02116456005565e+42*cos(theta)**7 + 1.58374834929734e+41*cos(theta)**5 - 4.87307184399181e+39*cos(theta)**3 + 3.86751733650144e+37*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl37_m25(theta, phi):
    return 1.34791030198661e-38*(1.0 - cos(theta)**2)**12.5*(3.65062130363143e+44*cos(theta)**12 - 3.30056172657088e+44*cos(theta)**10 + 1.0459526598288e+44*cos(theta)**8 - 1.41481519203896e+43*cos(theta)**6 + 7.9187417464867e+41*cos(theta)**4 - 1.46192155319754e+40*cos(theta)**2 + 3.86751733650144e+37)*cos(25*phi)

#@torch.jit.script
def Yl37_m26(theta, phi):
    return 4.90230237211461e-40*(1.0 - cos(theta)**2)**13*(4.38074556435771e+45*cos(theta)**11 - 3.30056172657088e+45*cos(theta)**9 + 8.3676212786304e+44*cos(theta)**7 - 8.48889115223374e+43*cos(theta)**5 + 3.16749669859468e+42*cos(theta)**3 - 2.92384310639509e+40*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl37_m27(theta, phi):
    return 1.84762472467879e-41*(1.0 - cos(theta)**2)**13.5*(4.81882012079349e+46*cos(theta)**10 - 2.97050555391379e+46*cos(theta)**8 + 5.85733489504128e+45*cos(theta)**6 - 4.24444557611687e+44*cos(theta)**4 + 9.50249009578404e+42*cos(theta)**2 - 2.92384310639509e+40)*cos(27*phi)

#@torch.jit.script
def Yl37_m28(theta, phi):
    return 7.24698040379513e-43*(1.0 - cos(theta)**2)**14*(4.81882012079349e+47*cos(theta)**9 - 2.37640444313103e+47*cos(theta)**7 + 3.51440093702477e+46*cos(theta)**5 - 1.69777823044675e+45*cos(theta)**3 + 1.90049801915681e+43*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl37_m29(theta, phi):
    return 2.9734720766705e-44*(1.0 - cos(theta)**2)**14.5*(4.33693810871414e+48*cos(theta)**8 - 1.66348311019172e+48*cos(theta)**6 + 1.75720046851238e+47*cos(theta)**4 - 5.09333469134024e+45*cos(theta)**2 + 1.90049801915681e+43)*cos(29*phi)

#@torch.jit.script
def Yl37_m30(theta, phi):
    return 1.28434432069174e-45*(1.0 - cos(theta)**2)**15*(3.46955048697131e+49*cos(theta)**7 - 9.98089866115034e+48*cos(theta)**5 + 7.02880187404954e+47*cos(theta)**3 - 1.01866693826805e+46*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl37_m31(theta, phi):
    return 5.88678254222418e-47*(1.0 - cos(theta)**2)**15.5*(2.42868534087992e+50*cos(theta)**6 - 4.99044933057517e+49*cos(theta)**4 + 2.10864056221486e+48*cos(theta)**2 - 1.01866693826805e+46)*cos(31*phi)

#@torch.jit.script
def Yl37_m32(theta, phi):
    return 2.89319577828011e-48*(1.0 - cos(theta)**2)**16*(1.45721120452795e+51*cos(theta)**5 - 1.99617973223007e+50*cos(theta)**3 + 4.21728112442972e+48*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl37_m33(theta, phi):
    return 1.54647819359785e-49*(1.0 - cos(theta)**2)**16.5*(7.28605602263975e+51*cos(theta)**4 - 5.98853919669021e+50*cos(theta)**2 + 4.21728112442972e+48)*cos(33*phi)

#@torch.jit.script
def Yl37_m34(theta, phi):
    return 9.17665977479345e-51*(1.0 - cos(theta)**2)**17*(2.9144224090559e+52*cos(theta)**3 - 1.19770783933804e+51*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl37_m35(theta, phi):
    return 6.24392610871321e-52*(1.0 - cos(theta)**2)**17.5*(8.7432672271677e+52*cos(theta)**2 - 1.19770783933804e+51)*cos(35*phi)

#@torch.jit.script
def Yl37_m36(theta, phi):
    return 9.03618419303727*(1.0 - cos(theta)**2)**18*cos(36*phi)*cos(theta)

#@torch.jit.script
def Yl37_m37(theta, phi):
    return 1.05043507569481*(1.0 - cos(theta)**2)**18.5*cos(37*phi)

#@torch.jit.script
def Yl38_m_minus_38(theta, phi):
    return 1.0573232483571*(1.0 - cos(theta)**2)**19*sin(38*phi)

#@torch.jit.script
def Yl38_m_minus_37(theta, phi):
    return 9.21753038048947*(1.0 - cos(theta)**2)**18.5*sin(37*phi)*cos(theta)

#@torch.jit.script
def Yl38_m_minus_36(theta, phi):
    return 8.60786001928606e-54*(1.0 - cos(theta)**2)**18*(6.55745042037577e+54*cos(theta)**2 - 8.7432672271677e+52)*sin(36*phi)

#@torch.jit.script
def Yl38_m_minus_35(theta, phi):
    return 1.28254225711204e-52*(1.0 - cos(theta)**2)**17.5*(2.18581680679192e+54*cos(theta)**3 - 8.7432672271677e+52*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl38_m_minus_34(theta, phi):
    return 2.19160916965865e-51*(1.0 - cos(theta)**2)**17*(5.46454201697981e+53*cos(theta)**4 - 4.37163361358385e+52*cos(theta)**2 + 2.9942695983451e+50)*sin(34*phi)

#@torch.jit.script
def Yl38_m_minus_33(theta, phi):
    return 4.15828603021903e-50*(1.0 - cos(theta)**2)**16.5*(1.09290840339596e+53*cos(theta)**5 - 1.45721120452795e+52*cos(theta)**3 + 2.9942695983451e+50*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl38_m_minus_32(theta, phi):
    return 8.58260566150099e-49*(1.0 - cos(theta)**2)**16*(1.82151400565994e+52*cos(theta)**6 - 3.64302801131987e+51*cos(theta)**4 + 1.49713479917255e+50*cos(theta)**2 - 7.02880187404954e+47)*sin(32*phi)

#@torch.jit.script
def Yl38_m_minus_31(theta, phi):
    return 1.89984075045795e-47*(1.0 - cos(theta)**2)**15.5*(2.60216286522848e+51*cos(theta)**7 - 7.28605602263975e+50*cos(theta)**5 + 4.99044933057517e+49*cos(theta)**3 - 7.02880187404954e+47*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl38_m_minus_30(theta, phi):
    return 4.46361509559185e-46*(1.0 - cos(theta)**2)**15*(3.2527035815356e+50*cos(theta)**8 - 1.21434267043996e+50*cos(theta)**6 + 1.24761233264379e+49*cos(theta)**4 - 3.51440093702477e+47*cos(theta)**2 + 1.27333367283506e+45)*sin(30*phi)

#@torch.jit.script
def Yl38_m_minus_29(theta, phi):
    return 1.1042373906736e-44*(1.0 - cos(theta)**2)**14.5*(3.61411509059511e+49*cos(theta)**9 - 1.73477524348565e+49*cos(theta)**7 + 2.49522466528759e+48*cos(theta)**5 - 1.17146697900826e+47*cos(theta)**3 + 1.27333367283506e+45*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl38_m_minus_28(theta, phi):
    return 2.85824761702743e-43*(1.0 - cos(theta)**2)**14*(3.61411509059511e+48*cos(theta)**10 - 2.16846905435707e+48*cos(theta)**8 + 4.15870777547931e+47*cos(theta)**6 - 2.92866744752064e+46*cos(theta)**4 + 6.3666683641753e+44*cos(theta)**2 - 1.90049801915681e+42)*sin(28*phi)

#@torch.jit.script
def Yl38_m_minus_27(theta, phi):
    return 7.70137304226747e-42*(1.0 - cos(theta)**2)**13.5*(3.28555917326829e+47*cos(theta)**11 - 2.40941006039674e+47*cos(theta)**9 + 5.94101110782758e+46*cos(theta)**7 - 5.85733489504128e+45*cos(theta)**5 + 2.12222278805844e+44*cos(theta)**3 - 1.90049801915681e+42*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl38_m_minus_26(theta, phi):
    return 2.15087643657668e-40*(1.0 - cos(theta)**2)**13*(2.73796597772357e+46*cos(theta)**12 - 2.40941006039674e+46*cos(theta)**10 + 7.42626388478448e+45*cos(theta)**8 - 9.7622248250688e+44*cos(theta)**6 + 5.30555697014609e+43*cos(theta)**4 - 9.50249009578404e+41*cos(theta)**2 + 2.43653592199591e+39)*sin(26*phi)

#@torch.jit.script
def Yl38_m_minus_25(theta, phi):
    return 6.20407622341159e-39*(1.0 - cos(theta)**2)**12.5*(2.10612767517198e+45*cos(theta)**13 - 2.19037278217886e+45*cos(theta)**11 + 8.2514043164272e+44*cos(theta)**9 - 1.3946035464384e+44*cos(theta)**7 + 1.06111139402922e+43*cos(theta)**5 - 3.16749669859468e+41*cos(theta)**3 + 2.43653592199591e+39*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl38_m_minus_24(theta, phi):
    return 1.84251663480048e-37*(1.0 - cos(theta)**2)**12*(1.50437691083713e+44*cos(theta)**14 - 1.82531065181571e+44*cos(theta)**12 + 8.2514043164272e+43*cos(theta)**10 - 1.743254433048e+43*cos(theta)**8 + 1.7685189900487e+42*cos(theta)**6 - 7.9187417464867e+40*cos(theta)**4 + 1.21826796099795e+39*cos(theta)**2 - 2.76251238321531e+36)*sin(24*phi)

#@torch.jit.script
def Yl38_m_minus_23(theta, phi):
    return 5.61892055563194e-36*(1.0 - cos(theta)**2)**11.5*(1.00291794055808e+43*cos(theta)**15 - 1.40408511678132e+43*cos(theta)**13 + 7.50127665129745e+42*cos(theta)**11 - 1.93694937005333e+42*cos(theta)**9 + 2.52645570006957e+41*cos(theta)**7 - 1.58374834929734e+40*cos(theta)**5 + 4.06089320332651e+38*cos(theta)**3 - 2.76251238321531e+36*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl38_m_minus_22(theta, phi):
    return 1.75540689794278e-34*(1.0 - cos(theta)**2)**11*(6.26823712848803e+41*cos(theta)**16 - 1.00291794055808e+42*cos(theta)**14 + 6.25106387608121e+41*cos(theta)**12 - 1.93694937005333e+41*cos(theta)**10 + 3.15806962508696e+40*cos(theta)**8 - 2.63958058216223e+39*cos(theta)**6 + 1.01522330083163e+38*cos(theta)**4 - 1.38125619160766e+36*cos(theta)**2 + 2.83044301558946e+33)*sin(22*phi)

#@torch.jit.script
def Yl38_m_minus_21(theta, phi):
    return 5.60632004517403e-33*(1.0 - cos(theta)**2)**10.5*(3.68719831087531e+40*cos(theta)**17 - 6.68611960372056e+40*cos(theta)**15 + 4.80851067390862e+40*cos(theta)**13 - 1.76086306368485e+40*cos(theta)**11 + 3.50896625009662e+39*cos(theta)**9 - 3.7708294030889e+38*cos(theta)**7 + 2.03044660166326e+37*cos(theta)**5 - 4.60418730535886e+35*cos(theta)**3 + 2.83044301558946e+33*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl38_m_minus_20(theta, phi):
    return 1.82700672042423e-31*(1.0 - cos(theta)**2)**10*(2.04844350604184e+39*cos(theta)**18 - 4.17882475232535e+39*cos(theta)**16 + 3.4346504813633e+39*cos(theta)**14 - 1.46738588640404e+39*cos(theta)**12 + 3.50896625009662e+38*cos(theta)**10 - 4.71353675386113e+37*cos(theta)**8 + 3.38407766943876e+36*cos(theta)**6 - 1.15104682633971e+35*cos(theta)**4 + 1.41522150779473e+33*cos(theta)**2 - 2.66520057965109e+30)*sin(20*phi)

#@torch.jit.script
def Yl38_m_minus_19(theta, phi):
    return 6.06500191198304e-30*(1.0 - cos(theta)**2)**9.5*(1.07812816107465e+38*cos(theta)**19 - 2.45813220725021e+38*cos(theta)**17 + 2.28976698757554e+38*cos(theta)**15 - 1.12875837415695e+38*cos(theta)**13 + 3.18996931826965e+37*cos(theta)**11 - 5.2372630598457e+36*cos(theta)**9 + 4.8343966706268e+35*cos(theta)**7 - 2.30209365267943e+34*cos(theta)**5 + 4.71740502598244e+32*cos(theta)**3 - 2.66520057965109e+30*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl38_m_minus_18(theta, phi):
    return 2.04778033341685e-28*(1.0 - cos(theta)**2)**9*(5.39064080537326e+36*cos(theta)**20 - 1.36562900402789e+37*cos(theta)**18 + 1.43110436723471e+37*cos(theta)**16 - 8.06255981540682e+36*cos(theta)**14 + 2.65830776522471e+36*cos(theta)**12 - 5.2372630598457e+35*cos(theta)**10 + 6.0429958382835e+34*cos(theta)**8 - 3.83682275446571e+33*cos(theta)**6 + 1.17935125649561e+32*cos(theta)**4 - 1.33260028982555e+30*cos(theta)**2 + 2.33789524530798e+27)*sin(18*phi)

#@torch.jit.script
def Yl38_m_minus_17(theta, phi):
    return 7.02242369104875e-27*(1.0 - cos(theta)**2)**8.5*(2.56697181208251e+35*cos(theta)**21 - 7.18752107383102e+35*cos(theta)**19 + 8.41826098373359e+35*cos(theta)**17 - 5.37503987693788e+35*cos(theta)**15 + 2.04485212709593e+35*cos(theta)**13 - 4.76114823622336e+34*cos(theta)**11 + 6.714439820315e+33*cos(theta)**9 - 5.48117536352245e+32*cos(theta)**7 + 2.35870251299122e+31*cos(theta)**5 - 4.44200096608516e+29*cos(theta)**3 + 2.33789524530798e+27*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl38_m_minus_16(theta, phi):
    return 2.44275389142847e-25*(1.0 - cos(theta)**2)**8*(1.16680536912841e+34*cos(theta)**22 - 3.59376053691551e+34*cos(theta)**20 + 4.67681165762977e+34*cos(theta)**18 - 3.35939992308617e+34*cos(theta)**16 + 1.46060866221138e+34*cos(theta)**14 - 3.96762353018614e+33*cos(theta)**12 + 6.714439820315e+32*cos(theta)**10 - 6.85146920440306e+31*cos(theta)**8 + 3.93117085498536e+30*cos(theta)**6 - 1.11050024152129e+29*cos(theta)**4 + 1.16894762265399e+27*cos(theta)**2 - 1.93214483083304e+24)*sin(16*phi)

#@torch.jit.script
def Yl38_m_minus_15(theta, phi):
    return 8.60875824089541e-24*(1.0 - cos(theta)**2)**7.5*(5.07306682229744e+32*cos(theta)**23 - 1.71131454138834e+33*cos(theta)**21 + 2.46147981980514e+33*cos(theta)**19 - 1.9761176018154e+33*cos(theta)**17 + 9.7373910814092e+32*cos(theta)**15 - 3.05201810014318e+32*cos(theta)**13 + 6.10403620028636e+31*cos(theta)**11 - 7.61274356044785e+30*cos(theta)**9 + 5.6159583642648e+29*cos(theta)**7 - 2.22100048304258e+28*cos(theta)**5 + 3.89649207551329e+26*cos(theta)**3 - 1.93214483083304e+24*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl38_m_minus_14(theta, phi):
    return 3.0703230101837e-22*(1.0 - cos(theta)**2)**7*(2.11377784262393e+31*cos(theta)**24 - 7.77870246085608e+31*cos(theta)**22 + 1.23073990990257e+32*cos(theta)**20 - 1.09784311211966e+32*cos(theta)**18 + 6.08586942588075e+31*cos(theta)**16 - 2.1800129286737e+31*cos(theta)**14 + 5.08669683357197e+30*cos(theta)**12 - 7.61274356044784e+29*cos(theta)**10 + 7.019947955331e+28*cos(theta)**8 - 3.70166747173763e+27*cos(theta)**6 + 9.74123018878324e+25*cos(theta)**4 - 9.66072415416519e+23*cos(theta)**2 + 1.5189817852461e+21)*sin(14*phi)

#@torch.jit.script
def Yl38_m_minus_13(theta, phi):
    return 1.10702070454543e-20*(1.0 - cos(theta)**2)**6.5*(8.45511137049574e+29*cos(theta)**25 - 3.38204454819829e+30*cos(theta)**23 + 5.86066623763129e+30*cos(theta)**21 - 5.77812164273508e+30*cos(theta)**19 + 3.57992319169456e+30*cos(theta)**17 - 1.45334195244913e+30*cos(theta)**15 + 3.91284371813228e+29*cos(theta)**13 - 6.9206759640435e+28*cos(theta)**11 + 7.79994217259001e+27*cos(theta)**9 - 5.28809638819661e+26*cos(theta)**7 + 1.94824603775665e+25*cos(theta)**5 - 3.22024138472173e+23*cos(theta)**3 + 1.5189817852461e+21*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl38_m_minus_12(theta, phi):
    return 4.03113651248321e-19*(1.0 - cos(theta)**2)**6*(3.25196591172913e+28*cos(theta)**26 - 1.40918522841596e+29*cos(theta)**24 + 2.66393919892331e+29*cos(theta)**22 - 2.88906082136754e+29*cos(theta)**20 + 1.98884621760809e+29*cos(theta)**18 - 9.08338720280709e+28*cos(theta)**16 + 2.79488837009449e+28*cos(theta)**14 - 5.76722997003625e+27*cos(theta)**12 + 7.79994217259e+26*cos(theta)**10 - 6.61012048524577e+25*cos(theta)**8 + 3.24707672959441e+24*cos(theta)**6 - 8.05060346180433e+22*cos(theta)**4 + 7.5949089262305e+20*cos(theta)**2 - 1.14553679128665e+18)*sin(12*phi)

#@torch.jit.script
def Yl38_m_minus_11(theta, phi):
    return 1.48113413086296e-17*(1.0 - cos(theta)**2)**5.5*(1.20443181915894e+27*cos(theta)**27 - 5.63674091366382e+27*cos(theta)**25 + 1.15823443431448e+28*cos(theta)**23 - 1.37574324827026e+28*cos(theta)**21 + 1.04676116716215e+28*cos(theta)**19 - 5.3431689428277e+27*cos(theta)**17 + 1.86325891339633e+27*cos(theta)**15 - 4.43633074618173e+26*cos(theta)**13 + 7.09085652053637e+25*cos(theta)**11 - 7.34457831693974e+24*cos(theta)**9 + 4.63868104227773e+23*cos(theta)**7 - 1.61012069236087e+22*cos(theta)**5 + 2.5316363087435e+20*cos(theta)**3 - 1.14553679128665e+18*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl38_m_minus_10(theta, phi):
    return 5.48619759603045e-16*(1.0 - cos(theta)**2)**5*(4.30154221128192e+25*cos(theta)**28 - 2.16797727448609e+26*cos(theta)**26 + 4.82597680964369e+26*cos(theta)**24 - 6.25337840122844e+26*cos(theta)**22 + 5.23380583581076e+26*cos(theta)**20 - 2.96842719045983e+26*cos(theta)**18 + 1.1645368208727e+26*cos(theta)**16 - 3.16880767584409e+25*cos(theta)**14 + 5.90904710044697e+24*cos(theta)**12 - 7.34457831693974e+23*cos(theta)**10 + 5.79835130284716e+22*cos(theta)**8 - 2.68353448726811e+21*cos(theta)**6 + 6.32909077185875e+19*cos(theta)**4 - 5.72768395643326e+17*cos(theta)**2 + 834939352249746.0)*sin(10*phi)

#@torch.jit.script
def Yl38_m_minus_9(theta, phi):
    return 2.04687378153282e-14*(1.0 - cos(theta)**2)**4.5*(1.48329041768342e+24*cos(theta)**29 - 8.02954546105958e+24*cos(theta)**27 + 1.93039072385747e+25*cos(theta)**25 - 2.71886017444715e+25*cos(theta)**23 + 2.49228849324322e+25*cos(theta)**21 - 1.56233010024202e+25*cos(theta)**19 + 6.85021659336884e+24*cos(theta)**17 - 2.11253845056273e+24*cos(theta)**15 + 4.54542084649767e+23*cos(theta)**13 - 6.67688937903613e+22*cos(theta)**11 + 6.44261255871907e+21*cos(theta)**9 - 3.8336206960973e+20*cos(theta)**7 + 1.26581815437175e+19*cos(theta)**5 - 1.90922798547775e+17*cos(theta)**3 + 834939352249746.0*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl38_m_minus_8(theta, phi):
    return 7.68600423582523e-13*(1.0 - cos(theta)**2)**4*(4.94430139227807e+22*cos(theta)**30 - 2.86769480752128e+23*cos(theta)**28 + 7.42457970714413e+23*cos(theta)**26 - 1.13285840601964e+24*cos(theta)**24 + 1.13285840601964e+24*cos(theta)**22 - 7.81165050121009e+23*cos(theta)**20 + 3.80567588520491e+23*cos(theta)**18 - 1.3203365316017e+23*cos(theta)**16 + 3.24672917606977e+22*cos(theta)**14 - 5.56407448253011e+21*cos(theta)**12 + 6.44261255871907e+20*cos(theta)**10 - 4.79202587012162e+19*cos(theta)**8 + 2.10969692395292e+18*cos(theta)**6 - 4.77306996369438e+16*cos(theta)**4 + 417469676124873.0*cos(theta)**2 - 592155568971.451)*sin(8*phi)

#@torch.jit.script
def Yl38_m_minus_7(theta, phi):
    return 2.90242083005401e-11*(1.0 - cos(theta)**2)**3.5*(1.59493593299292e+21*cos(theta)**31 - 9.88860278455613e+21*cos(theta)**29 + 2.74984433597931e+22*cos(theta)**27 - 4.53143362407858e+22*cos(theta)**25 + 4.92547133052019e+22*cos(theta)**23 - 3.7198335720048e+22*cos(theta)**21 + 2.00298730800259e+22*cos(theta)**19 - 7.76668548001003e+21*cos(theta)**17 + 2.16448611737984e+21*cos(theta)**15 - 4.28005729425393e+20*cos(theta)**13 + 5.85692050792643e+19*cos(theta)**11 - 5.32447318902403e+18*cos(theta)**9 + 3.01385274850417e+17*cos(theta)**7 - 9.54613992738876e+15*cos(theta)**5 + 139156558708291.0*cos(theta)**3 - 592155568971.451*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl38_m_minus_6(theta, phi):
    return 1.10139126615446e-9*(1.0 - cos(theta)**2)**3*(4.98417479060289e+19*cos(theta)**32 - 3.29620092818538e+20*cos(theta)**30 + 9.82087262849753e+20*cos(theta)**28 - 1.74285908618407e+21*cos(theta)**26 + 2.05227972105008e+21*cos(theta)**24 - 1.69083344182036e+21*cos(theta)**22 + 1.00149365400129e+21*cos(theta)**20 - 4.31482526667224e+20*cos(theta)**18 + 1.3528038233624e+20*cos(theta)**16 - 3.05718378160995e+19*cos(theta)**14 + 4.88076708993869e+18*cos(theta)**12 - 5.32447318902403e+17*cos(theta)**10 + 3.76731593563021e+16*cos(theta)**8 - 1.59102332123146e+15*cos(theta)**6 + 34789139677072.7*cos(theta)**4 - 296077784485.725*cos(theta)**2 + 411219145.119063)*sin(6*phi)

#@torch.jit.script
def Yl38_m_minus_5(theta, phi):
    return 4.1968643903827e-8*(1.0 - cos(theta)**2)**2.5*(1.51035599715239e+18*cos(theta)**33 - 1.06329062199528e+19*cos(theta)**31 + 3.38650780293018e+19*cos(theta)**29 - 6.45503365253359e+19*cos(theta)**27 + 8.20911888420032e+19*cos(theta)**25 - 7.35144974704506e+19*cos(theta)**23 + 4.76901740000616e+19*cos(theta)**21 - 2.2709606666696e+19*cos(theta)**19 + 7.9576695491906e+18*cos(theta)**17 - 2.0381225210733e+18*cos(theta)**15 + 3.75443622302976e+17*cos(theta)**13 - 4.84043017184002e+16*cos(theta)**11 + 4.18590659514467e+15*cos(theta)**9 - 227289045890209.0*cos(theta)**7 + 6957827935414.55*cos(theta)**5 - 98692594828.5751*cos(theta)**3 + 411219145.119063*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl38_m_minus_4(theta, phi):
    return 1.60471762562345e-6*(1.0 - cos(theta)**2)**2*(4.44222352103644e+16*cos(theta)**34 - 3.32278319373526e+17*cos(theta)**32 + 1.12883593431006e+18*cos(theta)**30 - 2.30536916161914e+18*cos(theta)**28 + 3.15735341700012e+18*cos(theta)**26 - 3.06310406126878e+18*cos(theta)**24 + 2.16773518182098e+18*cos(theta)**22 - 1.1354803333348e+18*cos(theta)**20 + 4.42092752732811e+17*cos(theta)**18 - 1.27382657567081e+17*cos(theta)**16 + 2.68174015930697e+16*cos(theta)**14 - 4.03369180986669e+15*cos(theta)**12 + 418590659514467.0*cos(theta)**10 - 28411130736276.1*cos(theta)**8 + 1159637989235.76*cos(theta)**6 - 24673148707.1438*cos(theta)**4 + 205609572.559532*cos(theta)**2 - 281271.645088278)*sin(4*phi)

#@torch.jit.script
def Yl38_m_minus_3(theta, phi):
    return 6.15258029386065e-5*(1.0 - cos(theta)**2)**1.5*(1.26920672029613e+15*cos(theta)**35 - 1.00690399810159e+16*cos(theta)**33 + 3.64140623970987e+16*cos(theta)**31 - 7.94954883316944e+16*cos(theta)**29 + 1.16939015444449e+17*cos(theta)**27 - 1.22524162450751e+17*cos(theta)**25 + 9.4249355731347e+16*cos(theta)**23 - 5.40704920635619e+16*cos(theta)**21 + 2.32680396175164e+16*cos(theta)**19 - 7.49309750394595e+15*cos(theta)**17 + 1.78782677287132e+15*cos(theta)**15 - 310283985374361.0*cos(theta)**13 + 38053696319497.0*cos(theta)**11 - 3156792304030.67*cos(theta)**9 + 165662569890.823*cos(theta)**7 - 4934629741.42876*cos(theta)**5 + 68536524.1865105*cos(theta)**3 - 281271.645088278*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl38_m_minus_2(theta, phi):
    return 0.00236374416014225*(1.0 - cos(theta)**2)*(35255742230448.0*cos(theta)**36 - 296148234735763.0*cos(theta)**34 + 1.13793944990934e+15*cos(theta)**32 - 2.64984961105648e+15*cos(theta)**30 + 4.17639340873032e+15*cos(theta)**28 - 4.71246778656735e+15*cos(theta)**26 + 3.92705648880612e+15*cos(theta)**24 - 2.45774963925281e+15*cos(theta)**22 + 1.16340198087582e+15*cos(theta)**20 - 416283194663664.0*cos(theta)**18 + 111739173304457.0*cos(theta)**16 - 22163141812454.3*cos(theta)**14 + 3171141359958.09*cos(theta)**12 - 315679230403.067*cos(theta)**10 + 20707821236.3528*cos(theta)**8 - 822438290.238126*cos(theta)**6 + 17134131.0466276*cos(theta)**4 - 140635.822544139*cos(theta)**2 + 190.56344518176)*sin(2*phi)

#@torch.jit.script
def Yl38_m_minus_1(theta, phi):
    return 0.090935053487738*(1.0 - cos(theta)**2)**0.5*(952857898120.215*cos(theta)**37 - 8461378135307.51*cos(theta)**35 + 34483013633616.2*cos(theta)**33 - 85479019711499.4*cos(theta)**31 + 144013565818287.0*cos(theta)**29 - 174535843946939.0*cos(theta)**27 + 157082259552245.0*cos(theta)**25 - 106858679967514.0*cos(theta)**23 + 55400094327420.0*cos(theta)**21 - 21909641824403.4*cos(theta)**19 + 6572892547321.01*cos(theta)**17 - 1477542787496.95*cos(theta)**15 + 243933950766.007*cos(theta)**13 - 28698111854.8243*cos(theta)**11 + 2300869026.26142*cos(theta)**9 - 117491184.319732*cos(theta)**7 + 3426826.20932553*cos(theta)**5 - 46878.6075147131*cos(theta)**3 + 190.56344518176*cos(theta))*sin(phi)

#@torch.jit.script
def Yl38_m0(theta, phi):
    return 195000104809.684*cos(theta)**38 - 1827800982416.11*cos(theta)**36 + 7887086430973.62*cos(theta)**34 - 20773030459043.2*cos(theta)**32 + 37331243143787.8*cos(theta)**30 - 48474897813575.2*cos(theta)**28 + 46983362496234.4*cos(theta)**26 - 34624927009696.6*cos(theta)**24 + 19582950521877.6*cos(theta)**22 - 8519136667709.45*cos(theta)**20 + 2839712222569.82*cos(theta)**18 - 718142099261.458*cos(theta)**16 + 135498509294.615*cos(theta)**14 - 18597834609.0648*cos(theta)**12 + 1789296041.10536*cos(theta)**10 - 114210385.602469*cos(theta)**8 + 4441514.99565159*cos(theta)**6 - 91139.1585975019*cos(theta)**4 + 740.968769085381*cos(theta)**2 - 0.999957853016709

#@torch.jit.script
def Yl38_m1(theta, phi):
    return 0.090935053487738*(1.0 - cos(theta)**2)**0.5*(952857898120.215*cos(theta)**37 - 8461378135307.51*cos(theta)**35 + 34483013633616.2*cos(theta)**33 - 85479019711499.4*cos(theta)**31 + 144013565818287.0*cos(theta)**29 - 174535843946939.0*cos(theta)**27 + 157082259552245.0*cos(theta)**25 - 106858679967514.0*cos(theta)**23 + 55400094327420.0*cos(theta)**21 - 21909641824403.4*cos(theta)**19 + 6572892547321.01*cos(theta)**17 - 1477542787496.95*cos(theta)**15 + 243933950766.007*cos(theta)**13 - 28698111854.8243*cos(theta)**11 + 2300869026.26142*cos(theta)**9 - 117491184.319732*cos(theta)**7 + 3426826.20932553*cos(theta)**5 - 46878.6075147131*cos(theta)**3 + 190.56344518176*cos(theta))*cos(phi)

#@torch.jit.script
def Yl38_m2(theta, phi):
    return 0.00236374416014225*(1.0 - cos(theta)**2)*(35255742230448.0*cos(theta)**36 - 296148234735763.0*cos(theta)**34 + 1.13793944990934e+15*cos(theta)**32 - 2.64984961105648e+15*cos(theta)**30 + 4.17639340873032e+15*cos(theta)**28 - 4.71246778656735e+15*cos(theta)**26 + 3.92705648880612e+15*cos(theta)**24 - 2.45774963925281e+15*cos(theta)**22 + 1.16340198087582e+15*cos(theta)**20 - 416283194663664.0*cos(theta)**18 + 111739173304457.0*cos(theta)**16 - 22163141812454.3*cos(theta)**14 + 3171141359958.09*cos(theta)**12 - 315679230403.067*cos(theta)**10 + 20707821236.3528*cos(theta)**8 - 822438290.238126*cos(theta)**6 + 17134131.0466276*cos(theta)**4 - 140635.822544139*cos(theta)**2 + 190.56344518176)*cos(2*phi)

#@torch.jit.script
def Yl38_m3(theta, phi):
    return 6.15258029386065e-5*(1.0 - cos(theta)**2)**1.5*(1.26920672029613e+15*cos(theta)**35 - 1.00690399810159e+16*cos(theta)**33 + 3.64140623970987e+16*cos(theta)**31 - 7.94954883316944e+16*cos(theta)**29 + 1.16939015444449e+17*cos(theta)**27 - 1.22524162450751e+17*cos(theta)**25 + 9.4249355731347e+16*cos(theta)**23 - 5.40704920635619e+16*cos(theta)**21 + 2.32680396175164e+16*cos(theta)**19 - 7.49309750394595e+15*cos(theta)**17 + 1.78782677287132e+15*cos(theta)**15 - 310283985374361.0*cos(theta)**13 + 38053696319497.0*cos(theta)**11 - 3156792304030.67*cos(theta)**9 + 165662569890.823*cos(theta)**7 - 4934629741.42876*cos(theta)**5 + 68536524.1865105*cos(theta)**3 - 281271.645088278*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl38_m4(theta, phi):
    return 1.60471762562345e-6*(1.0 - cos(theta)**2)**2*(4.44222352103644e+16*cos(theta)**34 - 3.32278319373526e+17*cos(theta)**32 + 1.12883593431006e+18*cos(theta)**30 - 2.30536916161914e+18*cos(theta)**28 + 3.15735341700012e+18*cos(theta)**26 - 3.06310406126878e+18*cos(theta)**24 + 2.16773518182098e+18*cos(theta)**22 - 1.1354803333348e+18*cos(theta)**20 + 4.42092752732811e+17*cos(theta)**18 - 1.27382657567081e+17*cos(theta)**16 + 2.68174015930697e+16*cos(theta)**14 - 4.03369180986669e+15*cos(theta)**12 + 418590659514467.0*cos(theta)**10 - 28411130736276.1*cos(theta)**8 + 1159637989235.76*cos(theta)**6 - 24673148707.1438*cos(theta)**4 + 205609572.559532*cos(theta)**2 - 281271.645088278)*cos(4*phi)

#@torch.jit.script
def Yl38_m5(theta, phi):
    return 4.1968643903827e-8*(1.0 - cos(theta)**2)**2.5*(1.51035599715239e+18*cos(theta)**33 - 1.06329062199528e+19*cos(theta)**31 + 3.38650780293018e+19*cos(theta)**29 - 6.45503365253359e+19*cos(theta)**27 + 8.20911888420032e+19*cos(theta)**25 - 7.35144974704506e+19*cos(theta)**23 + 4.76901740000616e+19*cos(theta)**21 - 2.2709606666696e+19*cos(theta)**19 + 7.9576695491906e+18*cos(theta)**17 - 2.0381225210733e+18*cos(theta)**15 + 3.75443622302976e+17*cos(theta)**13 - 4.84043017184002e+16*cos(theta)**11 + 4.18590659514467e+15*cos(theta)**9 - 227289045890209.0*cos(theta)**7 + 6957827935414.55*cos(theta)**5 - 98692594828.5751*cos(theta)**3 + 411219145.119063*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl38_m6(theta, phi):
    return 1.10139126615446e-9*(1.0 - cos(theta)**2)**3*(4.98417479060289e+19*cos(theta)**32 - 3.29620092818538e+20*cos(theta)**30 + 9.82087262849753e+20*cos(theta)**28 - 1.74285908618407e+21*cos(theta)**26 + 2.05227972105008e+21*cos(theta)**24 - 1.69083344182036e+21*cos(theta)**22 + 1.00149365400129e+21*cos(theta)**20 - 4.31482526667224e+20*cos(theta)**18 + 1.3528038233624e+20*cos(theta)**16 - 3.05718378160995e+19*cos(theta)**14 + 4.88076708993869e+18*cos(theta)**12 - 5.32447318902403e+17*cos(theta)**10 + 3.76731593563021e+16*cos(theta)**8 - 1.59102332123146e+15*cos(theta)**6 + 34789139677072.7*cos(theta)**4 - 296077784485.725*cos(theta)**2 + 411219145.119063)*cos(6*phi)

#@torch.jit.script
def Yl38_m7(theta, phi):
    return 2.90242083005401e-11*(1.0 - cos(theta)**2)**3.5*(1.59493593299292e+21*cos(theta)**31 - 9.88860278455613e+21*cos(theta)**29 + 2.74984433597931e+22*cos(theta)**27 - 4.53143362407858e+22*cos(theta)**25 + 4.92547133052019e+22*cos(theta)**23 - 3.7198335720048e+22*cos(theta)**21 + 2.00298730800259e+22*cos(theta)**19 - 7.76668548001003e+21*cos(theta)**17 + 2.16448611737984e+21*cos(theta)**15 - 4.28005729425393e+20*cos(theta)**13 + 5.85692050792643e+19*cos(theta)**11 - 5.32447318902403e+18*cos(theta)**9 + 3.01385274850417e+17*cos(theta)**7 - 9.54613992738876e+15*cos(theta)**5 + 139156558708291.0*cos(theta)**3 - 592155568971.451*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl38_m8(theta, phi):
    return 7.68600423582523e-13*(1.0 - cos(theta)**2)**4*(4.94430139227807e+22*cos(theta)**30 - 2.86769480752128e+23*cos(theta)**28 + 7.42457970714413e+23*cos(theta)**26 - 1.13285840601964e+24*cos(theta)**24 + 1.13285840601964e+24*cos(theta)**22 - 7.81165050121009e+23*cos(theta)**20 + 3.80567588520491e+23*cos(theta)**18 - 1.3203365316017e+23*cos(theta)**16 + 3.24672917606977e+22*cos(theta)**14 - 5.56407448253011e+21*cos(theta)**12 + 6.44261255871907e+20*cos(theta)**10 - 4.79202587012162e+19*cos(theta)**8 + 2.10969692395292e+18*cos(theta)**6 - 4.77306996369438e+16*cos(theta)**4 + 417469676124873.0*cos(theta)**2 - 592155568971.451)*cos(8*phi)

#@torch.jit.script
def Yl38_m9(theta, phi):
    return 2.04687378153282e-14*(1.0 - cos(theta)**2)**4.5*(1.48329041768342e+24*cos(theta)**29 - 8.02954546105958e+24*cos(theta)**27 + 1.93039072385747e+25*cos(theta)**25 - 2.71886017444715e+25*cos(theta)**23 + 2.49228849324322e+25*cos(theta)**21 - 1.56233010024202e+25*cos(theta)**19 + 6.85021659336884e+24*cos(theta)**17 - 2.11253845056273e+24*cos(theta)**15 + 4.54542084649767e+23*cos(theta)**13 - 6.67688937903613e+22*cos(theta)**11 + 6.44261255871907e+21*cos(theta)**9 - 3.8336206960973e+20*cos(theta)**7 + 1.26581815437175e+19*cos(theta)**5 - 1.90922798547775e+17*cos(theta)**3 + 834939352249746.0*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl38_m10(theta, phi):
    return 5.48619759603045e-16*(1.0 - cos(theta)**2)**5*(4.30154221128192e+25*cos(theta)**28 - 2.16797727448609e+26*cos(theta)**26 + 4.82597680964369e+26*cos(theta)**24 - 6.25337840122844e+26*cos(theta)**22 + 5.23380583581076e+26*cos(theta)**20 - 2.96842719045983e+26*cos(theta)**18 + 1.1645368208727e+26*cos(theta)**16 - 3.16880767584409e+25*cos(theta)**14 + 5.90904710044697e+24*cos(theta)**12 - 7.34457831693974e+23*cos(theta)**10 + 5.79835130284716e+22*cos(theta)**8 - 2.68353448726811e+21*cos(theta)**6 + 6.32909077185875e+19*cos(theta)**4 - 5.72768395643326e+17*cos(theta)**2 + 834939352249746.0)*cos(10*phi)

#@torch.jit.script
def Yl38_m11(theta, phi):
    return 1.48113413086296e-17*(1.0 - cos(theta)**2)**5.5*(1.20443181915894e+27*cos(theta)**27 - 5.63674091366382e+27*cos(theta)**25 + 1.15823443431448e+28*cos(theta)**23 - 1.37574324827026e+28*cos(theta)**21 + 1.04676116716215e+28*cos(theta)**19 - 5.3431689428277e+27*cos(theta)**17 + 1.86325891339633e+27*cos(theta)**15 - 4.43633074618173e+26*cos(theta)**13 + 7.09085652053637e+25*cos(theta)**11 - 7.34457831693974e+24*cos(theta)**9 + 4.63868104227773e+23*cos(theta)**7 - 1.61012069236087e+22*cos(theta)**5 + 2.5316363087435e+20*cos(theta)**3 - 1.14553679128665e+18*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl38_m12(theta, phi):
    return 4.03113651248321e-19*(1.0 - cos(theta)**2)**6*(3.25196591172913e+28*cos(theta)**26 - 1.40918522841596e+29*cos(theta)**24 + 2.66393919892331e+29*cos(theta)**22 - 2.88906082136754e+29*cos(theta)**20 + 1.98884621760809e+29*cos(theta)**18 - 9.08338720280709e+28*cos(theta)**16 + 2.79488837009449e+28*cos(theta)**14 - 5.76722997003625e+27*cos(theta)**12 + 7.79994217259e+26*cos(theta)**10 - 6.61012048524577e+25*cos(theta)**8 + 3.24707672959441e+24*cos(theta)**6 - 8.05060346180433e+22*cos(theta)**4 + 7.5949089262305e+20*cos(theta)**2 - 1.14553679128665e+18)*cos(12*phi)

#@torch.jit.script
def Yl38_m13(theta, phi):
    return 1.10702070454543e-20*(1.0 - cos(theta)**2)**6.5*(8.45511137049574e+29*cos(theta)**25 - 3.38204454819829e+30*cos(theta)**23 + 5.86066623763129e+30*cos(theta)**21 - 5.77812164273508e+30*cos(theta)**19 + 3.57992319169456e+30*cos(theta)**17 - 1.45334195244913e+30*cos(theta)**15 + 3.91284371813228e+29*cos(theta)**13 - 6.9206759640435e+28*cos(theta)**11 + 7.79994217259001e+27*cos(theta)**9 - 5.28809638819661e+26*cos(theta)**7 + 1.94824603775665e+25*cos(theta)**5 - 3.22024138472173e+23*cos(theta)**3 + 1.5189817852461e+21*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl38_m14(theta, phi):
    return 3.0703230101837e-22*(1.0 - cos(theta)**2)**7*(2.11377784262393e+31*cos(theta)**24 - 7.77870246085608e+31*cos(theta)**22 + 1.23073990990257e+32*cos(theta)**20 - 1.09784311211966e+32*cos(theta)**18 + 6.08586942588075e+31*cos(theta)**16 - 2.1800129286737e+31*cos(theta)**14 + 5.08669683357197e+30*cos(theta)**12 - 7.61274356044784e+29*cos(theta)**10 + 7.019947955331e+28*cos(theta)**8 - 3.70166747173763e+27*cos(theta)**6 + 9.74123018878324e+25*cos(theta)**4 - 9.66072415416519e+23*cos(theta)**2 + 1.5189817852461e+21)*cos(14*phi)

#@torch.jit.script
def Yl38_m15(theta, phi):
    return 8.60875824089541e-24*(1.0 - cos(theta)**2)**7.5*(5.07306682229744e+32*cos(theta)**23 - 1.71131454138834e+33*cos(theta)**21 + 2.46147981980514e+33*cos(theta)**19 - 1.9761176018154e+33*cos(theta)**17 + 9.7373910814092e+32*cos(theta)**15 - 3.05201810014318e+32*cos(theta)**13 + 6.10403620028636e+31*cos(theta)**11 - 7.61274356044785e+30*cos(theta)**9 + 5.6159583642648e+29*cos(theta)**7 - 2.22100048304258e+28*cos(theta)**5 + 3.89649207551329e+26*cos(theta)**3 - 1.93214483083304e+24*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl38_m16(theta, phi):
    return 2.44275389142847e-25*(1.0 - cos(theta)**2)**8*(1.16680536912841e+34*cos(theta)**22 - 3.59376053691551e+34*cos(theta)**20 + 4.67681165762977e+34*cos(theta)**18 - 3.35939992308617e+34*cos(theta)**16 + 1.46060866221138e+34*cos(theta)**14 - 3.96762353018614e+33*cos(theta)**12 + 6.714439820315e+32*cos(theta)**10 - 6.85146920440306e+31*cos(theta)**8 + 3.93117085498536e+30*cos(theta)**6 - 1.11050024152129e+29*cos(theta)**4 + 1.16894762265399e+27*cos(theta)**2 - 1.93214483083304e+24)*cos(16*phi)

#@torch.jit.script
def Yl38_m17(theta, phi):
    return 7.02242369104875e-27*(1.0 - cos(theta)**2)**8.5*(2.56697181208251e+35*cos(theta)**21 - 7.18752107383102e+35*cos(theta)**19 + 8.41826098373359e+35*cos(theta)**17 - 5.37503987693788e+35*cos(theta)**15 + 2.04485212709593e+35*cos(theta)**13 - 4.76114823622336e+34*cos(theta)**11 + 6.714439820315e+33*cos(theta)**9 - 5.48117536352245e+32*cos(theta)**7 + 2.35870251299122e+31*cos(theta)**5 - 4.44200096608516e+29*cos(theta)**3 + 2.33789524530798e+27*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl38_m18(theta, phi):
    return 2.04778033341685e-28*(1.0 - cos(theta)**2)**9*(5.39064080537326e+36*cos(theta)**20 - 1.36562900402789e+37*cos(theta)**18 + 1.43110436723471e+37*cos(theta)**16 - 8.06255981540682e+36*cos(theta)**14 + 2.65830776522471e+36*cos(theta)**12 - 5.2372630598457e+35*cos(theta)**10 + 6.0429958382835e+34*cos(theta)**8 - 3.83682275446571e+33*cos(theta)**6 + 1.17935125649561e+32*cos(theta)**4 - 1.33260028982555e+30*cos(theta)**2 + 2.33789524530798e+27)*cos(18*phi)

#@torch.jit.script
def Yl38_m19(theta, phi):
    return 6.06500191198304e-30*(1.0 - cos(theta)**2)**9.5*(1.07812816107465e+38*cos(theta)**19 - 2.45813220725021e+38*cos(theta)**17 + 2.28976698757554e+38*cos(theta)**15 - 1.12875837415695e+38*cos(theta)**13 + 3.18996931826965e+37*cos(theta)**11 - 5.2372630598457e+36*cos(theta)**9 + 4.8343966706268e+35*cos(theta)**7 - 2.30209365267943e+34*cos(theta)**5 + 4.71740502598244e+32*cos(theta)**3 - 2.66520057965109e+30*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl38_m20(theta, phi):
    return 1.82700672042423e-31*(1.0 - cos(theta)**2)**10*(2.04844350604184e+39*cos(theta)**18 - 4.17882475232535e+39*cos(theta)**16 + 3.4346504813633e+39*cos(theta)**14 - 1.46738588640404e+39*cos(theta)**12 + 3.50896625009662e+38*cos(theta)**10 - 4.71353675386113e+37*cos(theta)**8 + 3.38407766943876e+36*cos(theta)**6 - 1.15104682633971e+35*cos(theta)**4 + 1.41522150779473e+33*cos(theta)**2 - 2.66520057965109e+30)*cos(20*phi)

#@torch.jit.script
def Yl38_m21(theta, phi):
    return 5.60632004517403e-33*(1.0 - cos(theta)**2)**10.5*(3.68719831087531e+40*cos(theta)**17 - 6.68611960372056e+40*cos(theta)**15 + 4.80851067390862e+40*cos(theta)**13 - 1.76086306368485e+40*cos(theta)**11 + 3.50896625009662e+39*cos(theta)**9 - 3.7708294030889e+38*cos(theta)**7 + 2.03044660166326e+37*cos(theta)**5 - 4.60418730535886e+35*cos(theta)**3 + 2.83044301558946e+33*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl38_m22(theta, phi):
    return 1.75540689794278e-34*(1.0 - cos(theta)**2)**11*(6.26823712848803e+41*cos(theta)**16 - 1.00291794055808e+42*cos(theta)**14 + 6.25106387608121e+41*cos(theta)**12 - 1.93694937005333e+41*cos(theta)**10 + 3.15806962508696e+40*cos(theta)**8 - 2.63958058216223e+39*cos(theta)**6 + 1.01522330083163e+38*cos(theta)**4 - 1.38125619160766e+36*cos(theta)**2 + 2.83044301558946e+33)*cos(22*phi)

#@torch.jit.script
def Yl38_m23(theta, phi):
    return 5.61892055563194e-36*(1.0 - cos(theta)**2)**11.5*(1.00291794055808e+43*cos(theta)**15 - 1.40408511678132e+43*cos(theta)**13 + 7.50127665129745e+42*cos(theta)**11 - 1.93694937005333e+42*cos(theta)**9 + 2.52645570006957e+41*cos(theta)**7 - 1.58374834929734e+40*cos(theta)**5 + 4.06089320332651e+38*cos(theta)**3 - 2.76251238321531e+36*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl38_m24(theta, phi):
    return 1.84251663480048e-37*(1.0 - cos(theta)**2)**12*(1.50437691083713e+44*cos(theta)**14 - 1.82531065181571e+44*cos(theta)**12 + 8.2514043164272e+43*cos(theta)**10 - 1.743254433048e+43*cos(theta)**8 + 1.7685189900487e+42*cos(theta)**6 - 7.9187417464867e+40*cos(theta)**4 + 1.21826796099795e+39*cos(theta)**2 - 2.76251238321531e+36)*cos(24*phi)

#@torch.jit.script
def Yl38_m25(theta, phi):
    return 6.20407622341159e-39*(1.0 - cos(theta)**2)**12.5*(2.10612767517198e+45*cos(theta)**13 - 2.19037278217886e+45*cos(theta)**11 + 8.2514043164272e+44*cos(theta)**9 - 1.3946035464384e+44*cos(theta)**7 + 1.06111139402922e+43*cos(theta)**5 - 3.16749669859468e+41*cos(theta)**3 + 2.43653592199591e+39*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl38_m26(theta, phi):
    return 2.15087643657668e-40*(1.0 - cos(theta)**2)**13*(2.73796597772357e+46*cos(theta)**12 - 2.40941006039674e+46*cos(theta)**10 + 7.42626388478448e+45*cos(theta)**8 - 9.7622248250688e+44*cos(theta)**6 + 5.30555697014609e+43*cos(theta)**4 - 9.50249009578404e+41*cos(theta)**2 + 2.43653592199591e+39)*cos(26*phi)

#@torch.jit.script
def Yl38_m27(theta, phi):
    return 7.70137304226747e-42*(1.0 - cos(theta)**2)**13.5*(3.28555917326829e+47*cos(theta)**11 - 2.40941006039674e+47*cos(theta)**9 + 5.94101110782758e+46*cos(theta)**7 - 5.85733489504128e+45*cos(theta)**5 + 2.12222278805844e+44*cos(theta)**3 - 1.90049801915681e+42*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl38_m28(theta, phi):
    return 2.85824761702743e-43*(1.0 - cos(theta)**2)**14*(3.61411509059511e+48*cos(theta)**10 - 2.16846905435707e+48*cos(theta)**8 + 4.15870777547931e+47*cos(theta)**6 - 2.92866744752064e+46*cos(theta)**4 + 6.3666683641753e+44*cos(theta)**2 - 1.90049801915681e+42)*cos(28*phi)

#@torch.jit.script
def Yl38_m29(theta, phi):
    return 1.1042373906736e-44*(1.0 - cos(theta)**2)**14.5*(3.61411509059511e+49*cos(theta)**9 - 1.73477524348565e+49*cos(theta)**7 + 2.49522466528759e+48*cos(theta)**5 - 1.17146697900826e+47*cos(theta)**3 + 1.27333367283506e+45*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl38_m30(theta, phi):
    return 4.46361509559185e-46*(1.0 - cos(theta)**2)**15*(3.2527035815356e+50*cos(theta)**8 - 1.21434267043996e+50*cos(theta)**6 + 1.24761233264379e+49*cos(theta)**4 - 3.51440093702477e+47*cos(theta)**2 + 1.27333367283506e+45)*cos(30*phi)

#@torch.jit.script
def Yl38_m31(theta, phi):
    return 1.89984075045795e-47*(1.0 - cos(theta)**2)**15.5*(2.60216286522848e+51*cos(theta)**7 - 7.28605602263975e+50*cos(theta)**5 + 4.99044933057517e+49*cos(theta)**3 - 7.02880187404954e+47*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl38_m32(theta, phi):
    return 8.58260566150099e-49*(1.0 - cos(theta)**2)**16*(1.82151400565994e+52*cos(theta)**6 - 3.64302801131987e+51*cos(theta)**4 + 1.49713479917255e+50*cos(theta)**2 - 7.02880187404954e+47)*cos(32*phi)

#@torch.jit.script
def Yl38_m33(theta, phi):
    return 4.15828603021903e-50*(1.0 - cos(theta)**2)**16.5*(1.09290840339596e+53*cos(theta)**5 - 1.45721120452795e+52*cos(theta)**3 + 2.9942695983451e+50*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl38_m34(theta, phi):
    return 2.19160916965865e-51*(1.0 - cos(theta)**2)**17*(5.46454201697981e+53*cos(theta)**4 - 4.37163361358385e+52*cos(theta)**2 + 2.9942695983451e+50)*cos(34*phi)

#@torch.jit.script
def Yl38_m35(theta, phi):
    return 1.28254225711204e-52*(1.0 - cos(theta)**2)**17.5*(2.18581680679192e+54*cos(theta)**3 - 8.7432672271677e+52*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl38_m36(theta, phi):
    return 8.60786001928606e-54*(1.0 - cos(theta)**2)**18*(6.55745042037577e+54*cos(theta)**2 - 8.7432672271677e+52)*cos(36*phi)

#@torch.jit.script
def Yl38_m37(theta, phi):
    return 9.21753038048947*(1.0 - cos(theta)**2)**18.5*cos(37*phi)*cos(theta)

#@torch.jit.script
def Yl38_m38(theta, phi):
    return 1.0573232483571*(1.0 - cos(theta)**2)**19*cos(38*phi)

#@torch.jit.script
def Yl39_m_minus_39(theta, phi):
    return 1.064079376195*(1.0 - cos(theta)**2)**19.5*sin(39*phi)

#@torch.jit.script
def Yl39_m_minus_38(theta, phi):
    return 9.39769459334552*(1.0 - cos(theta)**2)**19*sin(38*phi)*cos(theta)

#@torch.jit.script
def Yl39_m_minus_37(theta, phi):
    return 1.15485099036113e-55*(1.0 - cos(theta)**2)**18.5*(5.04923682368935e+56*cos(theta)**2 - 6.55745042037577e+54)*sin(37*phi)

#@torch.jit.script
def Yl39_m_minus_36(theta, phi):
    return 1.743786754927e-54*(1.0 - cos(theta)**2)**18*(1.68307894122978e+56*cos(theta)**3 - 6.55745042037577e+54*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl39_m_minus_35(theta, phi):
    return 3.02032725709922e-53*(1.0 - cos(theta)**2)**17.5*(4.20769735307446e+55*cos(theta)**4 - 3.27872521018789e+54*cos(theta)**2 + 2.18581680679192e+52)*sin(35*phi)

#@torch.jit.script
def Yl39_m_minus_34(theta, phi):
    return 5.80971547822379e-52*(1.0 - cos(theta)**2)**17*(8.41539470614891e+54*cos(theta)**5 - 1.09290840339596e+54*cos(theta)**3 + 2.18581680679192e+52*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl39_m_minus_33(theta, phi):
    return 1.21588337207176e-50*(1.0 - cos(theta)**2)**16.5*(1.40256578435815e+54*cos(theta)**6 - 2.73227100848991e+53*cos(theta)**4 + 1.09290840339596e+52*cos(theta)**2 - 4.99044933057517e+49)*sin(33*phi)

#@torch.jit.script
def Yl39_m_minus_32(theta, phi):
    return 2.72965140034074e-49*(1.0 - cos(theta)**2)**16*(2.00366540622593e+53*cos(theta)**7 - 5.46454201697981e+52*cos(theta)**5 + 3.64302801131987e+51*cos(theta)**3 - 4.99044933057517e+49*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl39_m_minus_31(theta, phi):
    return 6.50551009827291e-48*(1.0 - cos(theta)**2)**15.5*(2.50458175778241e+52*cos(theta)**8 - 9.10757002829969e+51*cos(theta)**6 + 9.10757002829969e+50*cos(theta)**4 - 2.49522466528759e+49*cos(theta)**2 + 8.78600234256192e+46)*sin(31*phi)

#@torch.jit.script
def Yl39_m_minus_30(theta, phi):
    return 1.63287007543161e-46*(1.0 - cos(theta)**2)**15*(2.78286861975824e+51*cos(theta)**9 - 1.30108143261424e+51*cos(theta)**7 + 1.82151400565994e+50*cos(theta)**5 - 8.31741555095862e+48*cos(theta)**3 + 8.78600234256192e+46*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl39_m_minus_29(theta, phi):
    return 4.28919879632039e-45*(1.0 - cos(theta)**2)**14.5*(2.78286861975824e+50*cos(theta)**10 - 1.6263517907678e+50*cos(theta)**8 + 3.0358566760999e+49*cos(theta)**6 - 2.07935388773965e+48*cos(theta)**4 + 4.39300117128096e+46*cos(theta)**2 - 1.27333367283506e+44)*sin(29*phi)

#@torch.jit.script
def Yl39_m_minus_28(theta, phi):
    return 1.1730782277043e-43*(1.0 - cos(theta)**2)**14*(2.52988056341658e+49*cos(theta)**11 - 1.80705754529756e+49*cos(theta)**9 + 4.33693810871414e+48*cos(theta)**7 - 4.15870777547931e+47*cos(theta)**5 + 1.46433372376032e+46*cos(theta)**3 - 1.27333367283506e+44*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl39_m_minus_27(theta, phi):
    return 3.326250851581e-42*(1.0 - cos(theta)**2)**13.5*(2.10823380284715e+48*cos(theta)**12 - 1.80705754529756e+48*cos(theta)**10 + 5.42117263589267e+47*cos(theta)**8 - 6.93117962579885e+46*cos(theta)**6 + 3.6608343094008e+45*cos(theta)**4 - 6.3666683641753e+43*cos(theta)**2 + 1.58374834929734e+41)*sin(27*phi)

#@torch.jit.script
def Yl39_m_minus_26(theta, phi):
    return 9.74313326210721e-41*(1.0 - cos(theta)**2)**13*(1.62171830988242e+47*cos(theta)**13 - 1.64277958663414e+47*cos(theta)**11 + 6.02352515099186e+46*cos(theta)**9 - 9.90168517971264e+45*cos(theta)**7 + 7.3216686188016e+44*cos(theta)**5 - 2.12222278805844e+43*cos(theta)**3 + 1.58374834929734e+41*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl39_m_minus_25(theta, phi):
    return 2.93913367583875e-39*(1.0 - cos(theta)**2)**12.5*(1.15837022134459e+46*cos(theta)**14 - 1.36898298886179e+46*cos(theta)**12 + 6.02352515099186e+45*cos(theta)**10 - 1.23771064746408e+45*cos(theta)**8 + 1.2202781031336e+44*cos(theta)**6 - 5.30555697014609e+42*cos(theta)**4 + 7.9187417464867e+40*cos(theta)**2 - 1.74038280142565e+38)*sin(25*phi)

#@torch.jit.script
def Yl39_m_minus_24(theta, phi):
    return 9.10657262304068e-38*(1.0 - cos(theta)**2)**12*(7.72246814229725e+44*cos(theta)**15 - 1.05306383758599e+45*cos(theta)**13 + 5.47593195544714e+44*cos(theta)**11 - 1.37523405273787e+44*cos(theta)**9 + 1.743254433048e+43*cos(theta)**7 - 1.06111139402922e+42*cos(theta)**5 + 2.63958058216223e+40*cos(theta)**3 - 1.74038280142565e+38*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl39_m_minus_23(theta, phi):
    return 2.89124717480577e-36*(1.0 - cos(theta)**2)**11.5*(4.82654258893578e+43*cos(theta)**16 - 7.52188455418563e+43*cos(theta)**14 + 4.56327662953929e+43*cos(theta)**12 - 1.37523405273787e+43*cos(theta)**10 + 2.17906804131e+42*cos(theta)**8 - 1.7685189900487e+41*cos(theta)**6 + 6.59895145540558e+39*cos(theta)**4 - 8.70191400712824e+37*cos(theta)**2 + 1.72657023950957e+35)*sin(23*phi)

#@torch.jit.script
def Yl39_m_minus_22(theta, phi):
    return 9.38653981934599e-35*(1.0 - cos(theta)**2)**11*(2.83914269937399e+42*cos(theta)**17 - 5.01458970279042e+42*cos(theta)**15 + 3.5102127919533e+42*cos(theta)**13 - 1.25021277521624e+42*cos(theta)**11 + 2.42118671256667e+41*cos(theta)**9 - 2.52645570006957e+40*cos(theta)**7 + 1.31979029108112e+39*cos(theta)**5 - 2.90063800237608e+37*cos(theta)**3 + 1.72657023950957e+35*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl39_m_minus_21(theta, phi):
    return 3.1103316302064e-33*(1.0 - cos(theta)**2)**10.5*(1.57730149965222e+41*cos(theta)**18 - 3.13411856424401e+41*cos(theta)**16 + 2.50729485139521e+41*cos(theta)**14 - 1.04184397934687e+41*cos(theta)**12 + 2.42118671256667e+40*cos(theta)**10 - 3.15806962508696e+39*cos(theta)**8 + 2.19965048513519e+38*cos(theta)**6 - 7.2515950059402e+36*cos(theta)**4 + 8.63285119754786e+34*cos(theta)**2 - 1.57246834199415e+32)*sin(21*phi)

#@torch.jit.script
def Yl39_m_minus_20(theta, phi):
    return 1.05016882684848e-31*(1.0 - cos(theta)**2)**10*(8.30158684027482e+39*cos(theta)**19 - 1.84359915543766e+40*cos(theta)**17 + 1.67152990093014e+40*cos(theta)**15 - 8.01418445651438e+39*cos(theta)**13 + 2.20107882960606e+39*cos(theta)**11 - 3.50896625009662e+38*cos(theta)**9 + 3.14235783590742e+37*cos(theta)**7 - 1.45031900118804e+36*cos(theta)**5 + 2.87761706584929e+34*cos(theta)**3 - 1.57246834199415e+32*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl39_m_minus_19(theta, phi):
    return 3.60744838710617e-30*(1.0 - cos(theta)**2)**9.5*(4.15079342013741e+38*cos(theta)**20 - 1.02422175302092e+39*cos(theta)**18 + 1.04470618808134e+39*cos(theta)**16 - 5.72441746893884e+38*cos(theta)**14 + 1.83423235800505e+38*cos(theta)**12 - 3.50896625009662e+37*cos(theta)**10 + 3.92794729488427e+36*cos(theta)**8 - 2.4171983353134e+35*cos(theta)**6 + 7.19404266462321e+33*cos(theta)**4 - 7.86234170997073e+31*cos(theta)**2 + 1.33260028982555e+29)*sin(19*phi)

#@torch.jit.script
def Yl39_m_minus_18(theta, phi):
    return 1.25899431882528e-28*(1.0 - cos(theta)**2)**9*(1.97656829530353e+37*cos(theta)**21 - 5.39064080537326e+37*cos(theta)**19 + 6.14533051812552e+37*cos(theta)**17 - 3.81627831262589e+37*cos(theta)**15 + 1.41094796769619e+37*cos(theta)**13 - 3.18996931826965e+36*cos(theta)**11 + 4.36438588320475e+35*cos(theta)**9 - 3.45314047901914e+34*cos(theta)**7 + 1.43880853292464e+33*cos(theta)**5 - 2.62078056999024e+31*cos(theta)**3 + 1.33260028982555e+29*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl39_m_minus_17(theta, phi):
    return 4.45833336048602e-27*(1.0 - cos(theta)**2)**8.5*(8.98440134228877e+35*cos(theta)**22 - 2.69532040268663e+36*cos(theta)**20 + 3.41407251006973e+36*cos(theta)**18 - 2.38517394539118e+36*cos(theta)**16 + 1.00781997692585e+36*cos(theta)**14 - 2.65830776522471e+35*cos(theta)**12 + 4.36438588320475e+34*cos(theta)**10 - 4.31642559877393e+33*cos(theta)**8 + 2.39801422154107e+32*cos(theta)**6 - 6.5519514249756e+30*cos(theta)**4 + 6.66300144912773e+28*cos(theta)**2 - 1.06267965695817e+26)*sin(17*phi)

#@torch.jit.script
def Yl39_m_minus_16(theta, phi):
    return 1.60003863775068e-25*(1.0 - cos(theta)**2)**8*(3.90626145316903e+34*cos(theta)**23 - 1.28348590604125e+35*cos(theta)**21 + 1.79688026845775e+35*cos(theta)**19 - 1.40304349728893e+35*cos(theta)**17 + 6.71879984617235e+34*cos(theta)**15 - 2.04485212709593e+34*cos(theta)**13 + 3.96762353018614e+33*cos(theta)**11 - 4.79602844308214e+32*cos(theta)**9 + 3.42573460220153e+31*cos(theta)**7 - 1.31039028499512e+30*cos(theta)**5 + 2.22100048304258e+28*cos(theta)**3 - 1.06267965695817e+26*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl39_m_minus_15(theta, phi):
    return 5.81322905778663e-24*(1.0 - cos(theta)**2)**7.5*(1.62760893882043e+33*cos(theta)**24 - 5.83402684564206e+33*cos(theta)**22 + 8.98440134228877e+33*cos(theta)**20 - 7.79468609604962e+33*cos(theta)**18 + 4.19924990385772e+33*cos(theta)**16 - 1.46060866221138e+33*cos(theta)**14 + 3.30635294182178e+32*cos(theta)**12 - 4.79602844308214e+31*cos(theta)**10 + 4.28216825275191e+30*cos(theta)**8 - 2.1839838083252e+29*cos(theta)**6 + 5.55250120760644e+27*cos(theta)**4 - 5.31339828479086e+25*cos(theta)**2 + 8.05060346180433e+22)*sin(15*phi)

#@torch.jit.script
def Yl39_m_minus_14(theta, phi):
    return 2.13591674242462e-22*(1.0 - cos(theta)**2)**7*(6.51043575528172e+31*cos(theta)**25 - 2.53653341114872e+32*cos(theta)**23 + 4.27828635347084e+32*cos(theta)**21 - 4.1024663663419e+32*cos(theta)**19 + 2.47014700226925e+32*cos(theta)**17 - 9.7373910814092e+31*cos(theta)**15 + 2.54334841678598e+31*cos(theta)**13 - 4.3600258573474e+30*cos(theta)**11 + 4.7579647252799e+29*cos(theta)**9 - 3.119976869036e+28*cos(theta)**7 + 1.11050024152129e+27*cos(theta)**5 - 1.77113276159695e+25*cos(theta)**3 + 8.05060346180433e+22*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl39_m_minus_13(theta, phi):
    return 7.92882675780294e-21*(1.0 - cos(theta)**2)**6.5*(2.50401375203143e+30*cos(theta)**26 - 1.05688892131197e+31*cos(theta)**24 + 1.94467561521402e+31*cos(theta)**22 - 2.05123318317095e+31*cos(theta)**20 + 1.37230389014958e+31*cos(theta)**18 - 6.08586942588075e+30*cos(theta)**16 + 1.81667744056142e+30*cos(theta)**14 - 3.63335488112284e+29*cos(theta)**12 + 4.7579647252799e+28*cos(theta)**10 - 3.899971086295e+27*cos(theta)**8 + 1.85083373586881e+26*cos(theta)**6 - 4.42783190399238e+24*cos(theta)**4 + 4.02530173090216e+22*cos(theta)**2 - 5.84223763556192e+19)*sin(13*phi)

#@torch.jit.script
def Yl39_m_minus_12(theta, phi):
    return 2.97093043392762e-19*(1.0 - cos(theta)**2)**6*(9.27412500752381e+28*cos(theta)**27 - 4.22755568524787e+29*cos(theta)**25 + 8.45511137049574e+29*cos(theta)**23 - 9.76777706271882e+29*cos(theta)**21 + 7.22265205341885e+29*cos(theta)**19 - 3.57992319169456e+29*cos(theta)**17 + 1.21111829370761e+29*cos(theta)**15 - 2.79488837009449e+28*cos(theta)**13 + 4.32542247752718e+27*cos(theta)**11 - 4.33330120699445e+26*cos(theta)**9 + 2.64404819409831e+25*cos(theta)**7 - 8.85566380798476e+23*cos(theta)**5 + 1.34176724363405e+22*cos(theta)**3 - 5.84223763556192e+19*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl39_m_minus_11(theta, phi):
    return 1.12268155211275e-17*(1.0 - cos(theta)**2)**5.5*(3.31218750268708e+27*cos(theta)**28 - 1.62598295586456e+28*cos(theta)**26 + 3.52296307103989e+28*cos(theta)**24 - 4.43989866487219e+28*cos(theta)**22 + 3.61132602670942e+28*cos(theta)**20 - 1.98884621760809e+28*cos(theta)**18 + 7.56948933567257e+27*cos(theta)**16 - 1.99634883578178e+27*cos(theta)**14 + 3.60451873127265e+26*cos(theta)**12 - 4.33330120699445e+25*cos(theta)**10 + 3.30506024262288e+24*cos(theta)**8 - 1.47594396799746e+23*cos(theta)**6 + 3.35441810908514e+21*cos(theta)**4 - 2.92111881778096e+19*cos(theta)**2 + 4.09120282602375e+16)*sin(11*phi)

#@torch.jit.script
def Yl39_m_minus_10(theta, phi):
    return 4.27504398551492e-16*(1.0 - cos(theta)**2)**5*(1.14213362161623e+26*cos(theta)**29 - 6.02215909579468e+26*cos(theta)**27 + 1.40918522841596e+27*cos(theta)**25 - 1.93039072385747e+27*cos(theta)**23 + 1.71967906033782e+27*cos(theta)**21 - 1.04676116716215e+27*cos(theta)**19 + 4.45264078568975e+26*cos(theta)**17 - 1.33089922385452e+26*cos(theta)**15 + 2.77270671636358e+25*cos(theta)**13 - 3.93936473363132e+24*cos(theta)**11 + 3.67228915846987e+23*cos(theta)**9 - 2.10849138285351e+22*cos(theta)**7 + 6.70883621817027e+20*cos(theta)**5 - 9.73706272593654e+18*cos(theta)**3 + 4.09120282602375e+16*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl39_m_minus_9(theta, phi):
    return 1.63907661763532e-14*(1.0 - cos(theta)**2)**4.5*(3.80711207205411e+24*cos(theta)**30 - 2.15077110564096e+25*cos(theta)**28 + 5.41994318621522e+25*cos(theta)**26 - 8.04329468273948e+25*cos(theta)**24 + 7.81672300153555e+25*cos(theta)**22 - 5.23380583581076e+25*cos(theta)**20 + 2.47368932538319e+25*cos(theta)**18 - 8.31812014909074e+24*cos(theta)**16 + 1.98050479740256e+24*cos(theta)**14 - 3.28280394469276e+23*cos(theta)**12 + 3.67228915846987e+22*cos(theta)**10 - 2.63561422856689e+21*cos(theta)**8 + 1.11813936969505e+20*cos(theta)**6 - 2.43426568148413e+18*cos(theta)**4 + 2.04560141301188e+16*cos(theta)**2 - 27831311741658.2)*sin(9*phi)

#@torch.jit.script
def Yl39_m_minus_8(theta, phi):
    return 6.32267298839384e-13*(1.0 - cos(theta)**2)**4*(1.22810066840455e+23*cos(theta)**31 - 7.4164520884171e+23*cos(theta)**29 + 2.00738636526489e+24*cos(theta)**27 - 3.21731787309579e+24*cos(theta)**25 + 3.39857521805893e+24*cos(theta)**23 - 2.49228849324322e+24*cos(theta)**21 + 1.30194175020168e+24*cos(theta)**19 - 4.89301185240632e+23*cos(theta)**17 + 1.3203365316017e+23*cos(theta)**15 - 2.52523380360982e+22*cos(theta)**13 + 3.33844468951806e+21*cos(theta)**11 - 2.92846025396321e+20*cos(theta)**9 + 1.59734195670721e+19*cos(theta)**7 - 4.86853136296827e+17*cos(theta)**5 + 6.81867137670626e+15*cos(theta)**3 - 27831311741658.2*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl39_m_minus_7(theta, phi):
    return 2.45202355926937e-11*(1.0 - cos(theta)**2)**3.5*(3.83781458876422e+21*cos(theta)**32 - 2.47215069613903e+22*cos(theta)**30 + 7.1692370188032e+22*cos(theta)**28 - 1.23742995119069e+23*cos(theta)**26 + 1.41607300752456e+23*cos(theta)**24 - 1.13285840601964e+23*cos(theta)**22 + 6.5097087510084e+22*cos(theta)**20 - 2.71833991800351e+22*cos(theta)**18 + 8.25210332251065e+21*cos(theta)**16 - 1.80373843114987e+21*cos(theta)**14 + 2.78203724126505e+20*cos(theta)**12 - 2.92846025396321e+19*cos(theta)**10 + 1.99667744588401e+18*cos(theta)**8 - 8.11421893828044e+16*cos(theta)**6 + 1.70466784417656e+15*cos(theta)**4 - 13915655870829.1*cos(theta)**2 + 18504861530.3578)*sin(7*phi)

#@torch.jit.script
def Yl39_m_minus_6(theta, phi):
    return 9.55345636639005e-10*(1.0 - cos(theta)**2)**3*(1.16297411780734e+20*cos(theta)**33 - 7.97467966496462e+20*cos(theta)**31 + 2.47215069613903e+21*cos(theta)**29 - 4.58307389329885e+21*cos(theta)**27 + 5.66429203009822e+21*cos(theta)**25 - 4.92547133052019e+21*cos(theta)**23 + 3.099861310004e+21*cos(theta)**21 - 1.43070522000185e+21*cos(theta)**19 + 4.85417842500627e+20*cos(theta)**17 - 1.20249228743325e+20*cos(theta)**15 + 2.14002864712696e+19*cos(theta)**13 - 2.66223659451201e+18*cos(theta)**11 + 2.21853049542668e+17*cos(theta)**9 - 1.15917413404006e+16*cos(theta)**7 + 340933568835313.0*cos(theta)**5 - 4638551956943.03*cos(theta)**3 + 18504861530.3578*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl39_m_minus_5(theta, phi):
    return 3.73685494330611e-8*(1.0 - cos(theta)**2)**2.5*(3.42051211119806e+18*cos(theta)**34 - 2.49208739530144e+19*cos(theta)**32 + 8.24050232046344e+19*cos(theta)**30 - 1.63681210474959e+20*cos(theta)**28 + 2.17857385773009e+20*cos(theta)**26 - 2.05227972105008e+20*cos(theta)**24 + 1.40902786818364e+20*cos(theta)**22 - 7.15352610000924e+19*cos(theta)**20 + 2.69676579167015e+19*cos(theta)**18 - 7.51557679645779e+18*cos(theta)**16 + 1.52859189080497e+18*cos(theta)**14 - 2.21853049542668e+17*cos(theta)**12 + 2.21853049542668e+16*cos(theta)**10 - 1.44896766755008e+15*cos(theta)**8 + 56822261472552.1*cos(theta)**6 - 1159637989235.76*cos(theta)**4 + 9252430765.17892*cos(theta)**2 - 12094680.738796)*sin(5*phi)

#@torch.jit.script
def Yl39_m_minus_4(theta, phi):
    return 1.46644777253264e-6*(1.0 - cos(theta)**2)**2*(9.77289174628017e+16*cos(theta)**35 - 7.55177998576195e+17*cos(theta)**33 + 2.65822655498821e+18*cos(theta)**31 - 5.6441796715503e+18*cos(theta)**29 + 8.06879206566698e+18*cos(theta)**27 - 8.20911888420032e+18*cos(theta)**25 + 6.12620812253755e+18*cos(theta)**23 - 3.4064410000044e+18*cos(theta)**21 + 1.4193504166685e+18*cos(theta)**19 - 4.42092752732811e+17*cos(theta)**17 + 1.01906126053665e+17*cos(theta)**15 - 1.70656191955898e+16*cos(theta)**13 + 2.01684590493334e+15*cos(theta)**11 - 160996407505564.0*cos(theta)**9 + 8117465924650.31*cos(theta)**7 - 231927597847.152*cos(theta)**5 + 3084143588.39297*cos(theta)**3 - 12094680.738796*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl39_m_minus_3(theta, phi):
    return 5.76968467048944e-5*(1.0 - cos(theta)**2)**1.5*(2.71469215174449e+15*cos(theta)**36 - 2.22111176051822e+16*cos(theta)**34 + 8.30695798433815e+16*cos(theta)**32 - 1.8813932238501e+17*cos(theta)**30 + 2.88171145202392e+17*cos(theta)**28 - 3.15735341700012e+17*cos(theta)**26 + 2.55258671772398e+17*cos(theta)**24 - 1.54838227272927e+17*cos(theta)**22 + 7.0967520833425e+16*cos(theta)**20 - 2.45607084851562e+16*cos(theta)**18 + 6.36913287835406e+15*cos(theta)**16 - 1.21897279968499e+15*cos(theta)**14 + 168070492077779.0*cos(theta)**12 - 16099640750556.4*cos(theta)**10 + 1014683240581.29*cos(theta)**8 - 38654599641.1919*cos(theta)**6 + 771035897.098243*cos(theta)**4 - 6047340.36939799*cos(theta)**2 + 7813.10125245218)*sin(3*phi)

#@torch.jit.script
def Yl39_m_minus_2(theta, phi):
    return 0.00227445624051009*(1.0 - cos(theta)**2)*(73370058155256.6*cos(theta)**37 - 634603360148063.0*cos(theta)**35 + 2.51725999525398e+15*cos(theta)**33 - 6.06901039951646e+15*cos(theta)**31 + 9.9369360414618e+15*cos(theta)**29 - 1.16939015444449e+16*cos(theta)**27 + 1.02103468708959e+16*cos(theta)**25 - 6.73209683795336e+15*cos(theta)**23 + 3.37940575397262e+15*cos(theta)**21 - 1.2926688676398e+15*cos(theta)**19 + 374654875197298.0*cos(theta)**17 - 81264853312332.5*cos(theta)**15 + 12928499390598.4*cos(theta)**13 - 1463603704596.04*cos(theta)**11 + 112742582286.81*cos(theta)**9 - 5522085663.02742*cos(theta)**7 + 154207179.419649*cos(theta)**5 - 2015780.12313266*cos(theta)**3 + 7813.10125245218*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl39_m_minus_1(theta, phi):
    return 0.0897762193123137*(1.0 - cos(theta)**2)**0.5*(1930791004085.7*cos(theta)**38 - 17627871115224.0*cos(theta)**36 + 74037058683940.7*cos(theta)**34 - 189656574984889.0*cos(theta)**32 + 331231201382060.0*cos(theta)**30 - 417639340873032.0*cos(theta)**28 + 392705648880612.0*cos(theta)**26 - 280504034914723.0*cos(theta)**24 + 153609352453301.0*cos(theta)**22 - 64633443381989.9*cos(theta)**20 + 20814159733183.2*cos(theta)**18 - 5079053332020.78*cos(theta)**16 + 923464242185.597*cos(theta)**14 - 121966975383.003*cos(theta)**12 + 11274258228.681*cos(theta)**10 - 690260707.878427*cos(theta)**8 + 25701196.5699414*cos(theta)**6 - 503945.030783166*cos(theta)**4 + 3906.55062622609*cos(theta)**2 - 5.01482750478317)*sin(phi)

#@torch.jit.script
def Yl39_m0(theta, phi):
    return 389968157002.95*cos(theta)**39 - 3752810445963.45*cos(theta)**37 + 16662478380077.7*cos(theta)**35 - 45270203818019.4*cos(theta)**33 + 84164322591247.4*cos(theta)**31 - 113438869579507.0*cos(theta)**29 + 114567614550448.0*cos(theta)**27 - 88380731224631.1*cos(theta)**25 + 52607578109899.4*cos(theta)**23 - 24243565139899.0*cos(theta)**21 + 8629065558269.14*cos(theta)**19 - 2353381515891.58*cos(theta)**17 + 484939221456.448*cos(theta)**15 - 73902203560.1263*cos(theta)**13 + 8073349968.75329*cos(theta)**11 - 604128228.954328*cos(theta)**9 + 28921032.2371753*cos(theta)**7 - 793910.688863635*cos(theta)**5 + 10257.2440421658*cos(theta)**3 - 39.501581677147*cos(theta)

#@torch.jit.script
def Yl39_m1(theta, phi):
    return 0.0897762193123137*(1.0 - cos(theta)**2)**0.5*(1930791004085.7*cos(theta)**38 - 17627871115224.0*cos(theta)**36 + 74037058683940.7*cos(theta)**34 - 189656574984889.0*cos(theta)**32 + 331231201382060.0*cos(theta)**30 - 417639340873032.0*cos(theta)**28 + 392705648880612.0*cos(theta)**26 - 280504034914723.0*cos(theta)**24 + 153609352453301.0*cos(theta)**22 - 64633443381989.9*cos(theta)**20 + 20814159733183.2*cos(theta)**18 - 5079053332020.78*cos(theta)**16 + 923464242185.597*cos(theta)**14 - 121966975383.003*cos(theta)**12 + 11274258228.681*cos(theta)**10 - 690260707.878427*cos(theta)**8 + 25701196.5699414*cos(theta)**6 - 503945.030783166*cos(theta)**4 + 3906.55062622609*cos(theta)**2 - 5.01482750478317)*cos(phi)

#@torch.jit.script
def Yl39_m2(theta, phi):
    return 0.00227445624051009*(1.0 - cos(theta)**2)*(73370058155256.6*cos(theta)**37 - 634603360148063.0*cos(theta)**35 + 2.51725999525398e+15*cos(theta)**33 - 6.06901039951646e+15*cos(theta)**31 + 9.9369360414618e+15*cos(theta)**29 - 1.16939015444449e+16*cos(theta)**27 + 1.02103468708959e+16*cos(theta)**25 - 6.73209683795336e+15*cos(theta)**23 + 3.37940575397262e+15*cos(theta)**21 - 1.2926688676398e+15*cos(theta)**19 + 374654875197298.0*cos(theta)**17 - 81264853312332.5*cos(theta)**15 + 12928499390598.4*cos(theta)**13 - 1463603704596.04*cos(theta)**11 + 112742582286.81*cos(theta)**9 - 5522085663.02742*cos(theta)**7 + 154207179.419649*cos(theta)**5 - 2015780.12313266*cos(theta)**3 + 7813.10125245218*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl39_m3(theta, phi):
    return 5.76968467048944e-5*(1.0 - cos(theta)**2)**1.5*(2.71469215174449e+15*cos(theta)**36 - 2.22111176051822e+16*cos(theta)**34 + 8.30695798433815e+16*cos(theta)**32 - 1.8813932238501e+17*cos(theta)**30 + 2.88171145202392e+17*cos(theta)**28 - 3.15735341700012e+17*cos(theta)**26 + 2.55258671772398e+17*cos(theta)**24 - 1.54838227272927e+17*cos(theta)**22 + 7.0967520833425e+16*cos(theta)**20 - 2.45607084851562e+16*cos(theta)**18 + 6.36913287835406e+15*cos(theta)**16 - 1.21897279968499e+15*cos(theta)**14 + 168070492077779.0*cos(theta)**12 - 16099640750556.4*cos(theta)**10 + 1014683240581.29*cos(theta)**8 - 38654599641.1919*cos(theta)**6 + 771035897.098243*cos(theta)**4 - 6047340.36939799*cos(theta)**2 + 7813.10125245218)*cos(3*phi)

#@torch.jit.script
def Yl39_m4(theta, phi):
    return 1.46644777253264e-6*(1.0 - cos(theta)**2)**2*(9.77289174628017e+16*cos(theta)**35 - 7.55177998576195e+17*cos(theta)**33 + 2.65822655498821e+18*cos(theta)**31 - 5.6441796715503e+18*cos(theta)**29 + 8.06879206566698e+18*cos(theta)**27 - 8.20911888420032e+18*cos(theta)**25 + 6.12620812253755e+18*cos(theta)**23 - 3.4064410000044e+18*cos(theta)**21 + 1.4193504166685e+18*cos(theta)**19 - 4.42092752732811e+17*cos(theta)**17 + 1.01906126053665e+17*cos(theta)**15 - 1.70656191955898e+16*cos(theta)**13 + 2.01684590493334e+15*cos(theta)**11 - 160996407505564.0*cos(theta)**9 + 8117465924650.31*cos(theta)**7 - 231927597847.152*cos(theta)**5 + 3084143588.39297*cos(theta)**3 - 12094680.738796*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl39_m5(theta, phi):
    return 3.73685494330611e-8*(1.0 - cos(theta)**2)**2.5*(3.42051211119806e+18*cos(theta)**34 - 2.49208739530144e+19*cos(theta)**32 + 8.24050232046344e+19*cos(theta)**30 - 1.63681210474959e+20*cos(theta)**28 + 2.17857385773009e+20*cos(theta)**26 - 2.05227972105008e+20*cos(theta)**24 + 1.40902786818364e+20*cos(theta)**22 - 7.15352610000924e+19*cos(theta)**20 + 2.69676579167015e+19*cos(theta)**18 - 7.51557679645779e+18*cos(theta)**16 + 1.52859189080497e+18*cos(theta)**14 - 2.21853049542668e+17*cos(theta)**12 + 2.21853049542668e+16*cos(theta)**10 - 1.44896766755008e+15*cos(theta)**8 + 56822261472552.1*cos(theta)**6 - 1159637989235.76*cos(theta)**4 + 9252430765.17892*cos(theta)**2 - 12094680.738796)*cos(5*phi)

#@torch.jit.script
def Yl39_m6(theta, phi):
    return 9.55345636639005e-10*(1.0 - cos(theta)**2)**3*(1.16297411780734e+20*cos(theta)**33 - 7.97467966496462e+20*cos(theta)**31 + 2.47215069613903e+21*cos(theta)**29 - 4.58307389329885e+21*cos(theta)**27 + 5.66429203009822e+21*cos(theta)**25 - 4.92547133052019e+21*cos(theta)**23 + 3.099861310004e+21*cos(theta)**21 - 1.43070522000185e+21*cos(theta)**19 + 4.85417842500627e+20*cos(theta)**17 - 1.20249228743325e+20*cos(theta)**15 + 2.14002864712696e+19*cos(theta)**13 - 2.66223659451201e+18*cos(theta)**11 + 2.21853049542668e+17*cos(theta)**9 - 1.15917413404006e+16*cos(theta)**7 + 340933568835313.0*cos(theta)**5 - 4638551956943.03*cos(theta)**3 + 18504861530.3578*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl39_m7(theta, phi):
    return 2.45202355926937e-11*(1.0 - cos(theta)**2)**3.5*(3.83781458876422e+21*cos(theta)**32 - 2.47215069613903e+22*cos(theta)**30 + 7.1692370188032e+22*cos(theta)**28 - 1.23742995119069e+23*cos(theta)**26 + 1.41607300752456e+23*cos(theta)**24 - 1.13285840601964e+23*cos(theta)**22 + 6.5097087510084e+22*cos(theta)**20 - 2.71833991800351e+22*cos(theta)**18 + 8.25210332251065e+21*cos(theta)**16 - 1.80373843114987e+21*cos(theta)**14 + 2.78203724126505e+20*cos(theta)**12 - 2.92846025396321e+19*cos(theta)**10 + 1.99667744588401e+18*cos(theta)**8 - 8.11421893828044e+16*cos(theta)**6 + 1.70466784417656e+15*cos(theta)**4 - 13915655870829.1*cos(theta)**2 + 18504861530.3578)*cos(7*phi)

#@torch.jit.script
def Yl39_m8(theta, phi):
    return 6.32267298839384e-13*(1.0 - cos(theta)**2)**4*(1.22810066840455e+23*cos(theta)**31 - 7.4164520884171e+23*cos(theta)**29 + 2.00738636526489e+24*cos(theta)**27 - 3.21731787309579e+24*cos(theta)**25 + 3.39857521805893e+24*cos(theta)**23 - 2.49228849324322e+24*cos(theta)**21 + 1.30194175020168e+24*cos(theta)**19 - 4.89301185240632e+23*cos(theta)**17 + 1.3203365316017e+23*cos(theta)**15 - 2.52523380360982e+22*cos(theta)**13 + 3.33844468951806e+21*cos(theta)**11 - 2.92846025396321e+20*cos(theta)**9 + 1.59734195670721e+19*cos(theta)**7 - 4.86853136296827e+17*cos(theta)**5 + 6.81867137670626e+15*cos(theta)**3 - 27831311741658.2*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl39_m9(theta, phi):
    return 1.63907661763532e-14*(1.0 - cos(theta)**2)**4.5*(3.80711207205411e+24*cos(theta)**30 - 2.15077110564096e+25*cos(theta)**28 + 5.41994318621522e+25*cos(theta)**26 - 8.04329468273948e+25*cos(theta)**24 + 7.81672300153555e+25*cos(theta)**22 - 5.23380583581076e+25*cos(theta)**20 + 2.47368932538319e+25*cos(theta)**18 - 8.31812014909074e+24*cos(theta)**16 + 1.98050479740256e+24*cos(theta)**14 - 3.28280394469276e+23*cos(theta)**12 + 3.67228915846987e+22*cos(theta)**10 - 2.63561422856689e+21*cos(theta)**8 + 1.11813936969505e+20*cos(theta)**6 - 2.43426568148413e+18*cos(theta)**4 + 2.04560141301188e+16*cos(theta)**2 - 27831311741658.2)*cos(9*phi)

#@torch.jit.script
def Yl39_m10(theta, phi):
    return 4.27504398551492e-16*(1.0 - cos(theta)**2)**5*(1.14213362161623e+26*cos(theta)**29 - 6.02215909579468e+26*cos(theta)**27 + 1.40918522841596e+27*cos(theta)**25 - 1.93039072385747e+27*cos(theta)**23 + 1.71967906033782e+27*cos(theta)**21 - 1.04676116716215e+27*cos(theta)**19 + 4.45264078568975e+26*cos(theta)**17 - 1.33089922385452e+26*cos(theta)**15 + 2.77270671636358e+25*cos(theta)**13 - 3.93936473363132e+24*cos(theta)**11 + 3.67228915846987e+23*cos(theta)**9 - 2.10849138285351e+22*cos(theta)**7 + 6.70883621817027e+20*cos(theta)**5 - 9.73706272593654e+18*cos(theta)**3 + 4.09120282602375e+16*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl39_m11(theta, phi):
    return 1.12268155211275e-17*(1.0 - cos(theta)**2)**5.5*(3.31218750268708e+27*cos(theta)**28 - 1.62598295586456e+28*cos(theta)**26 + 3.52296307103989e+28*cos(theta)**24 - 4.43989866487219e+28*cos(theta)**22 + 3.61132602670942e+28*cos(theta)**20 - 1.98884621760809e+28*cos(theta)**18 + 7.56948933567257e+27*cos(theta)**16 - 1.99634883578178e+27*cos(theta)**14 + 3.60451873127265e+26*cos(theta)**12 - 4.33330120699445e+25*cos(theta)**10 + 3.30506024262288e+24*cos(theta)**8 - 1.47594396799746e+23*cos(theta)**6 + 3.35441810908514e+21*cos(theta)**4 - 2.92111881778096e+19*cos(theta)**2 + 4.09120282602375e+16)*cos(11*phi)

#@torch.jit.script
def Yl39_m12(theta, phi):
    return 2.97093043392762e-19*(1.0 - cos(theta)**2)**6*(9.27412500752381e+28*cos(theta)**27 - 4.22755568524787e+29*cos(theta)**25 + 8.45511137049574e+29*cos(theta)**23 - 9.76777706271882e+29*cos(theta)**21 + 7.22265205341885e+29*cos(theta)**19 - 3.57992319169456e+29*cos(theta)**17 + 1.21111829370761e+29*cos(theta)**15 - 2.79488837009449e+28*cos(theta)**13 + 4.32542247752718e+27*cos(theta)**11 - 4.33330120699445e+26*cos(theta)**9 + 2.64404819409831e+25*cos(theta)**7 - 8.85566380798476e+23*cos(theta)**5 + 1.34176724363405e+22*cos(theta)**3 - 5.84223763556192e+19*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl39_m13(theta, phi):
    return 7.92882675780294e-21*(1.0 - cos(theta)**2)**6.5*(2.50401375203143e+30*cos(theta)**26 - 1.05688892131197e+31*cos(theta)**24 + 1.94467561521402e+31*cos(theta)**22 - 2.05123318317095e+31*cos(theta)**20 + 1.37230389014958e+31*cos(theta)**18 - 6.08586942588075e+30*cos(theta)**16 + 1.81667744056142e+30*cos(theta)**14 - 3.63335488112284e+29*cos(theta)**12 + 4.7579647252799e+28*cos(theta)**10 - 3.899971086295e+27*cos(theta)**8 + 1.85083373586881e+26*cos(theta)**6 - 4.42783190399238e+24*cos(theta)**4 + 4.02530173090216e+22*cos(theta)**2 - 5.84223763556192e+19)*cos(13*phi)

#@torch.jit.script
def Yl39_m14(theta, phi):
    return 2.13591674242462e-22*(1.0 - cos(theta)**2)**7*(6.51043575528172e+31*cos(theta)**25 - 2.53653341114872e+32*cos(theta)**23 + 4.27828635347084e+32*cos(theta)**21 - 4.1024663663419e+32*cos(theta)**19 + 2.47014700226925e+32*cos(theta)**17 - 9.7373910814092e+31*cos(theta)**15 + 2.54334841678598e+31*cos(theta)**13 - 4.3600258573474e+30*cos(theta)**11 + 4.7579647252799e+29*cos(theta)**9 - 3.119976869036e+28*cos(theta)**7 + 1.11050024152129e+27*cos(theta)**5 - 1.77113276159695e+25*cos(theta)**3 + 8.05060346180433e+22*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl39_m15(theta, phi):
    return 5.81322905778663e-24*(1.0 - cos(theta)**2)**7.5*(1.62760893882043e+33*cos(theta)**24 - 5.83402684564206e+33*cos(theta)**22 + 8.98440134228877e+33*cos(theta)**20 - 7.79468609604962e+33*cos(theta)**18 + 4.19924990385772e+33*cos(theta)**16 - 1.46060866221138e+33*cos(theta)**14 + 3.30635294182178e+32*cos(theta)**12 - 4.79602844308214e+31*cos(theta)**10 + 4.28216825275191e+30*cos(theta)**8 - 2.1839838083252e+29*cos(theta)**6 + 5.55250120760644e+27*cos(theta)**4 - 5.31339828479086e+25*cos(theta)**2 + 8.05060346180433e+22)*cos(15*phi)

#@torch.jit.script
def Yl39_m16(theta, phi):
    return 1.60003863775068e-25*(1.0 - cos(theta)**2)**8*(3.90626145316903e+34*cos(theta)**23 - 1.28348590604125e+35*cos(theta)**21 + 1.79688026845775e+35*cos(theta)**19 - 1.40304349728893e+35*cos(theta)**17 + 6.71879984617235e+34*cos(theta)**15 - 2.04485212709593e+34*cos(theta)**13 + 3.96762353018614e+33*cos(theta)**11 - 4.79602844308214e+32*cos(theta)**9 + 3.42573460220153e+31*cos(theta)**7 - 1.31039028499512e+30*cos(theta)**5 + 2.22100048304258e+28*cos(theta)**3 - 1.06267965695817e+26*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl39_m17(theta, phi):
    return 4.45833336048602e-27*(1.0 - cos(theta)**2)**8.5*(8.98440134228877e+35*cos(theta)**22 - 2.69532040268663e+36*cos(theta)**20 + 3.41407251006973e+36*cos(theta)**18 - 2.38517394539118e+36*cos(theta)**16 + 1.00781997692585e+36*cos(theta)**14 - 2.65830776522471e+35*cos(theta)**12 + 4.36438588320475e+34*cos(theta)**10 - 4.31642559877393e+33*cos(theta)**8 + 2.39801422154107e+32*cos(theta)**6 - 6.5519514249756e+30*cos(theta)**4 + 6.66300144912773e+28*cos(theta)**2 - 1.06267965695817e+26)*cos(17*phi)

#@torch.jit.script
def Yl39_m18(theta, phi):
    return 1.25899431882528e-28*(1.0 - cos(theta)**2)**9*(1.97656829530353e+37*cos(theta)**21 - 5.39064080537326e+37*cos(theta)**19 + 6.14533051812552e+37*cos(theta)**17 - 3.81627831262589e+37*cos(theta)**15 + 1.41094796769619e+37*cos(theta)**13 - 3.18996931826965e+36*cos(theta)**11 + 4.36438588320475e+35*cos(theta)**9 - 3.45314047901914e+34*cos(theta)**7 + 1.43880853292464e+33*cos(theta)**5 - 2.62078056999024e+31*cos(theta)**3 + 1.33260028982555e+29*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl39_m19(theta, phi):
    return 3.60744838710617e-30*(1.0 - cos(theta)**2)**9.5*(4.15079342013741e+38*cos(theta)**20 - 1.02422175302092e+39*cos(theta)**18 + 1.04470618808134e+39*cos(theta)**16 - 5.72441746893884e+38*cos(theta)**14 + 1.83423235800505e+38*cos(theta)**12 - 3.50896625009662e+37*cos(theta)**10 + 3.92794729488427e+36*cos(theta)**8 - 2.4171983353134e+35*cos(theta)**6 + 7.19404266462321e+33*cos(theta)**4 - 7.86234170997073e+31*cos(theta)**2 + 1.33260028982555e+29)*cos(19*phi)

#@torch.jit.script
def Yl39_m20(theta, phi):
    return 1.05016882684848e-31*(1.0 - cos(theta)**2)**10*(8.30158684027482e+39*cos(theta)**19 - 1.84359915543766e+40*cos(theta)**17 + 1.67152990093014e+40*cos(theta)**15 - 8.01418445651438e+39*cos(theta)**13 + 2.20107882960606e+39*cos(theta)**11 - 3.50896625009662e+38*cos(theta)**9 + 3.14235783590742e+37*cos(theta)**7 - 1.45031900118804e+36*cos(theta)**5 + 2.87761706584929e+34*cos(theta)**3 - 1.57246834199415e+32*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl39_m21(theta, phi):
    return 3.1103316302064e-33*(1.0 - cos(theta)**2)**10.5*(1.57730149965222e+41*cos(theta)**18 - 3.13411856424401e+41*cos(theta)**16 + 2.50729485139521e+41*cos(theta)**14 - 1.04184397934687e+41*cos(theta)**12 + 2.42118671256667e+40*cos(theta)**10 - 3.15806962508696e+39*cos(theta)**8 + 2.19965048513519e+38*cos(theta)**6 - 7.2515950059402e+36*cos(theta)**4 + 8.63285119754786e+34*cos(theta)**2 - 1.57246834199415e+32)*cos(21*phi)

#@torch.jit.script
def Yl39_m22(theta, phi):
    return 9.38653981934599e-35*(1.0 - cos(theta)**2)**11*(2.83914269937399e+42*cos(theta)**17 - 5.01458970279042e+42*cos(theta)**15 + 3.5102127919533e+42*cos(theta)**13 - 1.25021277521624e+42*cos(theta)**11 + 2.42118671256667e+41*cos(theta)**9 - 2.52645570006957e+40*cos(theta)**7 + 1.31979029108112e+39*cos(theta)**5 - 2.90063800237608e+37*cos(theta)**3 + 1.72657023950957e+35*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl39_m23(theta, phi):
    return 2.89124717480577e-36*(1.0 - cos(theta)**2)**11.5*(4.82654258893578e+43*cos(theta)**16 - 7.52188455418563e+43*cos(theta)**14 + 4.56327662953929e+43*cos(theta)**12 - 1.37523405273787e+43*cos(theta)**10 + 2.17906804131e+42*cos(theta)**8 - 1.7685189900487e+41*cos(theta)**6 + 6.59895145540558e+39*cos(theta)**4 - 8.70191400712824e+37*cos(theta)**2 + 1.72657023950957e+35)*cos(23*phi)

#@torch.jit.script
def Yl39_m24(theta, phi):
    return 9.10657262304068e-38*(1.0 - cos(theta)**2)**12*(7.72246814229725e+44*cos(theta)**15 - 1.05306383758599e+45*cos(theta)**13 + 5.47593195544714e+44*cos(theta)**11 - 1.37523405273787e+44*cos(theta)**9 + 1.743254433048e+43*cos(theta)**7 - 1.06111139402922e+42*cos(theta)**5 + 2.63958058216223e+40*cos(theta)**3 - 1.74038280142565e+38*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl39_m25(theta, phi):
    return 2.93913367583875e-39*(1.0 - cos(theta)**2)**12.5*(1.15837022134459e+46*cos(theta)**14 - 1.36898298886179e+46*cos(theta)**12 + 6.02352515099186e+45*cos(theta)**10 - 1.23771064746408e+45*cos(theta)**8 + 1.2202781031336e+44*cos(theta)**6 - 5.30555697014609e+42*cos(theta)**4 + 7.9187417464867e+40*cos(theta)**2 - 1.74038280142565e+38)*cos(25*phi)

#@torch.jit.script
def Yl39_m26(theta, phi):
    return 9.74313326210721e-41*(1.0 - cos(theta)**2)**13*(1.62171830988242e+47*cos(theta)**13 - 1.64277958663414e+47*cos(theta)**11 + 6.02352515099186e+46*cos(theta)**9 - 9.90168517971264e+45*cos(theta)**7 + 7.3216686188016e+44*cos(theta)**5 - 2.12222278805844e+43*cos(theta)**3 + 1.58374834929734e+41*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl39_m27(theta, phi):
    return 3.326250851581e-42*(1.0 - cos(theta)**2)**13.5*(2.10823380284715e+48*cos(theta)**12 - 1.80705754529756e+48*cos(theta)**10 + 5.42117263589267e+47*cos(theta)**8 - 6.93117962579885e+46*cos(theta)**6 + 3.6608343094008e+45*cos(theta)**4 - 6.3666683641753e+43*cos(theta)**2 + 1.58374834929734e+41)*cos(27*phi)

#@torch.jit.script
def Yl39_m28(theta, phi):
    return 1.1730782277043e-43*(1.0 - cos(theta)**2)**14*(2.52988056341658e+49*cos(theta)**11 - 1.80705754529756e+49*cos(theta)**9 + 4.33693810871414e+48*cos(theta)**7 - 4.15870777547931e+47*cos(theta)**5 + 1.46433372376032e+46*cos(theta)**3 - 1.27333367283506e+44*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl39_m29(theta, phi):
    return 4.28919879632039e-45*(1.0 - cos(theta)**2)**14.5*(2.78286861975824e+50*cos(theta)**10 - 1.6263517907678e+50*cos(theta)**8 + 3.0358566760999e+49*cos(theta)**6 - 2.07935388773965e+48*cos(theta)**4 + 4.39300117128096e+46*cos(theta)**2 - 1.27333367283506e+44)*cos(29*phi)

#@torch.jit.script
def Yl39_m30(theta, phi):
    return 1.63287007543161e-46*(1.0 - cos(theta)**2)**15*(2.78286861975824e+51*cos(theta)**9 - 1.30108143261424e+51*cos(theta)**7 + 1.82151400565994e+50*cos(theta)**5 - 8.31741555095862e+48*cos(theta)**3 + 8.78600234256192e+46*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl39_m31(theta, phi):
    return 6.50551009827291e-48*(1.0 - cos(theta)**2)**15.5*(2.50458175778241e+52*cos(theta)**8 - 9.10757002829969e+51*cos(theta)**6 + 9.10757002829969e+50*cos(theta)**4 - 2.49522466528759e+49*cos(theta)**2 + 8.78600234256192e+46)*cos(31*phi)

#@torch.jit.script
def Yl39_m32(theta, phi):
    return 2.72965140034074e-49*(1.0 - cos(theta)**2)**16*(2.00366540622593e+53*cos(theta)**7 - 5.46454201697981e+52*cos(theta)**5 + 3.64302801131987e+51*cos(theta)**3 - 4.99044933057517e+49*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl39_m33(theta, phi):
    return 1.21588337207176e-50*(1.0 - cos(theta)**2)**16.5*(1.40256578435815e+54*cos(theta)**6 - 2.73227100848991e+53*cos(theta)**4 + 1.09290840339596e+52*cos(theta)**2 - 4.99044933057517e+49)*cos(33*phi)

#@torch.jit.script
def Yl39_m34(theta, phi):
    return 5.80971547822379e-52*(1.0 - cos(theta)**2)**17*(8.41539470614891e+54*cos(theta)**5 - 1.09290840339596e+54*cos(theta)**3 + 2.18581680679192e+52*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl39_m35(theta, phi):
    return 3.02032725709922e-53*(1.0 - cos(theta)**2)**17.5*(4.20769735307446e+55*cos(theta)**4 - 3.27872521018789e+54*cos(theta)**2 + 2.18581680679192e+52)*cos(35*phi)

#@torch.jit.script
def Yl39_m36(theta, phi):
    return 1.743786754927e-54*(1.0 - cos(theta)**2)**18*(1.68307894122978e+56*cos(theta)**3 - 6.55745042037577e+54*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl39_m37(theta, phi):
    return 1.15485099036113e-55*(1.0 - cos(theta)**2)**18.5*(5.04923682368935e+56*cos(theta)**2 - 6.55745042037577e+54)*cos(37*phi)

#@torch.jit.script
def Yl39_m38(theta, phi):
    return 9.39769459334552*(1.0 - cos(theta)**2)**19*cos(38*phi)*cos(theta)

#@torch.jit.script
def Yl39_m39(theta, phi):
    return 1.064079376195*(1.0 - cos(theta)**2)**19.5*cos(39*phi)

#@torch.jit.script
def Yl40_m_minus_40(theta, phi):
    return 1.07070921838241*(1.0 - cos(theta)**2)**20*sin(40*phi)

#@torch.jit.script
def Yl40_m_minus_39(theta, phi):
    return 9.57671438575497*(1.0 - cos(theta)**2)**19.5*sin(39*phi)*cos(theta)

#@torch.jit.script
def Yl40_m_minus_38(theta, phi):
    return 1.50890622763283e-57*(1.0 - cos(theta)**2)**19*(3.98889709071458e+58*cos(theta)**2 - 5.04923682368935e+56)*sin(38*phi)

#@torch.jit.script
def Yl40_m_minus_37(theta, phi):
    return 2.30818268966444e-56*(1.0 - cos(theta)**2)**18.5*(1.32963236357153e+58*cos(theta)**3 - 5.04923682368935e+56*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl40_m_minus_36(theta, phi):
    return 4.05084418028009e-55*(1.0 - cos(theta)**2)**18*(3.32408090892882e+57*cos(theta)**4 - 2.52461841184467e+56*cos(theta)**2 + 1.63936260509394e+54)*sin(36*phi)

#@torch.jit.script
def Yl40_m_minus_35(theta, phi):
    return 7.89654902961126e-54*(1.0 - cos(theta)**2)**17.5*(6.64816181785764e+56*cos(theta)**5 - 8.41539470614891e+55*cos(theta)**3 + 1.63936260509394e+54*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl40_m_minus_34(theta, phi):
    return 1.67511101004305e-52*(1.0 - cos(theta)**2)**17*(1.10802696964294e+56*cos(theta)**6 - 2.10384867653723e+55*cos(theta)**4 + 8.19681302546972e+53*cos(theta)**2 - 3.64302801131987e+51)*sin(34*phi)

#@torch.jit.script
def Yl40_m_minus_33(theta, phi):
    return 3.81248789127407e-51*(1.0 - cos(theta)**2)**16.5*(1.58289567091849e+55*cos(theta)**7 - 4.20769735307446e+54*cos(theta)**5 + 2.73227100848991e+53*cos(theta)**3 - 3.64302801131987e+51*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl40_m_minus_32(theta, phi):
    return 9.21329329280745e-50*(1.0 - cos(theta)**2)**16*(1.97861958864811e+54*cos(theta)**8 - 7.01282892179076e+53*cos(theta)**6 + 6.83067752122477e+52*cos(theta)**4 - 1.82151400565994e+51*cos(theta)**2 + 6.23806166321896e+48)*sin(32*phi)

#@torch.jit.script
def Yl40_m_minus_31(theta, phi):
    return 2.34532157918569e-48*(1.0 - cos(theta)**2)**15.5*(2.19846620960901e+53*cos(theta)**9 - 1.00183270311297e+53*cos(theta)**7 + 1.36613550424495e+52*cos(theta)**5 - 6.07171335219979e+50*cos(theta)**3 + 6.23806166321896e+48*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl40_m_minus_30(theta, phi):
    return 6.24930288108503e-47*(1.0 - cos(theta)**2)**15*(2.19846620960901e+52*cos(theta)**10 - 1.25229087889121e+52*cos(theta)**8 + 2.27689250707492e+51*cos(theta)**6 - 1.51792833804995e+50*cos(theta)**4 + 3.11903083160948e+48*cos(theta)**2 - 8.78600234256192e+45)*sin(30*phi)

#@torch.jit.script
def Yl40_m_minus_29(theta, phi):
    return 1.73411117304064e-45*(1.0 - cos(theta)**2)**14.5*(1.9986056450991e+51*cos(theta)**11 - 1.39143430987912e+51*cos(theta)**9 + 3.2527035815356e+50*cos(theta)**7 - 3.0358566760999e+49*cos(theta)**5 + 1.03967694386983e+48*cos(theta)**3 - 8.78600234256192e+45*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl40_m_minus_28(theta, phi):
    return 4.98990301715827e-44*(1.0 - cos(theta)**2)**14*(1.66550470424925e+50*cos(theta)**12 - 1.39143430987912e+50*cos(theta)**10 + 4.0658794769195e+49*cos(theta)**8 - 5.05976112683316e+48*cos(theta)**6 + 2.59919235967457e+47*cos(theta)**4 - 4.39300117128096e+45*cos(theta)**2 + 1.06111139402922e+43)*sin(28*phi)

#@torch.jit.script
def Yl40_m_minus_27(theta, phi):
    return 1.48360482591054e-42*(1.0 - cos(theta)**2)**13.5*(1.28115746480711e+49*cos(theta)**13 - 1.26494028170829e+49*cos(theta)**11 + 4.51764386324389e+48*cos(theta)**9 - 7.22823018119023e+47*cos(theta)**7 + 5.19838471934914e+46*cos(theta)**5 - 1.46433372376032e+45*cos(theta)**3 + 1.06111139402922e+43*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl40_m_minus_26(theta, phi):
    return 4.54380470106078e-41*(1.0 - cos(theta)**2)**13*(9.15112474862224e+47*cos(theta)**14 - 1.05411690142357e+48*cos(theta)**12 + 4.51764386324389e+47*cos(theta)**10 - 9.03528772648778e+46*cos(theta)**8 + 8.66397453224856e+45*cos(theta)**6 - 3.6608343094008e+44*cos(theta)**4 + 5.30555697014609e+42*cos(theta)**2 - 1.13124882092667e+40)*sin(26*phi)

#@torch.jit.script
def Yl40_m_minus_25(theta, phi):
    return 1.4296747724489e-39*(1.0 - cos(theta)**2)**12.5*(6.10074983241483e+46*cos(theta)**15 - 8.10859154941211e+46*cos(theta)**13 + 4.10694896658536e+46*cos(theta)**11 - 1.00392085849864e+46*cos(theta)**9 + 1.23771064746408e+45*cos(theta)**7 - 7.3216686188016e+43*cos(theta)**5 + 1.7685189900487e+42*cos(theta)**3 - 1.13124882092667e+40*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl40_m_minus_24(theta, phi):
    return 4.61056260468926e-38*(1.0 - cos(theta)**2)**12*(3.81296864525927e+45*cos(theta)**16 - 5.79185110672294e+45*cos(theta)**14 + 3.42245747215446e+45*cos(theta)**12 - 1.00392085849864e+45*cos(theta)**10 + 1.5471383093301e+44*cos(theta)**8 - 1.2202781031336e+43*cos(theta)**6 + 4.42129747512174e+41*cos(theta)**4 - 5.65624410463335e+39*cos(theta)**2 + 1.08773925089103e+37)*sin(24*phi)

#@torch.jit.script
def Yl40_m_minus_23(theta, phi):
    return 1.52078692901253e-36*(1.0 - cos(theta)**2)**11.5*(2.24292273250545e+44*cos(theta)**17 - 3.86123407114863e+44*cos(theta)**15 + 2.63265959396497e+44*cos(theta)**13 - 9.12655325907857e+43*cos(theta)**11 + 1.71904256592233e+43*cos(theta)**9 - 1.743254433048e+42*cos(theta)**7 + 8.84259495024348e+40*cos(theta)**5 - 1.88541470154445e+39*cos(theta)**3 + 1.08773925089103e+37*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl40_m_minus_22(theta, phi):
    return 5.12123728198411e-35*(1.0 - cos(theta)**2)**11*(1.24606818472525e+43*cos(theta)**18 - 2.41327129446789e+43*cos(theta)**16 + 1.88047113854641e+43*cos(theta)**14 - 7.60546104923214e+42*cos(theta)**12 + 1.71904256592233e+42*cos(theta)**10 - 2.17906804131e+41*cos(theta)**8 + 1.47376582504058e+40*cos(theta)**6 - 4.71353675386113e+38*cos(theta)**4 + 5.43869625445515e+36*cos(theta)**2 - 9.59205688616428e+33)*sin(22*phi)

#@torch.jit.script
def Yl40_m_minus_21(theta, phi):
    return 1.75771129567675e-33*(1.0 - cos(theta)**2)**10.5*(6.55825360381711e+41*cos(theta)**19 - 1.41957134968699e+42*cos(theta)**17 + 1.25364742569761e+42*cos(theta)**15 - 5.85035465325549e+41*cos(theta)**13 + 1.5627659690203e+41*cos(theta)**11 - 2.42118671256667e+40*cos(theta)**9 + 2.10537975005797e+39*cos(theta)**7 - 9.42707350772226e+37*cos(theta)**5 + 1.81289875148505e+36*cos(theta)**3 - 9.59205688616428e+33*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl40_m_minus_20(theta, phi):
    return 6.13942161666598e-32*(1.0 - cos(theta)**2)**10*(3.27912680190856e+40*cos(theta)**20 - 7.88650749826108e+40*cos(theta)**18 + 7.83529641061004e+40*cos(theta)**16 - 4.17882475232535e+40*cos(theta)**14 + 1.30230497418359e+40*cos(theta)**12 - 2.42118671256667e+39*cos(theta)**10 + 2.63172468757246e+38*cos(theta)**8 - 1.57117891795371e+37*cos(theta)**6 + 4.53224687871262e+35*cos(theta)**4 - 4.79602844308214e+33*cos(theta)**2 + 7.86234170997073e+30)*sin(20*phi)

#@torch.jit.script
def Yl40_m_minus_19(theta, phi):
    return 2.17927848637694e-30*(1.0 - cos(theta)**2)**9.5*(1.56148895328979e+39*cos(theta)**21 - 4.15079342013741e+39*cos(theta)**19 + 4.60899788859414e+39*cos(theta)**17 - 2.7858831682169e+39*cos(theta)**15 + 1.0017730570643e+39*cos(theta)**13 - 2.20107882960606e+38*cos(theta)**11 + 2.92413854174718e+37*cos(theta)**9 - 2.24454131136244e+36*cos(theta)**7 + 9.06449375742525e+34*cos(theta)**5 - 1.59867614769405e+33*cos(theta)**3 + 7.86234170997073e+30*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl40_m_minus_18(theta, phi):
    return 7.85145376863331e-29*(1.0 - cos(theta)**2)**9*(7.09767706040813e+37*cos(theta)**22 - 2.07539671006871e+38*cos(theta)**20 + 2.5605543825523e+38*cos(theta)**18 - 1.74117698013556e+38*cos(theta)**16 + 7.15552183617355e+37*cos(theta)**14 - 1.83423235800505e+37*cos(theta)**12 + 2.92413854174718e+36*cos(theta)**10 - 2.80567663920305e+35*cos(theta)**8 + 1.51074895957087e+34*cos(theta)**6 - 3.99669036923512e+32*cos(theta)**4 + 3.93117085498536e+30*cos(theta)**2 - 6.05727404466158e+27)*sin(18*phi)

#@torch.jit.script
def Yl40_m_minus_17(theta, phi):
    return 2.86766220567966e-27*(1.0 - cos(theta)**2)**8.5*(3.08594654800353e+36*cos(theta)**23 - 9.88284147651765e+36*cos(theta)**21 + 1.34766020134332e+37*cos(theta)**19 - 1.02422175302092e+37*cos(theta)**17 + 4.77034789078237e+36*cos(theta)**15 - 1.41094796769619e+36*cos(theta)**13 + 2.65830776522471e+35*cos(theta)**11 - 3.11741848800339e+34*cos(theta)**9 + 2.15821279938696e+33*cos(theta)**7 - 7.99338073847024e+31*cos(theta)**5 + 1.31039028499512e+30*cos(theta)**3 - 6.05727404466158e+27*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl40_m_minus_16(theta, phi):
    return 1.0606474233886e-25*(1.0 - cos(theta)**2)**8*(1.28581106166814e+35*cos(theta)**24 - 4.49220067114438e+35*cos(theta)**22 + 6.73830100671658e+35*cos(theta)**20 - 5.69012085011622e+35*cos(theta)**18 + 2.98146743173898e+35*cos(theta)**16 - 1.00781997692585e+35*cos(theta)**14 + 2.21525647102059e+34*cos(theta)**12 - 3.11741848800339e+33*cos(theta)**10 + 2.6977659992337e+32*cos(theta)**8 - 1.33223012307837e+31*cos(theta)**6 + 3.2759757124878e+29*cos(theta)**4 - 3.02863702233079e+27*cos(theta)**2 + 4.42783190399238e+24)*sin(16*phi)

#@torch.jit.script
def Yl40_m_minus_15(theta, phi):
    return 3.96857926648469e-24*(1.0 - cos(theta)**2)**7.5*(5.14324424667256e+33*cos(theta)**25 - 1.95313072658452e+34*cos(theta)**23 + 3.20871476510313e+34*cos(theta)**21 - 2.99480044742959e+34*cos(theta)**19 + 1.75380437161116e+34*cos(theta)**17 - 6.71879984617235e+33*cos(theta)**15 + 1.70404343924661e+33*cos(theta)**13 - 2.83401680727581e+32*cos(theta)**11 + 2.99751777692634e+31*cos(theta)**9 - 1.90318589011196e+30*cos(theta)**7 + 6.5519514249756e+28*cos(theta)**5 - 1.00954567411026e+27*cos(theta)**3 + 4.42783190399238e+24*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl40_m_minus_14(theta, phi):
    return 1.5007317746337e-22*(1.0 - cos(theta)**2)**7*(1.97817086410483e+32*cos(theta)**26 - 8.13804469410215e+32*cos(theta)**24 + 1.45850671141051e+33*cos(theta)**22 - 1.49740022371479e+33*cos(theta)**20 + 9.74335762006202e+32*cos(theta)**18 - 4.19924990385772e+32*cos(theta)**16 + 1.21717388517615e+32*cos(theta)**14 - 2.36168067272984e+31*cos(theta)**12 + 2.99751777692634e+30*cos(theta)**10 - 2.37898236263995e+29*cos(theta)**8 + 1.0919919041626e+28*cos(theta)**6 - 2.52386418527566e+26*cos(theta)**4 + 2.21391595199619e+24*cos(theta)**2 - 3.09638594684782e+21)*sin(14*phi)

#@torch.jit.script
def Yl40_m_minus_13(theta, phi):
    return 5.73035911876231e-21*(1.0 - cos(theta)**2)**6.5*(7.32655875594381e+30*cos(theta)**27 - 3.25521787764086e+31*cos(theta)**25 + 6.3413335278718e+31*cos(theta)**23 - 7.13047725578474e+31*cos(theta)**21 + 5.12808295792738e+31*cos(theta)**19 - 2.47014700226924e+31*cos(theta)**17 + 8.114492567841e+30*cos(theta)**15 - 1.81667744056142e+30*cos(theta)**13 + 2.72501616084213e+29*cos(theta)**11 - 2.64331373626661e+28*cos(theta)**9 + 1.559988434518e+27*cos(theta)**7 - 5.04772837055131e+25*cos(theta)**5 + 7.3797198399873e+23*cos(theta)**3 - 3.09638594684782e+21*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl40_m_minus_12(theta, phi):
    return 2.20749023089331e-19*(1.0 - cos(theta)**2)**6*(2.61662812712279e+29*cos(theta)**28 - 1.25200687601571e+30*cos(theta)**26 + 2.64222230327992e+30*cos(theta)**24 - 3.2411260253567e+30*cos(theta)**22 + 2.56404147896369e+30*cos(theta)**20 - 1.37230389014958e+30*cos(theta)**18 + 5.07155785490062e+29*cos(theta)**16 - 1.29762674325816e+29*cos(theta)**14 + 2.27084680070177e+28*cos(theta)**12 - 2.64331373626661e+27*cos(theta)**10 + 1.9499855431475e+26*cos(theta)**8 - 8.41288061758552e+24*cos(theta)**6 + 1.84492995999682e+23*cos(theta)**4 - 1.54819297342391e+21*cos(theta)**2 + 2.08651344127211e+18)*sin(12*phi)

#@torch.jit.script
def Yl40_m_minus_11(theta, phi):
    return 8.5723414445471e-18*(1.0 - cos(theta)**2)**5.5*(9.02285561076824e+27*cos(theta)**29 - 4.63706250376191e+28*cos(theta)**27 + 1.05688892131197e+29*cos(theta)**25 - 1.40918522841596e+29*cos(theta)**23 + 1.22097213283985e+29*cos(theta)**21 - 7.22265205341884e+28*cos(theta)**19 + 2.98326932641213e+28*cos(theta)**17 - 8.65084495505437e+27*cos(theta)**15 + 1.74680523130906e+27*cos(theta)**13 - 2.4030124875151e+26*cos(theta)**11 + 2.16665060349722e+25*cos(theta)**9 - 1.2018400882265e+24*cos(theta)**7 + 3.68985991999365e+22*cos(theta)**5 - 5.16064324474636e+20*cos(theta)**3 + 2.08651344127211e+18*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl40_m_minus_10(theta, phi):
    return 3.35308973781059e-16*(1.0 - cos(theta)**2)**5*(3.00761853692275e+26*cos(theta)**30 - 1.65609375134354e+27*cos(theta)**28 + 4.06495738966141e+27*cos(theta)**26 - 5.87160511839982e+27*cos(theta)**24 + 5.54987333109024e+27*cos(theta)**22 - 3.61132602670942e+27*cos(theta)**20 + 1.65737184800674e+27*cos(theta)**18 - 5.40677809690898e+26*cos(theta)**16 + 1.24771802236361e+26*cos(theta)**14 - 2.00251040626259e+25*cos(theta)**12 + 2.16665060349722e+24*cos(theta)**10 - 1.50230011028313e+23*cos(theta)**8 + 6.14976653332275e+21*cos(theta)**6 - 1.29016081118659e+20*cos(theta)**4 + 1.04325672063606e+18*cos(theta)**2 - 1.36373427534125e+15)*sin(10*phi)

#@torch.jit.script
def Yl40_m_minus_9(theta, phi):
    return 1.32011274988944e-14*(1.0 - cos(theta)**2)**4.5*(9.70199528039596e+24*cos(theta)**31 - 5.71066810808117e+25*cos(theta)**29 + 1.50553977394867e+26*cos(theta)**27 - 2.34864204735993e+26*cos(theta)**25 + 2.41298840482184e+26*cos(theta)**23 - 1.71967906033782e+26*cos(theta)**21 + 8.72300972635126e+25*cos(theta)**19 - 3.18045770406411e+25*cos(theta)**17 + 8.31812014909074e+24*cos(theta)**15 - 1.54039262020199e+24*cos(theta)**13 + 1.96968236681566e+23*cos(theta)**11 - 1.66922234475903e+22*cos(theta)**9 + 8.78538076188964e+20*cos(theta)**7 - 2.58032162237318e+19*cos(theta)**5 + 3.47752240212019e+17*cos(theta)**3 - 1.36373427534125e+15*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl40_m_minus_8(theta, phi):
    return 5.2273797933148e-13*(1.0 - cos(theta)**2)**4*(3.03187352512374e+23*cos(theta)**32 - 1.90355603602706e+24*cos(theta)**30 + 5.3769277641024e+24*cos(theta)**28 - 9.03323864369203e+24*cos(theta)**26 + 1.00541183534243e+25*cos(theta)**24 - 7.81672300153555e+24*cos(theta)**22 + 4.36150486317563e+24*cos(theta)**20 - 1.76692094670228e+24*cos(theta)**18 + 5.19882509318171e+23*cos(theta)**16 - 1.10028044300142e+23*cos(theta)**14 + 1.64140197234638e+22*cos(theta)**12 - 1.66922234475903e+21*cos(theta)**10 + 1.09817259523621e+20*cos(theta)**8 - 4.30053603728864e+18*cos(theta)**6 + 8.69380600530048e+16*cos(theta)**4 - 681867137670626.0*cos(theta)**2 + 869728491926.818)*sin(8*phi)

#@torch.jit.script
def Yl40_m_minus_7(theta, phi):
    return 2.08047088933329e-11*(1.0 - cos(theta)**2)**3.5*(9.18749553067799e+21*cos(theta)**33 - 6.14050334202276e+22*cos(theta)**31 + 1.85411302210427e+23*cos(theta)**29 - 3.34564394210816e+23*cos(theta)**27 + 4.02164734136974e+23*cos(theta)**25 - 3.39857521805893e+23*cos(theta)**23 + 2.07690707770268e+23*cos(theta)**21 - 9.29958393001201e+22*cos(theta)**19 + 3.05813240775395e+22*cos(theta)**17 - 7.3352029533428e+21*cos(theta)**15 + 1.26261690180491e+21*cos(theta)**13 - 1.51747485887185e+20*cos(theta)**11 + 1.22019177248467e+19*cos(theta)**9 - 6.14362291041234e+17*cos(theta)**7 + 1.7387612010601e+16*cos(theta)**5 - 227289045890209.0*cos(theta)**3 + 869728491926.818*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl40_m_minus_6(theta, phi):
    return 8.31668075372529e-10*(1.0 - cos(theta)**2)**3*(2.70220456784647e+20*cos(theta)**34 - 1.91890729438211e+21*cos(theta)**32 + 6.18037674034758e+21*cos(theta)**30 - 1.1948728364672e+22*cos(theta)**28 + 1.54678743898836e+22*cos(theta)**26 - 1.41607300752456e+22*cos(theta)**24 + 9.44048671683037e+21*cos(theta)**22 - 4.649791965006e+21*cos(theta)**20 + 1.69896244875219e+21*cos(theta)**18 - 4.58450184583925e+20*cos(theta)**16 + 9.01869215574935e+19*cos(theta)**14 - 1.26456238239321e+19*cos(theta)**12 + 1.22019177248467e+18*cos(theta)**10 - 7.67952863801542e+16*cos(theta)**8 + 2.89793533510016e+15*cos(theta)**6 - 56822261472552.1*cos(theta)**4 + 434864245963.409*cos(theta)**2 - 544260633.245819)*sin(6*phi)

#@torch.jit.script
def Yl40_m_minus_5(theta, phi):
    return 3.33705195947875e-8*(1.0 - cos(theta)**2)**2.5*(7.72058447956134e+18*cos(theta)**35 - 5.8148705890367e+19*cos(theta)**33 + 1.99366991624116e+20*cos(theta)**31 - 4.12025116023172e+20*cos(theta)**29 + 5.72884236662356e+20*cos(theta)**27 - 5.66429203009822e+20*cos(theta)**25 + 4.10455944210016e+20*cos(theta)**23 - 2.21418665000286e+20*cos(theta)**21 + 8.94190762501155e+19*cos(theta)**19 - 2.69676579167015e+19*cos(theta)**17 + 6.01246143716623e+18*cos(theta)**15 - 9.7274029414862e+17*cos(theta)**13 + 1.10926524771334e+17*cos(theta)**11 - 8.53280959779491e+15*cos(theta)**9 + 413990762157166.0*cos(theta)**7 - 11364452294510.4*cos(theta)**5 + 144954748654.47*cos(theta)**3 - 544260633.245819*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl40_m_minus_4(theta, phi):
    return 1.3431375046518e-6*(1.0 - cos(theta)**2)**2*(2.14460679987815e+17*cos(theta)**36 - 1.71025605559903e+18*cos(theta)**34 + 6.23021848825361e+18*cos(theta)**32 - 1.37341705341057e+19*cos(theta)**30 + 2.04601513093699e+19*cos(theta)**28 - 2.17857385773009e+19*cos(theta)**26 + 1.71023310087507e+19*cos(theta)**24 - 1.00644847727403e+19*cos(theta)**22 + 4.47095381250577e+18*cos(theta)**20 - 1.49820321759453e+18*cos(theta)**18 + 3.7577883982289e+17*cos(theta)**16 - 6.94814495820443e+16*cos(theta)**14 + 9.24387706427782e+15*cos(theta)**12 - 853280959779491.0*cos(theta)**10 + 51748845269645.7*cos(theta)**8 - 1894075382418.4*cos(theta)**6 + 36238687163.6174*cos(theta)**4 - 272130316.622909*cos(theta)**2 + 335963.353855444)*sin(4*phi)

#@torch.jit.script
def Yl40_m_minus_3(theta, phi):
    return 5.41935594348895e-5*(1.0 - cos(theta)**2)**1.5*(5.79623459426527e+15*cos(theta)**37 - 4.88644587314009e+16*cos(theta)**35 + 1.88794499644049e+17*cos(theta)**33 - 4.43037759164701e+17*cos(theta)**31 + 7.05522458943788e+17*cos(theta)**29 - 8.06879206566698e+17*cos(theta)**27 + 6.84093240350027e+17*cos(theta)**25 - 4.37586294466968e+17*cos(theta)**23 + 2.12902562500275e+17*cos(theta)**21 - 7.88528009260277e+16*cos(theta)**19 + 2.21046376366406e+16*cos(theta)**17 - 4.63209663880295e+15*cos(theta)**15 + 711067466482909.0*cos(theta)**13 - 77570996343590.1*cos(theta)**11 + 5749871696627.3*cos(theta)**9 - 270582197488.344*cos(theta)**7 + 7247737432.72349*cos(theta)**5 - 90710105.5409698*cos(theta)**3 + 335963.353855444*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl40_m_minus_2(theta, phi):
    return 0.00219065356430911*(1.0 - cos(theta)**2)*(152532489322770.0*cos(theta)**38 - 1.35734607587225e+15*cos(theta)**36 + 5.55277940129555e+15*cos(theta)**34 - 1.38449299738969e+16*cos(theta)**32 + 2.35174152981263e+16*cos(theta)**30 - 2.88171145202392e+16*cos(theta)**28 + 2.6311278475001e+16*cos(theta)**26 - 1.8232762269457e+16*cos(theta)**24 + 9.67738920455795e+15*cos(theta)**22 - 3.94264004630139e+15*cos(theta)**20 + 1.22803542425781e+15*cos(theta)**18 - 289506039925185.0*cos(theta)**16 + 50790533320207.8*cos(theta)**14 - 6464249695299.18*cos(theta)**12 + 574987169662.73*cos(theta)**10 - 33822774686.0429*cos(theta)**8 + 1207956238.78725*cos(theta)**6 - 22677526.3852425*cos(theta)**4 + 167981.676927722*cos(theta)**2 - 205.60792769611)*sin(2*phi)

#@torch.jit.script
def Yl40_m_minus_1(theta, phi):
    return 0.0886605969841593*(1.0 - cos(theta)**2)**0.5*(3911089469814.62*cos(theta)**39 - 36685029077628.3*cos(theta)**37 + 158650840037016.0*cos(theta)**35 - 419543332542331.0*cos(theta)**33 + 758626299939557.0*cos(theta)**31 - 993693604146180.0*cos(theta)**29 + 974491795370409.0*cos(theta)**27 - 729310490778280.0*cos(theta)**25 + 420756052372085.0*cos(theta)**23 - 187744764109590.0*cos(theta)**21 + 64633443381989.9*cos(theta)**19 - 17029767054422.6*cos(theta)**17 + 3386035554680.52*cos(theta)**15 - 497249976561.475*cos(theta)**13 + 52271560878.43*cos(theta)**11 - 3758086076.22699*cos(theta)**9 + 172565176.969607*cos(theta)**7 - 4535505.27704849*cos(theta)**5 + 55993.8923092406*cos(theta)**3 - 205.60792769611*cos(theta))*sin(phi)

#@torch.jit.script
def Yl40_m0(theta, phi):
    return 779875379101.005*cos(theta)**40 - 7700035388592.21*cos(theta)**38 + 35150161546625.5*cos(theta)**36 - 98420452330551.3*cos(theta)**34 + 189088608758354.0*cos(theta)**32 - 264191408293362.0*cos(theta)**30 + 277592421757518.0*cos(theta)**28 - 223731205595611.0*cos(theta)**26 + 139832003497257.0*cos(theta)**24 - 68066372072738.9*cos(theta)**22 + 25775954014430.6*cos(theta)**20 - 7546119048908.81*cos(theta)**18 + 1687947681992.76*cos(theta)**16 - 283291918656.128*cos(theta)**14 + 34743348514.4308*cos(theta)**12 - 2997465362.02932*cos(theta)**10 + 172048394.504234*cos(theta)**8 - 6029230.34558016*cos(theta)**6 + 111652.41380704*cos(theta)**4 - 819.968767248764*cos(theta)**2 + 0.999961911278981

#@torch.jit.script
def Yl40_m1(theta, phi):
    return 0.0886605969841593*(1.0 - cos(theta)**2)**0.5*(3911089469814.62*cos(theta)**39 - 36685029077628.3*cos(theta)**37 + 158650840037016.0*cos(theta)**35 - 419543332542331.0*cos(theta)**33 + 758626299939557.0*cos(theta)**31 - 993693604146180.0*cos(theta)**29 + 974491795370409.0*cos(theta)**27 - 729310490778280.0*cos(theta)**25 + 420756052372085.0*cos(theta)**23 - 187744764109590.0*cos(theta)**21 + 64633443381989.9*cos(theta)**19 - 17029767054422.6*cos(theta)**17 + 3386035554680.52*cos(theta)**15 - 497249976561.475*cos(theta)**13 + 52271560878.43*cos(theta)**11 - 3758086076.22699*cos(theta)**9 + 172565176.969607*cos(theta)**7 - 4535505.27704849*cos(theta)**5 + 55993.8923092406*cos(theta)**3 - 205.60792769611*cos(theta))*cos(phi)

#@torch.jit.script
def Yl40_m2(theta, phi):
    return 0.00219065356430911*(1.0 - cos(theta)**2)*(152532489322770.0*cos(theta)**38 - 1.35734607587225e+15*cos(theta)**36 + 5.55277940129555e+15*cos(theta)**34 - 1.38449299738969e+16*cos(theta)**32 + 2.35174152981263e+16*cos(theta)**30 - 2.88171145202392e+16*cos(theta)**28 + 2.6311278475001e+16*cos(theta)**26 - 1.8232762269457e+16*cos(theta)**24 + 9.67738920455795e+15*cos(theta)**22 - 3.94264004630139e+15*cos(theta)**20 + 1.22803542425781e+15*cos(theta)**18 - 289506039925185.0*cos(theta)**16 + 50790533320207.8*cos(theta)**14 - 6464249695299.18*cos(theta)**12 + 574987169662.73*cos(theta)**10 - 33822774686.0429*cos(theta)**8 + 1207956238.78725*cos(theta)**6 - 22677526.3852425*cos(theta)**4 + 167981.676927722*cos(theta)**2 - 205.60792769611)*cos(2*phi)

#@torch.jit.script
def Yl40_m3(theta, phi):
    return 5.41935594348895e-5*(1.0 - cos(theta)**2)**1.5*(5.79623459426527e+15*cos(theta)**37 - 4.88644587314009e+16*cos(theta)**35 + 1.88794499644049e+17*cos(theta)**33 - 4.43037759164701e+17*cos(theta)**31 + 7.05522458943788e+17*cos(theta)**29 - 8.06879206566698e+17*cos(theta)**27 + 6.84093240350027e+17*cos(theta)**25 - 4.37586294466968e+17*cos(theta)**23 + 2.12902562500275e+17*cos(theta)**21 - 7.88528009260277e+16*cos(theta)**19 + 2.21046376366406e+16*cos(theta)**17 - 4.63209663880295e+15*cos(theta)**15 + 711067466482909.0*cos(theta)**13 - 77570996343590.1*cos(theta)**11 + 5749871696627.3*cos(theta)**9 - 270582197488.344*cos(theta)**7 + 7247737432.72349*cos(theta)**5 - 90710105.5409698*cos(theta)**3 + 335963.353855444*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl40_m4(theta, phi):
    return 1.3431375046518e-6*(1.0 - cos(theta)**2)**2*(2.14460679987815e+17*cos(theta)**36 - 1.71025605559903e+18*cos(theta)**34 + 6.23021848825361e+18*cos(theta)**32 - 1.37341705341057e+19*cos(theta)**30 + 2.04601513093699e+19*cos(theta)**28 - 2.17857385773009e+19*cos(theta)**26 + 1.71023310087507e+19*cos(theta)**24 - 1.00644847727403e+19*cos(theta)**22 + 4.47095381250577e+18*cos(theta)**20 - 1.49820321759453e+18*cos(theta)**18 + 3.7577883982289e+17*cos(theta)**16 - 6.94814495820443e+16*cos(theta)**14 + 9.24387706427782e+15*cos(theta)**12 - 853280959779491.0*cos(theta)**10 + 51748845269645.7*cos(theta)**8 - 1894075382418.4*cos(theta)**6 + 36238687163.6174*cos(theta)**4 - 272130316.622909*cos(theta)**2 + 335963.353855444)*cos(4*phi)

#@torch.jit.script
def Yl40_m5(theta, phi):
    return 3.33705195947875e-8*(1.0 - cos(theta)**2)**2.5*(7.72058447956134e+18*cos(theta)**35 - 5.8148705890367e+19*cos(theta)**33 + 1.99366991624116e+20*cos(theta)**31 - 4.12025116023172e+20*cos(theta)**29 + 5.72884236662356e+20*cos(theta)**27 - 5.66429203009822e+20*cos(theta)**25 + 4.10455944210016e+20*cos(theta)**23 - 2.21418665000286e+20*cos(theta)**21 + 8.94190762501155e+19*cos(theta)**19 - 2.69676579167015e+19*cos(theta)**17 + 6.01246143716623e+18*cos(theta)**15 - 9.7274029414862e+17*cos(theta)**13 + 1.10926524771334e+17*cos(theta)**11 - 8.53280959779491e+15*cos(theta)**9 + 413990762157166.0*cos(theta)**7 - 11364452294510.4*cos(theta)**5 + 144954748654.47*cos(theta)**3 - 544260633.245819*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl40_m6(theta, phi):
    return 8.31668075372529e-10*(1.0 - cos(theta)**2)**3*(2.70220456784647e+20*cos(theta)**34 - 1.91890729438211e+21*cos(theta)**32 + 6.18037674034758e+21*cos(theta)**30 - 1.1948728364672e+22*cos(theta)**28 + 1.54678743898836e+22*cos(theta)**26 - 1.41607300752456e+22*cos(theta)**24 + 9.44048671683037e+21*cos(theta)**22 - 4.649791965006e+21*cos(theta)**20 + 1.69896244875219e+21*cos(theta)**18 - 4.58450184583925e+20*cos(theta)**16 + 9.01869215574935e+19*cos(theta)**14 - 1.26456238239321e+19*cos(theta)**12 + 1.22019177248467e+18*cos(theta)**10 - 7.67952863801542e+16*cos(theta)**8 + 2.89793533510016e+15*cos(theta)**6 - 56822261472552.1*cos(theta)**4 + 434864245963.409*cos(theta)**2 - 544260633.245819)*cos(6*phi)

#@torch.jit.script
def Yl40_m7(theta, phi):
    return 2.08047088933329e-11*(1.0 - cos(theta)**2)**3.5*(9.18749553067799e+21*cos(theta)**33 - 6.14050334202276e+22*cos(theta)**31 + 1.85411302210427e+23*cos(theta)**29 - 3.34564394210816e+23*cos(theta)**27 + 4.02164734136974e+23*cos(theta)**25 - 3.39857521805893e+23*cos(theta)**23 + 2.07690707770268e+23*cos(theta)**21 - 9.29958393001201e+22*cos(theta)**19 + 3.05813240775395e+22*cos(theta)**17 - 7.3352029533428e+21*cos(theta)**15 + 1.26261690180491e+21*cos(theta)**13 - 1.51747485887185e+20*cos(theta)**11 + 1.22019177248467e+19*cos(theta)**9 - 6.14362291041234e+17*cos(theta)**7 + 1.7387612010601e+16*cos(theta)**5 - 227289045890209.0*cos(theta)**3 + 869728491926.818*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl40_m8(theta, phi):
    return 5.2273797933148e-13*(1.0 - cos(theta)**2)**4*(3.03187352512374e+23*cos(theta)**32 - 1.90355603602706e+24*cos(theta)**30 + 5.3769277641024e+24*cos(theta)**28 - 9.03323864369203e+24*cos(theta)**26 + 1.00541183534243e+25*cos(theta)**24 - 7.81672300153555e+24*cos(theta)**22 + 4.36150486317563e+24*cos(theta)**20 - 1.76692094670228e+24*cos(theta)**18 + 5.19882509318171e+23*cos(theta)**16 - 1.10028044300142e+23*cos(theta)**14 + 1.64140197234638e+22*cos(theta)**12 - 1.66922234475903e+21*cos(theta)**10 + 1.09817259523621e+20*cos(theta)**8 - 4.30053603728864e+18*cos(theta)**6 + 8.69380600530048e+16*cos(theta)**4 - 681867137670626.0*cos(theta)**2 + 869728491926.818)*cos(8*phi)

#@torch.jit.script
def Yl40_m9(theta, phi):
    return 1.32011274988944e-14*(1.0 - cos(theta)**2)**4.5*(9.70199528039596e+24*cos(theta)**31 - 5.71066810808117e+25*cos(theta)**29 + 1.50553977394867e+26*cos(theta)**27 - 2.34864204735993e+26*cos(theta)**25 + 2.41298840482184e+26*cos(theta)**23 - 1.71967906033782e+26*cos(theta)**21 + 8.72300972635126e+25*cos(theta)**19 - 3.18045770406411e+25*cos(theta)**17 + 8.31812014909074e+24*cos(theta)**15 - 1.54039262020199e+24*cos(theta)**13 + 1.96968236681566e+23*cos(theta)**11 - 1.66922234475903e+22*cos(theta)**9 + 8.78538076188964e+20*cos(theta)**7 - 2.58032162237318e+19*cos(theta)**5 + 3.47752240212019e+17*cos(theta)**3 - 1.36373427534125e+15*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl40_m10(theta, phi):
    return 3.35308973781059e-16*(1.0 - cos(theta)**2)**5*(3.00761853692275e+26*cos(theta)**30 - 1.65609375134354e+27*cos(theta)**28 + 4.06495738966141e+27*cos(theta)**26 - 5.87160511839982e+27*cos(theta)**24 + 5.54987333109024e+27*cos(theta)**22 - 3.61132602670942e+27*cos(theta)**20 + 1.65737184800674e+27*cos(theta)**18 - 5.40677809690898e+26*cos(theta)**16 + 1.24771802236361e+26*cos(theta)**14 - 2.00251040626259e+25*cos(theta)**12 + 2.16665060349722e+24*cos(theta)**10 - 1.50230011028313e+23*cos(theta)**8 + 6.14976653332275e+21*cos(theta)**6 - 1.29016081118659e+20*cos(theta)**4 + 1.04325672063606e+18*cos(theta)**2 - 1.36373427534125e+15)*cos(10*phi)

#@torch.jit.script
def Yl40_m11(theta, phi):
    return 8.5723414445471e-18*(1.0 - cos(theta)**2)**5.5*(9.02285561076824e+27*cos(theta)**29 - 4.63706250376191e+28*cos(theta)**27 + 1.05688892131197e+29*cos(theta)**25 - 1.40918522841596e+29*cos(theta)**23 + 1.22097213283985e+29*cos(theta)**21 - 7.22265205341884e+28*cos(theta)**19 + 2.98326932641213e+28*cos(theta)**17 - 8.65084495505437e+27*cos(theta)**15 + 1.74680523130906e+27*cos(theta)**13 - 2.4030124875151e+26*cos(theta)**11 + 2.16665060349722e+25*cos(theta)**9 - 1.2018400882265e+24*cos(theta)**7 + 3.68985991999365e+22*cos(theta)**5 - 5.16064324474636e+20*cos(theta)**3 + 2.08651344127211e+18*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl40_m12(theta, phi):
    return 2.20749023089331e-19*(1.0 - cos(theta)**2)**6*(2.61662812712279e+29*cos(theta)**28 - 1.25200687601571e+30*cos(theta)**26 + 2.64222230327992e+30*cos(theta)**24 - 3.2411260253567e+30*cos(theta)**22 + 2.56404147896369e+30*cos(theta)**20 - 1.37230389014958e+30*cos(theta)**18 + 5.07155785490062e+29*cos(theta)**16 - 1.29762674325816e+29*cos(theta)**14 + 2.27084680070177e+28*cos(theta)**12 - 2.64331373626661e+27*cos(theta)**10 + 1.9499855431475e+26*cos(theta)**8 - 8.41288061758552e+24*cos(theta)**6 + 1.84492995999682e+23*cos(theta)**4 - 1.54819297342391e+21*cos(theta)**2 + 2.08651344127211e+18)*cos(12*phi)

#@torch.jit.script
def Yl40_m13(theta, phi):
    return 5.73035911876231e-21*(1.0 - cos(theta)**2)**6.5*(7.32655875594381e+30*cos(theta)**27 - 3.25521787764086e+31*cos(theta)**25 + 6.3413335278718e+31*cos(theta)**23 - 7.13047725578474e+31*cos(theta)**21 + 5.12808295792738e+31*cos(theta)**19 - 2.47014700226924e+31*cos(theta)**17 + 8.114492567841e+30*cos(theta)**15 - 1.81667744056142e+30*cos(theta)**13 + 2.72501616084213e+29*cos(theta)**11 - 2.64331373626661e+28*cos(theta)**9 + 1.559988434518e+27*cos(theta)**7 - 5.04772837055131e+25*cos(theta)**5 + 7.3797198399873e+23*cos(theta)**3 - 3.09638594684782e+21*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl40_m14(theta, phi):
    return 1.5007317746337e-22*(1.0 - cos(theta)**2)**7*(1.97817086410483e+32*cos(theta)**26 - 8.13804469410215e+32*cos(theta)**24 + 1.45850671141051e+33*cos(theta)**22 - 1.49740022371479e+33*cos(theta)**20 + 9.74335762006202e+32*cos(theta)**18 - 4.19924990385772e+32*cos(theta)**16 + 1.21717388517615e+32*cos(theta)**14 - 2.36168067272984e+31*cos(theta)**12 + 2.99751777692634e+30*cos(theta)**10 - 2.37898236263995e+29*cos(theta)**8 + 1.0919919041626e+28*cos(theta)**6 - 2.52386418527566e+26*cos(theta)**4 + 2.21391595199619e+24*cos(theta)**2 - 3.09638594684782e+21)*cos(14*phi)

#@torch.jit.script
def Yl40_m15(theta, phi):
    return 3.96857926648469e-24*(1.0 - cos(theta)**2)**7.5*(5.14324424667256e+33*cos(theta)**25 - 1.95313072658452e+34*cos(theta)**23 + 3.20871476510313e+34*cos(theta)**21 - 2.99480044742959e+34*cos(theta)**19 + 1.75380437161116e+34*cos(theta)**17 - 6.71879984617235e+33*cos(theta)**15 + 1.70404343924661e+33*cos(theta)**13 - 2.83401680727581e+32*cos(theta)**11 + 2.99751777692634e+31*cos(theta)**9 - 1.90318589011196e+30*cos(theta)**7 + 6.5519514249756e+28*cos(theta)**5 - 1.00954567411026e+27*cos(theta)**3 + 4.42783190399238e+24*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl40_m16(theta, phi):
    return 1.0606474233886e-25*(1.0 - cos(theta)**2)**8*(1.28581106166814e+35*cos(theta)**24 - 4.49220067114438e+35*cos(theta)**22 + 6.73830100671658e+35*cos(theta)**20 - 5.69012085011622e+35*cos(theta)**18 + 2.98146743173898e+35*cos(theta)**16 - 1.00781997692585e+35*cos(theta)**14 + 2.21525647102059e+34*cos(theta)**12 - 3.11741848800339e+33*cos(theta)**10 + 2.6977659992337e+32*cos(theta)**8 - 1.33223012307837e+31*cos(theta)**6 + 3.2759757124878e+29*cos(theta)**4 - 3.02863702233079e+27*cos(theta)**2 + 4.42783190399238e+24)*cos(16*phi)

#@torch.jit.script
def Yl40_m17(theta, phi):
    return 2.86766220567966e-27*(1.0 - cos(theta)**2)**8.5*(3.08594654800353e+36*cos(theta)**23 - 9.88284147651765e+36*cos(theta)**21 + 1.34766020134332e+37*cos(theta)**19 - 1.02422175302092e+37*cos(theta)**17 + 4.77034789078237e+36*cos(theta)**15 - 1.41094796769619e+36*cos(theta)**13 + 2.65830776522471e+35*cos(theta)**11 - 3.11741848800339e+34*cos(theta)**9 + 2.15821279938696e+33*cos(theta)**7 - 7.99338073847024e+31*cos(theta)**5 + 1.31039028499512e+30*cos(theta)**3 - 6.05727404466158e+27*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl40_m18(theta, phi):
    return 7.85145376863331e-29*(1.0 - cos(theta)**2)**9*(7.09767706040813e+37*cos(theta)**22 - 2.07539671006871e+38*cos(theta)**20 + 2.5605543825523e+38*cos(theta)**18 - 1.74117698013556e+38*cos(theta)**16 + 7.15552183617355e+37*cos(theta)**14 - 1.83423235800505e+37*cos(theta)**12 + 2.92413854174718e+36*cos(theta)**10 - 2.80567663920305e+35*cos(theta)**8 + 1.51074895957087e+34*cos(theta)**6 - 3.99669036923512e+32*cos(theta)**4 + 3.93117085498536e+30*cos(theta)**2 - 6.05727404466158e+27)*cos(18*phi)

#@torch.jit.script
def Yl40_m19(theta, phi):
    return 2.17927848637694e-30*(1.0 - cos(theta)**2)**9.5*(1.56148895328979e+39*cos(theta)**21 - 4.15079342013741e+39*cos(theta)**19 + 4.60899788859414e+39*cos(theta)**17 - 2.7858831682169e+39*cos(theta)**15 + 1.0017730570643e+39*cos(theta)**13 - 2.20107882960606e+38*cos(theta)**11 + 2.92413854174718e+37*cos(theta)**9 - 2.24454131136244e+36*cos(theta)**7 + 9.06449375742525e+34*cos(theta)**5 - 1.59867614769405e+33*cos(theta)**3 + 7.86234170997073e+30*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl40_m20(theta, phi):
    return 6.13942161666598e-32*(1.0 - cos(theta)**2)**10*(3.27912680190856e+40*cos(theta)**20 - 7.88650749826108e+40*cos(theta)**18 + 7.83529641061004e+40*cos(theta)**16 - 4.17882475232535e+40*cos(theta)**14 + 1.30230497418359e+40*cos(theta)**12 - 2.42118671256667e+39*cos(theta)**10 + 2.63172468757246e+38*cos(theta)**8 - 1.57117891795371e+37*cos(theta)**6 + 4.53224687871262e+35*cos(theta)**4 - 4.79602844308214e+33*cos(theta)**2 + 7.86234170997073e+30)*cos(20*phi)

#@torch.jit.script
def Yl40_m21(theta, phi):
    return 1.75771129567675e-33*(1.0 - cos(theta)**2)**10.5*(6.55825360381711e+41*cos(theta)**19 - 1.41957134968699e+42*cos(theta)**17 + 1.25364742569761e+42*cos(theta)**15 - 5.85035465325549e+41*cos(theta)**13 + 1.5627659690203e+41*cos(theta)**11 - 2.42118671256667e+40*cos(theta)**9 + 2.10537975005797e+39*cos(theta)**7 - 9.42707350772226e+37*cos(theta)**5 + 1.81289875148505e+36*cos(theta)**3 - 9.59205688616428e+33*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl40_m22(theta, phi):
    return 5.12123728198411e-35*(1.0 - cos(theta)**2)**11*(1.24606818472525e+43*cos(theta)**18 - 2.41327129446789e+43*cos(theta)**16 + 1.88047113854641e+43*cos(theta)**14 - 7.60546104923214e+42*cos(theta)**12 + 1.71904256592233e+42*cos(theta)**10 - 2.17906804131e+41*cos(theta)**8 + 1.47376582504058e+40*cos(theta)**6 - 4.71353675386113e+38*cos(theta)**4 + 5.43869625445515e+36*cos(theta)**2 - 9.59205688616428e+33)*cos(22*phi)

#@torch.jit.script
def Yl40_m23(theta, phi):
    return 1.52078692901253e-36*(1.0 - cos(theta)**2)**11.5*(2.24292273250545e+44*cos(theta)**17 - 3.86123407114863e+44*cos(theta)**15 + 2.63265959396497e+44*cos(theta)**13 - 9.12655325907857e+43*cos(theta)**11 + 1.71904256592233e+43*cos(theta)**9 - 1.743254433048e+42*cos(theta)**7 + 8.84259495024348e+40*cos(theta)**5 - 1.88541470154445e+39*cos(theta)**3 + 1.08773925089103e+37*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl40_m24(theta, phi):
    return 4.61056260468926e-38*(1.0 - cos(theta)**2)**12*(3.81296864525927e+45*cos(theta)**16 - 5.79185110672294e+45*cos(theta)**14 + 3.42245747215446e+45*cos(theta)**12 - 1.00392085849864e+45*cos(theta)**10 + 1.5471383093301e+44*cos(theta)**8 - 1.2202781031336e+43*cos(theta)**6 + 4.42129747512174e+41*cos(theta)**4 - 5.65624410463335e+39*cos(theta)**2 + 1.08773925089103e+37)*cos(24*phi)

#@torch.jit.script
def Yl40_m25(theta, phi):
    return 1.4296747724489e-39*(1.0 - cos(theta)**2)**12.5*(6.10074983241483e+46*cos(theta)**15 - 8.10859154941211e+46*cos(theta)**13 + 4.10694896658536e+46*cos(theta)**11 - 1.00392085849864e+46*cos(theta)**9 + 1.23771064746408e+45*cos(theta)**7 - 7.3216686188016e+43*cos(theta)**5 + 1.7685189900487e+42*cos(theta)**3 - 1.13124882092667e+40*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl40_m26(theta, phi):
    return 4.54380470106078e-41*(1.0 - cos(theta)**2)**13*(9.15112474862224e+47*cos(theta)**14 - 1.05411690142357e+48*cos(theta)**12 + 4.51764386324389e+47*cos(theta)**10 - 9.03528772648778e+46*cos(theta)**8 + 8.66397453224856e+45*cos(theta)**6 - 3.6608343094008e+44*cos(theta)**4 + 5.30555697014609e+42*cos(theta)**2 - 1.13124882092667e+40)*cos(26*phi)

#@torch.jit.script
def Yl40_m27(theta, phi):
    return 1.48360482591054e-42*(1.0 - cos(theta)**2)**13.5*(1.28115746480711e+49*cos(theta)**13 - 1.26494028170829e+49*cos(theta)**11 + 4.51764386324389e+48*cos(theta)**9 - 7.22823018119023e+47*cos(theta)**7 + 5.19838471934914e+46*cos(theta)**5 - 1.46433372376032e+45*cos(theta)**3 + 1.06111139402922e+43*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl40_m28(theta, phi):
    return 4.98990301715827e-44*(1.0 - cos(theta)**2)**14*(1.66550470424925e+50*cos(theta)**12 - 1.39143430987912e+50*cos(theta)**10 + 4.0658794769195e+49*cos(theta)**8 - 5.05976112683316e+48*cos(theta)**6 + 2.59919235967457e+47*cos(theta)**4 - 4.39300117128096e+45*cos(theta)**2 + 1.06111139402922e+43)*cos(28*phi)

#@torch.jit.script
def Yl40_m29(theta, phi):
    return 1.73411117304064e-45*(1.0 - cos(theta)**2)**14.5*(1.9986056450991e+51*cos(theta)**11 - 1.39143430987912e+51*cos(theta)**9 + 3.2527035815356e+50*cos(theta)**7 - 3.0358566760999e+49*cos(theta)**5 + 1.03967694386983e+48*cos(theta)**3 - 8.78600234256192e+45*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl40_m30(theta, phi):
    return 6.24930288108503e-47*(1.0 - cos(theta)**2)**15*(2.19846620960901e+52*cos(theta)**10 - 1.25229087889121e+52*cos(theta)**8 + 2.27689250707492e+51*cos(theta)**6 - 1.51792833804995e+50*cos(theta)**4 + 3.11903083160948e+48*cos(theta)**2 - 8.78600234256192e+45)*cos(30*phi)

#@torch.jit.script
def Yl40_m31(theta, phi):
    return 2.34532157918569e-48*(1.0 - cos(theta)**2)**15.5*(2.19846620960901e+53*cos(theta)**9 - 1.00183270311297e+53*cos(theta)**7 + 1.36613550424495e+52*cos(theta)**5 - 6.07171335219979e+50*cos(theta)**3 + 6.23806166321896e+48*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl40_m32(theta, phi):
    return 9.21329329280745e-50*(1.0 - cos(theta)**2)**16*(1.97861958864811e+54*cos(theta)**8 - 7.01282892179076e+53*cos(theta)**6 + 6.83067752122477e+52*cos(theta)**4 - 1.82151400565994e+51*cos(theta)**2 + 6.23806166321896e+48)*cos(32*phi)

#@torch.jit.script
def Yl40_m33(theta, phi):
    return 3.81248789127407e-51*(1.0 - cos(theta)**2)**16.5*(1.58289567091849e+55*cos(theta)**7 - 4.20769735307446e+54*cos(theta)**5 + 2.73227100848991e+53*cos(theta)**3 - 3.64302801131987e+51*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl40_m34(theta, phi):
    return 1.67511101004305e-52*(1.0 - cos(theta)**2)**17*(1.10802696964294e+56*cos(theta)**6 - 2.10384867653723e+55*cos(theta)**4 + 8.19681302546972e+53*cos(theta)**2 - 3.64302801131987e+51)*cos(34*phi)

#@torch.jit.script
def Yl40_m35(theta, phi):
    return 7.89654902961126e-54*(1.0 - cos(theta)**2)**17.5*(6.64816181785764e+56*cos(theta)**5 - 8.41539470614891e+55*cos(theta)**3 + 1.63936260509394e+54*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl40_m36(theta, phi):
    return 4.05084418028009e-55*(1.0 - cos(theta)**2)**18*(3.32408090892882e+57*cos(theta)**4 - 2.52461841184467e+56*cos(theta)**2 + 1.63936260509394e+54)*cos(36*phi)

#@torch.jit.script
def Yl40_m37(theta, phi):
    return 2.30818268966444e-56*(1.0 - cos(theta)**2)**18.5*(1.32963236357153e+58*cos(theta)**3 - 5.04923682368935e+56*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl40_m38(theta, phi):
    return 1.50890622763283e-57*(1.0 - cos(theta)**2)**19*(3.98889709071458e+58*cos(theta)**2 - 5.04923682368935e+56)*cos(38*phi)

#@torch.jit.script
def Yl40_m39(theta, phi):
    return 9.57671438575497*(1.0 - cos(theta)**2)**19.5*cos(39*phi)*cos(theta)

#@torch.jit.script
def Yl40_m40(theta, phi):
    return 1.07070921838241*(1.0 - cos(theta)**2)**20*cos(40*phi)

#@torch.jit.script
def Yl41_m_minus_41(theta, phi):
    return 1.07721814896289*(1.0 - cos(theta)**2)**20.5*sin(41*phi)

#@torch.jit.script
def Yl41_m_minus_40(theta, phi):
    return 9.75462521665048*(1.0 - cos(theta)**2)**20*sin(40*phi)*cos(theta)

#@torch.jit.script
def Yl41_m_minus_39(theta, phi):
    return 1.92132241117284e-59*(1.0 - cos(theta)**2)**19.5*(3.23100664347881e+60*cos(theta)**2 - 3.98889709071458e+58)*sin(39*phi)

#@torch.jit.script
def Yl41_m_minus_38(theta, phi):
    return 2.97649988046699e-58*(1.0 - cos(theta)**2)**19*(1.07700221449294e+60*cos(theta)**3 - 3.98889709071458e+58*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl41_m_minus_37(theta, phi):
    return 5.29114192414144e-57*(1.0 - cos(theta)**2)**18.5*(2.69250553623234e+59*cos(theta)**4 - 1.99444854535729e+58*cos(theta)**2 + 1.26230920592234e+56)*sin(37*phi)

#@torch.jit.script
def Yl41_m_minus_36(theta, phi):
    return 1.04491680606395e-55*(1.0 - cos(theta)**2)**18*(5.38501107246469e+58*cos(theta)**5 - 6.64816181785764e+57*cos(theta)**3 + 1.26230920592234e+56*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl41_m_minus_35(theta, phi):
    return 2.24596354110399e-54*(1.0 - cos(theta)**2)**17.5*(8.97501845410781e+57*cos(theta)**6 - 1.66204045446441e+57*cos(theta)**4 + 6.31154602961168e+55*cos(theta)**2 - 2.73227100848991e+53)*sin(35*phi)

#@torch.jit.script
def Yl41_m_minus_34(theta, phi):
    return 5.18034302462604e-53*(1.0 - cos(theta)**2)**17*(1.28214549344397e+57*cos(theta)**7 - 3.32408090892882e+56*cos(theta)**5 + 2.10384867653723e+55*cos(theta)**3 - 2.73227100848991e+53*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl41_m_minus_33(theta, phi):
    return 1.26891971029199e-51*(1.0 - cos(theta)**2)**16.5*(1.60268186680497e+56*cos(theta)**8 - 5.5401348482147e+55*cos(theta)**6 + 5.25962169134307e+54*cos(theta)**4 - 1.36613550424495e+53*cos(theta)**2 + 4.55378501414984e+50)*sin(33*phi)

#@torch.jit.script
def Yl41_m_minus_32(theta, phi):
    return 3.27469802570795e-50*(1.0 - cos(theta)**2)**16*(1.7807576297833e+55*cos(theta)**9 - 7.91447835459243e+54*cos(theta)**7 + 1.05192433826861e+54*cos(theta)**5 - 4.55378501414984e+52*cos(theta)**3 + 4.55378501414984e+50*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl41_m_minus_31(theta, phi):
    return 8.84774684679108e-49*(1.0 - cos(theta)**2)**15.5*(1.7807576297833e+54*cos(theta)**10 - 9.89309794324053e+53*cos(theta)**8 + 1.75320723044769e+53*cos(theta)**6 - 1.13844625353746e+52*cos(theta)**4 + 2.27689250707492e+50*cos(theta)**2 - 6.23806166321896e+47)*sin(31*phi)

#@torch.jit.script
def Yl41_m_minus_30(theta, phi):
    return 2.48997667494702e-47*(1.0 - cos(theta)**2)**15*(1.61887057253027e+53*cos(theta)**11 - 1.0992331048045e+53*cos(theta)**9 + 2.50458175778241e+52*cos(theta)**7 - 2.27689250707492e+51*cos(theta)**5 + 7.58964169024974e+49*cos(theta)**3 - 6.23806166321896e+47*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl41_m_minus_29(theta, phi):
    return 7.26800263703634e-46*(1.0 - cos(theta)**2)**14.5*(1.34905881044189e+52*cos(theta)**12 - 1.0992331048045e+52*cos(theta)**10 + 3.13072719722802e+51*cos(theta)**8 - 3.79482084512487e+50*cos(theta)**6 + 1.89741042256243e+49*cos(theta)**4 - 3.11903083160948e+47*cos(theta)**2 + 7.3216686188016e+44)*sin(29*phi)

#@torch.jit.script
def Yl41_m_minus_28(theta, phi):
    return 2.19248066632502e-44*(1.0 - cos(theta)**2)**14*(1.03773754649376e+51*cos(theta)**13 - 9.99302822549549e+50*cos(theta)**11 + 3.4785857746978e+50*cos(theta)**9 - 5.42117263589267e+49*cos(theta)**7 + 3.79482084512487e+48*cos(theta)**5 - 1.03967694386983e+47*cos(theta)**3 + 7.3216686188016e+44*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl41_m_minus_27(theta, phi):
    return 6.81434842237606e-43*(1.0 - cos(theta)**2)**13.5*(7.41241104638402e+49*cos(theta)**14 - 8.32752352124624e+49*cos(theta)**12 + 3.4785857746978e+49*cos(theta)**10 - 6.77646579486584e+48*cos(theta)**8 + 6.32470140854145e+47*cos(theta)**6 - 2.59919235967457e+46*cos(theta)**4 + 3.6608343094008e+44*cos(theta)**2 - 7.5793671002087e+41)*sin(27*phi)

#@torch.jit.script
def Yl41_m_minus_26(theta, phi):
    return 2.17632836010492e-41*(1.0 - cos(theta)**2)**13*(4.94160736425601e+48*cos(theta)**15 - 6.40578732403557e+48*cos(theta)**13 + 3.16235070427072e+48*cos(theta)**11 - 7.52940643873982e+47*cos(theta)**9 + 9.03528772648778e+46*cos(theta)**7 - 5.19838471934914e+45*cos(theta)**5 + 1.2202781031336e+44*cos(theta)**3 - 7.5793671002087e+41*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl41_m_minus_25(theta, phi):
    return 7.12560614995579e-40*(1.0 - cos(theta)**2)**12.5*(3.08850460266001e+47*cos(theta)**16 - 4.57556237431112e+47*cos(theta)**14 + 2.63529225355894e+47*cos(theta)**12 - 7.52940643873982e+46*cos(theta)**10 + 1.12941096581097e+46*cos(theta)**8 - 8.66397453224856e+44*cos(theta)**6 + 3.050695257834e+43*cos(theta)**4 - 3.78968355010435e+41*cos(theta)**2 + 7.07030513079169e+38)*sin(25*phi)

#@torch.jit.script
def Yl41_m_minus_24(theta, phi):
    return 2.3868121645997e-38*(1.0 - cos(theta)**2)**12*(1.81676741332942e+46*cos(theta)**17 - 3.05037491620741e+46*cos(theta)**15 + 2.02714788735303e+46*cos(theta)**13 - 6.84491494430893e+45*cos(theta)**11 + 1.2549010731233e+45*cos(theta)**9 - 1.23771064746408e+44*cos(theta)**7 + 6.101390515668e+42*cos(theta)**5 - 1.26322785003478e+41*cos(theta)**3 + 7.07030513079169e+38*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl41_m_minus_23(theta, phi):
    return 8.16415372321275e-37*(1.0 - cos(theta)**2)**11.5*(1.00931522962745e+45*cos(theta)**18 - 1.90648432262963e+45*cos(theta)**16 + 1.44796277668073e+45*cos(theta)**14 - 5.70409578692411e+44*cos(theta)**12 + 1.2549010731233e+44*cos(theta)**10 - 1.5471383093301e+43*cos(theta)**8 + 1.016898419278e+42*cos(theta)**6 - 3.15806962508696e+40*cos(theta)**4 + 3.53515256539585e+38*cos(theta)**2 - 6.0429958382835e+35)*sin(23*phi)

#@torch.jit.script
def Yl41_m_minus_22(theta, phi):
    return 2.84693768312126e-35*(1.0 - cos(theta)**2)**11*(5.31218541909186e+43*cos(theta)**19 - 1.12146136625273e+44*cos(theta)**17 + 9.65308517787156e+43*cos(theta)**15 - 4.38776598994162e+43*cos(theta)**13 + 1.14081915738482e+43*cos(theta)**11 - 1.71904256592233e+42*cos(theta)**9 + 1.45271202754e+41*cos(theta)**7 - 6.31613925017391e+39*cos(theta)**5 + 1.17838418846528e+38*cos(theta)**3 - 6.0429958382835e+35*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl41_m_minus_21(theta, phi):
    return 1.01056262825149e-33*(1.0 - cos(theta)**2)**10.5*(2.65609270954593e+42*cos(theta)**20 - 6.23034092362625e+42*cos(theta)**18 + 6.03317823616973e+42*cos(theta)**16 - 3.13411856424401e+42*cos(theta)**14 + 9.50682631154018e+41*cos(theta)**12 - 1.71904256592233e+41*cos(theta)**10 + 1.815890034425e+40*cos(theta)**8 - 1.05268987502899e+39*cos(theta)**6 + 2.94596047116321e+37*cos(theta)**4 - 3.02149791914175e+35*cos(theta)**2 + 4.79602844308214e+32)*sin(21*phi)

#@torch.jit.script
def Yl41_m_minus_20(theta, phi):
    return 3.64643709249914e-32*(1.0 - cos(theta)**2)**10*(1.26480605216473e+41*cos(theta)**21 - 3.27912680190856e+41*cos(theta)**19 + 3.54892837421749e+41*cos(theta)**17 - 2.08941237616268e+41*cos(theta)**15 + 7.31294331656937e+40*cos(theta)**13 - 1.5627659690203e+40*cos(theta)**11 + 2.01765559380556e+39*cos(theta)**9 - 1.50384267861284e+38*cos(theta)**7 + 5.89192094232641e+36*cos(theta)**5 - 1.00716597304725e+35*cos(theta)**3 + 4.79602844308214e+32*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl41_m_minus_19(theta, phi):
    return 1.33581090189222e-30*(1.0 - cos(theta)**2)**9.5*(5.74911841893058e+39*cos(theta)**22 - 1.63956340095428e+40*cos(theta)**20 + 1.97162687456527e+40*cos(theta)**18 - 1.30588273510167e+40*cos(theta)**16 + 5.22353094040669e+39*cos(theta)**14 - 1.30230497418359e+39*cos(theta)**12 + 2.01765559380556e+38*cos(theta)**10 - 1.87980334826605e+37*cos(theta)**8 + 9.81986823721069e+35*cos(theta)**6 - 2.51791493261812e+34*cos(theta)**4 + 2.39801422154107e+32*cos(theta)**2 - 3.57379168635033e+29)*sin(19*phi)

#@torch.jit.script
def Yl41_m_minus_18(theta, phi):
    return 4.96231725764027e-29*(1.0 - cos(theta)**2)**9*(2.49961670388286e+38*cos(theta)**23 - 7.80744476644894e+38*cos(theta)**21 + 1.03769835503435e+39*cos(theta)**19 - 7.6816631476569e+38*cos(theta)**17 + 3.48235396027113e+38*cos(theta)**15 - 1.0017730570643e+38*cos(theta)**13 + 1.83423235800505e+37*cos(theta)**11 - 2.08867038696227e+36*cos(theta)**9 + 1.40283831960153e+35*cos(theta)**7 - 5.03582986523625e+33*cos(theta)**5 + 7.99338073847024e+31*cos(theta)**3 - 3.57379168635033e+29*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl41_m_minus_17(theta, phi):
    return 1.8673088408914e-27*(1.0 - cos(theta)**2)**8.5*(1.04150695995119e+37*cos(theta)**24 - 3.54883853020406e+37*cos(theta)**22 + 5.18849177517177e+37*cos(theta)**20 - 4.26759063758717e+37*cos(theta)**18 + 2.17647122516945e+37*cos(theta)**16 - 7.15552183617355e+36*cos(theta)**14 + 1.52852696500421e+36*cos(theta)**12 - 2.08867038696227e+35*cos(theta)**10 + 1.75354789950191e+34*cos(theta)**8 - 8.39304977539375e+32*cos(theta)**6 + 1.99834518461756e+31*cos(theta)**4 - 1.78689584317516e+29*cos(theta)**2 + 2.52386418527566e+26)*sin(17*phi)

#@torch.jit.script
def Yl41_m_minus_16(theta, phi):
    return 7.11050022540132e-26*(1.0 - cos(theta)**2)**8*(4.16602783980477e+35*cos(theta)**25 - 1.54297327400177e+36*cos(theta)**23 + 2.47071036912941e+36*cos(theta)**21 - 2.24610033557219e+36*cos(theta)**19 + 1.28027719127615e+36*cos(theta)**17 - 4.77034789078237e+35*cos(theta)**15 + 1.17578997308016e+35*cos(theta)**13 - 1.89879126087479e+34*cos(theta)**11 + 1.94838655500212e+33*cos(theta)**9 - 1.19900711077054e+32*cos(theta)**7 + 3.99669036923512e+30*cos(theta)**5 - 5.95631947725055e+28*cos(theta)**3 + 2.52386418527566e+26*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl41_m_minus_15(theta, phi):
    return 2.73731171664738e-24*(1.0 - cos(theta)**2)**7.5*(1.60231839992491e+34*cos(theta)**26 - 6.4290553083407e+34*cos(theta)**24 + 1.1230501677861e+35*cos(theta)**22 - 1.1230501677861e+35*cos(theta)**20 + 7.11265106264528e+34*cos(theta)**18 - 2.98146743173898e+34*cos(theta)**16 + 8.39849980771543e+33*cos(theta)**14 - 1.58232605072899e+33*cos(theta)**12 + 1.94838655500212e+32*cos(theta)**10 - 1.49875888846317e+31*cos(theta)**8 + 6.66115061539186e+29*cos(theta)**6 - 1.48907986931264e+28*cos(theta)**4 + 1.26193209263783e+26*cos(theta)**2 - 1.7030122707663e+23)*sin(15*phi)

#@torch.jit.script
def Yl41_m_minus_14(theta, phi):
    return 1.06438844677832e-22*(1.0 - cos(theta)**2)**7*(5.93451259231449e+32*cos(theta)**27 - 2.57162212333628e+33*cos(theta)**25 + 4.88282681646129e+33*cos(theta)**23 - 5.34785794183855e+33*cos(theta)**21 + 3.74350055928699e+33*cos(theta)**19 - 1.75380437161116e+33*cos(theta)**17 + 5.59899987181029e+32*cos(theta)**15 - 1.21717388517615e+32*cos(theta)**13 + 1.77126050454738e+31*cos(theta)**11 - 1.66528765384797e+30*cos(theta)**9 + 9.51592945055981e+28*cos(theta)**7 - 2.97815973862527e+27*cos(theta)**5 + 4.20644030879276e+25*cos(theta)**3 - 1.7030122707663e+23*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl41_m_minus_13(theta, phi):
    return 4.17696188524406e-21*(1.0 - cos(theta)**2)**6.5*(2.11946878296946e+31*cos(theta)**28 - 9.89085432052415e+31*cos(theta)**26 + 2.03451117352554e+32*cos(theta)**24 - 2.43084451901752e+32*cos(theta)**22 + 1.87175027964349e+32*cos(theta)**20 - 9.74335762006202e+31*cos(theta)**18 + 3.49937491988143e+31*cos(theta)**16 - 8.69409917982964e+30*cos(theta)**14 + 1.47605042045615e+30*cos(theta)**12 - 1.66528765384797e+29*cos(theta)**10 + 1.18949118131998e+28*cos(theta)**8 - 4.96359956437546e+26*cos(theta)**6 + 1.05161007719819e+25*cos(theta)**4 - 8.5150613538315e+22*cos(theta)**2 + 1.10585212387422e+20)*sin(13*phi)

#@torch.jit.script
def Yl41_m_minus_12(theta, phi):
    return 1.65293734258634e-19*(1.0 - cos(theta)**2)**6*(7.30851304472228e+29*cos(theta)**29 - 3.66327937797191e+30*cos(theta)**27 + 8.13804469410215e+30*cos(theta)**25 - 1.05688892131197e+31*cos(theta)**23 + 8.91309656973092e+30*cos(theta)**21 - 5.12808295792738e+30*cos(theta)**19 + 2.05845583522437e+30*cos(theta)**17 - 5.79606611988643e+29*cos(theta)**15 + 1.13542340035089e+29*cos(theta)**13 - 1.51389786713451e+28*cos(theta)**11 + 1.32165686813331e+27*cos(theta)**9 - 7.09085652053637e+25*cos(theta)**7 + 2.10322015439638e+24*cos(theta)**5 - 2.8383537846105e+22*cos(theta)**3 + 1.10585212387422e+20*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl41_m_minus_11(theta, phi):
    return 6.59105526834746e-18*(1.0 - cos(theta)**2)**5.5*(2.43617101490743e+28*cos(theta)**30 - 1.3083140635614e+29*cos(theta)**28 + 3.13001719003929e+29*cos(theta)**26 - 4.40370383879986e+29*cos(theta)**24 + 4.05140753169587e+29*cos(theta)**22 - 2.56404147896369e+29*cos(theta)**20 + 1.14358657512465e+29*cos(theta)**18 - 3.62254132492902e+28*cos(theta)**16 + 8.11016714536347e+27*cos(theta)**14 - 1.26158155594543e+27*cos(theta)**12 + 1.32165686813331e+26*cos(theta)**10 - 8.86357065067046e+24*cos(theta)**8 + 3.50536692399397e+23*cos(theta)**6 - 7.09588446152625e+21*cos(theta)**4 + 5.5292606193711e+19*cos(theta)**2 - 6.95504480424038e+16)*sin(11*phi)

#@torch.jit.script
def Yl41_m_minus_10(theta, phi):
    return 2.64629022208945e-16*(1.0 - cos(theta)**2)**5*(7.85861617712073e+26*cos(theta)**31 - 4.51142780538412e+27*cos(theta)**29 + 1.15926562594048e+28*cos(theta)**27 - 1.76148153551995e+28*cos(theta)**25 + 1.76148153551995e+28*cos(theta)**23 - 1.22097213283985e+28*cos(theta)**21 + 6.01887671118237e+27*cos(theta)**19 - 2.13090666172295e+27*cos(theta)**17 + 5.40677809690898e+26*cos(theta)**15 - 9.70447350727253e+25*cos(theta)**13 + 1.20150624375755e+25*cos(theta)**11 - 9.84841183407829e+23*cos(theta)**9 + 5.0076670342771e+22*cos(theta)**7 - 1.41917689230525e+21*cos(theta)**5 + 1.8430868731237e+19*cos(theta)**3 - 6.95504480424038e+16*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl41_m_minus_9(theta, phi):
    return 1.06904884665327e-14*(1.0 - cos(theta)**2)**4.5*(2.45581755535023e+25*cos(theta)**32 - 1.50380926846137e+26*cos(theta)**30 + 4.14023437835885e+26*cos(theta)**28 - 6.77492898276902e+26*cos(theta)**26 + 7.33950639799977e+26*cos(theta)**24 - 5.54987333109024e+26*cos(theta)**22 + 3.00943835559119e+26*cos(theta)**20 - 1.18383703429053e+26*cos(theta)**18 + 3.37923631056811e+25*cos(theta)**16 - 6.93176679090895e+24*cos(theta)**14 + 1.00125520313129e+24*cos(theta)**12 - 9.84841183407829e+22*cos(theta)**10 + 6.25958379284637e+21*cos(theta)**8 - 2.36529482050875e+20*cos(theta)**6 + 4.60771718280925e+18*cos(theta)**4 - 3.47752240212019e+16*cos(theta)**2 + 42616696104414.1)*sin(9*phi)

#@torch.jit.script
def Yl41_m_minus_8(theta, phi):
    return 4.34249694332146e-13*(1.0 - cos(theta)**2)**4*(7.44187137984917e+23*cos(theta)**33 - 4.85099764019798e+24*cos(theta)**31 + 1.42766702702029e+25*cos(theta)**29 - 2.50923295658112e+25*cos(theta)**27 + 2.93580255919991e+25*cos(theta)**25 - 2.41298840482184e+25*cos(theta)**23 + 1.43306588361485e+25*cos(theta)**21 - 6.23072123310804e+24*cos(theta)**19 + 1.98778606504007e+24*cos(theta)**17 - 4.62117786060597e+23*cos(theta)**15 + 7.70196310100994e+22*cos(theta)**13 - 8.9531016673439e+21*cos(theta)**11 + 6.95509310316263e+20*cos(theta)**9 - 3.37899260072679e+19*cos(theta)**7 + 9.21543436561851e+17*cos(theta)**5 - 1.15917413404006e+16*cos(theta)**3 + 42616696104414.1*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl41_m_minus_7(theta, phi):
    return 1.77246235460141e-11*(1.0 - cos(theta)**2)**3.5*(2.18878569995564e+22*cos(theta)**34 - 1.51593676256187e+23*cos(theta)**32 + 4.75889009006764e+23*cos(theta)**30 - 8.96154627350399e+23*cos(theta)**28 + 1.1291548304615e+24*cos(theta)**26 - 1.00541183534243e+24*cos(theta)**24 + 6.51393583461296e+23*cos(theta)**22 - 3.11536061655402e+23*cos(theta)**20 + 1.10432559168893e+23*cos(theta)**18 - 2.88823616287873e+22*cos(theta)**16 + 5.5014022150071e+21*cos(theta)**14 - 7.46091805611992e+20*cos(theta)**12 + 6.95509310316263e+19*cos(theta)**10 - 4.22374075090848e+18*cos(theta)**8 + 1.53590572760308e+17*cos(theta)**6 - 2.89793533510016e+15*cos(theta)**4 + 21308348052207.1*cos(theta)**2 - 25580249762.5535)*sin(7*phi)

#@torch.jit.script
def Yl41_m_minus_6(theta, phi):
    return 7.264933792847e-10*(1.0 - cos(theta)**2)**3*(6.25367342844468e+20*cos(theta)**35 - 4.593747765339e+21*cos(theta)**33 + 1.53512583550569e+22*cos(theta)**31 - 3.09018837017379e+22*cos(theta)**29 + 4.1820549276352e+22*cos(theta)**27 - 4.02164734136974e+22*cos(theta)**25 + 2.83214601504911e+22*cos(theta)**23 - 1.48350505550192e+22*cos(theta)**21 + 5.8122399562575e+21*cos(theta)**19 - 1.69896244875219e+21*cos(theta)**17 + 3.6676014766714e+20*cos(theta)**15 - 5.73916773547686e+19*cos(theta)**13 + 6.32281191196603e+18*cos(theta)**11 - 4.6930452787872e+17*cos(theta)**9 + 2.19415103943298e+16*cos(theta)**7 - 579587067020032.0*cos(theta)**5 + 7102782684069.02*cos(theta)**3 - 25580249762.5535*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl41_m_minus_5(theta, phi):
    return 2.98835260671243e-8*(1.0 - cos(theta)**2)**2.5*(1.7371315079013e+19*cos(theta)**36 - 1.35110228392323e+20*cos(theta)**34 + 4.79726823595528e+20*cos(theta)**32 - 1.03006279005793e+21*cos(theta)**30 + 1.493591045584e+21*cos(theta)**28 - 1.54678743898836e+21*cos(theta)**26 + 1.1800608396038e+21*cos(theta)**24 - 6.74320479773598e+20*cos(theta)**22 + 2.90611997812875e+20*cos(theta)**20 - 9.43868027084552e+19*cos(theta)**18 + 2.29225092291963e+19*cos(theta)**16 - 4.09940552534061e+18*cos(theta)**14 + 5.26900992663836e+17*cos(theta)**12 - 4.6930452787872e+16*cos(theta)**10 + 2.74268879929122e+15*cos(theta)**8 - 96597844503338.6*cos(theta)**6 + 1775695671017.25*cos(theta)**4 - 12790124881.2767*cos(theta)**2 + 15118350.923495)*sin(5*phi)

#@torch.jit.script
def Yl41_m_minus_4(theta, phi):
    return 1.23285391332796e-6*(1.0 - cos(theta)**2)**2*(4.69495002135487e+17*cos(theta)**37 - 3.86029223978067e+18*cos(theta)**35 + 1.45371764725918e+19*cos(theta)**33 - 3.32278319373526e+19*cos(theta)**31 + 5.15031395028965e+19*cos(theta)**29 - 5.72884236662356e+19*cos(theta)**27 + 4.72024335841519e+19*cos(theta)**25 - 2.93182817292869e+19*cos(theta)**23 + 1.38386665625179e+19*cos(theta)**21 - 4.96772645833975e+18*cos(theta)**19 + 1.34838289583507e+18*cos(theta)**17 - 2.73293701689374e+17*cos(theta)**15 + 4.05308455895258e+16*cos(theta)**13 - 4.26640479889746e+15*cos(theta)**11 + 304743199921247.0*cos(theta)**9 - 13799692071905.5*cos(theta)**7 + 355139134203.451*cos(theta)**5 - 4263374960.42558*cos(theta)**3 + 15118350.923495*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl41_m_minus_3(theta, phi):
    return 5.09811553365533e-5*(1.0 - cos(theta)**2)**1.5*(1.23551316351444e+16*cos(theta)**38 - 1.07230339993907e+17*cos(theta)**36 + 4.27564013899758e+17*cos(theta)**34 - 1.03836974804227e+18*cos(theta)**32 + 1.71677131676322e+18*cos(theta)**30 - 2.04601513093699e+18*cos(theta)**28 + 1.81547821477507e+18*cos(theta)**26 - 1.22159507205362e+18*cos(theta)**24 + 6.29030298296267e+17*cos(theta)**22 - 2.48386322916987e+17*cos(theta)**20 + 7.49101608797264e+16*cos(theta)**18 - 1.70808563555859e+16*cos(theta)**16 + 2.89506039925185e+15*cos(theta)**14 - 355533733241455.0*cos(theta)**12 + 30474319992124.7*cos(theta)**10 - 1724961508988.19*cos(theta)**8 + 59189855700.5751*cos(theta)**6 - 1065843740.1064*cos(theta)**4 + 7559175.46174748*cos(theta)**2 - 8841.14089093273)*sin(3*phi)

#@torch.jit.script
def Yl41_m_minus_2(theta, phi):
    return 0.00211187551485778*(1.0 - cos(theta)**2)*(316798247054984.0*cos(theta)**39 - 2.89811729713263e+15*cos(theta)**37 + 1.22161146828502e+16*cos(theta)**35 - 3.14657499406748e+16*cos(theta)**33 + 5.53797198955877e+16*cos(theta)**31 - 7.05522458943788e+16*cos(theta)**29 + 6.72399338805582e+16*cos(theta)**27 - 4.88638028821448e+16*cos(theta)**25 + 2.73491434041855e+16*cos(theta)**23 - 1.18279201389042e+16*cos(theta)**21 + 3.94264004630139e+15*cos(theta)**19 - 1.00475625621093e+15*cos(theta)**17 + 193004026616790.0*cos(theta)**15 - 27348748710881.1*cos(theta)**13 + 2770392726556.79*cos(theta)**11 - 191662389887.577*cos(theta)**9 + 8455693671.51074*cos(theta)**7 - 213168748.021279*cos(theta)**5 + 2519725.15391583*cos(theta)**3 - 8841.14089093273*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl41_m_minus_1(theta, phi):
    return 0.0875855655187544*(1.0 - cos(theta)**2)**0.5*(7919956176374.61*cos(theta)**40 - 76266244661385.1*cos(theta)**38 + 339336518968062.0*cos(theta)**36 - 925463233549259.0*cos(theta)**34 + 1.73061624673711e+15*cos(theta)**32 - 2.35174152981263e+15*cos(theta)**30 + 2.40142621001994e+15*cos(theta)**28 - 1.87937703392865e+15*cos(theta)**26 + 1.13954764184106e+15*cos(theta)**24 - 537632733586553.0*cos(theta)**22 + 197132002315069.0*cos(theta)**20 - 55819792011718.6*cos(theta)**18 + 12062751663549.4*cos(theta)**16 - 1953482050777.22*cos(theta)**14 + 230866060546.399*cos(theta)**12 - 19166238988.7577*cos(theta)**10 + 1056961708.93884*cos(theta)**8 - 35528124.6702132*cos(theta)**6 + 629931.288478957*cos(theta)**4 - 4420.57044546636*cos(theta)**2 + 5.14019819240275)*sin(phi)

#@torch.jit.script
def Yl41_m0(theta, phi):
    return 1559634770043.59*cos(theta)**41 - 15788895202910.4*cos(theta)**39 + 74047919907320.4*cos(theta)**37 - 213488808044482.0*cos(theta)**35 + 423419469288223.0*cos(theta)**33 - 612508163792279.0*cos(theta)**31 + 668582854843685.0*cos(theta)**29 - 561997182332373.0*cos(theta)**27 + 368024274251237.0*cos(theta)**25 - 188730397051916.0*cos(theta)**23 + 75791730879579.0*cos(theta)**21 - 23720213837126.1*cos(theta)**19 + 5729034697949.94*cos(theta)**17 - 1051482751580.56*cos(theta)**15 + 143384011579.167*cos(theta)**13 - 14067865287.0126*cos(theta)**11 + 948201704.394231*cos(theta)**9 - 40978705.1118755*cos(theta)**7 + 1017201.89994017*cos(theta)**5 - 11897.0982449143*cos(theta)**3 + 41.501505505515*cos(theta)

#@torch.jit.script
def Yl41_m1(theta, phi):
    return 0.0875855655187544*(1.0 - cos(theta)**2)**0.5*(7919956176374.61*cos(theta)**40 - 76266244661385.1*cos(theta)**38 + 339336518968062.0*cos(theta)**36 - 925463233549259.0*cos(theta)**34 + 1.73061624673711e+15*cos(theta)**32 - 2.35174152981263e+15*cos(theta)**30 + 2.40142621001994e+15*cos(theta)**28 - 1.87937703392865e+15*cos(theta)**26 + 1.13954764184106e+15*cos(theta)**24 - 537632733586553.0*cos(theta)**22 + 197132002315069.0*cos(theta)**20 - 55819792011718.6*cos(theta)**18 + 12062751663549.4*cos(theta)**16 - 1953482050777.22*cos(theta)**14 + 230866060546.399*cos(theta)**12 - 19166238988.7577*cos(theta)**10 + 1056961708.93884*cos(theta)**8 - 35528124.6702132*cos(theta)**6 + 629931.288478957*cos(theta)**4 - 4420.57044546636*cos(theta)**2 + 5.14019819240275)*cos(phi)

#@torch.jit.script
def Yl41_m2(theta, phi):
    return 0.00211187551485778*(1.0 - cos(theta)**2)*(316798247054984.0*cos(theta)**39 - 2.89811729713263e+15*cos(theta)**37 + 1.22161146828502e+16*cos(theta)**35 - 3.14657499406748e+16*cos(theta)**33 + 5.53797198955877e+16*cos(theta)**31 - 7.05522458943788e+16*cos(theta)**29 + 6.72399338805582e+16*cos(theta)**27 - 4.88638028821448e+16*cos(theta)**25 + 2.73491434041855e+16*cos(theta)**23 - 1.18279201389042e+16*cos(theta)**21 + 3.94264004630139e+15*cos(theta)**19 - 1.00475625621093e+15*cos(theta)**17 + 193004026616790.0*cos(theta)**15 - 27348748710881.1*cos(theta)**13 + 2770392726556.79*cos(theta)**11 - 191662389887.577*cos(theta)**9 + 8455693671.51074*cos(theta)**7 - 213168748.021279*cos(theta)**5 + 2519725.15391583*cos(theta)**3 - 8841.14089093273*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl41_m3(theta, phi):
    return 5.09811553365533e-5*(1.0 - cos(theta)**2)**1.5*(1.23551316351444e+16*cos(theta)**38 - 1.07230339993907e+17*cos(theta)**36 + 4.27564013899758e+17*cos(theta)**34 - 1.03836974804227e+18*cos(theta)**32 + 1.71677131676322e+18*cos(theta)**30 - 2.04601513093699e+18*cos(theta)**28 + 1.81547821477507e+18*cos(theta)**26 - 1.22159507205362e+18*cos(theta)**24 + 6.29030298296267e+17*cos(theta)**22 - 2.48386322916987e+17*cos(theta)**20 + 7.49101608797264e+16*cos(theta)**18 - 1.70808563555859e+16*cos(theta)**16 + 2.89506039925185e+15*cos(theta)**14 - 355533733241455.0*cos(theta)**12 + 30474319992124.7*cos(theta)**10 - 1724961508988.19*cos(theta)**8 + 59189855700.5751*cos(theta)**6 - 1065843740.1064*cos(theta)**4 + 7559175.46174748*cos(theta)**2 - 8841.14089093273)*cos(3*phi)

#@torch.jit.script
def Yl41_m4(theta, phi):
    return 1.23285391332796e-6*(1.0 - cos(theta)**2)**2*(4.69495002135487e+17*cos(theta)**37 - 3.86029223978067e+18*cos(theta)**35 + 1.45371764725918e+19*cos(theta)**33 - 3.32278319373526e+19*cos(theta)**31 + 5.15031395028965e+19*cos(theta)**29 - 5.72884236662356e+19*cos(theta)**27 + 4.72024335841519e+19*cos(theta)**25 - 2.93182817292869e+19*cos(theta)**23 + 1.38386665625179e+19*cos(theta)**21 - 4.96772645833975e+18*cos(theta)**19 + 1.34838289583507e+18*cos(theta)**17 - 2.73293701689374e+17*cos(theta)**15 + 4.05308455895258e+16*cos(theta)**13 - 4.26640479889746e+15*cos(theta)**11 + 304743199921247.0*cos(theta)**9 - 13799692071905.5*cos(theta)**7 + 355139134203.451*cos(theta)**5 - 4263374960.42558*cos(theta)**3 + 15118350.923495*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl41_m5(theta, phi):
    return 2.98835260671243e-8*(1.0 - cos(theta)**2)**2.5*(1.7371315079013e+19*cos(theta)**36 - 1.35110228392323e+20*cos(theta)**34 + 4.79726823595528e+20*cos(theta)**32 - 1.03006279005793e+21*cos(theta)**30 + 1.493591045584e+21*cos(theta)**28 - 1.54678743898836e+21*cos(theta)**26 + 1.1800608396038e+21*cos(theta)**24 - 6.74320479773598e+20*cos(theta)**22 + 2.90611997812875e+20*cos(theta)**20 - 9.43868027084552e+19*cos(theta)**18 + 2.29225092291963e+19*cos(theta)**16 - 4.09940552534061e+18*cos(theta)**14 + 5.26900992663836e+17*cos(theta)**12 - 4.6930452787872e+16*cos(theta)**10 + 2.74268879929122e+15*cos(theta)**8 - 96597844503338.6*cos(theta)**6 + 1775695671017.25*cos(theta)**4 - 12790124881.2767*cos(theta)**2 + 15118350.923495)*cos(5*phi)

#@torch.jit.script
def Yl41_m6(theta, phi):
    return 7.264933792847e-10*(1.0 - cos(theta)**2)**3*(6.25367342844468e+20*cos(theta)**35 - 4.593747765339e+21*cos(theta)**33 + 1.53512583550569e+22*cos(theta)**31 - 3.09018837017379e+22*cos(theta)**29 + 4.1820549276352e+22*cos(theta)**27 - 4.02164734136974e+22*cos(theta)**25 + 2.83214601504911e+22*cos(theta)**23 - 1.48350505550192e+22*cos(theta)**21 + 5.8122399562575e+21*cos(theta)**19 - 1.69896244875219e+21*cos(theta)**17 + 3.6676014766714e+20*cos(theta)**15 - 5.73916773547686e+19*cos(theta)**13 + 6.32281191196603e+18*cos(theta)**11 - 4.6930452787872e+17*cos(theta)**9 + 2.19415103943298e+16*cos(theta)**7 - 579587067020032.0*cos(theta)**5 + 7102782684069.02*cos(theta)**3 - 25580249762.5535*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl41_m7(theta, phi):
    return 1.77246235460141e-11*(1.0 - cos(theta)**2)**3.5*(2.18878569995564e+22*cos(theta)**34 - 1.51593676256187e+23*cos(theta)**32 + 4.75889009006764e+23*cos(theta)**30 - 8.96154627350399e+23*cos(theta)**28 + 1.1291548304615e+24*cos(theta)**26 - 1.00541183534243e+24*cos(theta)**24 + 6.51393583461296e+23*cos(theta)**22 - 3.11536061655402e+23*cos(theta)**20 + 1.10432559168893e+23*cos(theta)**18 - 2.88823616287873e+22*cos(theta)**16 + 5.5014022150071e+21*cos(theta)**14 - 7.46091805611992e+20*cos(theta)**12 + 6.95509310316263e+19*cos(theta)**10 - 4.22374075090848e+18*cos(theta)**8 + 1.53590572760308e+17*cos(theta)**6 - 2.89793533510016e+15*cos(theta)**4 + 21308348052207.1*cos(theta)**2 - 25580249762.5535)*cos(7*phi)

#@torch.jit.script
def Yl41_m8(theta, phi):
    return 4.34249694332146e-13*(1.0 - cos(theta)**2)**4*(7.44187137984917e+23*cos(theta)**33 - 4.85099764019798e+24*cos(theta)**31 + 1.42766702702029e+25*cos(theta)**29 - 2.50923295658112e+25*cos(theta)**27 + 2.93580255919991e+25*cos(theta)**25 - 2.41298840482184e+25*cos(theta)**23 + 1.43306588361485e+25*cos(theta)**21 - 6.23072123310804e+24*cos(theta)**19 + 1.98778606504007e+24*cos(theta)**17 - 4.62117786060597e+23*cos(theta)**15 + 7.70196310100994e+22*cos(theta)**13 - 8.9531016673439e+21*cos(theta)**11 + 6.95509310316263e+20*cos(theta)**9 - 3.37899260072679e+19*cos(theta)**7 + 9.21543436561851e+17*cos(theta)**5 - 1.15917413404006e+16*cos(theta)**3 + 42616696104414.1*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl41_m9(theta, phi):
    return 1.06904884665327e-14*(1.0 - cos(theta)**2)**4.5*(2.45581755535023e+25*cos(theta)**32 - 1.50380926846137e+26*cos(theta)**30 + 4.14023437835885e+26*cos(theta)**28 - 6.77492898276902e+26*cos(theta)**26 + 7.33950639799977e+26*cos(theta)**24 - 5.54987333109024e+26*cos(theta)**22 + 3.00943835559119e+26*cos(theta)**20 - 1.18383703429053e+26*cos(theta)**18 + 3.37923631056811e+25*cos(theta)**16 - 6.93176679090895e+24*cos(theta)**14 + 1.00125520313129e+24*cos(theta)**12 - 9.84841183407829e+22*cos(theta)**10 + 6.25958379284637e+21*cos(theta)**8 - 2.36529482050875e+20*cos(theta)**6 + 4.60771718280925e+18*cos(theta)**4 - 3.47752240212019e+16*cos(theta)**2 + 42616696104414.1)*cos(9*phi)

#@torch.jit.script
def Yl41_m10(theta, phi):
    return 2.64629022208945e-16*(1.0 - cos(theta)**2)**5*(7.85861617712073e+26*cos(theta)**31 - 4.51142780538412e+27*cos(theta)**29 + 1.15926562594048e+28*cos(theta)**27 - 1.76148153551995e+28*cos(theta)**25 + 1.76148153551995e+28*cos(theta)**23 - 1.22097213283985e+28*cos(theta)**21 + 6.01887671118237e+27*cos(theta)**19 - 2.13090666172295e+27*cos(theta)**17 + 5.40677809690898e+26*cos(theta)**15 - 9.70447350727253e+25*cos(theta)**13 + 1.20150624375755e+25*cos(theta)**11 - 9.84841183407829e+23*cos(theta)**9 + 5.0076670342771e+22*cos(theta)**7 - 1.41917689230525e+21*cos(theta)**5 + 1.8430868731237e+19*cos(theta)**3 - 6.95504480424038e+16*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl41_m11(theta, phi):
    return 6.59105526834746e-18*(1.0 - cos(theta)**2)**5.5*(2.43617101490743e+28*cos(theta)**30 - 1.3083140635614e+29*cos(theta)**28 + 3.13001719003929e+29*cos(theta)**26 - 4.40370383879986e+29*cos(theta)**24 + 4.05140753169587e+29*cos(theta)**22 - 2.56404147896369e+29*cos(theta)**20 + 1.14358657512465e+29*cos(theta)**18 - 3.62254132492902e+28*cos(theta)**16 + 8.11016714536347e+27*cos(theta)**14 - 1.26158155594543e+27*cos(theta)**12 + 1.32165686813331e+26*cos(theta)**10 - 8.86357065067046e+24*cos(theta)**8 + 3.50536692399397e+23*cos(theta)**6 - 7.09588446152625e+21*cos(theta)**4 + 5.5292606193711e+19*cos(theta)**2 - 6.95504480424038e+16)*cos(11*phi)

#@torch.jit.script
def Yl41_m12(theta, phi):
    return 1.65293734258634e-19*(1.0 - cos(theta)**2)**6*(7.30851304472228e+29*cos(theta)**29 - 3.66327937797191e+30*cos(theta)**27 + 8.13804469410215e+30*cos(theta)**25 - 1.05688892131197e+31*cos(theta)**23 + 8.91309656973092e+30*cos(theta)**21 - 5.12808295792738e+30*cos(theta)**19 + 2.05845583522437e+30*cos(theta)**17 - 5.79606611988643e+29*cos(theta)**15 + 1.13542340035089e+29*cos(theta)**13 - 1.51389786713451e+28*cos(theta)**11 + 1.32165686813331e+27*cos(theta)**9 - 7.09085652053637e+25*cos(theta)**7 + 2.10322015439638e+24*cos(theta)**5 - 2.8383537846105e+22*cos(theta)**3 + 1.10585212387422e+20*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl41_m13(theta, phi):
    return 4.17696188524406e-21*(1.0 - cos(theta)**2)**6.5*(2.11946878296946e+31*cos(theta)**28 - 9.89085432052415e+31*cos(theta)**26 + 2.03451117352554e+32*cos(theta)**24 - 2.43084451901752e+32*cos(theta)**22 + 1.87175027964349e+32*cos(theta)**20 - 9.74335762006202e+31*cos(theta)**18 + 3.49937491988143e+31*cos(theta)**16 - 8.69409917982964e+30*cos(theta)**14 + 1.47605042045615e+30*cos(theta)**12 - 1.66528765384797e+29*cos(theta)**10 + 1.18949118131998e+28*cos(theta)**8 - 4.96359956437546e+26*cos(theta)**6 + 1.05161007719819e+25*cos(theta)**4 - 8.5150613538315e+22*cos(theta)**2 + 1.10585212387422e+20)*cos(13*phi)

#@torch.jit.script
def Yl41_m14(theta, phi):
    return 1.06438844677832e-22*(1.0 - cos(theta)**2)**7*(5.93451259231449e+32*cos(theta)**27 - 2.57162212333628e+33*cos(theta)**25 + 4.88282681646129e+33*cos(theta)**23 - 5.34785794183855e+33*cos(theta)**21 + 3.74350055928699e+33*cos(theta)**19 - 1.75380437161116e+33*cos(theta)**17 + 5.59899987181029e+32*cos(theta)**15 - 1.21717388517615e+32*cos(theta)**13 + 1.77126050454738e+31*cos(theta)**11 - 1.66528765384797e+30*cos(theta)**9 + 9.51592945055981e+28*cos(theta)**7 - 2.97815973862527e+27*cos(theta)**5 + 4.20644030879276e+25*cos(theta)**3 - 1.7030122707663e+23*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl41_m15(theta, phi):
    return 2.73731171664738e-24*(1.0 - cos(theta)**2)**7.5*(1.60231839992491e+34*cos(theta)**26 - 6.4290553083407e+34*cos(theta)**24 + 1.1230501677861e+35*cos(theta)**22 - 1.1230501677861e+35*cos(theta)**20 + 7.11265106264528e+34*cos(theta)**18 - 2.98146743173898e+34*cos(theta)**16 + 8.39849980771543e+33*cos(theta)**14 - 1.58232605072899e+33*cos(theta)**12 + 1.94838655500212e+32*cos(theta)**10 - 1.49875888846317e+31*cos(theta)**8 + 6.66115061539186e+29*cos(theta)**6 - 1.48907986931264e+28*cos(theta)**4 + 1.26193209263783e+26*cos(theta)**2 - 1.7030122707663e+23)*cos(15*phi)

#@torch.jit.script
def Yl41_m16(theta, phi):
    return 7.11050022540132e-26*(1.0 - cos(theta)**2)**8*(4.16602783980477e+35*cos(theta)**25 - 1.54297327400177e+36*cos(theta)**23 + 2.47071036912941e+36*cos(theta)**21 - 2.24610033557219e+36*cos(theta)**19 + 1.28027719127615e+36*cos(theta)**17 - 4.77034789078237e+35*cos(theta)**15 + 1.17578997308016e+35*cos(theta)**13 - 1.89879126087479e+34*cos(theta)**11 + 1.94838655500212e+33*cos(theta)**9 - 1.19900711077054e+32*cos(theta)**7 + 3.99669036923512e+30*cos(theta)**5 - 5.95631947725055e+28*cos(theta)**3 + 2.52386418527566e+26*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl41_m17(theta, phi):
    return 1.8673088408914e-27*(1.0 - cos(theta)**2)**8.5*(1.04150695995119e+37*cos(theta)**24 - 3.54883853020406e+37*cos(theta)**22 + 5.18849177517177e+37*cos(theta)**20 - 4.26759063758717e+37*cos(theta)**18 + 2.17647122516945e+37*cos(theta)**16 - 7.15552183617355e+36*cos(theta)**14 + 1.52852696500421e+36*cos(theta)**12 - 2.08867038696227e+35*cos(theta)**10 + 1.75354789950191e+34*cos(theta)**8 - 8.39304977539375e+32*cos(theta)**6 + 1.99834518461756e+31*cos(theta)**4 - 1.78689584317516e+29*cos(theta)**2 + 2.52386418527566e+26)*cos(17*phi)

#@torch.jit.script
def Yl41_m18(theta, phi):
    return 4.96231725764027e-29*(1.0 - cos(theta)**2)**9*(2.49961670388286e+38*cos(theta)**23 - 7.80744476644894e+38*cos(theta)**21 + 1.03769835503435e+39*cos(theta)**19 - 7.6816631476569e+38*cos(theta)**17 + 3.48235396027113e+38*cos(theta)**15 - 1.0017730570643e+38*cos(theta)**13 + 1.83423235800505e+37*cos(theta)**11 - 2.08867038696227e+36*cos(theta)**9 + 1.40283831960153e+35*cos(theta)**7 - 5.03582986523625e+33*cos(theta)**5 + 7.99338073847024e+31*cos(theta)**3 - 3.57379168635033e+29*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl41_m19(theta, phi):
    return 1.33581090189222e-30*(1.0 - cos(theta)**2)**9.5*(5.74911841893058e+39*cos(theta)**22 - 1.63956340095428e+40*cos(theta)**20 + 1.97162687456527e+40*cos(theta)**18 - 1.30588273510167e+40*cos(theta)**16 + 5.22353094040669e+39*cos(theta)**14 - 1.30230497418359e+39*cos(theta)**12 + 2.01765559380556e+38*cos(theta)**10 - 1.87980334826605e+37*cos(theta)**8 + 9.81986823721069e+35*cos(theta)**6 - 2.51791493261812e+34*cos(theta)**4 + 2.39801422154107e+32*cos(theta)**2 - 3.57379168635033e+29)*cos(19*phi)

#@torch.jit.script
def Yl41_m20(theta, phi):
    return 3.64643709249914e-32*(1.0 - cos(theta)**2)**10*(1.26480605216473e+41*cos(theta)**21 - 3.27912680190856e+41*cos(theta)**19 + 3.54892837421749e+41*cos(theta)**17 - 2.08941237616268e+41*cos(theta)**15 + 7.31294331656937e+40*cos(theta)**13 - 1.5627659690203e+40*cos(theta)**11 + 2.01765559380556e+39*cos(theta)**9 - 1.50384267861284e+38*cos(theta)**7 + 5.89192094232641e+36*cos(theta)**5 - 1.00716597304725e+35*cos(theta)**3 + 4.79602844308214e+32*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl41_m21(theta, phi):
    return 1.01056262825149e-33*(1.0 - cos(theta)**2)**10.5*(2.65609270954593e+42*cos(theta)**20 - 6.23034092362625e+42*cos(theta)**18 + 6.03317823616973e+42*cos(theta)**16 - 3.13411856424401e+42*cos(theta)**14 + 9.50682631154018e+41*cos(theta)**12 - 1.71904256592233e+41*cos(theta)**10 + 1.815890034425e+40*cos(theta)**8 - 1.05268987502899e+39*cos(theta)**6 + 2.94596047116321e+37*cos(theta)**4 - 3.02149791914175e+35*cos(theta)**2 + 4.79602844308214e+32)*cos(21*phi)

#@torch.jit.script
def Yl41_m22(theta, phi):
    return 2.84693768312126e-35*(1.0 - cos(theta)**2)**11*(5.31218541909186e+43*cos(theta)**19 - 1.12146136625273e+44*cos(theta)**17 + 9.65308517787156e+43*cos(theta)**15 - 4.38776598994162e+43*cos(theta)**13 + 1.14081915738482e+43*cos(theta)**11 - 1.71904256592233e+42*cos(theta)**9 + 1.45271202754e+41*cos(theta)**7 - 6.31613925017391e+39*cos(theta)**5 + 1.17838418846528e+38*cos(theta)**3 - 6.0429958382835e+35*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl41_m23(theta, phi):
    return 8.16415372321275e-37*(1.0 - cos(theta)**2)**11.5*(1.00931522962745e+45*cos(theta)**18 - 1.90648432262963e+45*cos(theta)**16 + 1.44796277668073e+45*cos(theta)**14 - 5.70409578692411e+44*cos(theta)**12 + 1.2549010731233e+44*cos(theta)**10 - 1.5471383093301e+43*cos(theta)**8 + 1.016898419278e+42*cos(theta)**6 - 3.15806962508696e+40*cos(theta)**4 + 3.53515256539585e+38*cos(theta)**2 - 6.0429958382835e+35)*cos(23*phi)

#@torch.jit.script
def Yl41_m24(theta, phi):
    return 2.3868121645997e-38*(1.0 - cos(theta)**2)**12*(1.81676741332942e+46*cos(theta)**17 - 3.05037491620741e+46*cos(theta)**15 + 2.02714788735303e+46*cos(theta)**13 - 6.84491494430893e+45*cos(theta)**11 + 1.2549010731233e+45*cos(theta)**9 - 1.23771064746408e+44*cos(theta)**7 + 6.101390515668e+42*cos(theta)**5 - 1.26322785003478e+41*cos(theta)**3 + 7.07030513079169e+38*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl41_m25(theta, phi):
    return 7.12560614995579e-40*(1.0 - cos(theta)**2)**12.5*(3.08850460266001e+47*cos(theta)**16 - 4.57556237431112e+47*cos(theta)**14 + 2.63529225355894e+47*cos(theta)**12 - 7.52940643873982e+46*cos(theta)**10 + 1.12941096581097e+46*cos(theta)**8 - 8.66397453224856e+44*cos(theta)**6 + 3.050695257834e+43*cos(theta)**4 - 3.78968355010435e+41*cos(theta)**2 + 7.07030513079169e+38)*cos(25*phi)

#@torch.jit.script
def Yl41_m26(theta, phi):
    return 2.17632836010492e-41*(1.0 - cos(theta)**2)**13*(4.94160736425601e+48*cos(theta)**15 - 6.40578732403557e+48*cos(theta)**13 + 3.16235070427072e+48*cos(theta)**11 - 7.52940643873982e+47*cos(theta)**9 + 9.03528772648778e+46*cos(theta)**7 - 5.19838471934914e+45*cos(theta)**5 + 1.2202781031336e+44*cos(theta)**3 - 7.5793671002087e+41*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl41_m27(theta, phi):
    return 6.81434842237606e-43*(1.0 - cos(theta)**2)**13.5*(7.41241104638402e+49*cos(theta)**14 - 8.32752352124624e+49*cos(theta)**12 + 3.4785857746978e+49*cos(theta)**10 - 6.77646579486584e+48*cos(theta)**8 + 6.32470140854145e+47*cos(theta)**6 - 2.59919235967457e+46*cos(theta)**4 + 3.6608343094008e+44*cos(theta)**2 - 7.5793671002087e+41)*cos(27*phi)

#@torch.jit.script
def Yl41_m28(theta, phi):
    return 2.19248066632502e-44*(1.0 - cos(theta)**2)**14*(1.03773754649376e+51*cos(theta)**13 - 9.99302822549549e+50*cos(theta)**11 + 3.4785857746978e+50*cos(theta)**9 - 5.42117263589267e+49*cos(theta)**7 + 3.79482084512487e+48*cos(theta)**5 - 1.03967694386983e+47*cos(theta)**3 + 7.3216686188016e+44*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl41_m29(theta, phi):
    return 7.26800263703634e-46*(1.0 - cos(theta)**2)**14.5*(1.34905881044189e+52*cos(theta)**12 - 1.0992331048045e+52*cos(theta)**10 + 3.13072719722802e+51*cos(theta)**8 - 3.79482084512487e+50*cos(theta)**6 + 1.89741042256243e+49*cos(theta)**4 - 3.11903083160948e+47*cos(theta)**2 + 7.3216686188016e+44)*cos(29*phi)

#@torch.jit.script
def Yl41_m30(theta, phi):
    return 2.48997667494702e-47*(1.0 - cos(theta)**2)**15*(1.61887057253027e+53*cos(theta)**11 - 1.0992331048045e+53*cos(theta)**9 + 2.50458175778241e+52*cos(theta)**7 - 2.27689250707492e+51*cos(theta)**5 + 7.58964169024974e+49*cos(theta)**3 - 6.23806166321896e+47*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl41_m31(theta, phi):
    return 8.84774684679108e-49*(1.0 - cos(theta)**2)**15.5*(1.7807576297833e+54*cos(theta)**10 - 9.89309794324053e+53*cos(theta)**8 + 1.75320723044769e+53*cos(theta)**6 - 1.13844625353746e+52*cos(theta)**4 + 2.27689250707492e+50*cos(theta)**2 - 6.23806166321896e+47)*cos(31*phi)

#@torch.jit.script
def Yl41_m32(theta, phi):
    return 3.27469802570795e-50*(1.0 - cos(theta)**2)**16*(1.7807576297833e+55*cos(theta)**9 - 7.91447835459243e+54*cos(theta)**7 + 1.05192433826861e+54*cos(theta)**5 - 4.55378501414984e+52*cos(theta)**3 + 4.55378501414984e+50*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl41_m33(theta, phi):
    return 1.26891971029199e-51*(1.0 - cos(theta)**2)**16.5*(1.60268186680497e+56*cos(theta)**8 - 5.5401348482147e+55*cos(theta)**6 + 5.25962169134307e+54*cos(theta)**4 - 1.36613550424495e+53*cos(theta)**2 + 4.55378501414984e+50)*cos(33*phi)

#@torch.jit.script
def Yl41_m34(theta, phi):
    return 5.18034302462604e-53*(1.0 - cos(theta)**2)**17*(1.28214549344397e+57*cos(theta)**7 - 3.32408090892882e+56*cos(theta)**5 + 2.10384867653723e+55*cos(theta)**3 - 2.73227100848991e+53*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl41_m35(theta, phi):
    return 2.24596354110399e-54*(1.0 - cos(theta)**2)**17.5*(8.97501845410781e+57*cos(theta)**6 - 1.66204045446441e+57*cos(theta)**4 + 6.31154602961168e+55*cos(theta)**2 - 2.73227100848991e+53)*cos(35*phi)

#@torch.jit.script
def Yl41_m36(theta, phi):
    return 1.04491680606395e-55*(1.0 - cos(theta)**2)**18*(5.38501107246469e+58*cos(theta)**5 - 6.64816181785764e+57*cos(theta)**3 + 1.26230920592234e+56*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl41_m37(theta, phi):
    return 5.29114192414144e-57*(1.0 - cos(theta)**2)**18.5*(2.69250553623234e+59*cos(theta)**4 - 1.99444854535729e+58*cos(theta)**2 + 1.26230920592234e+56)*cos(37*phi)

#@torch.jit.script
def Yl41_m38(theta, phi):
    return 2.97649988046699e-58*(1.0 - cos(theta)**2)**19*(1.07700221449294e+60*cos(theta)**3 - 3.98889709071458e+58*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl41_m39(theta, phi):
    return 1.92132241117284e-59*(1.0 - cos(theta)**2)**19.5*(3.23100664347881e+60*cos(theta)**2 - 3.98889709071458e+58)*cos(39*phi)

#@torch.jit.script
def Yl41_m40(theta, phi):
    return 9.75462521665048*(1.0 - cos(theta)**2)**20*cos(40*phi)*cos(theta)

#@torch.jit.script
def Yl41_m41(theta, phi):
    return 1.07721814896289*(1.0 - cos(theta)**2)**20.5*cos(41*phi)

#@torch.jit.script
def Yl42_m_minus_42(theta, phi):
    return 1.08361119113624*(1.0 - cos(theta)**2)**21*sin(42*phi)

#@torch.jit.script
def Yl42_m_minus_41(theta, phi):
    return 9.93146061456615*(1.0 - cos(theta)**2)**20.5*sin(41*phi)*cos(theta)

#@torch.jit.script
def Yl42_m_minus_40(theta, phi):
    return 2.38572965876905e-61*(1.0 - cos(theta)**2)**20*(2.68173551408741e+62*cos(theta)**2 - 3.23100664347881e+60)*sin(40*phi)

#@torch.jit.script
def Yl42_m_minus_39(theta, phi):
    return 3.74187075827541e-60*(1.0 - cos(theta)**2)**19.5*(8.93911838029138e+61*cos(theta)**3 - 3.23100664347881e+60*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl42_m_minus_38(theta, phi):
    return 6.73536736489573e-59*(1.0 - cos(theta)**2)**19*(2.23477959507285e+61*cos(theta)**4 - 1.61550332173941e+60*cos(theta)**2 + 9.97224272678646e+57)*sin(38*phi)

#@torch.jit.script
def Yl42_m_minus_37(theta, phi):
    return 1.34707347297915e-57*(1.0 - cos(theta)**2)**18.5*(4.46955919014569e+60*cos(theta)**5 - 5.38501107246469e+59*cos(theta)**3 + 9.97224272678646e+57*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl42_m_minus_36(theta, phi):
    return 2.93278654238651e-56*(1.0 - cos(theta)**2)**18*(7.44926531690948e+59*cos(theta)**6 - 1.34625276811617e+59*cos(theta)**4 + 4.98612136339323e+57*cos(theta)**2 - 2.10384867653723e+55)*sin(36*phi)

#@torch.jit.script
def Yl42_m_minus_35(theta, phi):
    return 6.85293758117573e-55*(1.0 - cos(theta)**2)**17.5*(1.0641807595585e+59*cos(theta)**7 - 2.69250553623234e+58*cos(theta)**5 + 1.66204045446441e+57*cos(theta)**3 - 2.10384867653723e+55*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl42_m_minus_34(theta, phi):
    return 1.70085437797474e-53*(1.0 - cos(theta)**2)**17*(1.33022594944812e+58*cos(theta)**8 - 4.48750922705391e+57*cos(theta)**6 + 4.15510113616102e+56*cos(theta)**4 - 1.05192433826861e+55*cos(theta)**2 + 3.41533876061238e+52)*sin(34*phi)

#@torch.jit.script
def Yl42_m_minus_33(theta, phi):
    return 4.44831141076236e-52*(1.0 - cos(theta)**2)**16.5*(1.47802883272014e+57*cos(theta)**9 - 6.41072746721987e+56*cos(theta)**7 + 8.31020227232205e+55*cos(theta)**5 - 3.50641446089538e+54*cos(theta)**3 + 3.41533876061238e+52*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl42_m_minus_32(theta, phi):
    return 1.21822025124109e-50*(1.0 - cos(theta)**2)**16*(1.47802883272014e+56*cos(theta)**10 - 8.01340933402483e+55*cos(theta)**8 + 1.38503371205367e+55*cos(theta)**6 - 8.76603615223845e+53*cos(theta)**4 + 1.70766938030619e+52*cos(theta)**2 - 4.55378501414984e+49)*sin(32*phi)

#@torch.jit.script
def Yl42_m_minus_31(theta, phi):
    return 3.4756658535518e-49*(1.0 - cos(theta)**2)**15.5*(1.34366257520012e+55*cos(theta)**11 - 8.90378814891648e+54*cos(theta)**9 + 1.97861958864811e+54*cos(theta)**7 - 1.75320723044769e+53*cos(theta)**5 + 5.6922312676873e+51*cos(theta)**3 - 4.55378501414984e+49*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl42_m_minus_30(theta, phi):
    return 1.02870315144741e-47*(1.0 - cos(theta)**2)**15*(1.11971881266677e+54*cos(theta)**12 - 8.90378814891648e+53*cos(theta)**10 + 2.47327448581013e+53*cos(theta)**8 - 2.92201205074615e+52*cos(theta)**6 + 1.42305781692183e+51*cos(theta)**4 - 2.27689250707492e+49*cos(theta)**2 + 5.19838471934914e+46)*sin(30*phi)

#@torch.jit.script
def Yl42_m_minus_29(theta, phi):
    return 3.14722646575483e-46*(1.0 - cos(theta)**2)**14.5*(8.61322163589823e+52*cos(theta)**13 - 8.09435286265135e+52*cos(theta)**11 + 2.74808276201126e+52*cos(theta)**9 - 4.17430292963736e+51*cos(theta)**7 + 2.84611563384365e+50*cos(theta)**5 - 7.58964169024974e+48*cos(theta)**3 + 5.19838471934914e+46*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl42_m_minus_28(theta, phi):
    return 9.92250181163357e-45*(1.0 - cos(theta)**2)**14*(6.15230116849873e+51*cos(theta)**14 - 6.74529405220946e+51*cos(theta)**12 + 2.74808276201126e+51*cos(theta)**10 - 5.2178786620467e+50*cos(theta)**8 + 4.74352605640609e+49*cos(theta)**6 - 1.89741042256243e+48*cos(theta)**4 + 2.59919235967457e+46*cos(theta)**2 - 5.229763299144e+43)*sin(28*phi)

#@torch.jit.script
def Yl42_m_minus_27(theta, phi):
    return 3.21525806603397e-43*(1.0 - cos(theta)**2)**13.5*(4.10153411233249e+50*cos(theta)**15 - 5.18868773246881e+50*cos(theta)**13 + 2.49825705637387e+50*cos(theta)**11 - 5.79764295782966e+49*cos(theta)**9 + 6.77646579486584e+48*cos(theta)**7 - 3.79482084512487e+47*cos(theta)**5 + 8.66397453224856e+45*cos(theta)**3 - 5.229763299144e+43*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl42_m_minus_26(theta, phi):
    return 1.0683175750703e-41*(1.0 - cos(theta)**2)**13*(2.56345882020781e+49*cos(theta)**16 - 3.70620552319201e+49*cos(theta)**14 + 2.08188088031156e+49*cos(theta)**12 - 5.79764295782966e+48*cos(theta)**10 + 8.4705822435823e+47*cos(theta)**8 - 6.32470140854145e+46*cos(theta)**6 + 2.16599363306214e+45*cos(theta)**4 - 2.614881649572e+43*cos(theta)**2 + 4.73710443763043e+40)*sin(26*phi)

#@torch.jit.script
def Yl42_m_minus_25(theta, phi):
    return 3.63227975523903e-40*(1.0 - cos(theta)**2)**12.5*(1.50791695306342e+48*cos(theta)**17 - 2.47080368212801e+48*cos(theta)**15 + 1.60144683100889e+48*cos(theta)**13 - 5.27058450711787e+47*cos(theta)**11 + 9.41175804842478e+46*cos(theta)**9 - 9.03528772648778e+45*cos(theta)**7 + 4.33198726612428e+44*cos(theta)**5 - 8.71627216524e+42*cos(theta)**3 + 4.73710443763043e+40*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl42_m_minus_24(theta, phi):
    return 1.26140034095862e-38*(1.0 - cos(theta)**2)**12*(8.37731640590786e+46*cos(theta)**18 - 1.54425230133e+47*cos(theta)**16 + 1.14389059357778e+47*cos(theta)**14 - 4.39215375593156e+46*cos(theta)**12 + 9.41175804842478e+45*cos(theta)**10 - 1.12941096581097e+45*cos(theta)**8 + 7.2199787768738e+43*cos(theta)**6 - 2.17906804131e+42*cos(theta)**4 + 2.36855221881522e+40*cos(theta)**2 - 3.92794729488427e+37)*sin(24*phi)

#@torch.jit.script
def Yl42_m_minus_23(theta, phi):
    return 4.46685353296235e-37*(1.0 - cos(theta)**2)**11.5*(4.40911389784624e+45*cos(theta)**19 - 9.08383706664708e+45*cos(theta)**17 + 7.62593729051854e+45*cos(theta)**15 - 3.37857981225505e+45*cos(theta)**13 + 8.55614368038616e+44*cos(theta)**11 - 1.2549010731233e+44*cos(theta)**9 + 1.0314255395534e+43*cos(theta)**7 - 4.35813608262e+41*cos(theta)**5 + 7.89517406271739e+39*cos(theta)**3 - 3.92794729488427e+37*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl42_m_minus_22(theta, phi):
    return 1.61054694530832e-35*(1.0 - cos(theta)**2)**11*(2.20455694892312e+44*cos(theta)**20 - 5.04657614813727e+44*cos(theta)**18 + 4.76621080657408e+44*cos(theta)**16 - 2.41327129446789e+44*cos(theta)**14 + 7.13011973365513e+43*cos(theta)**12 - 1.2549010731233e+43*cos(theta)**10 + 1.28928192444175e+42*cos(theta)**8 - 7.2635601377e+40*cos(theta)**6 + 1.97379351567935e+39*cos(theta)**4 - 1.96397364744214e+37*cos(theta)**2 + 3.02149791914175e+34)*sin(22*phi)

#@torch.jit.script
def Yl42_m_minus_21(theta, phi):
    return 5.90436262972423e-34*(1.0 - cos(theta)**2)**10.5*(1.04978902329672e+43*cos(theta)**21 - 2.65609270954593e+43*cos(theta)**19 + 2.80365341563181e+43*cos(theta)**17 - 1.60884752964526e+43*cos(theta)**15 + 5.48470748742703e+42*cos(theta)**13 - 1.14081915738482e+42*cos(theta)**11 + 1.43253547160194e+41*cos(theta)**9 - 1.03765144824286e+40*cos(theta)**7 + 3.9475870313587e+38*cos(theta)**5 - 6.54657882480712e+36*cos(theta)**3 + 3.02149791914175e+34*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl42_m_minus_20(theta, phi):
    return 2.19813639967386e-32*(1.0 - cos(theta)**2)**10*(4.77176828771238e+41*cos(theta)**22 - 1.32804635477296e+42*cos(theta)**20 + 1.55758523090656e+42*cos(theta)**18 - 1.00552970602829e+42*cos(theta)**16 + 3.91764820530502e+41*cos(theta)**14 - 9.50682631154018e+40*cos(theta)**12 + 1.43253547160194e+40*cos(theta)**10 - 1.29706431030357e+39*cos(theta)**8 + 6.57931171893116e+37*cos(theta)**6 - 1.63664470620178e+36*cos(theta)**4 + 1.51074895957087e+34*cos(theta)**2 - 2.1800129286737e+31)*sin(20*phi)

#@torch.jit.script
def Yl42_m_minus_19(theta, phi):
    return 8.30069393401569e-31*(1.0 - cos(theta)**2)**9.5*(2.07468186422278e+40*cos(theta)**23 - 6.32403026082364e+40*cos(theta)**21 + 8.19781700477139e+40*cos(theta)**19 - 5.91488062369581e+40*cos(theta)**17 + 2.61176547020335e+40*cos(theta)**15 - 7.31294331656937e+39*cos(theta)**13 + 1.30230497418359e+39*cos(theta)**11 - 1.44118256700397e+38*cos(theta)**9 + 9.39901674133023e+36*cos(theta)**7 - 3.27328941240356e+35*cos(theta)**5 + 5.03582986523625e+33*cos(theta)**3 - 2.1800129286737e+31*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl42_m_minus_18(theta, phi):
    return 3.17603250876001e-29*(1.0 - cos(theta)**2)**9*(8.6445077675949e+38*cos(theta)**24 - 2.87455920946529e+39*cos(theta)**22 + 4.09890850238569e+39*cos(theta)**20 - 3.28604479094212e+39*cos(theta)**18 + 1.63235341887709e+39*cos(theta)**16 - 5.22353094040669e+38*cos(theta)**14 + 1.08525414515299e+38*cos(theta)**12 - 1.44118256700397e+37*cos(theta)**10 + 1.17487709266628e+36*cos(theta)**8 - 5.45548235400594e+34*cos(theta)**6 + 1.25895746630906e+33*cos(theta)**4 - 1.09000646433685e+31*cos(theta)**2 + 1.48907986931264e+28)*sin(18*phi)

#@torch.jit.script
def Yl42_m_minus_17(theta, phi):
    return 1.23007210134409e-27*(1.0 - cos(theta)**2)**8.5*(3.45780310703796e+37*cos(theta)**25 - 1.24980835194143e+38*cos(theta)**23 + 1.95186119161224e+38*cos(theta)**21 - 1.72949725839059e+38*cos(theta)**19 + 9.60207893457112e+37*cos(theta)**17 - 3.48235396027113e+37*cos(theta)**15 + 8.34810880886914e+36*cos(theta)**13 - 1.31016597000361e+36*cos(theta)**11 + 1.30541899185142e+35*cos(theta)**9 - 7.79354622000848e+33*cos(theta)**7 + 2.51791493261812e+32*cos(theta)**5 - 3.63335488112284e+30*cos(theta)**3 + 1.48907986931264e+28*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl42_m_minus_16(theta, phi):
    return 4.81773877715548e-26*(1.0 - cos(theta)**2)**8*(1.32992427193768e+36*cos(theta)**26 - 5.20753479975596e+36*cos(theta)**24 + 8.87209632551016e+36*cos(theta)**22 - 8.64748629195294e+36*cos(theta)**20 + 5.33448829698396e+36*cos(theta)**18 - 2.17647122516945e+36*cos(theta)**16 + 5.96293486347796e+35*cos(theta)**14 - 1.09180497500301e+35*cos(theta)**12 + 1.30541899185142e+34*cos(theta)**10 - 9.7419327750106e+32*cos(theta)**8 + 4.19652488769687e+31*cos(theta)**6 - 9.08338720280709e+29*cos(theta)**4 + 7.44539934656319e+27*cos(theta)**2 - 9.70716994336791e+24)*sin(16*phi)

#@torch.jit.script
def Yl42_m_minus_15(theta, phi):
    return 1.90651017422948e-24*(1.0 - cos(theta)**2)**7.5*(4.92564545162103e+34*cos(theta)**27 - 2.08301391990239e+35*cos(theta)**25 + 3.85743318500442e+35*cos(theta)**23 - 4.11785061521569e+35*cos(theta)**21 + 2.80762541946524e+35*cos(theta)**19 - 1.28027719127615e+35*cos(theta)**17 + 3.97528990898531e+34*cos(theta)**15 - 8.39849980771543e+33*cos(theta)**13 + 1.18674453804675e+33*cos(theta)**11 - 1.08243697500118e+32*cos(theta)**9 + 5.99503555385268e+30*cos(theta)**7 - 1.81667744056142e+29*cos(theta)**5 + 2.48179978218773e+27*cos(theta)**3 - 9.70716994336791e+24*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl42_m_minus_14(theta, phi):
    return 7.61650218074352e-23*(1.0 - cos(theta)**2)**7*(1.75915908986465e+33*cos(theta)**28 - 8.01159199962456e+33*cos(theta)**26 + 1.60726382708517e+34*cos(theta)**24 - 1.87175027964349e+34*cos(theta)**22 + 1.40381270973262e+34*cos(theta)**20 - 7.11265106264528e+33*cos(theta)**18 + 2.48455619311582e+33*cos(theta)**16 - 5.99892843408245e+32*cos(theta)**14 + 9.88953781705622e+31*cos(theta)**12 - 1.08243697500118e+31*cos(theta)**10 + 7.49379444231585e+29*cos(theta)**8 - 3.02779573426903e+28*cos(theta)**6 + 6.20449945546932e+26*cos(theta)**4 - 4.85358497168395e+24*cos(theta)**2 + 6.08218668130821e+21)*sin(14*phi)

#@torch.jit.script
def Yl42_m_minus_13(theta, phi):
    return 3.06936532987026e-21*(1.0 - cos(theta)**2)**6.5*(6.06606582711949e+31*cos(theta)**29 - 2.96725629615724e+32*cos(theta)**27 + 6.4290553083407e+32*cos(theta)**25 - 8.13804469410215e+32*cos(theta)**23 + 6.68482242729819e+32*cos(theta)**21 - 3.74350055928699e+32*cos(theta)**19 + 1.4615036430093e+32*cos(theta)**17 - 3.99928562272163e+31*cos(theta)**15 + 7.60733678235094e+30*cos(theta)**13 - 9.84033613637434e+29*cos(theta)**11 + 8.32643826923983e+28*cos(theta)**9 - 4.32542247752718e+27*cos(theta)**7 + 1.24089989109386e+26*cos(theta)**5 - 1.61786165722798e+24*cos(theta)**3 + 6.08218668130821e+21*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl42_m_minus_12(theta, phi):
    return 1.24678209088621e-19*(1.0 - cos(theta)**2)**6*(2.02202194237316e+30*cos(theta)**30 - 1.05973439148473e+31*cos(theta)**28 + 2.47271358013104e+31*cos(theta)**26 - 3.39085195587589e+31*cos(theta)**24 + 3.03855564877191e+31*cos(theta)**22 - 1.87175027964349e+31*cos(theta)**20 + 8.11946468338502e+30*cos(theta)**18 - 2.49955351420102e+30*cos(theta)**16 + 5.43381198739353e+29*cos(theta)**14 - 8.20028011364529e+28*cos(theta)**12 + 8.32643826923983e+27*cos(theta)**10 - 5.40677809690898e+26*cos(theta)**8 + 2.06816648515644e+25*cos(theta)**6 - 4.04465414306996e+23*cos(theta)**4 + 3.04109334065411e+21*cos(theta)**2 - 3.6861737462474e+18)*sin(12*phi)

#@torch.jit.script
def Yl42_m_minus_11(theta, phi):
    return 5.10115220761621e-18*(1.0 - cos(theta)**2)**5.5*(6.5226514270102e+28*cos(theta)**31 - 3.65425652236114e+29*cos(theta)**29 + 9.15819844492977e+29*cos(theta)**27 - 1.35634078235036e+30*cos(theta)**25 + 1.32111115163996e+30*cos(theta)**23 - 8.91309656973092e+29*cos(theta)**21 + 4.27340246493948e+29*cos(theta)**19 - 1.47032559658884e+29*cos(theta)**17 + 3.62254132492902e+28*cos(theta)**15 - 6.30790777972714e+27*cos(theta)**13 + 7.56948933567257e+26*cos(theta)**11 - 6.00753121878776e+25*cos(theta)**9 + 2.95452355022349e+24*cos(theta)**7 - 8.08930828613992e+22*cos(theta)**5 + 1.01369778021804e+21*cos(theta)**3 - 3.6861737462474e+18*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl42_m_minus_10(theta, phi):
    return 2.10078305689983e-16*(1.0 - cos(theta)**2)**5*(2.03832857094069e+27*cos(theta)**32 - 1.21808550745371e+28*cos(theta)**30 + 3.27078515890349e+28*cos(theta)**28 - 5.21669531673214e+28*cos(theta)**26 + 5.50462979849983e+28*cos(theta)**24 - 4.05140753169587e+28*cos(theta)**22 + 2.13670123246974e+28*cos(theta)**20 - 8.16847553660465e+27*cos(theta)**18 + 2.26408832808064e+27*cos(theta)**16 - 4.50564841409082e+26*cos(theta)**14 + 6.30790777972714e+25*cos(theta)**12 - 6.00753121878776e+24*cos(theta)**10 + 3.69315443777936e+23*cos(theta)**8 - 1.34821804768999e+22*cos(theta)**6 + 2.53424445054509e+20*cos(theta)**4 - 1.8430868731237e+18*cos(theta)**2 + 2.17345150132512e+15)*sin(10*phi)

#@torch.jit.script
def Yl42_m_minus_9(theta, phi):
    return 8.70241615868955e-15*(1.0 - cos(theta)**2)**4.5*(6.17675324527481e+25*cos(theta)**33 - 3.92930808856036e+26*cos(theta)**31 + 1.12785695134603e+27*cos(theta)**29 - 1.93210937656746e+27*cos(theta)**27 + 2.20185191939993e+27*cos(theta)**25 - 1.76148153551995e+27*cos(theta)**23 + 1.01747677736654e+27*cos(theta)**21 - 4.29919765084455e+26*cos(theta)**19 + 1.33181666357684e+26*cos(theta)**17 - 3.00376560939388e+25*cos(theta)**15 + 4.85223675363626e+24*cos(theta)**13 - 5.46139201707978e+23*cos(theta)**11 + 4.10350493086595e+22*cos(theta)**9 - 1.92602578241427e+21*cos(theta)**7 + 5.06848890109018e+19*cos(theta)**5 - 6.14362291041234e+17*cos(theta)**3 + 2.17345150132512e+15*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl42_m_minus_8(theta, phi):
    return 3.62380145008391e-13*(1.0 - cos(theta)**2)**4*(1.81669213096318e+24*cos(theta)**34 - 1.22790877767511e+25*cos(theta)**32 + 3.75952317115343e+25*cos(theta)**30 - 6.90039063059808e+25*cos(theta)**28 + 8.46866122846127e+25*cos(theta)**26 - 7.33950639799977e+25*cos(theta)**24 + 4.6248944425752e+25*cos(theta)**22 - 2.14959882542228e+25*cos(theta)**20 + 7.3989814643158e+24*cos(theta)**18 - 1.87735350587117e+24*cos(theta)**16 + 3.46588339545447e+23*cos(theta)**14 - 4.55116001423315e+22*cos(theta)**12 + 4.10350493086595e+21*cos(theta)**10 - 2.40753222801783e+20*cos(theta)**8 + 8.44748150181696e+18*cos(theta)**6 - 1.53590572760308e+17*cos(theta)**4 + 1.08672575066256e+15*cos(theta)**2 - 1253432238365.12)*sin(8*phi)

#@torch.jit.script
def Yl42_m_minus_7(theta, phi):
    return 1.51594490869071e-11*(1.0 - cos(theta)**2)**3.5*(5.19054894560909e+22*cos(theta)**35 - 3.72093568992459e+23*cos(theta)**33 + 1.21274941004949e+24*cos(theta)**31 - 2.37944504503382e+24*cos(theta)**29 + 3.1365411957264e+24*cos(theta)**27 - 2.93580255919991e+24*cos(theta)**25 + 2.01082367068487e+24*cos(theta)**23 - 1.02361848829632e+24*cos(theta)**21 + 3.89420077069253e+23*cos(theta)**19 - 1.10432559168893e+23*cos(theta)**17 + 2.31058893030298e+22*cos(theta)**15 - 3.50089231864088e+21*cos(theta)**13 + 3.73045902805996e+20*cos(theta)**11 - 2.67503580890871e+19*cos(theta)**9 + 1.20678307168814e+18*cos(theta)**7 - 3.07181145520617e+16*cos(theta)**5 + 362241916887520.0*cos(theta)**3 - 1253432238365.12*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl42_m_minus_6(theta, phi):
    return 6.36696861650099e-10*(1.0 - cos(theta)**2)**3*(1.44181915155808e+21*cos(theta)**36 - 1.09439284997782e+22*cos(theta)**34 + 3.78984190640467e+22*cos(theta)**32 - 7.93148348344606e+22*cos(theta)**30 + 1.120193284188e+23*cos(theta)**28 - 1.1291548304615e+23*cos(theta)**26 + 8.37843196118695e+22*cos(theta)**24 - 4.65281131043783e+22*cos(theta)**22 + 1.94710038534626e+22*cos(theta)**20 - 6.13514217604959e+21*cos(theta)**18 + 1.44411808143936e+21*cos(theta)**16 - 2.50063737045777e+20*cos(theta)**14 + 3.10871585671663e+19*cos(theta)**12 - 2.67503580890871e+18*cos(theta)**10 + 1.50847883961017e+17*cos(theta)**8 - 5.11968575867695e+15*cos(theta)**6 + 90560479221880.0*cos(theta)**4 - 626716119182.56*cos(theta)**2 + 710562493.404263)*sin(6*phi)

#@torch.jit.script
def Yl42_m_minus_5(theta, phi):
    return 2.68320707194937e-8*(1.0 - cos(theta)**2)**2.5*(3.89680851772454e+19*cos(theta)**37 - 3.12683671422234e+20*cos(theta)**35 + 1.14843694133475e+21*cos(theta)**33 - 2.55854305917615e+21*cos(theta)**31 + 3.86273546271724e+21*cos(theta)**29 - 4.1820549276352e+21*cos(theta)**27 + 3.35137278447478e+21*cos(theta)**25 - 2.02296143932079e+21*cos(theta)**23 + 9.27190659688697e+20*cos(theta)**21 - 3.22902219792084e+20*cos(theta)**19 + 8.49481224376097e+19*cos(theta)**17 - 1.66709158030518e+19*cos(theta)**15 + 2.39131988978202e+18*cos(theta)**13 - 2.43185073537155e+17*cos(theta)**11 + 1.67608759956686e+16*cos(theta)**9 - 731383679810993.0*cos(theta)**7 + 18112095844376.0*cos(theta)**5 - 208905373060.853*cos(theta)**3 + 710562493.404263*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl42_m_minus_4(theta, phi):
    return 1.13395264191469e-6*(1.0 - cos(theta)**2)**2*(1.02547592571698e+18*cos(theta)**38 - 8.6856575395065e+18*cos(theta)**36 + 3.37775570980809e+19*cos(theta)**34 - 7.99544705992547e+19*cos(theta)**32 + 1.28757848757241e+20*cos(theta)**30 - 1.493591045584e+20*cos(theta)**28 + 1.2889895324903e+20*cos(theta)**26 - 8.42900599716997e+19*cos(theta)**24 + 4.21450299858499e+19*cos(theta)**22 - 1.61451109896042e+19*cos(theta)**20 + 4.71934013542276e+18*cos(theta)**18 - 1.04193223769074e+18*cos(theta)**16 + 1.70808563555859e+17*cos(theta)**14 - 2.02654227947629e+16*cos(theta)**12 + 1.67608759956686e+15*cos(theta)**10 - 91422959976374.1*cos(theta)**8 + 3018682640729.33*cos(theta)**6 - 52226343265.2134*cos(theta)**4 + 355281246.702132*cos(theta)**2 - 397851.340091973)*sin(4*phi)

#@torch.jit.script
def Yl42_m_minus_3(theta, phi):
    return 4.80292866678749e-5*(1.0 - cos(theta)**2)**1.5*(2.62942545055637e+16*cos(theta)**39 - 2.34747501067743e+17*cos(theta)**37 + 9.65073059945167e+17*cos(theta)**35 - 2.42286274543196e+18*cos(theta)**33 + 4.15347899216907e+18*cos(theta)**31 - 5.15031395028965e+18*cos(theta)**29 + 4.77403530551963e+18*cos(theta)**27 - 3.37160239886799e+18*cos(theta)**25 + 1.83239260808043e+18*cos(theta)**23 - 7.6881480902877e+17*cos(theta)**21 + 2.48386322916987e+17*cos(theta)**19 - 6.1290131628867e+16*cos(theta)**17 + 1.13872375703906e+16*cos(theta)**15 - 1.55887867652022e+15*cos(theta)**13 + 152371599960623.0*cos(theta)**11 - 10158106664041.6*cos(theta)**9 + 431240377247.047*cos(theta)**7 - 10445268653.0427*cos(theta)**5 + 118427082.234044*cos(theta)**3 - 397851.340091973*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl42_m_minus_2(theta, phi):
    return 0.00203771005790442*(1.0 - cos(theta)**2)*(657356362639093.0*cos(theta)**40 - 6.17756581757219e+15*cos(theta)**38 + 2.68075849984769e+16*cos(theta)**36 - 7.12606689832929e+16*cos(theta)**34 + 1.29796218505284e+17*cos(theta)**32 - 1.71677131676322e+17*cos(theta)**30 + 1.70501260911415e+17*cos(theta)**28 - 1.29677015341077e+17*cos(theta)**26 + 7.63496920033512e+16*cos(theta)**24 - 3.49461276831259e+16*cos(theta)**22 + 1.24193161458494e+16*cos(theta)**20 - 3.40500731271483e+15*cos(theta)**18 + 711702348149412.0*cos(theta)**16 - 111348476894302.0*cos(theta)**14 + 12697633330052.0*cos(theta)**12 - 1015810666404.16*cos(theta)**10 + 53905047155.8809*cos(theta)**8 - 1740878108.84045*cos(theta)**6 + 29606770.558511*cos(theta)**4 - 198925.670045986*cos(theta)**2 + 221.028522273318)*sin(2*phi)

#@torch.jit.script
def Yl42_m_minus_1(theta, phi):
    return 0.0865487212688497*(1.0 - cos(theta)**2)**0.5*(16033082015587.6*cos(theta)**41 - 158399123527492.0*cos(theta)**39 + 724529324283159.0*cos(theta)**37 - 2.03601911380837e+15*cos(theta)**35 + 3.93321874258435e+15*cos(theta)**33 - 5.53797198955877e+15*cos(theta)**31 + 5.87935382453157e+15*cos(theta)**29 - 4.80285242003987e+15*cos(theta)**27 + 3.05398768013405e+15*cos(theta)**25 - 1.51939685578808e+15*cos(theta)**23 + 591396006945208.0*cos(theta)**21 - 179210911195518.0*cos(theta)**19 + 41864844008788.9*cos(theta)**17 - 7423231792953.45*cos(theta)**15 + 976741025388.612*cos(theta)**13 - 92346424218.5597*cos(theta)**11 + 5989449683.98677*cos(theta)**9 - 248696872.691492*cos(theta)**7 + 5921354.1117022*cos(theta)**5 - 66308.5566819955*cos(theta)**3 + 221.028522273318*cos(theta))*sin(phi)

#@torch.jit.script
def Yl42_m0(theta, phi):
    return 3119048495581.35*cos(theta)**42 - 32355430779464.4*cos(theta)**40 + 155785407456680.0*cos(theta)**38 - 462097643215385.0*cos(theta)**36 + 945199724758743.0*cos(theta)**34 - 1.41401878823908e+15*cos(theta)**32 + 1.60126328531183e+15*cos(theta)**30 - 1.40150810686247e+15*cos(theta)**28 + 959728377525387.0*cos(theta)**26 - 517266538467249.0*cos(theta)**24 + 219639330179939.0*cos(theta)**22 - 73213110059979.8*cos(theta)**20 + 19003402884421.0*cos(theta)**18 - 3790770066905.36*cos(theta)**16 + 570040611564.716*cos(theta)**14 - 62877206851.3808*cos(theta)**12 + 4893744872.8669*cos(theta)**10 - 254000598.937728*cos(theta)**8 + 8063511.0773882*cos(theta)**6 - 135445.314849746*cos(theta)**4 + 902.968765664972*cos(theta)**2 - 0.999965410481697

#@torch.jit.script
def Yl42_m1(theta, phi):
    return 0.0865487212688497*(1.0 - cos(theta)**2)**0.5*(16033082015587.6*cos(theta)**41 - 158399123527492.0*cos(theta)**39 + 724529324283159.0*cos(theta)**37 - 2.03601911380837e+15*cos(theta)**35 + 3.93321874258435e+15*cos(theta)**33 - 5.53797198955877e+15*cos(theta)**31 + 5.87935382453157e+15*cos(theta)**29 - 4.80285242003987e+15*cos(theta)**27 + 3.05398768013405e+15*cos(theta)**25 - 1.51939685578808e+15*cos(theta)**23 + 591396006945208.0*cos(theta)**21 - 179210911195518.0*cos(theta)**19 + 41864844008788.9*cos(theta)**17 - 7423231792953.45*cos(theta)**15 + 976741025388.612*cos(theta)**13 - 92346424218.5597*cos(theta)**11 + 5989449683.98677*cos(theta)**9 - 248696872.691492*cos(theta)**7 + 5921354.1117022*cos(theta)**5 - 66308.5566819955*cos(theta)**3 + 221.028522273318*cos(theta))*cos(phi)

#@torch.jit.script
def Yl42_m2(theta, phi):
    return 0.00203771005790442*(1.0 - cos(theta)**2)*(657356362639093.0*cos(theta)**40 - 6.17756581757219e+15*cos(theta)**38 + 2.68075849984769e+16*cos(theta)**36 - 7.12606689832929e+16*cos(theta)**34 + 1.29796218505284e+17*cos(theta)**32 - 1.71677131676322e+17*cos(theta)**30 + 1.70501260911415e+17*cos(theta)**28 - 1.29677015341077e+17*cos(theta)**26 + 7.63496920033512e+16*cos(theta)**24 - 3.49461276831259e+16*cos(theta)**22 + 1.24193161458494e+16*cos(theta)**20 - 3.40500731271483e+15*cos(theta)**18 + 711702348149412.0*cos(theta)**16 - 111348476894302.0*cos(theta)**14 + 12697633330052.0*cos(theta)**12 - 1015810666404.16*cos(theta)**10 + 53905047155.8809*cos(theta)**8 - 1740878108.84045*cos(theta)**6 + 29606770.558511*cos(theta)**4 - 198925.670045986*cos(theta)**2 + 221.028522273318)*cos(2*phi)

#@torch.jit.script
def Yl42_m3(theta, phi):
    return 4.80292866678749e-5*(1.0 - cos(theta)**2)**1.5*(2.62942545055637e+16*cos(theta)**39 - 2.34747501067743e+17*cos(theta)**37 + 9.65073059945167e+17*cos(theta)**35 - 2.42286274543196e+18*cos(theta)**33 + 4.15347899216907e+18*cos(theta)**31 - 5.15031395028965e+18*cos(theta)**29 + 4.77403530551963e+18*cos(theta)**27 - 3.37160239886799e+18*cos(theta)**25 + 1.83239260808043e+18*cos(theta)**23 - 7.6881480902877e+17*cos(theta)**21 + 2.48386322916987e+17*cos(theta)**19 - 6.1290131628867e+16*cos(theta)**17 + 1.13872375703906e+16*cos(theta)**15 - 1.55887867652022e+15*cos(theta)**13 + 152371599960623.0*cos(theta)**11 - 10158106664041.6*cos(theta)**9 + 431240377247.047*cos(theta)**7 - 10445268653.0427*cos(theta)**5 + 118427082.234044*cos(theta)**3 - 397851.340091973*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl42_m4(theta, phi):
    return 1.13395264191469e-6*(1.0 - cos(theta)**2)**2*(1.02547592571698e+18*cos(theta)**38 - 8.6856575395065e+18*cos(theta)**36 + 3.37775570980809e+19*cos(theta)**34 - 7.99544705992547e+19*cos(theta)**32 + 1.28757848757241e+20*cos(theta)**30 - 1.493591045584e+20*cos(theta)**28 + 1.2889895324903e+20*cos(theta)**26 - 8.42900599716997e+19*cos(theta)**24 + 4.21450299858499e+19*cos(theta)**22 - 1.61451109896042e+19*cos(theta)**20 + 4.71934013542276e+18*cos(theta)**18 - 1.04193223769074e+18*cos(theta)**16 + 1.70808563555859e+17*cos(theta)**14 - 2.02654227947629e+16*cos(theta)**12 + 1.67608759956686e+15*cos(theta)**10 - 91422959976374.1*cos(theta)**8 + 3018682640729.33*cos(theta)**6 - 52226343265.2134*cos(theta)**4 + 355281246.702132*cos(theta)**2 - 397851.340091973)*cos(4*phi)

#@torch.jit.script
def Yl42_m5(theta, phi):
    return 2.68320707194937e-8*(1.0 - cos(theta)**2)**2.5*(3.89680851772454e+19*cos(theta)**37 - 3.12683671422234e+20*cos(theta)**35 + 1.14843694133475e+21*cos(theta)**33 - 2.55854305917615e+21*cos(theta)**31 + 3.86273546271724e+21*cos(theta)**29 - 4.1820549276352e+21*cos(theta)**27 + 3.35137278447478e+21*cos(theta)**25 - 2.02296143932079e+21*cos(theta)**23 + 9.27190659688697e+20*cos(theta)**21 - 3.22902219792084e+20*cos(theta)**19 + 8.49481224376097e+19*cos(theta)**17 - 1.66709158030518e+19*cos(theta)**15 + 2.39131988978202e+18*cos(theta)**13 - 2.43185073537155e+17*cos(theta)**11 + 1.67608759956686e+16*cos(theta)**9 - 731383679810993.0*cos(theta)**7 + 18112095844376.0*cos(theta)**5 - 208905373060.853*cos(theta)**3 + 710562493.404263*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl42_m6(theta, phi):
    return 6.36696861650099e-10*(1.0 - cos(theta)**2)**3*(1.44181915155808e+21*cos(theta)**36 - 1.09439284997782e+22*cos(theta)**34 + 3.78984190640467e+22*cos(theta)**32 - 7.93148348344606e+22*cos(theta)**30 + 1.120193284188e+23*cos(theta)**28 - 1.1291548304615e+23*cos(theta)**26 + 8.37843196118695e+22*cos(theta)**24 - 4.65281131043783e+22*cos(theta)**22 + 1.94710038534626e+22*cos(theta)**20 - 6.13514217604959e+21*cos(theta)**18 + 1.44411808143936e+21*cos(theta)**16 - 2.50063737045777e+20*cos(theta)**14 + 3.10871585671663e+19*cos(theta)**12 - 2.67503580890871e+18*cos(theta)**10 + 1.50847883961017e+17*cos(theta)**8 - 5.11968575867695e+15*cos(theta)**6 + 90560479221880.0*cos(theta)**4 - 626716119182.56*cos(theta)**2 + 710562493.404263)*cos(6*phi)

#@torch.jit.script
def Yl42_m7(theta, phi):
    return 1.51594490869071e-11*(1.0 - cos(theta)**2)**3.5*(5.19054894560909e+22*cos(theta)**35 - 3.72093568992459e+23*cos(theta)**33 + 1.21274941004949e+24*cos(theta)**31 - 2.37944504503382e+24*cos(theta)**29 + 3.1365411957264e+24*cos(theta)**27 - 2.93580255919991e+24*cos(theta)**25 + 2.01082367068487e+24*cos(theta)**23 - 1.02361848829632e+24*cos(theta)**21 + 3.89420077069253e+23*cos(theta)**19 - 1.10432559168893e+23*cos(theta)**17 + 2.31058893030298e+22*cos(theta)**15 - 3.50089231864088e+21*cos(theta)**13 + 3.73045902805996e+20*cos(theta)**11 - 2.67503580890871e+19*cos(theta)**9 + 1.20678307168814e+18*cos(theta)**7 - 3.07181145520617e+16*cos(theta)**5 + 362241916887520.0*cos(theta)**3 - 1253432238365.12*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl42_m8(theta, phi):
    return 3.62380145008391e-13*(1.0 - cos(theta)**2)**4*(1.81669213096318e+24*cos(theta)**34 - 1.22790877767511e+25*cos(theta)**32 + 3.75952317115343e+25*cos(theta)**30 - 6.90039063059808e+25*cos(theta)**28 + 8.46866122846127e+25*cos(theta)**26 - 7.33950639799977e+25*cos(theta)**24 + 4.6248944425752e+25*cos(theta)**22 - 2.14959882542228e+25*cos(theta)**20 + 7.3989814643158e+24*cos(theta)**18 - 1.87735350587117e+24*cos(theta)**16 + 3.46588339545447e+23*cos(theta)**14 - 4.55116001423315e+22*cos(theta)**12 + 4.10350493086595e+21*cos(theta)**10 - 2.40753222801783e+20*cos(theta)**8 + 8.44748150181696e+18*cos(theta)**6 - 1.53590572760308e+17*cos(theta)**4 + 1.08672575066256e+15*cos(theta)**2 - 1253432238365.12)*cos(8*phi)

#@torch.jit.script
def Yl42_m9(theta, phi):
    return 8.70241615868955e-15*(1.0 - cos(theta)**2)**4.5*(6.17675324527481e+25*cos(theta)**33 - 3.92930808856036e+26*cos(theta)**31 + 1.12785695134603e+27*cos(theta)**29 - 1.93210937656746e+27*cos(theta)**27 + 2.20185191939993e+27*cos(theta)**25 - 1.76148153551995e+27*cos(theta)**23 + 1.01747677736654e+27*cos(theta)**21 - 4.29919765084455e+26*cos(theta)**19 + 1.33181666357684e+26*cos(theta)**17 - 3.00376560939388e+25*cos(theta)**15 + 4.85223675363626e+24*cos(theta)**13 - 5.46139201707978e+23*cos(theta)**11 + 4.10350493086595e+22*cos(theta)**9 - 1.92602578241427e+21*cos(theta)**7 + 5.06848890109018e+19*cos(theta)**5 - 6.14362291041234e+17*cos(theta)**3 + 2.17345150132512e+15*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl42_m10(theta, phi):
    return 2.10078305689983e-16*(1.0 - cos(theta)**2)**5*(2.03832857094069e+27*cos(theta)**32 - 1.21808550745371e+28*cos(theta)**30 + 3.27078515890349e+28*cos(theta)**28 - 5.21669531673214e+28*cos(theta)**26 + 5.50462979849983e+28*cos(theta)**24 - 4.05140753169587e+28*cos(theta)**22 + 2.13670123246974e+28*cos(theta)**20 - 8.16847553660465e+27*cos(theta)**18 + 2.26408832808064e+27*cos(theta)**16 - 4.50564841409082e+26*cos(theta)**14 + 6.30790777972714e+25*cos(theta)**12 - 6.00753121878776e+24*cos(theta)**10 + 3.69315443777936e+23*cos(theta)**8 - 1.34821804768999e+22*cos(theta)**6 + 2.53424445054509e+20*cos(theta)**4 - 1.8430868731237e+18*cos(theta)**2 + 2.17345150132512e+15)*cos(10*phi)

#@torch.jit.script
def Yl42_m11(theta, phi):
    return 5.10115220761621e-18*(1.0 - cos(theta)**2)**5.5*(6.5226514270102e+28*cos(theta)**31 - 3.65425652236114e+29*cos(theta)**29 + 9.15819844492977e+29*cos(theta)**27 - 1.35634078235036e+30*cos(theta)**25 + 1.32111115163996e+30*cos(theta)**23 - 8.91309656973092e+29*cos(theta)**21 + 4.27340246493948e+29*cos(theta)**19 - 1.47032559658884e+29*cos(theta)**17 + 3.62254132492902e+28*cos(theta)**15 - 6.30790777972714e+27*cos(theta)**13 + 7.56948933567257e+26*cos(theta)**11 - 6.00753121878776e+25*cos(theta)**9 + 2.95452355022349e+24*cos(theta)**7 - 8.08930828613992e+22*cos(theta)**5 + 1.01369778021804e+21*cos(theta)**3 - 3.6861737462474e+18*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl42_m12(theta, phi):
    return 1.24678209088621e-19*(1.0 - cos(theta)**2)**6*(2.02202194237316e+30*cos(theta)**30 - 1.05973439148473e+31*cos(theta)**28 + 2.47271358013104e+31*cos(theta)**26 - 3.39085195587589e+31*cos(theta)**24 + 3.03855564877191e+31*cos(theta)**22 - 1.87175027964349e+31*cos(theta)**20 + 8.11946468338502e+30*cos(theta)**18 - 2.49955351420102e+30*cos(theta)**16 + 5.43381198739353e+29*cos(theta)**14 - 8.20028011364529e+28*cos(theta)**12 + 8.32643826923983e+27*cos(theta)**10 - 5.40677809690898e+26*cos(theta)**8 + 2.06816648515644e+25*cos(theta)**6 - 4.04465414306996e+23*cos(theta)**4 + 3.04109334065411e+21*cos(theta)**2 - 3.6861737462474e+18)*cos(12*phi)

#@torch.jit.script
def Yl42_m13(theta, phi):
    return 3.06936532987026e-21*(1.0 - cos(theta)**2)**6.5*(6.06606582711949e+31*cos(theta)**29 - 2.96725629615724e+32*cos(theta)**27 + 6.4290553083407e+32*cos(theta)**25 - 8.13804469410215e+32*cos(theta)**23 + 6.68482242729819e+32*cos(theta)**21 - 3.74350055928699e+32*cos(theta)**19 + 1.4615036430093e+32*cos(theta)**17 - 3.99928562272163e+31*cos(theta)**15 + 7.60733678235094e+30*cos(theta)**13 - 9.84033613637434e+29*cos(theta)**11 + 8.32643826923983e+28*cos(theta)**9 - 4.32542247752718e+27*cos(theta)**7 + 1.24089989109386e+26*cos(theta)**5 - 1.61786165722798e+24*cos(theta)**3 + 6.08218668130821e+21*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl42_m14(theta, phi):
    return 7.61650218074352e-23*(1.0 - cos(theta)**2)**7*(1.75915908986465e+33*cos(theta)**28 - 8.01159199962456e+33*cos(theta)**26 + 1.60726382708517e+34*cos(theta)**24 - 1.87175027964349e+34*cos(theta)**22 + 1.40381270973262e+34*cos(theta)**20 - 7.11265106264528e+33*cos(theta)**18 + 2.48455619311582e+33*cos(theta)**16 - 5.99892843408245e+32*cos(theta)**14 + 9.88953781705622e+31*cos(theta)**12 - 1.08243697500118e+31*cos(theta)**10 + 7.49379444231585e+29*cos(theta)**8 - 3.02779573426903e+28*cos(theta)**6 + 6.20449945546932e+26*cos(theta)**4 - 4.85358497168395e+24*cos(theta)**2 + 6.08218668130821e+21)*cos(14*phi)

#@torch.jit.script
def Yl42_m15(theta, phi):
    return 1.90651017422948e-24*(1.0 - cos(theta)**2)**7.5*(4.92564545162103e+34*cos(theta)**27 - 2.08301391990239e+35*cos(theta)**25 + 3.85743318500442e+35*cos(theta)**23 - 4.11785061521569e+35*cos(theta)**21 + 2.80762541946524e+35*cos(theta)**19 - 1.28027719127615e+35*cos(theta)**17 + 3.97528990898531e+34*cos(theta)**15 - 8.39849980771543e+33*cos(theta)**13 + 1.18674453804675e+33*cos(theta)**11 - 1.08243697500118e+32*cos(theta)**9 + 5.99503555385268e+30*cos(theta)**7 - 1.81667744056142e+29*cos(theta)**5 + 2.48179978218773e+27*cos(theta)**3 - 9.70716994336791e+24*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl42_m16(theta, phi):
    return 4.81773877715548e-26*(1.0 - cos(theta)**2)**8*(1.32992427193768e+36*cos(theta)**26 - 5.20753479975596e+36*cos(theta)**24 + 8.87209632551016e+36*cos(theta)**22 - 8.64748629195294e+36*cos(theta)**20 + 5.33448829698396e+36*cos(theta)**18 - 2.17647122516945e+36*cos(theta)**16 + 5.96293486347796e+35*cos(theta)**14 - 1.09180497500301e+35*cos(theta)**12 + 1.30541899185142e+34*cos(theta)**10 - 9.7419327750106e+32*cos(theta)**8 + 4.19652488769687e+31*cos(theta)**6 - 9.08338720280709e+29*cos(theta)**4 + 7.44539934656319e+27*cos(theta)**2 - 9.70716994336791e+24)*cos(16*phi)

#@torch.jit.script
def Yl42_m17(theta, phi):
    return 1.23007210134409e-27*(1.0 - cos(theta)**2)**8.5*(3.45780310703796e+37*cos(theta)**25 - 1.24980835194143e+38*cos(theta)**23 + 1.95186119161224e+38*cos(theta)**21 - 1.72949725839059e+38*cos(theta)**19 + 9.60207893457112e+37*cos(theta)**17 - 3.48235396027113e+37*cos(theta)**15 + 8.34810880886914e+36*cos(theta)**13 - 1.31016597000361e+36*cos(theta)**11 + 1.30541899185142e+35*cos(theta)**9 - 7.79354622000848e+33*cos(theta)**7 + 2.51791493261812e+32*cos(theta)**5 - 3.63335488112284e+30*cos(theta)**3 + 1.48907986931264e+28*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl42_m18(theta, phi):
    return 3.17603250876001e-29*(1.0 - cos(theta)**2)**9*(8.6445077675949e+38*cos(theta)**24 - 2.87455920946529e+39*cos(theta)**22 + 4.09890850238569e+39*cos(theta)**20 - 3.28604479094212e+39*cos(theta)**18 + 1.63235341887709e+39*cos(theta)**16 - 5.22353094040669e+38*cos(theta)**14 + 1.08525414515299e+38*cos(theta)**12 - 1.44118256700397e+37*cos(theta)**10 + 1.17487709266628e+36*cos(theta)**8 - 5.45548235400594e+34*cos(theta)**6 + 1.25895746630906e+33*cos(theta)**4 - 1.09000646433685e+31*cos(theta)**2 + 1.48907986931264e+28)*cos(18*phi)

#@torch.jit.script
def Yl42_m19(theta, phi):
    return 8.30069393401569e-31*(1.0 - cos(theta)**2)**9.5*(2.07468186422278e+40*cos(theta)**23 - 6.32403026082364e+40*cos(theta)**21 + 8.19781700477139e+40*cos(theta)**19 - 5.91488062369581e+40*cos(theta)**17 + 2.61176547020335e+40*cos(theta)**15 - 7.31294331656937e+39*cos(theta)**13 + 1.30230497418359e+39*cos(theta)**11 - 1.44118256700397e+38*cos(theta)**9 + 9.39901674133023e+36*cos(theta)**7 - 3.27328941240356e+35*cos(theta)**5 + 5.03582986523625e+33*cos(theta)**3 - 2.1800129286737e+31*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl42_m20(theta, phi):
    return 2.19813639967386e-32*(1.0 - cos(theta)**2)**10*(4.77176828771238e+41*cos(theta)**22 - 1.32804635477296e+42*cos(theta)**20 + 1.55758523090656e+42*cos(theta)**18 - 1.00552970602829e+42*cos(theta)**16 + 3.91764820530502e+41*cos(theta)**14 - 9.50682631154018e+40*cos(theta)**12 + 1.43253547160194e+40*cos(theta)**10 - 1.29706431030357e+39*cos(theta)**8 + 6.57931171893116e+37*cos(theta)**6 - 1.63664470620178e+36*cos(theta)**4 + 1.51074895957087e+34*cos(theta)**2 - 2.1800129286737e+31)*cos(20*phi)

#@torch.jit.script
def Yl42_m21(theta, phi):
    return 5.90436262972423e-34*(1.0 - cos(theta)**2)**10.5*(1.04978902329672e+43*cos(theta)**21 - 2.65609270954593e+43*cos(theta)**19 + 2.80365341563181e+43*cos(theta)**17 - 1.60884752964526e+43*cos(theta)**15 + 5.48470748742703e+42*cos(theta)**13 - 1.14081915738482e+42*cos(theta)**11 + 1.43253547160194e+41*cos(theta)**9 - 1.03765144824286e+40*cos(theta)**7 + 3.9475870313587e+38*cos(theta)**5 - 6.54657882480712e+36*cos(theta)**3 + 3.02149791914175e+34*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl42_m22(theta, phi):
    return 1.61054694530832e-35*(1.0 - cos(theta)**2)**11*(2.20455694892312e+44*cos(theta)**20 - 5.04657614813727e+44*cos(theta)**18 + 4.76621080657408e+44*cos(theta)**16 - 2.41327129446789e+44*cos(theta)**14 + 7.13011973365513e+43*cos(theta)**12 - 1.2549010731233e+43*cos(theta)**10 + 1.28928192444175e+42*cos(theta)**8 - 7.2635601377e+40*cos(theta)**6 + 1.97379351567935e+39*cos(theta)**4 - 1.96397364744214e+37*cos(theta)**2 + 3.02149791914175e+34)*cos(22*phi)

#@torch.jit.script
def Yl42_m23(theta, phi):
    return 4.46685353296235e-37*(1.0 - cos(theta)**2)**11.5*(4.40911389784624e+45*cos(theta)**19 - 9.08383706664708e+45*cos(theta)**17 + 7.62593729051854e+45*cos(theta)**15 - 3.37857981225505e+45*cos(theta)**13 + 8.55614368038616e+44*cos(theta)**11 - 1.2549010731233e+44*cos(theta)**9 + 1.0314255395534e+43*cos(theta)**7 - 4.35813608262e+41*cos(theta)**5 + 7.89517406271739e+39*cos(theta)**3 - 3.92794729488427e+37*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl42_m24(theta, phi):
    return 1.26140034095862e-38*(1.0 - cos(theta)**2)**12*(8.37731640590786e+46*cos(theta)**18 - 1.54425230133e+47*cos(theta)**16 + 1.14389059357778e+47*cos(theta)**14 - 4.39215375593156e+46*cos(theta)**12 + 9.41175804842478e+45*cos(theta)**10 - 1.12941096581097e+45*cos(theta)**8 + 7.2199787768738e+43*cos(theta)**6 - 2.17906804131e+42*cos(theta)**4 + 2.36855221881522e+40*cos(theta)**2 - 3.92794729488427e+37)*cos(24*phi)

#@torch.jit.script
def Yl42_m25(theta, phi):
    return 3.63227975523903e-40*(1.0 - cos(theta)**2)**12.5*(1.50791695306342e+48*cos(theta)**17 - 2.47080368212801e+48*cos(theta)**15 + 1.60144683100889e+48*cos(theta)**13 - 5.27058450711787e+47*cos(theta)**11 + 9.41175804842478e+46*cos(theta)**9 - 9.03528772648778e+45*cos(theta)**7 + 4.33198726612428e+44*cos(theta)**5 - 8.71627216524e+42*cos(theta)**3 + 4.73710443763043e+40*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl42_m26(theta, phi):
    return 1.0683175750703e-41*(1.0 - cos(theta)**2)**13*(2.56345882020781e+49*cos(theta)**16 - 3.70620552319201e+49*cos(theta)**14 + 2.08188088031156e+49*cos(theta)**12 - 5.79764295782966e+48*cos(theta)**10 + 8.4705822435823e+47*cos(theta)**8 - 6.32470140854145e+46*cos(theta)**6 + 2.16599363306214e+45*cos(theta)**4 - 2.614881649572e+43*cos(theta)**2 + 4.73710443763043e+40)*cos(26*phi)

#@torch.jit.script
def Yl42_m27(theta, phi):
    return 3.21525806603397e-43*(1.0 - cos(theta)**2)**13.5*(4.10153411233249e+50*cos(theta)**15 - 5.18868773246881e+50*cos(theta)**13 + 2.49825705637387e+50*cos(theta)**11 - 5.79764295782966e+49*cos(theta)**9 + 6.77646579486584e+48*cos(theta)**7 - 3.79482084512487e+47*cos(theta)**5 + 8.66397453224856e+45*cos(theta)**3 - 5.229763299144e+43*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl42_m28(theta, phi):
    return 9.92250181163357e-45*(1.0 - cos(theta)**2)**14*(6.15230116849873e+51*cos(theta)**14 - 6.74529405220946e+51*cos(theta)**12 + 2.74808276201126e+51*cos(theta)**10 - 5.2178786620467e+50*cos(theta)**8 + 4.74352605640609e+49*cos(theta)**6 - 1.89741042256243e+48*cos(theta)**4 + 2.59919235967457e+46*cos(theta)**2 - 5.229763299144e+43)*cos(28*phi)

#@torch.jit.script
def Yl42_m29(theta, phi):
    return 3.14722646575483e-46*(1.0 - cos(theta)**2)**14.5*(8.61322163589823e+52*cos(theta)**13 - 8.09435286265135e+52*cos(theta)**11 + 2.74808276201126e+52*cos(theta)**9 - 4.17430292963736e+51*cos(theta)**7 + 2.84611563384365e+50*cos(theta)**5 - 7.58964169024974e+48*cos(theta)**3 + 5.19838471934914e+46*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl42_m30(theta, phi):
    return 1.02870315144741e-47*(1.0 - cos(theta)**2)**15*(1.11971881266677e+54*cos(theta)**12 - 8.90378814891648e+53*cos(theta)**10 + 2.47327448581013e+53*cos(theta)**8 - 2.92201205074615e+52*cos(theta)**6 + 1.42305781692183e+51*cos(theta)**4 - 2.27689250707492e+49*cos(theta)**2 + 5.19838471934914e+46)*cos(30*phi)

#@torch.jit.script
def Yl42_m31(theta, phi):
    return 3.4756658535518e-49*(1.0 - cos(theta)**2)**15.5*(1.34366257520012e+55*cos(theta)**11 - 8.90378814891648e+54*cos(theta)**9 + 1.97861958864811e+54*cos(theta)**7 - 1.75320723044769e+53*cos(theta)**5 + 5.6922312676873e+51*cos(theta)**3 - 4.55378501414984e+49*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl42_m32(theta, phi):
    return 1.21822025124109e-50*(1.0 - cos(theta)**2)**16*(1.47802883272014e+56*cos(theta)**10 - 8.01340933402483e+55*cos(theta)**8 + 1.38503371205367e+55*cos(theta)**6 - 8.76603615223845e+53*cos(theta)**4 + 1.70766938030619e+52*cos(theta)**2 - 4.55378501414984e+49)*cos(32*phi)

#@torch.jit.script
def Yl42_m33(theta, phi):
    return 4.44831141076236e-52*(1.0 - cos(theta)**2)**16.5*(1.47802883272014e+57*cos(theta)**9 - 6.41072746721987e+56*cos(theta)**7 + 8.31020227232205e+55*cos(theta)**5 - 3.50641446089538e+54*cos(theta)**3 + 3.41533876061238e+52*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl42_m34(theta, phi):
    return 1.70085437797474e-53*(1.0 - cos(theta)**2)**17*(1.33022594944812e+58*cos(theta)**8 - 4.48750922705391e+57*cos(theta)**6 + 4.15510113616102e+56*cos(theta)**4 - 1.05192433826861e+55*cos(theta)**2 + 3.41533876061238e+52)*cos(34*phi)

#@torch.jit.script
def Yl42_m35(theta, phi):
    return 6.85293758117573e-55*(1.0 - cos(theta)**2)**17.5*(1.0641807595585e+59*cos(theta)**7 - 2.69250553623234e+58*cos(theta)**5 + 1.66204045446441e+57*cos(theta)**3 - 2.10384867653723e+55*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl42_m36(theta, phi):
    return 2.93278654238651e-56*(1.0 - cos(theta)**2)**18*(7.44926531690948e+59*cos(theta)**6 - 1.34625276811617e+59*cos(theta)**4 + 4.98612136339323e+57*cos(theta)**2 - 2.10384867653723e+55)*cos(36*phi)

#@torch.jit.script
def Yl42_m37(theta, phi):
    return 1.34707347297915e-57*(1.0 - cos(theta)**2)**18.5*(4.46955919014569e+60*cos(theta)**5 - 5.38501107246469e+59*cos(theta)**3 + 9.97224272678646e+57*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl42_m38(theta, phi):
    return 6.73536736489573e-59*(1.0 - cos(theta)**2)**19*(2.23477959507285e+61*cos(theta)**4 - 1.61550332173941e+60*cos(theta)**2 + 9.97224272678646e+57)*cos(38*phi)

#@torch.jit.script
def Yl42_m39(theta, phi):
    return 3.74187075827541e-60*(1.0 - cos(theta)**2)**19.5*(8.93911838029138e+61*cos(theta)**3 - 3.23100664347881e+60*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl42_m40(theta, phi):
    return 2.38572965876905e-61*(1.0 - cos(theta)**2)**20*(2.68173551408741e+62*cos(theta)**2 - 3.23100664347881e+60)*cos(40*phi)

#@torch.jit.script
def Yl42_m41(theta, phi):
    return 9.93146061456615*(1.0 - cos(theta)**2)**20.5*cos(41*phi)*cos(theta)

#@torch.jit.script
def Yl42_m42(theta, phi):
    return 1.08361119113624*(1.0 - cos(theta)**2)**21*cos(42*phi)

#@torch.jit.script
def Yl43_m_minus_43(theta, phi):
    return 1.08989304776835*(1.0 - cos(theta)**2)**21.5*sin(43*phi)

#@torch.jit.script
def Yl43_m_minus_42(theta, phi):
    return 10.1072523258968*(1.0 - cos(theta)**2)**21*sin(42*phi)*cos(theta)

#@torch.jit.script
def Yl43_m_minus_41(theta, phi):
    return 2.89063131941515e-63*(1.0 - cos(theta)**2)**20.5*(2.2794751869743e+64*cos(theta)**2 - 2.68173551408741e+62)*sin(41*phi)

#@torch.jit.script
def Yl43_m_minus_40(theta, phi):
    return 4.5887349618882e-62*(1.0 - cos(theta)**2)**20*(7.59825062324767e+63*cos(theta)**3 - 2.68173551408741e+62*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl43_m_minus_39(theta, phi):
    return 8.36107301651595e-61*(1.0 - cos(theta)**2)**19.5*(1.89956265581192e+63*cos(theta)**4 - 1.34086775704371e+62*cos(theta)**2 + 8.07751660869703e+59)*sin(39*phi)

#@torch.jit.script
def Yl43_m_minus_38(theta, phi):
    return 1.69298825202302e-59*(1.0 - cos(theta)**2)**19*(3.79912531162384e+62*cos(theta)**5 - 4.46955919014569e+61*cos(theta)**3 + 8.07751660869703e+59*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl43_m_minus_37(theta, phi):
    return 3.73226162218452e-58*(1.0 - cos(theta)**2)**18.5*(6.33187551937306e+61*cos(theta)**6 - 1.11738979753642e+61*cos(theta)**4 + 4.03875830434852e+59*cos(theta)**2 - 1.66204045446441e+57)*sin(37*phi)

#@torch.jit.script
def Yl43_m_minus_36(theta, phi):
    return 8.83214301129778e-57*(1.0 - cos(theta)**2)**18*(9.04553645624723e+60*cos(theta)**7 - 2.23477959507285e+60*cos(theta)**5 + 1.34625276811617e+59*cos(theta)**3 - 1.66204045446441e+57*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl43_m_minus_35(theta, phi):
    return 2.22036632357623e-55*(1.0 - cos(theta)**2)**17.5*(1.1306920570309e+60*cos(theta)**8 - 3.72463265845474e+59*cos(theta)**6 + 3.36563192029043e+58*cos(theta)**4 - 8.31020227232205e+56*cos(theta)**2 + 2.62981084567153e+54)*sin(35*phi)

#@torch.jit.script
def Yl43_m_minus_34(theta, phi):
    return 5.88292332164183e-54*(1.0 - cos(theta)**2)**17*(1.25632450781212e+59*cos(theta)**9 - 5.32090379779249e+58*cos(theta)**7 + 6.73126384058086e+57*cos(theta)**5 - 2.77006742410735e+56*cos(theta)**3 + 2.62981084567153e+54*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl43_m_minus_33(theta, phi):
    return 1.63244497127482e-52*(1.0 - cos(theta)**2)**16.5*(1.25632450781212e+58*cos(theta)**10 - 6.65112974724061e+57*cos(theta)**8 + 1.12187730676348e+57*cos(theta)**6 - 6.92516856026837e+55*cos(theta)**4 + 1.31490542283577e+54*cos(theta)**2 - 3.41533876061238e+51)*sin(33*phi)

#@torch.jit.script
def Yl43_m_minus_32(theta, phi):
    return 4.71999663604224e-51*(1.0 - cos(theta)**2)**16*(1.1421131889201e+57*cos(theta)**11 - 7.39014416360068e+56*cos(theta)**9 + 1.60268186680497e+56*cos(theta)**7 - 1.38503371205367e+55*cos(theta)**5 + 4.38301807611922e+53*cos(theta)**3 - 3.41533876061238e+51*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl43_m_minus_31(theta, phi):
    return 1.41599899081267e-49*(1.0 - cos(theta)**2)**15.5*(9.51760990766754e+55*cos(theta)**12 - 7.39014416360068e+55*cos(theta)**10 + 2.00335233350621e+55*cos(theta)**8 - 2.30838952008946e+54*cos(theta)**6 + 1.09575451902981e+53*cos(theta)**4 - 1.70766938030619e+51*cos(theta)**2 + 3.79482084512487e+48)*sin(31*phi)

#@torch.jit.script
def Yl43_m_minus_30(theta, phi):
    return 4.39188014702948e-48*(1.0 - cos(theta)**2)**15*(7.32123839051349e+54*cos(theta)**13 - 6.71831287600062e+54*cos(theta)**11 + 2.22594703722912e+54*cos(theta)**9 - 3.29769931441351e+53*cos(theta)**7 + 2.19150903805961e+52*cos(theta)**5 - 5.6922312676873e+50*cos(theta)**3 + 3.79482084512487e+48*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl43_m_minus_29(theta, phi):
    return 1.40402851370052e-46*(1.0 - cos(theta)**2)**14.5*(5.22945599322392e+53*cos(theta)**14 - 5.59859406333385e+53*cos(theta)**12 + 2.22594703722912e+53*cos(theta)**10 - 4.12212414301689e+52*cos(theta)**8 + 3.65251506343269e+51*cos(theta)**6 - 1.42305781692183e+50*cos(theta)**4 + 1.89741042256243e+48*cos(theta)**2 - 3.71313194239224e+45)*sin(29*phi)

#@torch.jit.script
def Yl43_m_minus_28(theta, phi):
    return 4.61410853000535e-45*(1.0 - cos(theta)**2)**14*(3.48630399548262e+52*cos(theta)**15 - 4.30661081794911e+52*cos(theta)**13 + 2.02358821566284e+52*cos(theta)**11 - 4.58013793668543e+51*cos(theta)**9 + 5.2178786620467e+50*cos(theta)**7 - 2.84611563384365e+49*cos(theta)**5 + 6.32470140854145e+47*cos(theta)**3 - 3.71313194239224e+45*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl43_m_minus_27(theta, phi):
    return 1.55516678174063e-43*(1.0 - cos(theta)**2)**13.5*(2.17893999717664e+51*cos(theta)**16 - 3.07615058424937e+51*cos(theta)**14 + 1.68632351305236e+51*cos(theta)**12 - 4.58013793668543e+50*cos(theta)**10 + 6.52234832755837e+49*cos(theta)**8 - 4.74352605640609e+48*cos(theta)**6 + 1.58117535213536e+47*cos(theta)**4 - 1.85656597119612e+45*cos(theta)**2 + 3.268602061965e+42)*sin(27*phi)

#@torch.jit.script
def Yl43_m_minus_26(theta, phi):
    return 5.36476190118919e-42*(1.0 - cos(theta)**2)**13*(1.2817294101039e+50*cos(theta)**17 - 2.05076705616624e+50*cos(theta)**15 + 1.2971719331172e+50*cos(theta)**13 - 4.16376176062312e+49*cos(theta)**11 + 7.24705369728708e+48*cos(theta)**9 - 6.77646579486584e+47*cos(theta)**7 + 3.16235070427072e+46*cos(theta)**5 - 6.1885532373204e+44*cos(theta)**3 + 3.268602061965e+42*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl43_m_minus_25(theta, phi):
    return 1.89065048220215e-40*(1.0 - cos(theta)**2)**12.5*(7.12071894502168e+48*cos(theta)**18 - 1.2817294101039e+49*cos(theta)**16 + 9.26551380798002e+48*cos(theta)**14 - 3.46980146718593e+48*cos(theta)**12 + 7.24705369728708e+47*cos(theta)**10 - 8.4705822435823e+46*cos(theta)**8 + 5.27058450711787e+45*cos(theta)**6 - 1.5471383093301e+44*cos(theta)**4 + 1.6343010309825e+42*cos(theta)**2 - 2.63172468757246e+39)*sin(25*phi)

#@torch.jit.script
def Yl43_m_minus_24(theta, phi):
    return 6.79583000496612e-39*(1.0 - cos(theta)**2)**12*(3.74774681316931e+47*cos(theta)**19 - 7.53958476531708e+47*cos(theta)**17 + 6.17700920532001e+47*cos(theta)**15 - 2.66907805168149e+47*cos(theta)**13 + 6.58823063389734e+46*cos(theta)**11 - 9.41175804842478e+45*cos(theta)**9 + 7.52940643873982e+44*cos(theta)**7 - 3.0942766186602e+43*cos(theta)**5 + 5.447670103275e+41*cos(theta)**3 - 2.63172468757246e+39*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl43_m_minus_23(theta, phi):
    return 2.48768224079308e-37*(1.0 - cos(theta)**2)**11.5*(1.87387340658465e+46*cos(theta)**20 - 4.18865820295393e+46*cos(theta)**18 + 3.86063075332501e+46*cos(theta)**16 - 1.90648432262963e+46*cos(theta)**14 + 5.49019219491445e+45*cos(theta)**12 - 9.41175804842478e+44*cos(theta)**10 + 9.41175804842478e+43*cos(theta)**8 - 5.157127697767e+42*cos(theta)**6 + 1.36191752581875e+41*cos(theta)**4 - 1.31586234378623e+39*cos(theta)**2 + 1.96397364744214e+36)*sin(23*phi)

#@torch.jit.script
def Yl43_m_minus_22(theta, phi):
    return 9.26139742295083e-36*(1.0 - cos(theta)**2)**11*(8.92320669802216e+44*cos(theta)**21 - 2.20455694892312e+45*cos(theta)**19 + 2.27095926666177e+45*cos(theta)**17 - 1.27098954841976e+45*cos(theta)**15 + 4.22322476531881e+44*cos(theta)**13 - 8.55614368038616e+43*cos(theta)**11 + 1.04575089426942e+43*cos(theta)**9 - 7.36732528252429e+41*cos(theta)**7 + 2.7238350516375e+40*cos(theta)**5 - 4.38620781262077e+38*cos(theta)**3 + 1.96397364744214e+36*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl43_m_minus_21(theta, phi):
    return 3.50222899855152e-34*(1.0 - cos(theta)**2)**10.5*(4.05600304455553e+43*cos(theta)**22 - 1.10227847446156e+44*cos(theta)**20 + 1.26164403703432e+44*cos(theta)**18 - 7.94368467762348e+43*cos(theta)**16 + 3.01658911808486e+43*cos(theta)**14 - 7.13011973365513e+42*cos(theta)**12 + 1.04575089426942e+42*cos(theta)**10 - 9.20915660315536e+40*cos(theta)**8 + 4.5397250860625e+39*cos(theta)**6 - 1.09655195315519e+38*cos(theta)**4 + 9.81986823721069e+35*cos(theta)**2 - 1.37340814506443e+33)*sin(21*phi)

#@torch.jit.script
def Yl43_m_minus_20(theta, phi):
    return 1.34368801864906e-32*(1.0 - cos(theta)**2)**10*(1.76347958458936e+42*cos(theta)**23 - 5.24894511648362e+42*cos(theta)**21 + 6.64023177386482e+42*cos(theta)**19 - 4.67275569271969e+42*cos(theta)**17 + 2.01105941205658e+42*cos(theta)**15 - 5.48470748742703e+41*cos(theta)**13 + 9.50682631154018e+40*cos(theta)**11 - 1.02323962257282e+40*cos(theta)**9 + 6.48532155151786e+38*cos(theta)**7 - 2.19310390631039e+37*cos(theta)**5 + 3.27328941240356e+35*cos(theta)**3 - 1.37340814506443e+33*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl43_m_minus_19(theta, phi):
    return 5.2248561770532e-31*(1.0 - cos(theta)**2)**9.5*(7.34783160245567e+40*cos(theta)**24 - 2.38588414385619e+41*cos(theta)**22 + 3.32011588693241e+41*cos(theta)**20 - 2.59597538484427e+41*cos(theta)**18 + 1.25691213253536e+41*cos(theta)**16 - 3.91764820530502e+40*cos(theta)**14 + 7.92235525961681e+39*cos(theta)**12 - 1.02323962257282e+39*cos(theta)**10 + 8.10665193939732e+37*cos(theta)**8 - 3.65517317718398e+36*cos(theta)**6 + 8.18322353100891e+34*cos(theta)**4 - 6.86704072532216e+32*cos(theta)**2 + 9.08338720280709e+29)*sin(19*phi)

#@torch.jit.script
def Yl43_m_minus_18(theta, phi):
    return 2.05702793393481e-29*(1.0 - cos(theta)**2)**9*(2.93913264098227e+39*cos(theta)**25 - 1.03734093211139e+40*cos(theta)**23 + 1.58100756520591e+40*cos(theta)**21 - 1.36630283412856e+40*cos(theta)**19 + 7.39360077961976e+39*cos(theta)**17 - 2.61176547020335e+39*cos(theta)**15 + 6.09411943047447e+38*cos(theta)**13 - 9.30217838702561e+37*cos(theta)**11 + 9.0073910437748e+36*cos(theta)**9 - 5.22167596740568e+35*cos(theta)**7 + 1.63664470620178e+34*cos(theta)**5 - 2.28901357510739e+32*cos(theta)**3 + 9.08338720280709e+29*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl43_m_minus_17(theta, phi):
    return 8.19203465488711e-28*(1.0 - cos(theta)**2)**8.5*(1.13043563114703e+38*cos(theta)**26 - 4.32225388379745e+38*cos(theta)**24 + 7.18639802366323e+38*cos(theta)**22 - 6.83151417064282e+38*cos(theta)**20 + 4.10755598867765e+38*cos(theta)**18 - 1.63235341887709e+38*cos(theta)**16 + 4.35294245033891e+37*cos(theta)**14 - 7.75181532252134e+36*cos(theta)**12 + 9.0073910437748e+35*cos(theta)**10 - 6.5270949592571e+34*cos(theta)**8 + 2.72774117700297e+33*cos(theta)**6 - 5.72253393776847e+31*cos(theta)**4 + 4.54169360140354e+29*cos(theta)**2 - 5.72723026658707e+26)*sin(17*phi)

#@torch.jit.script
def Yl43_m_minus_16(theta, phi):
    return 3.29723034522509e-26*(1.0 - cos(theta)**2)**8*(4.18679863387787e+36*cos(theta)**27 - 1.72890155351898e+37*cos(theta)**25 + 3.12452087985358e+37*cos(theta)**23 - 3.25310198602039e+37*cos(theta)**21 + 2.16187157298824e+37*cos(theta)**19 - 9.60207893457112e+36*cos(theta)**17 + 2.90196163355927e+36*cos(theta)**15 - 5.96293486347796e+35*cos(theta)**13 + 8.18853731252255e+34*cos(theta)**11 - 7.25232773250789e+33*cos(theta)**9 + 3.89677311000424e+32*cos(theta)**7 - 1.14450678755369e+31*cos(theta)**5 + 1.51389786713451e+29*cos(theta)**3 - 5.72723026658707e+26*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl43_m_minus_15(theta, phi):
    return 1.34015277384818e-24*(1.0 - cos(theta)**2)**7.5*(1.49528522638495e+35*cos(theta)**28 - 6.64962135968838e+35*cos(theta)**26 + 1.30188369993899e+36*cos(theta)**24 - 1.47868272091836e+36*cos(theta)**22 + 1.08093578649412e+36*cos(theta)**20 - 5.33448829698396e+35*cos(theta)**18 + 1.81372602097455e+35*cos(theta)**16 - 4.25923918819854e+34*cos(theta)**14 + 6.82378109376879e+33*cos(theta)**12 - 7.25232773250789e+32*cos(theta)**10 + 4.8709663875053e+31*cos(theta)**8 - 1.90751131258949e+30*cos(theta)**6 + 3.78474466783629e+28*cos(theta)**4 - 2.86361513329353e+26*cos(theta)**2 + 3.46684640834568e+23)*sin(15*phi)

#@torch.jit.script
def Yl43_m_minus_14(theta, phi):
    return 5.49626046244125e-23*(1.0 - cos(theta)**2)**7*(5.15615595305157e+33*cos(theta)**29 - 2.46282272581051e+34*cos(theta)**27 + 5.20753479975596e+34*cos(theta)**25 - 6.4290553083407e+34*cos(theta)**23 + 5.14731326901961e+34*cos(theta)**21 - 2.80762541946524e+34*cos(theta)**19 + 1.06689765939679e+34*cos(theta)**17 - 2.83949279213236e+33*cos(theta)**15 + 5.24906237982215e+32*cos(theta)**13 - 6.59302521137081e+31*cos(theta)**11 + 5.41218487500589e+30*cos(theta)**9 - 2.72501616084213e+29*cos(theta)**7 + 7.56948933567257e+27*cos(theta)**5 - 9.54538377764511e+25*cos(theta)**3 + 3.46684640834568e+23*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl43_m_minus_13(theta, phi):
    return 2.27282166505428e-21*(1.0 - cos(theta)**2)**6.5*(1.71871865101719e+32*cos(theta)**30 - 8.79579544932326e+32*cos(theta)**28 + 2.00289799990614e+33*cos(theta)**26 - 2.67877304514196e+33*cos(theta)**24 + 2.33968784955437e+33*cos(theta)**22 - 1.40381270973262e+33*cos(theta)**20 + 5.92720921887106e+32*cos(theta)**18 - 1.77468299508273e+32*cos(theta)**16 + 3.74933027130153e+31*cos(theta)**14 - 5.49418767614234e+30*cos(theta)**12 + 5.41218487500589e+29*cos(theta)**10 - 3.40627020105266e+28*cos(theta)**8 + 1.26158155594543e+27*cos(theta)**6 - 2.38634594441128e+25*cos(theta)**4 + 1.73342320417284e+23*cos(theta)**2 - 2.02739556043607e+20)*sin(13*phi)

#@torch.jit.script
def Yl43_m_minus_12(theta, phi):
    return 9.469787223322e-20*(1.0 - cos(theta)**2)**6*(5.54425371295867e+30*cos(theta)**31 - 3.03303291355974e+31*cos(theta)**29 + 7.41814074039311e+31*cos(theta)**27 - 1.07150921805678e+32*cos(theta)**25 + 1.01725558676277e+32*cos(theta)**23 - 6.68482242729819e+31*cos(theta)**21 + 3.11958379940582e+31*cos(theta)**19 - 1.04393117357807e+31*cos(theta)**17 + 2.49955351420102e+30*cos(theta)**15 - 4.22629821241719e+29*cos(theta)**13 + 4.92016806818717e+28*cos(theta)**11 - 3.78474466783629e+27*cos(theta)**9 + 1.80225936563633e+26*cos(theta)**7 - 4.77269188882256e+24*cos(theta)**5 + 5.7780773472428e+22*cos(theta)**3 - 2.02739556043607e+20*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl43_m_minus_11(theta, phi):
    return 3.97279865204351e-18*(1.0 - cos(theta)**2)**5.5*(1.73257928529959e+29*cos(theta)**32 - 1.01101097118658e+30*cos(theta)**30 + 2.64933597871183e+30*cos(theta)**28 - 4.12118930021839e+30*cos(theta)**26 + 4.23856494484487e+30*cos(theta)**24 - 3.03855564877191e+30*cos(theta)**22 + 1.55979189970291e+30*cos(theta)**20 - 5.7996176309893e+29*cos(theta)**18 + 1.56222094637564e+29*cos(theta)**16 - 3.01878443744085e+28*cos(theta)**14 + 4.10014005682264e+27*cos(theta)**12 - 3.78474466783629e+26*cos(theta)**10 + 2.25282420704541e+25*cos(theta)**8 - 7.95448648137093e+23*cos(theta)**6 + 1.4445193368107e+22*cos(theta)**4 - 1.01369778021804e+20*cos(theta)**2 + 1.15192929570231e+17)*sin(11*phi)

#@torch.jit.script
def Yl43_m_minus_10(theta, phi):
    return 1.67706696673351e-16*(1.0 - cos(theta)**2)**5*(5.25024025848359e+27*cos(theta)**33 - 3.2613257135051e+28*cos(theta)**31 + 9.13564130590285e+28*cos(theta)**29 - 1.52636640748829e+29*cos(theta)**27 + 1.69542597793795e+29*cos(theta)**25 - 1.32111115163996e+29*cos(theta)**23 + 7.42758047477577e+28*cos(theta)**21 - 3.05243033209963e+28*cos(theta)**19 + 9.18953497868023e+27*cos(theta)**17 - 2.0125229582939e+27*cos(theta)**15 + 3.15395388986357e+26*cos(theta)**13 - 3.44067697076026e+25*cos(theta)**11 + 2.50313800782823e+24*cos(theta)**9 - 1.13635521162442e+23*cos(theta)**7 + 2.8890386736214e+21*cos(theta)**5 - 3.37899260072679e+19*cos(theta)**3 + 1.15192929570231e+17*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl43_m_minus_9(theta, phi):
    return 7.11914433542231e-15*(1.0 - cos(theta)**2)**4.5*(1.5441883113187e+26*cos(theta)**34 - 1.01916428547034e+27*cos(theta)**32 + 3.04521376863428e+27*cos(theta)**30 - 5.45130859817248e+27*cos(theta)**28 + 6.52086914591518e+27*cos(theta)**26 - 5.50462979849983e+27*cos(theta)**24 + 3.37617294307989e+27*cos(theta)**22 - 1.52621516604982e+27*cos(theta)**20 + 5.1052972103779e+26*cos(theta)**18 - 1.25782684893369e+26*cos(theta)**16 + 2.25282420704541e+25*cos(theta)**14 - 2.86723080896688e+24*cos(theta)**12 + 2.50313800782823e+23*cos(theta)**10 - 1.42044401453052e+22*cos(theta)**8 + 4.81506445603567e+20*cos(theta)**6 - 8.44748150181696e+18*cos(theta)**4 + 5.75964647851157e+16*cos(theta)**2 - 63925044156621.2)*sin(9*phi)

#@torch.jit.script
def Yl43_m_minus_8(theta, phi):
    return 3.03713077171214e-13*(1.0 - cos(theta)**2)**4*(4.41196660376772e+24*cos(theta)**35 - 3.08837662263741e+25*cos(theta)**33 + 9.82327022140091e+25*cos(theta)**31 - 1.87976158557672e+26*cos(theta)**29 + 2.41513672070933e+26*cos(theta)**27 - 2.20185191939993e+26*cos(theta)**25 + 1.46790127959995e+26*cos(theta)**23 - 7.26769126690388e+25*cos(theta)**21 + 2.68699853177784e+25*cos(theta)**19 - 7.3989814643158e+24*cos(theta)**17 + 1.50188280469694e+24*cos(theta)**15 - 2.20556216074376e+23*cos(theta)**13 + 2.27558000711657e+22*cos(theta)**11 - 1.57827112725614e+21*cos(theta)**9 + 6.87866350862239e+19*cos(theta)**7 - 1.68949630036339e+18*cos(theta)**5 + 1.91988215950386e+16*cos(theta)**3 - 63925044156621.2*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl43_m_minus_7(theta, phi):
    return 1.30136712205844e-11*(1.0 - cos(theta)**2)**3.5*(1.22554627882437e+23*cos(theta)**36 - 9.0834606548159e+23*cos(theta)**34 + 3.06977194418778e+24*cos(theta)**32 - 6.26587195192239e+24*cos(theta)**30 + 8.6254882882476e+24*cos(theta)**28 - 8.46866122846128e+24*cos(theta)**26 + 6.11625533166648e+24*cos(theta)**24 - 3.30349603041086e+24*cos(theta)**22 + 1.34349926588892e+24*cos(theta)**20 - 4.11054525795322e+23*cos(theta)**18 + 9.38676752935587e+22*cos(theta)**16 - 1.5754015433884e+22*cos(theta)**14 + 1.89631667259715e+21*cos(theta)**12 - 1.57827112725614e+20*cos(theta)**10 + 8.59832938577798e+18*cos(theta)**8 - 2.81582716727232e+17*cos(theta)**6 + 4.79970539875964e+15*cos(theta)**4 - 31962522078310.6*cos(theta)**2 + 34817562176.8089)*sin(7*phi)

#@torch.jit.script
def Yl43_m_minus_6(theta, phi):
    return 5.59739163789093e-10*(1.0 - cos(theta)**2)**3*(3.31228724006586e+21*cos(theta)**37 - 2.59527447280454e+22*cos(theta)**35 + 9.30233922481147e+22*cos(theta)**33 - 2.02124901674916e+23*cos(theta)**31 + 2.97430630629227e+23*cos(theta)**29 - 3.1365411957264e+23*cos(theta)**27 + 2.44650213266659e+23*cos(theta)**25 - 1.43630262191776e+23*cos(theta)**23 + 6.39761555185201e+22*cos(theta)**21 - 2.16344487260696e+22*cos(theta)**19 + 5.52162795844463e+21*cos(theta)**17 - 1.05026769559227e+21*cos(theta)**15 + 1.45870513276703e+20*cos(theta)**13 - 1.43479193386921e+19*cos(theta)**11 + 9.55369931753109e+17*cos(theta)**9 - 4.02261023896046e+16*cos(theta)**7 + 959941079751928.0*cos(theta)**5 - 10654174026103.5*cos(theta)**3 + 34817562176.8089*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl43_m_minus_5(theta, phi):
    return 2.41532475749014e-8*(1.0 - cos(theta)**2)**2.5*(8.71654536859437e+19*cos(theta)**38 - 7.2090957577904e+20*cos(theta)**36 + 2.73598212494455e+21*cos(theta)**34 - 6.31640317734112e+21*cos(theta)**32 + 9.91435435430758e+21*cos(theta)**30 - 1.120193284188e+22*cos(theta)**28 + 9.40962358717919e+21*cos(theta)**26 - 5.98459425799068e+21*cos(theta)**24 + 2.90800706902364e+21*cos(theta)**22 - 1.08172243630348e+21*cos(theta)**20 + 3.06757108802479e+20*cos(theta)**18 - 6.56417309745166e+19*cos(theta)**16 + 1.04193223769074e+19*cos(theta)**14 - 1.19565994489101e+18*cos(theta)**12 + 9.55369931753109e+16*cos(theta)**10 - 5.02826279870057e+15*cos(theta)**8 + 159990179958655.0*cos(theta)**6 - 2663543506525.88*cos(theta)**4 + 17408781088.4045*cos(theta)**2 - 18699012.9843227)*sin(5*phi)

#@torch.jit.script
def Yl43_m_minus_4(theta, phi):
    return 1.0450292712034e-6*(1.0 - cos(theta)**2)**2*(2.23501163297291e+18*cos(theta)**39 - 1.94840425886227e+19*cos(theta)**37 + 7.81709178555585e+19*cos(theta)**35 - 1.91406156889125e+20*cos(theta)**33 + 3.19817882397019e+20*cos(theta)**31 - 3.86273546271724e+20*cos(theta)**29 + 3.48504577302933e+20*cos(theta)**27 - 2.39383770319627e+20*cos(theta)**25 + 1.2643508995755e+20*cos(theta)**23 - 5.15105922049276e+19*cos(theta)**21 + 1.61451109896042e+19*cos(theta)**19 - 3.86127829261862e+18*cos(theta)**17 + 6.94621491793826e+17*cos(theta)**15 - 9.19738419146932e+16*cos(theta)**13 + 8.68518119775554e+15*cos(theta)**11 - 558695866522286.0*cos(theta)**9 + 22855739994093.5*cos(theta)**7 - 532708701305.176*cos(theta)**5 + 5802927029.46815*cos(theta)**3 - 18699012.9843227*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl43_m_minus_3(theta, phi):
    return 4.53113894514745e-5*(1.0 - cos(theta)**2)**1.5*(5.58752908243229e+16*cos(theta)**40 - 5.12737962858492e+17*cos(theta)**38 + 2.17141438487663e+18*cos(theta)**36 - 5.62959284968014e+18*cos(theta)**34 + 9.99430882490683e+18*cos(theta)**32 - 1.28757848757241e+19*cos(theta)**30 + 1.24465920465333e+19*cos(theta)**28 - 9.20706808921643e+18*cos(theta)**26 + 5.26812874823123e+18*cos(theta)**24 - 2.34139055476944e+18*cos(theta)**22 + 8.07255549480209e+17*cos(theta)**20 - 2.14515460701035e+17*cos(theta)**18 + 4.34138432371141e+16*cos(theta)**16 - 6.5695601367638e+15*cos(theta)**14 + 723765099812961.0*cos(theta)**12 - 55869586652228.6*cos(theta)**10 + 2856967499261.69*cos(theta)**8 - 88784783550.8627*cos(theta)**6 + 1450731757.36704*cos(theta)**4 - 9349506.49216136*cos(theta)**2 + 9946.28350229932)*sin(3*phi)

#@torch.jit.script
def Yl43_m_minus_2(theta, phi):
    return 0.0019677876202598*(1.0 - cos(theta)**2)*(1.36281197132495e+15*cos(theta)**41 - 1.31471272527819e+16*cos(theta)**39 + 5.86868752669358e+16*cos(theta)**37 - 1.60845509990861e+17*cos(theta)**35 + 3.02857843178995e+17*cos(theta)**33 - 4.15347899216907e+17*cos(theta)**31 + 4.29192829190804e+17*cos(theta)**29 - 3.41002521822831e+17*cos(theta)**27 + 2.10725149929249e+17*cos(theta)**25 - 1.01799589337802e+17*cos(theta)**23 + 3.84407404514385e+16*cos(theta)**21 - 1.12902874053176e+16*cos(theta)**19 + 2.55375548453613e+15*cos(theta)**17 - 437970675784254.0*cos(theta)**15 + 55674238447150.9*cos(theta)**13 - 5079053332020.78*cos(theta)**11 + 317440833251.299*cos(theta)**9 - 12683540507.2661*cos(theta)**7 + 290146351.473408*cos(theta)**5 - 3116502.16405379*cos(theta)**3 + 9946.28350229932*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl43_m_minus_1(theta, phi):
    return 0.0855478552850171*(1.0 - cos(theta)**2)**0.5*(32447904079165.4*cos(theta)**42 - 328678181319546.0*cos(theta)**40 + 1.54439145439305e+15*cos(theta)**38 - 4.46793083307948e+15*cos(theta)**36 + 8.90758362291162e+15*cos(theta)**34 - 1.29796218505284e+16*cos(theta)**32 + 1.43064276396935e+16*cos(theta)**30 - 1.21786614936725e+16*cos(theta)**28 + 8.10481345881728e+15*cos(theta)**26 - 4.24164955574173e+15*cos(theta)**24 + 1.7473063841563e+15*cos(theta)**22 - 564514370265880.0*cos(theta)**20 + 141875304696451.0*cos(theta)**18 - 27373167236515.8*cos(theta)**16 + 3976731317653.63*cos(theta)**14 - 423254444335.065*cos(theta)**12 + 31744083325.1299*cos(theta)**10 - 1585442563.40826*cos(theta)**8 + 48357725.2455679*cos(theta)**6 - 779125.541013447*cos(theta)**4 + 4973.14175114966*cos(theta)**2 - 5.26258386365043)*sin(phi)

#@torch.jit.script
def Yl43_m0(theta, phi):
    return 6237675255909.47*cos(theta)**43 - 66266126542191.2*cos(theta)**41 + 327338697377089.0*cos(theta)**39 - 998180966075814.0*cos(theta)**37 + 2.10376115002055e+15*cos(theta)**35 - 3.25126723184993e+15*cos(theta)**33 + 3.81482021870392e+15*cos(theta)**31 - 3.47141174500455e+15*cos(theta)**29 + 2.48132600083072e+15*cos(theta)**27 - 1.40248860916519e+15*cos(theta)**25 + 627979974253069.0*cos(theta)**23 - 222208298581855.0*cos(theta)**21 + 61724527383848.6*cos(theta)**19 - 13310080936491.9*cos(theta)**17 + 2191490323683.9*cos(theta)**15 - 269130390627.848*cos(theta)**13 + 23854739169.2865*cos(theta)**11 - 1456171647.40373*cos(theta)**9 + 57104770.4864207*cos(theta)**7 - 1288077.52976889*cos(theta)**5 + 13702.9524443499*cos(theta)**3 - 43.5014363312694*cos(theta)

#@torch.jit.script
def Yl43_m1(theta, phi):
    return 0.0855478552850171*(1.0 - cos(theta)**2)**0.5*(32447904079165.4*cos(theta)**42 - 328678181319546.0*cos(theta)**40 + 1.54439145439305e+15*cos(theta)**38 - 4.46793083307948e+15*cos(theta)**36 + 8.90758362291162e+15*cos(theta)**34 - 1.29796218505284e+16*cos(theta)**32 + 1.43064276396935e+16*cos(theta)**30 - 1.21786614936725e+16*cos(theta)**28 + 8.10481345881728e+15*cos(theta)**26 - 4.24164955574173e+15*cos(theta)**24 + 1.7473063841563e+15*cos(theta)**22 - 564514370265880.0*cos(theta)**20 + 141875304696451.0*cos(theta)**18 - 27373167236515.8*cos(theta)**16 + 3976731317653.63*cos(theta)**14 - 423254444335.065*cos(theta)**12 + 31744083325.1299*cos(theta)**10 - 1585442563.40826*cos(theta)**8 + 48357725.2455679*cos(theta)**6 - 779125.541013447*cos(theta)**4 + 4973.14175114966*cos(theta)**2 - 5.26258386365043)*cos(phi)

#@torch.jit.script
def Yl43_m2(theta, phi):
    return 0.0019677876202598*(1.0 - cos(theta)**2)*(1.36281197132495e+15*cos(theta)**41 - 1.31471272527819e+16*cos(theta)**39 + 5.86868752669358e+16*cos(theta)**37 - 1.60845509990861e+17*cos(theta)**35 + 3.02857843178995e+17*cos(theta)**33 - 4.15347899216907e+17*cos(theta)**31 + 4.29192829190804e+17*cos(theta)**29 - 3.41002521822831e+17*cos(theta)**27 + 2.10725149929249e+17*cos(theta)**25 - 1.01799589337802e+17*cos(theta)**23 + 3.84407404514385e+16*cos(theta)**21 - 1.12902874053176e+16*cos(theta)**19 + 2.55375548453613e+15*cos(theta)**17 - 437970675784254.0*cos(theta)**15 + 55674238447150.9*cos(theta)**13 - 5079053332020.78*cos(theta)**11 + 317440833251.299*cos(theta)**9 - 12683540507.2661*cos(theta)**7 + 290146351.473408*cos(theta)**5 - 3116502.16405379*cos(theta)**3 + 9946.28350229932*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl43_m3(theta, phi):
    return 4.53113894514745e-5*(1.0 - cos(theta)**2)**1.5*(5.58752908243229e+16*cos(theta)**40 - 5.12737962858492e+17*cos(theta)**38 + 2.17141438487663e+18*cos(theta)**36 - 5.62959284968014e+18*cos(theta)**34 + 9.99430882490683e+18*cos(theta)**32 - 1.28757848757241e+19*cos(theta)**30 + 1.24465920465333e+19*cos(theta)**28 - 9.20706808921643e+18*cos(theta)**26 + 5.26812874823123e+18*cos(theta)**24 - 2.34139055476944e+18*cos(theta)**22 + 8.07255549480209e+17*cos(theta)**20 - 2.14515460701035e+17*cos(theta)**18 + 4.34138432371141e+16*cos(theta)**16 - 6.5695601367638e+15*cos(theta)**14 + 723765099812961.0*cos(theta)**12 - 55869586652228.6*cos(theta)**10 + 2856967499261.69*cos(theta)**8 - 88784783550.8627*cos(theta)**6 + 1450731757.36704*cos(theta)**4 - 9349506.49216136*cos(theta)**2 + 9946.28350229932)*cos(3*phi)

#@torch.jit.script
def Yl43_m4(theta, phi):
    return 1.0450292712034e-6*(1.0 - cos(theta)**2)**2*(2.23501163297291e+18*cos(theta)**39 - 1.94840425886227e+19*cos(theta)**37 + 7.81709178555585e+19*cos(theta)**35 - 1.91406156889125e+20*cos(theta)**33 + 3.19817882397019e+20*cos(theta)**31 - 3.86273546271724e+20*cos(theta)**29 + 3.48504577302933e+20*cos(theta)**27 - 2.39383770319627e+20*cos(theta)**25 + 1.2643508995755e+20*cos(theta)**23 - 5.15105922049276e+19*cos(theta)**21 + 1.61451109896042e+19*cos(theta)**19 - 3.86127829261862e+18*cos(theta)**17 + 6.94621491793826e+17*cos(theta)**15 - 9.19738419146932e+16*cos(theta)**13 + 8.68518119775554e+15*cos(theta)**11 - 558695866522286.0*cos(theta)**9 + 22855739994093.5*cos(theta)**7 - 532708701305.176*cos(theta)**5 + 5802927029.46815*cos(theta)**3 - 18699012.9843227*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl43_m5(theta, phi):
    return 2.41532475749014e-8*(1.0 - cos(theta)**2)**2.5*(8.71654536859437e+19*cos(theta)**38 - 7.2090957577904e+20*cos(theta)**36 + 2.73598212494455e+21*cos(theta)**34 - 6.31640317734112e+21*cos(theta)**32 + 9.91435435430758e+21*cos(theta)**30 - 1.120193284188e+22*cos(theta)**28 + 9.40962358717919e+21*cos(theta)**26 - 5.98459425799068e+21*cos(theta)**24 + 2.90800706902364e+21*cos(theta)**22 - 1.08172243630348e+21*cos(theta)**20 + 3.06757108802479e+20*cos(theta)**18 - 6.56417309745166e+19*cos(theta)**16 + 1.04193223769074e+19*cos(theta)**14 - 1.19565994489101e+18*cos(theta)**12 + 9.55369931753109e+16*cos(theta)**10 - 5.02826279870057e+15*cos(theta)**8 + 159990179958655.0*cos(theta)**6 - 2663543506525.88*cos(theta)**4 + 17408781088.4045*cos(theta)**2 - 18699012.9843227)*cos(5*phi)

#@torch.jit.script
def Yl43_m6(theta, phi):
    return 5.59739163789093e-10*(1.0 - cos(theta)**2)**3*(3.31228724006586e+21*cos(theta)**37 - 2.59527447280454e+22*cos(theta)**35 + 9.30233922481147e+22*cos(theta)**33 - 2.02124901674916e+23*cos(theta)**31 + 2.97430630629227e+23*cos(theta)**29 - 3.1365411957264e+23*cos(theta)**27 + 2.44650213266659e+23*cos(theta)**25 - 1.43630262191776e+23*cos(theta)**23 + 6.39761555185201e+22*cos(theta)**21 - 2.16344487260696e+22*cos(theta)**19 + 5.52162795844463e+21*cos(theta)**17 - 1.05026769559227e+21*cos(theta)**15 + 1.45870513276703e+20*cos(theta)**13 - 1.43479193386921e+19*cos(theta)**11 + 9.55369931753109e+17*cos(theta)**9 - 4.02261023896046e+16*cos(theta)**7 + 959941079751928.0*cos(theta)**5 - 10654174026103.5*cos(theta)**3 + 34817562176.8089*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl43_m7(theta, phi):
    return 1.30136712205844e-11*(1.0 - cos(theta)**2)**3.5*(1.22554627882437e+23*cos(theta)**36 - 9.0834606548159e+23*cos(theta)**34 + 3.06977194418778e+24*cos(theta)**32 - 6.26587195192239e+24*cos(theta)**30 + 8.6254882882476e+24*cos(theta)**28 - 8.46866122846128e+24*cos(theta)**26 + 6.11625533166648e+24*cos(theta)**24 - 3.30349603041086e+24*cos(theta)**22 + 1.34349926588892e+24*cos(theta)**20 - 4.11054525795322e+23*cos(theta)**18 + 9.38676752935587e+22*cos(theta)**16 - 1.5754015433884e+22*cos(theta)**14 + 1.89631667259715e+21*cos(theta)**12 - 1.57827112725614e+20*cos(theta)**10 + 8.59832938577798e+18*cos(theta)**8 - 2.81582716727232e+17*cos(theta)**6 + 4.79970539875964e+15*cos(theta)**4 - 31962522078310.6*cos(theta)**2 + 34817562176.8089)*cos(7*phi)

#@torch.jit.script
def Yl43_m8(theta, phi):
    return 3.03713077171214e-13*(1.0 - cos(theta)**2)**4*(4.41196660376772e+24*cos(theta)**35 - 3.08837662263741e+25*cos(theta)**33 + 9.82327022140091e+25*cos(theta)**31 - 1.87976158557672e+26*cos(theta)**29 + 2.41513672070933e+26*cos(theta)**27 - 2.20185191939993e+26*cos(theta)**25 + 1.46790127959995e+26*cos(theta)**23 - 7.26769126690388e+25*cos(theta)**21 + 2.68699853177784e+25*cos(theta)**19 - 7.3989814643158e+24*cos(theta)**17 + 1.50188280469694e+24*cos(theta)**15 - 2.20556216074376e+23*cos(theta)**13 + 2.27558000711657e+22*cos(theta)**11 - 1.57827112725614e+21*cos(theta)**9 + 6.87866350862239e+19*cos(theta)**7 - 1.68949630036339e+18*cos(theta)**5 + 1.91988215950386e+16*cos(theta)**3 - 63925044156621.2*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl43_m9(theta, phi):
    return 7.11914433542231e-15*(1.0 - cos(theta)**2)**4.5*(1.5441883113187e+26*cos(theta)**34 - 1.01916428547034e+27*cos(theta)**32 + 3.04521376863428e+27*cos(theta)**30 - 5.45130859817248e+27*cos(theta)**28 + 6.52086914591518e+27*cos(theta)**26 - 5.50462979849983e+27*cos(theta)**24 + 3.37617294307989e+27*cos(theta)**22 - 1.52621516604982e+27*cos(theta)**20 + 5.1052972103779e+26*cos(theta)**18 - 1.25782684893369e+26*cos(theta)**16 + 2.25282420704541e+25*cos(theta)**14 - 2.86723080896688e+24*cos(theta)**12 + 2.50313800782823e+23*cos(theta)**10 - 1.42044401453052e+22*cos(theta)**8 + 4.81506445603567e+20*cos(theta)**6 - 8.44748150181696e+18*cos(theta)**4 + 5.75964647851157e+16*cos(theta)**2 - 63925044156621.2)*cos(9*phi)

#@torch.jit.script
def Yl43_m10(theta, phi):
    return 1.67706696673351e-16*(1.0 - cos(theta)**2)**5*(5.25024025848359e+27*cos(theta)**33 - 3.2613257135051e+28*cos(theta)**31 + 9.13564130590285e+28*cos(theta)**29 - 1.52636640748829e+29*cos(theta)**27 + 1.69542597793795e+29*cos(theta)**25 - 1.32111115163996e+29*cos(theta)**23 + 7.42758047477577e+28*cos(theta)**21 - 3.05243033209963e+28*cos(theta)**19 + 9.18953497868023e+27*cos(theta)**17 - 2.0125229582939e+27*cos(theta)**15 + 3.15395388986357e+26*cos(theta)**13 - 3.44067697076026e+25*cos(theta)**11 + 2.50313800782823e+24*cos(theta)**9 - 1.13635521162442e+23*cos(theta)**7 + 2.8890386736214e+21*cos(theta)**5 - 3.37899260072679e+19*cos(theta)**3 + 1.15192929570231e+17*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl43_m11(theta, phi):
    return 3.97279865204351e-18*(1.0 - cos(theta)**2)**5.5*(1.73257928529959e+29*cos(theta)**32 - 1.01101097118658e+30*cos(theta)**30 + 2.64933597871183e+30*cos(theta)**28 - 4.12118930021839e+30*cos(theta)**26 + 4.23856494484487e+30*cos(theta)**24 - 3.03855564877191e+30*cos(theta)**22 + 1.55979189970291e+30*cos(theta)**20 - 5.7996176309893e+29*cos(theta)**18 + 1.56222094637564e+29*cos(theta)**16 - 3.01878443744085e+28*cos(theta)**14 + 4.10014005682264e+27*cos(theta)**12 - 3.78474466783629e+26*cos(theta)**10 + 2.25282420704541e+25*cos(theta)**8 - 7.95448648137093e+23*cos(theta)**6 + 1.4445193368107e+22*cos(theta)**4 - 1.01369778021804e+20*cos(theta)**2 + 1.15192929570231e+17)*cos(11*phi)

#@torch.jit.script
def Yl43_m12(theta, phi):
    return 9.469787223322e-20*(1.0 - cos(theta)**2)**6*(5.54425371295867e+30*cos(theta)**31 - 3.03303291355974e+31*cos(theta)**29 + 7.41814074039311e+31*cos(theta)**27 - 1.07150921805678e+32*cos(theta)**25 + 1.01725558676277e+32*cos(theta)**23 - 6.68482242729819e+31*cos(theta)**21 + 3.11958379940582e+31*cos(theta)**19 - 1.04393117357807e+31*cos(theta)**17 + 2.49955351420102e+30*cos(theta)**15 - 4.22629821241719e+29*cos(theta)**13 + 4.92016806818717e+28*cos(theta)**11 - 3.78474466783629e+27*cos(theta)**9 + 1.80225936563633e+26*cos(theta)**7 - 4.77269188882256e+24*cos(theta)**5 + 5.7780773472428e+22*cos(theta)**3 - 2.02739556043607e+20*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl43_m13(theta, phi):
    return 2.27282166505428e-21*(1.0 - cos(theta)**2)**6.5*(1.71871865101719e+32*cos(theta)**30 - 8.79579544932326e+32*cos(theta)**28 + 2.00289799990614e+33*cos(theta)**26 - 2.67877304514196e+33*cos(theta)**24 + 2.33968784955437e+33*cos(theta)**22 - 1.40381270973262e+33*cos(theta)**20 + 5.92720921887106e+32*cos(theta)**18 - 1.77468299508273e+32*cos(theta)**16 + 3.74933027130153e+31*cos(theta)**14 - 5.49418767614234e+30*cos(theta)**12 + 5.41218487500589e+29*cos(theta)**10 - 3.40627020105266e+28*cos(theta)**8 + 1.26158155594543e+27*cos(theta)**6 - 2.38634594441128e+25*cos(theta)**4 + 1.73342320417284e+23*cos(theta)**2 - 2.02739556043607e+20)*cos(13*phi)

#@torch.jit.script
def Yl43_m14(theta, phi):
    return 5.49626046244125e-23*(1.0 - cos(theta)**2)**7*(5.15615595305157e+33*cos(theta)**29 - 2.46282272581051e+34*cos(theta)**27 + 5.20753479975596e+34*cos(theta)**25 - 6.4290553083407e+34*cos(theta)**23 + 5.14731326901961e+34*cos(theta)**21 - 2.80762541946524e+34*cos(theta)**19 + 1.06689765939679e+34*cos(theta)**17 - 2.83949279213236e+33*cos(theta)**15 + 5.24906237982215e+32*cos(theta)**13 - 6.59302521137081e+31*cos(theta)**11 + 5.41218487500589e+30*cos(theta)**9 - 2.72501616084213e+29*cos(theta)**7 + 7.56948933567257e+27*cos(theta)**5 - 9.54538377764511e+25*cos(theta)**3 + 3.46684640834568e+23*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl43_m15(theta, phi):
    return 1.34015277384818e-24*(1.0 - cos(theta)**2)**7.5*(1.49528522638495e+35*cos(theta)**28 - 6.64962135968838e+35*cos(theta)**26 + 1.30188369993899e+36*cos(theta)**24 - 1.47868272091836e+36*cos(theta)**22 + 1.08093578649412e+36*cos(theta)**20 - 5.33448829698396e+35*cos(theta)**18 + 1.81372602097455e+35*cos(theta)**16 - 4.25923918819854e+34*cos(theta)**14 + 6.82378109376879e+33*cos(theta)**12 - 7.25232773250789e+32*cos(theta)**10 + 4.8709663875053e+31*cos(theta)**8 - 1.90751131258949e+30*cos(theta)**6 + 3.78474466783629e+28*cos(theta)**4 - 2.86361513329353e+26*cos(theta)**2 + 3.46684640834568e+23)*cos(15*phi)

#@torch.jit.script
def Yl43_m16(theta, phi):
    return 3.29723034522509e-26*(1.0 - cos(theta)**2)**8*(4.18679863387787e+36*cos(theta)**27 - 1.72890155351898e+37*cos(theta)**25 + 3.12452087985358e+37*cos(theta)**23 - 3.25310198602039e+37*cos(theta)**21 + 2.16187157298824e+37*cos(theta)**19 - 9.60207893457112e+36*cos(theta)**17 + 2.90196163355927e+36*cos(theta)**15 - 5.96293486347796e+35*cos(theta)**13 + 8.18853731252255e+34*cos(theta)**11 - 7.25232773250789e+33*cos(theta)**9 + 3.89677311000424e+32*cos(theta)**7 - 1.14450678755369e+31*cos(theta)**5 + 1.51389786713451e+29*cos(theta)**3 - 5.72723026658707e+26*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl43_m17(theta, phi):
    return 8.19203465488711e-28*(1.0 - cos(theta)**2)**8.5*(1.13043563114703e+38*cos(theta)**26 - 4.32225388379745e+38*cos(theta)**24 + 7.18639802366323e+38*cos(theta)**22 - 6.83151417064282e+38*cos(theta)**20 + 4.10755598867765e+38*cos(theta)**18 - 1.63235341887709e+38*cos(theta)**16 + 4.35294245033891e+37*cos(theta)**14 - 7.75181532252134e+36*cos(theta)**12 + 9.0073910437748e+35*cos(theta)**10 - 6.5270949592571e+34*cos(theta)**8 + 2.72774117700297e+33*cos(theta)**6 - 5.72253393776847e+31*cos(theta)**4 + 4.54169360140354e+29*cos(theta)**2 - 5.72723026658707e+26)*cos(17*phi)

#@torch.jit.script
def Yl43_m18(theta, phi):
    return 2.05702793393481e-29*(1.0 - cos(theta)**2)**9*(2.93913264098227e+39*cos(theta)**25 - 1.03734093211139e+40*cos(theta)**23 + 1.58100756520591e+40*cos(theta)**21 - 1.36630283412856e+40*cos(theta)**19 + 7.39360077961976e+39*cos(theta)**17 - 2.61176547020335e+39*cos(theta)**15 + 6.09411943047447e+38*cos(theta)**13 - 9.30217838702561e+37*cos(theta)**11 + 9.0073910437748e+36*cos(theta)**9 - 5.22167596740568e+35*cos(theta)**7 + 1.63664470620178e+34*cos(theta)**5 - 2.28901357510739e+32*cos(theta)**3 + 9.08338720280709e+29*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl43_m19(theta, phi):
    return 5.2248561770532e-31*(1.0 - cos(theta)**2)**9.5*(7.34783160245567e+40*cos(theta)**24 - 2.38588414385619e+41*cos(theta)**22 + 3.32011588693241e+41*cos(theta)**20 - 2.59597538484427e+41*cos(theta)**18 + 1.25691213253536e+41*cos(theta)**16 - 3.91764820530502e+40*cos(theta)**14 + 7.92235525961681e+39*cos(theta)**12 - 1.02323962257282e+39*cos(theta)**10 + 8.10665193939732e+37*cos(theta)**8 - 3.65517317718398e+36*cos(theta)**6 + 8.18322353100891e+34*cos(theta)**4 - 6.86704072532216e+32*cos(theta)**2 + 9.08338720280709e+29)*cos(19*phi)

#@torch.jit.script
def Yl43_m20(theta, phi):
    return 1.34368801864906e-32*(1.0 - cos(theta)**2)**10*(1.76347958458936e+42*cos(theta)**23 - 5.24894511648362e+42*cos(theta)**21 + 6.64023177386482e+42*cos(theta)**19 - 4.67275569271969e+42*cos(theta)**17 + 2.01105941205658e+42*cos(theta)**15 - 5.48470748742703e+41*cos(theta)**13 + 9.50682631154018e+40*cos(theta)**11 - 1.02323962257282e+40*cos(theta)**9 + 6.48532155151786e+38*cos(theta)**7 - 2.19310390631039e+37*cos(theta)**5 + 3.27328941240356e+35*cos(theta)**3 - 1.37340814506443e+33*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl43_m21(theta, phi):
    return 3.50222899855152e-34*(1.0 - cos(theta)**2)**10.5*(4.05600304455553e+43*cos(theta)**22 - 1.10227847446156e+44*cos(theta)**20 + 1.26164403703432e+44*cos(theta)**18 - 7.94368467762348e+43*cos(theta)**16 + 3.01658911808486e+43*cos(theta)**14 - 7.13011973365513e+42*cos(theta)**12 + 1.04575089426942e+42*cos(theta)**10 - 9.20915660315536e+40*cos(theta)**8 + 4.5397250860625e+39*cos(theta)**6 - 1.09655195315519e+38*cos(theta)**4 + 9.81986823721069e+35*cos(theta)**2 - 1.37340814506443e+33)*cos(21*phi)

#@torch.jit.script
def Yl43_m22(theta, phi):
    return 9.26139742295083e-36*(1.0 - cos(theta)**2)**11*(8.92320669802216e+44*cos(theta)**21 - 2.20455694892312e+45*cos(theta)**19 + 2.27095926666177e+45*cos(theta)**17 - 1.27098954841976e+45*cos(theta)**15 + 4.22322476531881e+44*cos(theta)**13 - 8.55614368038616e+43*cos(theta)**11 + 1.04575089426942e+43*cos(theta)**9 - 7.36732528252429e+41*cos(theta)**7 + 2.7238350516375e+40*cos(theta)**5 - 4.38620781262077e+38*cos(theta)**3 + 1.96397364744214e+36*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl43_m23(theta, phi):
    return 2.48768224079308e-37*(1.0 - cos(theta)**2)**11.5*(1.87387340658465e+46*cos(theta)**20 - 4.18865820295393e+46*cos(theta)**18 + 3.86063075332501e+46*cos(theta)**16 - 1.90648432262963e+46*cos(theta)**14 + 5.49019219491445e+45*cos(theta)**12 - 9.41175804842478e+44*cos(theta)**10 + 9.41175804842478e+43*cos(theta)**8 - 5.157127697767e+42*cos(theta)**6 + 1.36191752581875e+41*cos(theta)**4 - 1.31586234378623e+39*cos(theta)**2 + 1.96397364744214e+36)*cos(23*phi)

#@torch.jit.script
def Yl43_m24(theta, phi):
    return 6.79583000496612e-39*(1.0 - cos(theta)**2)**12*(3.74774681316931e+47*cos(theta)**19 - 7.53958476531708e+47*cos(theta)**17 + 6.17700920532001e+47*cos(theta)**15 - 2.66907805168149e+47*cos(theta)**13 + 6.58823063389734e+46*cos(theta)**11 - 9.41175804842478e+45*cos(theta)**9 + 7.52940643873982e+44*cos(theta)**7 - 3.0942766186602e+43*cos(theta)**5 + 5.447670103275e+41*cos(theta)**3 - 2.63172468757246e+39*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl43_m25(theta, phi):
    return 1.89065048220215e-40*(1.0 - cos(theta)**2)**12.5*(7.12071894502168e+48*cos(theta)**18 - 1.2817294101039e+49*cos(theta)**16 + 9.26551380798002e+48*cos(theta)**14 - 3.46980146718593e+48*cos(theta)**12 + 7.24705369728708e+47*cos(theta)**10 - 8.4705822435823e+46*cos(theta)**8 + 5.27058450711787e+45*cos(theta)**6 - 1.5471383093301e+44*cos(theta)**4 + 1.6343010309825e+42*cos(theta)**2 - 2.63172468757246e+39)*cos(25*phi)

#@torch.jit.script
def Yl43_m26(theta, phi):
    return 5.36476190118919e-42*(1.0 - cos(theta)**2)**13*(1.2817294101039e+50*cos(theta)**17 - 2.05076705616624e+50*cos(theta)**15 + 1.2971719331172e+50*cos(theta)**13 - 4.16376176062312e+49*cos(theta)**11 + 7.24705369728708e+48*cos(theta)**9 - 6.77646579486584e+47*cos(theta)**7 + 3.16235070427072e+46*cos(theta)**5 - 6.1885532373204e+44*cos(theta)**3 + 3.268602061965e+42*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl43_m27(theta, phi):
    return 1.55516678174063e-43*(1.0 - cos(theta)**2)**13.5*(2.17893999717664e+51*cos(theta)**16 - 3.07615058424937e+51*cos(theta)**14 + 1.68632351305236e+51*cos(theta)**12 - 4.58013793668543e+50*cos(theta)**10 + 6.52234832755837e+49*cos(theta)**8 - 4.74352605640609e+48*cos(theta)**6 + 1.58117535213536e+47*cos(theta)**4 - 1.85656597119612e+45*cos(theta)**2 + 3.268602061965e+42)*cos(27*phi)

#@torch.jit.script
def Yl43_m28(theta, phi):
    return 4.61410853000535e-45*(1.0 - cos(theta)**2)**14*(3.48630399548262e+52*cos(theta)**15 - 4.30661081794911e+52*cos(theta)**13 + 2.02358821566284e+52*cos(theta)**11 - 4.58013793668543e+51*cos(theta)**9 + 5.2178786620467e+50*cos(theta)**7 - 2.84611563384365e+49*cos(theta)**5 + 6.32470140854145e+47*cos(theta)**3 - 3.71313194239224e+45*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl43_m29(theta, phi):
    return 1.40402851370052e-46*(1.0 - cos(theta)**2)**14.5*(5.22945599322392e+53*cos(theta)**14 - 5.59859406333385e+53*cos(theta)**12 + 2.22594703722912e+53*cos(theta)**10 - 4.12212414301689e+52*cos(theta)**8 + 3.65251506343269e+51*cos(theta)**6 - 1.42305781692183e+50*cos(theta)**4 + 1.89741042256243e+48*cos(theta)**2 - 3.71313194239224e+45)*cos(29*phi)

#@torch.jit.script
def Yl43_m30(theta, phi):
    return 4.39188014702948e-48*(1.0 - cos(theta)**2)**15*(7.32123839051349e+54*cos(theta)**13 - 6.71831287600062e+54*cos(theta)**11 + 2.22594703722912e+54*cos(theta)**9 - 3.29769931441351e+53*cos(theta)**7 + 2.19150903805961e+52*cos(theta)**5 - 5.6922312676873e+50*cos(theta)**3 + 3.79482084512487e+48*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl43_m31(theta, phi):
    return 1.41599899081267e-49*(1.0 - cos(theta)**2)**15.5*(9.51760990766754e+55*cos(theta)**12 - 7.39014416360068e+55*cos(theta)**10 + 2.00335233350621e+55*cos(theta)**8 - 2.30838952008946e+54*cos(theta)**6 + 1.09575451902981e+53*cos(theta)**4 - 1.70766938030619e+51*cos(theta)**2 + 3.79482084512487e+48)*cos(31*phi)

#@torch.jit.script
def Yl43_m32(theta, phi):
    return 4.71999663604224e-51*(1.0 - cos(theta)**2)**16*(1.1421131889201e+57*cos(theta)**11 - 7.39014416360068e+56*cos(theta)**9 + 1.60268186680497e+56*cos(theta)**7 - 1.38503371205367e+55*cos(theta)**5 + 4.38301807611922e+53*cos(theta)**3 - 3.41533876061238e+51*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl43_m33(theta, phi):
    return 1.63244497127482e-52*(1.0 - cos(theta)**2)**16.5*(1.25632450781212e+58*cos(theta)**10 - 6.65112974724061e+57*cos(theta)**8 + 1.12187730676348e+57*cos(theta)**6 - 6.92516856026837e+55*cos(theta)**4 + 1.31490542283577e+54*cos(theta)**2 - 3.41533876061238e+51)*cos(33*phi)

#@torch.jit.script
def Yl43_m34(theta, phi):
    return 5.88292332164183e-54*(1.0 - cos(theta)**2)**17*(1.25632450781212e+59*cos(theta)**9 - 5.32090379779249e+58*cos(theta)**7 + 6.73126384058086e+57*cos(theta)**5 - 2.77006742410735e+56*cos(theta)**3 + 2.62981084567153e+54*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl43_m35(theta, phi):
    return 2.22036632357623e-55*(1.0 - cos(theta)**2)**17.5*(1.1306920570309e+60*cos(theta)**8 - 3.72463265845474e+59*cos(theta)**6 + 3.36563192029043e+58*cos(theta)**4 - 8.31020227232205e+56*cos(theta)**2 + 2.62981084567153e+54)*cos(35*phi)

#@torch.jit.script
def Yl43_m36(theta, phi):
    return 8.83214301129778e-57*(1.0 - cos(theta)**2)**18*(9.04553645624723e+60*cos(theta)**7 - 2.23477959507285e+60*cos(theta)**5 + 1.34625276811617e+59*cos(theta)**3 - 1.66204045446441e+57*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl43_m37(theta, phi):
    return 3.73226162218452e-58*(1.0 - cos(theta)**2)**18.5*(6.33187551937306e+61*cos(theta)**6 - 1.11738979753642e+61*cos(theta)**4 + 4.03875830434852e+59*cos(theta)**2 - 1.66204045446441e+57)*cos(37*phi)

#@torch.jit.script
def Yl43_m38(theta, phi):
    return 1.69298825202302e-59*(1.0 - cos(theta)**2)**19*(3.79912531162384e+62*cos(theta)**5 - 4.46955919014569e+61*cos(theta)**3 + 8.07751660869703e+59*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl43_m39(theta, phi):
    return 8.36107301651595e-61*(1.0 - cos(theta)**2)**19.5*(1.89956265581192e+63*cos(theta)**4 - 1.34086775704371e+62*cos(theta)**2 + 8.07751660869703e+59)*cos(39*phi)

#@torch.jit.script
def Yl43_m40(theta, phi):
    return 4.5887349618882e-62*(1.0 - cos(theta)**2)**20*(7.59825062324767e+63*cos(theta)**3 - 2.68173551408741e+62*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl43_m41(theta, phi):
    return 2.89063131941515e-63*(1.0 - cos(theta)**2)**20.5*(2.2794751869743e+64*cos(theta)**2 - 2.68173551408741e+62)*cos(41*phi)

#@torch.jit.script
def Yl43_m42(theta, phi):
    return 10.1072523258968*(1.0 - cos(theta)**2)**21*cos(42*phi)*cos(theta)

#@torch.jit.script
def Yl43_m43(theta, phi):
    return 1.08989304776835*(1.0 - cos(theta)**2)**21.5*cos(43*phi)

#@torch.jit.script
def Yl44_m_minus_44(theta, phi):
    return 1.09606812861653*(1.0 - cos(theta)**2)**22*sin(44*phi)

#@torch.jit.script
def Yl44_m_minus_43(theta, phi):
    return 10.2820304486063*(1.0 - cos(theta)**2)**21.5*sin(43*phi)*cos(theta)

#@torch.jit.script
def Yl44_m_minus_42(theta, phi):
    return 3.4195534181066e-65*(1.0 - cos(theta)**2)**21*(1.98314341266764e+66*cos(theta)**2 - 2.2794751869743e+64)*sin(42*phi)

#@torch.jit.script
def Yl44_m_minus_41(theta, phi):
    return 5.49261609750345e-64*(1.0 - cos(theta)**2)**20.5*(6.61047804222548e+65*cos(theta)**3 - 2.2794751869743e+64*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl44_m_minus_40(theta, phi):
    return 1.01278836595551e-62*(1.0 - cos(theta)**2)**20*(1.65261951055637e+65*cos(theta)**4 - 1.13973759348715e+64*cos(theta)**2 + 6.70433878521854e+61)*sin(40*phi)

#@torch.jit.script
def Yl44_m_minus_39(theta, phi):
    return 2.07559850445656e-61*(1.0 - cos(theta)**2)**19.5*(3.30523902111274e+64*cos(theta)**5 - 3.79912531162384e+63*cos(theta)**3 + 6.70433878521854e+61*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl44_m_minus_38(theta, phi):
    return 4.63188769029189e-60*(1.0 - cos(theta)**2)**19*(5.50873170185456e+63*cos(theta)**6 - 9.49781327905959e+62*cos(theta)**4 + 3.35216939260927e+61*cos(theta)**2 - 1.34625276811617e+59)*sin(38*phi)

#@torch.jit.script
def Yl44_m_minus_37(theta, phi):
    return 1.10972141424432e-58*(1.0 - cos(theta)**2)**18.5*(7.86961671693509e+62*cos(theta)**7 - 1.89956265581192e+62*cos(theta)**5 + 1.11738979753642e+61*cos(theta)**3 - 1.34625276811617e+59*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl44_m_minus_36(theta, phi):
    return 2.8248895340643e-57*(1.0 - cos(theta)**2)**18*(9.83702089616886e+61*cos(theta)**8 - 3.16593775968653e+61*cos(theta)**6 + 2.79347449384106e+60*cos(theta)**4 - 6.73126384058086e+58*cos(theta)**2 + 2.07755056808051e+56)*sin(36*phi)

#@torch.jit.script
def Yl44_m_minus_35(theta, phi):
    return 7.57997403251458e-56*(1.0 - cos(theta)**2)**17.5*(1.09300232179654e+61*cos(theta)**9 - 4.52276822812362e+60*cos(theta)**7 + 5.58694898768211e+59*cos(theta)**5 - 2.24375461352695e+58*cos(theta)**3 + 2.07755056808051e+56*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl44_m_minus_34(theta, phi):
    return 2.13049865063417e-54*(1.0 - cos(theta)**2)**17*(1.09300232179654e+60*cos(theta)**10 - 5.65346028515452e+59*cos(theta)**8 + 9.31158164613686e+58*cos(theta)**6 - 5.60938653381738e+57*cos(theta)**4 + 1.03877528404026e+56*cos(theta)**2 - 2.62981084567153e+53)*sin(34*phi)

#@torch.jit.script
def Yl44_m_minus_33(theta, phi):
    return 6.24057931710171e-53*(1.0 - cos(theta)**2)**16.5*(9.93638474360491e+58*cos(theta)**11 - 6.28162253906058e+58*cos(theta)**9 + 1.33022594944812e+58*cos(theta)**7 - 1.12187730676348e+57*cos(theta)**5 + 3.46258428013419e+55*cos(theta)**3 - 2.62981084567153e+53*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl44_m_minus_32(theta, phi):
    return 1.89697187951869e-51*(1.0 - cos(theta)**2)**16*(8.28032061967076e+57*cos(theta)**12 - 6.28162253906058e+57*cos(theta)**10 + 1.66278243681015e+57*cos(theta)**8 - 1.86979551127246e+56*cos(theta)**6 + 8.65646070033547e+54*cos(theta)**4 - 1.31490542283577e+53*cos(theta)**2 + 2.84611563384365e+50)*sin(32*phi)

#@torch.jit.script
def Yl44_m_minus_31(theta, phi):
    return 5.96265065549245e-50*(1.0 - cos(theta)**2)**15.5*(6.36947739974674e+56*cos(theta)**13 - 5.71056594460052e+56*cos(theta)**11 + 1.84753604090017e+56*cos(theta)**9 - 2.67113644467494e+55*cos(theta)**7 + 1.73129214006709e+54*cos(theta)**5 - 4.38301807611922e+52*cos(theta)**3 + 2.84611563384365e+50*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl44_m_minus_30(theta, phi):
    return 1.93211963867191e-48*(1.0 - cos(theta)**2)**15*(4.54962671410481e+55*cos(theta)**14 - 4.75880495383377e+55*cos(theta)**12 + 1.84753604090017e+55*cos(theta)**10 - 3.33892055584368e+54*cos(theta)**8 + 2.88548690011182e+53*cos(theta)**6 - 1.09575451902981e+52*cos(theta)**4 + 1.42305781692183e+50*cos(theta)**2 - 2.71058631794634e+47)*sin(30*phi)

#@torch.jit.script
def Yl44_m_minus_29(theta, phi):
    return 6.43717779072263e-47*(1.0 - cos(theta)**2)**14.5*(3.03308447606988e+54*cos(theta)**15 - 3.66061919525675e+54*cos(theta)**13 + 1.67957821900015e+54*cos(theta)**11 - 3.7099117287152e+53*cos(theta)**9 + 4.12212414301689e+52*cos(theta)**7 - 2.19150903805961e+51*cos(theta)**5 + 4.74352605640609e+49*cos(theta)**3 - 2.71058631794634e+47*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl44_m_minus_28(theta, phi):
    return 2.19997084612836e-45*(1.0 - cos(theta)**2)**14*(1.89567779754367e+53*cos(theta)**16 - 2.61472799661196e+53*cos(theta)**14 + 1.39964851583346e+53*cos(theta)**12 - 3.7099117287152e+52*cos(theta)**10 + 5.15265517877111e+51*cos(theta)**8 - 3.65251506343269e+50*cos(theta)**6 + 1.18588151410152e+49*cos(theta)**4 - 1.35529315897317e+47*cos(theta)**2 + 2.32070746399515e+44)*sin(28*phi)

#@torch.jit.script
def Yl44_m_minus_27(theta, phi):
    return 7.69675450430194e-44*(1.0 - cos(theta)**2)**13.5*(1.1151045867904e+52*cos(theta)**17 - 1.74315199774131e+52*cos(theta)**15 + 1.07665270448728e+52*cos(theta)**13 - 3.37264702610473e+51*cos(theta)**11 + 5.72517242085679e+50*cos(theta)**9 - 5.2178786620467e+49*cos(theta)**7 + 2.37176302820304e+48*cos(theta)**5 - 4.51764386324389e+46*cos(theta)**3 + 2.32070746399515e+44*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl44_m_minus_26(theta, phi):
    return 2.75152245514281e-42*(1.0 - cos(theta)**2)**13*(6.19502548216886e+50*cos(theta)**18 - 1.08946999858832e+51*cos(theta)**16 + 7.69037646062342e+50*cos(theta)**14 - 2.81053918842061e+50*cos(theta)**12 + 5.72517242085679e+49*cos(theta)**10 - 6.52234832755837e+48*cos(theta)**8 + 3.95293838033841e+47*cos(theta)**6 - 1.12941096581097e+46*cos(theta)**4 + 1.16035373199758e+44*cos(theta)**2 - 1.815890034425e+41)*sin(26*phi)

#@torch.jit.script
def Yl44_m_minus_25(theta, phi):
    return 1.00345726576353e-40*(1.0 - cos(theta)**2)**12.5*(3.2605397274573e+49*cos(theta)**19 - 6.40864705051951e+49*cos(theta)**17 + 5.12691764041561e+49*cos(theta)**15 - 2.161953221862e+49*cos(theta)**13 + 5.2047022007789e+48*cos(theta)**11 - 7.24705369728708e+47*cos(theta)**9 + 5.64705482905487e+46*cos(theta)**7 - 2.25882193162195e+45*cos(theta)**5 + 3.86784577332525e+43*cos(theta)**3 - 1.815890034425e+41*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl44_m_minus_24(theta, phi):
    return 3.72767829649342e-39*(1.0 - cos(theta)**2)**12*(1.63026986372865e+48*cos(theta)**20 - 3.56035947251084e+48*cos(theta)**18 + 3.20432352525976e+48*cos(theta)**16 - 1.54425230133e+48*cos(theta)**14 + 4.33725183398242e+47*cos(theta)**12 - 7.24705369728708e+46*cos(theta)**10 + 7.05881853631858e+45*cos(theta)**8 - 3.76470321936991e+44*cos(theta)**6 + 9.66961443331313e+42*cos(theta)**4 - 9.079450172125e+40*cos(theta)**2 + 1.31586234378623e+38)*sin(24*phi)

#@torch.jit.script
def Yl44_m_minus_23(theta, phi):
    return 1.40864814870526e-37*(1.0 - cos(theta)**2)**11.5*(7.76318982727928e+46*cos(theta)**21 - 1.87387340658465e+47*cos(theta)**19 + 1.88489619132927e+47*cos(theta)**17 - 1.02950153422e+47*cos(theta)**15 + 3.33634756460186e+46*cos(theta)**13 - 6.58823063389734e+45*cos(theta)**11 + 7.84313170702065e+44*cos(theta)**9 - 5.37814745624273e+43*cos(theta)**7 + 1.93392288666262e+42*cos(theta)**5 - 3.02648339070833e+40*cos(theta)**3 + 1.31586234378623e+38*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl44_m_minus_22(theta, phi):
    return 5.40818165421429e-36*(1.0 - cos(theta)**2)**11*(3.52872264876331e+45*cos(theta)**22 - 9.36936703292327e+45*cos(theta)**20 + 1.04716455073848e+46*cos(theta)**18 - 6.43438458887501e+45*cos(theta)**16 + 2.38310540328704e+45*cos(theta)**14 - 5.49019219491445e+44*cos(theta)**12 + 7.84313170702065e+43*cos(theta)**10 - 6.72268432030341e+42*cos(theta)**8 + 3.22320481110438e+41*cos(theta)**6 - 7.56620847677083e+39*cos(theta)**4 + 6.57931171893116e+37*cos(theta)**2 - 8.92715294291881e+34)*sin(22*phi)

#@torch.jit.script
def Yl44_m_minus_21(theta, phi):
    return 2.10710974858833e-34*(1.0 - cos(theta)**2)**10.5*(1.53422723859274e+44*cos(theta)**23 - 4.46160334901108e+44*cos(theta)**21 + 5.5113923723078e+44*cos(theta)**19 - 3.78493211110295e+44*cos(theta)**17 + 1.5887369355247e+44*cos(theta)**15 - 4.22322476531881e+43*cos(theta)**13 + 7.13011973365513e+42*cos(theta)**11 - 7.46964924478157e+41*cos(theta)**9 + 4.60457830157768e+40*cos(theta)**7 - 1.51324169535417e+39*cos(theta)**5 + 2.19310390631039e+37*cos(theta)**3 - 8.92715294291881e+34*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl44_m_minus_20(theta, phi):
    return 8.32241667332855e-33*(1.0 - cos(theta)**2)**10*(6.39261349413643e+42*cos(theta)**24 - 2.02800152227776e+43*cos(theta)**22 + 2.7556961861539e+43*cos(theta)**20 - 2.10274006172386e+43*cos(theta)**18 + 9.92960584702934e+42*cos(theta)**16 - 3.01658911808486e+42*cos(theta)**14 + 5.94176644471261e+41*cos(theta)**12 - 7.46964924478157e+40*cos(theta)**10 + 5.7557228769721e+39*cos(theta)**8 - 2.52206949225694e+38*cos(theta)**6 + 5.48275976577597e+36*cos(theta)**4 - 4.4635764714594e+34*cos(theta)**2 + 5.72253393776847e+31)*sin(20*phi)

#@torch.jit.script
def Yl44_m_minus_19(theta, phi):
    return 3.32896666933142e-31*(1.0 - cos(theta)**2)**9.5*(2.55704539765457e+41*cos(theta)**25 - 8.8173979229468e+41*cos(theta)**23 + 1.31223627912091e+42*cos(theta)**21 - 1.10670529564414e+42*cos(theta)**19 + 5.84094461589961e+41*cos(theta)**17 - 2.01105941205658e+41*cos(theta)**15 + 4.57058957285585e+40*cos(theta)**13 - 6.7905902225287e+39*cos(theta)**11 + 6.39524764108011e+38*cos(theta)**9 - 3.60295641750992e+37*cos(theta)**7 + 1.09655195315519e+36*cos(theta)**5 - 1.4878588238198e+34*cos(theta)**3 + 5.72253393776847e+31*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl44_m_minus_18(theta, phi):
    return 1.34730647078091e-29*(1.0 - cos(theta)**2)**9*(9.83478999097912e+39*cos(theta)**26 - 3.67391580122783e+40*cos(theta)**24 + 5.96471035964048e+40*cos(theta)**22 - 5.53352647822069e+40*cos(theta)**20 + 3.24496923105534e+40*cos(theta)**18 - 1.25691213253536e+40*cos(theta)**16 + 3.26470683775418e+39*cos(theta)**14 - 5.65882518544058e+38*cos(theta)**12 + 6.39524764108011e+37*cos(theta)**10 - 4.5036955218874e+36*cos(theta)**8 + 1.82758658859199e+35*cos(theta)**6 - 3.7196470595495e+33*cos(theta)**4 + 2.86126696888423e+31*cos(theta)**2 - 3.49361046261811e+28)*sin(18*phi)

#@torch.jit.script
def Yl44_m_minus_17(theta, phi):
    return 5.51244313501043e-28*(1.0 - cos(theta)**2)**8.5*(3.64251481147375e+38*cos(theta)**27 - 1.46956632049113e+39*cos(theta)**25 + 2.59335233027847e+39*cos(theta)**23 - 2.63501260867652e+39*cos(theta)**21 + 1.70787854266071e+39*cos(theta)**19 - 7.39360077961976e+38*cos(theta)**17 + 2.17647122516945e+38*cos(theta)**15 - 4.35294245033891e+37*cos(theta)**13 + 5.81386149189101e+36*cos(theta)**11 - 5.00410613543045e+35*cos(theta)**9 + 2.61083798370284e+34*cos(theta)**7 - 7.439294119099e+32*cos(theta)**5 + 9.53755656294744e+30*cos(theta)**3 - 3.49361046261811e+28*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl44_m_minus_16(theta, phi):
    return 2.27818010861661e-26*(1.0 - cos(theta)**2)**8*(1.30089814695491e+37*cos(theta)**28 - 5.65217815573513e+37*cos(theta)**26 + 1.08056347094936e+38*cos(theta)**24 - 1.19773300394387e+38*cos(theta)**22 + 8.53939271330353e+37*cos(theta)**20 - 4.10755598867765e+37*cos(theta)**18 + 1.36029451573091e+37*cos(theta)**16 - 3.10924460738494e+36*cos(theta)**14 + 4.84488457657584e+35*cos(theta)**12 - 5.00410613543045e+34*cos(theta)**10 + 3.26354747962855e+33*cos(theta)**8 - 1.23988235318317e+32*cos(theta)**6 + 2.38438914073686e+30*cos(theta)**4 - 1.74680523130906e+28*cos(theta)**2 + 2.04543938092395e+25)*sin(16*phi)

#@torch.jit.script
def Yl44_m_minus_15(theta, phi):
    return 9.50304267942416e-25*(1.0 - cos(theta)**2)**7.5*(4.48585567915486e+35*cos(theta)**29 - 2.09339931693894e+36*cos(theta)**27 + 4.32225388379745e+36*cos(theta)**25 - 5.20753479975596e+36*cos(theta)**23 + 4.06637748252549e+36*cos(theta)**21 - 2.16187157298824e+36*cos(theta)**19 + 8.00173244547594e+35*cos(theta)**17 - 2.07282973825662e+35*cos(theta)**15 + 3.72683428967372e+34*cos(theta)**13 - 4.54918739584586e+33*cos(theta)**11 + 3.62616386625395e+32*cos(theta)**9 - 1.77126050454738e+31*cos(theta)**7 + 4.76877828147372e+29*cos(theta)**5 - 5.82268410436352e+27*cos(theta)**3 + 2.04543938092395e+25*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl44_m_minus_14(theta, phi):
    return 3.99806005076855e-23*(1.0 - cos(theta)**2)**7*(1.49528522638495e+34*cos(theta)**30 - 7.47642613192477e+34*cos(theta)**28 + 1.6624053399221e+35*cos(theta)**26 - 2.16980616656498e+35*cos(theta)**24 + 1.84835340114795e+35*cos(theta)**22 - 1.08093578649412e+35*cos(theta)**20 + 4.4454069141533e+34*cos(theta)**18 - 1.29551858641039e+34*cos(theta)**16 + 2.66202449262409e+33*cos(theta)**14 - 3.79098949653822e+32*cos(theta)**12 + 3.62616386625395e+31*cos(theta)**10 - 2.21407563068423e+30*cos(theta)**8 + 7.9479638024562e+28*cos(theta)**6 - 1.45567102609088e+27*cos(theta)**4 + 1.02271969046198e+25*cos(theta)**2 - 1.15561546944856e+22)*sin(14*phi)

#@torch.jit.script
def Yl44_m_minus_13(theta, phi):
    return 1.69529061039261e-21*(1.0 - cos(theta)**2)**6.5*(4.82350073027405e+32*cos(theta)**31 - 2.57807797652578e+33*cos(theta)**29 + 6.15705681452628e+33*cos(theta)**27 - 8.67922466625994e+33*cos(theta)**25 + 8.03631913542587e+33*cos(theta)**23 - 5.14731326901961e+33*cos(theta)**21 + 2.33968784955437e+33*cos(theta)**19 - 7.62069756711994e+32*cos(theta)**17 + 1.77468299508273e+32*cos(theta)**15 - 2.91614576656786e+31*cos(theta)**13 + 3.29651260568541e+30*cos(theta)**11 - 2.46008403409359e+29*cos(theta)**9 + 1.13542340035089e+28*cos(theta)**7 - 2.91134205218176e+26*cos(theta)**5 + 3.40906563487325e+24*cos(theta)**3 - 1.15561546944856e+22*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl44_m_minus_12(theta, phi):
    return 7.24030020283832e-20*(1.0 - cos(theta)**2)**6*(1.50734397821064e+31*cos(theta)**32 - 8.59359325508594e+31*cos(theta)**30 + 2.19894886233082e+32*cos(theta)**28 - 3.3381633331769e+32*cos(theta)**26 + 3.34846630642745e+32*cos(theta)**24 - 2.33968784955437e+32*cos(theta)**22 + 1.16984392477718e+32*cos(theta)**20 - 4.23372087062219e+31*cos(theta)**18 + 1.1091768719267e+31*cos(theta)**16 - 2.08296126183418e+30*cos(theta)**14 + 2.74709383807117e+29*cos(theta)**12 - 2.46008403409359e+28*cos(theta)**10 + 1.41927925043861e+27*cos(theta)**8 - 4.85223675363626e+25*cos(theta)**6 + 8.52266408718313e+23*cos(theta)**4 - 5.7780773472428e+21*cos(theta)**2 + 6.33561112636272e+18)*sin(12*phi)

#@torch.jit.script
def Yl44_m_minus_11(theta, phi):
    return 3.11248707798609e-18*(1.0 - cos(theta)**2)**5.5*(4.56770902488073e+29*cos(theta)**33 - 2.77212685647934e+30*cos(theta)**31 + 7.58258228389936e+30*cos(theta)**29 - 1.23635679006552e+31*cos(theta)**27 + 1.33938652257098e+31*cos(theta)**25 - 1.01725558676277e+31*cos(theta)**23 + 5.57068535608183e+30*cos(theta)**21 - 2.22827414243273e+30*cos(theta)**19 + 6.52456983486296e+29*cos(theta)**17 - 1.38864084122279e+29*cos(theta)**15 + 2.11314910620859e+28*cos(theta)**13 - 2.23644003099417e+27*cos(theta)**11 + 1.57697694493179e+26*cos(theta)**9 - 6.93176679090895e+24*cos(theta)**7 + 1.70453281743663e+23*cos(theta)**5 - 1.92602578241427e+21*cos(theta)**3 + 6.33561112636272e+18*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl44_m_minus_10(theta, phi):
    return 1.34594824439422e-16*(1.0 - cos(theta)**2)**5*(1.34344383084727e+28*cos(theta)**34 - 8.66289642649793e+28*cos(theta)**32 + 2.52752742796645e+29*cos(theta)**30 - 4.41555996451971e+29*cos(theta)**28 + 5.15148662527299e+29*cos(theta)**26 - 4.23856494484487e+29*cos(theta)**24 + 2.53212970730992e+29*cos(theta)**22 - 1.11413707121637e+29*cos(theta)**20 + 3.62476101936831e+28*cos(theta)**18 - 8.67900525764244e+27*cos(theta)**16 + 1.50939221872042e+27*cos(theta)**14 - 1.86370002582847e+26*cos(theta)**12 + 1.57697694493179e+25*cos(theta)**10 - 8.66470848863619e+23*cos(theta)**8 + 2.84088802906104e+22*cos(theta)**6 - 4.81506445603567e+20*cos(theta)**4 + 3.16780556318136e+18*cos(theta)**2 - 3.38802734030092e+15)*sin(10*phi)

#@torch.jit.script
def Yl44_m_minus_9(theta, phi):
    return 5.85139292711667e-15*(1.0 - cos(theta)**2)**4.5*(3.83841094527792e+26*cos(theta)**35 - 2.6251201292418e+27*cos(theta)**33 + 8.15331428376276e+27*cos(theta)**31 - 1.52260688431714e+28*cos(theta)**29 + 1.90795800936037e+28*cos(theta)**27 - 1.69542597793795e+28*cos(theta)**25 + 1.10092595969997e+28*cos(theta)**23 - 5.30541462483984e+27*cos(theta)**21 + 1.90776895756227e+27*cos(theta)**19 - 5.1052972103779e+26*cos(theta)**17 + 1.00626147914695e+26*cos(theta)**15 - 1.43361540448344e+25*cos(theta)**13 + 1.43361540448344e+24*cos(theta)**11 - 9.62745387626243e+22*cos(theta)**9 + 4.05841147008721e+21*cos(theta)**7 - 9.63012891207134e+19*cos(theta)**5 + 1.05593518772712e+18*cos(theta)**3 - 3.38802734030092e+15*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl44_m_minus_8(theta, phi):
    return 2.55592701088609e-13*(1.0 - cos(theta)**2)**4*(1.0662252625772e+25*cos(theta)**36 - 7.72094155659352e+25*cos(theta)**34 + 2.54791071367586e+26*cos(theta)**32 - 5.07535628105714e+26*cos(theta)**30 + 6.8141357477156e+26*cos(theta)**28 - 6.52086914591518e+26*cos(theta)**26 + 4.58719149874986e+26*cos(theta)**24 - 2.41155210219992e+26*cos(theta)**22 + 9.53884478781135e+25*cos(theta)**20 - 2.83627622798772e+25*cos(theta)**18 + 6.28913424466843e+24*cos(theta)**16 - 1.02401100320246e+24*cos(theta)**14 + 1.1946795037362e+23*cos(theta)**12 - 9.62745387626243e+21*cos(theta)**10 + 5.07301433760901e+20*cos(theta)**8 - 1.60502148534522e+19*cos(theta)**6 + 2.6398379693178e+17*cos(theta)**4 - 1.69401367015046e+15*cos(theta)**2 + 1775695671017.25)*sin(8*phi)

#@torch.jit.script
def Yl44_m_minus_7(theta, phi):
    return 1.12111711211166e-11*(1.0 - cos(theta)**2)**3.5*(2.8816898988573e+23*cos(theta)**37 - 2.20598330188386e+24*cos(theta)**35 + 7.72094155659352e+24*cos(theta)**33 - 1.63721170356682e+25*cos(theta)**31 + 2.3497019819709e+25*cos(theta)**29 - 2.41513672070933e+25*cos(theta)**27 + 1.83487659949994e+25*cos(theta)**25 - 1.04850091399997e+25*cos(theta)**23 + 4.54230704181493e+24*cos(theta)**21 - 1.4927769620988e+24*cos(theta)**19 + 3.6994907321579e+23*cos(theta)**17 - 6.82674002134972e+22*cos(theta)**15 + 9.18984233643232e+21*cos(theta)**13 - 8.75223079660221e+20*cos(theta)**11 + 5.63668259734334e+19*cos(theta)**9 - 2.29288783620746e+18*cos(theta)**7 + 5.2796759386356e+16*cos(theta)**5 - 564671223383487.0*cos(theta)**3 + 1775695671017.25*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl44_m_minus_6(theta, phi):
    return 4.93546262901146e-10*(1.0 - cos(theta)**2)**3*(7.5833944706771e+21*cos(theta)**38 - 6.12773139412184e+22*cos(theta)**36 + 2.27086516370398e+23*cos(theta)**34 - 5.11628657364631e+23*cos(theta)**32 + 7.83233993990299e+23*cos(theta)**30 - 8.62548828824759e+23*cos(theta)**28 + 7.0572176903844e+23*cos(theta)**26 - 4.3687538083332e+23*cos(theta)**24 + 2.06468501900678e+23*cos(theta)**22 - 7.46388481049401e+22*cos(theta)**20 + 2.05527262897661e+22*cos(theta)**18 - 4.26671251334358e+21*cos(theta)**16 + 6.56417309745166e+20*cos(theta)**14 - 7.29352566383517e+19*cos(theta)**12 + 5.63668259734334e+18*cos(theta)**10 - 2.86610979525933e+17*cos(theta)**8 + 8.799459897726e+15*cos(theta)**6 - 141167805845872.0*cos(theta)**4 + 887847835508.627*cos(theta)**2 - 916251636.231813)*sin(6*phi)

#@torch.jit.script
def Yl44_m_minus_5(theta, phi):
    return 2.17944128520635e-8*(1.0 - cos(theta)**2)**2.5*(1.94446012068644e+20*cos(theta)**39 - 1.65614362003293e+21*cos(theta)**37 + 6.48818618201136e+21*cos(theta)**35 - 1.55038987080191e+22*cos(theta)**33 + 2.52656127093645e+22*cos(theta)**31 - 2.97430630629227e+22*cos(theta)**29 + 2.613784329772e+22*cos(theta)**27 - 1.74750152333328e+22*cos(theta)**25 + 8.97689138698602e+21*cos(theta)**23 - 3.55423086214001e+21*cos(theta)**21 + 1.08172243630348e+21*cos(theta)**19 - 2.5098308902021e+20*cos(theta)**17 + 4.3761153983011e+19*cos(theta)**15 - 5.61040435679629e+18*cos(theta)**13 + 5.12425690667577e+17*cos(theta)**11 - 3.18456643917703e+16*cos(theta)**9 + 1.25706569967514e+15*cos(theta)**7 - 28233561169174.3*cos(theta)**5 + 295949278502.876*cos(theta)**3 - 916251636.231813*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl44_m_minus_4(theta, phi):
    return 9.64879788299937e-7*(1.0 - cos(theta)**2)**2*(4.86115030171609e+18*cos(theta)**40 - 4.35827268429718e+19*cos(theta)**38 + 1.8022739394476e+20*cos(theta)**36 - 4.55997020824091e+20*cos(theta)**34 + 7.8955039716764e+20*cos(theta)**32 - 9.91435435430758e+20*cos(theta)**30 + 9.33494403489999e+20*cos(theta)**28 - 6.721159705128e+20*cos(theta)**26 + 3.74037141124418e+20*cos(theta)**24 - 1.61555948279091e+20*cos(theta)**22 + 5.4086121815174e+19*cos(theta)**20 - 1.39435049455672e+19*cos(theta)**18 + 2.73507212393819e+18*cos(theta)**16 - 4.00743168342592e+17*cos(theta)**14 + 4.27021408889647e+16*cos(theta)**12 - 3.18456643917703e+15*cos(theta)**10 + 157133212459393.0*cos(theta)**8 - 4705593528195.72*cos(theta)**6 + 73987319625.7189*cos(theta)**4 - 458125818.115907*cos(theta)**2 + 467475.324608068)*sin(4*phi)

#@torch.jit.script
def Yl44_m_minus_3(theta, phi):
    return 4.28041380657482e-5*(1.0 - cos(theta)**2)**1.5*(1.1856464150527e+17*cos(theta)**41 - 1.11750581648646e+18*cos(theta)**39 + 4.87101064715568e+18*cos(theta)**37 - 1.30284863092598e+19*cos(theta)**35 + 2.39257696111406e+19*cos(theta)**33 - 3.19817882397019e+19*cos(theta)**31 + 3.21894621893103e+19*cos(theta)**29 - 2.48931840930666e+19*cos(theta)**27 + 1.49614856449767e+19*cos(theta)**25 - 7.02417166430831e+18*cos(theta)**23 + 2.57552961024638e+18*cos(theta)**21 - 7.33868681345644e+17*cos(theta)**19 + 1.60886595525776e+17*cos(theta)**17 - 2.67162112228395e+16*cos(theta)**15 + 3.2847800683819e+15*cos(theta)**13 - 289506039925185.0*cos(theta)**11 + 17459245828821.4*cos(theta)**9 - 672227646885.103*cos(theta)**7 + 14797463925.1438*cos(theta)**5 - 152708606.038636*cos(theta)**3 + 467475.324608068*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl44_m_minus_2(theta, phi):
    return 0.00190177585981601*(1.0 - cos(theta)**2)*(2.82296765488739e+15*cos(theta)**42 - 2.79376454121614e+16*cos(theta)**40 + 1.28184490714623e+17*cos(theta)**38 - 3.61902397479438e+17*cos(theta)**36 + 7.03699106210018e+17*cos(theta)**34 - 9.99430882490684e+17*cos(theta)**32 + 1.07298207297701e+18*cos(theta)**30 - 8.89042289038095e+17*cos(theta)**28 + 5.75441755576027e+17*cos(theta)**26 - 2.9267381934618e+17*cos(theta)**24 + 1.17069527738472e+17*cos(theta)**22 - 3.66934340672822e+16*cos(theta)**20 + 8.93814419587644e+15*cos(theta)**18 - 1.66976320142747e+15*cos(theta)**16 + 234627147741564.0*cos(theta)**14 - 24125503327098.7*cos(theta)**12 + 1745924582882.14*cos(theta)**10 - 84028455860.6379*cos(theta)**8 + 2466243987.52396*cos(theta)**6 - 38177151.5096589*cos(theta)**4 + 233737.662304034*cos(theta)**2 - 236.81627386427)*sin(2*phi)

#@torch.jit.script
def Yl44_m_minus_1(theta, phi):
    return 0.0845809334938809*(1.0 - cos(theta)**2)**0.5*(65650410578776.6*cos(theta)**43 - 681405985662474.0*cos(theta)**41 + 3.28678181319546e+15*cos(theta)**39 - 9.78114587782264e+15*cos(theta)**37 + 2.01056887488577e+16*cos(theta)**35 - 3.02857843178995e+16*cos(theta)**33 + 3.46123249347423e+16*cos(theta)**31 - 3.0656630656486e+16*cos(theta)**29 + 2.13126576139269e+16*cos(theta)**27 - 1.17069527738472e+16*cos(theta)**25 + 5.08997946689008e+15*cos(theta)**23 - 1.7473063841563e+15*cos(theta)**21 + 470428641888234.0*cos(theta)**19 - 98221364789851.0*cos(theta)**17 + 15641809849437.6*cos(theta)**15 - 1855807948238.36*cos(theta)**13 + 158720416625.649*cos(theta)**11 - 9336495095.62644*cos(theta)**9 + 352320569.646281*cos(theta)**7 - 7635430.30193178*cos(theta)**5 + 77912.5541013447*cos(theta)**3 - 236.81627386427*cos(theta))*sin(phi)

#@torch.jit.script
def Yl44_m0(theta, phi):
    return 12474545000889.2*cos(theta)**44 - 135642753687829.0*cos(theta)**42 + 686990652501300.0*cos(theta)**40 - 2.15201891144986e+15*cos(theta)**38 + 4.669349675152e+15*cos(theta)**36 - 7.44731720340699e+15*cos(theta)**34 + 9.04317088985134e+15*cos(theta)**32 - 8.54364335498336e+15*cos(theta)**30 + 6.36384393735918e+15*cos(theta)**28 - 3.76452739956459e+15*cos(theta)**26 + 1.77314696356303e+15*cos(theta)**24 - 664027899516142.0*cos(theta)**22 + 196654416395165.0*cos(theta)**20 - 45621903681418.0*cos(theta)**18 + 8173479230980.04*cos(theta)**16 - 1108268370302.38*cos(theta)**14 + 110583795720.961*cos(theta)**12 - 7805914992.06784*cos(theta)**10 + 368203537.36169*cos(theta)**8 - 10639524.299409*cos(theta)**6 + 162849.861725648*cos(theta)**4 - 989.968764289654*cos(theta)**2 + 0.999968448777429

#@torch.jit.script
def Yl44_m1(theta, phi):
    return 0.0845809334938809*(1.0 - cos(theta)**2)**0.5*(65650410578776.6*cos(theta)**43 - 681405985662474.0*cos(theta)**41 + 3.28678181319546e+15*cos(theta)**39 - 9.78114587782264e+15*cos(theta)**37 + 2.01056887488577e+16*cos(theta)**35 - 3.02857843178995e+16*cos(theta)**33 + 3.46123249347423e+16*cos(theta)**31 - 3.0656630656486e+16*cos(theta)**29 + 2.13126576139269e+16*cos(theta)**27 - 1.17069527738472e+16*cos(theta)**25 + 5.08997946689008e+15*cos(theta)**23 - 1.7473063841563e+15*cos(theta)**21 + 470428641888234.0*cos(theta)**19 - 98221364789851.0*cos(theta)**17 + 15641809849437.6*cos(theta)**15 - 1855807948238.36*cos(theta)**13 + 158720416625.649*cos(theta)**11 - 9336495095.62644*cos(theta)**9 + 352320569.646281*cos(theta)**7 - 7635430.30193178*cos(theta)**5 + 77912.5541013447*cos(theta)**3 - 236.81627386427*cos(theta))*cos(phi)

#@torch.jit.script
def Yl44_m2(theta, phi):
    return 0.00190177585981601*(1.0 - cos(theta)**2)*(2.82296765488739e+15*cos(theta)**42 - 2.79376454121614e+16*cos(theta)**40 + 1.28184490714623e+17*cos(theta)**38 - 3.61902397479438e+17*cos(theta)**36 + 7.03699106210018e+17*cos(theta)**34 - 9.99430882490684e+17*cos(theta)**32 + 1.07298207297701e+18*cos(theta)**30 - 8.89042289038095e+17*cos(theta)**28 + 5.75441755576027e+17*cos(theta)**26 - 2.9267381934618e+17*cos(theta)**24 + 1.17069527738472e+17*cos(theta)**22 - 3.66934340672822e+16*cos(theta)**20 + 8.93814419587644e+15*cos(theta)**18 - 1.66976320142747e+15*cos(theta)**16 + 234627147741564.0*cos(theta)**14 - 24125503327098.7*cos(theta)**12 + 1745924582882.14*cos(theta)**10 - 84028455860.6379*cos(theta)**8 + 2466243987.52396*cos(theta)**6 - 38177151.5096589*cos(theta)**4 + 233737.662304034*cos(theta)**2 - 236.81627386427)*cos(2*phi)

#@torch.jit.script
def Yl44_m3(theta, phi):
    return 4.28041380657482e-5*(1.0 - cos(theta)**2)**1.5*(1.1856464150527e+17*cos(theta)**41 - 1.11750581648646e+18*cos(theta)**39 + 4.87101064715568e+18*cos(theta)**37 - 1.30284863092598e+19*cos(theta)**35 + 2.39257696111406e+19*cos(theta)**33 - 3.19817882397019e+19*cos(theta)**31 + 3.21894621893103e+19*cos(theta)**29 - 2.48931840930666e+19*cos(theta)**27 + 1.49614856449767e+19*cos(theta)**25 - 7.02417166430831e+18*cos(theta)**23 + 2.57552961024638e+18*cos(theta)**21 - 7.33868681345644e+17*cos(theta)**19 + 1.60886595525776e+17*cos(theta)**17 - 2.67162112228395e+16*cos(theta)**15 + 3.2847800683819e+15*cos(theta)**13 - 289506039925185.0*cos(theta)**11 + 17459245828821.4*cos(theta)**9 - 672227646885.103*cos(theta)**7 + 14797463925.1438*cos(theta)**5 - 152708606.038636*cos(theta)**3 + 467475.324608068*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl44_m4(theta, phi):
    return 9.64879788299937e-7*(1.0 - cos(theta)**2)**2*(4.86115030171609e+18*cos(theta)**40 - 4.35827268429718e+19*cos(theta)**38 + 1.8022739394476e+20*cos(theta)**36 - 4.55997020824091e+20*cos(theta)**34 + 7.8955039716764e+20*cos(theta)**32 - 9.91435435430758e+20*cos(theta)**30 + 9.33494403489999e+20*cos(theta)**28 - 6.721159705128e+20*cos(theta)**26 + 3.74037141124418e+20*cos(theta)**24 - 1.61555948279091e+20*cos(theta)**22 + 5.4086121815174e+19*cos(theta)**20 - 1.39435049455672e+19*cos(theta)**18 + 2.73507212393819e+18*cos(theta)**16 - 4.00743168342592e+17*cos(theta)**14 + 4.27021408889647e+16*cos(theta)**12 - 3.18456643917703e+15*cos(theta)**10 + 157133212459393.0*cos(theta)**8 - 4705593528195.72*cos(theta)**6 + 73987319625.7189*cos(theta)**4 - 458125818.115907*cos(theta)**2 + 467475.324608068)*cos(4*phi)

#@torch.jit.script
def Yl44_m5(theta, phi):
    return 2.17944128520635e-8*(1.0 - cos(theta)**2)**2.5*(1.94446012068644e+20*cos(theta)**39 - 1.65614362003293e+21*cos(theta)**37 + 6.48818618201136e+21*cos(theta)**35 - 1.55038987080191e+22*cos(theta)**33 + 2.52656127093645e+22*cos(theta)**31 - 2.97430630629227e+22*cos(theta)**29 + 2.613784329772e+22*cos(theta)**27 - 1.74750152333328e+22*cos(theta)**25 + 8.97689138698602e+21*cos(theta)**23 - 3.55423086214001e+21*cos(theta)**21 + 1.08172243630348e+21*cos(theta)**19 - 2.5098308902021e+20*cos(theta)**17 + 4.3761153983011e+19*cos(theta)**15 - 5.61040435679629e+18*cos(theta)**13 + 5.12425690667577e+17*cos(theta)**11 - 3.18456643917703e+16*cos(theta)**9 + 1.25706569967514e+15*cos(theta)**7 - 28233561169174.3*cos(theta)**5 + 295949278502.876*cos(theta)**3 - 916251636.231813*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl44_m6(theta, phi):
    return 4.93546262901146e-10*(1.0 - cos(theta)**2)**3*(7.5833944706771e+21*cos(theta)**38 - 6.12773139412184e+22*cos(theta)**36 + 2.27086516370398e+23*cos(theta)**34 - 5.11628657364631e+23*cos(theta)**32 + 7.83233993990299e+23*cos(theta)**30 - 8.62548828824759e+23*cos(theta)**28 + 7.0572176903844e+23*cos(theta)**26 - 4.3687538083332e+23*cos(theta)**24 + 2.06468501900678e+23*cos(theta)**22 - 7.46388481049401e+22*cos(theta)**20 + 2.05527262897661e+22*cos(theta)**18 - 4.26671251334358e+21*cos(theta)**16 + 6.56417309745166e+20*cos(theta)**14 - 7.29352566383517e+19*cos(theta)**12 + 5.63668259734334e+18*cos(theta)**10 - 2.86610979525933e+17*cos(theta)**8 + 8.799459897726e+15*cos(theta)**6 - 141167805845872.0*cos(theta)**4 + 887847835508.627*cos(theta)**2 - 916251636.231813)*cos(6*phi)

#@torch.jit.script
def Yl44_m7(theta, phi):
    return 1.12111711211166e-11*(1.0 - cos(theta)**2)**3.5*(2.8816898988573e+23*cos(theta)**37 - 2.20598330188386e+24*cos(theta)**35 + 7.72094155659352e+24*cos(theta)**33 - 1.63721170356682e+25*cos(theta)**31 + 2.3497019819709e+25*cos(theta)**29 - 2.41513672070933e+25*cos(theta)**27 + 1.83487659949994e+25*cos(theta)**25 - 1.04850091399997e+25*cos(theta)**23 + 4.54230704181493e+24*cos(theta)**21 - 1.4927769620988e+24*cos(theta)**19 + 3.6994907321579e+23*cos(theta)**17 - 6.82674002134972e+22*cos(theta)**15 + 9.18984233643232e+21*cos(theta)**13 - 8.75223079660221e+20*cos(theta)**11 + 5.63668259734334e+19*cos(theta)**9 - 2.29288783620746e+18*cos(theta)**7 + 5.2796759386356e+16*cos(theta)**5 - 564671223383487.0*cos(theta)**3 + 1775695671017.25*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl44_m8(theta, phi):
    return 2.55592701088609e-13*(1.0 - cos(theta)**2)**4*(1.0662252625772e+25*cos(theta)**36 - 7.72094155659352e+25*cos(theta)**34 + 2.54791071367586e+26*cos(theta)**32 - 5.07535628105714e+26*cos(theta)**30 + 6.8141357477156e+26*cos(theta)**28 - 6.52086914591518e+26*cos(theta)**26 + 4.58719149874986e+26*cos(theta)**24 - 2.41155210219992e+26*cos(theta)**22 + 9.53884478781135e+25*cos(theta)**20 - 2.83627622798772e+25*cos(theta)**18 + 6.28913424466843e+24*cos(theta)**16 - 1.02401100320246e+24*cos(theta)**14 + 1.1946795037362e+23*cos(theta)**12 - 9.62745387626243e+21*cos(theta)**10 + 5.07301433760901e+20*cos(theta)**8 - 1.60502148534522e+19*cos(theta)**6 + 2.6398379693178e+17*cos(theta)**4 - 1.69401367015046e+15*cos(theta)**2 + 1775695671017.25)*cos(8*phi)

#@torch.jit.script
def Yl44_m9(theta, phi):
    return 5.85139292711667e-15*(1.0 - cos(theta)**2)**4.5*(3.83841094527792e+26*cos(theta)**35 - 2.6251201292418e+27*cos(theta)**33 + 8.15331428376276e+27*cos(theta)**31 - 1.52260688431714e+28*cos(theta)**29 + 1.90795800936037e+28*cos(theta)**27 - 1.69542597793795e+28*cos(theta)**25 + 1.10092595969997e+28*cos(theta)**23 - 5.30541462483984e+27*cos(theta)**21 + 1.90776895756227e+27*cos(theta)**19 - 5.1052972103779e+26*cos(theta)**17 + 1.00626147914695e+26*cos(theta)**15 - 1.43361540448344e+25*cos(theta)**13 + 1.43361540448344e+24*cos(theta)**11 - 9.62745387626243e+22*cos(theta)**9 + 4.05841147008721e+21*cos(theta)**7 - 9.63012891207134e+19*cos(theta)**5 + 1.05593518772712e+18*cos(theta)**3 - 3.38802734030092e+15*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl44_m10(theta, phi):
    return 1.34594824439422e-16*(1.0 - cos(theta)**2)**5*(1.34344383084727e+28*cos(theta)**34 - 8.66289642649793e+28*cos(theta)**32 + 2.52752742796645e+29*cos(theta)**30 - 4.41555996451971e+29*cos(theta)**28 + 5.15148662527299e+29*cos(theta)**26 - 4.23856494484487e+29*cos(theta)**24 + 2.53212970730992e+29*cos(theta)**22 - 1.11413707121637e+29*cos(theta)**20 + 3.62476101936831e+28*cos(theta)**18 - 8.67900525764244e+27*cos(theta)**16 + 1.50939221872042e+27*cos(theta)**14 - 1.86370002582847e+26*cos(theta)**12 + 1.57697694493179e+25*cos(theta)**10 - 8.66470848863619e+23*cos(theta)**8 + 2.84088802906104e+22*cos(theta)**6 - 4.81506445603567e+20*cos(theta)**4 + 3.16780556318136e+18*cos(theta)**2 - 3.38802734030092e+15)*cos(10*phi)

#@torch.jit.script
def Yl44_m11(theta, phi):
    return 3.11248707798609e-18*(1.0 - cos(theta)**2)**5.5*(4.56770902488073e+29*cos(theta)**33 - 2.77212685647934e+30*cos(theta)**31 + 7.58258228389936e+30*cos(theta)**29 - 1.23635679006552e+31*cos(theta)**27 + 1.33938652257098e+31*cos(theta)**25 - 1.01725558676277e+31*cos(theta)**23 + 5.57068535608183e+30*cos(theta)**21 - 2.22827414243273e+30*cos(theta)**19 + 6.52456983486296e+29*cos(theta)**17 - 1.38864084122279e+29*cos(theta)**15 + 2.11314910620859e+28*cos(theta)**13 - 2.23644003099417e+27*cos(theta)**11 + 1.57697694493179e+26*cos(theta)**9 - 6.93176679090895e+24*cos(theta)**7 + 1.70453281743663e+23*cos(theta)**5 - 1.92602578241427e+21*cos(theta)**3 + 6.33561112636272e+18*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl44_m12(theta, phi):
    return 7.24030020283832e-20*(1.0 - cos(theta)**2)**6*(1.50734397821064e+31*cos(theta)**32 - 8.59359325508594e+31*cos(theta)**30 + 2.19894886233082e+32*cos(theta)**28 - 3.3381633331769e+32*cos(theta)**26 + 3.34846630642745e+32*cos(theta)**24 - 2.33968784955437e+32*cos(theta)**22 + 1.16984392477718e+32*cos(theta)**20 - 4.23372087062219e+31*cos(theta)**18 + 1.1091768719267e+31*cos(theta)**16 - 2.08296126183418e+30*cos(theta)**14 + 2.74709383807117e+29*cos(theta)**12 - 2.46008403409359e+28*cos(theta)**10 + 1.41927925043861e+27*cos(theta)**8 - 4.85223675363626e+25*cos(theta)**6 + 8.52266408718313e+23*cos(theta)**4 - 5.7780773472428e+21*cos(theta)**2 + 6.33561112636272e+18)*cos(12*phi)

#@torch.jit.script
def Yl44_m13(theta, phi):
    return 1.69529061039261e-21*(1.0 - cos(theta)**2)**6.5*(4.82350073027405e+32*cos(theta)**31 - 2.57807797652578e+33*cos(theta)**29 + 6.15705681452628e+33*cos(theta)**27 - 8.67922466625994e+33*cos(theta)**25 + 8.03631913542587e+33*cos(theta)**23 - 5.14731326901961e+33*cos(theta)**21 + 2.33968784955437e+33*cos(theta)**19 - 7.62069756711994e+32*cos(theta)**17 + 1.77468299508273e+32*cos(theta)**15 - 2.91614576656786e+31*cos(theta)**13 + 3.29651260568541e+30*cos(theta)**11 - 2.46008403409359e+29*cos(theta)**9 + 1.13542340035089e+28*cos(theta)**7 - 2.91134205218176e+26*cos(theta)**5 + 3.40906563487325e+24*cos(theta)**3 - 1.15561546944856e+22*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl44_m14(theta, phi):
    return 3.99806005076855e-23*(1.0 - cos(theta)**2)**7*(1.49528522638495e+34*cos(theta)**30 - 7.47642613192477e+34*cos(theta)**28 + 1.6624053399221e+35*cos(theta)**26 - 2.16980616656498e+35*cos(theta)**24 + 1.84835340114795e+35*cos(theta)**22 - 1.08093578649412e+35*cos(theta)**20 + 4.4454069141533e+34*cos(theta)**18 - 1.29551858641039e+34*cos(theta)**16 + 2.66202449262409e+33*cos(theta)**14 - 3.79098949653822e+32*cos(theta)**12 + 3.62616386625395e+31*cos(theta)**10 - 2.21407563068423e+30*cos(theta)**8 + 7.9479638024562e+28*cos(theta)**6 - 1.45567102609088e+27*cos(theta)**4 + 1.02271969046198e+25*cos(theta)**2 - 1.15561546944856e+22)*cos(14*phi)

#@torch.jit.script
def Yl44_m15(theta, phi):
    return 9.50304267942416e-25*(1.0 - cos(theta)**2)**7.5*(4.48585567915486e+35*cos(theta)**29 - 2.09339931693894e+36*cos(theta)**27 + 4.32225388379745e+36*cos(theta)**25 - 5.20753479975596e+36*cos(theta)**23 + 4.06637748252549e+36*cos(theta)**21 - 2.16187157298824e+36*cos(theta)**19 + 8.00173244547594e+35*cos(theta)**17 - 2.07282973825662e+35*cos(theta)**15 + 3.72683428967372e+34*cos(theta)**13 - 4.54918739584586e+33*cos(theta)**11 + 3.62616386625395e+32*cos(theta)**9 - 1.77126050454738e+31*cos(theta)**7 + 4.76877828147372e+29*cos(theta)**5 - 5.82268410436352e+27*cos(theta)**3 + 2.04543938092395e+25*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl44_m16(theta, phi):
    return 2.27818010861661e-26*(1.0 - cos(theta)**2)**8*(1.30089814695491e+37*cos(theta)**28 - 5.65217815573513e+37*cos(theta)**26 + 1.08056347094936e+38*cos(theta)**24 - 1.19773300394387e+38*cos(theta)**22 + 8.53939271330353e+37*cos(theta)**20 - 4.10755598867765e+37*cos(theta)**18 + 1.36029451573091e+37*cos(theta)**16 - 3.10924460738494e+36*cos(theta)**14 + 4.84488457657584e+35*cos(theta)**12 - 5.00410613543045e+34*cos(theta)**10 + 3.26354747962855e+33*cos(theta)**8 - 1.23988235318317e+32*cos(theta)**6 + 2.38438914073686e+30*cos(theta)**4 - 1.74680523130906e+28*cos(theta)**2 + 2.04543938092395e+25)*cos(16*phi)

#@torch.jit.script
def Yl44_m17(theta, phi):
    return 5.51244313501043e-28*(1.0 - cos(theta)**2)**8.5*(3.64251481147375e+38*cos(theta)**27 - 1.46956632049113e+39*cos(theta)**25 + 2.59335233027847e+39*cos(theta)**23 - 2.63501260867652e+39*cos(theta)**21 + 1.70787854266071e+39*cos(theta)**19 - 7.39360077961976e+38*cos(theta)**17 + 2.17647122516945e+38*cos(theta)**15 - 4.35294245033891e+37*cos(theta)**13 + 5.81386149189101e+36*cos(theta)**11 - 5.00410613543045e+35*cos(theta)**9 + 2.61083798370284e+34*cos(theta)**7 - 7.439294119099e+32*cos(theta)**5 + 9.53755656294744e+30*cos(theta)**3 - 3.49361046261811e+28*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl44_m18(theta, phi):
    return 1.34730647078091e-29*(1.0 - cos(theta)**2)**9*(9.83478999097912e+39*cos(theta)**26 - 3.67391580122783e+40*cos(theta)**24 + 5.96471035964048e+40*cos(theta)**22 - 5.53352647822069e+40*cos(theta)**20 + 3.24496923105534e+40*cos(theta)**18 - 1.25691213253536e+40*cos(theta)**16 + 3.26470683775418e+39*cos(theta)**14 - 5.65882518544058e+38*cos(theta)**12 + 6.39524764108011e+37*cos(theta)**10 - 4.5036955218874e+36*cos(theta)**8 + 1.82758658859199e+35*cos(theta)**6 - 3.7196470595495e+33*cos(theta)**4 + 2.86126696888423e+31*cos(theta)**2 - 3.49361046261811e+28)*cos(18*phi)

#@torch.jit.script
def Yl44_m19(theta, phi):
    return 3.32896666933142e-31*(1.0 - cos(theta)**2)**9.5*(2.55704539765457e+41*cos(theta)**25 - 8.8173979229468e+41*cos(theta)**23 + 1.31223627912091e+42*cos(theta)**21 - 1.10670529564414e+42*cos(theta)**19 + 5.84094461589961e+41*cos(theta)**17 - 2.01105941205658e+41*cos(theta)**15 + 4.57058957285585e+40*cos(theta)**13 - 6.7905902225287e+39*cos(theta)**11 + 6.39524764108011e+38*cos(theta)**9 - 3.60295641750992e+37*cos(theta)**7 + 1.09655195315519e+36*cos(theta)**5 - 1.4878588238198e+34*cos(theta)**3 + 5.72253393776847e+31*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl44_m20(theta, phi):
    return 8.32241667332855e-33*(1.0 - cos(theta)**2)**10*(6.39261349413643e+42*cos(theta)**24 - 2.02800152227776e+43*cos(theta)**22 + 2.7556961861539e+43*cos(theta)**20 - 2.10274006172386e+43*cos(theta)**18 + 9.92960584702934e+42*cos(theta)**16 - 3.01658911808486e+42*cos(theta)**14 + 5.94176644471261e+41*cos(theta)**12 - 7.46964924478157e+40*cos(theta)**10 + 5.7557228769721e+39*cos(theta)**8 - 2.52206949225694e+38*cos(theta)**6 + 5.48275976577597e+36*cos(theta)**4 - 4.4635764714594e+34*cos(theta)**2 + 5.72253393776847e+31)*cos(20*phi)

#@torch.jit.script
def Yl44_m21(theta, phi):
    return 2.10710974858833e-34*(1.0 - cos(theta)**2)**10.5*(1.53422723859274e+44*cos(theta)**23 - 4.46160334901108e+44*cos(theta)**21 + 5.5113923723078e+44*cos(theta)**19 - 3.78493211110295e+44*cos(theta)**17 + 1.5887369355247e+44*cos(theta)**15 - 4.22322476531881e+43*cos(theta)**13 + 7.13011973365513e+42*cos(theta)**11 - 7.46964924478157e+41*cos(theta)**9 + 4.60457830157768e+40*cos(theta)**7 - 1.51324169535417e+39*cos(theta)**5 + 2.19310390631039e+37*cos(theta)**3 - 8.92715294291881e+34*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl44_m22(theta, phi):
    return 5.40818165421429e-36*(1.0 - cos(theta)**2)**11*(3.52872264876331e+45*cos(theta)**22 - 9.36936703292327e+45*cos(theta)**20 + 1.04716455073848e+46*cos(theta)**18 - 6.43438458887501e+45*cos(theta)**16 + 2.38310540328704e+45*cos(theta)**14 - 5.49019219491445e+44*cos(theta)**12 + 7.84313170702065e+43*cos(theta)**10 - 6.72268432030341e+42*cos(theta)**8 + 3.22320481110438e+41*cos(theta)**6 - 7.56620847677083e+39*cos(theta)**4 + 6.57931171893116e+37*cos(theta)**2 - 8.92715294291881e+34)*cos(22*phi)

#@torch.jit.script
def Yl44_m23(theta, phi):
    return 1.40864814870526e-37*(1.0 - cos(theta)**2)**11.5*(7.76318982727928e+46*cos(theta)**21 - 1.87387340658465e+47*cos(theta)**19 + 1.88489619132927e+47*cos(theta)**17 - 1.02950153422e+47*cos(theta)**15 + 3.33634756460186e+46*cos(theta)**13 - 6.58823063389734e+45*cos(theta)**11 + 7.84313170702065e+44*cos(theta)**9 - 5.37814745624273e+43*cos(theta)**7 + 1.93392288666262e+42*cos(theta)**5 - 3.02648339070833e+40*cos(theta)**3 + 1.31586234378623e+38*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl44_m24(theta, phi):
    return 3.72767829649342e-39*(1.0 - cos(theta)**2)**12*(1.63026986372865e+48*cos(theta)**20 - 3.56035947251084e+48*cos(theta)**18 + 3.20432352525976e+48*cos(theta)**16 - 1.54425230133e+48*cos(theta)**14 + 4.33725183398242e+47*cos(theta)**12 - 7.24705369728708e+46*cos(theta)**10 + 7.05881853631858e+45*cos(theta)**8 - 3.76470321936991e+44*cos(theta)**6 + 9.66961443331313e+42*cos(theta)**4 - 9.079450172125e+40*cos(theta)**2 + 1.31586234378623e+38)*cos(24*phi)

#@torch.jit.script
def Yl44_m25(theta, phi):
    return 1.00345726576353e-40*(1.0 - cos(theta)**2)**12.5*(3.2605397274573e+49*cos(theta)**19 - 6.40864705051951e+49*cos(theta)**17 + 5.12691764041561e+49*cos(theta)**15 - 2.161953221862e+49*cos(theta)**13 + 5.2047022007789e+48*cos(theta)**11 - 7.24705369728708e+47*cos(theta)**9 + 5.64705482905487e+46*cos(theta)**7 - 2.25882193162195e+45*cos(theta)**5 + 3.86784577332525e+43*cos(theta)**3 - 1.815890034425e+41*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl44_m26(theta, phi):
    return 2.75152245514281e-42*(1.0 - cos(theta)**2)**13*(6.19502548216886e+50*cos(theta)**18 - 1.08946999858832e+51*cos(theta)**16 + 7.69037646062342e+50*cos(theta)**14 - 2.81053918842061e+50*cos(theta)**12 + 5.72517242085679e+49*cos(theta)**10 - 6.52234832755837e+48*cos(theta)**8 + 3.95293838033841e+47*cos(theta)**6 - 1.12941096581097e+46*cos(theta)**4 + 1.16035373199758e+44*cos(theta)**2 - 1.815890034425e+41)*cos(26*phi)

#@torch.jit.script
def Yl44_m27(theta, phi):
    return 7.69675450430194e-44*(1.0 - cos(theta)**2)**13.5*(1.1151045867904e+52*cos(theta)**17 - 1.74315199774131e+52*cos(theta)**15 + 1.07665270448728e+52*cos(theta)**13 - 3.37264702610473e+51*cos(theta)**11 + 5.72517242085679e+50*cos(theta)**9 - 5.2178786620467e+49*cos(theta)**7 + 2.37176302820304e+48*cos(theta)**5 - 4.51764386324389e+46*cos(theta)**3 + 2.32070746399515e+44*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl44_m28(theta, phi):
    return 2.19997084612836e-45*(1.0 - cos(theta)**2)**14*(1.89567779754367e+53*cos(theta)**16 - 2.61472799661196e+53*cos(theta)**14 + 1.39964851583346e+53*cos(theta)**12 - 3.7099117287152e+52*cos(theta)**10 + 5.15265517877111e+51*cos(theta)**8 - 3.65251506343269e+50*cos(theta)**6 + 1.18588151410152e+49*cos(theta)**4 - 1.35529315897317e+47*cos(theta)**2 + 2.32070746399515e+44)*cos(28*phi)

#@torch.jit.script
def Yl44_m29(theta, phi):
    return 6.43717779072263e-47*(1.0 - cos(theta)**2)**14.5*(3.03308447606988e+54*cos(theta)**15 - 3.66061919525675e+54*cos(theta)**13 + 1.67957821900015e+54*cos(theta)**11 - 3.7099117287152e+53*cos(theta)**9 + 4.12212414301689e+52*cos(theta)**7 - 2.19150903805961e+51*cos(theta)**5 + 4.74352605640609e+49*cos(theta)**3 - 2.71058631794634e+47*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl44_m30(theta, phi):
    return 1.93211963867191e-48*(1.0 - cos(theta)**2)**15*(4.54962671410481e+55*cos(theta)**14 - 4.75880495383377e+55*cos(theta)**12 + 1.84753604090017e+55*cos(theta)**10 - 3.33892055584368e+54*cos(theta)**8 + 2.88548690011182e+53*cos(theta)**6 - 1.09575451902981e+52*cos(theta)**4 + 1.42305781692183e+50*cos(theta)**2 - 2.71058631794634e+47)*cos(30*phi)

#@torch.jit.script
def Yl44_m31(theta, phi):
    return 5.96265065549245e-50*(1.0 - cos(theta)**2)**15.5*(6.36947739974674e+56*cos(theta)**13 - 5.71056594460052e+56*cos(theta)**11 + 1.84753604090017e+56*cos(theta)**9 - 2.67113644467494e+55*cos(theta)**7 + 1.73129214006709e+54*cos(theta)**5 - 4.38301807611922e+52*cos(theta)**3 + 2.84611563384365e+50*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl44_m32(theta, phi):
    return 1.89697187951869e-51*(1.0 - cos(theta)**2)**16*(8.28032061967076e+57*cos(theta)**12 - 6.28162253906058e+57*cos(theta)**10 + 1.66278243681015e+57*cos(theta)**8 - 1.86979551127246e+56*cos(theta)**6 + 8.65646070033547e+54*cos(theta)**4 - 1.31490542283577e+53*cos(theta)**2 + 2.84611563384365e+50)*cos(32*phi)

#@torch.jit.script
def Yl44_m33(theta, phi):
    return 6.24057931710171e-53*(1.0 - cos(theta)**2)**16.5*(9.93638474360491e+58*cos(theta)**11 - 6.28162253906058e+58*cos(theta)**9 + 1.33022594944812e+58*cos(theta)**7 - 1.12187730676348e+57*cos(theta)**5 + 3.46258428013419e+55*cos(theta)**3 - 2.62981084567153e+53*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl44_m34(theta, phi):
    return 2.13049865063417e-54*(1.0 - cos(theta)**2)**17*(1.09300232179654e+60*cos(theta)**10 - 5.65346028515452e+59*cos(theta)**8 + 9.31158164613686e+58*cos(theta)**6 - 5.60938653381738e+57*cos(theta)**4 + 1.03877528404026e+56*cos(theta)**2 - 2.62981084567153e+53)*cos(34*phi)

#@torch.jit.script
def Yl44_m35(theta, phi):
    return 7.57997403251458e-56*(1.0 - cos(theta)**2)**17.5*(1.09300232179654e+61*cos(theta)**9 - 4.52276822812362e+60*cos(theta)**7 + 5.58694898768211e+59*cos(theta)**5 - 2.24375461352695e+58*cos(theta)**3 + 2.07755056808051e+56*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl44_m36(theta, phi):
    return 2.8248895340643e-57*(1.0 - cos(theta)**2)**18*(9.83702089616886e+61*cos(theta)**8 - 3.16593775968653e+61*cos(theta)**6 + 2.79347449384106e+60*cos(theta)**4 - 6.73126384058086e+58*cos(theta)**2 + 2.07755056808051e+56)*cos(36*phi)

#@torch.jit.script
def Yl44_m37(theta, phi):
    return 1.10972141424432e-58*(1.0 - cos(theta)**2)**18.5*(7.86961671693509e+62*cos(theta)**7 - 1.89956265581192e+62*cos(theta)**5 + 1.11738979753642e+61*cos(theta)**3 - 1.34625276811617e+59*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl44_m38(theta, phi):
    return 4.63188769029189e-60*(1.0 - cos(theta)**2)**19*(5.50873170185456e+63*cos(theta)**6 - 9.49781327905959e+62*cos(theta)**4 + 3.35216939260927e+61*cos(theta)**2 - 1.34625276811617e+59)*cos(38*phi)

#@torch.jit.script
def Yl44_m39(theta, phi):
    return 2.07559850445656e-61*(1.0 - cos(theta)**2)**19.5*(3.30523902111274e+64*cos(theta)**5 - 3.79912531162384e+63*cos(theta)**3 + 6.70433878521854e+61*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl44_m40(theta, phi):
    return 1.01278836595551e-62*(1.0 - cos(theta)**2)**20*(1.65261951055637e+65*cos(theta)**4 - 1.13973759348715e+64*cos(theta)**2 + 6.70433878521854e+61)*cos(40*phi)

#@torch.jit.script
def Yl44_m41(theta, phi):
    return 5.49261609750345e-64*(1.0 - cos(theta)**2)**20.5*(6.61047804222548e+65*cos(theta)**3 - 2.2794751869743e+64*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl44_m42(theta, phi):
    return 3.4195534181066e-65*(1.0 - cos(theta)**2)**21*(1.98314341266764e+66*cos(theta)**2 - 2.2794751869743e+64)*cos(42*phi)

#@torch.jit.script
def Yl44_m43(theta, phi):
    return 10.2820304486063*(1.0 - cos(theta)**2)**21.5*cos(43*phi)*cos(theta)

#@torch.jit.script
def Yl44_m44(theta, phi):
    return 1.09606812861653*(1.0 - cos(theta)**2)**22*cos(44*phi)

#@torch.jit.script
def Yl45_m_minus_45(theta, phi):
    return 1.10214057468876*(1.0 - cos(theta)**2)**22.5*sin(45*phi)

#@torch.jit.script
def Yl45_m_minus_44(theta, phi):
    return 10.4558235531102*(1.0 - cos(theta)**2)**22*sin(44*phi)*cos(theta)

#@torch.jit.script
def Yl45_m_minus_43(theta, phi):
    return 3.95179241074826e-67*(1.0 - cos(theta)**2)**21.5*(1.7649976372742e+68*cos(theta)**2 - 1.98314341266764e+66)*sin(43*phi)

#@torch.jit.script
def Yl45_m_minus_42(theta, phi):
    return 6.42090266241355e-66*(1.0 - cos(theta)**2)**21*(5.88332545758067e+67*cos(theta)**3 - 1.98314341266764e+66*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl45_m_minus_41(theta, phi):
    return 1.19780385990637e-64*(1.0 - cos(theta)**2)**20.5*(1.47083136439517e+67*cos(theta)**4 - 9.91571706333822e+65*cos(theta)**2 + 5.69868796743576e+63)*sin(41*phi)

#@torch.jit.script
def Yl45_m_minus_40(theta, phi):
    return 2.4838189493738e-63*(1.0 - cos(theta)**2)**20*(2.94166272879034e+66*cos(theta)**5 - 3.30523902111274e+65*cos(theta)**3 + 5.69868796743576e+63*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl45_m_minus_39(theta, phi):
    return 5.60925293810759e-62*(1.0 - cos(theta)**2)**19.5*(4.90277121465056e+65*cos(theta)**6 - 8.26309755278185e+64*cos(theta)**4 + 2.84934398371788e+63*cos(theta)**2 - 1.11738979753642e+61)*sin(39*phi)

#@torch.jit.script
def Yl45_m_minus_38(theta, phi):
    return 1.36017155138303e-60*(1.0 - cos(theta)**2)**19*(7.00395887807223e+64*cos(theta)**7 - 1.65261951055637e+64*cos(theta)**5 + 9.49781327905959e+62*cos(theta)**3 - 1.11738979753642e+61*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl45_m_minus_37(theta, phi):
    return 3.50491691066036e-59*(1.0 - cos(theta)**2)**18.5*(8.75494859759029e+63*cos(theta)**8 - 2.75436585092728e+63*cos(theta)**6 + 2.3744533197649e+62*cos(theta)**4 - 5.58694898768211e+60*cos(theta)**2 + 1.68281596014522e+58)*sin(37*phi)

#@torch.jit.script
def Yl45_m_minus_36(theta, phi):
    return 9.52151175096011e-58*(1.0 - cos(theta)**2)**18*(9.72772066398921e+62*cos(theta)**9 - 3.93480835846755e+62*cos(theta)**7 + 4.7489066395298e+61*cos(theta)**5 - 1.86231632922737e+60*cos(theta)**3 + 1.68281596014522e+58*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl45_m_minus_35(theta, phi):
    return 2.70986975109827e-56*(1.0 - cos(theta)**2)**17.5*(9.72772066398921e+61*cos(theta)**10 - 4.91851044808443e+61*cos(theta)**8 + 7.91484439921633e+60*cos(theta)**6 - 4.65579082306843e+59*cos(theta)**4 + 8.41407980072608e+57*cos(theta)**2 - 2.07755056808051e+55)*sin(35*phi)

#@torch.jit.script
def Yl45_m_minus_34(theta, phi):
    return 8.03877277932851e-55*(1.0 - cos(theta)**2)**17*(8.84338242180837e+60*cos(theta)**11 - 5.4650116089827e+60*cos(theta)**9 + 1.1306920570309e+60*cos(theta)**7 - 9.31158164613686e+58*cos(theta)**5 + 2.80469326690869e+57*cos(theta)**3 - 2.07755056808051e+55*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl45_m_minus_33(theta, phi):
    return 2.47510667794732e-53*(1.0 - cos(theta)**2)**16.5*(7.36948535150698e+59*cos(theta)**12 - 5.4650116089827e+59*cos(theta)**10 + 1.41336507128863e+59*cos(theta)**8 - 1.55193027435614e+58*cos(theta)**6 + 7.01173316727173e+56*cos(theta)**4 - 1.03877528404026e+55*cos(theta)**2 + 2.19150903805961e+52)*sin(33*phi)

#@torch.jit.script
def Yl45_m_minus_32(theta, phi):
    return 7.88157294590393e-52*(1.0 - cos(theta)**2)**16*(5.6688348857746e+58*cos(theta)**13 - 4.96819237180246e+58*cos(theta)**11 + 1.57040563476514e+58*cos(theta)**9 - 2.2170432490802e+57*cos(theta)**7 + 1.40234663345435e+56*cos(theta)**5 - 3.46258428013419e+54*cos(theta)**3 + 2.19150903805961e+52*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl45_m_minus_31(theta, phi):
    return 2.5877497770366e-50*(1.0 - cos(theta)**2)**15.5*(4.04916777555328e+57*cos(theta)**14 - 4.14016030983538e+57*cos(theta)**12 + 1.57040563476514e+57*cos(theta)**10 - 2.77130406135025e+56*cos(theta)**8 + 2.33724438909058e+55*cos(theta)**6 - 8.65646070033547e+53*cos(theta)**4 + 1.09575451902981e+52*cos(theta)**2 - 2.03293973845975e+49)*sin(31*phi)

#@torch.jit.script
def Yl45_m_minus_30(theta, phi):
    return 8.73724885518915e-49*(1.0 - cos(theta)**2)**15*(2.69944518370219e+56*cos(theta)**15 - 3.18473869987337e+56*cos(theta)**13 + 1.42764148615013e+56*cos(theta)**11 - 3.07922673483362e+55*cos(theta)**9 + 3.33892055584368e+54*cos(theta)**7 - 1.73129214006709e+53*cos(theta)**5 + 3.65251506343269e+51*cos(theta)**3 - 2.03293973845975e+49*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl45_m_minus_29(theta, phi):
    return 3.02667178711212e-47*(1.0 - cos(theta)**2)**14.5*(1.68715323981387e+55*cos(theta)**16 - 2.27481335705241e+55*cos(theta)**14 + 1.18970123845844e+55*cos(theta)**12 - 3.07922673483362e+54*cos(theta)**10 + 4.1736506948046e+53*cos(theta)**8 - 2.88548690011182e+52*cos(theta)**6 + 9.13128765858172e+50*cos(theta)**4 - 1.01646986922988e+49*cos(theta)**2 + 1.69411644871646e+46)*sin(29*phi)

#@torch.jit.script
def Yl45_m_minus_28(theta, phi):
    return 1.07350889938001e-45*(1.0 - cos(theta)**2)**14*(9.92443082243452e+53*cos(theta)**17 - 1.51654223803494e+54*cos(theta)**15 + 9.15154798814187e+53*cos(theta)**13 - 2.79929703166692e+53*cos(theta)**11 + 4.637389660894e+52*cos(theta)**9 - 4.12212414301689e+51*cos(theta)**7 + 1.82625753171634e+50*cos(theta)**5 - 3.38823289743292e+48*cos(theta)**3 + 1.69411644871646e+46*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl45_m_minus_27(theta, phi):
    return 3.89137721528147e-44*(1.0 - cos(theta)**2)**13.5*(5.51357267913029e+52*cos(theta)**18 - 9.47838898771836e+52*cos(theta)**16 + 6.5368199915299e+52*cos(theta)**14 - 2.3327475263891e+52*cos(theta)**12 + 4.637389660894e+51*cos(theta)**10 - 5.15265517877111e+50*cos(theta)**8 + 3.04376255286057e+49*cos(theta)**6 - 8.4705822435823e+47*cos(theta)**4 + 8.4705822435823e+45*cos(theta)**2 - 1.28928192444175e+43)*sin(27*phi)

#@torch.jit.script
def Yl45_m_minus_26(theta, phi):
    return 1.43928361180293e-42*(1.0 - cos(theta)**2)**13*(2.90188035743699e+51*cos(theta)**19 - 5.57552293395198e+51*cos(theta)**17 + 4.35787999435327e+51*cos(theta)**15 - 1.79442117414546e+51*cos(theta)**13 + 4.21580878263091e+50*cos(theta)**11 - 5.72517242085679e+49*cos(theta)**9 + 4.34823221837225e+48*cos(theta)**7 - 1.69411644871646e+47*cos(theta)**5 + 2.82352741452743e+45*cos(theta)**3 - 1.28928192444175e+43*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl45_m_minus_25(theta, phi):
    return 5.42363622267421e-41*(1.0 - cos(theta)**2)**12.5*(1.4509401787185e+50*cos(theta)**20 - 3.09751274108443e+50*cos(theta)**18 + 2.72367499647079e+50*cos(theta)**16 - 1.2817294101039e+50*cos(theta)**14 + 3.51317398552576e+49*cos(theta)**12 - 5.72517242085679e+48*cos(theta)**10 + 5.43529027296531e+47*cos(theta)**8 - 2.82352741452743e+46*cos(theta)**6 + 7.05881853631858e+44*cos(theta)**4 - 6.44640962220875e+42*cos(theta)**2 + 9.079450172125e+39)*sin(25*phi)

#@torch.jit.script
def Yl45_m_minus_24(theta, phi):
    return 2.07945353200254e-39*(1.0 - cos(theta)**2)**12*(6.90923894627856e+48*cos(theta)**21 - 1.63026986372865e+49*cos(theta)**19 + 1.60216176262988e+49*cos(theta)**17 - 8.54486273402602e+48*cos(theta)**15 + 2.70244152732751e+48*cos(theta)**13 - 5.2047022007789e+47*cos(theta)**11 + 6.0392114144059e+46*cos(theta)**9 - 4.03361059218205e+45*cos(theta)**7 + 1.41176370726372e+44*cos(theta)**5 - 2.14880320740292e+42*cos(theta)**3 + 9.079450172125e+39*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl45_m_minus_23(theta, phi):
    return 8.10186692897904e-38*(1.0 - cos(theta)**2)**11.5*(3.14056315739934e+47*cos(theta)**22 - 8.15134931864324e+47*cos(theta)**20 + 8.9008986812771e+47*cos(theta)**18 - 5.34053920876626e+47*cos(theta)**16 + 1.9303153766625e+47*cos(theta)**14 - 4.33725183398242e+46*cos(theta)**12 + 6.0392114144059e+45*cos(theta)**10 - 5.04201324022756e+44*cos(theta)**8 + 2.35293951210619e+43*cos(theta)**6 - 5.37200801850729e+41*cos(theta)**4 + 4.5397250860625e+39*cos(theta)**2 - 5.9811924717556e+36)*sin(23*phi)

#@torch.jit.script
def Yl45_m_minus_22(theta, phi):
    return 3.20408095180754e-36*(1.0 - cos(theta)**2)**11*(1.36546224234754e+46*cos(theta)**23 - 3.88159491363964e+46*cos(theta)**21 + 4.68468351646163e+46*cos(theta)**19 - 3.14149365221545e+46*cos(theta)**17 + 1.286876917775e+46*cos(theta)**15 - 3.33634756460186e+45*cos(theta)**13 + 5.49019219491445e+44*cos(theta)**11 - 5.60223693358618e+43*cos(theta)**9 + 3.36134216015171e+42*cos(theta)**7 - 1.07440160370146e+41*cos(theta)**5 + 1.51324169535417e+39*cos(theta)**3 - 5.9811924717556e+36*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl45_m_minus_21(theta, phi):
    return 1.28483246655521e-34*(1.0 - cos(theta)**2)**10.5*(5.68942600978142e+44*cos(theta)**24 - 1.76436132438165e+45*cos(theta)**22 + 2.34234175823082e+45*cos(theta)**20 - 1.7452742512308e+45*cos(theta)**18 + 8.04298073609377e+44*cos(theta)**16 - 2.38310540328704e+44*cos(theta)**14 + 4.57516016242871e+43*cos(theta)**12 - 5.60223693358618e+42*cos(theta)**10 + 4.20167770018963e+41*cos(theta)**8 - 1.79066933950243e+40*cos(theta)**6 + 3.78310423838542e+38*cos(theta)**4 - 2.9905962358778e+36*cos(theta)**2 + 3.7196470595495e+33)*sin(21*phi)

#@torch.jit.script
def Yl45_m_minus_20(theta, phi):
    return 5.21901415090882e-33*(1.0 - cos(theta)**2)**10*(2.27577040391257e+43*cos(theta)**25 - 7.67113619296371e+43*cos(theta)**23 + 1.11540083725277e+44*cos(theta)**21 - 9.18565395384634e+43*cos(theta)**19 + 4.73116513887869e+43*cos(theta)**17 - 1.5887369355247e+43*cos(theta)**15 + 3.51935397109901e+42*cos(theta)**13 - 5.09294266689652e+41*cos(theta)**11 + 4.66853077798848e+40*cos(theta)**9 - 2.55809905643204e+39*cos(theta)**7 + 7.56620847677083e+37*cos(theta)**5 - 9.96865411959267e+35*cos(theta)**3 + 3.7196470595495e+33*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl45_m_minus_19(theta, phi):
    return 2.14551634147781e-31*(1.0 - cos(theta)**2)**9.5*(8.75296309197142e+41*cos(theta)**26 - 3.19630674706821e+42*cos(theta)**24 + 5.07000380569441e+42*cos(theta)**22 - 4.59282697692317e+42*cos(theta)**20 + 2.62842507715483e+42*cos(theta)**18 - 9.92960584702934e+41*cos(theta)**16 + 2.51382426507072e+41*cos(theta)**14 - 4.24411888908044e+40*cos(theta)**12 + 4.66853077798848e+39*cos(theta)**10 - 3.19762382054005e+38*cos(theta)**8 + 1.26103474612847e+37*cos(theta)**6 - 2.49216352989817e+35*cos(theta)**4 + 1.85982352977475e+33*cos(theta)**2 - 2.20097459144941e+30)*sin(19*phi)

#@torch.jit.script
def Yl45_m_minus_18(theta, phi):
    return 8.91874394858126e-30*(1.0 - cos(theta)**2)**9*(3.24183818221164e+40*cos(theta)**27 - 1.27852269882729e+41*cos(theta)**25 + 2.2043494807367e+41*cos(theta)**23 - 2.18706046520151e+41*cos(theta)**21 + 1.38338161955517e+41*cos(theta)**19 - 5.84094461589961e+40*cos(theta)**17 + 1.67588284338048e+40*cos(theta)**15 - 3.26470683775418e+39*cos(theta)**13 + 4.24411888908044e+38*cos(theta)**11 - 3.55291535615562e+37*cos(theta)**9 + 1.80147820875496e+36*cos(theta)**7 - 4.98432705979633e+34*cos(theta)**5 + 6.19941176591584e+32*cos(theta)**3 - 2.20097459144941e+30*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl45_m_minus_17(theta, phi):
    return 3.74587245840413e-28*(1.0 - cos(theta)**2)**8.5*(1.15779935078987e+39*cos(theta)**28 - 4.91739499548956e+39*cos(theta)**26 + 9.18478950306958e+39*cos(theta)**24 - 9.94118393273413e+39*cos(theta)**22 + 6.91690809777586e+39*cos(theta)**20 - 3.24496923105534e+39*cos(theta)**18 + 1.0474267771128e+39*cos(theta)**16 - 2.3319334555387e+38*cos(theta)**14 + 3.53676574090036e+37*cos(theta)**12 - 3.55291535615562e+36*cos(theta)**10 + 2.2518477609437e+35*cos(theta)**8 - 8.30721176632722e+33*cos(theta)**6 + 1.54985294147896e+32*cos(theta)**4 - 1.1004872957247e+30*cos(theta)**2 + 1.24771802236361e+27)*sin(17*phi)

#@torch.jit.script
def Yl45_m_minus_16(theta, phi):
    return 1.5883559340836e-26*(1.0 - cos(theta)**2)**8*(3.99241155444783e+37*cos(theta)**29 - 1.82125740573687e+38*cos(theta)**27 + 3.67391580122783e+38*cos(theta)**25 - 4.32225388379745e+38*cos(theta)**23 + 3.29376576084565e+38*cos(theta)**21 - 1.70787854266071e+38*cos(theta)**19 + 6.16133398301647e+37*cos(theta)**17 - 1.55462230369247e+37*cos(theta)**15 + 2.72058903146182e+36*cos(theta)**13 - 3.22992305105056e+35*cos(theta)**11 + 2.50205306771522e+34*cos(theta)**9 - 1.18674453804675e+33*cos(theta)**7 + 3.09970588295792e+31*cos(theta)**5 - 3.66829098574902e+29*cos(theta)**3 + 1.24771802236361e+27*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl45_m_minus_15(theta, phi):
    return 6.79474831705311e-25*(1.0 - cos(theta)**2)**7.5*(1.33080385148261e+36*cos(theta)**30 - 6.50449073477455e+36*cos(theta)**28 + 1.41304453893378e+37*cos(theta)**26 - 1.80093911824894e+37*cos(theta)**24 + 1.49716625492984e+37*cos(theta)**22 - 8.53939271330353e+36*cos(theta)**20 + 3.42296332389804e+36*cos(theta)**18 - 9.71638939807792e+35*cos(theta)**16 + 1.94327787961558e+35*cos(theta)**14 - 2.69160254254213e+34*cos(theta)**12 + 2.50205306771522e+33*cos(theta)**10 - 1.48343067255843e+32*cos(theta)**8 + 5.16617647159653e+30*cos(theta)**6 - 9.17072746437254e+28*cos(theta)**4 + 6.23859011181806e+26*cos(theta)**2 - 6.81813126974651e+23)*sin(15*phi)

#@torch.jit.script
def Yl45_m_minus_14(theta, phi):
    return 2.93041984581218e-23*(1.0 - cos(theta)**2)**7*(4.2929156499439e+34*cos(theta)**31 - 2.24292783957743e+35*cos(theta)**29 + 5.23349829234734e+35*cos(theta)**27 - 7.20375647299575e+35*cos(theta)**25 + 6.50941849969495e+35*cos(theta)**23 - 4.06637748252549e+35*cos(theta)**21 + 1.80155964415686e+35*cos(theta)**19 - 5.71552317533995e+34*cos(theta)**17 + 1.29551858641039e+34*cos(theta)**15 - 2.07046349426318e+33*cos(theta)**13 + 2.27459369792293e+32*cos(theta)**11 - 1.6482563028427e+31*cos(theta)**9 + 7.38025210228076e+29*cos(theta)**7 - 1.83414549287451e+28*cos(theta)**5 + 2.07953003727268e+26*cos(theta)**3 - 6.81813126974651e+23*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl45_m_minus_13(theta, phi):
    return 1.27330030128458e-21*(1.0 - cos(theta)**2)**6.5*(1.34153614060747e+33*cos(theta)**32 - 7.47642613192477e+33*cos(theta)**30 + 1.86910653298119e+34*cos(theta)**28 - 2.77067556653683e+34*cos(theta)**26 + 2.71225770820623e+34*cos(theta)**24 - 1.84835340114795e+34*cos(theta)**22 + 9.00779822078431e+33*cos(theta)**20 - 3.17529065296664e+33*cos(theta)**18 + 8.09699116506493e+32*cos(theta)**16 - 1.47890249590227e+32*cos(theta)**14 + 1.89549474826911e+31*cos(theta)**12 - 1.6482563028427e+30*cos(theta)**10 + 9.22531512785095e+28*cos(theta)**8 - 3.05690915479085e+27*cos(theta)**6 + 5.19882509318171e+25*cos(theta)**4 - 3.40906563487325e+23*cos(theta)**2 + 3.61129834202675e+20)*sin(13*phi)

#@torch.jit.script
def Yl45_m_minus_12(theta, phi):
    return 5.57059786735605e-20*(1.0 - cos(theta)**2)**6*(4.06526103214385e+31*cos(theta)**33 - 2.41175036513702e+32*cos(theta)**31 + 6.44519494131446e+32*cos(theta)**29 - 1.02617613575438e+33*cos(theta)**27 + 1.08490308328249e+33*cos(theta)**25 - 8.03631913542587e+32*cos(theta)**23 + 4.28942772418301e+32*cos(theta)**21 - 1.67120560682455e+32*cos(theta)**19 + 4.76293597944996e+31*cos(theta)**17 - 9.85934997268181e+30*cos(theta)**15 + 1.45807288328393e+30*cos(theta)**13 - 1.49841482076609e+29*cos(theta)**11 + 1.02503501420566e+28*cos(theta)**9 - 4.36701307827264e+26*cos(theta)**7 + 1.03976501863634e+25*cos(theta)**5 - 1.13635521162442e+23*cos(theta)**3 + 3.61129834202675e+20*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl45_m_minus_11(theta, phi):
    return 2.45232877980087e-18*(1.0 - cos(theta)**2)**5.5*(1.19566500945407e+30*cos(theta)**34 - 7.5367198910532e+30*cos(theta)**32 + 2.14839831377149e+31*cos(theta)**30 - 3.66491477055136e+31*cos(theta)**28 + 4.17270416647112e+31*cos(theta)**26 - 3.34846630642745e+31*cos(theta)**24 + 1.94973987462864e+31*cos(theta)**22 - 8.35602803412274e+30*cos(theta)**20 + 2.64607554413887e+30*cos(theta)**18 - 6.16209373292613e+29*cos(theta)**16 + 1.04148063091709e+29*cos(theta)**14 - 1.24867901730508e+28*cos(theta)**12 + 1.02503501420566e+27*cos(theta)**10 - 5.4587663478408e+25*cos(theta)**8 + 1.73294169772724e+24*cos(theta)**6 - 2.84088802906104e+22*cos(theta)**4 + 1.80564917101338e+20*cos(theta)**2 - 1.86341503716551e+17)*sin(11*phi)

#@torch.jit.script
def Yl45_m_minus_10(theta, phi):
    return 1.08569223220532e-16*(1.0 - cos(theta)**2)**5*(3.41618574129735e+28*cos(theta)**35 - 2.28385451244036e+29*cos(theta)**33 + 6.93031714119834e+29*cos(theta)**31 - 1.26376371398323e+30*cos(theta)**29 + 1.5454459875819e+30*cos(theta)**27 - 1.33938652257098e+30*cos(theta)**25 + 8.47712988968974e+29*cos(theta)**23 - 3.97906096862988e+29*cos(theta)**21 + 1.39267133902046e+29*cos(theta)**19 - 3.62476101936831e+28*cos(theta)**17 + 6.94320420611395e+27*cos(theta)**15 - 9.60522321003906e+26*cos(theta)**13 + 9.31850012914237e+25*cos(theta)**11 - 6.06529594204533e+24*cos(theta)**9 + 2.4756309967532e+23*cos(theta)**7 - 5.68177605812209e+21*cos(theta)**5 + 6.01883057004459e+19*cos(theta)**3 - 1.86341503716551e+17*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl45_m_minus_9(theta, phi):
    return 4.83102545395957e-15*(1.0 - cos(theta)**2)**4.5*(9.48940483693708e+26*cos(theta)**36 - 6.71721915423636e+27*cos(theta)**34 + 2.16572410662448e+28*cos(theta)**32 - 4.21254571327742e+28*cos(theta)**30 + 5.51944995564964e+28*cos(theta)**28 - 5.15148662527299e+28*cos(theta)**26 + 3.53213745403739e+28*cos(theta)**24 - 1.80866407664994e+28*cos(theta)**22 + 6.96335669510228e+27*cos(theta)**20 - 2.01375612187128e+27*cos(theta)**18 + 4.33950262882122e+26*cos(theta)**16 - 6.86087372145647e+25*cos(theta)**14 + 7.76541677428531e+24*cos(theta)**12 - 6.06529594204533e+23*cos(theta)**10 + 3.0945387459415e+22*cos(theta)**8 - 9.46962676353682e+20*cos(theta)**6 + 1.50470764251115e+19*cos(theta)**4 - 9.31707518582753e+16*cos(theta)**2 + 94111870563914.5)*sin(9*phi)

#@torch.jit.script
def Yl45_m_minus_8(theta, phi):
    return 2.15941974288782e-13*(1.0 - cos(theta)**2)**4*(2.56470400998299e+25*cos(theta)**37 - 1.91920547263896e+26*cos(theta)**35 + 6.56280032310449e+26*cos(theta)**33 - 1.35888571396046e+27*cos(theta)**31 + 1.90325860539643e+27*cos(theta)**29 - 1.90795800936037e+27*cos(theta)**27 + 1.41285498161496e+27*cos(theta)**25 - 7.86375685499976e+26*cos(theta)**23 + 3.3158841405249e+26*cos(theta)**21 - 1.05987164309015e+26*cos(theta)**19 + 2.55264860518895e+25*cos(theta)**17 - 4.57391581430431e+24*cos(theta)**15 + 5.97339751868101e+23*cos(theta)**13 - 5.51390540185939e+22*cos(theta)**11 + 3.43837638437944e+21*cos(theta)**9 - 1.3528038233624e+20*cos(theta)**7 + 3.00941528502229e+18*cos(theta)**5 - 3.10569172860918e+16*cos(theta)**3 + 94111870563914.5*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl45_m_minus_7(theta, phi):
    return 9.69095999512484e-12*(1.0 - cos(theta)**2)**3.5*(6.74922107890262e+23*cos(theta)**38 - 5.331126312886e+24*cos(theta)**36 + 1.93023538914838e+25*cos(theta)**34 - 4.24651785612643e+25*cos(theta)**32 + 6.34419535132142e+25*cos(theta)**30 - 6.8141357477156e+25*cos(theta)**28 + 5.43405762159598e+25*cos(theta)**26 - 3.2765653562499e+25*cos(theta)**24 + 1.50722006387495e+25*cos(theta)**22 - 5.29935821545075e+24*cos(theta)**20 + 1.41813811399386e+24*cos(theta)**18 - 2.8586973839402e+23*cos(theta)**16 + 4.26671251334358e+22*cos(theta)**14 - 4.59492116821616e+21*cos(theta)**12 + 3.43837638437944e+20*cos(theta)**10 - 1.691004779203e+19*cos(theta)**8 + 5.01569214170382e+17*cos(theta)**6 - 7.76422932152295e+15*cos(theta)**4 + 47055935281957.2*cos(theta)**2 - 46728833447.8225)*sin(7*phi)

#@torch.jit.script
def Yl45_m_minus_6(theta, phi):
    return 4.36416112227515e-10*(1.0 - cos(theta)**2)**3*(1.73056950741093e+22*cos(theta)**39 - 1.44084494942865e+23*cos(theta)**37 + 5.51495825470966e+23*cos(theta)**35 - 1.28682359276559e+24*cos(theta)**33 + 2.04651462945852e+24*cos(theta)**31 - 2.3497019819709e+24*cos(theta)**29 + 2.01261393392444e+24*cos(theta)**27 - 1.31062614249996e+24*cos(theta)**25 + 6.5531307124998e+23*cos(theta)**23 - 2.5235039121194e+23*cos(theta)**21 + 7.46388481049401e+22*cos(theta)**19 - 1.68158669643541e+22*cos(theta)**17 + 2.84447500889572e+21*cos(theta)**15 - 3.53455474478166e+20*cos(theta)**13 + 3.12579671307222e+19*cos(theta)**11 - 1.87889419911445e+18*cos(theta)**9 + 7.16527448814832e+16*cos(theta)**7 - 1.55284586430459e+15*cos(theta)**5 + 15685311760652.4*cos(theta)**3 - 46728833447.8225*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl45_m_minus_5(theta, phi):
    return 1.97113268691894e-8*(1.0 - cos(theta)**2)**2.5*(4.32642376852732e+20*cos(theta)**40 - 3.79169723533855e+21*cos(theta)**38 + 1.53193284853046e+22*cos(theta)**36 - 3.78477527283996e+22*cos(theta)**34 + 6.39535821705788e+22*cos(theta)**32 - 7.83233993990299e+22*cos(theta)**30 + 7.187906906873e+22*cos(theta)**28 - 5.040869778846e+22*cos(theta)**26 + 2.73047113020825e+22*cos(theta)**24 - 1.14704723278155e+22*cos(theta)**22 + 3.73194240524701e+21*cos(theta)**20 - 9.34214831353005e+20*cos(theta)**18 + 1.77779688055982e+20*cos(theta)**16 - 2.52468196055833e+19*cos(theta)**14 + 2.60483059422685e+18*cos(theta)**12 - 1.87889419911445e+17*cos(theta)**10 + 8.9565931101854e+15*cos(theta)**8 - 258807644050765.0*cos(theta)**6 + 3921327940163.1*cos(theta)**4 - 23364416723.9112*cos(theta)**2 + 22906290.9057953)*sin(5*phi)

#@torch.jit.script
def Yl45_m_minus_4(theta, phi):
    return 8.92468281921133e-7*(1.0 - cos(theta)**2)**2*(1.05522530939691e+19*cos(theta)**41 - 9.72230060343218e+19*cos(theta)**39 + 4.14035905008232e+20*cos(theta)**37 - 1.08136436366856e+21*cos(theta)**35 + 1.93798733850239e+21*cos(theta)**33 - 2.52656127093645e+21*cos(theta)**31 + 2.4785885885769e+21*cos(theta)**29 - 1.86698880698e+21*cos(theta)**27 + 1.0921884520833e+21*cos(theta)**25 - 4.9871618816589e+20*cos(theta)**23 + 1.77711543107e+20*cos(theta)**21 - 4.91692016501582e+19*cos(theta)**19 + 1.04576287091754e+19*cos(theta)**17 - 1.68312130703889e+18*cos(theta)**15 + 2.00371584171296e+17*cos(theta)**13 - 1.70808563555859e+16*cos(theta)**11 + 995177012242822.0*cos(theta)**9 - 36972520578680.7*cos(theta)**7 + 784265588032.621*cos(theta)**5 - 7788138907.97041*cos(theta)**3 + 22906290.9057953*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl45_m_minus_3(theta, phi):
    return 4.0486988616791e-5*(1.0 - cos(theta)**2)**1.5*(2.51244121284978e+17*cos(theta)**42 - 2.43057515085804e+18*cos(theta)**40 + 1.0895681710743e+19*cos(theta)**38 - 3.00378989907933e+19*cos(theta)**36 + 5.69996276030114e+19*cos(theta)**34 - 7.8955039716764e+19*cos(theta)**32 + 8.26196196192298e+19*cos(theta)**30 - 6.66781716778571e+19*cos(theta)**28 + 4.200724815705e+19*cos(theta)**26 - 2.07798411735788e+19*cos(theta)**24 + 8.07779741395456e+18*cos(theta)**22 - 2.45846008250791e+18*cos(theta)**20 + 5.80979372731969e+17*cos(theta)**18 - 1.0519508168993e+17*cos(theta)**16 + 1.43122560122354e+16*cos(theta)**14 - 1.42340469629882e+15*cos(theta)**12 + 99517701224282.2*cos(theta)**10 - 4621565072335.09*cos(theta)**8 + 130710931338.77*cos(theta)**6 - 1947034726.9926*cos(theta)**4 + 11453145.4528977*cos(theta)**2 - 11130.3648716207)*sin(3*phi)

#@torch.jit.script
def Yl45_m_minus_2(theta, phi):
    return 0.00183937518041772*(1.0 - cos(theta)**2)*(5.84288654151111e+15*cos(theta)**43 - 5.92823207526352e+16*cos(theta)**41 + 2.79376454121614e+17*cos(theta)**39 - 8.11835107859279e+17*cos(theta)**37 + 1.62856078865747e+18*cos(theta)**35 - 2.39257696111406e+18*cos(theta)**33 + 2.66514901997516e+18*cos(theta)**31 - 2.29924729923645e+18*cos(theta)**29 + 1.55582400581667e+18*cos(theta)**27 - 8.3119364694315e+17*cos(theta)**25 + 3.51208583215416e+17*cos(theta)**23 - 1.17069527738472e+17*cos(theta)**21 + 3.05778617227352e+16*cos(theta)**19 - 6.18794598176061e+15*cos(theta)**17 + 954150400815695.0*cos(theta)**15 - 109492668946063.0*cos(theta)**13 + 9047063747662.02*cos(theta)**11 - 513507230259.454*cos(theta)**9 + 18672990191.2529*cos(theta)**7 - 389406945.398521*cos(theta)**5 + 3817715.15096589*cos(theta)**3 - 11130.3648716207*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl45_m_minus_1(theta, phi):
    return 0.0836460792886812*(1.0 - cos(theta)**2)**0.5*(132792875943434.0*cos(theta)**44 - 1.4114838274437e+15*cos(theta)**42 + 6.98441135304036e+15*cos(theta)**40 - 2.13640817857705e+16*cos(theta)**38 + 4.52377996849297e+16*cos(theta)**36 - 7.03699106210018e+16*cos(theta)**34 + 8.32859068742236e+16*cos(theta)**32 - 7.66415766412151e+16*cos(theta)**30 + 5.55651430648809e+16*cos(theta)**28 - 3.19689864208904e+16*cos(theta)**26 + 1.4633690967309e+16*cos(theta)**24 - 5.32134216993054e+15*cos(theta)**22 + 1.52889308613676e+15*cos(theta)**20 - 343774776764478.0*cos(theta)**18 + 59634400050981.0*cos(theta)**16 - 7820904924718.81*cos(theta)**14 + 753921978971.835*cos(theta)**12 - 51350723025.9454*cos(theta)**10 + 2334123773.90661*cos(theta)**8 - 64901157.5664201*cos(theta)**6 + 954428.787741472*cos(theta)**4 - 5565.18243581033*cos(theta)**2 + 5.38218804236976)*sin(phi)

#@torch.jit.script
def Yl45_m0(theta, phi):
    return 24947549886958.4*cos(theta)**45 - 277506453798751.0*cos(theta)**43 + 1.4401628033349e+15*cos(theta)**41 - 4.63111175974358e+15*cos(theta)**39 + 1.03363066685843e+16*cos(theta)**37 - 1.69974820772276e+16*cos(theta)**35 + 2.13365017636084e+16*cos(theta)**33 - 2.09010629521062e+16*cos(theta)**31 + 1.61983237878823e+16*cos(theta)**29 - 1.0009923071355e+16*cos(theta)**27 + 4.94856760288112e+15*cos(theta)**25 - 1.95595557426131e+15*cos(theta)**23 + 615493482945413.0*cos(theta)**21 - 152962877418387.0*cos(theta)**19 + 29656068070911.7*cos(theta)**17 - 4407896456441.52*cos(theta)**15 + 490285093142.33*cos(theta)**13 - 39465673132.2*cos(theta)**11 + 2192537396.23333*cos(theta)**9 - 78382667.5912611*cos(theta)**7 + 1613760.80334949*cos(theta)**5 - 15682.8066409086*cos(theta)**3 + 45.5013732328102*cos(theta)

#@torch.jit.script
def Yl45_m1(theta, phi):
    return 0.0836460792886812*(1.0 - cos(theta)**2)**0.5*(132792875943434.0*cos(theta)**44 - 1.4114838274437e+15*cos(theta)**42 + 6.98441135304036e+15*cos(theta)**40 - 2.13640817857705e+16*cos(theta)**38 + 4.52377996849297e+16*cos(theta)**36 - 7.03699106210018e+16*cos(theta)**34 + 8.32859068742236e+16*cos(theta)**32 - 7.66415766412151e+16*cos(theta)**30 + 5.55651430648809e+16*cos(theta)**28 - 3.19689864208904e+16*cos(theta)**26 + 1.4633690967309e+16*cos(theta)**24 - 5.32134216993054e+15*cos(theta)**22 + 1.52889308613676e+15*cos(theta)**20 - 343774776764478.0*cos(theta)**18 + 59634400050981.0*cos(theta)**16 - 7820904924718.81*cos(theta)**14 + 753921978971.835*cos(theta)**12 - 51350723025.9454*cos(theta)**10 + 2334123773.90661*cos(theta)**8 - 64901157.5664201*cos(theta)**6 + 954428.787741472*cos(theta)**4 - 5565.18243581033*cos(theta)**2 + 5.38218804236976)*cos(phi)

#@torch.jit.script
def Yl45_m2(theta, phi):
    return 0.00183937518041772*(1.0 - cos(theta)**2)*(5.84288654151111e+15*cos(theta)**43 - 5.92823207526352e+16*cos(theta)**41 + 2.79376454121614e+17*cos(theta)**39 - 8.11835107859279e+17*cos(theta)**37 + 1.62856078865747e+18*cos(theta)**35 - 2.39257696111406e+18*cos(theta)**33 + 2.66514901997516e+18*cos(theta)**31 - 2.29924729923645e+18*cos(theta)**29 + 1.55582400581667e+18*cos(theta)**27 - 8.3119364694315e+17*cos(theta)**25 + 3.51208583215416e+17*cos(theta)**23 - 1.17069527738472e+17*cos(theta)**21 + 3.05778617227352e+16*cos(theta)**19 - 6.18794598176061e+15*cos(theta)**17 + 954150400815695.0*cos(theta)**15 - 109492668946063.0*cos(theta)**13 + 9047063747662.02*cos(theta)**11 - 513507230259.454*cos(theta)**9 + 18672990191.2529*cos(theta)**7 - 389406945.398521*cos(theta)**5 + 3817715.15096589*cos(theta)**3 - 11130.3648716207*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl45_m3(theta, phi):
    return 4.0486988616791e-5*(1.0 - cos(theta)**2)**1.5*(2.51244121284978e+17*cos(theta)**42 - 2.43057515085804e+18*cos(theta)**40 + 1.0895681710743e+19*cos(theta)**38 - 3.00378989907933e+19*cos(theta)**36 + 5.69996276030114e+19*cos(theta)**34 - 7.8955039716764e+19*cos(theta)**32 + 8.26196196192298e+19*cos(theta)**30 - 6.66781716778571e+19*cos(theta)**28 + 4.200724815705e+19*cos(theta)**26 - 2.07798411735788e+19*cos(theta)**24 + 8.07779741395456e+18*cos(theta)**22 - 2.45846008250791e+18*cos(theta)**20 + 5.80979372731969e+17*cos(theta)**18 - 1.0519508168993e+17*cos(theta)**16 + 1.43122560122354e+16*cos(theta)**14 - 1.42340469629882e+15*cos(theta)**12 + 99517701224282.2*cos(theta)**10 - 4621565072335.09*cos(theta)**8 + 130710931338.77*cos(theta)**6 - 1947034726.9926*cos(theta)**4 + 11453145.4528977*cos(theta)**2 - 11130.3648716207)*cos(3*phi)

#@torch.jit.script
def Yl45_m4(theta, phi):
    return 8.92468281921133e-7*(1.0 - cos(theta)**2)**2*(1.05522530939691e+19*cos(theta)**41 - 9.72230060343218e+19*cos(theta)**39 + 4.14035905008232e+20*cos(theta)**37 - 1.08136436366856e+21*cos(theta)**35 + 1.93798733850239e+21*cos(theta)**33 - 2.52656127093645e+21*cos(theta)**31 + 2.4785885885769e+21*cos(theta)**29 - 1.86698880698e+21*cos(theta)**27 + 1.0921884520833e+21*cos(theta)**25 - 4.9871618816589e+20*cos(theta)**23 + 1.77711543107e+20*cos(theta)**21 - 4.91692016501582e+19*cos(theta)**19 + 1.04576287091754e+19*cos(theta)**17 - 1.68312130703889e+18*cos(theta)**15 + 2.00371584171296e+17*cos(theta)**13 - 1.70808563555859e+16*cos(theta)**11 + 995177012242822.0*cos(theta)**9 - 36972520578680.7*cos(theta)**7 + 784265588032.621*cos(theta)**5 - 7788138907.97041*cos(theta)**3 + 22906290.9057953*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl45_m5(theta, phi):
    return 1.97113268691894e-8*(1.0 - cos(theta)**2)**2.5*(4.32642376852732e+20*cos(theta)**40 - 3.79169723533855e+21*cos(theta)**38 + 1.53193284853046e+22*cos(theta)**36 - 3.78477527283996e+22*cos(theta)**34 + 6.39535821705788e+22*cos(theta)**32 - 7.83233993990299e+22*cos(theta)**30 + 7.187906906873e+22*cos(theta)**28 - 5.040869778846e+22*cos(theta)**26 + 2.73047113020825e+22*cos(theta)**24 - 1.14704723278155e+22*cos(theta)**22 + 3.73194240524701e+21*cos(theta)**20 - 9.34214831353005e+20*cos(theta)**18 + 1.77779688055982e+20*cos(theta)**16 - 2.52468196055833e+19*cos(theta)**14 + 2.60483059422685e+18*cos(theta)**12 - 1.87889419911445e+17*cos(theta)**10 + 8.9565931101854e+15*cos(theta)**8 - 258807644050765.0*cos(theta)**6 + 3921327940163.1*cos(theta)**4 - 23364416723.9112*cos(theta)**2 + 22906290.9057953)*cos(5*phi)

#@torch.jit.script
def Yl45_m6(theta, phi):
    return 4.36416112227515e-10*(1.0 - cos(theta)**2)**3*(1.73056950741093e+22*cos(theta)**39 - 1.44084494942865e+23*cos(theta)**37 + 5.51495825470966e+23*cos(theta)**35 - 1.28682359276559e+24*cos(theta)**33 + 2.04651462945852e+24*cos(theta)**31 - 2.3497019819709e+24*cos(theta)**29 + 2.01261393392444e+24*cos(theta)**27 - 1.31062614249996e+24*cos(theta)**25 + 6.5531307124998e+23*cos(theta)**23 - 2.5235039121194e+23*cos(theta)**21 + 7.46388481049401e+22*cos(theta)**19 - 1.68158669643541e+22*cos(theta)**17 + 2.84447500889572e+21*cos(theta)**15 - 3.53455474478166e+20*cos(theta)**13 + 3.12579671307222e+19*cos(theta)**11 - 1.87889419911445e+18*cos(theta)**9 + 7.16527448814832e+16*cos(theta)**7 - 1.55284586430459e+15*cos(theta)**5 + 15685311760652.4*cos(theta)**3 - 46728833447.8225*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl45_m7(theta, phi):
    return 9.69095999512484e-12*(1.0 - cos(theta)**2)**3.5*(6.74922107890262e+23*cos(theta)**38 - 5.331126312886e+24*cos(theta)**36 + 1.93023538914838e+25*cos(theta)**34 - 4.24651785612643e+25*cos(theta)**32 + 6.34419535132142e+25*cos(theta)**30 - 6.8141357477156e+25*cos(theta)**28 + 5.43405762159598e+25*cos(theta)**26 - 3.2765653562499e+25*cos(theta)**24 + 1.50722006387495e+25*cos(theta)**22 - 5.29935821545075e+24*cos(theta)**20 + 1.41813811399386e+24*cos(theta)**18 - 2.8586973839402e+23*cos(theta)**16 + 4.26671251334358e+22*cos(theta)**14 - 4.59492116821616e+21*cos(theta)**12 + 3.43837638437944e+20*cos(theta)**10 - 1.691004779203e+19*cos(theta)**8 + 5.01569214170382e+17*cos(theta)**6 - 7.76422932152295e+15*cos(theta)**4 + 47055935281957.2*cos(theta)**2 - 46728833447.8225)*cos(7*phi)

#@torch.jit.script
def Yl45_m8(theta, phi):
    return 2.15941974288782e-13*(1.0 - cos(theta)**2)**4*(2.56470400998299e+25*cos(theta)**37 - 1.91920547263896e+26*cos(theta)**35 + 6.56280032310449e+26*cos(theta)**33 - 1.35888571396046e+27*cos(theta)**31 + 1.90325860539643e+27*cos(theta)**29 - 1.90795800936037e+27*cos(theta)**27 + 1.41285498161496e+27*cos(theta)**25 - 7.86375685499976e+26*cos(theta)**23 + 3.3158841405249e+26*cos(theta)**21 - 1.05987164309015e+26*cos(theta)**19 + 2.55264860518895e+25*cos(theta)**17 - 4.57391581430431e+24*cos(theta)**15 + 5.97339751868101e+23*cos(theta)**13 - 5.51390540185939e+22*cos(theta)**11 + 3.43837638437944e+21*cos(theta)**9 - 1.3528038233624e+20*cos(theta)**7 + 3.00941528502229e+18*cos(theta)**5 - 3.10569172860918e+16*cos(theta)**3 + 94111870563914.5*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl45_m9(theta, phi):
    return 4.83102545395957e-15*(1.0 - cos(theta)**2)**4.5*(9.48940483693708e+26*cos(theta)**36 - 6.71721915423636e+27*cos(theta)**34 + 2.16572410662448e+28*cos(theta)**32 - 4.21254571327742e+28*cos(theta)**30 + 5.51944995564964e+28*cos(theta)**28 - 5.15148662527299e+28*cos(theta)**26 + 3.53213745403739e+28*cos(theta)**24 - 1.80866407664994e+28*cos(theta)**22 + 6.96335669510228e+27*cos(theta)**20 - 2.01375612187128e+27*cos(theta)**18 + 4.33950262882122e+26*cos(theta)**16 - 6.86087372145647e+25*cos(theta)**14 + 7.76541677428531e+24*cos(theta)**12 - 6.06529594204533e+23*cos(theta)**10 + 3.0945387459415e+22*cos(theta)**8 - 9.46962676353682e+20*cos(theta)**6 + 1.50470764251115e+19*cos(theta)**4 - 9.31707518582753e+16*cos(theta)**2 + 94111870563914.5)*cos(9*phi)

#@torch.jit.script
def Yl45_m10(theta, phi):
    return 1.08569223220532e-16*(1.0 - cos(theta)**2)**5*(3.41618574129735e+28*cos(theta)**35 - 2.28385451244036e+29*cos(theta)**33 + 6.93031714119834e+29*cos(theta)**31 - 1.26376371398323e+30*cos(theta)**29 + 1.5454459875819e+30*cos(theta)**27 - 1.33938652257098e+30*cos(theta)**25 + 8.47712988968974e+29*cos(theta)**23 - 3.97906096862988e+29*cos(theta)**21 + 1.39267133902046e+29*cos(theta)**19 - 3.62476101936831e+28*cos(theta)**17 + 6.94320420611395e+27*cos(theta)**15 - 9.60522321003906e+26*cos(theta)**13 + 9.31850012914237e+25*cos(theta)**11 - 6.06529594204533e+24*cos(theta)**9 + 2.4756309967532e+23*cos(theta)**7 - 5.68177605812209e+21*cos(theta)**5 + 6.01883057004459e+19*cos(theta)**3 - 1.86341503716551e+17*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl45_m11(theta, phi):
    return 2.45232877980087e-18*(1.0 - cos(theta)**2)**5.5*(1.19566500945407e+30*cos(theta)**34 - 7.5367198910532e+30*cos(theta)**32 + 2.14839831377149e+31*cos(theta)**30 - 3.66491477055136e+31*cos(theta)**28 + 4.17270416647112e+31*cos(theta)**26 - 3.34846630642745e+31*cos(theta)**24 + 1.94973987462864e+31*cos(theta)**22 - 8.35602803412274e+30*cos(theta)**20 + 2.64607554413887e+30*cos(theta)**18 - 6.16209373292613e+29*cos(theta)**16 + 1.04148063091709e+29*cos(theta)**14 - 1.24867901730508e+28*cos(theta)**12 + 1.02503501420566e+27*cos(theta)**10 - 5.4587663478408e+25*cos(theta)**8 + 1.73294169772724e+24*cos(theta)**6 - 2.84088802906104e+22*cos(theta)**4 + 1.80564917101338e+20*cos(theta)**2 - 1.86341503716551e+17)*cos(11*phi)

#@torch.jit.script
def Yl45_m12(theta, phi):
    return 5.57059786735605e-20*(1.0 - cos(theta)**2)**6*(4.06526103214385e+31*cos(theta)**33 - 2.41175036513702e+32*cos(theta)**31 + 6.44519494131446e+32*cos(theta)**29 - 1.02617613575438e+33*cos(theta)**27 + 1.08490308328249e+33*cos(theta)**25 - 8.03631913542587e+32*cos(theta)**23 + 4.28942772418301e+32*cos(theta)**21 - 1.67120560682455e+32*cos(theta)**19 + 4.76293597944996e+31*cos(theta)**17 - 9.85934997268181e+30*cos(theta)**15 + 1.45807288328393e+30*cos(theta)**13 - 1.49841482076609e+29*cos(theta)**11 + 1.02503501420566e+28*cos(theta)**9 - 4.36701307827264e+26*cos(theta)**7 + 1.03976501863634e+25*cos(theta)**5 - 1.13635521162442e+23*cos(theta)**3 + 3.61129834202675e+20*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl45_m13(theta, phi):
    return 1.27330030128458e-21*(1.0 - cos(theta)**2)**6.5*(1.34153614060747e+33*cos(theta)**32 - 7.47642613192477e+33*cos(theta)**30 + 1.86910653298119e+34*cos(theta)**28 - 2.77067556653683e+34*cos(theta)**26 + 2.71225770820623e+34*cos(theta)**24 - 1.84835340114795e+34*cos(theta)**22 + 9.00779822078431e+33*cos(theta)**20 - 3.17529065296664e+33*cos(theta)**18 + 8.09699116506493e+32*cos(theta)**16 - 1.47890249590227e+32*cos(theta)**14 + 1.89549474826911e+31*cos(theta)**12 - 1.6482563028427e+30*cos(theta)**10 + 9.22531512785095e+28*cos(theta)**8 - 3.05690915479085e+27*cos(theta)**6 + 5.19882509318171e+25*cos(theta)**4 - 3.40906563487325e+23*cos(theta)**2 + 3.61129834202675e+20)*cos(13*phi)

#@torch.jit.script
def Yl45_m14(theta, phi):
    return 2.93041984581218e-23*(1.0 - cos(theta)**2)**7*(4.2929156499439e+34*cos(theta)**31 - 2.24292783957743e+35*cos(theta)**29 + 5.23349829234734e+35*cos(theta)**27 - 7.20375647299575e+35*cos(theta)**25 + 6.50941849969495e+35*cos(theta)**23 - 4.06637748252549e+35*cos(theta)**21 + 1.80155964415686e+35*cos(theta)**19 - 5.71552317533995e+34*cos(theta)**17 + 1.29551858641039e+34*cos(theta)**15 - 2.07046349426318e+33*cos(theta)**13 + 2.27459369792293e+32*cos(theta)**11 - 1.6482563028427e+31*cos(theta)**9 + 7.38025210228076e+29*cos(theta)**7 - 1.83414549287451e+28*cos(theta)**5 + 2.07953003727268e+26*cos(theta)**3 - 6.81813126974651e+23*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl45_m15(theta, phi):
    return 6.79474831705311e-25*(1.0 - cos(theta)**2)**7.5*(1.33080385148261e+36*cos(theta)**30 - 6.50449073477455e+36*cos(theta)**28 + 1.41304453893378e+37*cos(theta)**26 - 1.80093911824894e+37*cos(theta)**24 + 1.49716625492984e+37*cos(theta)**22 - 8.53939271330353e+36*cos(theta)**20 + 3.42296332389804e+36*cos(theta)**18 - 9.71638939807792e+35*cos(theta)**16 + 1.94327787961558e+35*cos(theta)**14 - 2.69160254254213e+34*cos(theta)**12 + 2.50205306771522e+33*cos(theta)**10 - 1.48343067255843e+32*cos(theta)**8 + 5.16617647159653e+30*cos(theta)**6 - 9.17072746437254e+28*cos(theta)**4 + 6.23859011181806e+26*cos(theta)**2 - 6.81813126974651e+23)*cos(15*phi)

#@torch.jit.script
def Yl45_m16(theta, phi):
    return 1.5883559340836e-26*(1.0 - cos(theta)**2)**8*(3.99241155444783e+37*cos(theta)**29 - 1.82125740573687e+38*cos(theta)**27 + 3.67391580122783e+38*cos(theta)**25 - 4.32225388379745e+38*cos(theta)**23 + 3.29376576084565e+38*cos(theta)**21 - 1.70787854266071e+38*cos(theta)**19 + 6.16133398301647e+37*cos(theta)**17 - 1.55462230369247e+37*cos(theta)**15 + 2.72058903146182e+36*cos(theta)**13 - 3.22992305105056e+35*cos(theta)**11 + 2.50205306771522e+34*cos(theta)**9 - 1.18674453804675e+33*cos(theta)**7 + 3.09970588295792e+31*cos(theta)**5 - 3.66829098574902e+29*cos(theta)**3 + 1.24771802236361e+27*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl45_m17(theta, phi):
    return 3.74587245840413e-28*(1.0 - cos(theta)**2)**8.5*(1.15779935078987e+39*cos(theta)**28 - 4.91739499548956e+39*cos(theta)**26 + 9.18478950306958e+39*cos(theta)**24 - 9.94118393273413e+39*cos(theta)**22 + 6.91690809777586e+39*cos(theta)**20 - 3.24496923105534e+39*cos(theta)**18 + 1.0474267771128e+39*cos(theta)**16 - 2.3319334555387e+38*cos(theta)**14 + 3.53676574090036e+37*cos(theta)**12 - 3.55291535615562e+36*cos(theta)**10 + 2.2518477609437e+35*cos(theta)**8 - 8.30721176632722e+33*cos(theta)**6 + 1.54985294147896e+32*cos(theta)**4 - 1.1004872957247e+30*cos(theta)**2 + 1.24771802236361e+27)*cos(17*phi)

#@torch.jit.script
def Yl45_m18(theta, phi):
    return 8.91874394858126e-30*(1.0 - cos(theta)**2)**9*(3.24183818221164e+40*cos(theta)**27 - 1.27852269882729e+41*cos(theta)**25 + 2.2043494807367e+41*cos(theta)**23 - 2.18706046520151e+41*cos(theta)**21 + 1.38338161955517e+41*cos(theta)**19 - 5.84094461589961e+40*cos(theta)**17 + 1.67588284338048e+40*cos(theta)**15 - 3.26470683775418e+39*cos(theta)**13 + 4.24411888908044e+38*cos(theta)**11 - 3.55291535615562e+37*cos(theta)**9 + 1.80147820875496e+36*cos(theta)**7 - 4.98432705979633e+34*cos(theta)**5 + 6.19941176591584e+32*cos(theta)**3 - 2.20097459144941e+30*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl45_m19(theta, phi):
    return 2.14551634147781e-31*(1.0 - cos(theta)**2)**9.5*(8.75296309197142e+41*cos(theta)**26 - 3.19630674706821e+42*cos(theta)**24 + 5.07000380569441e+42*cos(theta)**22 - 4.59282697692317e+42*cos(theta)**20 + 2.62842507715483e+42*cos(theta)**18 - 9.92960584702934e+41*cos(theta)**16 + 2.51382426507072e+41*cos(theta)**14 - 4.24411888908044e+40*cos(theta)**12 + 4.66853077798848e+39*cos(theta)**10 - 3.19762382054005e+38*cos(theta)**8 + 1.26103474612847e+37*cos(theta)**6 - 2.49216352989817e+35*cos(theta)**4 + 1.85982352977475e+33*cos(theta)**2 - 2.20097459144941e+30)*cos(19*phi)

#@torch.jit.script
def Yl45_m20(theta, phi):
    return 5.21901415090882e-33*(1.0 - cos(theta)**2)**10*(2.27577040391257e+43*cos(theta)**25 - 7.67113619296371e+43*cos(theta)**23 + 1.11540083725277e+44*cos(theta)**21 - 9.18565395384634e+43*cos(theta)**19 + 4.73116513887869e+43*cos(theta)**17 - 1.5887369355247e+43*cos(theta)**15 + 3.51935397109901e+42*cos(theta)**13 - 5.09294266689652e+41*cos(theta)**11 + 4.66853077798848e+40*cos(theta)**9 - 2.55809905643204e+39*cos(theta)**7 + 7.56620847677083e+37*cos(theta)**5 - 9.96865411959267e+35*cos(theta)**3 + 3.7196470595495e+33*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl45_m21(theta, phi):
    return 1.28483246655521e-34*(1.0 - cos(theta)**2)**10.5*(5.68942600978142e+44*cos(theta)**24 - 1.76436132438165e+45*cos(theta)**22 + 2.34234175823082e+45*cos(theta)**20 - 1.7452742512308e+45*cos(theta)**18 + 8.04298073609377e+44*cos(theta)**16 - 2.38310540328704e+44*cos(theta)**14 + 4.57516016242871e+43*cos(theta)**12 - 5.60223693358618e+42*cos(theta)**10 + 4.20167770018963e+41*cos(theta)**8 - 1.79066933950243e+40*cos(theta)**6 + 3.78310423838542e+38*cos(theta)**4 - 2.9905962358778e+36*cos(theta)**2 + 3.7196470595495e+33)*cos(21*phi)

#@torch.jit.script
def Yl45_m22(theta, phi):
    return 3.20408095180754e-36*(1.0 - cos(theta)**2)**11*(1.36546224234754e+46*cos(theta)**23 - 3.88159491363964e+46*cos(theta)**21 + 4.68468351646163e+46*cos(theta)**19 - 3.14149365221545e+46*cos(theta)**17 + 1.286876917775e+46*cos(theta)**15 - 3.33634756460186e+45*cos(theta)**13 + 5.49019219491445e+44*cos(theta)**11 - 5.60223693358618e+43*cos(theta)**9 + 3.36134216015171e+42*cos(theta)**7 - 1.07440160370146e+41*cos(theta)**5 + 1.51324169535417e+39*cos(theta)**3 - 5.9811924717556e+36*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl45_m23(theta, phi):
    return 8.10186692897904e-38*(1.0 - cos(theta)**2)**11.5*(3.14056315739934e+47*cos(theta)**22 - 8.15134931864324e+47*cos(theta)**20 + 8.9008986812771e+47*cos(theta)**18 - 5.34053920876626e+47*cos(theta)**16 + 1.9303153766625e+47*cos(theta)**14 - 4.33725183398242e+46*cos(theta)**12 + 6.0392114144059e+45*cos(theta)**10 - 5.04201324022756e+44*cos(theta)**8 + 2.35293951210619e+43*cos(theta)**6 - 5.37200801850729e+41*cos(theta)**4 + 4.5397250860625e+39*cos(theta)**2 - 5.9811924717556e+36)*cos(23*phi)

#@torch.jit.script
def Yl45_m24(theta, phi):
    return 2.07945353200254e-39*(1.0 - cos(theta)**2)**12*(6.90923894627856e+48*cos(theta)**21 - 1.63026986372865e+49*cos(theta)**19 + 1.60216176262988e+49*cos(theta)**17 - 8.54486273402602e+48*cos(theta)**15 + 2.70244152732751e+48*cos(theta)**13 - 5.2047022007789e+47*cos(theta)**11 + 6.0392114144059e+46*cos(theta)**9 - 4.03361059218205e+45*cos(theta)**7 + 1.41176370726372e+44*cos(theta)**5 - 2.14880320740292e+42*cos(theta)**3 + 9.079450172125e+39*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl45_m25(theta, phi):
    return 5.42363622267421e-41*(1.0 - cos(theta)**2)**12.5*(1.4509401787185e+50*cos(theta)**20 - 3.09751274108443e+50*cos(theta)**18 + 2.72367499647079e+50*cos(theta)**16 - 1.2817294101039e+50*cos(theta)**14 + 3.51317398552576e+49*cos(theta)**12 - 5.72517242085679e+48*cos(theta)**10 + 5.43529027296531e+47*cos(theta)**8 - 2.82352741452743e+46*cos(theta)**6 + 7.05881853631858e+44*cos(theta)**4 - 6.44640962220875e+42*cos(theta)**2 + 9.079450172125e+39)*cos(25*phi)

#@torch.jit.script
def Yl45_m26(theta, phi):
    return 1.43928361180293e-42*(1.0 - cos(theta)**2)**13*(2.90188035743699e+51*cos(theta)**19 - 5.57552293395198e+51*cos(theta)**17 + 4.35787999435327e+51*cos(theta)**15 - 1.79442117414546e+51*cos(theta)**13 + 4.21580878263091e+50*cos(theta)**11 - 5.72517242085679e+49*cos(theta)**9 + 4.34823221837225e+48*cos(theta)**7 - 1.69411644871646e+47*cos(theta)**5 + 2.82352741452743e+45*cos(theta)**3 - 1.28928192444175e+43*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl45_m27(theta, phi):
    return 3.89137721528147e-44*(1.0 - cos(theta)**2)**13.5*(5.51357267913029e+52*cos(theta)**18 - 9.47838898771836e+52*cos(theta)**16 + 6.5368199915299e+52*cos(theta)**14 - 2.3327475263891e+52*cos(theta)**12 + 4.637389660894e+51*cos(theta)**10 - 5.15265517877111e+50*cos(theta)**8 + 3.04376255286057e+49*cos(theta)**6 - 8.4705822435823e+47*cos(theta)**4 + 8.4705822435823e+45*cos(theta)**2 - 1.28928192444175e+43)*cos(27*phi)

#@torch.jit.script
def Yl45_m28(theta, phi):
    return 1.07350889938001e-45*(1.0 - cos(theta)**2)**14*(9.92443082243452e+53*cos(theta)**17 - 1.51654223803494e+54*cos(theta)**15 + 9.15154798814187e+53*cos(theta)**13 - 2.79929703166692e+53*cos(theta)**11 + 4.637389660894e+52*cos(theta)**9 - 4.12212414301689e+51*cos(theta)**7 + 1.82625753171634e+50*cos(theta)**5 - 3.38823289743292e+48*cos(theta)**3 + 1.69411644871646e+46*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl45_m29(theta, phi):
    return 3.02667178711212e-47*(1.0 - cos(theta)**2)**14.5*(1.68715323981387e+55*cos(theta)**16 - 2.27481335705241e+55*cos(theta)**14 + 1.18970123845844e+55*cos(theta)**12 - 3.07922673483362e+54*cos(theta)**10 + 4.1736506948046e+53*cos(theta)**8 - 2.88548690011182e+52*cos(theta)**6 + 9.13128765858172e+50*cos(theta)**4 - 1.01646986922988e+49*cos(theta)**2 + 1.69411644871646e+46)*cos(29*phi)

#@torch.jit.script
def Yl45_m30(theta, phi):
    return 8.73724885518915e-49*(1.0 - cos(theta)**2)**15*(2.69944518370219e+56*cos(theta)**15 - 3.18473869987337e+56*cos(theta)**13 + 1.42764148615013e+56*cos(theta)**11 - 3.07922673483362e+55*cos(theta)**9 + 3.33892055584368e+54*cos(theta)**7 - 1.73129214006709e+53*cos(theta)**5 + 3.65251506343269e+51*cos(theta)**3 - 2.03293973845975e+49*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl45_m31(theta, phi):
    return 2.5877497770366e-50*(1.0 - cos(theta)**2)**15.5*(4.04916777555328e+57*cos(theta)**14 - 4.14016030983538e+57*cos(theta)**12 + 1.57040563476514e+57*cos(theta)**10 - 2.77130406135025e+56*cos(theta)**8 + 2.33724438909058e+55*cos(theta)**6 - 8.65646070033547e+53*cos(theta)**4 + 1.09575451902981e+52*cos(theta)**2 - 2.03293973845975e+49)*cos(31*phi)

#@torch.jit.script
def Yl45_m32(theta, phi):
    return 7.88157294590393e-52*(1.0 - cos(theta)**2)**16*(5.6688348857746e+58*cos(theta)**13 - 4.96819237180246e+58*cos(theta)**11 + 1.57040563476514e+58*cos(theta)**9 - 2.2170432490802e+57*cos(theta)**7 + 1.40234663345435e+56*cos(theta)**5 - 3.46258428013419e+54*cos(theta)**3 + 2.19150903805961e+52*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl45_m33(theta, phi):
    return 2.47510667794732e-53*(1.0 - cos(theta)**2)**16.5*(7.36948535150698e+59*cos(theta)**12 - 5.4650116089827e+59*cos(theta)**10 + 1.41336507128863e+59*cos(theta)**8 - 1.55193027435614e+58*cos(theta)**6 + 7.01173316727173e+56*cos(theta)**4 - 1.03877528404026e+55*cos(theta)**2 + 2.19150903805961e+52)*cos(33*phi)

#@torch.jit.script
def Yl45_m34(theta, phi):
    return 8.03877277932851e-55*(1.0 - cos(theta)**2)**17*(8.84338242180837e+60*cos(theta)**11 - 5.4650116089827e+60*cos(theta)**9 + 1.1306920570309e+60*cos(theta)**7 - 9.31158164613686e+58*cos(theta)**5 + 2.80469326690869e+57*cos(theta)**3 - 2.07755056808051e+55*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl45_m35(theta, phi):
    return 2.70986975109827e-56*(1.0 - cos(theta)**2)**17.5*(9.72772066398921e+61*cos(theta)**10 - 4.91851044808443e+61*cos(theta)**8 + 7.91484439921633e+60*cos(theta)**6 - 4.65579082306843e+59*cos(theta)**4 + 8.41407980072608e+57*cos(theta)**2 - 2.07755056808051e+55)*cos(35*phi)

#@torch.jit.script
def Yl45_m36(theta, phi):
    return 9.52151175096011e-58*(1.0 - cos(theta)**2)**18*(9.72772066398921e+62*cos(theta)**9 - 3.93480835846755e+62*cos(theta)**7 + 4.7489066395298e+61*cos(theta)**5 - 1.86231632922737e+60*cos(theta)**3 + 1.68281596014522e+58*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl45_m37(theta, phi):
    return 3.50491691066036e-59*(1.0 - cos(theta)**2)**18.5*(8.75494859759029e+63*cos(theta)**8 - 2.75436585092728e+63*cos(theta)**6 + 2.3744533197649e+62*cos(theta)**4 - 5.58694898768211e+60*cos(theta)**2 + 1.68281596014522e+58)*cos(37*phi)

#@torch.jit.script
def Yl45_m38(theta, phi):
    return 1.36017155138303e-60*(1.0 - cos(theta)**2)**19*(7.00395887807223e+64*cos(theta)**7 - 1.65261951055637e+64*cos(theta)**5 + 9.49781327905959e+62*cos(theta)**3 - 1.11738979753642e+61*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl45_m39(theta, phi):
    return 5.60925293810759e-62*(1.0 - cos(theta)**2)**19.5*(4.90277121465056e+65*cos(theta)**6 - 8.26309755278185e+64*cos(theta)**4 + 2.84934398371788e+63*cos(theta)**2 - 1.11738979753642e+61)*cos(39*phi)

#@torch.jit.script
def Yl45_m40(theta, phi):
    return 2.4838189493738e-63*(1.0 - cos(theta)**2)**20*(2.94166272879034e+66*cos(theta)**5 - 3.30523902111274e+65*cos(theta)**3 + 5.69868796743576e+63*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl45_m41(theta, phi):
    return 1.19780385990637e-64*(1.0 - cos(theta)**2)**20.5*(1.47083136439517e+67*cos(theta)**4 - 9.91571706333822e+65*cos(theta)**2 + 5.69868796743576e+63)*cos(41*phi)

#@torch.jit.script
def Yl45_m42(theta, phi):
    return 6.42090266241355e-66*(1.0 - cos(theta)**2)**21*(5.88332545758067e+67*cos(theta)**3 - 1.98314341266764e+66*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl45_m43(theta, phi):
    return 3.95179241074826e-67*(1.0 - cos(theta)**2)**21.5*(1.7649976372742e+68*cos(theta)**2 - 1.98314341266764e+66)*cos(43*phi)

#@torch.jit.script
def Yl45_m44(theta, phi):
    return 10.4558235531102*(1.0 - cos(theta)**2)**22*cos(44*phi)*cos(theta)

#@torch.jit.script
def Yl45_m45(theta, phi):
    return 1.10214057468876*(1.0 - cos(theta)**2)**22.5*cos(45*phi)

#@torch.jit.script
def Yl46_m_minus_46(theta, phi):
    return 1.1081142800943*(1.0 - cos(theta)**2)**23*sin(46*phi)

#@torch.jit.script
def Yl46_m_minus_45(theta, phi):
    return 10.6286587918185*(1.0 - cos(theta)**2)**22.5*sin(45*phi)*cos(theta)

#@torch.jit.script
def Yl46_m_minus_44(theta, phi):
    return 4.46373745781704e-69*(1.0 - cos(theta)**2)**22*(1.60614784991952e+70*cos(theta)**2 - 1.7649976372742e+68)*sin(44*phi)

#@torch.jit.script
def Yl46_m_minus_43(theta, phi):
    return 7.33466908928147e-68*(1.0 - cos(theta)**2)**21.5*(5.35382616639841e+69*cos(theta)**3 - 1.7649976372742e+68*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl46_m_minus_42(theta, phi):
    return 1.3839025959632e-66*(1.0 - cos(theta)**2)**21*(1.3384565415996e+69*cos(theta)**4 - 8.82498818637101e+67*cos(theta)**2 + 4.95785853166911e+65)*sin(42*phi)

#@torch.jit.script
def Yl46_m_minus_41(theta, phi):
    return 2.9028985753037e-65*(1.0 - cos(theta)**2)**20.5*(2.67691308319921e+68*cos(theta)**5 - 2.94166272879034e+67*cos(theta)**3 + 4.95785853166911e+65*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl46_m_minus_40(theta, phi):
    return 6.63234506965458e-64*(1.0 - cos(theta)**2)**20*(4.46152180533201e+67*cos(theta)**6 - 7.35415682197584e+66*cos(theta)**4 + 2.47892926583455e+65*cos(theta)**2 - 9.49781327905959e+62)*sin(40*phi)

#@torch.jit.script
def Yl46_m_minus_39(theta, phi):
    return 1.62729151279139e-62*(1.0 - cos(theta)**2)**19.5*(6.37360257904573e+66*cos(theta)**7 - 1.47083136439517e+66*cos(theta)**5 + 8.26309755278185e+64*cos(theta)**3 - 9.49781327905959e+62*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl46_m_minus_38(theta, phi):
    return 4.24345709766218e-61*(1.0 - cos(theta)**2)**19*(7.96700322380716e+65*cos(theta)**8 - 2.45138560732528e+65*cos(theta)**6 + 2.06577438819546e+64*cos(theta)**4 - 4.7489066395298e+62*cos(theta)**2 + 1.39673724692053e+60)*sin(38*phi)

#@torch.jit.script
def Yl46_m_minus_37(theta, phi):
    return 1.16675780150007e-59*(1.0 - cos(theta)**2)**18.5*(8.85222580423018e+64*cos(theta)**9 - 3.50197943903612e+64*cos(theta)**7 + 4.13154877639092e+63*cos(theta)**5 - 1.58296887984327e+62*cos(theta)**3 + 1.39673724692053e+60*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl46_m_minus_36(theta, phi):
    return 3.36139662478243e-58*(1.0 - cos(theta)**2)**18*(8.85222580423018e+63*cos(theta)**10 - 4.37747429879514e+63*cos(theta)**8 + 6.88591462731821e+62*cos(theta)**6 - 3.95742219960816e+61*cos(theta)**4 + 6.98368623460264e+59*cos(theta)**2 - 1.68281596014521e+57)*sin(36*phi)

#@torch.jit.script
def Yl46_m_minus_35(theta, phi):
    return 1.00953883118615e-56*(1.0 - cos(theta)**2)**17.5*(8.04747800384562e+62*cos(theta)**11 - 4.8638603319946e+62*cos(theta)**9 + 9.83702089616886e+61*cos(theta)**7 - 7.91484439921633e+60*cos(theta)**5 + 2.32789541153421e+59*cos(theta)**3 - 1.68281596014521e+57*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl46_m_minus_34(theta, phi):
    return 3.14743058609061e-55*(1.0 - cos(theta)**2)**17*(6.70623166987135e+61*cos(theta)**12 - 4.86386033199461e+61*cos(theta)**10 + 1.22962761202111e+61*cos(theta)**8 - 1.31914073320272e+60*cos(theta)**6 + 5.81973852883553e+58*cos(theta)**4 - 8.41407980072607e+56*cos(theta)**2 + 1.73129214006709e+54)*sin(34*phi)

#@torch.jit.script
def Yl46_m_minus_33(theta, phi):
    return 1.01501586519763e-53*(1.0 - cos(theta)**2)**16.5*(5.15863974605488e+60*cos(theta)**13 - 4.42169121090419e+60*cos(theta)**11 + 1.36625290224568e+60*cos(theta)**9 - 1.88448676171817e+59*cos(theta)**7 + 1.16394770576711e+58*cos(theta)**5 - 2.80469326690869e+56*cos(theta)**3 + 1.73129214006709e+54*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl46_m_minus_32(theta, phi):
    return 3.37559545932685e-52*(1.0 - cos(theta)**2)**16*(3.68474267575349e+59*cos(theta)**14 - 3.68474267575349e+59*cos(theta)**12 + 1.36625290224568e+59*cos(theta)**10 - 2.35560845214772e+58*cos(theta)**8 + 1.93991284294518e+57*cos(theta)**6 - 7.01173316727173e+55*cos(theta)**4 + 8.65646070033547e+53*cos(theta)**2 - 1.56536359861401e+51)*sin(32*phi)

#@torch.jit.script
def Yl46_m_minus_31(theta, phi):
    return 1.15463129634021e-50*(1.0 - cos(theta)**2)**15.5*(2.45649511716899e+58*cos(theta)**15 - 2.8344174428873e+58*cos(theta)**13 + 1.24204809295061e+58*cos(theta)**11 - 2.61734272460857e+57*cos(theta)**9 + 2.77130406135025e+56*cos(theta)**7 - 1.40234663345435e+55*cos(theta)**5 + 2.88548690011182e+53*cos(theta)**3 - 1.56536359861401e+51*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl46_m_minus_30(theta, phi):
    return 4.05273940238151e-49*(1.0 - cos(theta)**2)**15*(1.53530944823062e+57*cos(theta)**16 - 2.02458388777664e+57*cos(theta)**14 + 1.03504007745885e+57*cos(theta)**12 - 2.61734272460857e+56*cos(theta)**10 + 3.46413007668782e+55*cos(theta)**8 - 2.33724438909058e+54*cos(theta)**6 + 7.21371725027956e+52*cos(theta)**4 - 7.82681799307004e+50*cos(theta)**2 + 1.27058733653734e+48)*sin(30*phi)

#@torch.jit.script
def Yl46_m_minus_29(theta, phi):
    return 1.45673292299555e-47*(1.0 - cos(theta)**2)**14.5*(9.03123204841541e+55*cos(theta)**17 - 1.34972259185109e+56*cos(theta)**15 + 7.96184674968342e+55*cos(theta)**13 - 2.37940247691689e+55*cos(theta)**11 + 3.84903341854202e+54*cos(theta)**9 - 3.33892055584368e+53*cos(theta)**7 + 1.44274345005591e+52*cos(theta)**5 - 2.60893933102335e+50*cos(theta)**3 + 1.27058733653734e+48*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl46_m_minus_28(theta, phi):
    return 5.35237852927822e-46*(1.0 - cos(theta)**2)**14*(5.01735113800856e+54*cos(theta)**18 - 8.43576619906934e+54*cos(theta)**16 + 5.68703339263102e+54*cos(theta)**14 - 1.98283539743074e+54*cos(theta)**12 + 3.84903341854202e+53*cos(theta)**10 - 4.1736506948046e+52*cos(theta)**8 + 2.40457241675985e+51*cos(theta)**6 - 6.52234832755837e+49*cos(theta)**4 + 6.35293668268672e+47*cos(theta)**2 - 9.41175804842478e+44)*sin(28*phi)

#@torch.jit.script
def Yl46_m_minus_27(theta, phi):
    return 2.00696352793153e-44*(1.0 - cos(theta)**2)**13.5*(2.64071112526766e+53*cos(theta)**19 - 4.96221541121726e+53*cos(theta)**17 + 3.79135559508734e+53*cos(theta)**15 - 1.52525799802364e+53*cos(theta)**13 + 3.49912128958366e+52*cos(theta)**11 - 4.637389660894e+51*cos(theta)**9 + 3.43510345251407e+50*cos(theta)**7 - 1.30446966551167e+49*cos(theta)**5 + 2.11764556089557e+47*cos(theta)**3 - 9.41175804842478e+44*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl46_m_minus_26(theta, phi):
    return 7.66859687268355e-43*(1.0 - cos(theta)**2)**13*(1.32035556263383e+52*cos(theta)**20 - 2.75678633956514e+52*cos(theta)**18 + 2.36959724692959e+52*cos(theta)**16 - 1.08946999858832e+52*cos(theta)**14 + 2.91593440798638e+51*cos(theta)**12 - 4.637389660894e+50*cos(theta)**10 + 4.29387931564259e+49*cos(theta)**8 - 2.17411610918612e+48*cos(theta)**6 + 5.29411390223894e+46*cos(theta)**4 - 4.70587902421239e+44*cos(theta)**2 + 6.44640962220875e+41)*sin(26*phi)

#@torch.jit.script
def Yl46_m_minus_25(theta, phi):
    return 2.98189127114901e-41*(1.0 - cos(theta)**2)**12.5*(6.28740744111349e+50*cos(theta)**21 - 1.4509401787185e+51*cos(theta)**19 + 1.39388073348799e+51*cos(theta)**17 - 7.26313332392212e+50*cos(theta)**15 + 2.24302646768183e+50*cos(theta)**13 - 4.21580878263091e+49*cos(theta)**11 + 4.77097701738066e+48*cos(theta)**9 - 3.10588015598018e+47*cos(theta)**7 + 1.05882278044779e+46*cos(theta)**5 - 1.56862634140413e+44*cos(theta)**3 + 6.44640962220875e+41*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl46_m_minus_24(theta, phi):
    return 1.17850741252294e-39*(1.0 - cos(theta)**2)**12*(2.8579124732334e+49*cos(theta)**22 - 7.25470089359249e+49*cos(theta)**20 + 7.74378185271108e+49*cos(theta)**18 - 4.53945832745132e+49*cos(theta)**16 + 1.60216176262988e+49*cos(theta)**14 - 3.51317398552576e+48*cos(theta)**12 + 4.77097701738066e+47*cos(theta)**10 - 3.88235019497522e+46*cos(theta)**8 + 1.76470463407965e+45*cos(theta)**6 - 3.92156585351032e+43*cos(theta)**4 + 3.22320481110438e+41*cos(theta)**2 - 4.12702280551136e+38)*sin(24*phi)

#@torch.jit.script
def Yl46_m_minus_23(theta, phi):
    return 4.72873804667603e-38*(1.0 - cos(theta)**2)**11.5*(1.24257064053626e+48*cos(theta)**23 - 3.45461947313928e+48*cos(theta)**21 + 4.07567465932162e+48*cos(theta)**19 - 2.67026960438313e+48*cos(theta)**17 + 1.06810784175325e+48*cos(theta)**15 - 2.70244152732751e+47*cos(theta)**13 + 4.33725183398242e+46*cos(theta)**11 - 4.31372243886136e+45*cos(theta)**9 + 2.52100662011378e+44*cos(theta)**7 - 7.84313170702065e+42*cos(theta)**5 + 1.07440160370146e+41*cos(theta)**3 - 4.12702280551136e+38*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl46_m_minus_22(theta, phi):
    return 1.92431171017896e-36*(1.0 - cos(theta)**2)**11*(5.17737766890109e+46*cos(theta)**24 - 1.57028157869967e+47*cos(theta)**22 + 2.03783732966081e+47*cos(theta)**20 - 1.48348311354618e+47*cos(theta)**18 + 6.67567401095783e+46*cos(theta)**16 - 1.9303153766625e+46*cos(theta)**14 + 3.61437652831868e+45*cos(theta)**12 - 4.31372243886136e+44*cos(theta)**10 + 3.15125827514222e+43*cos(theta)**8 - 1.30718861783677e+42*cos(theta)**6 + 2.68600400925365e+40*cos(theta)**4 - 2.06351140275568e+38*cos(theta)**2 + 2.49216352989817e+35)*sin(22*phi)

#@torch.jit.script
def Yl46_m_minus_21(theta, phi):
    return 7.93414043768083e-35*(1.0 - cos(theta)**2)**10.5*(2.07095106756044e+45*cos(theta)**25 - 6.82731121173771e+45*cos(theta)**23 + 9.7039872840991e+45*cos(theta)**21 - 7.80780586076939e+45*cos(theta)**19 + 3.92686706526931e+45*cos(theta)**17 - 1.286876917775e+45*cos(theta)**15 + 2.78028963716822e+44*cos(theta)**13 - 3.92156585351032e+43*cos(theta)**11 + 3.50139808349136e+42*cos(theta)**9 - 1.86741231119539e+41*cos(theta)**7 + 5.37200801850729e+39*cos(theta)**5 - 6.87837134251894e+37*cos(theta)**3 + 2.49216352989817e+35*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl46_m_minus_20(theta, phi):
    return 3.31149389509621e-33*(1.0 - cos(theta)**2)**10*(7.96519641369399e+43*cos(theta)**26 - 2.84471300489071e+44*cos(theta)**24 + 4.41090331095414e+44*cos(theta)**22 - 3.90390293038469e+44*cos(theta)**20 + 2.18159281403851e+44*cos(theta)**18 - 8.04298073609377e+43*cos(theta)**16 + 1.98592116940587e+43*cos(theta)**14 - 3.26797154459194e+42*cos(theta)**12 + 3.50139808349136e+41*cos(theta)**10 - 2.33426538899424e+40*cos(theta)**8 + 8.95334669751215e+38*cos(theta)**6 - 1.71959283562973e+37*cos(theta)**4 + 1.24608176494908e+35*cos(theta)**2 - 1.43063348444212e+32)*sin(20*phi)

#@torch.jit.script
def Yl46_m_minus_19(theta, phi):
    return 1.39790548387065e-31*(1.0 - cos(theta)**2)**9.5*(2.95007274581259e+42*cos(theta)**27 - 1.13788520195628e+43*cos(theta)**25 + 1.91778404824093e+43*cos(theta)**23 - 1.85900139542128e+43*cos(theta)**21 + 1.14820674423079e+43*cos(theta)**19 - 4.73116513887869e+42*cos(theta)**17 + 1.32394744627058e+42*cos(theta)**15 - 2.51382426507072e+41*cos(theta)**13 + 3.18308916681033e+40*cos(theta)**11 - 2.5936282099936e+39*cos(theta)**9 + 1.27904952821602e+38*cos(theta)**7 - 3.43918567125947e+36*cos(theta)**5 + 4.15360588316361e+34*cos(theta)**3 - 1.43063348444212e+32*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl46_m_minus_18(theta, phi):
    return 5.96366861096496e-30*(1.0 - cos(theta)**2)**9*(1.05359740921878e+41*cos(theta)**28 - 4.37648154598571e+41*cos(theta)**26 + 7.99076686767054e+41*cos(theta)**24 - 8.45000634282401e+41*cos(theta)**22 + 5.74103372115396e+41*cos(theta)**20 - 2.62842507715483e+41*cos(theta)**18 + 8.27467153919112e+40*cos(theta)**16 - 1.7955887607648e+40*cos(theta)**14 + 2.65257430567527e+39*cos(theta)**12 - 2.5936282099936e+38*cos(theta)**10 + 1.59881191027003e+37*cos(theta)**8 - 5.73197611876578e+35*cos(theta)**6 + 1.0384014707909e+34*cos(theta)**4 - 7.15316742221058e+31*cos(theta)**2 + 7.86062354089075e+28)*sin(18*phi)

#@torch.jit.script
def Yl46_m_minus_17(theta, phi):
    return 2.56922706601449e-28*(1.0 - cos(theta)**2)**8.5*(3.63309451454752e+39*cos(theta)**29 - 1.62091909110582e+40*cos(theta)**27 + 3.19630674706821e+40*cos(theta)**25 - 3.67391580122783e+40*cos(theta)**23 + 2.73382558150189e+40*cos(theta)**21 - 1.38338161955517e+40*cos(theta)**19 + 4.86745384658301e+39*cos(theta)**17 - 1.1970591738432e+39*cos(theta)**15 + 2.04044177359636e+38*cos(theta)**13 - 2.35784382726691e+37*cos(theta)**11 + 1.77645767807781e+36*cos(theta)**9 - 8.18853731252255e+34*cos(theta)**7 + 2.07680294158181e+33*cos(theta)**5 - 2.38438914073686e+31*cos(theta)**3 + 7.86062354089075e+28*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl46_m_minus_16(theta, phi):
    return 1.11694912080369e-26*(1.0 - cos(theta)**2)**8*(1.21103150484917e+38*cos(theta)**30 - 5.78899675394935e+38*cos(theta)**28 + 1.22934874887239e+39*cos(theta)**26 - 1.5307982505116e+39*cos(theta)**24 + 1.24264799159177e+39*cos(theta)**22 - 6.91690809777586e+38*cos(theta)**20 + 2.70414102587945e+38*cos(theta)**18 - 7.48161983652e+37*cos(theta)**16 + 1.45745840971169e+37*cos(theta)**14 - 1.96486985605576e+36*cos(theta)**12 + 1.77645767807781e+35*cos(theta)**10 - 1.02356716406532e+34*cos(theta)**8 + 3.46133823596968e+32*cos(theta)**6 - 5.96097285184215e+30*cos(theta)**4 + 3.93031177044537e+28*cos(theta)**2 - 4.15906007454537e+25)*sin(16*phi)

#@torch.jit.script
def Yl46_m_minus_15(theta, phi):
    return 4.89677424487597e-25*(1.0 - cos(theta)**2)**7.5*(3.90655324144895e+36*cos(theta)**31 - 1.99620577722391e+37*cos(theta)**29 + 4.55314351434219e+37*cos(theta)**27 - 6.12319300204639e+37*cos(theta)**25 + 5.40281735474681e+37*cos(theta)**23 - 3.29376576084565e+37*cos(theta)**21 + 1.42323211888392e+37*cos(theta)**19 - 4.40095284501176e+36*cos(theta)**17 + 9.71638939807792e+35*cos(theta)**15 - 1.51143835081212e+35*cos(theta)**13 + 1.61496152552528e+34*cos(theta)**11 - 1.13729684896146e+33*cos(theta)**9 + 4.94476890852811e+31*cos(theta)**7 - 1.19219457036843e+30*cos(theta)**5 + 1.31010392348179e+28*cos(theta)**3 - 4.15906007454537e+25*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl46_m_minus_14(theta, phi):
    return 2.16346557417279e-23*(1.0 - cos(theta)**2)**7*(1.2207978879528e+35*cos(theta)**32 - 6.65401925741305e+35*cos(theta)**30 + 1.62612268369364e+36*cos(theta)**28 - 2.3550742315563e+36*cos(theta)**26 + 2.25117389781117e+36*cos(theta)**24 - 1.49716625492984e+36*cos(theta)**22 + 7.11616059441961e+35*cos(theta)**20 - 2.44497380278431e+35*cos(theta)**18 + 6.0727433737987e+34*cos(theta)**16 - 1.07959882200866e+34*cos(theta)**14 + 1.34580127127107e+33*cos(theta)**12 - 1.13729684896146e+32*cos(theta)**10 + 6.18096113566013e+30*cos(theta)**8 - 1.98699095061405e+29*cos(theta)**6 + 3.27525980870448e+27*cos(theta)**4 - 2.07953003727268e+25*cos(theta)**2 + 2.13066602179578e+22)*sin(14*phi)

#@torch.jit.script
def Yl46_m_minus_13(theta, phi):
    return 9.62681407083826e-22*(1.0 - cos(theta)**2)**6.5*(3.6993875392509e+33*cos(theta)**33 - 2.14645782497195e+34*cos(theta)**31 + 5.60731959894358e+34*cos(theta)**29 - 8.72249715391223e+34*cos(theta)**27 + 9.00469559124469e+34*cos(theta)**25 - 6.50941849969495e+34*cos(theta)**23 + 3.38864790210458e+34*cos(theta)**21 - 1.2868283172549e+34*cos(theta)**19 + 3.57220198458747e+33*cos(theta)**17 - 7.19732548005772e+32*cos(theta)**15 + 1.03523174713159e+32*cos(theta)**13 - 1.0339062263286e+31*cos(theta)**11 + 6.86773459517793e+29*cos(theta)**9 - 2.83855850087721e+28*cos(theta)**7 + 6.55051961740896e+26*cos(theta)**5 - 6.93176679090895e+24*cos(theta)**3 + 2.13066602179578e+22*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl46_m_minus_12(theta, phi):
    return 4.31169516088401e-20*(1.0 - cos(theta)**2)**6*(1.08805515860321e+32*cos(theta)**34 - 6.70768070303734e+32*cos(theta)**32 + 1.86910653298119e+33*cos(theta)**30 - 3.11517755496865e+33*cos(theta)**28 + 3.46334445817103e+33*cos(theta)**26 - 2.71225770820623e+33*cos(theta)**24 + 1.54029450095663e+33*cos(theta)**22 - 6.43414158627451e+32*cos(theta)**20 + 1.98455665810415e+32*cos(theta)**18 - 4.49832842503608e+31*cos(theta)**16 + 7.39451247951136e+30*cos(theta)**14 - 8.61588521940504e+29*cos(theta)**12 + 6.86773459517793e+28*cos(theta)**10 - 3.54819812609652e+27*cos(theta)**8 + 1.09175326956816e+26*cos(theta)**6 - 1.73294169772724e+24*cos(theta)**4 + 1.06533301089789e+22*cos(theta)**2 - 1.06214657118434e+19)*sin(12*phi)

#@torch.jit.script
def Yl46_m_minus_11(theta, phi):
    return 1.9426567317875e-18*(1.0 - cos(theta)**2)**5.5*(3.10872902458059e+30*cos(theta)**35 - 2.03263051607192e+31*cos(theta)**33 + 6.02937591284256e+31*cos(theta)**31 - 1.07419915688574e+32*cos(theta)**29 + 1.28272016969298e+32*cos(theta)**27 - 1.08490308328249e+32*cos(theta)**25 + 6.69693261285489e+31*cos(theta)**23 - 3.063876945845e+31*cos(theta)**21 + 1.04450350426534e+31*cos(theta)**19 - 2.64607554413887e+30*cos(theta)**17 + 4.9296749863409e+29*cos(theta)**15 - 6.62760401492695e+28*cos(theta)**13 + 6.24339508652539e+27*cos(theta)**11 - 3.94244236232947e+26*cos(theta)**9 + 1.55964752795451e+25*cos(theta)**7 - 3.46588339545447e+23*cos(theta)**5 + 3.55111003632631e+21*cos(theta)**3 - 1.06214657118434e+19*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl46_m_minus_10(theta, phi):
    return 8.80004201373588e-17*(1.0 - cos(theta)**2)**5*(8.63535840161274e+28*cos(theta)**36 - 5.97832504727036e+29*cos(theta)**34 + 1.8841799727633e+30*cos(theta)**32 - 3.58066385628581e+30*cos(theta)**30 + 4.5811434631892e+30*cos(theta)**28 - 4.17270416647112e+30*cos(theta)**26 + 2.79038858868954e+30*cos(theta)**24 - 1.39267133902046e+30*cos(theta)**22 + 5.22251752132671e+29*cos(theta)**20 - 1.47004196896604e+29*cos(theta)**18 + 3.08104686646307e+28*cos(theta)**16 - 4.73400286780497e+27*cos(theta)**14 + 5.20282923877116e+26*cos(theta)**12 - 3.94244236232946e+25*cos(theta)**10 + 1.94955940994314e+24*cos(theta)**8 - 5.77647232575746e+22*cos(theta)**6 + 8.87777509081577e+20*cos(theta)**4 - 5.31073285592169e+18*cos(theta)**2 + 5.1761528810153e+15)*sin(10*phi)

#@torch.jit.script
def Yl46_m_minus_9(theta, phi):
    return 4.00571107454053e-15*(1.0 - cos(theta)**2)**4.5*(2.33388064908453e+27*cos(theta)**37 - 1.70809287064867e+28*cos(theta)**35 + 5.70963628110091e+28*cos(theta)**33 - 1.15505285686639e+29*cos(theta)**31 + 1.57970464247903e+29*cos(theta)**29 - 1.5454459875819e+29*cos(theta)**27 + 1.11615543547582e+29*cos(theta)**25 - 6.05509277834981e+28*cos(theta)**23 + 2.48691310539367e+28*cos(theta)**21 - 7.73706299455809e+27*cos(theta)**19 + 1.81238050968416e+27*cos(theta)**17 - 3.15600191186998e+26*cos(theta)**15 + 4.00217633751628e+25*cos(theta)**13 - 3.5840385112086e+24*cos(theta)**11 + 2.16617712215905e+23*cos(theta)**9 - 8.25210332251065e+21*cos(theta)**7 + 1.77555501816315e+20*cos(theta)**5 - 1.77024428530723e+18*cos(theta)**3 + 5.1761528810153e+15*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl46_m_minus_8(theta, phi):
    return 1.83127161651504e-13*(1.0 - cos(theta)**2)**4*(6.14179118180138e+25*cos(theta)**38 - 4.74470241846854e+26*cos(theta)**36 + 1.67930478855909e+27*cos(theta)**34 - 3.60954017770747e+27*cos(theta)**32 + 5.26568214159678e+27*cos(theta)**30 - 5.51944995564964e+27*cos(theta)**28 + 4.29290552106083e+27*cos(theta)**26 - 2.52295532431242e+27*cos(theta)**24 + 1.13041504790621e+27*cos(theta)**22 - 3.86853149727905e+26*cos(theta)**20 + 1.00687806093564e+26*cos(theta)**18 - 1.97250119491874e+25*cos(theta)**16 + 2.8586973839402e+24*cos(theta)**14 - 2.9866987593405e+23*cos(theta)**12 + 2.16617712215905e+22*cos(theta)**10 - 1.03151291531383e+21*cos(theta)**8 + 2.95925836360525e+19*cos(theta)**6 - 4.42561071326808e+17*cos(theta)**4 + 2.58807644050765e+15*cos(theta)**2 - 2476628172734.59)*sin(8*phi)

#@torch.jit.script
def Yl46_m_minus_7(theta, phi):
    return 8.4039207365689e-12*(1.0 - cos(theta)**2)**3.5*(1.57481825174394e+24*cos(theta)**39 - 1.2823520049915e+25*cos(theta)**37 + 4.7980136815974e+25*cos(theta)**35 - 1.09380005385075e+26*cos(theta)**33 + 1.69860714245057e+26*cos(theta)**31 - 1.90325860539643e+26*cos(theta)**29 + 1.58996500780031e+26*cos(theta)**27 - 1.00918212972497e+26*cos(theta)**25 + 4.91484803437485e+25*cos(theta)**23 - 1.84215785584716e+25*cos(theta)**21 + 5.29935821545075e+24*cos(theta)**19 - 1.16029482054043e+24*cos(theta)**17 + 1.90579825596013e+23*cos(theta)**15 - 2.29746058410808e+22*cos(theta)**13 + 1.9692519292355e+21*cos(theta)**11 - 1.14612546145981e+20*cos(theta)**9 + 4.22751194800751e+18*cos(theta)**7 - 8.85122142653616e+16*cos(theta)**5 + 862692146835883.0*cos(theta)**3 - 2476628172734.59*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl46_m_minus_6(theta, phi):
    return 3.86945569224729e-10*(1.0 - cos(theta)**2)**3*(3.93704562935986e+22*cos(theta)**40 - 3.37461053945131e+23*cos(theta)**38 + 1.3327815782215e+24*cos(theta)**36 - 3.21705898191397e+24*cos(theta)**34 + 5.30814732015804e+24*cos(theta)**32 - 6.34419535132142e+24*cos(theta)**30 + 5.67844645642967e+24*cos(theta)**28 - 3.88146972971142e+24*cos(theta)**26 + 2.04785334765619e+24*cos(theta)**24 - 8.3734447993053e+23*cos(theta)**22 + 2.64967910772537e+23*cos(theta)**20 - 6.44608233633574e+22*cos(theta)**18 + 1.19112390997508e+22*cos(theta)**16 - 1.64104327436291e+21*cos(theta)**14 + 1.64104327436291e+20*cos(theta)**12 - 1.14612546145981e+19*cos(theta)**10 + 5.28438993500938e+17*cos(theta)**8 - 1.47520357108936e+16*cos(theta)**6 + 215673036708971.0*cos(theta)**4 - 1238314086367.3*cos(theta)**2 + 1168220836.19556)*sin(6*phi)

#@torch.jit.script
def Yl46_m_minus_5(theta, phi):
    return 1.78666643331353e-8*(1.0 - cos(theta)**2)**2.5*(9.60255031551185e+20*cos(theta)**41 - 8.65284753705464e+21*cos(theta)**39 + 3.60211237357162e+22*cos(theta)**37 - 9.19159709118276e+22*cos(theta)**35 + 1.60852949095698e+23*cos(theta)**33 - 2.04651462945852e+23*cos(theta)**31 + 1.95808498497575e+23*cos(theta)**29 - 1.4375813813746e+23*cos(theta)**27 + 8.19141339062474e+22*cos(theta)**25 - 3.640628173611e+22*cos(theta)**23 + 1.2617519560597e+22*cos(theta)**21 - 3.39267491386091e+21*cos(theta)**19 + 7.00661123514754e+20*cos(theta)**17 - 1.09402884957528e+20*cos(theta)**15 + 1.26234098027916e+19*cos(theta)**13 - 1.04193223769074e+18*cos(theta)**11 + 5.87154437223265e+16*cos(theta)**9 - 2.1074336729848e+15*cos(theta)**7 + 43134607341794.1*cos(theta)**5 - 412771362122.432*cos(theta)**3 + 1168220836.19556*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl46_m_minus_4(theta, phi):
    return 8.26900418061119e-7*(1.0 - cos(theta)**2)**2*(2.2863215036933e+19*cos(theta)**42 - 2.16321188426366e+20*cos(theta)**40 + 9.47924308834637e+20*cos(theta)**38 - 2.55322141421743e+21*cos(theta)**36 + 4.73096909104995e+21*cos(theta)**34 - 6.39535821705788e+21*cos(theta)**32 + 6.52694994991916e+21*cos(theta)**30 - 5.134219219195e+21*cos(theta)**28 + 3.15054361177875e+21*cos(theta)**26 - 1.51692840567125e+21*cos(theta)**24 + 5.73523616390774e+20*cos(theta)**22 - 1.69633745693046e+20*cos(theta)**20 + 3.89256179730419e+19*cos(theta)**18 - 6.83768030984548e+18*cos(theta)**16 + 9.01672128770832e+17*cos(theta)**14 - 8.68276864742283e+16*cos(theta)**12 + 5.87154437223265e+15*cos(theta)**10 - 263429209123100.0*cos(theta)**8 + 7189101223632.36*cos(theta)**6 - 103192840530.608*cos(theta)**4 + 584110418.097781*cos(theta)**2 - 545387.878709413)*sin(4*phi)

#@torch.jit.script
def Yl46_m_minus_3(theta, phi):
    return 3.83417950543236e-5*(1.0 - cos(theta)**2)**1.5*(5.31702675277511e+17*cos(theta)**43 - 5.27612654698454e+18*cos(theta)**41 + 2.43057515085804e+19*cos(theta)**39 - 6.90059841680387e+19*cos(theta)**37 + 1.3517054545857e+20*cos(theta)**35 - 1.93798733850239e+20*cos(theta)**33 + 2.10546772578037e+20*cos(theta)**31 - 1.77042042041207e+20*cos(theta)**29 + 1.1668680043625e+20*cos(theta)**27 - 6.067713622685e+19*cos(theta)**25 + 2.49358094082945e+19*cos(theta)**23 - 8.07779741395456e+18*cos(theta)**21 + 2.04871673542326e+18*cos(theta)**19 - 4.0221648881444e+17*cos(theta)**17 + 6.01114752513888e+16*cos(theta)**15 - 6.67905280570987e+15*cos(theta)**13 + 533776761112059.0*cos(theta)**11 - 29269912124788.9*cos(theta)**9 + 1027014460518.91*cos(theta)**7 - 20638568106.1216*cos(theta)**5 + 194703472.69926*cos(theta)**3 - 545387.878709413*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl46_m_minus_2(theta, phi):
    return 0.00178031487177454*(1.0 - cos(theta)**2)*(1.20841517108525e+16*cos(theta)**44 - 1.25622060642489e+17*cos(theta)**42 + 6.07643787714511e+17*cos(theta)**40 - 1.81594695179049e+18*cos(theta)**38 + 3.75473737384917e+18*cos(theta)**36 - 5.69996276030114e+18*cos(theta)**34 + 6.57958664306367e+18*cos(theta)**32 - 5.90140140137356e+18*cos(theta)**30 + 4.16738572986607e+18*cos(theta)**28 - 2.333736008725e+18*cos(theta)**26 + 1.03899205867894e+18*cos(theta)**24 - 3.67172609725207e+17*cos(theta)**22 + 1.02435836771163e+17*cos(theta)**20 - 2.23453604896911e+16*cos(theta)**18 + 3.7569672032118e+15*cos(theta)**16 - 477075200407848.0*cos(theta)**14 + 44481396759338.3*cos(theta)**12 - 2926991212478.89*cos(theta)**10 + 128376807564.864*cos(theta)**8 - 3439761351.02027*cos(theta)**6 + 48675868.1748151*cos(theta)**4 - 272693.939354706*cos(theta)**2 + 252.962837991379)*sin(2*phi)

#@torch.jit.script
def Yl46_m_minus_1(theta, phi):
    return 0.0827415581926583*(1.0 - cos(theta)**2)**0.5*(268536704685612.0*cos(theta)**45 - 2.92144327075556e+15*cos(theta)**43 + 1.48205801881588e+16*cos(theta)**41 - 4.65627423536024e+16*cos(theta)**39 + 1.0147938848241e+17*cos(theta)**37 - 1.62856078865747e+17*cos(theta)**35 + 1.99381413426172e+17*cos(theta)**33 - 1.90367787141083e+17*cos(theta)**31 + 1.43702956202278e+17*cos(theta)**29 - 8.64346669898148e+16*cos(theta)**27 + 4.15596823471575e+16*cos(theta)**25 - 1.59640265097916e+16*cos(theta)**23 + 4.87789698910299e+15*cos(theta)**21 - 1.17607160472058e+15*cos(theta)**19 + 220998070777165.0*cos(theta)**17 - 31805013360523.2*cos(theta)**15 + 3421645904564.48*cos(theta)**13 - 266090110225.353*cos(theta)**11 + 14264089729.4293*cos(theta)**9 - 491394478.717181*cos(theta)**7 + 9735173.63496302*cos(theta)**5 - 90897.9797849021*cos(theta)**3 + 252.962837991379*cos(theta))*sin(phi)

#@torch.jit.script
def Yl46_m0(theta, phi):
    return 49892152197498.7*cos(theta)**46 - 567454698070452.0*cos(theta)**44 + 3.01579856390251e+15*cos(theta)**42 - 9.94866882574737e+15*cos(theta)**40 + 2.2823416717891e+16*cos(theta)**38 - 3.86623179582588e+16*cos(theta)**36 + 5.01178195755206e+16*cos(theta)**34 - 5.08428513234486e+16*cos(theta)**32 + 4.09383997669326e+16*cos(theta)**30 - 2.63825242942455e+16*cos(theta)**28 + 1.36610879222257e+16*cos(theta)**26 - 5.68483172179689e+15*cos(theta)**24 + 1.89494390726563e+15*cos(theta)**22 - 502562620641056.0*cos(theta)**20 + 104930657056924.0*cos(theta)**18 - 16988773047311.5*cos(theta)**16 + 2088783571390.76*cos(theta)**14 - 189510772678.523*cos(theta)**12 + 12190751458.8524*cos(theta)**10 - 524960589.137183*cos(theta)**8 + 13866883.4866426*cos(theta)**6 - 194214.05443477*cos(theta)**4 + 1080.96876308777*cos(theta)**2 - 0.999971103688968

#@torch.jit.script
def Yl46_m1(theta, phi):
    return 0.0827415581926583*(1.0 - cos(theta)**2)**0.5*(268536704685612.0*cos(theta)**45 - 2.92144327075556e+15*cos(theta)**43 + 1.48205801881588e+16*cos(theta)**41 - 4.65627423536024e+16*cos(theta)**39 + 1.0147938848241e+17*cos(theta)**37 - 1.62856078865747e+17*cos(theta)**35 + 1.99381413426172e+17*cos(theta)**33 - 1.90367787141083e+17*cos(theta)**31 + 1.43702956202278e+17*cos(theta)**29 - 8.64346669898148e+16*cos(theta)**27 + 4.15596823471575e+16*cos(theta)**25 - 1.59640265097916e+16*cos(theta)**23 + 4.87789698910299e+15*cos(theta)**21 - 1.17607160472058e+15*cos(theta)**19 + 220998070777165.0*cos(theta)**17 - 31805013360523.2*cos(theta)**15 + 3421645904564.48*cos(theta)**13 - 266090110225.353*cos(theta)**11 + 14264089729.4293*cos(theta)**9 - 491394478.717181*cos(theta)**7 + 9735173.63496302*cos(theta)**5 - 90897.9797849021*cos(theta)**3 + 252.962837991379*cos(theta))*cos(phi)

#@torch.jit.script
def Yl46_m2(theta, phi):
    return 0.00178031487177454*(1.0 - cos(theta)**2)*(1.20841517108525e+16*cos(theta)**44 - 1.25622060642489e+17*cos(theta)**42 + 6.07643787714511e+17*cos(theta)**40 - 1.81594695179049e+18*cos(theta)**38 + 3.75473737384917e+18*cos(theta)**36 - 5.69996276030114e+18*cos(theta)**34 + 6.57958664306367e+18*cos(theta)**32 - 5.90140140137356e+18*cos(theta)**30 + 4.16738572986607e+18*cos(theta)**28 - 2.333736008725e+18*cos(theta)**26 + 1.03899205867894e+18*cos(theta)**24 - 3.67172609725207e+17*cos(theta)**22 + 1.02435836771163e+17*cos(theta)**20 - 2.23453604896911e+16*cos(theta)**18 + 3.7569672032118e+15*cos(theta)**16 - 477075200407848.0*cos(theta)**14 + 44481396759338.3*cos(theta)**12 - 2926991212478.89*cos(theta)**10 + 128376807564.864*cos(theta)**8 - 3439761351.02027*cos(theta)**6 + 48675868.1748151*cos(theta)**4 - 272693.939354706*cos(theta)**2 + 252.962837991379)*cos(2*phi)

#@torch.jit.script
def Yl46_m3(theta, phi):
    return 3.83417950543236e-5*(1.0 - cos(theta)**2)**1.5*(5.31702675277511e+17*cos(theta)**43 - 5.27612654698454e+18*cos(theta)**41 + 2.43057515085804e+19*cos(theta)**39 - 6.90059841680387e+19*cos(theta)**37 + 1.3517054545857e+20*cos(theta)**35 - 1.93798733850239e+20*cos(theta)**33 + 2.10546772578037e+20*cos(theta)**31 - 1.77042042041207e+20*cos(theta)**29 + 1.1668680043625e+20*cos(theta)**27 - 6.067713622685e+19*cos(theta)**25 + 2.49358094082945e+19*cos(theta)**23 - 8.07779741395456e+18*cos(theta)**21 + 2.04871673542326e+18*cos(theta)**19 - 4.0221648881444e+17*cos(theta)**17 + 6.01114752513888e+16*cos(theta)**15 - 6.67905280570987e+15*cos(theta)**13 + 533776761112059.0*cos(theta)**11 - 29269912124788.9*cos(theta)**9 + 1027014460518.91*cos(theta)**7 - 20638568106.1216*cos(theta)**5 + 194703472.69926*cos(theta)**3 - 545387.878709413*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl46_m4(theta, phi):
    return 8.26900418061119e-7*(1.0 - cos(theta)**2)**2*(2.2863215036933e+19*cos(theta)**42 - 2.16321188426366e+20*cos(theta)**40 + 9.47924308834637e+20*cos(theta)**38 - 2.55322141421743e+21*cos(theta)**36 + 4.73096909104995e+21*cos(theta)**34 - 6.39535821705788e+21*cos(theta)**32 + 6.52694994991916e+21*cos(theta)**30 - 5.134219219195e+21*cos(theta)**28 + 3.15054361177875e+21*cos(theta)**26 - 1.51692840567125e+21*cos(theta)**24 + 5.73523616390774e+20*cos(theta)**22 - 1.69633745693046e+20*cos(theta)**20 + 3.89256179730419e+19*cos(theta)**18 - 6.83768030984548e+18*cos(theta)**16 + 9.01672128770832e+17*cos(theta)**14 - 8.68276864742283e+16*cos(theta)**12 + 5.87154437223265e+15*cos(theta)**10 - 263429209123100.0*cos(theta)**8 + 7189101223632.36*cos(theta)**6 - 103192840530.608*cos(theta)**4 + 584110418.097781*cos(theta)**2 - 545387.878709413)*cos(4*phi)

#@torch.jit.script
def Yl46_m5(theta, phi):
    return 1.78666643331353e-8*(1.0 - cos(theta)**2)**2.5*(9.60255031551185e+20*cos(theta)**41 - 8.65284753705464e+21*cos(theta)**39 + 3.60211237357162e+22*cos(theta)**37 - 9.19159709118276e+22*cos(theta)**35 + 1.60852949095698e+23*cos(theta)**33 - 2.04651462945852e+23*cos(theta)**31 + 1.95808498497575e+23*cos(theta)**29 - 1.4375813813746e+23*cos(theta)**27 + 8.19141339062474e+22*cos(theta)**25 - 3.640628173611e+22*cos(theta)**23 + 1.2617519560597e+22*cos(theta)**21 - 3.39267491386091e+21*cos(theta)**19 + 7.00661123514754e+20*cos(theta)**17 - 1.09402884957528e+20*cos(theta)**15 + 1.26234098027916e+19*cos(theta)**13 - 1.04193223769074e+18*cos(theta)**11 + 5.87154437223265e+16*cos(theta)**9 - 2.1074336729848e+15*cos(theta)**7 + 43134607341794.1*cos(theta)**5 - 412771362122.432*cos(theta)**3 + 1168220836.19556*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl46_m6(theta, phi):
    return 3.86945569224729e-10*(1.0 - cos(theta)**2)**3*(3.93704562935986e+22*cos(theta)**40 - 3.37461053945131e+23*cos(theta)**38 + 1.3327815782215e+24*cos(theta)**36 - 3.21705898191397e+24*cos(theta)**34 + 5.30814732015804e+24*cos(theta)**32 - 6.34419535132142e+24*cos(theta)**30 + 5.67844645642967e+24*cos(theta)**28 - 3.88146972971142e+24*cos(theta)**26 + 2.04785334765619e+24*cos(theta)**24 - 8.3734447993053e+23*cos(theta)**22 + 2.64967910772537e+23*cos(theta)**20 - 6.44608233633574e+22*cos(theta)**18 + 1.19112390997508e+22*cos(theta)**16 - 1.64104327436291e+21*cos(theta)**14 + 1.64104327436291e+20*cos(theta)**12 - 1.14612546145981e+19*cos(theta)**10 + 5.28438993500938e+17*cos(theta)**8 - 1.47520357108936e+16*cos(theta)**6 + 215673036708971.0*cos(theta)**4 - 1238314086367.3*cos(theta)**2 + 1168220836.19556)*cos(6*phi)

#@torch.jit.script
def Yl46_m7(theta, phi):
    return 8.4039207365689e-12*(1.0 - cos(theta)**2)**3.5*(1.57481825174394e+24*cos(theta)**39 - 1.2823520049915e+25*cos(theta)**37 + 4.7980136815974e+25*cos(theta)**35 - 1.09380005385075e+26*cos(theta)**33 + 1.69860714245057e+26*cos(theta)**31 - 1.90325860539643e+26*cos(theta)**29 + 1.58996500780031e+26*cos(theta)**27 - 1.00918212972497e+26*cos(theta)**25 + 4.91484803437485e+25*cos(theta)**23 - 1.84215785584716e+25*cos(theta)**21 + 5.29935821545075e+24*cos(theta)**19 - 1.16029482054043e+24*cos(theta)**17 + 1.90579825596013e+23*cos(theta)**15 - 2.29746058410808e+22*cos(theta)**13 + 1.9692519292355e+21*cos(theta)**11 - 1.14612546145981e+20*cos(theta)**9 + 4.22751194800751e+18*cos(theta)**7 - 8.85122142653616e+16*cos(theta)**5 + 862692146835883.0*cos(theta)**3 - 2476628172734.59*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl46_m8(theta, phi):
    return 1.83127161651504e-13*(1.0 - cos(theta)**2)**4*(6.14179118180138e+25*cos(theta)**38 - 4.74470241846854e+26*cos(theta)**36 + 1.67930478855909e+27*cos(theta)**34 - 3.60954017770747e+27*cos(theta)**32 + 5.26568214159678e+27*cos(theta)**30 - 5.51944995564964e+27*cos(theta)**28 + 4.29290552106083e+27*cos(theta)**26 - 2.52295532431242e+27*cos(theta)**24 + 1.13041504790621e+27*cos(theta)**22 - 3.86853149727905e+26*cos(theta)**20 + 1.00687806093564e+26*cos(theta)**18 - 1.97250119491874e+25*cos(theta)**16 + 2.8586973839402e+24*cos(theta)**14 - 2.9866987593405e+23*cos(theta)**12 + 2.16617712215905e+22*cos(theta)**10 - 1.03151291531383e+21*cos(theta)**8 + 2.95925836360525e+19*cos(theta)**6 - 4.42561071326808e+17*cos(theta)**4 + 2.58807644050765e+15*cos(theta)**2 - 2476628172734.59)*cos(8*phi)

#@torch.jit.script
def Yl46_m9(theta, phi):
    return 4.00571107454053e-15*(1.0 - cos(theta)**2)**4.5*(2.33388064908453e+27*cos(theta)**37 - 1.70809287064867e+28*cos(theta)**35 + 5.70963628110091e+28*cos(theta)**33 - 1.15505285686639e+29*cos(theta)**31 + 1.57970464247903e+29*cos(theta)**29 - 1.5454459875819e+29*cos(theta)**27 + 1.11615543547582e+29*cos(theta)**25 - 6.05509277834981e+28*cos(theta)**23 + 2.48691310539367e+28*cos(theta)**21 - 7.73706299455809e+27*cos(theta)**19 + 1.81238050968416e+27*cos(theta)**17 - 3.15600191186998e+26*cos(theta)**15 + 4.00217633751628e+25*cos(theta)**13 - 3.5840385112086e+24*cos(theta)**11 + 2.16617712215905e+23*cos(theta)**9 - 8.25210332251065e+21*cos(theta)**7 + 1.77555501816315e+20*cos(theta)**5 - 1.77024428530723e+18*cos(theta)**3 + 5.1761528810153e+15*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl46_m10(theta, phi):
    return 8.80004201373588e-17*(1.0 - cos(theta)**2)**5*(8.63535840161274e+28*cos(theta)**36 - 5.97832504727036e+29*cos(theta)**34 + 1.8841799727633e+30*cos(theta)**32 - 3.58066385628581e+30*cos(theta)**30 + 4.5811434631892e+30*cos(theta)**28 - 4.17270416647112e+30*cos(theta)**26 + 2.79038858868954e+30*cos(theta)**24 - 1.39267133902046e+30*cos(theta)**22 + 5.22251752132671e+29*cos(theta)**20 - 1.47004196896604e+29*cos(theta)**18 + 3.08104686646307e+28*cos(theta)**16 - 4.73400286780497e+27*cos(theta)**14 + 5.20282923877116e+26*cos(theta)**12 - 3.94244236232946e+25*cos(theta)**10 + 1.94955940994314e+24*cos(theta)**8 - 5.77647232575746e+22*cos(theta)**6 + 8.87777509081577e+20*cos(theta)**4 - 5.31073285592169e+18*cos(theta)**2 + 5.1761528810153e+15)*cos(10*phi)

#@torch.jit.script
def Yl46_m11(theta, phi):
    return 1.9426567317875e-18*(1.0 - cos(theta)**2)**5.5*(3.10872902458059e+30*cos(theta)**35 - 2.03263051607192e+31*cos(theta)**33 + 6.02937591284256e+31*cos(theta)**31 - 1.07419915688574e+32*cos(theta)**29 + 1.28272016969298e+32*cos(theta)**27 - 1.08490308328249e+32*cos(theta)**25 + 6.69693261285489e+31*cos(theta)**23 - 3.063876945845e+31*cos(theta)**21 + 1.04450350426534e+31*cos(theta)**19 - 2.64607554413887e+30*cos(theta)**17 + 4.9296749863409e+29*cos(theta)**15 - 6.62760401492695e+28*cos(theta)**13 + 6.24339508652539e+27*cos(theta)**11 - 3.94244236232947e+26*cos(theta)**9 + 1.55964752795451e+25*cos(theta)**7 - 3.46588339545447e+23*cos(theta)**5 + 3.55111003632631e+21*cos(theta)**3 - 1.06214657118434e+19*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl46_m12(theta, phi):
    return 4.31169516088401e-20*(1.0 - cos(theta)**2)**6*(1.08805515860321e+32*cos(theta)**34 - 6.70768070303734e+32*cos(theta)**32 + 1.86910653298119e+33*cos(theta)**30 - 3.11517755496865e+33*cos(theta)**28 + 3.46334445817103e+33*cos(theta)**26 - 2.71225770820623e+33*cos(theta)**24 + 1.54029450095663e+33*cos(theta)**22 - 6.43414158627451e+32*cos(theta)**20 + 1.98455665810415e+32*cos(theta)**18 - 4.49832842503608e+31*cos(theta)**16 + 7.39451247951136e+30*cos(theta)**14 - 8.61588521940504e+29*cos(theta)**12 + 6.86773459517793e+28*cos(theta)**10 - 3.54819812609652e+27*cos(theta)**8 + 1.09175326956816e+26*cos(theta)**6 - 1.73294169772724e+24*cos(theta)**4 + 1.06533301089789e+22*cos(theta)**2 - 1.06214657118434e+19)*cos(12*phi)

#@torch.jit.script
def Yl46_m13(theta, phi):
    return 9.62681407083826e-22*(1.0 - cos(theta)**2)**6.5*(3.6993875392509e+33*cos(theta)**33 - 2.14645782497195e+34*cos(theta)**31 + 5.60731959894358e+34*cos(theta)**29 - 8.72249715391223e+34*cos(theta)**27 + 9.00469559124469e+34*cos(theta)**25 - 6.50941849969495e+34*cos(theta)**23 + 3.38864790210458e+34*cos(theta)**21 - 1.2868283172549e+34*cos(theta)**19 + 3.57220198458747e+33*cos(theta)**17 - 7.19732548005772e+32*cos(theta)**15 + 1.03523174713159e+32*cos(theta)**13 - 1.0339062263286e+31*cos(theta)**11 + 6.86773459517793e+29*cos(theta)**9 - 2.83855850087721e+28*cos(theta)**7 + 6.55051961740896e+26*cos(theta)**5 - 6.93176679090895e+24*cos(theta)**3 + 2.13066602179578e+22*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl46_m14(theta, phi):
    return 2.16346557417279e-23*(1.0 - cos(theta)**2)**7*(1.2207978879528e+35*cos(theta)**32 - 6.65401925741305e+35*cos(theta)**30 + 1.62612268369364e+36*cos(theta)**28 - 2.3550742315563e+36*cos(theta)**26 + 2.25117389781117e+36*cos(theta)**24 - 1.49716625492984e+36*cos(theta)**22 + 7.11616059441961e+35*cos(theta)**20 - 2.44497380278431e+35*cos(theta)**18 + 6.0727433737987e+34*cos(theta)**16 - 1.07959882200866e+34*cos(theta)**14 + 1.34580127127107e+33*cos(theta)**12 - 1.13729684896146e+32*cos(theta)**10 + 6.18096113566013e+30*cos(theta)**8 - 1.98699095061405e+29*cos(theta)**6 + 3.27525980870448e+27*cos(theta)**4 - 2.07953003727268e+25*cos(theta)**2 + 2.13066602179578e+22)*cos(14*phi)

#@torch.jit.script
def Yl46_m15(theta, phi):
    return 4.89677424487597e-25*(1.0 - cos(theta)**2)**7.5*(3.90655324144895e+36*cos(theta)**31 - 1.99620577722391e+37*cos(theta)**29 + 4.55314351434219e+37*cos(theta)**27 - 6.12319300204639e+37*cos(theta)**25 + 5.40281735474681e+37*cos(theta)**23 - 3.29376576084565e+37*cos(theta)**21 + 1.42323211888392e+37*cos(theta)**19 - 4.40095284501176e+36*cos(theta)**17 + 9.71638939807792e+35*cos(theta)**15 - 1.51143835081212e+35*cos(theta)**13 + 1.61496152552528e+34*cos(theta)**11 - 1.13729684896146e+33*cos(theta)**9 + 4.94476890852811e+31*cos(theta)**7 - 1.19219457036843e+30*cos(theta)**5 + 1.31010392348179e+28*cos(theta)**3 - 4.15906007454537e+25*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl46_m16(theta, phi):
    return 1.11694912080369e-26*(1.0 - cos(theta)**2)**8*(1.21103150484917e+38*cos(theta)**30 - 5.78899675394935e+38*cos(theta)**28 + 1.22934874887239e+39*cos(theta)**26 - 1.5307982505116e+39*cos(theta)**24 + 1.24264799159177e+39*cos(theta)**22 - 6.91690809777586e+38*cos(theta)**20 + 2.70414102587945e+38*cos(theta)**18 - 7.48161983652e+37*cos(theta)**16 + 1.45745840971169e+37*cos(theta)**14 - 1.96486985605576e+36*cos(theta)**12 + 1.77645767807781e+35*cos(theta)**10 - 1.02356716406532e+34*cos(theta)**8 + 3.46133823596968e+32*cos(theta)**6 - 5.96097285184215e+30*cos(theta)**4 + 3.93031177044537e+28*cos(theta)**2 - 4.15906007454537e+25)*cos(16*phi)

#@torch.jit.script
def Yl46_m17(theta, phi):
    return 2.56922706601449e-28*(1.0 - cos(theta)**2)**8.5*(3.63309451454752e+39*cos(theta)**29 - 1.62091909110582e+40*cos(theta)**27 + 3.19630674706821e+40*cos(theta)**25 - 3.67391580122783e+40*cos(theta)**23 + 2.73382558150189e+40*cos(theta)**21 - 1.38338161955517e+40*cos(theta)**19 + 4.86745384658301e+39*cos(theta)**17 - 1.1970591738432e+39*cos(theta)**15 + 2.04044177359636e+38*cos(theta)**13 - 2.35784382726691e+37*cos(theta)**11 + 1.77645767807781e+36*cos(theta)**9 - 8.18853731252255e+34*cos(theta)**7 + 2.07680294158181e+33*cos(theta)**5 - 2.38438914073686e+31*cos(theta)**3 + 7.86062354089075e+28*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl46_m18(theta, phi):
    return 5.96366861096496e-30*(1.0 - cos(theta)**2)**9*(1.05359740921878e+41*cos(theta)**28 - 4.37648154598571e+41*cos(theta)**26 + 7.99076686767054e+41*cos(theta)**24 - 8.45000634282401e+41*cos(theta)**22 + 5.74103372115396e+41*cos(theta)**20 - 2.62842507715483e+41*cos(theta)**18 + 8.27467153919112e+40*cos(theta)**16 - 1.7955887607648e+40*cos(theta)**14 + 2.65257430567527e+39*cos(theta)**12 - 2.5936282099936e+38*cos(theta)**10 + 1.59881191027003e+37*cos(theta)**8 - 5.73197611876578e+35*cos(theta)**6 + 1.0384014707909e+34*cos(theta)**4 - 7.15316742221058e+31*cos(theta)**2 + 7.86062354089075e+28)*cos(18*phi)

#@torch.jit.script
def Yl46_m19(theta, phi):
    return 1.39790548387065e-31*(1.0 - cos(theta)**2)**9.5*(2.95007274581259e+42*cos(theta)**27 - 1.13788520195628e+43*cos(theta)**25 + 1.91778404824093e+43*cos(theta)**23 - 1.85900139542128e+43*cos(theta)**21 + 1.14820674423079e+43*cos(theta)**19 - 4.73116513887869e+42*cos(theta)**17 + 1.32394744627058e+42*cos(theta)**15 - 2.51382426507072e+41*cos(theta)**13 + 3.18308916681033e+40*cos(theta)**11 - 2.5936282099936e+39*cos(theta)**9 + 1.27904952821602e+38*cos(theta)**7 - 3.43918567125947e+36*cos(theta)**5 + 4.15360588316361e+34*cos(theta)**3 - 1.43063348444212e+32*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl46_m20(theta, phi):
    return 3.31149389509621e-33*(1.0 - cos(theta)**2)**10*(7.96519641369399e+43*cos(theta)**26 - 2.84471300489071e+44*cos(theta)**24 + 4.41090331095414e+44*cos(theta)**22 - 3.90390293038469e+44*cos(theta)**20 + 2.18159281403851e+44*cos(theta)**18 - 8.04298073609377e+43*cos(theta)**16 + 1.98592116940587e+43*cos(theta)**14 - 3.26797154459194e+42*cos(theta)**12 + 3.50139808349136e+41*cos(theta)**10 - 2.33426538899424e+40*cos(theta)**8 + 8.95334669751215e+38*cos(theta)**6 - 1.71959283562973e+37*cos(theta)**4 + 1.24608176494908e+35*cos(theta)**2 - 1.43063348444212e+32)*cos(20*phi)

#@torch.jit.script
def Yl46_m21(theta, phi):
    return 7.93414043768083e-35*(1.0 - cos(theta)**2)**10.5*(2.07095106756044e+45*cos(theta)**25 - 6.82731121173771e+45*cos(theta)**23 + 9.7039872840991e+45*cos(theta)**21 - 7.80780586076939e+45*cos(theta)**19 + 3.92686706526931e+45*cos(theta)**17 - 1.286876917775e+45*cos(theta)**15 + 2.78028963716822e+44*cos(theta)**13 - 3.92156585351032e+43*cos(theta)**11 + 3.50139808349136e+42*cos(theta)**9 - 1.86741231119539e+41*cos(theta)**7 + 5.37200801850729e+39*cos(theta)**5 - 6.87837134251894e+37*cos(theta)**3 + 2.49216352989817e+35*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl46_m22(theta, phi):
    return 1.92431171017896e-36*(1.0 - cos(theta)**2)**11*(5.17737766890109e+46*cos(theta)**24 - 1.57028157869967e+47*cos(theta)**22 + 2.03783732966081e+47*cos(theta)**20 - 1.48348311354618e+47*cos(theta)**18 + 6.67567401095783e+46*cos(theta)**16 - 1.9303153766625e+46*cos(theta)**14 + 3.61437652831868e+45*cos(theta)**12 - 4.31372243886136e+44*cos(theta)**10 + 3.15125827514222e+43*cos(theta)**8 - 1.30718861783677e+42*cos(theta)**6 + 2.68600400925365e+40*cos(theta)**4 - 2.06351140275568e+38*cos(theta)**2 + 2.49216352989817e+35)*cos(22*phi)

#@torch.jit.script
def Yl46_m23(theta, phi):
    return 4.72873804667603e-38*(1.0 - cos(theta)**2)**11.5*(1.24257064053626e+48*cos(theta)**23 - 3.45461947313928e+48*cos(theta)**21 + 4.07567465932162e+48*cos(theta)**19 - 2.67026960438313e+48*cos(theta)**17 + 1.06810784175325e+48*cos(theta)**15 - 2.70244152732751e+47*cos(theta)**13 + 4.33725183398242e+46*cos(theta)**11 - 4.31372243886136e+45*cos(theta)**9 + 2.52100662011378e+44*cos(theta)**7 - 7.84313170702065e+42*cos(theta)**5 + 1.07440160370146e+41*cos(theta)**3 - 4.12702280551136e+38*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl46_m24(theta, phi):
    return 1.17850741252294e-39*(1.0 - cos(theta)**2)**12*(2.8579124732334e+49*cos(theta)**22 - 7.25470089359249e+49*cos(theta)**20 + 7.74378185271108e+49*cos(theta)**18 - 4.53945832745132e+49*cos(theta)**16 + 1.60216176262988e+49*cos(theta)**14 - 3.51317398552576e+48*cos(theta)**12 + 4.77097701738066e+47*cos(theta)**10 - 3.88235019497522e+46*cos(theta)**8 + 1.76470463407965e+45*cos(theta)**6 - 3.92156585351032e+43*cos(theta)**4 + 3.22320481110438e+41*cos(theta)**2 - 4.12702280551136e+38)*cos(24*phi)

#@torch.jit.script
def Yl46_m25(theta, phi):
    return 2.98189127114901e-41*(1.0 - cos(theta)**2)**12.5*(6.28740744111349e+50*cos(theta)**21 - 1.4509401787185e+51*cos(theta)**19 + 1.39388073348799e+51*cos(theta)**17 - 7.26313332392212e+50*cos(theta)**15 + 2.24302646768183e+50*cos(theta)**13 - 4.21580878263091e+49*cos(theta)**11 + 4.77097701738066e+48*cos(theta)**9 - 3.10588015598018e+47*cos(theta)**7 + 1.05882278044779e+46*cos(theta)**5 - 1.56862634140413e+44*cos(theta)**3 + 6.44640962220875e+41*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl46_m26(theta, phi):
    return 7.66859687268355e-43*(1.0 - cos(theta)**2)**13*(1.32035556263383e+52*cos(theta)**20 - 2.75678633956514e+52*cos(theta)**18 + 2.36959724692959e+52*cos(theta)**16 - 1.08946999858832e+52*cos(theta)**14 + 2.91593440798638e+51*cos(theta)**12 - 4.637389660894e+50*cos(theta)**10 + 4.29387931564259e+49*cos(theta)**8 - 2.17411610918612e+48*cos(theta)**6 + 5.29411390223894e+46*cos(theta)**4 - 4.70587902421239e+44*cos(theta)**2 + 6.44640962220875e+41)*cos(26*phi)

#@torch.jit.script
def Yl46_m27(theta, phi):
    return 2.00696352793153e-44*(1.0 - cos(theta)**2)**13.5*(2.64071112526766e+53*cos(theta)**19 - 4.96221541121726e+53*cos(theta)**17 + 3.79135559508734e+53*cos(theta)**15 - 1.52525799802364e+53*cos(theta)**13 + 3.49912128958366e+52*cos(theta)**11 - 4.637389660894e+51*cos(theta)**9 + 3.43510345251407e+50*cos(theta)**7 - 1.30446966551167e+49*cos(theta)**5 + 2.11764556089557e+47*cos(theta)**3 - 9.41175804842478e+44*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl46_m28(theta, phi):
    return 5.35237852927822e-46*(1.0 - cos(theta)**2)**14*(5.01735113800856e+54*cos(theta)**18 - 8.43576619906934e+54*cos(theta)**16 + 5.68703339263102e+54*cos(theta)**14 - 1.98283539743074e+54*cos(theta)**12 + 3.84903341854202e+53*cos(theta)**10 - 4.1736506948046e+52*cos(theta)**8 + 2.40457241675985e+51*cos(theta)**6 - 6.52234832755837e+49*cos(theta)**4 + 6.35293668268672e+47*cos(theta)**2 - 9.41175804842478e+44)*cos(28*phi)

#@torch.jit.script
def Yl46_m29(theta, phi):
    return 1.45673292299555e-47*(1.0 - cos(theta)**2)**14.5*(9.03123204841541e+55*cos(theta)**17 - 1.34972259185109e+56*cos(theta)**15 + 7.96184674968342e+55*cos(theta)**13 - 2.37940247691689e+55*cos(theta)**11 + 3.84903341854202e+54*cos(theta)**9 - 3.33892055584368e+53*cos(theta)**7 + 1.44274345005591e+52*cos(theta)**5 - 2.60893933102335e+50*cos(theta)**3 + 1.27058733653734e+48*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl46_m30(theta, phi):
    return 4.05273940238151e-49*(1.0 - cos(theta)**2)**15*(1.53530944823062e+57*cos(theta)**16 - 2.02458388777664e+57*cos(theta)**14 + 1.03504007745885e+57*cos(theta)**12 - 2.61734272460857e+56*cos(theta)**10 + 3.46413007668782e+55*cos(theta)**8 - 2.33724438909058e+54*cos(theta)**6 + 7.21371725027956e+52*cos(theta)**4 - 7.82681799307004e+50*cos(theta)**2 + 1.27058733653734e+48)*cos(30*phi)

#@torch.jit.script
def Yl46_m31(theta, phi):
    return 1.15463129634021e-50*(1.0 - cos(theta)**2)**15.5*(2.45649511716899e+58*cos(theta)**15 - 2.8344174428873e+58*cos(theta)**13 + 1.24204809295061e+58*cos(theta)**11 - 2.61734272460857e+57*cos(theta)**9 + 2.77130406135025e+56*cos(theta)**7 - 1.40234663345435e+55*cos(theta)**5 + 2.88548690011182e+53*cos(theta)**3 - 1.56536359861401e+51*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl46_m32(theta, phi):
    return 3.37559545932685e-52*(1.0 - cos(theta)**2)**16*(3.68474267575349e+59*cos(theta)**14 - 3.68474267575349e+59*cos(theta)**12 + 1.36625290224568e+59*cos(theta)**10 - 2.35560845214772e+58*cos(theta)**8 + 1.93991284294518e+57*cos(theta)**6 - 7.01173316727173e+55*cos(theta)**4 + 8.65646070033547e+53*cos(theta)**2 - 1.56536359861401e+51)*cos(32*phi)

#@torch.jit.script
def Yl46_m33(theta, phi):
    return 1.01501586519763e-53*(1.0 - cos(theta)**2)**16.5*(5.15863974605488e+60*cos(theta)**13 - 4.42169121090419e+60*cos(theta)**11 + 1.36625290224568e+60*cos(theta)**9 - 1.88448676171817e+59*cos(theta)**7 + 1.16394770576711e+58*cos(theta)**5 - 2.80469326690869e+56*cos(theta)**3 + 1.73129214006709e+54*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl46_m34(theta, phi):
    return 3.14743058609061e-55*(1.0 - cos(theta)**2)**17*(6.70623166987135e+61*cos(theta)**12 - 4.86386033199461e+61*cos(theta)**10 + 1.22962761202111e+61*cos(theta)**8 - 1.31914073320272e+60*cos(theta)**6 + 5.81973852883553e+58*cos(theta)**4 - 8.41407980072607e+56*cos(theta)**2 + 1.73129214006709e+54)*cos(34*phi)

#@torch.jit.script
def Yl46_m35(theta, phi):
    return 1.00953883118615e-56*(1.0 - cos(theta)**2)**17.5*(8.04747800384562e+62*cos(theta)**11 - 4.8638603319946e+62*cos(theta)**9 + 9.83702089616886e+61*cos(theta)**7 - 7.91484439921633e+60*cos(theta)**5 + 2.32789541153421e+59*cos(theta)**3 - 1.68281596014521e+57*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl46_m36(theta, phi):
    return 3.36139662478243e-58*(1.0 - cos(theta)**2)**18*(8.85222580423018e+63*cos(theta)**10 - 4.37747429879514e+63*cos(theta)**8 + 6.88591462731821e+62*cos(theta)**6 - 3.95742219960816e+61*cos(theta)**4 + 6.98368623460264e+59*cos(theta)**2 - 1.68281596014521e+57)*cos(36*phi)

#@torch.jit.script
def Yl46_m37(theta, phi):
    return 1.16675780150007e-59*(1.0 - cos(theta)**2)**18.5*(8.85222580423018e+64*cos(theta)**9 - 3.50197943903612e+64*cos(theta)**7 + 4.13154877639092e+63*cos(theta)**5 - 1.58296887984327e+62*cos(theta)**3 + 1.39673724692053e+60*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl46_m38(theta, phi):
    return 4.24345709766218e-61*(1.0 - cos(theta)**2)**19*(7.96700322380716e+65*cos(theta)**8 - 2.45138560732528e+65*cos(theta)**6 + 2.06577438819546e+64*cos(theta)**4 - 4.7489066395298e+62*cos(theta)**2 + 1.39673724692053e+60)*cos(38*phi)

#@torch.jit.script
def Yl46_m39(theta, phi):
    return 1.62729151279139e-62*(1.0 - cos(theta)**2)**19.5*(6.37360257904573e+66*cos(theta)**7 - 1.47083136439517e+66*cos(theta)**5 + 8.26309755278185e+64*cos(theta)**3 - 9.49781327905959e+62*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl46_m40(theta, phi):
    return 6.63234506965458e-64*(1.0 - cos(theta)**2)**20*(4.46152180533201e+67*cos(theta)**6 - 7.35415682197584e+66*cos(theta)**4 + 2.47892926583455e+65*cos(theta)**2 - 9.49781327905959e+62)*cos(40*phi)

#@torch.jit.script
def Yl46_m41(theta, phi):
    return 2.9028985753037e-65*(1.0 - cos(theta)**2)**20.5*(2.67691308319921e+68*cos(theta)**5 - 2.94166272879034e+67*cos(theta)**3 + 4.95785853166911e+65*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl46_m42(theta, phi):
    return 1.3839025959632e-66*(1.0 - cos(theta)**2)**21*(1.3384565415996e+69*cos(theta)**4 - 8.82498818637101e+67*cos(theta)**2 + 4.95785853166911e+65)*cos(42*phi)

#@torch.jit.script
def Yl46_m43(theta, phi):
    return 7.33466908928147e-68*(1.0 - cos(theta)**2)**21.5*(5.35382616639841e+69*cos(theta)**3 - 1.7649976372742e+68*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl46_m44(theta, phi):
    return 4.46373745781704e-69*(1.0 - cos(theta)**2)**22*(1.60614784991952e+70*cos(theta)**2 - 1.7649976372742e+68)*cos(44*phi)

#@torch.jit.script
def Yl46_m45(theta, phi):
    return 10.6286587918185*(1.0 - cos(theta)**2)**22.5*cos(45*phi)*cos(theta)

#@torch.jit.script
def Yl46_m46(theta, phi):
    return 1.1081142800943*(1.0 - cos(theta)**2)**23*cos(46*phi)

#@torch.jit.script
def Yl47_m_minus_47(theta, phi):
    return 1.11399291169174*(1.0 - cos(theta)**2)**23.5*sin(47*phi)

#@torch.jit.script
def Yl47_m_minus_46(theta, phi):
    return 10.8005619986252*(1.0 - cos(theta)**2)**23*sin(46*phi)*cos(theta)

#@torch.jit.script
def Yl47_m_minus_45(theta, phi):
    return 4.93065211209231e-71*(1.0 - cos(theta)**2)**22.5*(1.49371750042516e+72*cos(theta)**2 - 1.60614784991952e+70)*sin(45*phi)

#@torch.jit.script
def Yl47_m_minus_44(theta, phi):
    return 8.19141449881068e-70*(1.0 - cos(theta)**2)**22*(4.97905833475052e+71*cos(theta)**3 - 1.60614784991952e+70*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl47_m_minus_43(theta, phi):
    return 1.56282228109413e-68*(1.0 - cos(theta)**2)**21.5*(1.24476458368763e+71*cos(theta)**4 - 8.03073924959762e+69*cos(theta)**2 + 4.41249409318551e+67)*sin(43*phi)

#@torch.jit.script
def Yl47_m_minus_42(theta, phi):
    return 3.31524669825326e-67*(1.0 - cos(theta)**2)**21*(2.48952916737526e+70*cos(theta)**5 - 2.67691308319921e+69*cos(theta)**3 + 4.41249409318551e+67*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl47_m_minus_41(theta, phi):
    return 7.66101794667593e-66*(1.0 - cos(theta)**2)**20.5*(4.14921527895877e+69*cos(theta)**6 - 6.69228270799802e+68*cos(theta)**4 + 2.20624704659275e+67*cos(theta)**2 - 8.26309755278185e+64)*sin(41*phi)

#@torch.jit.script
def Yl47_m_minus_40(theta, phi):
    return 1.90141465028655e-64*(1.0 - cos(theta)**2)**20*(5.92745039851253e+68*cos(theta)**7 - 1.3384565415996e+68*cos(theta)**5 + 7.35415682197584e+66*cos(theta)**3 - 8.26309755278185e+64*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl47_m_minus_39(theta, phi):
    return 5.01627636792244e-63*(1.0 - cos(theta)**2)**19.5*(7.40931299814066e+67*cos(theta)**8 - 2.23076090266601e+67*cos(theta)**6 + 1.83853920549396e+66*cos(theta)**4 - 4.13154877639092e+64*cos(theta)**2 + 1.18722665988245e+62)*sin(39*phi)

#@torch.jit.script
def Yl47_m_minus_38(theta, phi):
    return 1.39557099912251e-61*(1.0 - cos(theta)**2)**19*(8.23256999793407e+66*cos(theta)**9 - 3.18680128952287e+66*cos(theta)**7 + 3.67707841098792e+65*cos(theta)**5 - 1.37718292546364e+64*cos(theta)**3 + 1.18722665988245e+62*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl47_m_minus_37(theta, phi):
    return 4.06875368086227e-60*(1.0 - cos(theta)**2)**18.5*(8.23256999793407e+65*cos(theta)**10 - 3.98350161190358e+65*cos(theta)**8 + 6.1284640183132e+64*cos(theta)**6 - 3.4429573136591e+63*cos(theta)**4 + 5.93613329941225e+61*cos(theta)**2 - 1.39673724692053e+59)*sin(37*phi)

#@torch.jit.script
def Yl47_m_minus_36(theta, phi):
    return 1.23679404188207e-58*(1.0 - cos(theta)**2)**18*(7.48415454357643e+64*cos(theta)**11 - 4.42611290211509e+64*cos(theta)**9 + 8.75494859759029e+63*cos(theta)**7 - 6.88591462731821e+62*cos(theta)**5 + 1.97871109980408e+61*cos(theta)**3 - 1.39673724692053e+59*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl47_m_minus_35(theta, phi):
    return 3.90325615867939e-57*(1.0 - cos(theta)**2)**17.5*(6.23679545298036e+63*cos(theta)**12 - 4.42611290211509e+63*cos(theta)**10 + 1.09436857469879e+63*cos(theta)**8 - 1.14765243788637e+62*cos(theta)**6 + 4.94677774951021e+60*cos(theta)**4 - 6.98368623460264e+58*cos(theta)**2 + 1.40234663345435e+56)*sin(35*phi)

#@torch.jit.script
def Yl47_m_minus_34(theta, phi):
    return 1.27439968653976e-55*(1.0 - cos(theta)**2)**17*(4.79753496383104e+62*cos(theta)**13 - 4.02373900192281e+62*cos(theta)**11 + 1.21596508299865e+62*cos(theta)**9 - 1.63950348269481e+61*cos(theta)**7 + 9.89355549902041e+59*cos(theta)**5 - 2.32789541153421e+58*cos(theta)**3 + 1.40234663345435e+56*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl47_m_minus_33(theta, phi):
    return 4.29153030075948e-54*(1.0 - cos(theta)**2)**16.5*(3.42681068845074e+61*cos(theta)**14 - 3.35311583493567e+61*cos(theta)**12 + 1.21596508299865e+61*cos(theta)**10 - 2.04937935336851e+60*cos(theta)**8 + 1.6489259165034e+59*cos(theta)**6 - 5.81973852883553e+57*cos(theta)**4 + 7.01173316727173e+55*cos(theta)**2 - 1.23663724290507e+53)*sin(33*phi)

#@torch.jit.script
def Yl47_m_minus_32(theta, phi):
    return 1.48662970462735e-52*(1.0 - cos(theta)**2)**16*(2.28454045896716e+60*cos(theta)**15 - 2.57931987302744e+60*cos(theta)**13 + 1.10542280272605e+60*cos(theta)**11 - 2.27708817040946e+59*cos(theta)**9 + 2.35560845214772e+58*cos(theta)**7 - 1.16394770576711e+57*cos(theta)**5 + 2.33724438909058e+55*cos(theta)**3 - 1.23663724290507e+53*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl47_m_minus_31(theta, phi):
    return 5.28538153651375e-51*(1.0 - cos(theta)**2)**15.5*(1.42783778685448e+59*cos(theta)**16 - 1.84237133787674e+59*cos(theta)**14 + 9.21185668938372e+58*cos(theta)**12 - 2.27708817040946e+58*cos(theta)**10 + 2.94451056518465e+57*cos(theta)**8 - 1.93991284294518e+56*cos(theta)**6 + 5.84311097272644e+54*cos(theta)**4 - 6.18318621452533e+52*cos(theta)**2 + 9.78352249133755e+49)*sin(31*phi)

#@torch.jit.script
def Yl47_m_minus_30(theta, phi):
    return 1.92463378568823e-49*(1.0 - cos(theta)**2)**15*(8.39904580502633e+57*cos(theta)**17 - 1.2282475585845e+58*cos(theta)**15 + 7.08604360721825e+57*cos(theta)**13 - 2.07008015491769e+57*cos(theta)**11 + 3.27167840576072e+56*cos(theta)**9 - 2.77130406135025e+55*cos(theta)**7 + 1.16862219454529e+54*cos(theta)**5 - 2.06106207150844e+52*cos(theta)**3 + 9.78352249133755e+49*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl47_m_minus_29(theta, phi):
    return 7.16522315053166e-48*(1.0 - cos(theta)**2)**14.5*(4.66613655834796e+56*cos(theta)**18 - 7.6765472411531e+56*cos(theta)**16 + 5.06145971944161e+56*cos(theta)**14 - 1.72506679576474e+56*cos(theta)**12 + 3.27167840576072e+55*cos(theta)**10 - 3.46413007668782e+54*cos(theta)**8 + 1.94770365757548e+53*cos(theta)**6 - 5.15265517877111e+51*cos(theta)**4 + 4.89176124566878e+49*cos(theta)**2 - 7.05881853631858e+46)*sin(29*phi)

#@torch.jit.script
def Yl47_m_minus_28(theta, phi):
    return 2.72278479720203e-46*(1.0 - cos(theta)**2)**14*(2.45586134649893e+55*cos(theta)**19 - 4.51561602420771e+55*cos(theta)**17 + 3.37430647962774e+55*cos(theta)**15 - 1.32697445828057e+55*cos(theta)**13 + 2.97425309614611e+54*cos(theta)**11 - 3.84903341854202e+53*cos(theta)**9 + 2.7824337965364e+52*cos(theta)**7 - 1.03053103575422e+51*cos(theta)**5 + 1.63058708188959e+49*cos(theta)**3 - 7.05881853631858e+46*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl47_m_minus_27(theta, phi):
    return 1.05453001748702e-44*(1.0 - cos(theta)**2)**13.5*(1.22793067324946e+54*cos(theta)**20 - 2.50867556900428e+54*cos(theta)**18 + 2.10894154976734e+54*cos(theta)**16 - 9.47838898771836e+53*cos(theta)**14 + 2.47854424678842e+53*cos(theta)**12 - 3.84903341854202e+52*cos(theta)**10 + 3.4780422456705e+51*cos(theta)**8 - 1.71755172625704e+50*cos(theta)**6 + 4.07646770472398e+48*cos(theta)**4 - 3.52940926815929e+46*cos(theta)**2 + 4.70587902421239e+43)*sin(27*phi)

#@torch.jit.script
def Yl47_m_minus_26(theta, phi):
    return 4.15704239669497e-43*(1.0 - cos(theta)**2)**13*(5.84728892023554e+52*cos(theta)**21 - 1.32035556263383e+53*cos(theta)**19 + 1.24055385280432e+53*cos(theta)**17 - 6.31892599181224e+52*cos(theta)**15 + 1.90657249752956e+52*cos(theta)**13 - 3.49912128958366e+51*cos(theta)**11 + 3.86449138407833e+50*cos(theta)**9 - 2.45364532322434e+49*cos(theta)**7 + 8.15293540944796e+47*cos(theta)**5 - 1.1764697560531e+46*cos(theta)**3 + 4.70587902421239e+43*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl47_m_minus_25(theta, phi):
    return 1.66593182302274e-41*(1.0 - cos(theta)**2)**12.5*(2.65785860010707e+51*cos(theta)**22 - 6.60177781316916e+51*cos(theta)**20 + 6.89196584891286e+51*cos(theta)**18 - 3.94932874488265e+51*cos(theta)**16 + 1.3618374982354e+51*cos(theta)**14 - 2.91593440798638e+50*cos(theta)**12 + 3.86449138407833e+49*cos(theta)**10 - 3.06705665403042e+48*cos(theta)**8 + 1.35882256824133e+47*cos(theta)**6 - 2.94117439013274e+45*cos(theta)**4 + 2.35293951210619e+43*cos(theta)**2 - 2.93018619191307e+40)*sin(25*phi)

#@torch.jit.script
def Yl47_m_minus_24(theta, phi):
    return 6.77933961187779e-40*(1.0 - cos(theta)**2)**12*(1.15559069569872e+50*cos(theta)**23 - 3.14370372055674e+50*cos(theta)**21 + 3.62735044679624e+50*cos(theta)**19 - 2.32313455581332e+50*cos(theta)**17 + 9.07891665490265e+49*cos(theta)**15 - 2.24302646768183e+49*cos(theta)**13 + 3.51317398552576e+48*cos(theta)**11 - 3.40784072670047e+47*cos(theta)**9 + 1.94117509748761e+46*cos(theta)**7 - 5.88234878026548e+44*cos(theta)**5 + 7.84313170702065e+42*cos(theta)**3 - 2.93018619191307e+40*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl47_m_minus_23(theta, phi):
    return 2.79847985979336e-38*(1.0 - cos(theta)**2)**11.5*(4.81496123207802e+48*cos(theta)**24 - 1.4289562366167e+49*cos(theta)**22 + 1.81367522339812e+49*cos(theta)**20 - 1.29063030878518e+49*cos(theta)**18 + 5.67432290931415e+48*cos(theta)**16 - 1.60216176262988e+48*cos(theta)**14 + 2.92764498793813e+47*cos(theta)**12 - 3.40784072670047e+46*cos(theta)**10 + 2.42646887185951e+45*cos(theta)**8 - 9.80391463377581e+43*cos(theta)**6 + 1.96078292675516e+42*cos(theta)**4 - 1.46509309595653e+40*cos(theta)**2 + 1.71959283562973e+37)*sin(23*phi)

#@torch.jit.script
def Yl47_m_minus_22(theta, phi):
    return 1.1706881168749e-36*(1.0 - cos(theta)**2)**11*(1.92598449283121e+47*cos(theta)**25 - 6.21285320268131e+47*cos(theta)**23 + 8.6365486828482e+47*cos(theta)**21 - 6.79279109886937e+47*cos(theta)**19 + 3.33783700547891e+47*cos(theta)**17 - 1.06810784175325e+47*cos(theta)**15 + 2.25203460610626e+46*cos(theta)**13 - 3.09803702427316e+45*cos(theta)**11 + 2.69607652428835e+44*cos(theta)**9 - 1.40055923339654e+43*cos(theta)**7 + 3.92156585351032e+41*cos(theta)**5 - 4.88364365318845e+39*cos(theta)**3 + 1.71959283562973e+37*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl47_m_minus_21(theta, phi):
    return 4.95852411165239e-35*(1.0 - cos(theta)**2)**10.5*(7.40763266473541e+45*cos(theta)**26 - 2.58868883445055e+46*cos(theta)**24 + 3.92570394674918e+46*cos(theta)**22 - 3.39639554943468e+46*cos(theta)**20 + 1.85435389193273e+46*cos(theta)**18 - 6.67567401095783e+45*cos(theta)**16 + 1.60859614721875e+45*cos(theta)**14 - 2.58169752022763e+44*cos(theta)**12 + 2.69607652428835e+43*cos(theta)**10 - 1.75069904174568e+42*cos(theta)**8 + 6.53594308918387e+40*cos(theta)**6 - 1.22091091329711e+39*cos(theta)**4 + 8.59796417814867e+36*cos(theta)**2 - 9.58524434576218e+33)*sin(21*phi)

#@torch.jit.script
def Yl47_m_minus_20(theta, phi):
    return 2.12465670327417e-33*(1.0 - cos(theta)**2)**10*(2.74356765360571e+44*cos(theta)**27 - 1.03547553378022e+45*cos(theta)**25 + 1.70682780293443e+45*cos(theta)**23 - 1.61733121401652e+45*cos(theta)**21 + 9.75975732596174e+44*cos(theta)**19 - 3.92686706526931e+44*cos(theta)**17 + 1.07239743147917e+44*cos(theta)**15 - 1.98592116940587e+43*cos(theta)**13 + 2.45097865844395e+42*cos(theta)**11 - 1.9452211574952e+41*cos(theta)**9 + 9.33706155597696e+39*cos(theta)**7 - 2.44182182659422e+38*cos(theta)**5 + 2.86598805938289e+36*cos(theta)**3 - 9.58524434576218e+33*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl47_m_minus_19(theta, phi):
    return 9.20248641199569e-32*(1.0 - cos(theta)**2)**9.5*(9.79845590573467e+42*cos(theta)**28 - 3.98259820684699e+43*cos(theta)**26 + 7.11178251222678e+43*cos(theta)**24 - 7.35150551825689e+43*cos(theta)**22 + 4.87987866298087e+43*cos(theta)**20 - 2.18159281403851e+43*cos(theta)**18 + 6.70248394674481e+42*cos(theta)**16 - 1.41851512100419e+42*cos(theta)**14 + 2.04248221536996e+41*cos(theta)**12 - 1.9452211574952e+40*cos(theta)**10 + 1.16713269449712e+39*cos(theta)**8 - 4.06970304432371e+37*cos(theta)**6 + 7.16497014845723e+35*cos(theta)**4 - 4.79262217288109e+33*cos(theta)**2 + 5.10940530157899e+30)*sin(19*phi)

#@torch.jit.script
def Yl47_m_minus_18(theta, phi):
    return 4.02602207266572e-30*(1.0 - cos(theta)**2)**9*(3.3787778985292e+41*cos(theta)**29 - 1.47503637290629e+42*cos(theta)**27 + 2.84471300489071e+42*cos(theta)**25 - 3.19630674706821e+42*cos(theta)**23 + 2.3237517442766e+42*cos(theta)**21 - 1.14820674423079e+42*cos(theta)**19 + 3.94263761573224e+41*cos(theta)**17 - 9.45676747336128e+40*cos(theta)**15 + 1.5711401656692e+40*cos(theta)**13 - 1.76838287045018e+39*cos(theta)**11 + 1.2968141049968e+38*cos(theta)**9 - 5.81386149189101e+36*cos(theta)**7 + 1.43299402969145e+35*cos(theta)**5 - 1.5975407242937e+33*cos(theta)**3 + 5.10940530157899e+30*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl47_m_minus_17(theta, phi):
    return 1.77784320941706e-28*(1.0 - cos(theta)**2)**8.5*(1.12625929950973e+40*cos(theta)**30 - 5.26798704609391e+40*cos(theta)**28 + 1.09412038649643e+41*cos(theta)**26 - 1.33179447794509e+41*cos(theta)**24 + 1.056250792853e+41*cos(theta)**22 - 5.74103372115396e+40*cos(theta)**20 + 2.19035423096236e+40*cos(theta)**18 - 5.9104796708508e+39*cos(theta)**16 + 1.122242975478e+39*cos(theta)**14 - 1.47365239204182e+38*cos(theta)**12 + 1.2968141049968e+37*cos(theta)**10 - 7.26732686486376e+35*cos(theta)**8 + 2.38832338281908e+34*cos(theta)**6 - 3.99385181073424e+32*cos(theta)**4 + 2.55470265078949e+30*cos(theta)**2 - 2.62020784696358e+27)*sin(17*phi)

#@torch.jit.script
def Yl47_m_minus_16(theta, phi):
    return 7.91888965127333e-27*(1.0 - cos(theta)**2)**8*(3.63309451454752e+38*cos(theta)**31 - 1.81654725727376e+39*cos(theta)**29 + 4.05229772776454e+39*cos(theta)**27 - 5.32717791178036e+39*cos(theta)**25 + 4.59239475153479e+39*cos(theta)**23 - 2.73382558150189e+39*cos(theta)**21 + 1.15281801629598e+39*cos(theta)**19 - 3.47675274755929e+38*cos(theta)**17 + 7.48161983652e+37*cos(theta)**15 - 1.13357876310909e+37*cos(theta)**13 + 1.17892191363345e+36*cos(theta)**11 - 8.0748076276264e+34*cos(theta)**9 + 3.41189054688439e+33*cos(theta)**7 - 7.98770362146848e+31*cos(theta)**5 + 8.51567550263164e+29*cos(theta)**3 - 2.62020784696358e+27*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl47_m_minus_15(theta, phi):
    return 3.55557263504815e-25*(1.0 - cos(theta)**2)**7.5*(1.1353420357961e+37*cos(theta)**32 - 6.05515752424587e+37*cos(theta)**30 + 1.44724918848734e+38*cos(theta)**28 - 2.04891458145398e+38*cos(theta)**26 + 1.9134978131395e+38*cos(theta)**24 - 1.24264799159177e+38*cos(theta)**22 + 5.76409008147988e+37*cos(theta)**20 - 1.93152930419961e+37*cos(theta)**18 + 4.676012397825e+36*cos(theta)**16 - 8.09699116506493e+35*cos(theta)**14 + 9.82434928027879e+34*cos(theta)**12 - 8.0748076276264e+33*cos(theta)**10 + 4.26486318360549e+32*cos(theta)**8 - 1.33128393691141e+31*cos(theta)**6 + 2.12891887565791e+29*cos(theta)**4 - 1.31010392348179e+27*cos(theta)**2 + 1.29970627329543e+24)*sin(15*phi)

#@torch.jit.script
def Yl47_m_minus_14(theta, phi):
    return 1.60828262371106e-23*(1.0 - cos(theta)**2)**7*(3.44043041150334e+35*cos(theta)**33 - 1.95327662072447e+36*cos(theta)**31 + 4.99051444305978e+36*cos(theta)**29 - 7.58857252390364e+36*cos(theta)**27 + 7.65399125255798e+36*cos(theta)**25 - 5.40281735474681e+36*cos(theta)**23 + 2.74480480070471e+36*cos(theta)**21 - 1.01659437063137e+36*cos(theta)**19 + 2.75059552813235e+35*cos(theta)**17 - 5.39799411004329e+34*cos(theta)**15 + 7.55719175406061e+33*cos(theta)**13 - 7.34073420693309e+32*cos(theta)**11 + 4.73873687067277e+31*cos(theta)**9 - 1.90183419558773e+30*cos(theta)**7 + 4.25783775131582e+28*cos(theta)**5 - 4.36701307827264e+26*cos(theta)**3 + 1.29970627329543e+24*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl47_m_minus_13(theta, phi):
    return 7.32431047764493e-22*(1.0 - cos(theta)**2)**6.5*(1.01189129750098e+34*cos(theta)**34 - 6.10398943976398e+34*cos(theta)**32 + 1.66350481435326e+35*cos(theta)**30 - 2.71020447282273e+35*cos(theta)**28 + 2.94384278944538e+35*cos(theta)**26 - 2.25117389781117e+35*cos(theta)**24 + 1.24763854577487e+35*cos(theta)**22 - 5.08297185315686e+34*cos(theta)**20 + 1.5281086267402e+34*cos(theta)**18 - 3.37374631877706e+33*cos(theta)**16 + 5.39799411004329e+32*cos(theta)**14 - 6.11727850577758e+31*cos(theta)**12 + 4.73873687067277e+30*cos(theta)**10 - 2.37729274448467e+29*cos(theta)**8 + 7.09639625219304e+27*cos(theta)**6 - 1.09175326956816e+26*cos(theta)**4 + 6.49853136647714e+23*cos(theta)**2 - 6.2666647699876e+20)*sin(13*phi)

#@torch.jit.script
def Yl47_m_minus_12(theta, phi):
    return 3.35642071771661e-20*(1.0 - cos(theta)**2)**6*(2.89111799285995e+32*cos(theta)**35 - 1.84969376962545e+33*cos(theta)**33 + 5.36614456242988e+33*cos(theta)**31 - 9.34553266490596e+33*cos(theta)**29 + 1.09031214423903e+34*cos(theta)**27 - 9.00469559124469e+33*cos(theta)**25 + 5.42451541641246e+33*cos(theta)**23 - 2.42046278721755e+33*cos(theta)**21 + 8.04267698284314e+32*cos(theta)**19 - 1.98455665810415e+32*cos(theta)**17 + 3.59866274002886e+31*cos(theta)**15 - 4.70559885059814e+30*cos(theta)**13 + 4.30794260970252e+29*cos(theta)**11 - 2.64143638276074e+28*cos(theta)**9 + 1.01377089317043e+27*cos(theta)**7 - 2.18350653913632e+25*cos(theta)**5 + 2.16617712215905e+23*cos(theta)**3 - 6.2666647699876e+20*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl47_m_minus_11(theta, phi):
    return 1.54686940343682e-18*(1.0 - cos(theta)**2)**5.5*(8.03088331349985e+30*cos(theta)**36 - 5.44027579301603e+31*cos(theta)**34 + 1.67692017575934e+32*cos(theta)**32 - 3.11517755496865e+32*cos(theta)**30 + 3.89397194371082e+32*cos(theta)**28 - 3.46334445817103e+32*cos(theta)**26 + 2.26021475683853e+32*cos(theta)**24 - 1.10021035782616e+32*cos(theta)**22 + 4.02133849142157e+31*cos(theta)**20 - 1.10253147672453e+31*cos(theta)**18 + 2.24916421251804e+30*cos(theta)**16 - 3.36114203614153e+29*cos(theta)**14 + 3.5899521747521e+28*cos(theta)**12 - 2.64143638276074e+27*cos(theta)**10 + 1.26721361646304e+26*cos(theta)**8 - 3.6391775652272e+24*cos(theta)**6 + 5.41544280539762e+22*cos(theta)**4 - 3.1333323849938e+20*cos(theta)**2 + 2.95040714217872e+17)*sin(11*phi)

#@torch.jit.script
def Yl47_m_minus_10(theta, phi):
    return 7.16586312000596e-17*(1.0 - cos(theta)**2)**5*(2.17050900364861e+29*cos(theta)**37 - 1.55436451229029e+30*cos(theta)**35 + 5.08157629017981e+30*cos(theta)**33 - 1.00489598547376e+31*cos(theta)**31 + 1.34274894610718e+31*cos(theta)**29 - 1.28272016969298e+31*cos(theta)**27 + 9.0408590273541e+30*cos(theta)**25 - 4.78352329489635e+30*cos(theta)**23 + 1.91492309115313e+30*cos(theta)**21 - 5.80279724591857e+29*cos(theta)**19 + 1.32303777206943e+29*cos(theta)**17 - 2.24076135742768e+28*cos(theta)**15 + 2.76150167288623e+27*cos(theta)**13 - 2.40130580250977e+26*cos(theta)**11 + 1.40801512940338e+25*cos(theta)**9 - 5.19882509318171e+23*cos(theta)**7 + 1.08308856107952e+22*cos(theta)**5 - 1.04444412833127e+20*cos(theta)**3 + 2.95040714217872e+17*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl47_m_minus_9(theta, phi):
    return 3.33501456002215e-15*(1.0 - cos(theta)**2)**4.5*(5.71186579907529e+27*cos(theta)**38 - 4.31767920080637e+28*cos(theta)**36 + 1.49458126181759e+29*cos(theta)**34 - 3.1402999546055e+29*cos(theta)**32 + 4.47582982035726e+29*cos(theta)**30 - 4.5811434631892e+29*cos(theta)**28 + 3.47725347205927e+29*cos(theta)**26 - 1.99313470620681e+29*cos(theta)**24 + 8.70419586887785e+28*cos(theta)**22 - 2.90139862295928e+28*cos(theta)**20 + 7.35020984483019e+27*cos(theta)**18 - 1.4004758483923e+27*cos(theta)**16 + 1.97250119491874e+26*cos(theta)**14 - 2.00108816875814e+25*cos(theta)**12 + 1.40801512940338e+24*cos(theta)**10 - 6.49853136647714e+22*cos(theta)**8 + 1.80514760179921e+21*cos(theta)**6 - 2.61111032082817e+19*cos(theta)**4 + 1.47520357108936e+17*cos(theta)**2 - 136214549500403.0)*sin(9*phi)

#@torch.jit.script
def Yl47_m_minus_8(theta, phi):
    return 1.55856188521285e-13*(1.0 - cos(theta)**2)**4*(1.46458097412187e+26*cos(theta)**39 - 1.16694032454226e+27*cos(theta)**37 + 4.27023217662169e+27*cos(theta)**35 - 9.51606046850151e+27*cos(theta)**33 + 1.44381607108299e+28*cos(theta)**31 - 1.57970464247903e+28*cos(theta)**29 + 1.28787165631825e+28*cos(theta)**27 - 7.97253882482725e+27*cos(theta)**25 + 3.78443298646863e+27*cos(theta)**23 - 1.38161839188537e+27*cos(theta)**21 + 3.86853149727905e+26*cos(theta)**19 - 8.23809322583707e+25*cos(theta)**17 + 1.31500079661249e+25*cos(theta)**15 - 1.53929859135241e+24*cos(theta)**13 + 1.28001375400307e+23*cos(theta)**11 - 7.22059040719682e+21*cos(theta)**9 + 2.57878228828458e+20*cos(theta)**7 - 5.22222064165633e+18*cos(theta)**5 + 4.91734523696453e+16*cos(theta)**3 - 136214549500403.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl47_m_minus_7(theta, phi):
    return 7.31030322906247e-12*(1.0 - cos(theta)**2)**3.5*(3.66145243530467e+24*cos(theta)**40 - 3.07089559090069e+25*cos(theta)**38 + 1.18617560461714e+26*cos(theta)**36 - 2.79884131426515e+26*cos(theta)**34 + 4.51192522213434e+26*cos(theta)**32 - 5.26568214159678e+26*cos(theta)**30 + 4.59954162970803e+26*cos(theta)**28 - 3.06636108647202e+26*cos(theta)**26 + 1.57684707769526e+26*cos(theta)**24 - 6.28008359947897e+25*cos(theta)**22 + 1.93426574863952e+25*cos(theta)**20 - 4.57671845879837e+24*cos(theta)**18 + 8.21875497882807e+23*cos(theta)**16 - 1.09949899382315e+23*cos(theta)**14 + 1.06667812833589e+22*cos(theta)**12 - 7.22059040719682e+20*cos(theta)**10 + 3.22347786035572e+19*cos(theta)**8 - 8.70370106942722e+17*cos(theta)**6 + 1.22933630924113e+16*cos(theta)**4 - 68107274750201.3*cos(theta)**2 + 61915704318.3648)*sin(7*phi)

#@torch.jit.script
def Yl47_m_minus_6(theta, phi):
    return 3.43972877896009e-10*(1.0 - cos(theta)**2)**3*(8.93037179342602e+22*cos(theta)**41 - 7.87409125871972e+23*cos(theta)**39 + 3.20588001247874e+24*cos(theta)**37 - 7.996689469329e+24*cos(theta)**35 + 1.36725006731344e+25*cos(theta)**33 - 1.69860714245057e+25*cos(theta)**31 + 1.58604883783036e+25*cos(theta)**29 - 1.13568929128593e+25*cos(theta)**27 + 6.30738831078105e+24*cos(theta)**25 - 2.73047113020825e+24*cos(theta)**23 + 9.21078927923582e+23*cos(theta)**21 - 2.40879918884125e+23*cos(theta)**19 + 4.8345617522518e+22*cos(theta)**17 - 7.32999329215435e+21*cos(theta)**15 + 8.20521637181457e+20*cos(theta)**13 - 6.56417309745166e+19*cos(theta)**11 + 3.58164206706192e+18*cos(theta)**9 - 1.24338586706103e+17*cos(theta)**7 + 2.45867261848227e+15*cos(theta)**5 - 22702424916733.8*cos(theta)**3 + 61915704318.3648*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl47_m_minus_5(theta, phi):
    return 1.62288138956816e-8*(1.0 - cos(theta)**2)**2.5*(2.12627899843477e+21*cos(theta)**42 - 1.96852281467993e+22*cos(theta)**40 + 8.43652634862827e+22*cos(theta)**38 - 2.22130263036917e+23*cos(theta)**36 + 4.02132372739246e+23*cos(theta)**34 - 5.30814732015804e+23*cos(theta)**32 + 5.28682945943452e+23*cos(theta)**30 - 4.05603318316405e+23*cos(theta)**28 + 2.42591858106964e+23*cos(theta)**26 - 1.13769630425344e+23*cos(theta)**24 + 4.18672239965265e+22*cos(theta)**22 - 1.20439959442062e+22*cos(theta)**20 + 2.68586764013989e+21*cos(theta)**18 - 4.58124580759647e+20*cos(theta)**16 + 5.86086883701041e+19*cos(theta)**14 - 5.47014424787638e+18*cos(theta)**12 + 3.58164206706192e+17*cos(theta)**10 - 1.55423233382629e+16*cos(theta)**8 + 409778769747044.0*cos(theta)**6 - 5675606229183.44*cos(theta)**4 + 30957852159.1824*cos(theta)**2 - 27814781.8141801)*sin(5*phi)

#@torch.jit.script
def Yl47_m_minus_4(theta, phi):
    return 7.67401563348715e-7*(1.0 - cos(theta)**2)**2*(4.94483488008086e+19*cos(theta)**43 - 4.80127515775593e+20*cos(theta)**41 + 2.16321188426366e+21*cos(theta)**39 - 6.00352062261937e+21*cos(theta)**37 + 1.14894963639784e+22*cos(theta)**35 - 1.60852949095698e+22*cos(theta)**33 + 1.7054288578821e+22*cos(theta)**31 - 1.39863213212553e+22*cos(theta)**29 + 8.98488363359124e+21*cos(theta)**27 - 4.55078521701375e+21*cos(theta)**25 + 1.8203140868055e+21*cos(theta)**23 - 5.73523616390774e+20*cos(theta)**21 + 1.41361454744205e+20*cos(theta)**19 - 2.69485047505675e+19*cos(theta)**17 + 3.90724589134027e+18*cos(theta)**15 - 4.20780326759722e+17*cos(theta)**13 + 3.25603824278356e+16*cos(theta)**11 - 1.72692481536254e+15*cos(theta)**9 + 58539824249577.8*cos(theta)**7 - 1135121245836.69*cos(theta)**5 + 10319284053.0608*cos(theta)**3 - 27814781.8141801*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl47_m_minus_3(theta, phi):
    return 3.63524851662309e-5*(1.0 - cos(theta)**2)**1.5*(1.12382610910929e+18*cos(theta)**44 - 1.14316075184665e+19*cos(theta)**42 + 5.40802971065915e+19*cos(theta)**40 - 1.57987384805773e+20*cos(theta)**38 + 3.19152676777179e+20*cos(theta)**36 - 4.73096909104995e+20*cos(theta)**34 + 5.32946518088157e+20*cos(theta)**32 - 4.66210710708511e+20*cos(theta)**30 + 3.20888701199687e+20*cos(theta)**28 - 1.75030200654375e+20*cos(theta)**26 + 7.58464202835625e+19*cos(theta)**24 - 2.60692552904897e+19*cos(theta)**22 + 7.06807273721024e+18*cos(theta)**20 - 1.4971391528093e+18*cos(theta)**18 + 2.44202868208767e+17*cos(theta)**16 - 3.00557376256944e+16*cos(theta)**14 + 2.71336520231963e+15*cos(theta)**12 - 172692481536254.0*cos(theta)**10 + 7317478031197.22*cos(theta)**8 - 189186874306.115*cos(theta)**6 + 2579821013.2652*cos(theta)**4 - 13907390.90709*cos(theta)**2 + 12395.1790615776)*sin(3*phi)

#@torch.jit.script
def Yl47_m_minus_2(theta, phi):
    return 0.00172434977599161*(1.0 - cos(theta)**2)*(2.49739135357619e+16*cos(theta)**45 - 2.65851337638756e+17*cos(theta)**43 + 1.31903163674613e+18*cos(theta)**41 - 4.05095858476341e+18*cos(theta)**39 + 8.62574802100484e+18*cos(theta)**37 - 1.3517054545857e+19*cos(theta)**35 + 1.61498944875199e+19*cos(theta)**33 - 1.50390551841455e+19*cos(theta)**31 + 1.10651276275754e+19*cos(theta)**29 - 6.48260002423611e+18*cos(theta)**27 + 3.0338568113425e+18*cos(theta)**25 - 1.1334458821952e+18*cos(theta)**23 + 3.36574892248107e+17*cos(theta)**21 - 7.87967975162791e+16*cos(theta)**19 + 1.43648746005157e+16*cos(theta)**17 - 2.00371584171296e+15*cos(theta)**15 + 208720400178433.0*cos(theta)**13 - 15699316503295.9*cos(theta)**11 + 813053114577.469*cos(theta)**9 - 27026696329.4449*cos(theta)**7 + 515964202.65304*cos(theta)**5 - 4635796.96903001*cos(theta)**3 + 12395.1790615776*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl47_m_minus_1(theta, phi):
    return 0.0818657643097229*(1.0 - cos(theta)**2)**0.5*(542911163820911.0*cos(theta)**46 - 6.04207585542627e+15*cos(theta)**44 + 3.14055151606222e+16*cos(theta)**42 - 1.01273964619085e+17*cos(theta)**40 + 2.26993368973812e+17*cos(theta)**38 - 3.75473737384917e+17*cos(theta)**36 + 4.74996896691762e+17*cos(theta)**34 - 4.69970474504548e+17*cos(theta)**32 + 3.68837587585847e+17*cos(theta)**30 - 2.31521429437004e+17*cos(theta)**28 + 1.1668680043625e+17*cos(theta)**26 - 4.72269117581335e+16*cos(theta)**24 + 1.52988587385503e+16*cos(theta)**22 - 3.93983987581396e+15*cos(theta)**20 + 798048588917539.0*cos(theta)**18 - 125232240107060.0*cos(theta)**16 + 14908600012745.2*cos(theta)**14 - 1308276375274.65*cos(theta)**12 + 81305311457.7469*cos(theta)**10 - 3378337041.18062*cos(theta)**8 + 85994033.7755067*cos(theta)**6 - 1158949.2422575*cos(theta)**4 + 6197.58953078878*cos(theta)**2 - 5.49919213024737)*sin(phi)

#@torch.jit.script
def Yl47_m0(theta, phi):
    return 99778657771650.4*cos(theta)**47 - 1.15979278549628e+15*cos(theta)**45 + 6.30876295407318e+15*cos(theta)**43 - 2.13363780806295e+16*cos(theta)**41 + 5.02753736382649e+16*cos(theta)**39 - 8.76565926257748e+16*cos(theta)**37 + 1.17227491342904e+17*cos(theta)**35 - 1.23016503261072e+17*cos(theta)**33 + 1.02773281205452e+17*cos(theta)**31 - 6.89604267828793e+16*cos(theta)**29 + 3.73305776984653e+16*cos(theta)**27 - 1.63175999653317e+16*cos(theta)**25 + 5.74563379060974e+15*cos(theta)**23 - 1.62056337683865e+15*cos(theta)**21 + 362812696307159.0*cos(theta)**19 - 63631765198486.4*cos(theta)**17 + 8585238161700.55*cos(theta)**15 - 869286409815.388*cos(theta)**13 + 63845894506.215*cos(theta)**11 - 3242404614.81239*cos(theta)**9 + 106115060.121133*cos(theta)**7 - 2002170.94568175*cos(theta)**5 + 17844.6608349532*cos(theta)**3 - 47.5013154435312*cos(theta)

#@torch.jit.script
def Yl47_m1(theta, phi):
    return 0.0818657643097229*(1.0 - cos(theta)**2)**0.5*(542911163820911.0*cos(theta)**46 - 6.04207585542627e+15*cos(theta)**44 + 3.14055151606222e+16*cos(theta)**42 - 1.01273964619085e+17*cos(theta)**40 + 2.26993368973812e+17*cos(theta)**38 - 3.75473737384917e+17*cos(theta)**36 + 4.74996896691762e+17*cos(theta)**34 - 4.69970474504548e+17*cos(theta)**32 + 3.68837587585847e+17*cos(theta)**30 - 2.31521429437004e+17*cos(theta)**28 + 1.1668680043625e+17*cos(theta)**26 - 4.72269117581335e+16*cos(theta)**24 + 1.52988587385503e+16*cos(theta)**22 - 3.93983987581396e+15*cos(theta)**20 + 798048588917539.0*cos(theta)**18 - 125232240107060.0*cos(theta)**16 + 14908600012745.2*cos(theta)**14 - 1308276375274.65*cos(theta)**12 + 81305311457.7469*cos(theta)**10 - 3378337041.18062*cos(theta)**8 + 85994033.7755067*cos(theta)**6 - 1158949.2422575*cos(theta)**4 + 6197.58953078878*cos(theta)**2 - 5.49919213024737)*cos(phi)

#@torch.jit.script
def Yl47_m2(theta, phi):
    return 0.00172434977599161*(1.0 - cos(theta)**2)*(2.49739135357619e+16*cos(theta)**45 - 2.65851337638756e+17*cos(theta)**43 + 1.31903163674613e+18*cos(theta)**41 - 4.05095858476341e+18*cos(theta)**39 + 8.62574802100484e+18*cos(theta)**37 - 1.3517054545857e+19*cos(theta)**35 + 1.61498944875199e+19*cos(theta)**33 - 1.50390551841455e+19*cos(theta)**31 + 1.10651276275754e+19*cos(theta)**29 - 6.48260002423611e+18*cos(theta)**27 + 3.0338568113425e+18*cos(theta)**25 - 1.1334458821952e+18*cos(theta)**23 + 3.36574892248107e+17*cos(theta)**21 - 7.87967975162791e+16*cos(theta)**19 + 1.43648746005157e+16*cos(theta)**17 - 2.00371584171296e+15*cos(theta)**15 + 208720400178433.0*cos(theta)**13 - 15699316503295.9*cos(theta)**11 + 813053114577.469*cos(theta)**9 - 27026696329.4449*cos(theta)**7 + 515964202.65304*cos(theta)**5 - 4635796.96903001*cos(theta)**3 + 12395.1790615776*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl47_m3(theta, phi):
    return 3.63524851662309e-5*(1.0 - cos(theta)**2)**1.5*(1.12382610910929e+18*cos(theta)**44 - 1.14316075184665e+19*cos(theta)**42 + 5.40802971065915e+19*cos(theta)**40 - 1.57987384805773e+20*cos(theta)**38 + 3.19152676777179e+20*cos(theta)**36 - 4.73096909104995e+20*cos(theta)**34 + 5.32946518088157e+20*cos(theta)**32 - 4.66210710708511e+20*cos(theta)**30 + 3.20888701199687e+20*cos(theta)**28 - 1.75030200654375e+20*cos(theta)**26 + 7.58464202835625e+19*cos(theta)**24 - 2.60692552904897e+19*cos(theta)**22 + 7.06807273721024e+18*cos(theta)**20 - 1.4971391528093e+18*cos(theta)**18 + 2.44202868208767e+17*cos(theta)**16 - 3.00557376256944e+16*cos(theta)**14 + 2.71336520231963e+15*cos(theta)**12 - 172692481536254.0*cos(theta)**10 + 7317478031197.22*cos(theta)**8 - 189186874306.115*cos(theta)**6 + 2579821013.2652*cos(theta)**4 - 13907390.90709*cos(theta)**2 + 12395.1790615776)*cos(3*phi)

#@torch.jit.script
def Yl47_m4(theta, phi):
    return 7.67401563348715e-7*(1.0 - cos(theta)**2)**2*(4.94483488008086e+19*cos(theta)**43 - 4.80127515775593e+20*cos(theta)**41 + 2.16321188426366e+21*cos(theta)**39 - 6.00352062261937e+21*cos(theta)**37 + 1.14894963639784e+22*cos(theta)**35 - 1.60852949095698e+22*cos(theta)**33 + 1.7054288578821e+22*cos(theta)**31 - 1.39863213212553e+22*cos(theta)**29 + 8.98488363359124e+21*cos(theta)**27 - 4.55078521701375e+21*cos(theta)**25 + 1.8203140868055e+21*cos(theta)**23 - 5.73523616390774e+20*cos(theta)**21 + 1.41361454744205e+20*cos(theta)**19 - 2.69485047505675e+19*cos(theta)**17 + 3.90724589134027e+18*cos(theta)**15 - 4.20780326759722e+17*cos(theta)**13 + 3.25603824278356e+16*cos(theta)**11 - 1.72692481536254e+15*cos(theta)**9 + 58539824249577.8*cos(theta)**7 - 1135121245836.69*cos(theta)**5 + 10319284053.0608*cos(theta)**3 - 27814781.8141801*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl47_m5(theta, phi):
    return 1.62288138956816e-8*(1.0 - cos(theta)**2)**2.5*(2.12627899843477e+21*cos(theta)**42 - 1.96852281467993e+22*cos(theta)**40 + 8.43652634862827e+22*cos(theta)**38 - 2.22130263036917e+23*cos(theta)**36 + 4.02132372739246e+23*cos(theta)**34 - 5.30814732015804e+23*cos(theta)**32 + 5.28682945943452e+23*cos(theta)**30 - 4.05603318316405e+23*cos(theta)**28 + 2.42591858106964e+23*cos(theta)**26 - 1.13769630425344e+23*cos(theta)**24 + 4.18672239965265e+22*cos(theta)**22 - 1.20439959442062e+22*cos(theta)**20 + 2.68586764013989e+21*cos(theta)**18 - 4.58124580759647e+20*cos(theta)**16 + 5.86086883701041e+19*cos(theta)**14 - 5.47014424787638e+18*cos(theta)**12 + 3.58164206706192e+17*cos(theta)**10 - 1.55423233382629e+16*cos(theta)**8 + 409778769747044.0*cos(theta)**6 - 5675606229183.44*cos(theta)**4 + 30957852159.1824*cos(theta)**2 - 27814781.8141801)*cos(5*phi)

#@torch.jit.script
def Yl47_m6(theta, phi):
    return 3.43972877896009e-10*(1.0 - cos(theta)**2)**3*(8.93037179342602e+22*cos(theta)**41 - 7.87409125871972e+23*cos(theta)**39 + 3.20588001247874e+24*cos(theta)**37 - 7.996689469329e+24*cos(theta)**35 + 1.36725006731344e+25*cos(theta)**33 - 1.69860714245057e+25*cos(theta)**31 + 1.58604883783036e+25*cos(theta)**29 - 1.13568929128593e+25*cos(theta)**27 + 6.30738831078105e+24*cos(theta)**25 - 2.73047113020825e+24*cos(theta)**23 + 9.21078927923582e+23*cos(theta)**21 - 2.40879918884125e+23*cos(theta)**19 + 4.8345617522518e+22*cos(theta)**17 - 7.32999329215435e+21*cos(theta)**15 + 8.20521637181457e+20*cos(theta)**13 - 6.56417309745166e+19*cos(theta)**11 + 3.58164206706192e+18*cos(theta)**9 - 1.24338586706103e+17*cos(theta)**7 + 2.45867261848227e+15*cos(theta)**5 - 22702424916733.8*cos(theta)**3 + 61915704318.3648*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl47_m7(theta, phi):
    return 7.31030322906247e-12*(1.0 - cos(theta)**2)**3.5*(3.66145243530467e+24*cos(theta)**40 - 3.07089559090069e+25*cos(theta)**38 + 1.18617560461714e+26*cos(theta)**36 - 2.79884131426515e+26*cos(theta)**34 + 4.51192522213434e+26*cos(theta)**32 - 5.26568214159678e+26*cos(theta)**30 + 4.59954162970803e+26*cos(theta)**28 - 3.06636108647202e+26*cos(theta)**26 + 1.57684707769526e+26*cos(theta)**24 - 6.28008359947897e+25*cos(theta)**22 + 1.93426574863952e+25*cos(theta)**20 - 4.57671845879837e+24*cos(theta)**18 + 8.21875497882807e+23*cos(theta)**16 - 1.09949899382315e+23*cos(theta)**14 + 1.06667812833589e+22*cos(theta)**12 - 7.22059040719682e+20*cos(theta)**10 + 3.22347786035572e+19*cos(theta)**8 - 8.70370106942722e+17*cos(theta)**6 + 1.22933630924113e+16*cos(theta)**4 - 68107274750201.3*cos(theta)**2 + 61915704318.3648)*cos(7*phi)

#@torch.jit.script
def Yl47_m8(theta, phi):
    return 1.55856188521285e-13*(1.0 - cos(theta)**2)**4*(1.46458097412187e+26*cos(theta)**39 - 1.16694032454226e+27*cos(theta)**37 + 4.27023217662169e+27*cos(theta)**35 - 9.51606046850151e+27*cos(theta)**33 + 1.44381607108299e+28*cos(theta)**31 - 1.57970464247903e+28*cos(theta)**29 + 1.28787165631825e+28*cos(theta)**27 - 7.97253882482725e+27*cos(theta)**25 + 3.78443298646863e+27*cos(theta)**23 - 1.38161839188537e+27*cos(theta)**21 + 3.86853149727905e+26*cos(theta)**19 - 8.23809322583707e+25*cos(theta)**17 + 1.31500079661249e+25*cos(theta)**15 - 1.53929859135241e+24*cos(theta)**13 + 1.28001375400307e+23*cos(theta)**11 - 7.22059040719682e+21*cos(theta)**9 + 2.57878228828458e+20*cos(theta)**7 - 5.22222064165633e+18*cos(theta)**5 + 4.91734523696453e+16*cos(theta)**3 - 136214549500403.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl47_m9(theta, phi):
    return 3.33501456002215e-15*(1.0 - cos(theta)**2)**4.5*(5.71186579907529e+27*cos(theta)**38 - 4.31767920080637e+28*cos(theta)**36 + 1.49458126181759e+29*cos(theta)**34 - 3.1402999546055e+29*cos(theta)**32 + 4.47582982035726e+29*cos(theta)**30 - 4.5811434631892e+29*cos(theta)**28 + 3.47725347205927e+29*cos(theta)**26 - 1.99313470620681e+29*cos(theta)**24 + 8.70419586887785e+28*cos(theta)**22 - 2.90139862295928e+28*cos(theta)**20 + 7.35020984483019e+27*cos(theta)**18 - 1.4004758483923e+27*cos(theta)**16 + 1.97250119491874e+26*cos(theta)**14 - 2.00108816875814e+25*cos(theta)**12 + 1.40801512940338e+24*cos(theta)**10 - 6.49853136647714e+22*cos(theta)**8 + 1.80514760179921e+21*cos(theta)**6 - 2.61111032082817e+19*cos(theta)**4 + 1.47520357108936e+17*cos(theta)**2 - 136214549500403.0)*cos(9*phi)

#@torch.jit.script
def Yl47_m10(theta, phi):
    return 7.16586312000596e-17*(1.0 - cos(theta)**2)**5*(2.17050900364861e+29*cos(theta)**37 - 1.55436451229029e+30*cos(theta)**35 + 5.08157629017981e+30*cos(theta)**33 - 1.00489598547376e+31*cos(theta)**31 + 1.34274894610718e+31*cos(theta)**29 - 1.28272016969298e+31*cos(theta)**27 + 9.0408590273541e+30*cos(theta)**25 - 4.78352329489635e+30*cos(theta)**23 + 1.91492309115313e+30*cos(theta)**21 - 5.80279724591857e+29*cos(theta)**19 + 1.32303777206943e+29*cos(theta)**17 - 2.24076135742768e+28*cos(theta)**15 + 2.76150167288623e+27*cos(theta)**13 - 2.40130580250977e+26*cos(theta)**11 + 1.40801512940338e+25*cos(theta)**9 - 5.19882509318171e+23*cos(theta)**7 + 1.08308856107952e+22*cos(theta)**5 - 1.04444412833127e+20*cos(theta)**3 + 2.95040714217872e+17*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl47_m11(theta, phi):
    return 1.54686940343682e-18*(1.0 - cos(theta)**2)**5.5*(8.03088331349985e+30*cos(theta)**36 - 5.44027579301603e+31*cos(theta)**34 + 1.67692017575934e+32*cos(theta)**32 - 3.11517755496865e+32*cos(theta)**30 + 3.89397194371082e+32*cos(theta)**28 - 3.46334445817103e+32*cos(theta)**26 + 2.26021475683853e+32*cos(theta)**24 - 1.10021035782616e+32*cos(theta)**22 + 4.02133849142157e+31*cos(theta)**20 - 1.10253147672453e+31*cos(theta)**18 + 2.24916421251804e+30*cos(theta)**16 - 3.36114203614153e+29*cos(theta)**14 + 3.5899521747521e+28*cos(theta)**12 - 2.64143638276074e+27*cos(theta)**10 + 1.26721361646304e+26*cos(theta)**8 - 3.6391775652272e+24*cos(theta)**6 + 5.41544280539762e+22*cos(theta)**4 - 3.1333323849938e+20*cos(theta)**2 + 2.95040714217872e+17)*cos(11*phi)

#@torch.jit.script
def Yl47_m12(theta, phi):
    return 3.35642071771661e-20*(1.0 - cos(theta)**2)**6*(2.89111799285995e+32*cos(theta)**35 - 1.84969376962545e+33*cos(theta)**33 + 5.36614456242988e+33*cos(theta)**31 - 9.34553266490596e+33*cos(theta)**29 + 1.09031214423903e+34*cos(theta)**27 - 9.00469559124469e+33*cos(theta)**25 + 5.42451541641246e+33*cos(theta)**23 - 2.42046278721755e+33*cos(theta)**21 + 8.04267698284314e+32*cos(theta)**19 - 1.98455665810415e+32*cos(theta)**17 + 3.59866274002886e+31*cos(theta)**15 - 4.70559885059814e+30*cos(theta)**13 + 4.30794260970252e+29*cos(theta)**11 - 2.64143638276074e+28*cos(theta)**9 + 1.01377089317043e+27*cos(theta)**7 - 2.18350653913632e+25*cos(theta)**5 + 2.16617712215905e+23*cos(theta)**3 - 6.2666647699876e+20*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl47_m13(theta, phi):
    return 7.32431047764493e-22*(1.0 - cos(theta)**2)**6.5*(1.01189129750098e+34*cos(theta)**34 - 6.10398943976398e+34*cos(theta)**32 + 1.66350481435326e+35*cos(theta)**30 - 2.71020447282273e+35*cos(theta)**28 + 2.94384278944538e+35*cos(theta)**26 - 2.25117389781117e+35*cos(theta)**24 + 1.24763854577487e+35*cos(theta)**22 - 5.08297185315686e+34*cos(theta)**20 + 1.5281086267402e+34*cos(theta)**18 - 3.37374631877706e+33*cos(theta)**16 + 5.39799411004329e+32*cos(theta)**14 - 6.11727850577758e+31*cos(theta)**12 + 4.73873687067277e+30*cos(theta)**10 - 2.37729274448467e+29*cos(theta)**8 + 7.09639625219304e+27*cos(theta)**6 - 1.09175326956816e+26*cos(theta)**4 + 6.49853136647714e+23*cos(theta)**2 - 6.2666647699876e+20)*cos(13*phi)

#@torch.jit.script
def Yl47_m14(theta, phi):
    return 1.60828262371106e-23*(1.0 - cos(theta)**2)**7*(3.44043041150334e+35*cos(theta)**33 - 1.95327662072447e+36*cos(theta)**31 + 4.99051444305978e+36*cos(theta)**29 - 7.58857252390364e+36*cos(theta)**27 + 7.65399125255798e+36*cos(theta)**25 - 5.40281735474681e+36*cos(theta)**23 + 2.74480480070471e+36*cos(theta)**21 - 1.01659437063137e+36*cos(theta)**19 + 2.75059552813235e+35*cos(theta)**17 - 5.39799411004329e+34*cos(theta)**15 + 7.55719175406061e+33*cos(theta)**13 - 7.34073420693309e+32*cos(theta)**11 + 4.73873687067277e+31*cos(theta)**9 - 1.90183419558773e+30*cos(theta)**7 + 4.25783775131582e+28*cos(theta)**5 - 4.36701307827264e+26*cos(theta)**3 + 1.29970627329543e+24*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl47_m15(theta, phi):
    return 3.55557263504815e-25*(1.0 - cos(theta)**2)**7.5*(1.1353420357961e+37*cos(theta)**32 - 6.05515752424587e+37*cos(theta)**30 + 1.44724918848734e+38*cos(theta)**28 - 2.04891458145398e+38*cos(theta)**26 + 1.9134978131395e+38*cos(theta)**24 - 1.24264799159177e+38*cos(theta)**22 + 5.76409008147988e+37*cos(theta)**20 - 1.93152930419961e+37*cos(theta)**18 + 4.676012397825e+36*cos(theta)**16 - 8.09699116506493e+35*cos(theta)**14 + 9.82434928027879e+34*cos(theta)**12 - 8.0748076276264e+33*cos(theta)**10 + 4.26486318360549e+32*cos(theta)**8 - 1.33128393691141e+31*cos(theta)**6 + 2.12891887565791e+29*cos(theta)**4 - 1.31010392348179e+27*cos(theta)**2 + 1.29970627329543e+24)*cos(15*phi)

#@torch.jit.script
def Yl47_m16(theta, phi):
    return 7.91888965127333e-27*(1.0 - cos(theta)**2)**8*(3.63309451454752e+38*cos(theta)**31 - 1.81654725727376e+39*cos(theta)**29 + 4.05229772776454e+39*cos(theta)**27 - 5.32717791178036e+39*cos(theta)**25 + 4.59239475153479e+39*cos(theta)**23 - 2.73382558150189e+39*cos(theta)**21 + 1.15281801629598e+39*cos(theta)**19 - 3.47675274755929e+38*cos(theta)**17 + 7.48161983652e+37*cos(theta)**15 - 1.13357876310909e+37*cos(theta)**13 + 1.17892191363345e+36*cos(theta)**11 - 8.0748076276264e+34*cos(theta)**9 + 3.41189054688439e+33*cos(theta)**7 - 7.98770362146848e+31*cos(theta)**5 + 8.51567550263164e+29*cos(theta)**3 - 2.62020784696358e+27*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl47_m17(theta, phi):
    return 1.77784320941706e-28*(1.0 - cos(theta)**2)**8.5*(1.12625929950973e+40*cos(theta)**30 - 5.26798704609391e+40*cos(theta)**28 + 1.09412038649643e+41*cos(theta)**26 - 1.33179447794509e+41*cos(theta)**24 + 1.056250792853e+41*cos(theta)**22 - 5.74103372115396e+40*cos(theta)**20 + 2.19035423096236e+40*cos(theta)**18 - 5.9104796708508e+39*cos(theta)**16 + 1.122242975478e+39*cos(theta)**14 - 1.47365239204182e+38*cos(theta)**12 + 1.2968141049968e+37*cos(theta)**10 - 7.26732686486376e+35*cos(theta)**8 + 2.38832338281908e+34*cos(theta)**6 - 3.99385181073424e+32*cos(theta)**4 + 2.55470265078949e+30*cos(theta)**2 - 2.62020784696358e+27)*cos(17*phi)

#@torch.jit.script
def Yl47_m18(theta, phi):
    return 4.02602207266572e-30*(1.0 - cos(theta)**2)**9*(3.3787778985292e+41*cos(theta)**29 - 1.47503637290629e+42*cos(theta)**27 + 2.84471300489071e+42*cos(theta)**25 - 3.19630674706821e+42*cos(theta)**23 + 2.3237517442766e+42*cos(theta)**21 - 1.14820674423079e+42*cos(theta)**19 + 3.94263761573224e+41*cos(theta)**17 - 9.45676747336128e+40*cos(theta)**15 + 1.5711401656692e+40*cos(theta)**13 - 1.76838287045018e+39*cos(theta)**11 + 1.2968141049968e+38*cos(theta)**9 - 5.81386149189101e+36*cos(theta)**7 + 1.43299402969145e+35*cos(theta)**5 - 1.5975407242937e+33*cos(theta)**3 + 5.10940530157899e+30*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl47_m19(theta, phi):
    return 9.20248641199569e-32*(1.0 - cos(theta)**2)**9.5*(9.79845590573467e+42*cos(theta)**28 - 3.98259820684699e+43*cos(theta)**26 + 7.11178251222678e+43*cos(theta)**24 - 7.35150551825689e+43*cos(theta)**22 + 4.87987866298087e+43*cos(theta)**20 - 2.18159281403851e+43*cos(theta)**18 + 6.70248394674481e+42*cos(theta)**16 - 1.41851512100419e+42*cos(theta)**14 + 2.04248221536996e+41*cos(theta)**12 - 1.9452211574952e+40*cos(theta)**10 + 1.16713269449712e+39*cos(theta)**8 - 4.06970304432371e+37*cos(theta)**6 + 7.16497014845723e+35*cos(theta)**4 - 4.79262217288109e+33*cos(theta)**2 + 5.10940530157899e+30)*cos(19*phi)

#@torch.jit.script
def Yl47_m20(theta, phi):
    return 2.12465670327417e-33*(1.0 - cos(theta)**2)**10*(2.74356765360571e+44*cos(theta)**27 - 1.03547553378022e+45*cos(theta)**25 + 1.70682780293443e+45*cos(theta)**23 - 1.61733121401652e+45*cos(theta)**21 + 9.75975732596174e+44*cos(theta)**19 - 3.92686706526931e+44*cos(theta)**17 + 1.07239743147917e+44*cos(theta)**15 - 1.98592116940587e+43*cos(theta)**13 + 2.45097865844395e+42*cos(theta)**11 - 1.9452211574952e+41*cos(theta)**9 + 9.33706155597696e+39*cos(theta)**7 - 2.44182182659422e+38*cos(theta)**5 + 2.86598805938289e+36*cos(theta)**3 - 9.58524434576218e+33*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl47_m21(theta, phi):
    return 4.95852411165239e-35*(1.0 - cos(theta)**2)**10.5*(7.40763266473541e+45*cos(theta)**26 - 2.58868883445055e+46*cos(theta)**24 + 3.92570394674918e+46*cos(theta)**22 - 3.39639554943468e+46*cos(theta)**20 + 1.85435389193273e+46*cos(theta)**18 - 6.67567401095783e+45*cos(theta)**16 + 1.60859614721875e+45*cos(theta)**14 - 2.58169752022763e+44*cos(theta)**12 + 2.69607652428835e+43*cos(theta)**10 - 1.75069904174568e+42*cos(theta)**8 + 6.53594308918387e+40*cos(theta)**6 - 1.22091091329711e+39*cos(theta)**4 + 8.59796417814867e+36*cos(theta)**2 - 9.58524434576218e+33)*cos(21*phi)

#@torch.jit.script
def Yl47_m22(theta, phi):
    return 1.1706881168749e-36*(1.0 - cos(theta)**2)**11*(1.92598449283121e+47*cos(theta)**25 - 6.21285320268131e+47*cos(theta)**23 + 8.6365486828482e+47*cos(theta)**21 - 6.79279109886937e+47*cos(theta)**19 + 3.33783700547891e+47*cos(theta)**17 - 1.06810784175325e+47*cos(theta)**15 + 2.25203460610626e+46*cos(theta)**13 - 3.09803702427316e+45*cos(theta)**11 + 2.69607652428835e+44*cos(theta)**9 - 1.40055923339654e+43*cos(theta)**7 + 3.92156585351032e+41*cos(theta)**5 - 4.88364365318845e+39*cos(theta)**3 + 1.71959283562973e+37*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl47_m23(theta, phi):
    return 2.79847985979336e-38*(1.0 - cos(theta)**2)**11.5*(4.81496123207802e+48*cos(theta)**24 - 1.4289562366167e+49*cos(theta)**22 + 1.81367522339812e+49*cos(theta)**20 - 1.29063030878518e+49*cos(theta)**18 + 5.67432290931415e+48*cos(theta)**16 - 1.60216176262988e+48*cos(theta)**14 + 2.92764498793813e+47*cos(theta)**12 - 3.40784072670047e+46*cos(theta)**10 + 2.42646887185951e+45*cos(theta)**8 - 9.80391463377581e+43*cos(theta)**6 + 1.96078292675516e+42*cos(theta)**4 - 1.46509309595653e+40*cos(theta)**2 + 1.71959283562973e+37)*cos(23*phi)

#@torch.jit.script
def Yl47_m24(theta, phi):
    return 6.77933961187779e-40*(1.0 - cos(theta)**2)**12*(1.15559069569872e+50*cos(theta)**23 - 3.14370372055674e+50*cos(theta)**21 + 3.62735044679624e+50*cos(theta)**19 - 2.32313455581332e+50*cos(theta)**17 + 9.07891665490265e+49*cos(theta)**15 - 2.24302646768183e+49*cos(theta)**13 + 3.51317398552576e+48*cos(theta)**11 - 3.40784072670047e+47*cos(theta)**9 + 1.94117509748761e+46*cos(theta)**7 - 5.88234878026548e+44*cos(theta)**5 + 7.84313170702065e+42*cos(theta)**3 - 2.93018619191307e+40*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl47_m25(theta, phi):
    return 1.66593182302274e-41*(1.0 - cos(theta)**2)**12.5*(2.65785860010707e+51*cos(theta)**22 - 6.60177781316916e+51*cos(theta)**20 + 6.89196584891286e+51*cos(theta)**18 - 3.94932874488265e+51*cos(theta)**16 + 1.3618374982354e+51*cos(theta)**14 - 2.91593440798638e+50*cos(theta)**12 + 3.86449138407833e+49*cos(theta)**10 - 3.06705665403042e+48*cos(theta)**8 + 1.35882256824133e+47*cos(theta)**6 - 2.94117439013274e+45*cos(theta)**4 + 2.35293951210619e+43*cos(theta)**2 - 2.93018619191307e+40)*cos(25*phi)

#@torch.jit.script
def Yl47_m26(theta, phi):
    return 4.15704239669497e-43*(1.0 - cos(theta)**2)**13*(5.84728892023554e+52*cos(theta)**21 - 1.32035556263383e+53*cos(theta)**19 + 1.24055385280432e+53*cos(theta)**17 - 6.31892599181224e+52*cos(theta)**15 + 1.90657249752956e+52*cos(theta)**13 - 3.49912128958366e+51*cos(theta)**11 + 3.86449138407833e+50*cos(theta)**9 - 2.45364532322434e+49*cos(theta)**7 + 8.15293540944796e+47*cos(theta)**5 - 1.1764697560531e+46*cos(theta)**3 + 4.70587902421239e+43*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl47_m27(theta, phi):
    return 1.05453001748702e-44*(1.0 - cos(theta)**2)**13.5*(1.22793067324946e+54*cos(theta)**20 - 2.50867556900428e+54*cos(theta)**18 + 2.10894154976734e+54*cos(theta)**16 - 9.47838898771836e+53*cos(theta)**14 + 2.47854424678842e+53*cos(theta)**12 - 3.84903341854202e+52*cos(theta)**10 + 3.4780422456705e+51*cos(theta)**8 - 1.71755172625704e+50*cos(theta)**6 + 4.07646770472398e+48*cos(theta)**4 - 3.52940926815929e+46*cos(theta)**2 + 4.70587902421239e+43)*cos(27*phi)

#@torch.jit.script
def Yl47_m28(theta, phi):
    return 2.72278479720203e-46*(1.0 - cos(theta)**2)**14*(2.45586134649893e+55*cos(theta)**19 - 4.51561602420771e+55*cos(theta)**17 + 3.37430647962774e+55*cos(theta)**15 - 1.32697445828057e+55*cos(theta)**13 + 2.97425309614611e+54*cos(theta)**11 - 3.84903341854202e+53*cos(theta)**9 + 2.7824337965364e+52*cos(theta)**7 - 1.03053103575422e+51*cos(theta)**5 + 1.63058708188959e+49*cos(theta)**3 - 7.05881853631858e+46*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl47_m29(theta, phi):
    return 7.16522315053166e-48*(1.0 - cos(theta)**2)**14.5*(4.66613655834796e+56*cos(theta)**18 - 7.6765472411531e+56*cos(theta)**16 + 5.06145971944161e+56*cos(theta)**14 - 1.72506679576474e+56*cos(theta)**12 + 3.27167840576072e+55*cos(theta)**10 - 3.46413007668782e+54*cos(theta)**8 + 1.94770365757548e+53*cos(theta)**6 - 5.15265517877111e+51*cos(theta)**4 + 4.89176124566878e+49*cos(theta)**2 - 7.05881853631858e+46)*cos(29*phi)

#@torch.jit.script
def Yl47_m30(theta, phi):
    return 1.92463378568823e-49*(1.0 - cos(theta)**2)**15*(8.39904580502633e+57*cos(theta)**17 - 1.2282475585845e+58*cos(theta)**15 + 7.08604360721825e+57*cos(theta)**13 - 2.07008015491769e+57*cos(theta)**11 + 3.27167840576072e+56*cos(theta)**9 - 2.77130406135025e+55*cos(theta)**7 + 1.16862219454529e+54*cos(theta)**5 - 2.06106207150844e+52*cos(theta)**3 + 9.78352249133755e+49*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl47_m31(theta, phi):
    return 5.28538153651375e-51*(1.0 - cos(theta)**2)**15.5*(1.42783778685448e+59*cos(theta)**16 - 1.84237133787674e+59*cos(theta)**14 + 9.21185668938372e+58*cos(theta)**12 - 2.27708817040946e+58*cos(theta)**10 + 2.94451056518465e+57*cos(theta)**8 - 1.93991284294518e+56*cos(theta)**6 + 5.84311097272644e+54*cos(theta)**4 - 6.18318621452533e+52*cos(theta)**2 + 9.78352249133755e+49)*cos(31*phi)

#@torch.jit.script
def Yl47_m32(theta, phi):
    return 1.48662970462735e-52*(1.0 - cos(theta)**2)**16*(2.28454045896716e+60*cos(theta)**15 - 2.57931987302744e+60*cos(theta)**13 + 1.10542280272605e+60*cos(theta)**11 - 2.27708817040946e+59*cos(theta)**9 + 2.35560845214772e+58*cos(theta)**7 - 1.16394770576711e+57*cos(theta)**5 + 2.33724438909058e+55*cos(theta)**3 - 1.23663724290507e+53*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl47_m33(theta, phi):
    return 4.29153030075948e-54*(1.0 - cos(theta)**2)**16.5*(3.42681068845074e+61*cos(theta)**14 - 3.35311583493567e+61*cos(theta)**12 + 1.21596508299865e+61*cos(theta)**10 - 2.04937935336851e+60*cos(theta)**8 + 1.6489259165034e+59*cos(theta)**6 - 5.81973852883553e+57*cos(theta)**4 + 7.01173316727173e+55*cos(theta)**2 - 1.23663724290507e+53)*cos(33*phi)

#@torch.jit.script
def Yl47_m34(theta, phi):
    return 1.27439968653976e-55*(1.0 - cos(theta)**2)**17*(4.79753496383104e+62*cos(theta)**13 - 4.02373900192281e+62*cos(theta)**11 + 1.21596508299865e+62*cos(theta)**9 - 1.63950348269481e+61*cos(theta)**7 + 9.89355549902041e+59*cos(theta)**5 - 2.32789541153421e+58*cos(theta)**3 + 1.40234663345435e+56*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl47_m35(theta, phi):
    return 3.90325615867939e-57*(1.0 - cos(theta)**2)**17.5*(6.23679545298036e+63*cos(theta)**12 - 4.42611290211509e+63*cos(theta)**10 + 1.09436857469879e+63*cos(theta)**8 - 1.14765243788637e+62*cos(theta)**6 + 4.94677774951021e+60*cos(theta)**4 - 6.98368623460264e+58*cos(theta)**2 + 1.40234663345435e+56)*cos(35*phi)

#@torch.jit.script
def Yl47_m36(theta, phi):
    return 1.23679404188207e-58*(1.0 - cos(theta)**2)**18*(7.48415454357643e+64*cos(theta)**11 - 4.42611290211509e+64*cos(theta)**9 + 8.75494859759029e+63*cos(theta)**7 - 6.88591462731821e+62*cos(theta)**5 + 1.97871109980408e+61*cos(theta)**3 - 1.39673724692053e+59*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl47_m37(theta, phi):
    return 4.06875368086227e-60*(1.0 - cos(theta)**2)**18.5*(8.23256999793407e+65*cos(theta)**10 - 3.98350161190358e+65*cos(theta)**8 + 6.1284640183132e+64*cos(theta)**6 - 3.4429573136591e+63*cos(theta)**4 + 5.93613329941225e+61*cos(theta)**2 - 1.39673724692053e+59)*cos(37*phi)

#@torch.jit.script
def Yl47_m38(theta, phi):
    return 1.39557099912251e-61*(1.0 - cos(theta)**2)**19*(8.23256999793407e+66*cos(theta)**9 - 3.18680128952287e+66*cos(theta)**7 + 3.67707841098792e+65*cos(theta)**5 - 1.37718292546364e+64*cos(theta)**3 + 1.18722665988245e+62*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl47_m39(theta, phi):
    return 5.01627636792244e-63*(1.0 - cos(theta)**2)**19.5*(7.40931299814066e+67*cos(theta)**8 - 2.23076090266601e+67*cos(theta)**6 + 1.83853920549396e+66*cos(theta)**4 - 4.13154877639092e+64*cos(theta)**2 + 1.18722665988245e+62)*cos(39*phi)

#@torch.jit.script
def Yl47_m40(theta, phi):
    return 1.90141465028655e-64*(1.0 - cos(theta)**2)**20*(5.92745039851253e+68*cos(theta)**7 - 1.3384565415996e+68*cos(theta)**5 + 7.35415682197584e+66*cos(theta)**3 - 8.26309755278185e+64*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl47_m41(theta, phi):
    return 7.66101794667593e-66*(1.0 - cos(theta)**2)**20.5*(4.14921527895877e+69*cos(theta)**6 - 6.69228270799802e+68*cos(theta)**4 + 2.20624704659275e+67*cos(theta)**2 - 8.26309755278185e+64)*cos(41*phi)

#@torch.jit.script
def Yl47_m42(theta, phi):
    return 3.31524669825326e-67*(1.0 - cos(theta)**2)**21*(2.48952916737526e+70*cos(theta)**5 - 2.67691308319921e+69*cos(theta)**3 + 4.41249409318551e+67*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl47_m43(theta, phi):
    return 1.56282228109413e-68*(1.0 - cos(theta)**2)**21.5*(1.24476458368763e+71*cos(theta)**4 - 8.03073924959762e+69*cos(theta)**2 + 4.41249409318551e+67)*cos(43*phi)

#@torch.jit.script
def Yl47_m44(theta, phi):
    return 8.19141449881068e-70*(1.0 - cos(theta)**2)**22*(4.97905833475052e+71*cos(theta)**3 - 1.60614784991952e+70*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl47_m45(theta, phi):
    return 4.93065211209231e-71*(1.0 - cos(theta)**2)**22.5*(1.49371750042516e+72*cos(theta)**2 - 1.60614784991952e+70)*cos(45*phi)

#@torch.jit.script
def Yl47_m46(theta, phi):
    return 10.8005619986252*(1.0 - cos(theta)**2)**23*cos(46*phi)*cos(theta)

#@torch.jit.script
def Yl47_m47(theta, phi):
    return 1.11399291169174*(1.0 - cos(theta)**2)**23.5*cos(47*phi)

#@torch.jit.script
def Yl48_m_minus_48(theta, phi):
    return 1.11977992679758*(1.0 - cos(theta)**2)**24*sin(48*phi)

#@torch.jit.script
def Yl48_m_minus_47(theta, phi):
    return 10.9715577794607*(1.0 - cos(theta)**2)**23.5*sin(47*phi)*cos(theta)

#@torch.jit.script
def Yl48_m_minus_46(theta, phi):
    return 5.32872152427948e-73*(1.0 - cos(theta)**2)**23*(1.4190316254039e+74*cos(theta)**2 - 1.49371750042516e+72)*sin(46*phi)

#@torch.jit.script
def Yl48_m_minus_45(theta, phi):
    return 8.94844512163766e-72*(1.0 - cos(theta)**2)**22.5*(4.730105418013e+73*cos(theta)**3 - 1.49371750042516e+72*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl48_m_minus_44(theta, phi):
    return 1.72591359213969e-70*(1.0 - cos(theta)**2)**22*(1.18252635450325e+73*cos(theta)**4 - 7.46858750212579e+71*cos(theta)**2 + 4.01536962479881e+69)*sin(44*phi)

#@torch.jit.script
def Yl48_m_minus_43(theta, phi):
    return 3.70167226353842e-69*(1.0 - cos(theta)**2)**21.5*(2.3650527090065e+72*cos(theta)**5 - 2.48952916737526e+71*cos(theta)**3 + 4.01536962479881e+69*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl48_m_minus_42(theta, phi):
    return 8.64956538819768e-68*(1.0 - cos(theta)**2)**21*(3.94175451501083e+71*cos(theta)**6 - 6.22382291843816e+70*cos(theta)**4 + 2.00768481239941e+69*cos(theta)**2 - 7.35415682197584e+66)*sin(42*phi)

#@torch.jit.script
def Yl48_m_minus_41(theta, phi):
    return 2.17102368215931e-66*(1.0 - cos(theta)**2)**20.5*(5.6310778785869e+70*cos(theta)**7 - 1.24476458368763e+70*cos(theta)**5 + 6.69228270799802e+68*cos(theta)**3 - 7.35415682197584e+66*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl48_m_minus_40(theta, phi):
    return 5.79301372852641e-65*(1.0 - cos(theta)**2)**20*(7.03884734823363e+69*cos(theta)**8 - 2.07460763947939e+69*cos(theta)**6 + 1.6730706769995e+68*cos(theta)**4 - 3.67707841098792e+66*cos(theta)**2 + 1.03288719409773e+64)*sin(40*phi)

#@torch.jit.script
def Yl48_m_minus_39(theta, phi):
    return 1.63029857334923e-63*(1.0 - cos(theta)**2)**19.5*(7.82094149803737e+68*cos(theta)**9 - 2.96372519925626e+68*cos(theta)**7 + 3.34614135399901e+67*cos(theta)**5 - 1.22569280366264e+66*cos(theta)**3 + 1.03288719409773e+64*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl48_m_minus_38(theta, phi):
    return 4.80868993728036e-62*(1.0 - cos(theta)**2)**19*(7.82094149803737e+67*cos(theta)**10 - 3.70465649907033e+67*cos(theta)**8 + 5.57690225666501e+66*cos(theta)**6 - 3.0642320091566e+65*cos(theta)**4 + 5.16443597048865e+63*cos(theta)**2 - 1.18722665988245e+61)*sin(38*phi)

#@torch.jit.script
def Yl48_m_minus_37(theta, phi):
    return 1.47901419775487e-60*(1.0 - cos(theta)**2)**18.5*(7.1099468163976e+66*cos(theta)**11 - 4.11628499896703e+66*cos(theta)**9 + 7.96700322380716e+65*cos(theta)**7 - 6.1284640183132e+64*cos(theta)**5 + 1.72147865682955e+63*cos(theta)**3 - 1.18722665988245e+61*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl48_m_minus_36(theta, phi):
    return 4.72359254921895e-59*(1.0 - cos(theta)**2)**18*(5.92495568033134e+65*cos(theta)**12 - 4.11628499896703e+65*cos(theta)**10 + 9.95875402975895e+64*cos(theta)**8 - 1.02141066971887e+64*cos(theta)**6 + 4.30369664207388e+62*cos(theta)**4 - 5.93613329941225e+60*cos(theta)**2 + 1.16394770576711e+58)*sin(36*phi)

#@torch.jit.script
def Yl48_m_minus_35(theta, phi):
    return 1.5609311520875e-57*(1.0 - cos(theta)**2)**17.5*(4.55765821563949e+64*cos(theta)**13 - 3.74207727178821e+64*cos(theta)**11 + 1.10652822552877e+64*cos(theta)**9 - 1.45915809959838e+63*cos(theta)**7 + 8.60739328414776e+61*cos(theta)**5 - 1.97871109980408e+60*cos(theta)**3 + 1.16394770576711e+58*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl48_m_minus_34(theta, phi):
    return 5.32092101381846e-56*(1.0 - cos(theta)**2)**17*(3.25547015402821e+63*cos(theta)**14 - 3.11839772649018e+63*cos(theta)**12 + 1.10652822552877e+63*cos(theta)**10 - 1.82394762449798e+62*cos(theta)**8 + 1.43456554735796e+61*cos(theta)**6 - 4.94677774951021e+59*cos(theta)**4 + 5.81973852883553e+57*cos(theta)**2 - 1.0016761667531e+55)*sin(34*phi)

#@torch.jit.script
def Yl48_m_minus_33(theta, phi):
    return 1.86611914237577e-54*(1.0 - cos(theta)**2)**16.5*(2.1703134360188e+62*cos(theta)**15 - 2.39876748191552e+62*cos(theta)**13 + 1.0059347504807e+62*cos(theta)**11 - 2.02660847166442e+61*cos(theta)**9 + 2.04937935336851e+60*cos(theta)**7 - 9.89355549902041e+58*cos(theta)**5 + 1.93991284294518e+57*cos(theta)**3 - 1.0016761667531e+55*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl48_m_minus_32(theta, phi):
    return 6.71802891255276e-53*(1.0 - cos(theta)**2)**16*(1.35644589751175e+61*cos(theta)**16 - 1.71340534422537e+61*cos(theta)**14 + 8.38278958733919e+60*cos(theta)**12 - 2.02660847166442e+60*cos(theta)**10 + 2.56172419171064e+59*cos(theta)**8 - 1.6489259165034e+58*cos(theta)**6 + 4.84978210736295e+56*cos(theta)**4 - 5.00838083376552e+54*cos(theta)**2 + 7.72898276815667e+51)*sin(32*phi)

#@torch.jit.script
def Yl48_m_minus_31(theta, phi):
    return 2.47748664898637e-51*(1.0 - cos(theta)**2)**15.5*(7.97909351477502e+59*cos(theta)**17 - 1.14227022948358e+60*cos(theta)**15 + 6.44829968256861e+59*cos(theta)**13 - 1.84237133787674e+59*cos(theta)**11 + 2.84636021301182e+58*cos(theta)**9 - 2.35560845214772e+57*cos(theta)**7 + 9.69956421472589e+55*cos(theta)**5 - 1.66946027792184e+54*cos(theta)**3 + 7.72898276815667e+51*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl48_m_minus_30(theta, phi):
    return 9.34245728723332e-50*(1.0 - cos(theta)**2)**15*(4.43282973043057e+58*cos(theta)**18 - 7.13918893427238e+58*cos(theta)**16 + 4.60592834469186e+58*cos(theta)**14 - 1.53530944823062e+58*cos(theta)**12 + 2.84636021301182e+57*cos(theta)**10 - 2.94451056518465e+56*cos(theta)**8 + 1.61659403578765e+55*cos(theta)**6 - 4.1736506948046e+53*cos(theta)**4 + 3.86449138407833e+51*cos(theta)**2 - 5.43529027296531e+48)*sin(30*phi)

#@torch.jit.script
def Yl48_m_minus_29(theta, phi):
    return 3.5965427162585e-48*(1.0 - cos(theta)**2)**14.5*(2.33306827917398e+57*cos(theta)**19 - 4.19952290251317e+57*cos(theta)**17 + 3.07061889646124e+57*cos(theta)**15 - 1.18100726786971e+57*cos(theta)**13 + 2.58760019364711e+56*cos(theta)**11 - 3.27167840576072e+55*cos(theta)**9 + 2.30942005112521e+54*cos(theta)**7 - 8.3473013896092e+52*cos(theta)**5 + 1.28816379469278e+51*cos(theta)**3 - 5.43529027296531e+48*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl48_m_minus_28(theta, phi):
    return 1.41138527855448e-46*(1.0 - cos(theta)**2)**14*(1.16653413958699e+56*cos(theta)**20 - 2.33306827917398e+56*cos(theta)**18 + 1.91913681028828e+56*cos(theta)**16 - 8.43576619906934e+55*cos(theta)**14 + 2.15633349470593e+55*cos(theta)**12 - 3.27167840576072e+54*cos(theta)**10 + 2.88677506390652e+53*cos(theta)**8 - 1.3912168982682e+52*cos(theta)**6 + 3.22040948673195e+50*cos(theta)**4 - 2.71764513648265e+48*cos(theta)**2 + 3.52940926815929e+45)*sin(28*phi)

#@torch.jit.script
def Yl48_m_minus_27(theta, phi):
    return 5.63847977172428e-45*(1.0 - cos(theta)**2)**13.5*(5.55492447422377e+54*cos(theta)**21 - 1.22793067324946e+55*cos(theta)**19 + 1.12890400605193e+55*cos(theta)**17 - 5.6238441327129e+54*cos(theta)**15 + 1.65871807285071e+54*cos(theta)**13 - 2.97425309614611e+53*cos(theta)**11 + 3.20752784878502e+52*cos(theta)**9 - 1.98745271181171e+51*cos(theta)**7 + 6.44081897346389e+49*cos(theta)**5 - 9.05881712160885e+47*cos(theta)**3 + 3.52940926815929e+45*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl48_m_minus_26(theta, phi):
    return 2.29036131046255e-43*(1.0 - cos(theta)**2)**13*(2.52496567010171e+53*cos(theta)**22 - 6.13965336624732e+53*cos(theta)**20 + 6.2716889225107e+53*cos(theta)**18 - 3.51490258294556e+53*cos(theta)**16 + 1.1847986234648e+53*cos(theta)**14 - 2.47854424678842e+52*cos(theta)**12 + 3.20752784878502e+51*cos(theta)**10 - 2.48431588976464e+50*cos(theta)**8 + 1.07346982891065e+49*cos(theta)**6 - 2.26470428040221e+47*cos(theta)**4 + 1.76470463407965e+45*cos(theta)**2 - 2.13903592009654e+42)*sin(26*phi)

#@torch.jit.script
def Yl48_m_minus_25(theta, phi):
    return 9.44895491313896e-42*(1.0 - cos(theta)**2)**12.5*(1.09781116091379e+52*cos(theta)**23 - 2.92364446011777e+52*cos(theta)**21 + 3.30088890658458e+52*cos(theta)**19 - 2.06758975467386e+52*cos(theta)**17 + 7.8986574897653e+51*cos(theta)**15 - 1.90657249752956e+51*cos(theta)**13 + 2.91593440798638e+50*cos(theta)**11 - 2.76035098862738e+49*cos(theta)**9 + 1.53352832701521e+48*cos(theta)**7 - 4.52940856080442e+46*cos(theta)**5 + 5.88234878026548e+44*cos(theta)**3 - 2.13903592009654e+42*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl48_m_minus_24(theta, phi):
    return 3.9550395214376e-40*(1.0 - cos(theta)**2)**12*(4.57421317047412e+50*cos(theta)**24 - 1.32892930005353e+51*cos(theta)**22 + 1.65044445329229e+51*cos(theta)**20 - 1.14866097481881e+51*cos(theta)**18 + 4.93666093110331e+50*cos(theta)**16 - 1.3618374982354e+50*cos(theta)**14 + 2.42994533998865e+49*cos(theta)**12 - 2.76035098862738e+48*cos(theta)**10 + 1.91691040876902e+47*cos(theta)**8 - 7.54901426800737e+45*cos(theta)**6 + 1.47058719506637e+44*cos(theta)**4 - 1.06951796004827e+42*cos(theta)**2 + 1.22091091329711e+39)*sin(24*phi)

#@torch.jit.script
def Yl48_m_minus_23(theta, phi):
    return 1.67798115928159e-38*(1.0 - cos(theta)**2)**11.5*(1.82968526818965e+49*cos(theta)**25 - 5.77795347849362e+49*cos(theta)**23 + 7.85925930139186e+49*cos(theta)**21 - 6.04558407799374e+49*cos(theta)**19 + 2.90391819476665e+49*cos(theta)**17 - 9.07891665490265e+48*cos(theta)**15 + 1.86918872306819e+48*cos(theta)**13 - 2.50940998966126e+47*cos(theta)**11 + 2.12990045418779e+46*cos(theta)**9 - 1.07843060971534e+45*cos(theta)**7 + 2.94117439013274e+43*cos(theta)**5 - 3.56505986682757e+41*cos(theta)**3 + 1.22091091329711e+39*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl48_m_minus_22(theta, phi):
    return 7.20946318604152e-37*(1.0 - cos(theta)**2)**11*(7.03725103149864e+47*cos(theta)**26 - 2.40748061603901e+48*cos(theta)**24 + 3.57239059154175e+48*cos(theta)**22 - 3.02279203899687e+48*cos(theta)**20 + 1.61328788598148e+48*cos(theta)**18 - 5.67432290931415e+47*cos(theta)**16 + 1.33513480219157e+47*cos(theta)**14 - 2.09117499138438e+46*cos(theta)**12 + 2.12990045418779e+45*cos(theta)**10 - 1.34803826214417e+44*cos(theta)**8 + 4.9019573168879e+42*cos(theta)**6 - 8.91264966706892e+40*cos(theta)**4 + 6.10455456648556e+38*cos(theta)**2 - 6.6138185985759e+35)*sin(22*phi)

#@torch.jit.script
def Yl48_m_minus_21(theta, phi):
    return 3.13425141500133e-35*(1.0 - cos(theta)**2)**10.5*(2.60638927092542e+46*cos(theta)**27 - 9.62992246415603e+46*cos(theta)**25 + 1.55321330067033e+47*cos(theta)**23 - 1.4394247804747e+47*cos(theta)**21 + 8.49098887358671e+46*cos(theta)**19 - 3.33783700547891e+46*cos(theta)**17 + 8.9008986812771e+45*cos(theta)**15 - 1.60859614721875e+45*cos(theta)**13 + 1.93627314017072e+44*cos(theta)**11 - 1.4978202912713e+43*cos(theta)**9 + 7.00279616698272e+41*cos(theta)**7 - 1.78252993341378e+40*cos(theta)**5 + 2.03485152216185e+38*cos(theta)**3 - 6.6138185985759e+35*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl48_m_minus_20(theta, phi):
    return 1.37764522622734e-33*(1.0 - cos(theta)**2)**10*(9.30853311044794e+44*cos(theta)**28 - 3.70381633236771e+45*cos(theta)**26 + 6.47172208612637e+45*cos(theta)**24 - 6.54283991124863e+45*cos(theta)**22 + 4.24549443679336e+45*cos(theta)**20 - 1.85435389193273e+45*cos(theta)**18 + 5.56306167579819e+44*cos(theta)**16 - 1.1489972480134e+44*cos(theta)**14 + 1.61356095014227e+43*cos(theta)**12 - 1.4978202912713e+42*cos(theta)**10 + 8.7534952087284e+40*cos(theta)**8 - 2.97088322235631e+39*cos(theta)**6 + 5.08712880540463e+37*cos(theta)**4 - 3.30690929928795e+35*cos(theta)**2 + 3.42330155205792e+32)*sin(20*phi)

#@torch.jit.script
def Yl48_m_minus_19(theta, phi):
    return 6.11773762133704e-32*(1.0 - cos(theta)**2)**9.5*(3.20983900360274e+43*cos(theta)**29 - 1.37178382680285e+44*cos(theta)**27 + 2.58868883445055e+44*cos(theta)**25 - 2.84471300489071e+44*cos(theta)**23 + 2.02166401752065e+44*cos(theta)**21 - 9.75975732596174e+43*cos(theta)**19 + 3.27238922105776e+43*cos(theta)**17 - 7.65998165342264e+42*cos(theta)**15 + 1.24120073087867e+42*cos(theta)**13 - 1.36165481024664e+41*cos(theta)**11 + 9.726105787476e+39*cos(theta)**9 - 4.24411888908044e+38*cos(theta)**7 + 1.01742576108093e+37*cos(theta)**5 - 1.10230309976265e+35*cos(theta)**3 + 3.42330155205792e+32*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl48_m_minus_18(theta, phi):
    return 2.7427667480681e-30*(1.0 - cos(theta)**2)**9*(1.06994633453425e+42*cos(theta)**30 - 4.89922795286733e+42*cos(theta)**28 + 9.95649551711749e+42*cos(theta)**26 - 1.18529708537113e+43*cos(theta)**24 + 9.18938189782112e+42*cos(theta)**22 - 4.87987866298087e+42*cos(theta)**20 + 1.81799401169875e+42*cos(theta)**18 - 4.78748853338915e+41*cos(theta)**16 + 8.8657195062762e+40*cos(theta)**14 - 1.1347123418722e+40*cos(theta)**12 + 9.726105787476e+38*cos(theta)**10 - 5.30514861135055e+37*cos(theta)**8 + 1.69570960180154e+36*cos(theta)**6 - 2.75575774940663e+34*cos(theta)**4 + 1.71165077602896e+32*cos(theta)**2 - 1.70313510052633e+29)*sin(18*phi)

#@torch.jit.script
def Yl48_m_minus_17(theta, phi):
    return 1.24062831914294e-28*(1.0 - cos(theta)**2)**8.5*(3.45143978882015e+40*cos(theta)**31 - 1.6893889492646e+41*cos(theta)**29 + 3.68759093226574e+41*cos(theta)**27 - 4.74118834148452e+41*cos(theta)**25 + 3.99538343383527e+41*cos(theta)**23 - 2.3237517442766e+41*cos(theta)**21 + 9.5683895352566e+40*cos(theta)**19 - 2.81616972552303e+40*cos(theta)**17 + 5.9104796708508e+39*cos(theta)**15 - 8.72855647594e+38*cos(theta)**13 + 8.84191435225091e+37*cos(theta)**11 - 5.89460956816727e+36*cos(theta)**9 + 2.42244228828792e+35*cos(theta)**7 - 5.51151549881325e+33*cos(theta)**5 + 5.7055025867632e+31*cos(theta)**3 - 1.70313510052633e+29*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl48_m_minus_16(theta, phi):
    return 5.6581356846753e-27*(1.0 - cos(theta)**2)**8*(1.0785749340063e+39*cos(theta)**32 - 5.63129649754866e+39*cos(theta)**30 + 1.31699676152348e+40*cos(theta)**28 - 1.82353397749405e+40*cos(theta)**26 + 1.66474309743136e+40*cos(theta)**24 - 1.056250792853e+40*cos(theta)**22 + 4.7841947676283e+39*cos(theta)**20 - 1.56453873640168e+39*cos(theta)**18 + 3.69404979428175e+38*cos(theta)**16 - 6.2346831971e+37*cos(theta)**14 + 7.36826196020909e+36*cos(theta)**12 - 5.89460956816727e+35*cos(theta)**10 + 3.0280528603599e+34*cos(theta)**8 - 9.18585916468876e+32*cos(theta)**6 + 1.4263756466908e+31*cos(theta)**4 - 8.51567550263164e+28*cos(theta)**2 + 8.1881495217612e+25)*sin(16*phi)

#@torch.jit.script
def Yl48_m_minus_15(theta, phi):
    return 2.60028119225837e-25*(1.0 - cos(theta)**2)**7.5*(3.26840889092817e+37*cos(theta)**33 - 1.81654725727376e+38*cos(theta)**31 + 4.5413681431844e+38*cos(theta)**29 - 6.75382954627424e+38*cos(theta)**27 + 6.65897238972545e+38*cos(theta)**25 - 4.59239475153479e+38*cos(theta)**23 + 2.27818798458491e+38*cos(theta)**21 - 8.23441440211412e+37*cos(theta)**19 + 2.17297046722456e+37*cos(theta)**17 - 4.15645546473333e+36*cos(theta)**15 + 5.66789381554545e+35*cos(theta)**13 - 5.35873597106116e+34*cos(theta)**11 + 3.36450317817767e+33*cos(theta)**9 - 1.31226559495554e+32*cos(theta)**7 + 2.8527512933816e+30*cos(theta)**5 - 2.83855850087721e+28*cos(theta)**3 + 8.1881495217612e+25*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl48_m_minus_14(theta, phi):
    return 1.20345553308864e-23*(1.0 - cos(theta)**2)**7*(9.61296732625932e+35*cos(theta)**34 - 5.67671017898051e+36*cos(theta)**32 + 1.51378938106147e+37*cos(theta)**30 - 2.41208198081223e+37*cos(theta)**28 + 2.56114322681748e+37*cos(theta)**26 - 1.9134978131395e+37*cos(theta)**24 + 1.03553999299314e+37*cos(theta)**22 - 4.11720720105706e+36*cos(theta)**20 + 1.20720581512475e+36*cos(theta)**18 - 2.59778466545833e+35*cos(theta)**16 + 4.04849558253247e+34*cos(theta)**14 - 4.46561330921763e+33*cos(theta)**12 + 3.36450317817767e+32*cos(theta)**10 - 1.64033199369442e+31*cos(theta)**8 + 4.75458548896934e+29*cos(theta)**6 - 7.09639625219304e+27*cos(theta)**4 + 4.0940747608806e+25*cos(theta)**2 - 3.82266550969244e+22)*sin(14*phi)

#@torch.jit.script
def Yl48_m_minus_13(theta, phi):
    return 5.60608805466343e-22*(1.0 - cos(theta)**2)**6.5*(2.74656209321695e+34*cos(theta)**35 - 1.72021520575167e+35*cos(theta)**33 + 4.88319155181119e+35*cos(theta)**31 - 8.31752407176631e+35*cos(theta)**29 + 9.48571565487955e+35*cos(theta)**27 - 7.65399125255798e+35*cos(theta)**25 + 4.50234779562234e+35*cos(theta)**23 - 1.96057485764622e+35*cos(theta)**21 + 6.35371481644608e+34*cos(theta)**19 - 1.5281086267402e+34*cos(theta)**17 + 2.69899705502165e+33*cos(theta)**15 - 3.43508716093664e+32*cos(theta)**13 + 3.05863925288879e+31*cos(theta)**11 - 1.82259110410491e+30*cos(theta)**9 + 6.79226498424191e+28*cos(theta)**7 - 1.41927925043861e+27*cos(theta)**5 + 1.3646915869602e+25*cos(theta)**3 - 3.82266550969244e+22*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl48_m_minus_12(theta, phi):
    return 2.62709684472235e-20*(1.0 - cos(theta)**2)**6*(7.62933914782486e+32*cos(theta)**36 - 5.05945648750491e+33*cos(theta)**34 + 1.525997359941e+34*cos(theta)**32 - 2.7725080239221e+34*cos(theta)**30 + 3.38775559102841e+34*cos(theta)**28 - 2.94384278944538e+34*cos(theta)**26 + 1.87597824817598e+34*cos(theta)**24 - 8.9117038983919e+33*cos(theta)**22 + 3.17685740822304e+33*cos(theta)**20 - 8.48949237077887e+32*cos(theta)**18 + 1.68687315938853e+32*cos(theta)**16 - 2.45363368638331e+31*cos(theta)**14 + 2.54886604407399e+30*cos(theta)**12 - 1.82259110410491e+29*cos(theta)**10 + 8.49033123030238e+27*cos(theta)**8 - 2.36546541739768e+26*cos(theta)**6 + 3.4117289674005e+24*cos(theta)**4 - 1.91133275484622e+22*cos(theta)**2 + 1.74074021388544e+19)*sin(12*phi)

#@torch.jit.script
def Yl48_m_minus_11(theta, phi):
    return 1.23780596161278e-18*(1.0 - cos(theta)**2)**5.5*(2.06198355346618e+31*cos(theta)**37 - 1.44555899642997e+32*cos(theta)**35 + 4.62423442406362e+32*cos(theta)**33 - 8.94357427071646e+32*cos(theta)**31 + 1.16819158311325e+33*cos(theta)**29 - 1.09031214423903e+33*cos(theta)**27 + 7.50391299270391e+32*cos(theta)**25 - 3.87465386886604e+32*cos(theta)**23 + 1.51278924201097e+32*cos(theta)**21 - 4.4681538793573e+31*cos(theta)**19 + 9.92278329052075e+30*cos(theta)**17 - 1.63575579092221e+30*cos(theta)**15 + 1.96066618774922e+29*cos(theta)**13 - 1.65690100373174e+28*cos(theta)**11 + 9.43370136700265e+26*cos(theta)**9 - 3.37923631056811e+25*cos(theta)**7 + 6.823457934801e+23*cos(theta)**5 - 6.37110918282073e+21*cos(theta)**3 + 1.74074021388544e+19*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl48_m_minus_10(theta, phi):
    return 5.86098181883417e-17*(1.0 - cos(theta)**2)**5*(5.42627250912152e+29*cos(theta)**38 - 4.01544165674993e+30*cos(theta)**36 + 1.36006894825401e+31*cos(theta)**34 - 2.79486695959889e+31*cos(theta)**32 + 3.89397194371082e+31*cos(theta)**30 - 3.89397194371082e+31*cos(theta)**28 + 2.88612038180919e+31*cos(theta)**26 - 1.61443911202752e+31*cos(theta)**24 + 6.8763147364135e+30*cos(theta)**22 - 2.23407693967865e+30*cos(theta)**20 + 5.51265738362264e+29*cos(theta)**18 - 1.02234736932638e+29*cos(theta)**16 + 1.4004758483923e+28*cos(theta)**14 - 1.38075083644311e+27*cos(theta)**12 + 9.43370136700265e+25*cos(theta)**10 - 4.22404538821014e+24*cos(theta)**8 + 1.1372429891335e+23*cos(theta)**6 - 1.59277729570518e+21*cos(theta)**4 + 8.70370106942722e+18*cos(theta)**2 - 7.76422932152295e+15)*sin(10*phi)

#@torch.jit.script
def Yl48_m_minus_9(theta, phi):
    return 2.78751154304613e-15*(1.0 - cos(theta)**2)**4.5*(1.39135192541577e+28*cos(theta)**39 - 1.0852545018243e+29*cos(theta)**37 + 3.88591128072573e+29*cos(theta)**35 - 8.46929381696635e+29*cos(theta)**33 + 1.2561199818422e+30*cos(theta)**31 - 1.34274894610718e+30*cos(theta)**29 + 1.06893347474415e+30*cos(theta)**27 - 6.45775644811007e+29*cos(theta)**25 + 2.98970205931022e+29*cos(theta)**23 - 1.06384616175174e+29*cos(theta)**21 + 2.90139862295928e+28*cos(theta)**19 - 6.01380805486106e+27*cos(theta)**17 + 9.33650565594868e+26*cos(theta)**15 - 1.06211602803317e+26*cos(theta)**13 + 8.57609215182059e+24*cos(theta)**11 - 4.69338376467793e+23*cos(theta)**9 + 1.62463284161929e+22*cos(theta)**7 - 3.18555459141036e+20*cos(theta)**5 + 2.90123368980907e+18*cos(theta)**3 - 7.76422932152295e+15*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl48_m_minus_8(theta, phi):
    return 1.33101851880292e-13*(1.0 - cos(theta)**2)**4*(3.47837981353944e+26*cos(theta)**40 - 2.85593289953764e+27*cos(theta)**38 + 1.07941980020159e+28*cos(theta)**36 - 2.49096876969598e+28*cos(theta)**34 + 3.92537494325687e+28*cos(theta)**32 - 4.47582982035726e+28*cos(theta)**30 + 3.81761955265766e+28*cos(theta)**28 - 2.48375248004234e+28*cos(theta)**26 + 1.24570919137926e+28*cos(theta)**24 - 4.83566437159881e+27*cos(theta)**22 + 1.45069931147964e+27*cos(theta)**20 - 3.34100447492281e+26*cos(theta)**18 + 5.83531603496793e+25*cos(theta)**16 - 7.58654305737975e+24*cos(theta)**14 + 7.14674345985049e+23*cos(theta)**12 - 4.69338376467793e+22*cos(theta)**10 + 2.03079105202411e+21*cos(theta)**8 - 5.3092576523506e+19*cos(theta)**6 + 7.25308422452268e+17*cos(theta)**4 - 3.88211466076147e+15*cos(theta)**2 + 3405363737510.06)*sin(8*phi)

#@torch.jit.script
def Yl48_m_minus_7(theta, phi):
    return 6.37778742419495e-12*(1.0 - cos(theta)**2)**3.5*(8.48385320375472e+24*cos(theta)**41 - 7.32290487060934e+25*cos(theta)**39 + 2.91735081135566e+26*cos(theta)**37 - 7.11705362770281e+26*cos(theta)**35 + 1.18950755856269e+27*cos(theta)**33 - 1.44381607108299e+27*cos(theta)**31 + 1.31642053539919e+27*cos(theta)**29 - 9.19908325941606e+26*cos(theta)**27 + 4.98283676551703e+26*cos(theta)**25 - 2.10246277026035e+26*cos(theta)**23 + 6.90809195942687e+25*cos(theta)**21 - 1.75842340785411e+25*cos(theta)**19 + 3.43253884409878e+24*cos(theta)**17 - 5.0576953715865e+23*cos(theta)**15 + 5.49749496911576e+22*cos(theta)**13 - 4.26671251334358e+21*cos(theta)**11 + 2.25643450224901e+20*cos(theta)**9 - 7.58465378907229e+18*cos(theta)**7 + 1.45061684490454e+17*cos(theta)**5 - 1.29403822025382e+15*cos(theta)**3 + 3405363737510.06*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl48_m_minus_6(theta, phi):
    return 3.06532148899894e-10*(1.0 - cos(theta)**2)**3*(2.01996504851303e+23*cos(theta)**42 - 1.83072621765233e+24*cos(theta)**40 + 7.67723897725173e+24*cos(theta)**38 - 1.97695934102856e+25*cos(theta)**36 + 3.49855164283144e+25*cos(theta)**34 - 4.51192522213434e+25*cos(theta)**32 + 4.38806845133065e+25*cos(theta)**30 - 3.28538687836288e+25*cos(theta)**28 + 1.91647567904501e+25*cos(theta)**26 - 8.76026154275146e+24*cos(theta)**24 + 3.14004179973949e+24*cos(theta)**22 - 8.79211703927056e+23*cos(theta)**20 + 1.90696602449932e+23*cos(theta)**18 - 3.16105960724156e+22*cos(theta)**16 + 3.92678212079697e+21*cos(theta)**14 - 3.55559376111965e+20*cos(theta)**12 + 2.25643450224901e+19*cos(theta)**10 - 9.48081723634037e+17*cos(theta)**8 + 2.41769474150756e+16*cos(theta)**6 - 323509555063456.0*cos(theta)**4 + 1702681868755.03*cos(theta)**2 - 1474183436.15154)*sin(6*phi)

#@torch.jit.script
def Yl48_m_minus_5(theta, phi):
    return 1.47709061060563e-8*(1.0 - cos(theta)**2)**2.5*(4.69759313607681e+21*cos(theta)**43 - 4.46518589671301e+22*cos(theta)**41 + 1.96852281467993e+23*cos(theta)**39 - 5.34313335413124e+23*cos(theta)**37 + 9.99586183666125e+23*cos(theta)**35 - 1.36725006731344e+24*cos(theta)**33 + 1.41550595204214e+24*cos(theta)**31 - 1.13289202702168e+24*cos(theta)**29 + 7.09805807053708e+23*cos(theta)**27 - 3.50410461710059e+23*cos(theta)**25 + 1.36523556510412e+23*cos(theta)**23 - 4.18672239965265e+22*cos(theta)**21 + 1.00366632868385e+22*cos(theta)**19 - 1.85944682778916e+21*cos(theta)**17 + 2.61785474719798e+20*cos(theta)**15 - 2.73507212393819e+19*cos(theta)**13 + 2.05130409295364e+18*cos(theta)**11 - 1.05342413737115e+17*cos(theta)**9 + 3.45384963072509e+15*cos(theta)**7 - 64701911012691.2*cos(theta)**5 + 567560622918.344*cos(theta)**3 - 1474183436.15154*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl48_m_minus_4(theta, phi):
    return 7.13298663882281e-7*(1.0 - cos(theta)**2)**2*(1.06763480365382e+20*cos(theta)**44 - 1.06313949921738e+21*cos(theta)**42 + 4.92130703669983e+21*cos(theta)**40 - 1.40608772477138e+22*cos(theta)**38 + 2.77662828796146e+22*cos(theta)**36 - 4.02132372739246e+22*cos(theta)**34 + 4.4234561001317e+22*cos(theta)**32 - 3.77630675673894e+22*cos(theta)**30 + 2.53502073947753e+22*cos(theta)**28 - 1.34773254503869e+22*cos(theta)**26 + 5.68848152126718e+21*cos(theta)**24 - 1.90305563620575e+21*cos(theta)**22 + 5.01833164341927e+20*cos(theta)**20 - 1.03302601543842e+20*cos(theta)**18 + 1.63615921699874e+19*cos(theta)**16 - 1.95362294567014e+18*cos(theta)**14 + 1.70942007746137e+17*cos(theta)**12 - 1.05342413737115e+16*cos(theta)**10 + 431731203840636.0*cos(theta)**8 - 10783651835448.5*cos(theta)**6 + 141890155729.586*cos(theta)**4 - 737091718.075771*cos(theta)**2 + 632154.132140456)*sin(4*phi)

#@torch.jit.script
def Yl48_m_minus_3(theta, phi):
    return 3.45047860784155e-5*(1.0 - cos(theta)**2)**1.5*(2.37252178589738e+18*cos(theta)**45 - 2.47241744004043e+19*cos(theta)**43 + 1.20031878943898e+20*cos(theta)**41 - 3.60535314043943e+20*cos(theta)**39 + 7.50440077827421e+20*cos(theta)**37 - 1.14894963639784e+21*cos(theta)**35 + 1.34044124246415e+21*cos(theta)**33 - 1.21816346991579e+21*cos(theta)**31 + 8.74145082578459e+20*cos(theta)**29 - 4.9916020186618e+20*cos(theta)**27 + 2.27539260850687e+20*cos(theta)**25 - 8.27415494002499e+19*cos(theta)**23 + 2.38968173496156e+19*cos(theta)**21 - 5.43697902862326e+18*cos(theta)**19 + 9.62446598234552e+17*cos(theta)**17 - 1.30241529711342e+17*cos(theta)**15 + 1.31493852112413e+16*cos(theta)**13 - 957658306701047.0*cos(theta)**11 + 47970133760070.7*cos(theta)**9 - 1540521690778.36*cos(theta)**7 + 28378031145.9172*cos(theta)**5 - 245697239.35859*cos(theta)**3 + 632154.132140456*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl48_m_minus_2(theta, phi):
    return 0.0016712573995038*(1.0 - cos(theta)**2)*(5.15765605629865e+16*cos(theta)**46 - 5.61913054554643e+17*cos(theta)**44 + 2.85790187961662e+18*cos(theta)**42 - 9.01338285109858e+18*cos(theta)**40 + 1.97484231007216e+19*cos(theta)**38 - 3.19152676777179e+19*cos(theta)**36 + 3.94247424254162e+19*cos(theta)**34 - 3.80676084348684e+19*cos(theta)**32 + 2.91381694192819e+19*cos(theta)**30 - 1.78271500666493e+19*cos(theta)**28 + 8.75151003271874e+18*cos(theta)**26 - 3.44756455834375e+18*cos(theta)**24 + 1.08621897043707e+18*cos(theta)**22 - 2.71848951431163e+17*cos(theta)**20 + 5.34692554574751e+16*cos(theta)**18 - 8.1400956069589e+15*cos(theta)**16 + 939241800802950.0*cos(theta)**14 - 79804858891753.9*cos(theta)**12 + 4797013376007.07*cos(theta)**10 - 192565211347.295*cos(theta)**8 + 4729671857.65287*cos(theta)**6 - 61424309.8396476*cos(theta)**4 + 316077.066070228*cos(theta)**2 - 269.460414382121)*sin(2*phi)

#@torch.jit.script
def Yl48_m_minus_1(theta, phi):
    return 0.0810172083213255*(1.0 - cos(theta)**2)**0.5*(1.09737362899971e+15*cos(theta)**47 - 1.24869567678809e+16*cos(theta)**45 + 6.64628344096889e+16*cos(theta)**43 - 2.19838606124356e+17*cos(theta)**41 + 5.06369823095426e+17*cos(theta)**39 - 8.62574802100484e+17*cos(theta)**37 + 1.12642121215475e+18*cos(theta)**35 - 1.15356389196571e+18*cos(theta)**33 + 9.39940949009095e+17*cos(theta)**31 - 6.14729312643079e+17*cos(theta)**29 + 3.24130001211805e+17*cos(theta)**27 - 1.3790258233375e+17*cos(theta)**25 + 4.72269117581335e+16*cos(theta)**23 - 1.29451881633887e+16*cos(theta)**21 + 2.81417133986711e+15*cos(theta)**19 - 478829153350524.0*cos(theta)**17 + 62616120053530.0*cos(theta)**15 - 6138835299365.69*cos(theta)**13 + 436092125091.551*cos(theta)**11 - 21396134594.1439*cos(theta)**9 + 675667408.236124*cos(theta)**7 - 12284861.9679295*cos(theta)**5 + 105359.022023409*cos(theta)**3 - 269.460414382121*cos(theta))*sin(phi)

#@torch.jit.script
def Yl48_m0(theta, phi):
    return 199546488572317.0*cos(theta)**48 - 2.36935199062709e+15*cos(theta)**46 + 1.31842973671991e+16*cos(theta)**44 - 4.56862465544702e+16*cos(theta)**42 + 1.10493983942132e+17*cos(theta)**40 - 1.98127143620374e+17*cos(theta)**38 + 2.73104670519849e+17*cos(theta)**36 - 2.96137594539595e+17*cos(theta)**34 + 2.5637838045789e+17*cos(theta)**32 - 1.78851865973437e+17*cos(theta)**30 + 1.01039690517461e+17*cos(theta)**28 - 4.62945491098185e+16*cos(theta)**26 + 1.71754891103779e+16*cos(theta)**24 - 5.13589923560595e+15*cos(theta)**22 + 1.22814981721012e+15*cos(theta)**20 - 232187527631764.0*cos(theta)**18 + 34158357430442.2*cos(theta)**16 - 3827266938985.12*cos(theta)**14 + 317196075999.677*cos(theta)**12 - 18675237302.3896*cos(theta)**10 + 737180419.831167*cos(theta)**8 - 17871040.4807556*cos(theta)**6 + 229901.89297713*cos(theta)**4 - 1175.96876203136*cos(theta)**2 + 0.999973437101492

#@torch.jit.script
def Yl48_m1(theta, phi):
    return 0.0810172083213255*(1.0 - cos(theta)**2)**0.5*(1.09737362899971e+15*cos(theta)**47 - 1.24869567678809e+16*cos(theta)**45 + 6.64628344096889e+16*cos(theta)**43 - 2.19838606124356e+17*cos(theta)**41 + 5.06369823095426e+17*cos(theta)**39 - 8.62574802100484e+17*cos(theta)**37 + 1.12642121215475e+18*cos(theta)**35 - 1.15356389196571e+18*cos(theta)**33 + 9.39940949009095e+17*cos(theta)**31 - 6.14729312643079e+17*cos(theta)**29 + 3.24130001211805e+17*cos(theta)**27 - 1.3790258233375e+17*cos(theta)**25 + 4.72269117581335e+16*cos(theta)**23 - 1.29451881633887e+16*cos(theta)**21 + 2.81417133986711e+15*cos(theta)**19 - 478829153350524.0*cos(theta)**17 + 62616120053530.0*cos(theta)**15 - 6138835299365.69*cos(theta)**13 + 436092125091.551*cos(theta)**11 - 21396134594.1439*cos(theta)**9 + 675667408.236124*cos(theta)**7 - 12284861.9679295*cos(theta)**5 + 105359.022023409*cos(theta)**3 - 269.460414382121*cos(theta))*cos(phi)

#@torch.jit.script
def Yl48_m2(theta, phi):
    return 0.0016712573995038*(1.0 - cos(theta)**2)*(5.15765605629865e+16*cos(theta)**46 - 5.61913054554643e+17*cos(theta)**44 + 2.85790187961662e+18*cos(theta)**42 - 9.01338285109858e+18*cos(theta)**40 + 1.97484231007216e+19*cos(theta)**38 - 3.19152676777179e+19*cos(theta)**36 + 3.94247424254162e+19*cos(theta)**34 - 3.80676084348684e+19*cos(theta)**32 + 2.91381694192819e+19*cos(theta)**30 - 1.78271500666493e+19*cos(theta)**28 + 8.75151003271874e+18*cos(theta)**26 - 3.44756455834375e+18*cos(theta)**24 + 1.08621897043707e+18*cos(theta)**22 - 2.71848951431163e+17*cos(theta)**20 + 5.34692554574751e+16*cos(theta)**18 - 8.1400956069589e+15*cos(theta)**16 + 939241800802950.0*cos(theta)**14 - 79804858891753.9*cos(theta)**12 + 4797013376007.07*cos(theta)**10 - 192565211347.295*cos(theta)**8 + 4729671857.65287*cos(theta)**6 - 61424309.8396476*cos(theta)**4 + 316077.066070228*cos(theta)**2 - 269.460414382121)*cos(2*phi)

#@torch.jit.script
def Yl48_m3(theta, phi):
    return 3.45047860784155e-5*(1.0 - cos(theta)**2)**1.5*(2.37252178589738e+18*cos(theta)**45 - 2.47241744004043e+19*cos(theta)**43 + 1.20031878943898e+20*cos(theta)**41 - 3.60535314043943e+20*cos(theta)**39 + 7.50440077827421e+20*cos(theta)**37 - 1.14894963639784e+21*cos(theta)**35 + 1.34044124246415e+21*cos(theta)**33 - 1.21816346991579e+21*cos(theta)**31 + 8.74145082578459e+20*cos(theta)**29 - 4.9916020186618e+20*cos(theta)**27 + 2.27539260850687e+20*cos(theta)**25 - 8.27415494002499e+19*cos(theta)**23 + 2.38968173496156e+19*cos(theta)**21 - 5.43697902862326e+18*cos(theta)**19 + 9.62446598234552e+17*cos(theta)**17 - 1.30241529711342e+17*cos(theta)**15 + 1.31493852112413e+16*cos(theta)**13 - 957658306701047.0*cos(theta)**11 + 47970133760070.7*cos(theta)**9 - 1540521690778.36*cos(theta)**7 + 28378031145.9172*cos(theta)**5 - 245697239.35859*cos(theta)**3 + 632154.132140456*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl48_m4(theta, phi):
    return 7.13298663882281e-7*(1.0 - cos(theta)**2)**2*(1.06763480365382e+20*cos(theta)**44 - 1.06313949921738e+21*cos(theta)**42 + 4.92130703669983e+21*cos(theta)**40 - 1.40608772477138e+22*cos(theta)**38 + 2.77662828796146e+22*cos(theta)**36 - 4.02132372739246e+22*cos(theta)**34 + 4.4234561001317e+22*cos(theta)**32 - 3.77630675673894e+22*cos(theta)**30 + 2.53502073947753e+22*cos(theta)**28 - 1.34773254503869e+22*cos(theta)**26 + 5.68848152126718e+21*cos(theta)**24 - 1.90305563620575e+21*cos(theta)**22 + 5.01833164341927e+20*cos(theta)**20 - 1.03302601543842e+20*cos(theta)**18 + 1.63615921699874e+19*cos(theta)**16 - 1.95362294567014e+18*cos(theta)**14 + 1.70942007746137e+17*cos(theta)**12 - 1.05342413737115e+16*cos(theta)**10 + 431731203840636.0*cos(theta)**8 - 10783651835448.5*cos(theta)**6 + 141890155729.586*cos(theta)**4 - 737091718.075771*cos(theta)**2 + 632154.132140456)*cos(4*phi)

#@torch.jit.script
def Yl48_m5(theta, phi):
    return 1.47709061060563e-8*(1.0 - cos(theta)**2)**2.5*(4.69759313607681e+21*cos(theta)**43 - 4.46518589671301e+22*cos(theta)**41 + 1.96852281467993e+23*cos(theta)**39 - 5.34313335413124e+23*cos(theta)**37 + 9.99586183666125e+23*cos(theta)**35 - 1.36725006731344e+24*cos(theta)**33 + 1.41550595204214e+24*cos(theta)**31 - 1.13289202702168e+24*cos(theta)**29 + 7.09805807053708e+23*cos(theta)**27 - 3.50410461710059e+23*cos(theta)**25 + 1.36523556510412e+23*cos(theta)**23 - 4.18672239965265e+22*cos(theta)**21 + 1.00366632868385e+22*cos(theta)**19 - 1.85944682778916e+21*cos(theta)**17 + 2.61785474719798e+20*cos(theta)**15 - 2.73507212393819e+19*cos(theta)**13 + 2.05130409295364e+18*cos(theta)**11 - 1.05342413737115e+17*cos(theta)**9 + 3.45384963072509e+15*cos(theta)**7 - 64701911012691.2*cos(theta)**5 + 567560622918.344*cos(theta)**3 - 1474183436.15154*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl48_m6(theta, phi):
    return 3.06532148899894e-10*(1.0 - cos(theta)**2)**3*(2.01996504851303e+23*cos(theta)**42 - 1.83072621765233e+24*cos(theta)**40 + 7.67723897725173e+24*cos(theta)**38 - 1.97695934102856e+25*cos(theta)**36 + 3.49855164283144e+25*cos(theta)**34 - 4.51192522213434e+25*cos(theta)**32 + 4.38806845133065e+25*cos(theta)**30 - 3.28538687836288e+25*cos(theta)**28 + 1.91647567904501e+25*cos(theta)**26 - 8.76026154275146e+24*cos(theta)**24 + 3.14004179973949e+24*cos(theta)**22 - 8.79211703927056e+23*cos(theta)**20 + 1.90696602449932e+23*cos(theta)**18 - 3.16105960724156e+22*cos(theta)**16 + 3.92678212079697e+21*cos(theta)**14 - 3.55559376111965e+20*cos(theta)**12 + 2.25643450224901e+19*cos(theta)**10 - 9.48081723634037e+17*cos(theta)**8 + 2.41769474150756e+16*cos(theta)**6 - 323509555063456.0*cos(theta)**4 + 1702681868755.03*cos(theta)**2 - 1474183436.15154)*cos(6*phi)

#@torch.jit.script
def Yl48_m7(theta, phi):
    return 6.37778742419495e-12*(1.0 - cos(theta)**2)**3.5*(8.48385320375472e+24*cos(theta)**41 - 7.32290487060934e+25*cos(theta)**39 + 2.91735081135566e+26*cos(theta)**37 - 7.11705362770281e+26*cos(theta)**35 + 1.18950755856269e+27*cos(theta)**33 - 1.44381607108299e+27*cos(theta)**31 + 1.31642053539919e+27*cos(theta)**29 - 9.19908325941606e+26*cos(theta)**27 + 4.98283676551703e+26*cos(theta)**25 - 2.10246277026035e+26*cos(theta)**23 + 6.90809195942687e+25*cos(theta)**21 - 1.75842340785411e+25*cos(theta)**19 + 3.43253884409878e+24*cos(theta)**17 - 5.0576953715865e+23*cos(theta)**15 + 5.49749496911576e+22*cos(theta)**13 - 4.26671251334358e+21*cos(theta)**11 + 2.25643450224901e+20*cos(theta)**9 - 7.58465378907229e+18*cos(theta)**7 + 1.45061684490454e+17*cos(theta)**5 - 1.29403822025382e+15*cos(theta)**3 + 3405363737510.06*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl48_m8(theta, phi):
    return 1.33101851880292e-13*(1.0 - cos(theta)**2)**4*(3.47837981353944e+26*cos(theta)**40 - 2.85593289953764e+27*cos(theta)**38 + 1.07941980020159e+28*cos(theta)**36 - 2.49096876969598e+28*cos(theta)**34 + 3.92537494325687e+28*cos(theta)**32 - 4.47582982035726e+28*cos(theta)**30 + 3.81761955265766e+28*cos(theta)**28 - 2.48375248004234e+28*cos(theta)**26 + 1.24570919137926e+28*cos(theta)**24 - 4.83566437159881e+27*cos(theta)**22 + 1.45069931147964e+27*cos(theta)**20 - 3.34100447492281e+26*cos(theta)**18 + 5.83531603496793e+25*cos(theta)**16 - 7.58654305737975e+24*cos(theta)**14 + 7.14674345985049e+23*cos(theta)**12 - 4.69338376467793e+22*cos(theta)**10 + 2.03079105202411e+21*cos(theta)**8 - 5.3092576523506e+19*cos(theta)**6 + 7.25308422452268e+17*cos(theta)**4 - 3.88211466076147e+15*cos(theta)**2 + 3405363737510.06)*cos(8*phi)

#@torch.jit.script
def Yl48_m9(theta, phi):
    return 2.78751154304613e-15*(1.0 - cos(theta)**2)**4.5*(1.39135192541577e+28*cos(theta)**39 - 1.0852545018243e+29*cos(theta)**37 + 3.88591128072573e+29*cos(theta)**35 - 8.46929381696635e+29*cos(theta)**33 + 1.2561199818422e+30*cos(theta)**31 - 1.34274894610718e+30*cos(theta)**29 + 1.06893347474415e+30*cos(theta)**27 - 6.45775644811007e+29*cos(theta)**25 + 2.98970205931022e+29*cos(theta)**23 - 1.06384616175174e+29*cos(theta)**21 + 2.90139862295928e+28*cos(theta)**19 - 6.01380805486106e+27*cos(theta)**17 + 9.33650565594868e+26*cos(theta)**15 - 1.06211602803317e+26*cos(theta)**13 + 8.57609215182059e+24*cos(theta)**11 - 4.69338376467793e+23*cos(theta)**9 + 1.62463284161929e+22*cos(theta)**7 - 3.18555459141036e+20*cos(theta)**5 + 2.90123368980907e+18*cos(theta)**3 - 7.76422932152295e+15*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl48_m10(theta, phi):
    return 5.86098181883417e-17*(1.0 - cos(theta)**2)**5*(5.42627250912152e+29*cos(theta)**38 - 4.01544165674993e+30*cos(theta)**36 + 1.36006894825401e+31*cos(theta)**34 - 2.79486695959889e+31*cos(theta)**32 + 3.89397194371082e+31*cos(theta)**30 - 3.89397194371082e+31*cos(theta)**28 + 2.88612038180919e+31*cos(theta)**26 - 1.61443911202752e+31*cos(theta)**24 + 6.8763147364135e+30*cos(theta)**22 - 2.23407693967865e+30*cos(theta)**20 + 5.51265738362264e+29*cos(theta)**18 - 1.02234736932638e+29*cos(theta)**16 + 1.4004758483923e+28*cos(theta)**14 - 1.38075083644311e+27*cos(theta)**12 + 9.43370136700265e+25*cos(theta)**10 - 4.22404538821014e+24*cos(theta)**8 + 1.1372429891335e+23*cos(theta)**6 - 1.59277729570518e+21*cos(theta)**4 + 8.70370106942722e+18*cos(theta)**2 - 7.76422932152295e+15)*cos(10*phi)

#@torch.jit.script
def Yl48_m11(theta, phi):
    return 1.23780596161278e-18*(1.0 - cos(theta)**2)**5.5*(2.06198355346618e+31*cos(theta)**37 - 1.44555899642997e+32*cos(theta)**35 + 4.62423442406362e+32*cos(theta)**33 - 8.94357427071646e+32*cos(theta)**31 + 1.16819158311325e+33*cos(theta)**29 - 1.09031214423903e+33*cos(theta)**27 + 7.50391299270391e+32*cos(theta)**25 - 3.87465386886604e+32*cos(theta)**23 + 1.51278924201097e+32*cos(theta)**21 - 4.4681538793573e+31*cos(theta)**19 + 9.92278329052075e+30*cos(theta)**17 - 1.63575579092221e+30*cos(theta)**15 + 1.96066618774922e+29*cos(theta)**13 - 1.65690100373174e+28*cos(theta)**11 + 9.43370136700265e+26*cos(theta)**9 - 3.37923631056811e+25*cos(theta)**7 + 6.823457934801e+23*cos(theta)**5 - 6.37110918282073e+21*cos(theta)**3 + 1.74074021388544e+19*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl48_m12(theta, phi):
    return 2.62709684472235e-20*(1.0 - cos(theta)**2)**6*(7.62933914782486e+32*cos(theta)**36 - 5.05945648750491e+33*cos(theta)**34 + 1.525997359941e+34*cos(theta)**32 - 2.7725080239221e+34*cos(theta)**30 + 3.38775559102841e+34*cos(theta)**28 - 2.94384278944538e+34*cos(theta)**26 + 1.87597824817598e+34*cos(theta)**24 - 8.9117038983919e+33*cos(theta)**22 + 3.17685740822304e+33*cos(theta)**20 - 8.48949237077887e+32*cos(theta)**18 + 1.68687315938853e+32*cos(theta)**16 - 2.45363368638331e+31*cos(theta)**14 + 2.54886604407399e+30*cos(theta)**12 - 1.82259110410491e+29*cos(theta)**10 + 8.49033123030238e+27*cos(theta)**8 - 2.36546541739768e+26*cos(theta)**6 + 3.4117289674005e+24*cos(theta)**4 - 1.91133275484622e+22*cos(theta)**2 + 1.74074021388544e+19)*cos(12*phi)

#@torch.jit.script
def Yl48_m13(theta, phi):
    return 5.60608805466343e-22*(1.0 - cos(theta)**2)**6.5*(2.74656209321695e+34*cos(theta)**35 - 1.72021520575167e+35*cos(theta)**33 + 4.88319155181119e+35*cos(theta)**31 - 8.31752407176631e+35*cos(theta)**29 + 9.48571565487955e+35*cos(theta)**27 - 7.65399125255798e+35*cos(theta)**25 + 4.50234779562234e+35*cos(theta)**23 - 1.96057485764622e+35*cos(theta)**21 + 6.35371481644608e+34*cos(theta)**19 - 1.5281086267402e+34*cos(theta)**17 + 2.69899705502165e+33*cos(theta)**15 - 3.43508716093664e+32*cos(theta)**13 + 3.05863925288879e+31*cos(theta)**11 - 1.82259110410491e+30*cos(theta)**9 + 6.79226498424191e+28*cos(theta)**7 - 1.41927925043861e+27*cos(theta)**5 + 1.3646915869602e+25*cos(theta)**3 - 3.82266550969244e+22*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl48_m14(theta, phi):
    return 1.20345553308864e-23*(1.0 - cos(theta)**2)**7*(9.61296732625932e+35*cos(theta)**34 - 5.67671017898051e+36*cos(theta)**32 + 1.51378938106147e+37*cos(theta)**30 - 2.41208198081223e+37*cos(theta)**28 + 2.56114322681748e+37*cos(theta)**26 - 1.9134978131395e+37*cos(theta)**24 + 1.03553999299314e+37*cos(theta)**22 - 4.11720720105706e+36*cos(theta)**20 + 1.20720581512475e+36*cos(theta)**18 - 2.59778466545833e+35*cos(theta)**16 + 4.04849558253247e+34*cos(theta)**14 - 4.46561330921763e+33*cos(theta)**12 + 3.36450317817767e+32*cos(theta)**10 - 1.64033199369442e+31*cos(theta)**8 + 4.75458548896934e+29*cos(theta)**6 - 7.09639625219304e+27*cos(theta)**4 + 4.0940747608806e+25*cos(theta)**2 - 3.82266550969244e+22)*cos(14*phi)

#@torch.jit.script
def Yl48_m15(theta, phi):
    return 2.60028119225837e-25*(1.0 - cos(theta)**2)**7.5*(3.26840889092817e+37*cos(theta)**33 - 1.81654725727376e+38*cos(theta)**31 + 4.5413681431844e+38*cos(theta)**29 - 6.75382954627424e+38*cos(theta)**27 + 6.65897238972545e+38*cos(theta)**25 - 4.59239475153479e+38*cos(theta)**23 + 2.27818798458491e+38*cos(theta)**21 - 8.23441440211412e+37*cos(theta)**19 + 2.17297046722456e+37*cos(theta)**17 - 4.15645546473333e+36*cos(theta)**15 + 5.66789381554545e+35*cos(theta)**13 - 5.35873597106116e+34*cos(theta)**11 + 3.36450317817767e+33*cos(theta)**9 - 1.31226559495554e+32*cos(theta)**7 + 2.8527512933816e+30*cos(theta)**5 - 2.83855850087721e+28*cos(theta)**3 + 8.1881495217612e+25*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl48_m16(theta, phi):
    return 5.6581356846753e-27*(1.0 - cos(theta)**2)**8*(1.0785749340063e+39*cos(theta)**32 - 5.63129649754866e+39*cos(theta)**30 + 1.31699676152348e+40*cos(theta)**28 - 1.82353397749405e+40*cos(theta)**26 + 1.66474309743136e+40*cos(theta)**24 - 1.056250792853e+40*cos(theta)**22 + 4.7841947676283e+39*cos(theta)**20 - 1.56453873640168e+39*cos(theta)**18 + 3.69404979428175e+38*cos(theta)**16 - 6.2346831971e+37*cos(theta)**14 + 7.36826196020909e+36*cos(theta)**12 - 5.89460956816727e+35*cos(theta)**10 + 3.0280528603599e+34*cos(theta)**8 - 9.18585916468876e+32*cos(theta)**6 + 1.4263756466908e+31*cos(theta)**4 - 8.51567550263164e+28*cos(theta)**2 + 8.1881495217612e+25)*cos(16*phi)

#@torch.jit.script
def Yl48_m17(theta, phi):
    return 1.24062831914294e-28*(1.0 - cos(theta)**2)**8.5*(3.45143978882015e+40*cos(theta)**31 - 1.6893889492646e+41*cos(theta)**29 + 3.68759093226574e+41*cos(theta)**27 - 4.74118834148452e+41*cos(theta)**25 + 3.99538343383527e+41*cos(theta)**23 - 2.3237517442766e+41*cos(theta)**21 + 9.5683895352566e+40*cos(theta)**19 - 2.81616972552303e+40*cos(theta)**17 + 5.9104796708508e+39*cos(theta)**15 - 8.72855647594e+38*cos(theta)**13 + 8.84191435225091e+37*cos(theta)**11 - 5.89460956816727e+36*cos(theta)**9 + 2.42244228828792e+35*cos(theta)**7 - 5.51151549881325e+33*cos(theta)**5 + 5.7055025867632e+31*cos(theta)**3 - 1.70313510052633e+29*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl48_m18(theta, phi):
    return 2.7427667480681e-30*(1.0 - cos(theta)**2)**9*(1.06994633453425e+42*cos(theta)**30 - 4.89922795286733e+42*cos(theta)**28 + 9.95649551711749e+42*cos(theta)**26 - 1.18529708537113e+43*cos(theta)**24 + 9.18938189782112e+42*cos(theta)**22 - 4.87987866298087e+42*cos(theta)**20 + 1.81799401169875e+42*cos(theta)**18 - 4.78748853338915e+41*cos(theta)**16 + 8.8657195062762e+40*cos(theta)**14 - 1.1347123418722e+40*cos(theta)**12 + 9.726105787476e+38*cos(theta)**10 - 5.30514861135055e+37*cos(theta)**8 + 1.69570960180154e+36*cos(theta)**6 - 2.75575774940663e+34*cos(theta)**4 + 1.71165077602896e+32*cos(theta)**2 - 1.70313510052633e+29)*cos(18*phi)

#@torch.jit.script
def Yl48_m19(theta, phi):
    return 6.11773762133704e-32*(1.0 - cos(theta)**2)**9.5*(3.20983900360274e+43*cos(theta)**29 - 1.37178382680285e+44*cos(theta)**27 + 2.58868883445055e+44*cos(theta)**25 - 2.84471300489071e+44*cos(theta)**23 + 2.02166401752065e+44*cos(theta)**21 - 9.75975732596174e+43*cos(theta)**19 + 3.27238922105776e+43*cos(theta)**17 - 7.65998165342264e+42*cos(theta)**15 + 1.24120073087867e+42*cos(theta)**13 - 1.36165481024664e+41*cos(theta)**11 + 9.726105787476e+39*cos(theta)**9 - 4.24411888908044e+38*cos(theta)**7 + 1.01742576108093e+37*cos(theta)**5 - 1.10230309976265e+35*cos(theta)**3 + 3.42330155205792e+32*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl48_m20(theta, phi):
    return 1.37764522622734e-33*(1.0 - cos(theta)**2)**10*(9.30853311044794e+44*cos(theta)**28 - 3.70381633236771e+45*cos(theta)**26 + 6.47172208612637e+45*cos(theta)**24 - 6.54283991124863e+45*cos(theta)**22 + 4.24549443679336e+45*cos(theta)**20 - 1.85435389193273e+45*cos(theta)**18 + 5.56306167579819e+44*cos(theta)**16 - 1.1489972480134e+44*cos(theta)**14 + 1.61356095014227e+43*cos(theta)**12 - 1.4978202912713e+42*cos(theta)**10 + 8.7534952087284e+40*cos(theta)**8 - 2.97088322235631e+39*cos(theta)**6 + 5.08712880540463e+37*cos(theta)**4 - 3.30690929928795e+35*cos(theta)**2 + 3.42330155205792e+32)*cos(20*phi)

#@torch.jit.script
def Yl48_m21(theta, phi):
    return 3.13425141500133e-35*(1.0 - cos(theta)**2)**10.5*(2.60638927092542e+46*cos(theta)**27 - 9.62992246415603e+46*cos(theta)**25 + 1.55321330067033e+47*cos(theta)**23 - 1.4394247804747e+47*cos(theta)**21 + 8.49098887358671e+46*cos(theta)**19 - 3.33783700547891e+46*cos(theta)**17 + 8.9008986812771e+45*cos(theta)**15 - 1.60859614721875e+45*cos(theta)**13 + 1.93627314017072e+44*cos(theta)**11 - 1.4978202912713e+43*cos(theta)**9 + 7.00279616698272e+41*cos(theta)**7 - 1.78252993341378e+40*cos(theta)**5 + 2.03485152216185e+38*cos(theta)**3 - 6.6138185985759e+35*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl48_m22(theta, phi):
    return 7.20946318604152e-37*(1.0 - cos(theta)**2)**11*(7.03725103149864e+47*cos(theta)**26 - 2.40748061603901e+48*cos(theta)**24 + 3.57239059154175e+48*cos(theta)**22 - 3.02279203899687e+48*cos(theta)**20 + 1.61328788598148e+48*cos(theta)**18 - 5.67432290931415e+47*cos(theta)**16 + 1.33513480219157e+47*cos(theta)**14 - 2.09117499138438e+46*cos(theta)**12 + 2.12990045418779e+45*cos(theta)**10 - 1.34803826214417e+44*cos(theta)**8 + 4.9019573168879e+42*cos(theta)**6 - 8.91264966706892e+40*cos(theta)**4 + 6.10455456648556e+38*cos(theta)**2 - 6.6138185985759e+35)*cos(22*phi)

#@torch.jit.script
def Yl48_m23(theta, phi):
    return 1.67798115928159e-38*(1.0 - cos(theta)**2)**11.5*(1.82968526818965e+49*cos(theta)**25 - 5.77795347849362e+49*cos(theta)**23 + 7.85925930139186e+49*cos(theta)**21 - 6.04558407799374e+49*cos(theta)**19 + 2.90391819476665e+49*cos(theta)**17 - 9.07891665490265e+48*cos(theta)**15 + 1.86918872306819e+48*cos(theta)**13 - 2.50940998966126e+47*cos(theta)**11 + 2.12990045418779e+46*cos(theta)**9 - 1.07843060971534e+45*cos(theta)**7 + 2.94117439013274e+43*cos(theta)**5 - 3.56505986682757e+41*cos(theta)**3 + 1.22091091329711e+39*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl48_m24(theta, phi):
    return 3.9550395214376e-40*(1.0 - cos(theta)**2)**12*(4.57421317047412e+50*cos(theta)**24 - 1.32892930005353e+51*cos(theta)**22 + 1.65044445329229e+51*cos(theta)**20 - 1.14866097481881e+51*cos(theta)**18 + 4.93666093110331e+50*cos(theta)**16 - 1.3618374982354e+50*cos(theta)**14 + 2.42994533998865e+49*cos(theta)**12 - 2.76035098862738e+48*cos(theta)**10 + 1.91691040876902e+47*cos(theta)**8 - 7.54901426800737e+45*cos(theta)**6 + 1.47058719506637e+44*cos(theta)**4 - 1.06951796004827e+42*cos(theta)**2 + 1.22091091329711e+39)*cos(24*phi)

#@torch.jit.script
def Yl48_m25(theta, phi):
    return 9.44895491313896e-42*(1.0 - cos(theta)**2)**12.5*(1.09781116091379e+52*cos(theta)**23 - 2.92364446011777e+52*cos(theta)**21 + 3.30088890658458e+52*cos(theta)**19 - 2.06758975467386e+52*cos(theta)**17 + 7.8986574897653e+51*cos(theta)**15 - 1.90657249752956e+51*cos(theta)**13 + 2.91593440798638e+50*cos(theta)**11 - 2.76035098862738e+49*cos(theta)**9 + 1.53352832701521e+48*cos(theta)**7 - 4.52940856080442e+46*cos(theta)**5 + 5.88234878026548e+44*cos(theta)**3 - 2.13903592009654e+42*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl48_m26(theta, phi):
    return 2.29036131046255e-43*(1.0 - cos(theta)**2)**13*(2.52496567010171e+53*cos(theta)**22 - 6.13965336624732e+53*cos(theta)**20 + 6.2716889225107e+53*cos(theta)**18 - 3.51490258294556e+53*cos(theta)**16 + 1.1847986234648e+53*cos(theta)**14 - 2.47854424678842e+52*cos(theta)**12 + 3.20752784878502e+51*cos(theta)**10 - 2.48431588976464e+50*cos(theta)**8 + 1.07346982891065e+49*cos(theta)**6 - 2.26470428040221e+47*cos(theta)**4 + 1.76470463407965e+45*cos(theta)**2 - 2.13903592009654e+42)*cos(26*phi)

#@torch.jit.script
def Yl48_m27(theta, phi):
    return 5.63847977172428e-45*(1.0 - cos(theta)**2)**13.5*(5.55492447422377e+54*cos(theta)**21 - 1.22793067324946e+55*cos(theta)**19 + 1.12890400605193e+55*cos(theta)**17 - 5.6238441327129e+54*cos(theta)**15 + 1.65871807285071e+54*cos(theta)**13 - 2.97425309614611e+53*cos(theta)**11 + 3.20752784878502e+52*cos(theta)**9 - 1.98745271181171e+51*cos(theta)**7 + 6.44081897346389e+49*cos(theta)**5 - 9.05881712160885e+47*cos(theta)**3 + 3.52940926815929e+45*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl48_m28(theta, phi):
    return 1.41138527855448e-46*(1.0 - cos(theta)**2)**14*(1.16653413958699e+56*cos(theta)**20 - 2.33306827917398e+56*cos(theta)**18 + 1.91913681028828e+56*cos(theta)**16 - 8.43576619906934e+55*cos(theta)**14 + 2.15633349470593e+55*cos(theta)**12 - 3.27167840576072e+54*cos(theta)**10 + 2.88677506390652e+53*cos(theta)**8 - 1.3912168982682e+52*cos(theta)**6 + 3.22040948673195e+50*cos(theta)**4 - 2.71764513648265e+48*cos(theta)**2 + 3.52940926815929e+45)*cos(28*phi)

#@torch.jit.script
def Yl48_m29(theta, phi):
    return 3.5965427162585e-48*(1.0 - cos(theta)**2)**14.5*(2.33306827917398e+57*cos(theta)**19 - 4.19952290251317e+57*cos(theta)**17 + 3.07061889646124e+57*cos(theta)**15 - 1.18100726786971e+57*cos(theta)**13 + 2.58760019364711e+56*cos(theta)**11 - 3.27167840576072e+55*cos(theta)**9 + 2.30942005112521e+54*cos(theta)**7 - 8.3473013896092e+52*cos(theta)**5 + 1.28816379469278e+51*cos(theta)**3 - 5.43529027296531e+48*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl48_m30(theta, phi):
    return 9.34245728723332e-50*(1.0 - cos(theta)**2)**15*(4.43282973043057e+58*cos(theta)**18 - 7.13918893427238e+58*cos(theta)**16 + 4.60592834469186e+58*cos(theta)**14 - 1.53530944823062e+58*cos(theta)**12 + 2.84636021301182e+57*cos(theta)**10 - 2.94451056518465e+56*cos(theta)**8 + 1.61659403578765e+55*cos(theta)**6 - 4.1736506948046e+53*cos(theta)**4 + 3.86449138407833e+51*cos(theta)**2 - 5.43529027296531e+48)*cos(30*phi)

#@torch.jit.script
def Yl48_m31(theta, phi):
    return 2.47748664898637e-51*(1.0 - cos(theta)**2)**15.5*(7.97909351477502e+59*cos(theta)**17 - 1.14227022948358e+60*cos(theta)**15 + 6.44829968256861e+59*cos(theta)**13 - 1.84237133787674e+59*cos(theta)**11 + 2.84636021301182e+58*cos(theta)**9 - 2.35560845214772e+57*cos(theta)**7 + 9.69956421472589e+55*cos(theta)**5 - 1.66946027792184e+54*cos(theta)**3 + 7.72898276815667e+51*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl48_m32(theta, phi):
    return 6.71802891255276e-53*(1.0 - cos(theta)**2)**16*(1.35644589751175e+61*cos(theta)**16 - 1.71340534422537e+61*cos(theta)**14 + 8.38278958733919e+60*cos(theta)**12 - 2.02660847166442e+60*cos(theta)**10 + 2.56172419171064e+59*cos(theta)**8 - 1.6489259165034e+58*cos(theta)**6 + 4.84978210736295e+56*cos(theta)**4 - 5.00838083376552e+54*cos(theta)**2 + 7.72898276815667e+51)*cos(32*phi)

#@torch.jit.script
def Yl48_m33(theta, phi):
    return 1.86611914237577e-54*(1.0 - cos(theta)**2)**16.5*(2.1703134360188e+62*cos(theta)**15 - 2.39876748191552e+62*cos(theta)**13 + 1.0059347504807e+62*cos(theta)**11 - 2.02660847166442e+61*cos(theta)**9 + 2.04937935336851e+60*cos(theta)**7 - 9.89355549902041e+58*cos(theta)**5 + 1.93991284294518e+57*cos(theta)**3 - 1.0016761667531e+55*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl48_m34(theta, phi):
    return 5.32092101381846e-56*(1.0 - cos(theta)**2)**17*(3.25547015402821e+63*cos(theta)**14 - 3.11839772649018e+63*cos(theta)**12 + 1.10652822552877e+63*cos(theta)**10 - 1.82394762449798e+62*cos(theta)**8 + 1.43456554735796e+61*cos(theta)**6 - 4.94677774951021e+59*cos(theta)**4 + 5.81973852883553e+57*cos(theta)**2 - 1.0016761667531e+55)*cos(34*phi)

#@torch.jit.script
def Yl48_m35(theta, phi):
    return 1.5609311520875e-57*(1.0 - cos(theta)**2)**17.5*(4.55765821563949e+64*cos(theta)**13 - 3.74207727178821e+64*cos(theta)**11 + 1.10652822552877e+64*cos(theta)**9 - 1.45915809959838e+63*cos(theta)**7 + 8.60739328414776e+61*cos(theta)**5 - 1.97871109980408e+60*cos(theta)**3 + 1.16394770576711e+58*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl48_m36(theta, phi):
    return 4.72359254921895e-59*(1.0 - cos(theta)**2)**18*(5.92495568033134e+65*cos(theta)**12 - 4.11628499896703e+65*cos(theta)**10 + 9.95875402975895e+64*cos(theta)**8 - 1.02141066971887e+64*cos(theta)**6 + 4.30369664207388e+62*cos(theta)**4 - 5.93613329941225e+60*cos(theta)**2 + 1.16394770576711e+58)*cos(36*phi)

#@torch.jit.script
def Yl48_m37(theta, phi):
    return 1.47901419775487e-60*(1.0 - cos(theta)**2)**18.5*(7.1099468163976e+66*cos(theta)**11 - 4.11628499896703e+66*cos(theta)**9 + 7.96700322380716e+65*cos(theta)**7 - 6.1284640183132e+64*cos(theta)**5 + 1.72147865682955e+63*cos(theta)**3 - 1.18722665988245e+61*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl48_m38(theta, phi):
    return 4.80868993728036e-62*(1.0 - cos(theta)**2)**19*(7.82094149803737e+67*cos(theta)**10 - 3.70465649907033e+67*cos(theta)**8 + 5.57690225666501e+66*cos(theta)**6 - 3.0642320091566e+65*cos(theta)**4 + 5.16443597048865e+63*cos(theta)**2 - 1.18722665988245e+61)*cos(38*phi)

#@torch.jit.script
def Yl48_m39(theta, phi):
    return 1.63029857334923e-63*(1.0 - cos(theta)**2)**19.5*(7.82094149803737e+68*cos(theta)**9 - 2.96372519925626e+68*cos(theta)**7 + 3.34614135399901e+67*cos(theta)**5 - 1.22569280366264e+66*cos(theta)**3 + 1.03288719409773e+64*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl48_m40(theta, phi):
    return 5.79301372852641e-65*(1.0 - cos(theta)**2)**20*(7.03884734823363e+69*cos(theta)**8 - 2.07460763947939e+69*cos(theta)**6 + 1.6730706769995e+68*cos(theta)**4 - 3.67707841098792e+66*cos(theta)**2 + 1.03288719409773e+64)*cos(40*phi)

#@torch.jit.script
def Yl48_m41(theta, phi):
    return 2.17102368215931e-66*(1.0 - cos(theta)**2)**20.5*(5.6310778785869e+70*cos(theta)**7 - 1.24476458368763e+70*cos(theta)**5 + 6.69228270799802e+68*cos(theta)**3 - 7.35415682197584e+66*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl48_m42(theta, phi):
    return 8.64956538819768e-68*(1.0 - cos(theta)**2)**21*(3.94175451501083e+71*cos(theta)**6 - 6.22382291843816e+70*cos(theta)**4 + 2.00768481239941e+69*cos(theta)**2 - 7.35415682197584e+66)*cos(42*phi)

#@torch.jit.script
def Yl48_m43(theta, phi):
    return 3.70167226353842e-69*(1.0 - cos(theta)**2)**21.5*(2.3650527090065e+72*cos(theta)**5 - 2.48952916737526e+71*cos(theta)**3 + 4.01536962479881e+69*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl48_m44(theta, phi):
    return 1.72591359213969e-70*(1.0 - cos(theta)**2)**22*(1.18252635450325e+73*cos(theta)**4 - 7.46858750212579e+71*cos(theta)**2 + 4.01536962479881e+69)*cos(44*phi)

#@torch.jit.script
def Yl48_m45(theta, phi):
    return 8.94844512163766e-72*(1.0 - cos(theta)**2)**22.5*(4.730105418013e+73*cos(theta)**3 - 1.49371750042516e+72*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl48_m46(theta, phi):
    return 5.32872152427948e-73*(1.0 - cos(theta)**2)**23*(1.4190316254039e+74*cos(theta)**2 - 1.49371750042516e+72)*cos(46*phi)

#@torch.jit.script
def Yl48_m47(theta, phi):
    return 10.9715577794607*(1.0 - cos(theta)**2)**23.5*cos(47*phi)*cos(theta)

#@torch.jit.script
def Yl48_m48(theta, phi):
    return 1.11977992679758*(1.0 - cos(theta)**2)**24*cos(48*phi)

#@torch.jit.script
def Yl49_m_minus_49(theta, phi):
    return 1.12547858918257*(1.0 - cos(theta)**2)**24.5*sin(49*phi)

#@torch.jit.script
def Yl49_m_minus_48(theta, phi):
    return 11.1416695948776*(1.0 - cos(theta)**2)**24*sin(48*phi)*cos(theta)

#@torch.jit.script
def Yl49_m_minus_47(theta, phi):
    return 5.63712072589557e-75*(1.0 - cos(theta)**2)**23.5*(1.37646067664178e+76*cos(theta)**2 - 1.4190316254039e+74)*sin(47*phi)

#@torch.jit.script
def Yl49_m_minus_46(theta, phi):
    return 9.56651109995517e-74*(1.0 - cos(theta)**2)**23*(4.58820225547261e+75*cos(theta)**3 - 1.4190316254039e+74*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl49_m_minus_45(theta, phi):
    return 1.86485632577191e-72*(1.0 - cos(theta)**2)**22.5*(1.14705056386815e+75*cos(theta)**4 - 7.0951581270195e+73*cos(theta)**2 + 3.73429375106289e+71)*sin(45*phi)

#@torch.jit.script
def Yl49_m_minus_44(theta, phi):
    return 4.04291217368446e-71*(1.0 - cos(theta)**2)**22*(2.2941011277363e+74*cos(theta)**5 - 2.3650527090065e+73*cos(theta)**3 + 3.73429375106289e+71*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl49_m_minus_43(theta, phi):
    return 9.55017668685889e-70*(1.0 - cos(theta)**2)**21.5*(3.82350187956051e+73*cos(theta)**6 - 5.91263177251625e+72*cos(theta)**4 + 1.86714687553145e+71*cos(theta)**2 - 6.69228270799802e+68)*sin(43*phi)

#@torch.jit.script
def Yl49_m_minus_42(theta, phi):
    return 2.42356314832405e-68*(1.0 - cos(theta)**2)**21*(5.4621455422293e+72*cos(theta)**7 - 1.18252635450325e+72*cos(theta)**5 + 6.22382291843816e+70*cos(theta)**3 - 6.69228270799802e+68*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl49_m_minus_41(theta, phi):
    return 6.53913088039203e-67*(1.0 - cos(theta)**2)**20.5*(6.82768192778662e+71*cos(theta)**8 - 1.97087725750542e+71*cos(theta)**6 + 1.55595572960954e+70*cos(theta)**4 - 3.34614135399901e+68*cos(theta)**2 + 9.1926960274698e+65)*sin(41*phi)

#@torch.jit.script
def Yl49_m_minus_40(theta, phi):
    return 1.86106927499828e-65*(1.0 - cos(theta)**2)**20*(7.58631325309624e+70*cos(theta)**9 - 2.81553893929345e+70*cos(theta)**7 + 3.11191145921908e+69*cos(theta)**5 - 1.115380451333e+68*cos(theta)**3 + 9.1926960274698e+65*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl49_m_minus_39(theta, phi):
    return 5.55210336111004e-64*(1.0 - cos(theta)**2)**19.5*(7.58631325309624e+69*cos(theta)**10 - 3.51942367411681e+69*cos(theta)**8 + 5.18651909869846e+68*cos(theta)**6 - 2.78845112833251e+67*cos(theta)**4 + 4.5963480137349e+65*cos(theta)**2 - 1.03288719409773e+63)*sin(39*phi)

#@torch.jit.script
def Yl49_m_minus_38(theta, phi):
    return 1.72740917205539e-62*(1.0 - cos(theta)**2)**19*(6.89664841190568e+68*cos(theta)**11 - 3.91047074901868e+68*cos(theta)**9 + 7.40931299814066e+67*cos(theta)**7 - 5.57690225666501e+66*cos(theta)**5 + 1.5321160045783e+65*cos(theta)**3 - 1.03288719409773e+63*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl49_m_minus_37(theta, phi):
    return 5.58142984852443e-61*(1.0 - cos(theta)**2)**18.5*(5.7472070099214e+67*cos(theta)**12 - 3.91047074901868e+67*cos(theta)**10 + 9.26164124767583e+66*cos(theta)**8 - 9.29483709444169e+65*cos(theta)**6 + 3.83029001144575e+64*cos(theta)**4 - 5.16443597048865e+62*cos(theta)**2 + 9.89355549902041e+59)*sin(37*phi)

#@torch.jit.script
def Yl49_m_minus_36(theta, phi):
    return 1.86623518170062e-59*(1.0 - cos(theta)**2)**18*(4.42092846917031e+66*cos(theta)**13 - 3.5549734081988e+66*cos(theta)**11 + 1.02907124974176e+66*cos(theta)**9 - 1.32783387063453e+65*cos(theta)**7 + 7.6605800228915e+63*cos(theta)**5 - 1.72147865682955e+62*cos(theta)**3 + 9.89355549902041e+59*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl49_m_minus_35(theta, phi):
    return 6.43783516919034e-58*(1.0 - cos(theta)**2)**17.5*(3.15780604940736e+65*cos(theta)**14 - 2.96247784016567e+65*cos(theta)**12 + 1.02907124974176e+65*cos(theta)**10 - 1.65979233829316e+64*cos(theta)**8 + 1.27676333714858e+63*cos(theta)**6 - 4.30369664207388e+61*cos(theta)**4 + 4.94677774951021e+59*cos(theta)**2 - 8.31391218405076e+56)*sin(35*phi)

#@torch.jit.script
def Yl49_m_minus_34(theta, phi):
    return 2.28520478948248e-56*(1.0 - cos(theta)**2)**17*(2.10520403293824e+64*cos(theta)**15 - 2.27882910781975e+64*cos(theta)**13 + 9.35519317947053e+63*cos(theta)**11 - 1.84421370921462e+63*cos(theta)**9 + 1.82394762449798e+62*cos(theta)**7 - 8.60739328414776e+60*cos(theta)**5 + 1.6489259165034e+59*cos(theta)**3 - 8.31391218405076e+56*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl49_m_minus_33(theta, phi):
    return 8.32768257972902e-55*(1.0 - cos(theta)**2)**16.5*(1.3157525205864e+63*cos(theta)**16 - 1.6277350770141e+63*cos(theta)**14 + 7.79599431622544e+62*cos(theta)**12 - 1.84421370921462e+62*cos(theta)**10 + 2.27993453062247e+61*cos(theta)**8 - 1.43456554735796e+60*cos(theta)**6 + 4.1223147912585e+58*cos(theta)**4 - 4.15695609202538e+56*cos(theta)**2 + 6.2604760422069e+53)*sin(33*phi)

#@torch.jit.script
def Yl49_m_minus_32(theta, phi):
    return 3.10924933424965e-53*(1.0 - cos(theta)**2)**16*(7.73972070933177e+61*cos(theta)**17 - 1.0851567180094e+62*cos(theta)**15 + 5.9969187047888e+61*cos(theta)**13 - 1.67655791746784e+61*cos(theta)**11 + 2.53326058958052e+60*cos(theta)**9 - 2.04937935336851e+59*cos(theta)**7 + 8.24462958251701e+57*cos(theta)**5 - 1.38565203067513e+56*cos(theta)**3 + 6.2604760422069e+53*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl49_m_minus_31(theta, phi):
    return 1.18722849586975e-51*(1.0 - cos(theta)**2)**15.5*(4.29984483851765e+60*cos(theta)**18 - 6.78222948755876e+60*cos(theta)**16 + 4.28351336056343e+60*cos(theta)**14 - 1.39713159788986e+60*cos(theta)**12 + 2.53326058958052e+59*cos(theta)**10 - 2.56172419171064e+58*cos(theta)**8 + 1.3741049304195e+57*cos(theta)**6 - 3.46413007668782e+55*cos(theta)**4 + 3.13023802110345e+53*cos(theta)**2 - 4.29387931564259e+50)*sin(31*phi)

#@torch.jit.script
def Yl49_m_minus_30(theta, phi):
    return 4.62866879581573e-50*(1.0 - cos(theta)**2)**15*(2.26307623079876e+59*cos(theta)**19 - 3.98954675738751e+59*cos(theta)**17 + 2.85567557370895e+59*cos(theta)**15 - 1.07471661376143e+59*cos(theta)**13 + 2.30296417234593e+58*cos(theta)**11 - 2.84636021301182e+57*cos(theta)**9 + 1.96300704345643e+56*cos(theta)**7 - 6.92826015337564e+54*cos(theta)**5 + 1.04341267370115e+53*cos(theta)**3 - 4.29387931564259e+50*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl49_m_minus_29(theta, phi):
    return 1.83985945707127e-48*(1.0 - cos(theta)**2)**14.5*(1.13153811539938e+58*cos(theta)**20 - 2.21641486521528e+58*cos(theta)**18 + 1.7847972335681e+58*cos(theta)**16 - 7.6765472411531e+57*cos(theta)**14 + 1.91913681028828e+57*cos(theta)**12 - 2.84636021301182e+56*cos(theta)**10 + 2.45375880432054e+55*cos(theta)**8 - 1.15471002556261e+54*cos(theta)**6 + 2.60853168425288e+52*cos(theta)**4 - 2.1469396578213e+50*cos(theta)**2 + 2.71764513648265e+47)*sin(29*phi)

#@torch.jit.script
def Yl49_m_minus_28(theta, phi):
    return 7.44631832657374e-47*(1.0 - cos(theta)**2)**14*(5.38827673999705e+56*cos(theta)**21 - 1.16653413958699e+57*cos(theta)**19 + 1.04988072562829e+57*cos(theta)**17 - 5.11769816076873e+56*cos(theta)**15 + 1.47625908483713e+56*cos(theta)**13 - 2.58760019364711e+55*cos(theta)**11 + 2.72639867146726e+54*cos(theta)**9 - 1.64958575080372e+53*cos(theta)**7 + 5.21706336850575e+51*cos(theta)**5 - 7.15646552607099e+49*cos(theta)**3 + 2.71764513648265e+47*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl49_m_minus_27(theta, phi):
    return 3.06477291679843e-45*(1.0 - cos(theta)**2)**13.5*(2.44921669999866e+55*cos(theta)**22 - 5.83267069793495e+55*cos(theta)**20 + 5.83267069793495e+55*cos(theta)**18 - 3.19856135048046e+55*cos(theta)**16 + 1.05447077488367e+55*cos(theta)**14 - 2.15633349470593e+54*cos(theta)**12 + 2.72639867146726e+53*cos(theta)**10 - 2.06198218850465e+52*cos(theta)**8 + 8.69510561417625e+50*cos(theta)**6 - 1.78911638151775e+49*cos(theta)**4 + 1.35882256824133e+47*cos(theta)**2 - 1.6042769400724e+44)*sin(27*phi)

#@torch.jit.script
def Yl49_m_minus_26(theta, phi):
    return 1.28135366465055e-43*(1.0 - cos(theta)**2)**13*(1.06487682608637e+54*cos(theta)**23 - 2.77746223711188e+54*cos(theta)**21 + 3.06982668312366e+54*cos(theta)**19 - 1.88150667675321e+54*cos(theta)**17 + 7.02980516589112e+53*cos(theta)**15 - 1.65871807285071e+53*cos(theta)**13 + 2.47854424678842e+52*cos(theta)**11 - 2.29109132056073e+51*cos(theta)**9 + 1.24215794488232e+50*cos(theta)**7 - 3.57823276303549e+48*cos(theta)**5 + 4.52940856080442e+46*cos(theta)**3 - 1.6042769400724e+44*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl49_m_minus_25(theta, phi):
    return 5.43632319223582e-42*(1.0 - cos(theta)**2)**12.5*(4.43698677535989e+52*cos(theta)**24 - 1.26248283505086e+53*cos(theta)**22 + 1.53491334156183e+53*cos(theta)**20 - 1.04528148708512e+53*cos(theta)**18 + 4.39362822868195e+52*cos(theta)**16 - 1.1847986234648e+52*cos(theta)**14 + 2.06545353899035e+51*cos(theta)**12 - 2.29109132056073e+50*cos(theta)**10 + 1.5526974311029e+49*cos(theta)**8 - 5.96372127172582e+47*cos(theta)**6 + 1.13235214020111e+46*cos(theta)**4 - 8.02138470036202e+43*cos(theta)**2 + 8.91264966706892e+40)*sin(25*phi)

#@torch.jit.script
def Yl49_m_minus_24(theta, phi):
    return 2.338251017819e-40*(1.0 - cos(theta)**2)**12*(1.77479471014396e+51*cos(theta)**25 - 5.48905580456894e+51*cos(theta)**23 + 7.30911115029443e+51*cos(theta)**21 - 5.5014815109743e+51*cos(theta)**19 + 2.58448719334232e+51*cos(theta)**17 - 7.8986574897653e+50*cos(theta)**15 + 1.58881041460796e+50*cos(theta)**13 - 2.08281029141884e+49*cos(theta)**11 + 1.72521936789211e+48*cos(theta)**9 - 8.51960181675118e+46*cos(theta)**7 + 2.26470428040221e+45*cos(theta)**5 - 2.67379490012067e+43*cos(theta)**3 + 8.91264966706892e+40*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl49_m_minus_23(theta, phi):
    return 1.01868341631664e-38*(1.0 - cos(theta)**2)**11.5*(6.82613350055368e+49*cos(theta)**26 - 2.28710658523706e+50*cos(theta)**24 + 3.32232325013383e+50*cos(theta)**22 - 2.75074075548715e+50*cos(theta)**20 + 1.43582621852351e+50*cos(theta)**18 - 4.93666093110331e+49*cos(theta)**16 + 1.13486458186283e+49*cos(theta)**14 - 1.73567524284904e+48*cos(theta)**12 + 1.72521936789211e+47*cos(theta)**10 - 1.0649502270939e+46*cos(theta)**8 + 3.77450713400369e+44*cos(theta)**6 - 6.68448725030169e+42*cos(theta)**4 + 4.45632483353446e+40*cos(theta)**2 - 4.69581120498889e+37)*sin(23*phi)

#@torch.jit.script
def Yl49_m_minus_22(theta, phi):
    return 4.49145824293968e-37*(1.0 - cos(theta)**2)**11*(2.52819759279766e+48*cos(theta)**27 - 9.14842634094823e+48*cos(theta)**25 + 1.44448836962341e+49*cos(theta)**23 - 1.30987655023198e+49*cos(theta)**21 + 7.55698009749217e+48*cos(theta)**19 - 2.90391819476666e+48*cos(theta)**17 + 7.56576387908554e+47*cos(theta)**15 - 1.33513480219157e+47*cos(theta)**13 + 1.56838124353828e+46*cos(theta)**11 - 1.18327803010433e+45*cos(theta)**9 + 5.39215304857669e+43*cos(theta)**7 - 1.33689745006034e+42*cos(theta)**5 + 1.48544161117815e+40*cos(theta)**3 - 4.69581120498889e+37*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl49_m_minus_21(theta, phi):
    return 2.00260620018926e-35*(1.0 - cos(theta)**2)**10.5*(9.0292771171345e+46*cos(theta)**28 - 3.51862551574932e+47*cos(theta)**26 + 6.01870154009752e+47*cos(theta)**24 - 5.95398431923626e+47*cos(theta)**22 + 3.77849004874609e+47*cos(theta)**20 - 1.61328788598148e+47*cos(theta)**18 + 4.72860242442846e+46*cos(theta)**16 - 9.53667715851118e+45*cos(theta)**14 + 1.30698436961524e+45*cos(theta)**12 - 1.18327803010433e+44*cos(theta)**10 + 6.74019131072087e+42*cos(theta)**8 - 2.22816241676723e+41*cos(theta)**6 + 3.71360402794538e+39*cos(theta)**4 - 2.34790560249445e+37*cos(theta)**2 + 2.36207807091997e+34)*sin(21*phi)

#@torch.jit.script
def Yl49_m_minus_20(theta, phi):
    return 9.0228466316701e-34*(1.0 - cos(theta)**2)**10*(3.11354383349465e+45*cos(theta)**29 - 1.30319463546271e+46*cos(theta)**27 + 2.40748061603901e+46*cos(theta)**25 - 2.58868883445055e+46*cos(theta)**23 + 1.79928097559337e+46*cos(theta)**21 - 8.49098887358671e+45*cos(theta)**19 + 2.78153083789909e+45*cos(theta)**17 - 6.35778477234079e+44*cos(theta)**15 + 1.00537259201172e+44*cos(theta)**13 - 1.07570730009485e+43*cos(theta)**11 + 7.48910145635652e+41*cos(theta)**9 - 3.18308916681033e+40*cos(theta)**7 + 7.42720805589076e+38*cos(theta)**5 - 7.82635200831482e+36*cos(theta)**3 + 2.36207807091997e+34*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl49_m_minus_19(theta, phi):
    return 4.10514732952406e-32*(1.0 - cos(theta)**2)**9.5*(1.03784794449822e+44*cos(theta)**30 - 4.65426655522397e+44*cos(theta)**28 + 9.25954083091926e+44*cos(theta)**26 - 1.07862034768773e+45*cos(theta)**24 + 8.17854988906079e+44*cos(theta)**22 - 4.24549443679336e+44*cos(theta)**20 + 1.54529490994394e+44*cos(theta)**18 - 3.97361548271299e+43*cos(theta)**16 + 7.18123280008372e+42*cos(theta)**14 - 8.96422750079038e+41*cos(theta)**12 + 7.48910145635652e+40*cos(theta)**10 - 3.97886145851291e+39*cos(theta)**8 + 1.23786800931513e+38*cos(theta)**6 - 1.9565880020787e+36*cos(theta)**4 + 1.18103903545998e+34*cos(theta)**2 - 1.14110051735264e+31)*sin(19*phi)

#@torch.jit.script
def Yl49_m_minus_18(theta, phi):
    return 1.88479469785661e-30*(1.0 - cos(theta)**2)**9*(3.34789659515554e+42*cos(theta)**31 - 1.60491950180137e+43*cos(theta)**29 + 3.42945956700713e+43*cos(theta)**27 - 4.31448139075091e+43*cos(theta)**25 + 3.55589125611339e+43*cos(theta)**23 - 2.02166401752065e+43*cos(theta)**21 + 8.13313110496811e+42*cos(theta)**19 - 2.33742087218411e+42*cos(theta)**17 + 4.78748853338915e+41*cos(theta)**15 - 6.8955596159926e+40*cos(theta)**13 + 6.8082740512332e+39*cos(theta)**11 - 4.42095717612545e+38*cos(theta)**9 + 1.76838287045018e+37*cos(theta)**7 - 3.91317600415741e+35*cos(theta)**5 + 3.93679678486661e+33*cos(theta)**3 - 1.14110051735264e+31*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl49_m_minus_17(theta, phi):
    return 8.72723040705274e-29*(1.0 - cos(theta)**2)**8.5*(1.04621768598611e+41*cos(theta)**32 - 5.34973167267123e+41*cos(theta)**30 + 1.22480698821683e+42*cos(theta)**28 - 1.65941591951958e+42*cos(theta)**26 + 1.48162135671391e+42*cos(theta)**24 - 9.18938189782112e+41*cos(theta)**22 + 4.06656555248406e+41*cos(theta)**20 - 1.2985671512134e+41*cos(theta)**18 + 2.99218033336822e+40*cos(theta)**16 - 4.925399725709e+39*cos(theta)**14 + 5.673561709361e+38*cos(theta)**12 - 4.42095717612545e+37*cos(theta)**10 + 2.21047858806273e+36*cos(theta)**8 - 6.52196000692902e+34*cos(theta)**6 + 9.84199196216652e+32*cos(theta)**4 - 5.7055025867632e+30*cos(theta)**2 + 5.32229718914478e+27)*sin(17*phi)

#@torch.jit.script
def Yl49_m_minus_16(theta, phi):
    return 4.07291530919092e-27*(1.0 - cos(theta)**2)**8*(3.17035662420032e+39*cos(theta)**33 - 1.72571989441007e+40*cos(theta)**31 + 4.2234723731615e+40*cos(theta)**29 - 6.14598488710956e+40*cos(theta)**27 + 5.92648542685565e+40*cos(theta)**25 - 3.99538343383527e+40*cos(theta)**23 + 1.93645978689717e+40*cos(theta)**21 - 6.83456395375472e+39*cos(theta)**19 + 1.76010607845189e+39*cos(theta)**17 - 3.28359981713933e+38*cos(theta)**15 + 4.36427823797e+37*cos(theta)**13 - 4.01905197829587e+36*cos(theta)**11 + 2.4560873200697e+35*cos(theta)**9 - 9.31708572418431e+33*cos(theta)**7 + 1.9683983924333e+32*cos(theta)**5 - 1.90183419558773e+30*cos(theta)**3 + 5.32229718914478e+27*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl49_m_minus_15(theta, phi):
    return 1.91470343515674e-25*(1.0 - cos(theta)**2)**7.5*(9.32457830647154e+37*cos(theta)**34 - 5.39287467003148e+38*cos(theta)**32 + 1.40782412438717e+39*cos(theta)**30 - 2.19499460253913e+39*cos(theta)**28 + 2.27941747186756e+39*cos(theta)**26 - 1.66474309743136e+39*cos(theta)**24 + 8.80208994044168e+38*cos(theta)**22 - 3.41728197687736e+38*cos(theta)**20 + 9.77836710251051e+37*cos(theta)**18 - 2.05224988571208e+37*cos(theta)**16 + 3.11734159855e+36*cos(theta)**14 - 3.34920998191322e+35*cos(theta)**12 + 2.4560873200697e+34*cos(theta)**10 - 1.16463571552304e+33*cos(theta)**8 + 3.28066398738884e+31*cos(theta)**6 - 4.75458548896934e+29*cos(theta)**4 + 2.66114859457239e+27*cos(theta)**2 - 2.40827927110623e+24)*sin(15*phi)

#@torch.jit.script
def Yl49_m_minus_14(theta, phi):
    return 9.06203062668976e-24*(1.0 - cos(theta)**2)**7*(2.66416523042044e+36*cos(theta)**35 - 1.63420444546408e+37*cos(theta)**33 + 4.5413681431844e+37*cos(theta)**31 - 7.56894690530734e+37*cos(theta)**29 + 8.4422869328428e+37*cos(theta)**27 - 6.65897238972545e+37*cos(theta)**25 + 3.82699562627899e+37*cos(theta)**23 - 1.62727713184636e+37*cos(theta)**21 + 5.14650900132132e+36*cos(theta)**19 - 1.20720581512475e+36*cos(theta)**17 + 2.07822773236667e+35*cos(theta)**15 - 2.57631537070248e+34*cos(theta)**13 + 2.23280665460882e+33*cos(theta)**11 - 1.29403968391449e+32*cos(theta)**9 + 4.68666283912692e+30*cos(theta)**7 - 9.50917097793867e+28*cos(theta)**5 + 8.8704953152413e+26*cos(theta)**3 - 2.40827927110623e+24*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl49_m_minus_13(theta, phi):
    return 4.31565829406494e-22*(1.0 - cos(theta)**2)**6.5*(7.40045897339011e+34*cos(theta)**36 - 4.80648366312966e+35*cos(theta)**34 + 1.41917754474513e+36*cos(theta)**32 - 2.52298230176911e+36*cos(theta)**30 + 3.01510247601529e+36*cos(theta)**28 - 2.56114322681748e+36*cos(theta)**26 + 1.59458151094958e+36*cos(theta)**24 - 7.39671423566528e+35*cos(theta)**22 + 2.57325450066066e+35*cos(theta)**20 - 6.70669897291531e+34*cos(theta)**18 + 1.29889233272917e+34*cos(theta)**16 - 1.84022526478749e+33*cos(theta)**14 + 1.86067221217401e+32*cos(theta)**12 - 1.29403968391449e+31*cos(theta)**10 + 5.85832854890864e+29*cos(theta)**8 - 1.58486182965644e+28*cos(theta)**6 + 2.21762382881032e+26*cos(theta)**4 - 1.20413963555312e+24*cos(theta)**2 + 1.06185153047012e+21)*sin(13*phi)

#@torch.jit.script
def Yl49_m_minus_12(theta, phi):
    return 2.06701561524183e-20*(1.0 - cos(theta)**2)**6*(2.00012404686219e+33*cos(theta)**37 - 1.37328104660847e+34*cos(theta)**35 + 4.30053801437917e+34*cos(theta)**33 - 8.13865258635198e+34*cos(theta)**31 + 1.03969050897079e+35*cos(theta)**29 - 9.48571565487955e+34*cos(theta)**27 + 6.37832604379832e+34*cos(theta)**25 - 3.21596271115882e+34*cos(theta)**23 + 1.22535928602889e+34*cos(theta)**21 - 3.52984156469227e+33*cos(theta)**19 + 7.64054313370098e+32*cos(theta)**17 - 1.22681684319166e+32*cos(theta)**15 + 1.43128631705693e+31*cos(theta)**13 - 1.17639971264953e+30*cos(theta)**11 + 6.50925394323183e+28*cos(theta)**9 - 2.26408832808064e+27*cos(theta)**7 + 4.43524765762065e+25*cos(theta)**5 - 4.01379878517706e+23*cos(theta)**3 + 1.06185153047012e+21*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl49_m_minus_11(theta, phi):
    return 9.95177327784801e-19*(1.0 - cos(theta)**2)**5.5*(5.26348433384788e+31*cos(theta)**38 - 3.81466957391243e+32*cos(theta)**36 + 1.26486412187623e+33*cos(theta)**34 - 2.54332893323499e+33*cos(theta)**32 + 3.46563502990263e+33*cos(theta)**30 - 3.38775559102841e+33*cos(theta)**28 + 2.45320232453782e+33*cos(theta)**26 - 1.33998446298284e+33*cos(theta)**24 + 5.56981493649494e+32*cos(theta)**22 - 1.76492078234613e+32*cos(theta)**20 + 4.24474618538943e+31*cos(theta)**18 - 7.66760526994786e+30*cos(theta)**16 + 1.02234736932638e+30*cos(theta)**14 - 9.80333093874612e+28*cos(theta)**12 + 6.50925394323183e+27*cos(theta)**10 - 2.83011041010079e+26*cos(theta)**8 + 7.39207942936775e+24*cos(theta)**6 - 1.00344969629426e+23*cos(theta)**4 + 5.30925765235061e+20*cos(theta)**2 - 4.58089529969854e+17)*sin(11*phi)

#@torch.jit.script
def Yl49_m_minus_10(theta, phi):
    return 4.81402567311844e-17*(1.0 - cos(theta)**2)**5*(1.3496113676533e+30*cos(theta)**39 - 1.03099177673309e+31*cos(theta)**37 + 3.61389749107493e+31*cos(theta)**35 - 7.70705737343937e+31*cos(theta)**33 + 1.11794678383956e+32*cos(theta)**31 - 1.16819158311325e+32*cos(theta)**29 + 9.08593453532524e+31*cos(theta)**27 - 5.35993785193136e+31*cos(theta)**25 + 2.42165866804128e+31*cos(theta)**23 - 8.40438467783873e+30*cos(theta)**21 + 2.23407693967865e+30*cos(theta)**19 - 4.5103560411458e+29*cos(theta)**17 + 6.81564912884254e+28*cos(theta)**15 - 7.54102379903547e+27*cos(theta)**13 + 5.91750358475621e+26*cos(theta)**11 - 3.14456712233422e+25*cos(theta)**9 + 1.05601134705254e+24*cos(theta)**7 - 2.00689939258853e+22*cos(theta)**5 + 1.76975255078354e+20*cos(theta)**3 - 4.58089529969854e+17*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl49_m_minus_9(theta, phi):
    return 2.33864554621273e-15*(1.0 - cos(theta)**2)**4.5*(3.37402841913325e+28*cos(theta)**40 - 2.71313625456076e+29*cos(theta)**38 + 1.00386041418748e+30*cos(theta)**36 - 2.26678158042335e+30*cos(theta)**34 + 3.49358369949862e+30*cos(theta)**32 - 3.89397194371082e+30*cos(theta)**30 + 3.24497661975901e+30*cos(theta)**28 - 2.06151455843514e+30*cos(theta)**26 + 1.0090244450172e+30*cos(theta)**24 - 3.82017485356306e+29*cos(theta)**22 + 1.11703846983932e+29*cos(theta)**20 - 2.50575335619211e+28*cos(theta)**18 + 4.25978070552659e+27*cos(theta)**16 - 5.38644557073962e+26*cos(theta)**14 + 4.93125298729684e+25*cos(theta)**12 - 3.14456712233422e+24*cos(theta)**10 + 1.32001418381567e+23*cos(theta)**8 - 3.34483232098088e+21*cos(theta)**6 + 4.42438137695884e+19*cos(theta)**4 - 2.29044764984927e+17*cos(theta)**2 + 194105733038074.0)*sin(9*phi)

#@torch.jit.script
def Yl49_m_minus_8(theta, phi):
    return 1.14043445195993e-13*(1.0 - cos(theta)**2)**4*(8.22933760764208e+26*cos(theta)**41 - 6.95675962707887e+27*cos(theta)**39 + 2.71313625456076e+28*cos(theta)**37 - 6.47651880120956e+28*cos(theta)**35 + 1.05866172712079e+29*cos(theta)**33 - 1.2561199818422e+29*cos(theta)**31 + 1.11895745508932e+29*cos(theta)**29 - 7.63523910531533e+28*cos(theta)**27 + 4.0360977800688e+28*cos(theta)**25 - 1.66094558850568e+28*cos(theta)**23 + 5.31923080875869e+27*cos(theta)**21 - 1.31881755589058e+27*cos(theta)**19 + 2.50575335619211e+26*cos(theta)**17 - 3.59096371382642e+25*cos(theta)**15 + 3.79327152868988e+24*cos(theta)**13 - 2.8586973839402e+23*cos(theta)**11 + 1.46668242646185e+22*cos(theta)**9 - 4.77833188711554e+20*cos(theta)**7 + 8.84876275391767e+18*cos(theta)**5 - 7.63482549949756e+16*cos(theta)**3 + 194105733038074.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl49_m_minus_7(theta, phi):
    return 5.57997690827288e-12*(1.0 - cos(theta)**2)**3.5*(1.95936609705764e+25*cos(theta)**42 - 1.73918990676972e+26*cos(theta)**40 + 7.13983224884411e+26*cos(theta)**38 - 1.79903300033599e+27*cos(theta)**36 + 3.11371096211998e+27*cos(theta)**34 - 3.92537494325687e+27*cos(theta)**32 + 3.72985818363105e+27*cos(theta)**30 - 2.72687110904119e+27*cos(theta)**28 + 1.55234530002646e+27*cos(theta)**26 - 6.92060661877366e+26*cos(theta)**24 + 2.4178321857994e+26*cos(theta)**22 - 6.59408777945292e+25*cos(theta)**20 + 1.39208519788451e+25*cos(theta)**18 - 2.24435232114151e+24*cos(theta)**16 + 2.70947966334991e+23*cos(theta)**14 - 2.38224781995016e+22*cos(theta)**12 + 1.46668242646185e+21*cos(theta)**10 - 5.97291485889443e+19*cos(theta)**8 + 1.47479379231961e+18*cos(theta)**6 - 1.90870637487439e+16*cos(theta)**4 + 97052866519036.8*cos(theta)**2 - 81080088988.3348)*sin(7*phi)

#@torch.jit.script
def Yl49_m_minus_6(theta, phi):
    return 2.73817148204482e-10*(1.0 - cos(theta)**2)**3*(4.55666534199451e+23*cos(theta)**43 - 4.24192660187736e+24*cos(theta)**41 + 1.83072621765234e+25*cos(theta)**39 - 4.86225135225943e+25*cos(theta)**37 + 8.89631703462851e+25*cos(theta)**35 - 1.18950755856269e+26*cos(theta)**33 + 1.20318005923582e+26*cos(theta)**31 - 9.40300382427996e+25*cos(theta)**29 + 5.74942703713504e+25*cos(theta)**27 - 2.76824264750946e+25*cos(theta)**25 + 1.05123138513018e+25*cos(theta)**23 - 3.14004179973949e+24*cos(theta)**21 + 7.32676419939213e+23*cos(theta)**19 - 1.3202072477303e+23*cos(theta)**17 + 1.80631977556661e+22*cos(theta)**15 - 1.83249832303859e+21*cos(theta)**13 + 1.33334766041987e+20*cos(theta)**11 - 6.63657206543826e+18*cos(theta)**9 + 2.1068482747423e+17*cos(theta)**7 - 3.81741274974878e+15*cos(theta)**5 + 32350955506345.6*cos(theta)**3 - 81080088988.3348*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl49_m_minus_5(theta, phi):
    return 1.34700226493879e-8*(1.0 - cos(theta)**2)**2.5*(1.03560575954421e+22*cos(theta)**44 - 1.00998252425651e+23*cos(theta)**42 + 4.57681554413084e+23*cos(theta)**40 - 1.27953982954195e+24*cos(theta)**38 + 2.4711991762857e+24*cos(theta)**36 - 3.49855164283144e+24*cos(theta)**34 + 3.75993768511195e+24*cos(theta)**32 - 3.13433460809332e+24*cos(theta)**30 + 2.0533667989768e+24*cos(theta)**28 - 1.06470871058056e+24*cos(theta)**26 + 4.38013077137573e+23*cos(theta)**24 - 1.42729172715431e+23*cos(theta)**22 + 3.66338209969607e+22*cos(theta)**20 - 7.33448470961278e+21*cos(theta)**18 + 1.12894985972913e+21*cos(theta)**16 - 1.30892737359899e+20*cos(theta)**14 + 1.11112305034989e+19*cos(theta)**12 - 6.63657206543826e+17*cos(theta)**10 + 2.63356034342788e+16*cos(theta)**8 - 636235458291464.0*cos(theta)**6 + 8087738876586.4*cos(theta)**4 - 40540044494.1674*cos(theta)**2 + 33504169.0034442)*sin(5*phi)

#@torch.jit.script
def Yl49_m_minus_4(theta, phi):
    return 6.6400517296577e-7*(1.0 - cos(theta)**2)**2*(2.30134613232046e+20*cos(theta)**45 - 2.34879656803841e+21*cos(theta)**43 + 1.11629647417825e+22*cos(theta)**41 - 3.28087135779988e+22*cos(theta)**39 + 6.67891669266405e+22*cos(theta)**37 - 9.99586183666125e+22*cos(theta)**35 + 1.13937505609453e+23*cos(theta)**33 - 1.0110756800301e+23*cos(theta)**31 + 7.08057516888551e+22*cos(theta)**29 - 3.94336559474282e+22*cos(theta)**27 + 1.75205230855029e+22*cos(theta)**25 - 6.20561620501875e+21*cos(theta)**23 + 1.74446766652194e+21*cos(theta)**21 - 3.86025511032251e+20*cos(theta)**19 + 6.64088152781841e+19*cos(theta)**17 - 8.72618249065994e+18*cos(theta)**15 + 8.54710038730685e+17*cos(theta)**13 - 6.0332473322166e+16*cos(theta)**11 + 2.92617815936431e+15*cos(theta)**9 - 90890779755923.4*cos(theta)**7 + 1617547775317.28*cos(theta)**5 - 13513348164.7225*cos(theta)**3 + 33504169.0034442*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl49_m_minus_3(theta, phi):
    return 3.27859908557037e-5*(1.0 - cos(theta)**2)**1.5*(5.00292637460969e+18*cos(theta)**46 - 5.33817401826911e+19*cos(theta)**44 + 2.65784874804346e+20*cos(theta)**42 - 8.20217839449971e+20*cos(theta)**40 + 1.75760965596422e+21*cos(theta)**38 - 2.77662828796146e+21*cos(theta)**36 + 3.35110310616038e+21*cos(theta)**34 - 3.15961150009407e+21*cos(theta)**32 + 2.36019172296184e+21*cos(theta)**30 - 1.40834485526529e+21*cos(theta)**28 + 6.73866272519343e+20*cos(theta)**26 - 2.58567341875781e+20*cos(theta)**24 + 7.92939848419062e+19*cos(theta)**22 - 1.93012755516126e+19*cos(theta)**20 + 3.68937862656578e+18*cos(theta)**18 - 5.45386405666246e+17*cos(theta)**16 + 6.10507170521918e+16*cos(theta)**14 - 5.0277061101805e+15*cos(theta)**12 + 292617815936431.0*cos(theta)**10 - 11361347469490.4*cos(theta)**8 + 269591295886.213*cos(theta)**6 - 3378337041.18062*cos(theta)**4 + 16752084.5017221*cos(theta)**2 - 13742.4811334882)*sin(3*phi)

#@torch.jit.script
def Yl49_m_minus_2(theta, phi):
    return 0.00162083540311096*(1.0 - cos(theta)**2)*(1.06445242012972e+17*cos(theta)**47 - 1.18626089294869e+18*cos(theta)**45 + 6.18104360010107e+18*cos(theta)**43 - 2.00053131573164e+19*cos(theta)**41 + 4.50669142554929e+19*cos(theta)**39 - 7.50440077827421e+19*cos(theta)**37 + 9.57458030331537e+19*cos(theta)**35 - 9.57458030331537e+19*cos(theta)**33 + 7.61352168697367e+19*cos(theta)**31 - 4.85636156988033e+19*cos(theta)**29 + 2.4958010093309e+19*cos(theta)**27 - 1.03426936750312e+19*cos(theta)**25 + 3.44756455834375e+18*cos(theta)**23 - 9.19108359600599e+17*cos(theta)**21 + 1.94177822450831e+17*cos(theta)**19 - 3.20815532744851e+16*cos(theta)**17 + 4.07004780347945e+15*cos(theta)**15 - 386746623860038.0*cos(theta)**13 + 26601619630584.6*cos(theta)**11 - 1262371941054.49*cos(theta)**9 + 38513042269.4591*cos(theta)**7 - 675667408.236124*cos(theta)**5 + 5584028.16724069*cos(theta)**3 - 13742.4811334882*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl49_m_minus_1(theta, phi):
    return 0.0801945068252048*(1.0 - cos(theta)**2)**0.5*(2.21760920860359e+15*cos(theta)**48 - 2.57882802814933e+16*cos(theta)**46 + 1.40478263638661e+17*cos(theta)**44 - 4.76316979936104e+17*cos(theta)**42 + 1.12667285638732e+18*cos(theta)**40 - 1.97484231007216e+18*cos(theta)**38 + 2.65960563980983e+18*cos(theta)**36 - 2.81605303038687e+18*cos(theta)**34 + 2.37922552717927e+18*cos(theta)**32 - 1.61878718996011e+18*cos(theta)**30 + 8.91357503332465e+17*cos(theta)**28 - 3.97795910578125e+17*cos(theta)**26 + 1.43648523264323e+17*cos(theta)**24 - 4.17776527091181e+16*cos(theta)**22 + 9.70889112254154e+15*cos(theta)**20 - 1.78230851524917e+15*cos(theta)**18 + 254377987717466.0*cos(theta)**16 - 27624758847145.6*cos(theta)**14 + 2216801635882.05*cos(theta)**12 - 126237194105.449*cos(theta)**10 + 4814130283.68238*cos(theta)**8 - 112611234.706021*cos(theta)**6 + 1396007.04181017*cos(theta)**4 - 6871.24056674408*cos(theta)**2 + 5.61375863296085)*sin(phi)

#@torch.jit.script
def Yl49_m0(theta, phi):
    return 399072199168457.0*cos(theta)**49 - 4.83823614661965e+15*cos(theta)**47 + 2.75270172341886e+16*cos(theta)**45 - 9.76765127664757e+16*cos(theta)**43 + 2.42312887439911e+17*cos(theta)**41 - 4.4650914090051e+17*cos(theta)**39 + 6.33837688519689e+17*cos(theta)**37 - 7.09472101771619e+17*cos(theta)**35 + 6.35746838183905e+17*cos(theta)**33 - 4.60458615310154e+17*cos(theta)**31 + 2.71029438125597e+17*cos(theta)**29 - 1.29914937283344e+17*cos(theta)**27 + 5.06668255405041e+16*cos(theta)**25 - 1.60169100760287e+16*cos(theta)**23 + 4.0767386813232e+15*cos(theta)**21 - 827164370123548.0*cos(theta)**19 + 131945062771573.0*cos(theta)**17 - 16239392341116.7*cos(theta)**15 + 1503647438992.29*cos(theta)**13 - 101194564487.833*cos(theta)**11 + 4716695802.399*cos(theta)**9 - 141855512.854105*cos(theta)**7 + 2461955.18176546*cos(theta)**5 - 20196.5150267881*cos(theta)**3 + 49.501262320559*cos(theta)

#@torch.jit.script
def Yl49_m1(theta, phi):
    return 0.0801945068252048*(1.0 - cos(theta)**2)**0.5*(2.21760920860359e+15*cos(theta)**48 - 2.57882802814933e+16*cos(theta)**46 + 1.40478263638661e+17*cos(theta)**44 - 4.76316979936104e+17*cos(theta)**42 + 1.12667285638732e+18*cos(theta)**40 - 1.97484231007216e+18*cos(theta)**38 + 2.65960563980983e+18*cos(theta)**36 - 2.81605303038687e+18*cos(theta)**34 + 2.37922552717927e+18*cos(theta)**32 - 1.61878718996011e+18*cos(theta)**30 + 8.91357503332465e+17*cos(theta)**28 - 3.97795910578125e+17*cos(theta)**26 + 1.43648523264323e+17*cos(theta)**24 - 4.17776527091181e+16*cos(theta)**22 + 9.70889112254154e+15*cos(theta)**20 - 1.78230851524917e+15*cos(theta)**18 + 254377987717466.0*cos(theta)**16 - 27624758847145.6*cos(theta)**14 + 2216801635882.05*cos(theta)**12 - 126237194105.449*cos(theta)**10 + 4814130283.68238*cos(theta)**8 - 112611234.706021*cos(theta)**6 + 1396007.04181017*cos(theta)**4 - 6871.24056674408*cos(theta)**2 + 5.61375863296085)*cos(phi)

#@torch.jit.script
def Yl49_m2(theta, phi):
    return 0.00162083540311096*(1.0 - cos(theta)**2)*(1.06445242012972e+17*cos(theta)**47 - 1.18626089294869e+18*cos(theta)**45 + 6.18104360010107e+18*cos(theta)**43 - 2.00053131573164e+19*cos(theta)**41 + 4.50669142554929e+19*cos(theta)**39 - 7.50440077827421e+19*cos(theta)**37 + 9.57458030331537e+19*cos(theta)**35 - 9.57458030331537e+19*cos(theta)**33 + 7.61352168697367e+19*cos(theta)**31 - 4.85636156988033e+19*cos(theta)**29 + 2.4958010093309e+19*cos(theta)**27 - 1.03426936750312e+19*cos(theta)**25 + 3.44756455834375e+18*cos(theta)**23 - 9.19108359600599e+17*cos(theta)**21 + 1.94177822450831e+17*cos(theta)**19 - 3.20815532744851e+16*cos(theta)**17 + 4.07004780347945e+15*cos(theta)**15 - 386746623860038.0*cos(theta)**13 + 26601619630584.6*cos(theta)**11 - 1262371941054.49*cos(theta)**9 + 38513042269.4591*cos(theta)**7 - 675667408.236124*cos(theta)**5 + 5584028.16724069*cos(theta)**3 - 13742.4811334882*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl49_m3(theta, phi):
    return 3.27859908557037e-5*(1.0 - cos(theta)**2)**1.5*(5.00292637460969e+18*cos(theta)**46 - 5.33817401826911e+19*cos(theta)**44 + 2.65784874804346e+20*cos(theta)**42 - 8.20217839449971e+20*cos(theta)**40 + 1.75760965596422e+21*cos(theta)**38 - 2.77662828796146e+21*cos(theta)**36 + 3.35110310616038e+21*cos(theta)**34 - 3.15961150009407e+21*cos(theta)**32 + 2.36019172296184e+21*cos(theta)**30 - 1.40834485526529e+21*cos(theta)**28 + 6.73866272519343e+20*cos(theta)**26 - 2.58567341875781e+20*cos(theta)**24 + 7.92939848419062e+19*cos(theta)**22 - 1.93012755516126e+19*cos(theta)**20 + 3.68937862656578e+18*cos(theta)**18 - 5.45386405666246e+17*cos(theta)**16 + 6.10507170521918e+16*cos(theta)**14 - 5.0277061101805e+15*cos(theta)**12 + 292617815936431.0*cos(theta)**10 - 11361347469490.4*cos(theta)**8 + 269591295886.213*cos(theta)**6 - 3378337041.18062*cos(theta)**4 + 16752084.5017221*cos(theta)**2 - 13742.4811334882)*cos(3*phi)

#@torch.jit.script
def Yl49_m4(theta, phi):
    return 6.6400517296577e-7*(1.0 - cos(theta)**2)**2*(2.30134613232046e+20*cos(theta)**45 - 2.34879656803841e+21*cos(theta)**43 + 1.11629647417825e+22*cos(theta)**41 - 3.28087135779988e+22*cos(theta)**39 + 6.67891669266405e+22*cos(theta)**37 - 9.99586183666125e+22*cos(theta)**35 + 1.13937505609453e+23*cos(theta)**33 - 1.0110756800301e+23*cos(theta)**31 + 7.08057516888551e+22*cos(theta)**29 - 3.94336559474282e+22*cos(theta)**27 + 1.75205230855029e+22*cos(theta)**25 - 6.20561620501875e+21*cos(theta)**23 + 1.74446766652194e+21*cos(theta)**21 - 3.86025511032251e+20*cos(theta)**19 + 6.64088152781841e+19*cos(theta)**17 - 8.72618249065994e+18*cos(theta)**15 + 8.54710038730685e+17*cos(theta)**13 - 6.0332473322166e+16*cos(theta)**11 + 2.92617815936431e+15*cos(theta)**9 - 90890779755923.4*cos(theta)**7 + 1617547775317.28*cos(theta)**5 - 13513348164.7225*cos(theta)**3 + 33504169.0034442*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl49_m5(theta, phi):
    return 1.34700226493879e-8*(1.0 - cos(theta)**2)**2.5*(1.03560575954421e+22*cos(theta)**44 - 1.00998252425651e+23*cos(theta)**42 + 4.57681554413084e+23*cos(theta)**40 - 1.27953982954195e+24*cos(theta)**38 + 2.4711991762857e+24*cos(theta)**36 - 3.49855164283144e+24*cos(theta)**34 + 3.75993768511195e+24*cos(theta)**32 - 3.13433460809332e+24*cos(theta)**30 + 2.0533667989768e+24*cos(theta)**28 - 1.06470871058056e+24*cos(theta)**26 + 4.38013077137573e+23*cos(theta)**24 - 1.42729172715431e+23*cos(theta)**22 + 3.66338209969607e+22*cos(theta)**20 - 7.33448470961278e+21*cos(theta)**18 + 1.12894985972913e+21*cos(theta)**16 - 1.30892737359899e+20*cos(theta)**14 + 1.11112305034989e+19*cos(theta)**12 - 6.63657206543826e+17*cos(theta)**10 + 2.63356034342788e+16*cos(theta)**8 - 636235458291464.0*cos(theta)**6 + 8087738876586.4*cos(theta)**4 - 40540044494.1674*cos(theta)**2 + 33504169.0034442)*cos(5*phi)

#@torch.jit.script
def Yl49_m6(theta, phi):
    return 2.73817148204482e-10*(1.0 - cos(theta)**2)**3*(4.55666534199451e+23*cos(theta)**43 - 4.24192660187736e+24*cos(theta)**41 + 1.83072621765234e+25*cos(theta)**39 - 4.86225135225943e+25*cos(theta)**37 + 8.89631703462851e+25*cos(theta)**35 - 1.18950755856269e+26*cos(theta)**33 + 1.20318005923582e+26*cos(theta)**31 - 9.40300382427996e+25*cos(theta)**29 + 5.74942703713504e+25*cos(theta)**27 - 2.76824264750946e+25*cos(theta)**25 + 1.05123138513018e+25*cos(theta)**23 - 3.14004179973949e+24*cos(theta)**21 + 7.32676419939213e+23*cos(theta)**19 - 1.3202072477303e+23*cos(theta)**17 + 1.80631977556661e+22*cos(theta)**15 - 1.83249832303859e+21*cos(theta)**13 + 1.33334766041987e+20*cos(theta)**11 - 6.63657206543826e+18*cos(theta)**9 + 2.1068482747423e+17*cos(theta)**7 - 3.81741274974878e+15*cos(theta)**5 + 32350955506345.6*cos(theta)**3 - 81080088988.3348*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl49_m7(theta, phi):
    return 5.57997690827288e-12*(1.0 - cos(theta)**2)**3.5*(1.95936609705764e+25*cos(theta)**42 - 1.73918990676972e+26*cos(theta)**40 + 7.13983224884411e+26*cos(theta)**38 - 1.79903300033599e+27*cos(theta)**36 + 3.11371096211998e+27*cos(theta)**34 - 3.92537494325687e+27*cos(theta)**32 + 3.72985818363105e+27*cos(theta)**30 - 2.72687110904119e+27*cos(theta)**28 + 1.55234530002646e+27*cos(theta)**26 - 6.92060661877366e+26*cos(theta)**24 + 2.4178321857994e+26*cos(theta)**22 - 6.59408777945292e+25*cos(theta)**20 + 1.39208519788451e+25*cos(theta)**18 - 2.24435232114151e+24*cos(theta)**16 + 2.70947966334991e+23*cos(theta)**14 - 2.38224781995016e+22*cos(theta)**12 + 1.46668242646185e+21*cos(theta)**10 - 5.97291485889443e+19*cos(theta)**8 + 1.47479379231961e+18*cos(theta)**6 - 1.90870637487439e+16*cos(theta)**4 + 97052866519036.8*cos(theta)**2 - 81080088988.3348)*cos(7*phi)

#@torch.jit.script
def Yl49_m8(theta, phi):
    return 1.14043445195993e-13*(1.0 - cos(theta)**2)**4*(8.22933760764208e+26*cos(theta)**41 - 6.95675962707887e+27*cos(theta)**39 + 2.71313625456076e+28*cos(theta)**37 - 6.47651880120956e+28*cos(theta)**35 + 1.05866172712079e+29*cos(theta)**33 - 1.2561199818422e+29*cos(theta)**31 + 1.11895745508932e+29*cos(theta)**29 - 7.63523910531533e+28*cos(theta)**27 + 4.0360977800688e+28*cos(theta)**25 - 1.66094558850568e+28*cos(theta)**23 + 5.31923080875869e+27*cos(theta)**21 - 1.31881755589058e+27*cos(theta)**19 + 2.50575335619211e+26*cos(theta)**17 - 3.59096371382642e+25*cos(theta)**15 + 3.79327152868988e+24*cos(theta)**13 - 2.8586973839402e+23*cos(theta)**11 + 1.46668242646185e+22*cos(theta)**9 - 4.77833188711554e+20*cos(theta)**7 + 8.84876275391767e+18*cos(theta)**5 - 7.63482549949756e+16*cos(theta)**3 + 194105733038074.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl49_m9(theta, phi):
    return 2.33864554621273e-15*(1.0 - cos(theta)**2)**4.5*(3.37402841913325e+28*cos(theta)**40 - 2.71313625456076e+29*cos(theta)**38 + 1.00386041418748e+30*cos(theta)**36 - 2.26678158042335e+30*cos(theta)**34 + 3.49358369949862e+30*cos(theta)**32 - 3.89397194371082e+30*cos(theta)**30 + 3.24497661975901e+30*cos(theta)**28 - 2.06151455843514e+30*cos(theta)**26 + 1.0090244450172e+30*cos(theta)**24 - 3.82017485356306e+29*cos(theta)**22 + 1.11703846983932e+29*cos(theta)**20 - 2.50575335619211e+28*cos(theta)**18 + 4.25978070552659e+27*cos(theta)**16 - 5.38644557073962e+26*cos(theta)**14 + 4.93125298729684e+25*cos(theta)**12 - 3.14456712233422e+24*cos(theta)**10 + 1.32001418381567e+23*cos(theta)**8 - 3.34483232098088e+21*cos(theta)**6 + 4.42438137695884e+19*cos(theta)**4 - 2.29044764984927e+17*cos(theta)**2 + 194105733038074.0)*cos(9*phi)

#@torch.jit.script
def Yl49_m10(theta, phi):
    return 4.81402567311844e-17*(1.0 - cos(theta)**2)**5*(1.3496113676533e+30*cos(theta)**39 - 1.03099177673309e+31*cos(theta)**37 + 3.61389749107493e+31*cos(theta)**35 - 7.70705737343937e+31*cos(theta)**33 + 1.11794678383956e+32*cos(theta)**31 - 1.16819158311325e+32*cos(theta)**29 + 9.08593453532524e+31*cos(theta)**27 - 5.35993785193136e+31*cos(theta)**25 + 2.42165866804128e+31*cos(theta)**23 - 8.40438467783873e+30*cos(theta)**21 + 2.23407693967865e+30*cos(theta)**19 - 4.5103560411458e+29*cos(theta)**17 + 6.81564912884254e+28*cos(theta)**15 - 7.54102379903547e+27*cos(theta)**13 + 5.91750358475621e+26*cos(theta)**11 - 3.14456712233422e+25*cos(theta)**9 + 1.05601134705254e+24*cos(theta)**7 - 2.00689939258853e+22*cos(theta)**5 + 1.76975255078354e+20*cos(theta)**3 - 4.58089529969854e+17*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl49_m11(theta, phi):
    return 9.95177327784801e-19*(1.0 - cos(theta)**2)**5.5*(5.26348433384788e+31*cos(theta)**38 - 3.81466957391243e+32*cos(theta)**36 + 1.26486412187623e+33*cos(theta)**34 - 2.54332893323499e+33*cos(theta)**32 + 3.46563502990263e+33*cos(theta)**30 - 3.38775559102841e+33*cos(theta)**28 + 2.45320232453782e+33*cos(theta)**26 - 1.33998446298284e+33*cos(theta)**24 + 5.56981493649494e+32*cos(theta)**22 - 1.76492078234613e+32*cos(theta)**20 + 4.24474618538943e+31*cos(theta)**18 - 7.66760526994786e+30*cos(theta)**16 + 1.02234736932638e+30*cos(theta)**14 - 9.80333093874612e+28*cos(theta)**12 + 6.50925394323183e+27*cos(theta)**10 - 2.83011041010079e+26*cos(theta)**8 + 7.39207942936775e+24*cos(theta)**6 - 1.00344969629426e+23*cos(theta)**4 + 5.30925765235061e+20*cos(theta)**2 - 4.58089529969854e+17)*cos(11*phi)

#@torch.jit.script
def Yl49_m12(theta, phi):
    return 2.06701561524183e-20*(1.0 - cos(theta)**2)**6*(2.00012404686219e+33*cos(theta)**37 - 1.37328104660847e+34*cos(theta)**35 + 4.30053801437917e+34*cos(theta)**33 - 8.13865258635198e+34*cos(theta)**31 + 1.03969050897079e+35*cos(theta)**29 - 9.48571565487955e+34*cos(theta)**27 + 6.37832604379832e+34*cos(theta)**25 - 3.21596271115882e+34*cos(theta)**23 + 1.22535928602889e+34*cos(theta)**21 - 3.52984156469227e+33*cos(theta)**19 + 7.64054313370098e+32*cos(theta)**17 - 1.22681684319166e+32*cos(theta)**15 + 1.43128631705693e+31*cos(theta)**13 - 1.17639971264953e+30*cos(theta)**11 + 6.50925394323183e+28*cos(theta)**9 - 2.26408832808064e+27*cos(theta)**7 + 4.43524765762065e+25*cos(theta)**5 - 4.01379878517706e+23*cos(theta)**3 + 1.06185153047012e+21*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl49_m13(theta, phi):
    return 4.31565829406494e-22*(1.0 - cos(theta)**2)**6.5*(7.40045897339011e+34*cos(theta)**36 - 4.80648366312966e+35*cos(theta)**34 + 1.41917754474513e+36*cos(theta)**32 - 2.52298230176911e+36*cos(theta)**30 + 3.01510247601529e+36*cos(theta)**28 - 2.56114322681748e+36*cos(theta)**26 + 1.59458151094958e+36*cos(theta)**24 - 7.39671423566528e+35*cos(theta)**22 + 2.57325450066066e+35*cos(theta)**20 - 6.70669897291531e+34*cos(theta)**18 + 1.29889233272917e+34*cos(theta)**16 - 1.84022526478749e+33*cos(theta)**14 + 1.86067221217401e+32*cos(theta)**12 - 1.29403968391449e+31*cos(theta)**10 + 5.85832854890864e+29*cos(theta)**8 - 1.58486182965644e+28*cos(theta)**6 + 2.21762382881032e+26*cos(theta)**4 - 1.20413963555312e+24*cos(theta)**2 + 1.06185153047012e+21)*cos(13*phi)

#@torch.jit.script
def Yl49_m14(theta, phi):
    return 9.06203062668976e-24*(1.0 - cos(theta)**2)**7*(2.66416523042044e+36*cos(theta)**35 - 1.63420444546408e+37*cos(theta)**33 + 4.5413681431844e+37*cos(theta)**31 - 7.56894690530734e+37*cos(theta)**29 + 8.4422869328428e+37*cos(theta)**27 - 6.65897238972545e+37*cos(theta)**25 + 3.82699562627899e+37*cos(theta)**23 - 1.62727713184636e+37*cos(theta)**21 + 5.14650900132132e+36*cos(theta)**19 - 1.20720581512475e+36*cos(theta)**17 + 2.07822773236667e+35*cos(theta)**15 - 2.57631537070248e+34*cos(theta)**13 + 2.23280665460882e+33*cos(theta)**11 - 1.29403968391449e+32*cos(theta)**9 + 4.68666283912692e+30*cos(theta)**7 - 9.50917097793867e+28*cos(theta)**5 + 8.8704953152413e+26*cos(theta)**3 - 2.40827927110623e+24*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl49_m15(theta, phi):
    return 1.91470343515674e-25*(1.0 - cos(theta)**2)**7.5*(9.32457830647154e+37*cos(theta)**34 - 5.39287467003148e+38*cos(theta)**32 + 1.40782412438717e+39*cos(theta)**30 - 2.19499460253913e+39*cos(theta)**28 + 2.27941747186756e+39*cos(theta)**26 - 1.66474309743136e+39*cos(theta)**24 + 8.80208994044168e+38*cos(theta)**22 - 3.41728197687736e+38*cos(theta)**20 + 9.77836710251051e+37*cos(theta)**18 - 2.05224988571208e+37*cos(theta)**16 + 3.11734159855e+36*cos(theta)**14 - 3.34920998191322e+35*cos(theta)**12 + 2.4560873200697e+34*cos(theta)**10 - 1.16463571552304e+33*cos(theta)**8 + 3.28066398738884e+31*cos(theta)**6 - 4.75458548896934e+29*cos(theta)**4 + 2.66114859457239e+27*cos(theta)**2 - 2.40827927110623e+24)*cos(15*phi)

#@torch.jit.script
def Yl49_m16(theta, phi):
    return 4.07291530919092e-27*(1.0 - cos(theta)**2)**8*(3.17035662420032e+39*cos(theta)**33 - 1.72571989441007e+40*cos(theta)**31 + 4.2234723731615e+40*cos(theta)**29 - 6.14598488710956e+40*cos(theta)**27 + 5.92648542685565e+40*cos(theta)**25 - 3.99538343383527e+40*cos(theta)**23 + 1.93645978689717e+40*cos(theta)**21 - 6.83456395375472e+39*cos(theta)**19 + 1.76010607845189e+39*cos(theta)**17 - 3.28359981713933e+38*cos(theta)**15 + 4.36427823797e+37*cos(theta)**13 - 4.01905197829587e+36*cos(theta)**11 + 2.4560873200697e+35*cos(theta)**9 - 9.31708572418431e+33*cos(theta)**7 + 1.9683983924333e+32*cos(theta)**5 - 1.90183419558773e+30*cos(theta)**3 + 5.32229718914478e+27*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl49_m17(theta, phi):
    return 8.72723040705274e-29*(1.0 - cos(theta)**2)**8.5*(1.04621768598611e+41*cos(theta)**32 - 5.34973167267123e+41*cos(theta)**30 + 1.22480698821683e+42*cos(theta)**28 - 1.65941591951958e+42*cos(theta)**26 + 1.48162135671391e+42*cos(theta)**24 - 9.18938189782112e+41*cos(theta)**22 + 4.06656555248406e+41*cos(theta)**20 - 1.2985671512134e+41*cos(theta)**18 + 2.99218033336822e+40*cos(theta)**16 - 4.925399725709e+39*cos(theta)**14 + 5.673561709361e+38*cos(theta)**12 - 4.42095717612545e+37*cos(theta)**10 + 2.21047858806273e+36*cos(theta)**8 - 6.52196000692902e+34*cos(theta)**6 + 9.84199196216652e+32*cos(theta)**4 - 5.7055025867632e+30*cos(theta)**2 + 5.32229718914478e+27)*cos(17*phi)

#@torch.jit.script
def Yl49_m18(theta, phi):
    return 1.88479469785661e-30*(1.0 - cos(theta)**2)**9*(3.34789659515554e+42*cos(theta)**31 - 1.60491950180137e+43*cos(theta)**29 + 3.42945956700713e+43*cos(theta)**27 - 4.31448139075091e+43*cos(theta)**25 + 3.55589125611339e+43*cos(theta)**23 - 2.02166401752065e+43*cos(theta)**21 + 8.13313110496811e+42*cos(theta)**19 - 2.33742087218411e+42*cos(theta)**17 + 4.78748853338915e+41*cos(theta)**15 - 6.8955596159926e+40*cos(theta)**13 + 6.8082740512332e+39*cos(theta)**11 - 4.42095717612545e+38*cos(theta)**9 + 1.76838287045018e+37*cos(theta)**7 - 3.91317600415741e+35*cos(theta)**5 + 3.93679678486661e+33*cos(theta)**3 - 1.14110051735264e+31*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl49_m19(theta, phi):
    return 4.10514732952406e-32*(1.0 - cos(theta)**2)**9.5*(1.03784794449822e+44*cos(theta)**30 - 4.65426655522397e+44*cos(theta)**28 + 9.25954083091926e+44*cos(theta)**26 - 1.07862034768773e+45*cos(theta)**24 + 8.17854988906079e+44*cos(theta)**22 - 4.24549443679336e+44*cos(theta)**20 + 1.54529490994394e+44*cos(theta)**18 - 3.97361548271299e+43*cos(theta)**16 + 7.18123280008372e+42*cos(theta)**14 - 8.96422750079038e+41*cos(theta)**12 + 7.48910145635652e+40*cos(theta)**10 - 3.97886145851291e+39*cos(theta)**8 + 1.23786800931513e+38*cos(theta)**6 - 1.9565880020787e+36*cos(theta)**4 + 1.18103903545998e+34*cos(theta)**2 - 1.14110051735264e+31)*cos(19*phi)

#@torch.jit.script
def Yl49_m20(theta, phi):
    return 9.0228466316701e-34*(1.0 - cos(theta)**2)**10*(3.11354383349465e+45*cos(theta)**29 - 1.30319463546271e+46*cos(theta)**27 + 2.40748061603901e+46*cos(theta)**25 - 2.58868883445055e+46*cos(theta)**23 + 1.79928097559337e+46*cos(theta)**21 - 8.49098887358671e+45*cos(theta)**19 + 2.78153083789909e+45*cos(theta)**17 - 6.35778477234079e+44*cos(theta)**15 + 1.00537259201172e+44*cos(theta)**13 - 1.07570730009485e+43*cos(theta)**11 + 7.48910145635652e+41*cos(theta)**9 - 3.18308916681033e+40*cos(theta)**7 + 7.42720805589076e+38*cos(theta)**5 - 7.82635200831482e+36*cos(theta)**3 + 2.36207807091997e+34*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl49_m21(theta, phi):
    return 2.00260620018926e-35*(1.0 - cos(theta)**2)**10.5*(9.0292771171345e+46*cos(theta)**28 - 3.51862551574932e+47*cos(theta)**26 + 6.01870154009752e+47*cos(theta)**24 - 5.95398431923626e+47*cos(theta)**22 + 3.77849004874609e+47*cos(theta)**20 - 1.61328788598148e+47*cos(theta)**18 + 4.72860242442846e+46*cos(theta)**16 - 9.53667715851118e+45*cos(theta)**14 + 1.30698436961524e+45*cos(theta)**12 - 1.18327803010433e+44*cos(theta)**10 + 6.74019131072087e+42*cos(theta)**8 - 2.22816241676723e+41*cos(theta)**6 + 3.71360402794538e+39*cos(theta)**4 - 2.34790560249445e+37*cos(theta)**2 + 2.36207807091997e+34)*cos(21*phi)

#@torch.jit.script
def Yl49_m22(theta, phi):
    return 4.49145824293968e-37*(1.0 - cos(theta)**2)**11*(2.52819759279766e+48*cos(theta)**27 - 9.14842634094823e+48*cos(theta)**25 + 1.44448836962341e+49*cos(theta)**23 - 1.30987655023198e+49*cos(theta)**21 + 7.55698009749217e+48*cos(theta)**19 - 2.90391819476666e+48*cos(theta)**17 + 7.56576387908554e+47*cos(theta)**15 - 1.33513480219157e+47*cos(theta)**13 + 1.56838124353828e+46*cos(theta)**11 - 1.18327803010433e+45*cos(theta)**9 + 5.39215304857669e+43*cos(theta)**7 - 1.33689745006034e+42*cos(theta)**5 + 1.48544161117815e+40*cos(theta)**3 - 4.69581120498889e+37*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl49_m23(theta, phi):
    return 1.01868341631664e-38*(1.0 - cos(theta)**2)**11.5*(6.82613350055368e+49*cos(theta)**26 - 2.28710658523706e+50*cos(theta)**24 + 3.32232325013383e+50*cos(theta)**22 - 2.75074075548715e+50*cos(theta)**20 + 1.43582621852351e+50*cos(theta)**18 - 4.93666093110331e+49*cos(theta)**16 + 1.13486458186283e+49*cos(theta)**14 - 1.73567524284904e+48*cos(theta)**12 + 1.72521936789211e+47*cos(theta)**10 - 1.0649502270939e+46*cos(theta)**8 + 3.77450713400369e+44*cos(theta)**6 - 6.68448725030169e+42*cos(theta)**4 + 4.45632483353446e+40*cos(theta)**2 - 4.69581120498889e+37)*cos(23*phi)

#@torch.jit.script
def Yl49_m24(theta, phi):
    return 2.338251017819e-40*(1.0 - cos(theta)**2)**12*(1.77479471014396e+51*cos(theta)**25 - 5.48905580456894e+51*cos(theta)**23 + 7.30911115029443e+51*cos(theta)**21 - 5.5014815109743e+51*cos(theta)**19 + 2.58448719334232e+51*cos(theta)**17 - 7.8986574897653e+50*cos(theta)**15 + 1.58881041460796e+50*cos(theta)**13 - 2.08281029141884e+49*cos(theta)**11 + 1.72521936789211e+48*cos(theta)**9 - 8.51960181675118e+46*cos(theta)**7 + 2.26470428040221e+45*cos(theta)**5 - 2.67379490012067e+43*cos(theta)**3 + 8.91264966706892e+40*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl49_m25(theta, phi):
    return 5.43632319223582e-42*(1.0 - cos(theta)**2)**12.5*(4.43698677535989e+52*cos(theta)**24 - 1.26248283505086e+53*cos(theta)**22 + 1.53491334156183e+53*cos(theta)**20 - 1.04528148708512e+53*cos(theta)**18 + 4.39362822868195e+52*cos(theta)**16 - 1.1847986234648e+52*cos(theta)**14 + 2.06545353899035e+51*cos(theta)**12 - 2.29109132056073e+50*cos(theta)**10 + 1.5526974311029e+49*cos(theta)**8 - 5.96372127172582e+47*cos(theta)**6 + 1.13235214020111e+46*cos(theta)**4 - 8.02138470036202e+43*cos(theta)**2 + 8.91264966706892e+40)*cos(25*phi)

#@torch.jit.script
def Yl49_m26(theta, phi):
    return 1.28135366465055e-43*(1.0 - cos(theta)**2)**13*(1.06487682608637e+54*cos(theta)**23 - 2.77746223711188e+54*cos(theta)**21 + 3.06982668312366e+54*cos(theta)**19 - 1.88150667675321e+54*cos(theta)**17 + 7.02980516589112e+53*cos(theta)**15 - 1.65871807285071e+53*cos(theta)**13 + 2.47854424678842e+52*cos(theta)**11 - 2.29109132056073e+51*cos(theta)**9 + 1.24215794488232e+50*cos(theta)**7 - 3.57823276303549e+48*cos(theta)**5 + 4.52940856080442e+46*cos(theta)**3 - 1.6042769400724e+44*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl49_m27(theta, phi):
    return 3.06477291679843e-45*(1.0 - cos(theta)**2)**13.5*(2.44921669999866e+55*cos(theta)**22 - 5.83267069793495e+55*cos(theta)**20 + 5.83267069793495e+55*cos(theta)**18 - 3.19856135048046e+55*cos(theta)**16 + 1.05447077488367e+55*cos(theta)**14 - 2.15633349470593e+54*cos(theta)**12 + 2.72639867146726e+53*cos(theta)**10 - 2.06198218850465e+52*cos(theta)**8 + 8.69510561417625e+50*cos(theta)**6 - 1.78911638151775e+49*cos(theta)**4 + 1.35882256824133e+47*cos(theta)**2 - 1.6042769400724e+44)*cos(27*phi)

#@torch.jit.script
def Yl49_m28(theta, phi):
    return 7.44631832657374e-47*(1.0 - cos(theta)**2)**14*(5.38827673999705e+56*cos(theta)**21 - 1.16653413958699e+57*cos(theta)**19 + 1.04988072562829e+57*cos(theta)**17 - 5.11769816076873e+56*cos(theta)**15 + 1.47625908483713e+56*cos(theta)**13 - 2.58760019364711e+55*cos(theta)**11 + 2.72639867146726e+54*cos(theta)**9 - 1.64958575080372e+53*cos(theta)**7 + 5.21706336850575e+51*cos(theta)**5 - 7.15646552607099e+49*cos(theta)**3 + 2.71764513648265e+47*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl49_m29(theta, phi):
    return 1.83985945707127e-48*(1.0 - cos(theta)**2)**14.5*(1.13153811539938e+58*cos(theta)**20 - 2.21641486521528e+58*cos(theta)**18 + 1.7847972335681e+58*cos(theta)**16 - 7.6765472411531e+57*cos(theta)**14 + 1.91913681028828e+57*cos(theta)**12 - 2.84636021301182e+56*cos(theta)**10 + 2.45375880432054e+55*cos(theta)**8 - 1.15471002556261e+54*cos(theta)**6 + 2.60853168425288e+52*cos(theta)**4 - 2.1469396578213e+50*cos(theta)**2 + 2.71764513648265e+47)*cos(29*phi)

#@torch.jit.script
def Yl49_m30(theta, phi):
    return 4.62866879581573e-50*(1.0 - cos(theta)**2)**15*(2.26307623079876e+59*cos(theta)**19 - 3.98954675738751e+59*cos(theta)**17 + 2.85567557370895e+59*cos(theta)**15 - 1.07471661376143e+59*cos(theta)**13 + 2.30296417234593e+58*cos(theta)**11 - 2.84636021301182e+57*cos(theta)**9 + 1.96300704345643e+56*cos(theta)**7 - 6.92826015337564e+54*cos(theta)**5 + 1.04341267370115e+53*cos(theta)**3 - 4.29387931564259e+50*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl49_m31(theta, phi):
    return 1.18722849586975e-51*(1.0 - cos(theta)**2)**15.5*(4.29984483851765e+60*cos(theta)**18 - 6.78222948755876e+60*cos(theta)**16 + 4.28351336056343e+60*cos(theta)**14 - 1.39713159788986e+60*cos(theta)**12 + 2.53326058958052e+59*cos(theta)**10 - 2.56172419171064e+58*cos(theta)**8 + 1.3741049304195e+57*cos(theta)**6 - 3.46413007668782e+55*cos(theta)**4 + 3.13023802110345e+53*cos(theta)**2 - 4.29387931564259e+50)*cos(31*phi)

#@torch.jit.script
def Yl49_m32(theta, phi):
    return 3.10924933424965e-53*(1.0 - cos(theta)**2)**16*(7.73972070933177e+61*cos(theta)**17 - 1.0851567180094e+62*cos(theta)**15 + 5.9969187047888e+61*cos(theta)**13 - 1.67655791746784e+61*cos(theta)**11 + 2.53326058958052e+60*cos(theta)**9 - 2.04937935336851e+59*cos(theta)**7 + 8.24462958251701e+57*cos(theta)**5 - 1.38565203067513e+56*cos(theta)**3 + 6.2604760422069e+53*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl49_m33(theta, phi):
    return 8.32768257972902e-55*(1.0 - cos(theta)**2)**16.5*(1.3157525205864e+63*cos(theta)**16 - 1.6277350770141e+63*cos(theta)**14 + 7.79599431622544e+62*cos(theta)**12 - 1.84421370921462e+62*cos(theta)**10 + 2.27993453062247e+61*cos(theta)**8 - 1.43456554735796e+60*cos(theta)**6 + 4.1223147912585e+58*cos(theta)**4 - 4.15695609202538e+56*cos(theta)**2 + 6.2604760422069e+53)*cos(33*phi)

#@torch.jit.script
def Yl49_m34(theta, phi):
    return 2.28520478948248e-56*(1.0 - cos(theta)**2)**17*(2.10520403293824e+64*cos(theta)**15 - 2.27882910781975e+64*cos(theta)**13 + 9.35519317947053e+63*cos(theta)**11 - 1.84421370921462e+63*cos(theta)**9 + 1.82394762449798e+62*cos(theta)**7 - 8.60739328414776e+60*cos(theta)**5 + 1.6489259165034e+59*cos(theta)**3 - 8.31391218405076e+56*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl49_m35(theta, phi):
    return 6.43783516919034e-58*(1.0 - cos(theta)**2)**17.5*(3.15780604940736e+65*cos(theta)**14 - 2.96247784016567e+65*cos(theta)**12 + 1.02907124974176e+65*cos(theta)**10 - 1.65979233829316e+64*cos(theta)**8 + 1.27676333714858e+63*cos(theta)**6 - 4.30369664207388e+61*cos(theta)**4 + 4.94677774951021e+59*cos(theta)**2 - 8.31391218405076e+56)*cos(35*phi)

#@torch.jit.script
def Yl49_m36(theta, phi):
    return 1.86623518170062e-59*(1.0 - cos(theta)**2)**18*(4.42092846917031e+66*cos(theta)**13 - 3.5549734081988e+66*cos(theta)**11 + 1.02907124974176e+66*cos(theta)**9 - 1.32783387063453e+65*cos(theta)**7 + 7.6605800228915e+63*cos(theta)**5 - 1.72147865682955e+62*cos(theta)**3 + 9.89355549902041e+59*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl49_m37(theta, phi):
    return 5.58142984852443e-61*(1.0 - cos(theta)**2)**18.5*(5.7472070099214e+67*cos(theta)**12 - 3.91047074901868e+67*cos(theta)**10 + 9.26164124767583e+66*cos(theta)**8 - 9.29483709444169e+65*cos(theta)**6 + 3.83029001144575e+64*cos(theta)**4 - 5.16443597048865e+62*cos(theta)**2 + 9.89355549902041e+59)*cos(37*phi)

#@torch.jit.script
def Yl49_m38(theta, phi):
    return 1.72740917205539e-62*(1.0 - cos(theta)**2)**19*(6.89664841190568e+68*cos(theta)**11 - 3.91047074901868e+68*cos(theta)**9 + 7.40931299814066e+67*cos(theta)**7 - 5.57690225666501e+66*cos(theta)**5 + 1.5321160045783e+65*cos(theta)**3 - 1.03288719409773e+63*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl49_m39(theta, phi):
    return 5.55210336111004e-64*(1.0 - cos(theta)**2)**19.5*(7.58631325309624e+69*cos(theta)**10 - 3.51942367411681e+69*cos(theta)**8 + 5.18651909869846e+68*cos(theta)**6 - 2.78845112833251e+67*cos(theta)**4 + 4.5963480137349e+65*cos(theta)**2 - 1.03288719409773e+63)*cos(39*phi)

#@torch.jit.script
def Yl49_m40(theta, phi):
    return 1.86106927499828e-65*(1.0 - cos(theta)**2)**20*(7.58631325309624e+70*cos(theta)**9 - 2.81553893929345e+70*cos(theta)**7 + 3.11191145921908e+69*cos(theta)**5 - 1.115380451333e+68*cos(theta)**3 + 9.1926960274698e+65*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl49_m41(theta, phi):
    return 6.53913088039203e-67*(1.0 - cos(theta)**2)**20.5*(6.82768192778662e+71*cos(theta)**8 - 1.97087725750542e+71*cos(theta)**6 + 1.55595572960954e+70*cos(theta)**4 - 3.34614135399901e+68*cos(theta)**2 + 9.1926960274698e+65)*cos(41*phi)

#@torch.jit.script
def Yl49_m42(theta, phi):
    return 2.42356314832405e-68*(1.0 - cos(theta)**2)**21*(5.4621455422293e+72*cos(theta)**7 - 1.18252635450325e+72*cos(theta)**5 + 6.22382291843816e+70*cos(theta)**3 - 6.69228270799802e+68*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl49_m43(theta, phi):
    return 9.55017668685889e-70*(1.0 - cos(theta)**2)**21.5*(3.82350187956051e+73*cos(theta)**6 - 5.91263177251625e+72*cos(theta)**4 + 1.86714687553145e+71*cos(theta)**2 - 6.69228270799802e+68)*cos(43*phi)

#@torch.jit.script
def Yl49_m44(theta, phi):
    return 4.04291217368446e-71*(1.0 - cos(theta)**2)**22*(2.2941011277363e+74*cos(theta)**5 - 2.3650527090065e+73*cos(theta)**3 + 3.73429375106289e+71*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl49_m45(theta, phi):
    return 1.86485632577191e-72*(1.0 - cos(theta)**2)**22.5*(1.14705056386815e+75*cos(theta)**4 - 7.0951581270195e+73*cos(theta)**2 + 3.73429375106289e+71)*cos(45*phi)

#@torch.jit.script
def Yl49_m46(theta, phi):
    return 9.56651109995517e-74*(1.0 - cos(theta)**2)**23*(4.58820225547261e+75*cos(theta)**3 - 1.4190316254039e+74*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl49_m47(theta, phi):
    return 5.63712072589557e-75*(1.0 - cos(theta)**2)**23.5*(1.37646067664178e+76*cos(theta)**2 - 1.4190316254039e+74)*cos(47*phi)

#@torch.jit.script
def Yl49_m48(theta, phi):
    return 11.1416695948776*(1.0 - cos(theta)**2)**24*cos(48*phi)*cos(theta)

#@torch.jit.script
def Yl49_m49(theta, phi):
    return 1.12547858918257*(1.0 - cos(theta)**2)**24.5*cos(49*phi)

#@torch.jit.script
def Yl50_m_minus_50(theta, phi):
    return 1.13109198355194*(1.0 - cos(theta)**2)**25*sin(50*phi)

#@torch.jit.script
def Yl50_m_minus_49(theta, phi):
    return 11.3109198355194*(1.0 - cos(theta)**2)**24.5*sin(49*phi)*cos(theta)

#@torch.jit.script
def Yl50_m_minus_48(theta, phi):
    return 5.83984769173129e-77*(1.0 - cos(theta)**2)**24*(1.36269606987536e+78*cos(theta)**2 - 1.37646067664178e+76)*sin(48*phi)

#@torch.jit.script
def Yl50_m_minus_47(theta, phi):
    return 1.00132529142183e-75*(1.0 - cos(theta)**2)**23.5*(4.54232023291788e+77*cos(theta)**3 - 1.37646067664178e+76*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl50_m_minus_46(theta, phi):
    return 1.97238208171112e-74*(1.0 - cos(theta)**2)**23*(1.13558005822947e+77*cos(theta)**4 - 6.88230338320891e+75*cos(theta)**2 + 3.54757906350975e+73)*sin(46*phi)

#@torch.jit.script
def Yl50_m_minus_45(theta, phi):
    return 4.32127263268872e-73*(1.0 - cos(theta)**2)**22.5*(2.27116011645894e+76*cos(theta)**5 - 2.2941011277363e+75*cos(theta)**3 + 3.54757906350975e+73*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl50_m_minus_44(theta, phi):
    return 1.0316897006675e-71*(1.0 - cos(theta)**2)**22*(3.7852668607649e+75*cos(theta)**6 - 5.73525281934076e+74*cos(theta)**4 + 1.77378953175487e+73*cos(theta)**2 - 6.22382291843816e+70)*sin(44*phi)

#@torch.jit.script
def Yl50_m_minus_43(theta, phi):
    return 2.64643993717771e-70*(1.0 - cos(theta)**2)**21.5*(5.407524086807e+74*cos(theta)**7 - 1.14705056386815e+74*cos(theta)**5 + 5.91263177251625e+72*cos(theta)**3 - 6.22382291843816e+70*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl50_m_minus_42(theta, phi):
    return 7.21852574267788e-69*(1.0 - cos(theta)**2)**21*(6.75940510850875e+73*cos(theta)**8 - 1.91175093978025e+73*cos(theta)**6 + 1.47815794312906e+72*cos(theta)**4 - 3.11191145921908e+70*cos(theta)**2 + 8.36535338499752e+67)*sin(42*phi)

#@torch.jit.script
def Yl50_m_minus_41(theta, phi):
    return 2.07712999851474e-67*(1.0 - cos(theta)**2)**20.5*(7.51045012056528e+72*cos(theta)**9 - 2.73107277111465e+72*cos(theta)**7 + 2.95631588625812e+71*cos(theta)**5 - 1.03730381973969e+70*cos(theta)**3 + 8.36535338499752e+67*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl50_m_minus_40(theta, phi):
    return 6.26591319598679e-66*(1.0 - cos(theta)**2)**20*(7.51045012056528e+71*cos(theta)**10 - 3.41384096389331e+71*cos(theta)**8 + 4.92719314376354e+70*cos(theta)**6 - 2.59325954934923e+69*cos(theta)**4 + 4.18267669249876e+67*cos(theta)**2 - 9.1926960274698e+64)*sin(40*phi)

#@torch.jit.script
def Yl50_m_minus_39(theta, phi):
    return 1.97152356054512e-64*(1.0 - cos(theta)**2)**19.5*(6.82768192778662e+70*cos(theta)**11 - 3.79315662654812e+70*cos(theta)**9 + 7.03884734823363e+69*cos(theta)**7 - 5.18651909869846e+68*cos(theta)**5 + 1.39422556416625e+67*cos(theta)**3 - 9.1926960274698e+64*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl50_m_minus_38(theta, phi):
    return 6.44299208440446e-63*(1.0 - cos(theta)**2)**19*(5.68973493982218e+69*cos(theta)**12 - 3.79315662654812e+69*cos(theta)**10 + 8.79855918529204e+68*cos(theta)**8 - 8.64419849783077e+67*cos(theta)**6 + 3.48556391041563e+66*cos(theta)**4 - 4.5963480137349e+64*cos(theta)**2 + 8.60739328414776e+61)*sin(38*phi)

#@torch.jit.script
def Yl50_m_minus_37(theta, phi):
    return 2.17921766163123e-61*(1.0 - cos(theta)**2)**18.5*(4.3767191844786e+68*cos(theta)**13 - 3.44832420595284e+68*cos(theta)**11 + 9.77617687254671e+67*cos(theta)**9 - 1.23488549969011e+67*cos(theta)**7 + 6.97112782083127e+65*cos(theta)**5 - 1.5321160045783e+64*cos(theta)**3 + 8.60739328414776e+61*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl50_m_minus_36(theta, phi):
    return 7.60543841814552e-60*(1.0 - cos(theta)**2)**18*(3.12622798891329e+67*cos(theta)**14 - 2.8736035049607e+67*cos(theta)**12 + 9.77617687254671e+66*cos(theta)**10 - 1.54360687461264e+66*cos(theta)**8 + 1.16185463680521e+65*cos(theta)**6 - 3.83029001144575e+63*cos(theta)**4 + 4.30369664207388e+61*cos(theta)**2 - 7.06682535644315e+58)*sin(36*phi)

#@torch.jit.script
def Yl50_m_minus_35(theta, phi):
    return 2.73161261266203e-58*(1.0 - cos(theta)**2)**17.5*(2.08415199260886e+66*cos(theta)**15 - 2.21046423458515e+66*cos(theta)**13 + 8.88743352049701e+65*cos(theta)**11 - 1.7151187495696e+65*cos(theta)**9 + 1.65979233829316e+64*cos(theta)**7 - 7.6605800228915e+62*cos(theta)**5 + 1.43456554735796e+61*cos(theta)**3 - 7.06682535644315e+58*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl50_m_minus_34(theta, phi):
    return 1.00736895690158e-56*(1.0 - cos(theta)**2)**17*(1.30259499538054e+65*cos(theta)**16 - 1.57890302470368e+65*cos(theta)**14 + 7.40619460041417e+64*cos(theta)**12 - 1.7151187495696e+64*cos(theta)**10 + 2.07474042286645e+63*cos(theta)**8 - 1.27676333714858e+62*cos(theta)**6 + 3.5864138683949e+60*cos(theta)**4 - 3.53341267822157e+58*cos(theta)**2 + 5.19619511503173e+55)*sin(34*phi)

#@torch.jit.script
def Yl50_m_minus_33(theta, phi):
    return 3.80673519369261e-55*(1.0 - cos(theta)**2)**16.5*(7.66232350223845e+63*cos(theta)**17 - 1.05260201646912e+64*cos(theta)**15 + 5.69707276954936e+63*cos(theta)**13 - 1.55919886324509e+63*cos(theta)**11 + 2.30526713651828e+62*cos(theta)**9 - 1.82394762449798e+61*cos(theta)**7 + 7.1728277367898e+59*cos(theta)**5 - 1.17780422607386e+58*cos(theta)**3 + 5.19619511503173e+55*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl50_m_minus_32(theta, phi):
    return 1.47139056186104e-53*(1.0 - cos(theta)**2)**16*(4.25684639013247e+62*cos(theta)**18 - 6.578762602932e+62*cos(theta)**16 + 4.06933769253526e+62*cos(theta)**14 - 1.29933238603757e+62*cos(theta)**12 + 2.30526713651828e+61*cos(theta)**10 - 2.27993453062247e+60*cos(theta)**8 + 1.19547128946497e+59*cos(theta)**6 - 2.94451056518465e+57*cos(theta)**4 + 2.59809755751586e+55*cos(theta)**2 - 3.4780422456705e+52)*sin(32*phi)

#@torch.jit.script
def Yl50_m_minus_31(theta, phi):
    return 5.80780053812248e-52*(1.0 - cos(theta)**2)**15.5*(2.24044546849077e+61*cos(theta)**19 - 3.86986035466588e+61*cos(theta)**17 + 2.71289179502351e+61*cos(theta)**15 - 9.99486450798134e+60*cos(theta)**13 + 2.0956973968348e+60*cos(theta)**11 - 2.53326058958052e+59*cos(theta)**9 + 1.70781612780709e+58*cos(theta)**7 - 5.88902113036929e+56*cos(theta)**5 + 8.66032519171955e+54*cos(theta)**3 - 3.4780422456705e+52*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl50_m_minus_30(theta, phi):
    return 2.33759462454031e-50*(1.0 - cos(theta)**2)**15*(1.12022273424539e+60*cos(theta)**20 - 2.14992241925882e+60*cos(theta)**18 + 1.69555737188969e+60*cos(theta)**16 - 7.13918893427238e+59*cos(theta)**14 + 1.74641449736233e+59*cos(theta)**12 - 2.53326058958052e+58*cos(theta)**10 + 2.13477015975887e+57*cos(theta)**8 - 9.81503521728215e+55*cos(theta)**6 + 2.16508129792989e+54*cos(theta)**4 - 1.73902112283525e+52*cos(theta)**2 + 2.1469396578213e+49)*sin(30*phi)

#@torch.jit.script
def Yl50_m_minus_29(theta, phi):
    return 9.58128681137455e-49*(1.0 - cos(theta)**2)**14.5*(5.33439397259708e+58*cos(theta)**21 - 1.13153811539938e+59*cos(theta)**19 + 9.97386689346877e+58*cos(theta)**17 - 4.75945928951492e+58*cos(theta)**15 + 1.34339576720179e+58*cos(theta)**13 - 2.30296417234593e+57*cos(theta)**11 + 2.37196684417652e+56*cos(theta)**9 - 1.40214788818316e+55*cos(theta)**7 + 4.33016259585977e+53*cos(theta)**5 - 5.7967370761175e+51*cos(theta)**3 + 2.1469396578213e+49*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl50_m_minus_28(theta, phi):
    return 3.9943740060195e-47*(1.0 - cos(theta)**2)**14*(2.42472453299867e+57*cos(theta)**22 - 5.65769057699691e+57*cos(theta)**20 + 5.54103716303821e+57*cos(theta)**18 - 2.97466205594683e+57*cos(theta)**16 + 9.59568405144138e+56*cos(theta)**14 - 1.91913681028828e+56*cos(theta)**12 + 2.37196684417652e+55*cos(theta)**10 - 1.75268486022896e+54*cos(theta)**8 + 7.21693765976629e+52*cos(theta)**6 - 1.44918426902938e+51*cos(theta)**4 + 1.07346982891065e+49*cos(theta)**2 - 1.23529324385575e+46)*sin(28*phi)

#@torch.jit.script
def Yl50_m_minus_27(theta, phi):
    return 1.69184256116626e-45*(1.0 - cos(theta)**2)**13.5*(1.05422805782551e+56*cos(theta)**23 - 2.69413836999853e+56*cos(theta)**21 + 2.91633534896748e+56*cos(theta)**19 - 1.74980120938049e+56*cos(theta)**17 + 6.39712270096092e+55*cos(theta)**15 - 1.47625908483713e+55*cos(theta)**13 + 2.15633349470593e+54*cos(theta)**11 - 1.94742762247662e+53*cos(theta)**9 + 1.03099109425233e+52*cos(theta)**7 - 2.89836853805875e+50*cos(theta)**5 + 3.57823276303549e+48*cos(theta)**3 - 1.23529324385575e+46*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl50_m_minus_26(theta, phi):
    return 7.27295548816133e-44*(1.0 - cos(theta)**2)**13*(4.39261690760629e+54*cos(theta)**24 - 1.22460834999933e+55*cos(theta)**22 + 1.45816767448374e+55*cos(theta)**20 - 9.72111782989159e+54*cos(theta)**18 + 3.99820168810057e+54*cos(theta)**16 - 1.05447077488367e+54*cos(theta)**14 + 1.79694457892161e+53*cos(theta)**12 - 1.94742762247662e+52*cos(theta)**10 + 1.28873886781541e+51*cos(theta)**8 - 4.83061423009792e+49*cos(theta)**6 + 8.94558190758874e+47*cos(theta)**4 - 6.17646621927876e+45*cos(theta)**2 + 6.68448725030169e+42)*sin(26*phi)

#@torch.jit.script
def Yl50_m_minus_25(theta, phi):
    return 3.17020779937648e-42*(1.0 - cos(theta)**2)**12.5*(1.75704676304252e+53*cos(theta)**25 - 5.32438413043187e+53*cos(theta)**23 + 6.94365559277971e+53*cos(theta)**21 - 5.1163778052061e+53*cos(theta)**19 + 2.35188334594151e+53*cos(theta)**17 - 7.02980516589112e+52*cos(theta)**15 + 1.38226506070893e+52*cos(theta)**13 - 1.77038874770602e+51*cos(theta)**11 + 1.43193207535045e+50*cos(theta)**9 - 6.90087747156845e+48*cos(theta)**7 + 1.78911638151775e+47*cos(theta)**5 - 2.05882207309292e+45*cos(theta)**3 + 6.68448725030169e+42*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl50_m_minus_24(theta, phi):
    return 1.39992585903302e-40*(1.0 - cos(theta)**2)**12*(6.75787216554814e+51*cos(theta)**26 - 2.21849338767995e+52*cos(theta)**24 + 3.15620708762714e+52*cos(theta)**22 - 2.55818890260305e+52*cos(theta)**20 + 1.3066018588564e+52*cos(theta)**18 - 4.39362822868195e+51*cos(theta)**16 + 9.87332186220663e+50*cos(theta)**14 - 1.47532395642168e+50*cos(theta)**12 + 1.43193207535045e+49*cos(theta)**10 - 8.62609683946057e+47*cos(theta)**8 + 2.98186063586291e+46*cos(theta)**6 - 5.1470551827323e+44*cos(theta)**4 + 3.34224362515084e+42*cos(theta)**2 - 3.42794217964189e+39)*sin(24*phi)

#@torch.jit.script
def Yl50_m_minus_23(theta, phi):
    return 6.25752765615712e-39*(1.0 - cos(theta)**2)**11.5*(2.50291561686968e+50*cos(theta)**27 - 8.87397355071979e+50*cos(theta)**25 + 1.37226395114223e+51*cos(theta)**23 - 1.21818519171574e+51*cos(theta)**21 + 6.87685188871788e+50*cos(theta)**19 - 2.58448719334232e+50*cos(theta)**17 + 6.58221457480442e+49*cos(theta)**15 - 1.13486458186283e+49*cos(theta)**13 + 1.30175643213678e+48*cos(theta)**11 - 9.58455204384508e+46*cos(theta)**9 + 4.25980090837559e+45*cos(theta)**7 - 1.02941103654646e+44*cos(theta)**5 + 1.11408120838361e+42*cos(theta)**3 - 3.42794217964189e+39*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl50_m_minus_22(theta, phi):
    return 2.82906693875058e-37*(1.0 - cos(theta)**2)**11*(8.93898434596315e+48*cos(theta)**28 - 3.41306675027684e+49*cos(theta)**26 + 5.71776646309264e+49*cos(theta)**24 - 5.53720541688972e+49*cos(theta)**22 + 3.43842594435894e+49*cos(theta)**20 - 1.43582621852351e+49*cos(theta)**18 + 4.11388410925276e+48*cos(theta)**16 - 8.1061755847345e+47*cos(theta)**14 + 1.08479702678065e+47*cos(theta)**12 - 9.58455204384507e+45*cos(theta)**10 + 5.32475113546949e+44*cos(theta)**8 - 1.71568506091077e+43*cos(theta)**6 + 2.78520302095904e+41*cos(theta)**4 - 1.71397108982095e+39*cos(theta)**2 + 1.67707543035318e+36)*sin(22*phi)

#@torch.jit.script
def Yl50_m_minus_21(theta, phi):
    return 1.29273191440952e-35*(1.0 - cos(theta)**2)**10.5*(3.08240839515971e+47*cos(theta)**29 - 1.26409879639883e+48*cos(theta)**27 + 2.28710658523706e+48*cos(theta)**25 - 2.40748061603901e+48*cos(theta)**23 + 1.63734568778997e+48*cos(theta)**21 - 7.55698009749217e+47*cos(theta)**19 + 2.41993182897221e+47*cos(theta)**17 - 5.40411705648967e+46*cos(theta)**15 + 8.34459251369728e+45*cos(theta)**13 - 8.71322913076825e+44*cos(theta)**11 + 5.91639015052165e+43*cos(theta)**9 - 2.45097865844395e+42*cos(theta)**7 + 5.57040604191807e+40*cos(theta)**5 - 5.71323696606982e+38*cos(theta)**3 + 1.67707543035318e+36*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl50_m_minus_20(theta, phi):
    return 5.96620638211175e-34*(1.0 - cos(theta)**2)**10*(1.02746946505324e+46*cos(theta)**30 - 4.51463855856725e+46*cos(theta)**28 + 8.7965637893733e+46*cos(theta)**26 - 1.00311692334959e+47*cos(theta)**24 + 7.44248039904532e+46*cos(theta)**22 - 3.77849004874609e+46*cos(theta)**20 + 1.34440657165123e+46*cos(theta)**18 - 3.37757316030604e+45*cos(theta)**16 + 5.96042322406949e+44*cos(theta)**14 - 7.26102427564021e+43*cos(theta)**12 + 5.91639015052165e+42*cos(theta)**10 - 3.06372332305494e+41*cos(theta)**8 + 9.28401006986345e+39*cos(theta)**6 - 1.42830924151745e+38*cos(theta)**4 + 8.38537715176588e+35*cos(theta)**2 - 7.87359356973322e+32)*sin(20*phi)

#@torch.jit.script
def Yl50_m_minus_19(theta, phi):
    return 2.77925335924729e-32*(1.0 - cos(theta)**2)**9.5*(3.31441762920399e+44*cos(theta)**31 - 1.55677191674733e+45*cos(theta)**29 + 3.25798658865678e+45*cos(theta)**27 - 4.01246769339835e+45*cos(theta)**25 + 3.23586104306318e+45*cos(theta)**23 - 1.79928097559337e+45*cos(theta)**21 + 7.07582406132226e+44*cos(theta)**19 - 1.9868077413565e+44*cos(theta)**17 + 3.97361548271299e+43*cos(theta)**15 - 5.58540328895401e+42*cos(theta)**13 + 5.37853650047423e+41*cos(theta)**11 - 3.4041370256166e+40*cos(theta)**9 + 1.32628715283764e+39*cos(theta)**7 - 2.85661848303491e+37*cos(theta)**5 + 2.79512571725529e+35*cos(theta)**3 - 7.87359356973322e+32*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl50_m_minus_18(theta, phi):
    return 1.30595338012623e-30*(1.0 - cos(theta)**2)**9*(1.03575550912625e+43*cos(theta)**32 - 5.18923972249109e+43*cos(theta)**30 + 1.16356663880599e+44*cos(theta)**28 - 1.54325680515321e+44*cos(theta)**26 + 1.34827543460966e+44*cos(theta)**24 - 8.17854988906079e+43*cos(theta)**22 + 3.53791203066113e+43*cos(theta)**20 - 1.10378207853139e+43*cos(theta)**18 + 2.48350967669562e+42*cos(theta)**16 - 3.98957377782429e+41*cos(theta)**14 + 4.48211375039519e+40*cos(theta)**12 - 3.4041370256166e+39*cos(theta)**10 + 1.65785894104705e+38*cos(theta)**8 - 4.76103080505818e+36*cos(theta)**6 + 6.98781429313823e+34*cos(theta)**4 - 3.93679678486661e+32*cos(theta)**2 + 3.565939116727e+29)*sin(18*phi)

#@torch.jit.script
def Yl50_m_minus_17(theta, phi):
    return 6.18641571065642e-29*(1.0 - cos(theta)**2)**8.5*(3.13865305795832e+41*cos(theta)**33 - 1.67394829757777e+42*cos(theta)**31 + 4.01229875450342e+42*cos(theta)**29 - 5.71576594501189e+42*cos(theta)**27 + 5.39310173843864e+42*cos(theta)**25 - 3.55589125611339e+42*cos(theta)**23 + 1.68472001460054e+42*cos(theta)**21 - 5.80937936069151e+41*cos(theta)**19 + 1.46088804511507e+41*cos(theta)**17 - 2.65971585188286e+40*cos(theta)**15 + 3.4477798079963e+39*cos(theta)**13 - 3.09467002328782e+38*cos(theta)**11 + 1.84206549005227e+37*cos(theta)**9 - 6.80147257865454e+35*cos(theta)**7 + 1.39756285862765e+34*cos(theta)**5 - 1.31226559495554e+32*cos(theta)**3 + 3.565939116727e+29*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl50_m_minus_16(theta, phi):
    return 2.95267712809984e-27*(1.0 - cos(theta)**2)**8*(9.23133252340683e+39*cos(theta)**34 - 5.23108842993054e+40*cos(theta)**32 + 1.33743291816781e+41*cos(theta)**30 - 2.04134498036139e+41*cos(theta)**28 + 2.07426989939948e+41*cos(theta)**26 - 1.48162135671391e+41*cos(theta)**24 + 7.65781824818426e+40*cos(theta)**22 - 2.90468968034575e+40*cos(theta)**20 + 8.11604469508373e+39*cos(theta)**18 - 1.66232240742679e+39*cos(theta)**16 + 2.4626998628545e+38*cos(theta)**14 - 2.57889168607318e+37*cos(theta)**12 + 1.84206549005227e+36*cos(theta)**10 - 8.50184072331818e+34*cos(theta)**8 + 2.32927143104608e+33*cos(theta)**6 - 3.28066398738884e+31*cos(theta)**4 + 1.7829695583635e+29*cos(theta)**2 - 1.56538152621905e+26)*sin(16*phi)

#@torch.jit.script
def Yl50_m_minus_15(theta, phi):
    return 1.41912924480743e-25*(1.0 - cos(theta)**2)**7.5*(2.63752357811624e+38*cos(theta)**35 - 1.58517831210016e+39*cos(theta)**33 + 4.31429973602518e+39*cos(theta)**31 - 7.03912062193583e+39*cos(theta)**29 + 7.68248110888695e+39*cos(theta)**27 - 5.92648542685565e+39*cos(theta)**25 + 3.32948619486272e+39*cos(theta)**23 - 1.38318556206941e+39*cos(theta)**21 + 4.2716024710967e+38*cos(theta)**19 - 9.77836710251051e+37*cos(theta)**17 + 1.64179990856967e+37*cos(theta)**15 - 1.98376283544091e+36*cos(theta)**13 + 1.67460499095661e+35*cos(theta)**11 - 9.44648969257576e+33*cos(theta)**9 + 3.32753061578011e+32*cos(theta)**7 - 6.56132797477768e+30*cos(theta)**5 + 5.94323186121167e+28*cos(theta)**3 - 1.56538152621905e+26*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl50_m_minus_14(theta, phi):
    return 6.86483144987145e-24*(1.0 - cos(theta)**2)**7*(7.32645438365621e+36*cos(theta)**36 - 4.66228915323577e+37*cos(theta)**34 + 1.34821866750787e+38*cos(theta)**32 - 2.34637354064528e+38*cos(theta)**30 + 2.74374325317391e+38*cos(theta)**28 - 2.27941747186756e+38*cos(theta)**26 + 1.38728591452613e+38*cos(theta)**24 - 6.28720710031549e+37*cos(theta)**22 + 2.13580123554835e+37*cos(theta)**20 - 5.4324261680614e+36*cos(theta)**18 + 1.02612494285604e+36*cos(theta)**16 - 1.41697345388636e+35*cos(theta)**14 + 1.39550415913051e+34*cos(theta)**12 - 9.44648969257576e+32*cos(theta)**10 + 4.15941326972514e+31*cos(theta)**8 - 1.09355466246295e+30*cos(theta)**6 + 1.48580796530292e+28*cos(theta)**4 - 7.82690763109526e+25*cos(theta)**2 + 6.68966464196176e+22)*sin(14*phi)

#@torch.jit.script
def Yl50_m_minus_13(theta, phi):
    return 3.34057116160727e-22*(1.0 - cos(theta)**2)**6.5*(1.98012280639357e+35*cos(theta)**37 - 1.33208261521022e+36*cos(theta)**35 + 4.08551111366021e+36*cos(theta)**33 - 7.56894690530734e+36*cos(theta)**31 + 9.46118363163418e+36*cos(theta)**29 - 8.4422869328428e+36*cos(theta)**27 + 5.54914365810454e+36*cos(theta)**25 - 2.73356830448499e+36*cos(theta)**23 + 1.01704820740398e+36*cos(theta)**21 - 2.85917166740074e+35*cos(theta)**19 + 6.03602907562377e+34*cos(theta)**17 - 9.44648969257576e+33*cos(theta)**15 + 1.0734647377927e+33*cos(theta)**13 - 8.5877179023416e+31*cos(theta)**11 + 4.6215702996946e+30*cos(theta)**9 - 1.56222094637564e+29*cos(theta)**7 + 2.97161593060583e+27*cos(theta)**5 - 2.60896921036509e+25*cos(theta)**3 + 6.68966464196176e+22*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl50_m_minus_12(theta, phi):
    return 1.63449200523326e-20*(1.0 - cos(theta)**2)**6*(5.2108494905094e+33*cos(theta)**38 - 3.70022948669506e+34*cos(theta)**36 + 1.20162091578242e+35*cos(theta)**34 - 2.36529590790854e+35*cos(theta)**32 + 3.15372787721139e+35*cos(theta)**30 - 3.01510247601529e+35*cos(theta)**28 + 2.1342860223479e+35*cos(theta)**26 - 1.13898679353541e+35*cos(theta)**24 + 4.6229463972908e+34*cos(theta)**22 - 1.42958583370037e+34*cos(theta)**20 + 3.35334948645765e+33*cos(theta)**18 - 5.90405605785985e+32*cos(theta)**16 + 7.66760526994786e+31*cos(theta)**14 - 7.15643158528467e+30*cos(theta)**12 + 4.6215702996946e+29*cos(theta)**10 - 1.95277618296955e+28*cos(theta)**8 + 4.95269321767639e+26*cos(theta)**6 - 6.52242302591272e+24*cos(theta)**4 + 3.34483232098088e+22*cos(theta)**2 - 2.79434613281611e+19)*sin(12*phi)

#@torch.jit.script
def Yl50_m_minus_11(theta, phi):
    return 8.0373142469886e-19*(1.0 - cos(theta)**2)**5.5*(1.33611525397677e+32*cos(theta)**39 - 1.0000620234311e+33*cos(theta)**37 + 3.43320261652119e+33*cos(theta)**35 - 7.16756335729862e+33*cos(theta)**33 + 1.017331573294e+34*cos(theta)**31 - 1.03969050897079e+34*cos(theta)**29 + 7.90476304573296e+33*cos(theta)**27 - 4.55594717414166e+33*cos(theta)**25 + 2.00997669447426e+33*cos(theta)**23 - 6.80755158904937e+32*cos(theta)**21 + 1.76492078234613e+32*cos(theta)**19 - 3.47297415168226e+31*cos(theta)**17 + 5.1117368466319e+30*cos(theta)**15 - 5.5049473732959e+29*cos(theta)**13 + 4.20142754517691e+28*cos(theta)**11 - 2.16975131441061e+27*cos(theta)**9 + 7.07527602525199e+25*cos(theta)**7 - 1.30448460518254e+24*cos(theta)**5 + 1.11494410699363e+22*cos(theta)**3 - 2.79434613281611e+19*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl50_m_minus_10(theta, phi):
    return 3.9701403696069e-17*(1.0 - cos(theta)**2)**5*(3.34028813494192e+30*cos(theta)**40 - 2.63174216692394e+31*cos(theta)**38 + 9.53667393478107e+31*cos(theta)**36 - 2.10810686979371e+32*cos(theta)**34 + 3.17916116654374e+32*cos(theta)**32 - 3.46563502990263e+32*cos(theta)**30 + 2.82312965919034e+32*cos(theta)**28 - 1.75228737466987e+32*cos(theta)**26 + 8.37490289364275e+31*cos(theta)**24 - 3.09434163138608e+31*cos(theta)**22 + 8.82460391173066e+30*cos(theta)**20 - 1.92943008426792e+30*cos(theta)**18 + 3.19483552914494e+29*cos(theta)**16 - 3.93210526663993e+28*cos(theta)**14 + 3.50118962098076e+27*cos(theta)**12 - 2.16975131441061e+26*cos(theta)**10 + 8.84409503156498e+24*cos(theta)**8 - 2.17414100863757e+23*cos(theta)**6 + 2.78736026748407e+21*cos(theta)**4 - 1.39717306640805e+19*cos(theta)**2 + 1.14522382492463e+16)*sin(10*phi)

#@torch.jit.script
def Yl50_m_minus_9(theta, phi):
    return 1.96912558776175e-15*(1.0 - cos(theta)**2)**4.5*(8.14704423156566e+28*cos(theta)**41 - 6.74805683826651e+29*cos(theta)**39 + 2.57747944183272e+30*cos(theta)**37 - 6.02316248512489e+30*cos(theta)**35 + 9.63382171679922e+30*cos(theta)**33 - 1.11794678383956e+31*cos(theta)**31 + 9.73492985927705e+30*cos(theta)**29 - 6.48995323951803e+30*cos(theta)**27 + 3.3499611574571e+30*cos(theta)**25 - 1.3453659266896e+30*cos(theta)**23 + 4.20219233891936e+29*cos(theta)**21 - 1.01548951803575e+29*cos(theta)**19 + 1.87931501714408e+28*cos(theta)**17 - 2.62140351109328e+27*cos(theta)**15 + 2.69322278536981e+26*cos(theta)**13 - 1.97250119491874e+25*cos(theta)**11 + 9.82677225729443e+23*cos(theta)**9 - 3.1059157266251e+22*cos(theta)**7 + 5.57472053496814e+20*cos(theta)**5 - 4.65724355469351e+18*cos(theta)**3 + 1.14522382492463e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl50_m_minus_8(theta, phi):
    return 9.80221144853387e-14*(1.0 - cos(theta)**2)**4*(1.93977243608706e+27*cos(theta)**42 - 1.68701420956663e+28*cos(theta)**40 + 6.7828406364019e+28*cos(theta)**38 - 1.67310069031247e+29*cos(theta)**36 + 2.83347697552918e+29*cos(theta)**34 - 3.49358369949862e+29*cos(theta)**32 + 3.24497661975902e+29*cos(theta)**30 - 2.31784044268501e+29*cos(theta)**28 + 1.28844659902196e+29*cos(theta)**26 - 5.60569136120666e+28*cos(theta)**24 + 1.91008742678153e+28*cos(theta)**22 - 5.07744759017875e+27*cos(theta)**20 + 1.04406389841338e+27*cos(theta)**18 - 1.6383771944333e+26*cos(theta)**16 + 1.92373056097844e+25*cos(theta)**14 - 1.64375099576561e+24*cos(theta)**12 + 9.82677225729443e+22*cos(theta)**10 - 3.88239465828138e+21*cos(theta)**8 + 9.29120089161356e+19*cos(theta)**6 - 1.16431088867338e+18*cos(theta)**4 + 5.72611912462317e+15*cos(theta)**2 - 4621565072335.09)*sin(8*phi)

#@torch.jit.script
def Yl50_m_minus_7(theta, phi):
    return 4.89522086436078e-12*(1.0 - cos(theta)**2)**3.5*(4.51109868857456e+25*cos(theta)**43 - 4.11466880382104e+26*cos(theta)**41 + 1.73918990676972e+27*cos(theta)**39 - 4.52189375760127e+27*cos(theta)**37 + 8.09564850151195e+27*cos(theta)**35 - 1.05866172712079e+28*cos(theta)**33 + 1.04676665153517e+28*cos(theta)**31 - 7.99255325063797e+27*cos(theta)**29 + 4.77202444082208e+27*cos(theta)**27 - 2.24227654448266e+27*cos(theta)**25 + 8.30472794252839e+26*cos(theta)**23 - 2.4178321857994e+26*cos(theta)**21 + 5.4950731495441e+25*cos(theta)**19 - 9.63751290843119e+24*cos(theta)**17 + 1.28248704065229e+24*cos(theta)**15 - 1.26442384289663e+23*cos(theta)**13 + 8.93342932481311e+21*cos(theta)**11 - 4.31377184253487e+20*cos(theta)**9 + 1.32731441308765e+19*cos(theta)**7 - 2.32862177734676e+17*cos(theta)**5 + 1.90870637487439e+15*cos(theta)**3 - 4621565072335.09*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl50_m_minus_6(theta, phi):
    return 2.45152348093323e-10*(1.0 - cos(theta)**2)**3*(1.02524970194876e+24*cos(theta)**44 - 9.79683048528819e+24*cos(theta)**42 + 4.3479747669243e+25*cos(theta)**40 - 1.18997204147402e+26*cos(theta)**38 + 2.24879125041999e+26*cos(theta)**36 - 3.11371096211998e+26*cos(theta)**34 + 3.27114578604739e+26*cos(theta)**32 - 2.66418441687932e+26*cos(theta)**30 + 1.70429444315074e+26*cos(theta)**28 - 8.62414055570256e+25*cos(theta)**26 + 3.46030330938683e+25*cos(theta)**24 - 1.09901462990882e+25*cos(theta)**22 + 2.74753657477205e+24*cos(theta)**20 - 5.35417383801733e+23*cos(theta)**18 + 8.01554400407682e+22*cos(theta)**16 - 9.03159887783304e+21*cos(theta)**14 + 7.44452443734426e+20*cos(theta)**12 - 4.31377184253487e+19*cos(theta)**10 + 1.65914301635956e+18*cos(theta)**8 - 3.88103629557793e+16*cos(theta)**6 + 477176593718598.0*cos(theta)**4 - 2310782536167.54*cos(theta)**2 + 1842729295.18943)*sin(6*phi)

#@torch.jit.script
def Yl50_m_minus_5(theta, phi):
    return 1.2306550203639e-8*(1.0 - cos(theta)**2)**2.5*(2.27833267099725e+22*cos(theta)**45 - 2.27833267099725e+23*cos(theta)**43 + 1.06048165046934e+24*cos(theta)**41 - 3.05121036275389e+24*cos(theta)**39 + 6.07781419032428e+24*cos(theta)**37 - 8.89631703462851e+24*cos(theta)**35 + 9.91256298802241e+24*cos(theta)**33 - 8.59414328025588e+24*cos(theta)**31 + 5.87687739017498e+24*cos(theta)**29 - 3.19412613174169e+24*cos(theta)**27 + 1.38412132375473e+24*cos(theta)**25 - 4.77832447786443e+23*cos(theta)**23 + 1.30835074989145e+23*cos(theta)**21 - 2.81798623053544e+22*cos(theta)**19 + 4.71502588475107e+21*cos(theta)**17 - 6.02106591855536e+20*cos(theta)**15 + 5.72655725949559e+19*cos(theta)**13 - 3.92161076594079e+18*cos(theta)**11 + 1.84349224039952e+17*cos(theta)**9 - 5.54433756511133e+15*cos(theta)**7 + 95435318743719.5*cos(theta)**5 - 770260845389.181*cos(theta)**3 + 1842729295.18943*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl50_m_minus_4(theta, phi):
    return 6.19008465308964e-7*(1.0 - cos(theta)**2)**2*(4.9528971108636e+20*cos(theta)**46 - 5.17802879772103e+21*cos(theta)**44 + 2.52495631064129e+22*cos(theta)**42 - 7.62802590688473e+22*cos(theta)**40 + 1.59942478692744e+23*cos(theta)**38 - 2.4711991762857e+23*cos(theta)**36 + 2.91545970235953e+23*cos(theta)**34 - 2.68566977507996e+23*cos(theta)**32 + 1.95895913005833e+23*cos(theta)**30 - 1.14075933276489e+23*cos(theta)**28 + 5.32354355290281e+22*cos(theta)**26 - 1.99096853244351e+22*cos(theta)**24 + 5.94704886314296e+21*cos(theta)**22 - 1.40899311526772e+21*cos(theta)**20 + 2.61945882486171e+20*cos(theta)**18 - 3.7631661990971e+19*cos(theta)**16 + 4.09039804249685e+18*cos(theta)**14 - 3.26800897161732e+17*cos(theta)**12 + 1.84349224039952e+16*cos(theta)**10 - 693042195638916.0*cos(theta)**8 + 15905886457286.6*cos(theta)**6 - 192565211347.295*cos(theta)**4 + 921364647.594714*cos(theta)**2 - 728351.500074873)*sin(4*phi)

#@torch.jit.script
def Yl50_m_minus_3(theta, phi):
    return 3.11847593634313e-5*(1.0 - cos(theta)**2)**1.5*(1.05380789592842e+19*cos(theta)**47 - 1.15067306616023e+20*cos(theta)**45 + 5.87199142009602e+20*cos(theta)**43 - 1.86049412363042e+21*cos(theta)**41 + 4.10108919724985e+21*cos(theta)**39 - 6.67891669266405e+21*cos(theta)**37 + 8.32988486388438e+21*cos(theta)**35 - 8.13839325781807e+21*cos(theta)**33 + 6.31922300018815e+21*cos(theta)**31 - 3.93365287160306e+21*cos(theta)**29 + 1.97168279737141e+21*cos(theta)**27 - 7.96387412977406e+20*cos(theta)**25 + 2.58567341875781e+20*cos(theta)**23 - 6.70949102508437e+19*cos(theta)**21 + 1.3786625394009e+19*cos(theta)**19 - 2.21362717593947e+18*cos(theta)**17 + 2.72693202833123e+17*cos(theta)**15 - 2.51385305509025e+16*cos(theta)**13 + 1.67590203672683e+15*cos(theta)**11 - 77004688404324.0*cos(theta)**9 + 2272269493898.08*cos(theta)**7 - 38513042269.4591*cos(theta)**5 + 307121549.198238*cos(theta)**3 - 728351.500074873*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl50_m_minus_2(theta, phi):
    return 0.00157289941411275*(1.0 - cos(theta)**2)*(2.19543311651755e+17*cos(theta)**48 - 2.50146318730485e+18*cos(theta)**46 + 1.33454350456728e+19*cos(theta)**44 - 4.42974791340577e+19*cos(theta)**42 + 1.02527229931246e+20*cos(theta)**40 - 1.75760965596422e+20*cos(theta)**38 + 2.31385690663455e+20*cos(theta)**36 - 2.39364507582884e+20*cos(theta)**34 + 1.9747571875588e+20*cos(theta)**32 - 1.31121762386769e+20*cos(theta)**30 + 7.04172427632647e+19*cos(theta)**28 - 3.06302851145156e+19*cos(theta)**26 + 1.07736392448242e+19*cos(theta)**24 - 3.04976864776562e+18*cos(theta)**22 + 6.89331269700449e+17*cos(theta)**20 - 1.22979287552193e+17*cos(theta)**18 + 1.70433251770702e+16*cos(theta)**16 - 1.79560932506446e+15*cos(theta)**14 + 139658503060569.0*cos(theta)**12 - 7700468840432.4*cos(theta)**10 + 284033686737.26*cos(theta)**8 - 6418840378.24318*cos(theta)**6 + 76780387.2995595*cos(theta)**4 - 364175.750037436*cos(theta)**2 + 286.301690281003)*sin(2*phi)

#@torch.jit.script
def Yl50_m_minus_1(theta, phi):
    return 0.0793963728422308*(1.0 - cos(theta)**2)**0.5*(4.480475747995e+15*cos(theta)**49 - 5.32226210064861e+16*cos(theta)**47 + 2.96565223237172e+17*cos(theta)**45 - 1.03017393335018e+18*cos(theta)**43 + 2.50066414466455e+18*cos(theta)**41 - 4.50669142554929e+18*cos(theta)**39 + 6.25366731522851e+18*cos(theta)**37 - 6.83898593093955e+18*cos(theta)**35 + 5.98411268957211e+18*cos(theta)**33 - 4.22973427054093e+18*cos(theta)**31 + 2.42818078494016e+18*cos(theta)**29 - 1.13445500424132e+18*cos(theta)**27 + 4.30945569792969e+17*cos(theta)**25 - 1.32598636859375e+17*cos(theta)**23 + 3.28252985571642e+16*cos(theta)**21 - 6.47259408169436e+15*cos(theta)**19 + 1.00254853982766e+15*cos(theta)**17 - 119707288337631.0*cos(theta)**15 + 10742961773890.0*cos(theta)**13 - 700042621857.49*cos(theta)**11 + 31559298526.3623*cos(theta)**9 - 916977196.891882*cos(theta)**7 + 15356077.4599119*cos(theta)**5 - 121391.916679145*cos(theta)**3 + 286.301690281003*cos(theta))*sin(phi)

#@torch.jit.script
def Yl50_m0(theta, phi):
    return 798104490119267.0*cos(theta)**50 - 9.87553535753638e+15*cos(theta)**48 + 5.74206385737167e+16*cos(theta)**46 - 2.08527582188761e+17*cos(theta)**44 + 5.30287883738085e+17*cos(theta)**42 - 1.00346784153515e+18*cos(theta)**40 + 1.46573954381538e+18*cos(theta)**38 - 1.69197848818097e+18*cos(theta)**36 + 1.56756830522649e+18*cos(theta)**34 - 1.17725009268013e+18*cos(theta)**32 + 7.20884007369564e+17*cos(theta)**30 - 3.60856781594661e+17*cos(theta)**28 + 1.47623228834179e+17*cos(theta)**26 - 4.92077429447265e+16*cos(theta)**24 + 1.32889795036639e+16*cos(theta)**22 - 2.88239837121724e+15*cos(theta)**20 + 496064937075431.0*cos(theta)**18 - 66635588562371.3*cos(theta)**16 + 6834419339730.39*cos(theta)**14 - 519575739277.749*cos(theta)**12 + 28108195731.4192*cos(theta)**10 - 1020878779.5915*cos(theta)**8 + 22794741.4900813*cos(theta)**6 - 270293.377352742*cos(theta)**4 + 1274.96876109784*cos(theta)**2 - 0.999975498900268

#@torch.jit.script
def Yl50_m1(theta, phi):
    return 0.0793963728422308*(1.0 - cos(theta)**2)**0.5*(4.480475747995e+15*cos(theta)**49 - 5.32226210064861e+16*cos(theta)**47 + 2.96565223237172e+17*cos(theta)**45 - 1.03017393335018e+18*cos(theta)**43 + 2.50066414466455e+18*cos(theta)**41 - 4.50669142554929e+18*cos(theta)**39 + 6.25366731522851e+18*cos(theta)**37 - 6.83898593093955e+18*cos(theta)**35 + 5.98411268957211e+18*cos(theta)**33 - 4.22973427054093e+18*cos(theta)**31 + 2.42818078494016e+18*cos(theta)**29 - 1.13445500424132e+18*cos(theta)**27 + 4.30945569792969e+17*cos(theta)**25 - 1.32598636859375e+17*cos(theta)**23 + 3.28252985571642e+16*cos(theta)**21 - 6.47259408169436e+15*cos(theta)**19 + 1.00254853982766e+15*cos(theta)**17 - 119707288337631.0*cos(theta)**15 + 10742961773890.0*cos(theta)**13 - 700042621857.49*cos(theta)**11 + 31559298526.3623*cos(theta)**9 - 916977196.891882*cos(theta)**7 + 15356077.4599119*cos(theta)**5 - 121391.916679145*cos(theta)**3 + 286.301690281003*cos(theta))*cos(phi)

#@torch.jit.script
def Yl50_m2(theta, phi):
    return 0.00157289941411275*(1.0 - cos(theta)**2)*(2.19543311651755e+17*cos(theta)**48 - 2.50146318730485e+18*cos(theta)**46 + 1.33454350456728e+19*cos(theta)**44 - 4.42974791340577e+19*cos(theta)**42 + 1.02527229931246e+20*cos(theta)**40 - 1.75760965596422e+20*cos(theta)**38 + 2.31385690663455e+20*cos(theta)**36 - 2.39364507582884e+20*cos(theta)**34 + 1.9747571875588e+20*cos(theta)**32 - 1.31121762386769e+20*cos(theta)**30 + 7.04172427632647e+19*cos(theta)**28 - 3.06302851145156e+19*cos(theta)**26 + 1.07736392448242e+19*cos(theta)**24 - 3.04976864776562e+18*cos(theta)**22 + 6.89331269700449e+17*cos(theta)**20 - 1.22979287552193e+17*cos(theta)**18 + 1.70433251770702e+16*cos(theta)**16 - 1.79560932506446e+15*cos(theta)**14 + 139658503060569.0*cos(theta)**12 - 7700468840432.4*cos(theta)**10 + 284033686737.26*cos(theta)**8 - 6418840378.24318*cos(theta)**6 + 76780387.2995595*cos(theta)**4 - 364175.750037436*cos(theta)**2 + 286.301690281003)*cos(2*phi)

#@torch.jit.script
def Yl50_m3(theta, phi):
    return 3.11847593634313e-5*(1.0 - cos(theta)**2)**1.5*(1.05380789592842e+19*cos(theta)**47 - 1.15067306616023e+20*cos(theta)**45 + 5.87199142009602e+20*cos(theta)**43 - 1.86049412363042e+21*cos(theta)**41 + 4.10108919724985e+21*cos(theta)**39 - 6.67891669266405e+21*cos(theta)**37 + 8.32988486388438e+21*cos(theta)**35 - 8.13839325781807e+21*cos(theta)**33 + 6.31922300018815e+21*cos(theta)**31 - 3.93365287160306e+21*cos(theta)**29 + 1.97168279737141e+21*cos(theta)**27 - 7.96387412977406e+20*cos(theta)**25 + 2.58567341875781e+20*cos(theta)**23 - 6.70949102508437e+19*cos(theta)**21 + 1.3786625394009e+19*cos(theta)**19 - 2.21362717593947e+18*cos(theta)**17 + 2.72693202833123e+17*cos(theta)**15 - 2.51385305509025e+16*cos(theta)**13 + 1.67590203672683e+15*cos(theta)**11 - 77004688404324.0*cos(theta)**9 + 2272269493898.08*cos(theta)**7 - 38513042269.4591*cos(theta)**5 + 307121549.198238*cos(theta)**3 - 728351.500074873*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl50_m4(theta, phi):
    return 6.19008465308964e-7*(1.0 - cos(theta)**2)**2*(4.9528971108636e+20*cos(theta)**46 - 5.17802879772103e+21*cos(theta)**44 + 2.52495631064129e+22*cos(theta)**42 - 7.62802590688473e+22*cos(theta)**40 + 1.59942478692744e+23*cos(theta)**38 - 2.4711991762857e+23*cos(theta)**36 + 2.91545970235953e+23*cos(theta)**34 - 2.68566977507996e+23*cos(theta)**32 + 1.95895913005833e+23*cos(theta)**30 - 1.14075933276489e+23*cos(theta)**28 + 5.32354355290281e+22*cos(theta)**26 - 1.99096853244351e+22*cos(theta)**24 + 5.94704886314296e+21*cos(theta)**22 - 1.40899311526772e+21*cos(theta)**20 + 2.61945882486171e+20*cos(theta)**18 - 3.7631661990971e+19*cos(theta)**16 + 4.09039804249685e+18*cos(theta)**14 - 3.26800897161732e+17*cos(theta)**12 + 1.84349224039952e+16*cos(theta)**10 - 693042195638916.0*cos(theta)**8 + 15905886457286.6*cos(theta)**6 - 192565211347.295*cos(theta)**4 + 921364647.594714*cos(theta)**2 - 728351.500074873)*cos(4*phi)

#@torch.jit.script
def Yl50_m5(theta, phi):
    return 1.2306550203639e-8*(1.0 - cos(theta)**2)**2.5*(2.27833267099725e+22*cos(theta)**45 - 2.27833267099725e+23*cos(theta)**43 + 1.06048165046934e+24*cos(theta)**41 - 3.05121036275389e+24*cos(theta)**39 + 6.07781419032428e+24*cos(theta)**37 - 8.89631703462851e+24*cos(theta)**35 + 9.91256298802241e+24*cos(theta)**33 - 8.59414328025588e+24*cos(theta)**31 + 5.87687739017498e+24*cos(theta)**29 - 3.19412613174169e+24*cos(theta)**27 + 1.38412132375473e+24*cos(theta)**25 - 4.77832447786443e+23*cos(theta)**23 + 1.30835074989145e+23*cos(theta)**21 - 2.81798623053544e+22*cos(theta)**19 + 4.71502588475107e+21*cos(theta)**17 - 6.02106591855536e+20*cos(theta)**15 + 5.72655725949559e+19*cos(theta)**13 - 3.92161076594079e+18*cos(theta)**11 + 1.84349224039952e+17*cos(theta)**9 - 5.54433756511133e+15*cos(theta)**7 + 95435318743719.5*cos(theta)**5 - 770260845389.181*cos(theta)**3 + 1842729295.18943*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl50_m6(theta, phi):
    return 2.45152348093323e-10*(1.0 - cos(theta)**2)**3*(1.02524970194876e+24*cos(theta)**44 - 9.79683048528819e+24*cos(theta)**42 + 4.3479747669243e+25*cos(theta)**40 - 1.18997204147402e+26*cos(theta)**38 + 2.24879125041999e+26*cos(theta)**36 - 3.11371096211998e+26*cos(theta)**34 + 3.27114578604739e+26*cos(theta)**32 - 2.66418441687932e+26*cos(theta)**30 + 1.70429444315074e+26*cos(theta)**28 - 8.62414055570256e+25*cos(theta)**26 + 3.46030330938683e+25*cos(theta)**24 - 1.09901462990882e+25*cos(theta)**22 + 2.74753657477205e+24*cos(theta)**20 - 5.35417383801733e+23*cos(theta)**18 + 8.01554400407682e+22*cos(theta)**16 - 9.03159887783304e+21*cos(theta)**14 + 7.44452443734426e+20*cos(theta)**12 - 4.31377184253487e+19*cos(theta)**10 + 1.65914301635956e+18*cos(theta)**8 - 3.88103629557793e+16*cos(theta)**6 + 477176593718598.0*cos(theta)**4 - 2310782536167.54*cos(theta)**2 + 1842729295.18943)*cos(6*phi)

#@torch.jit.script
def Yl50_m7(theta, phi):
    return 4.89522086436078e-12*(1.0 - cos(theta)**2)**3.5*(4.51109868857456e+25*cos(theta)**43 - 4.11466880382104e+26*cos(theta)**41 + 1.73918990676972e+27*cos(theta)**39 - 4.52189375760127e+27*cos(theta)**37 + 8.09564850151195e+27*cos(theta)**35 - 1.05866172712079e+28*cos(theta)**33 + 1.04676665153517e+28*cos(theta)**31 - 7.99255325063797e+27*cos(theta)**29 + 4.77202444082208e+27*cos(theta)**27 - 2.24227654448266e+27*cos(theta)**25 + 8.30472794252839e+26*cos(theta)**23 - 2.4178321857994e+26*cos(theta)**21 + 5.4950731495441e+25*cos(theta)**19 - 9.63751290843119e+24*cos(theta)**17 + 1.28248704065229e+24*cos(theta)**15 - 1.26442384289663e+23*cos(theta)**13 + 8.93342932481311e+21*cos(theta)**11 - 4.31377184253487e+20*cos(theta)**9 + 1.32731441308765e+19*cos(theta)**7 - 2.32862177734676e+17*cos(theta)**5 + 1.90870637487439e+15*cos(theta)**3 - 4621565072335.09*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl50_m8(theta, phi):
    return 9.80221144853387e-14*(1.0 - cos(theta)**2)**4*(1.93977243608706e+27*cos(theta)**42 - 1.68701420956663e+28*cos(theta)**40 + 6.7828406364019e+28*cos(theta)**38 - 1.67310069031247e+29*cos(theta)**36 + 2.83347697552918e+29*cos(theta)**34 - 3.49358369949862e+29*cos(theta)**32 + 3.24497661975902e+29*cos(theta)**30 - 2.31784044268501e+29*cos(theta)**28 + 1.28844659902196e+29*cos(theta)**26 - 5.60569136120666e+28*cos(theta)**24 + 1.91008742678153e+28*cos(theta)**22 - 5.07744759017875e+27*cos(theta)**20 + 1.04406389841338e+27*cos(theta)**18 - 1.6383771944333e+26*cos(theta)**16 + 1.92373056097844e+25*cos(theta)**14 - 1.64375099576561e+24*cos(theta)**12 + 9.82677225729443e+22*cos(theta)**10 - 3.88239465828138e+21*cos(theta)**8 + 9.29120089161356e+19*cos(theta)**6 - 1.16431088867338e+18*cos(theta)**4 + 5.72611912462317e+15*cos(theta)**2 - 4621565072335.09)*cos(8*phi)

#@torch.jit.script
def Yl50_m9(theta, phi):
    return 1.96912558776175e-15*(1.0 - cos(theta)**2)**4.5*(8.14704423156566e+28*cos(theta)**41 - 6.74805683826651e+29*cos(theta)**39 + 2.57747944183272e+30*cos(theta)**37 - 6.02316248512489e+30*cos(theta)**35 + 9.63382171679922e+30*cos(theta)**33 - 1.11794678383956e+31*cos(theta)**31 + 9.73492985927705e+30*cos(theta)**29 - 6.48995323951803e+30*cos(theta)**27 + 3.3499611574571e+30*cos(theta)**25 - 1.3453659266896e+30*cos(theta)**23 + 4.20219233891936e+29*cos(theta)**21 - 1.01548951803575e+29*cos(theta)**19 + 1.87931501714408e+28*cos(theta)**17 - 2.62140351109328e+27*cos(theta)**15 + 2.69322278536981e+26*cos(theta)**13 - 1.97250119491874e+25*cos(theta)**11 + 9.82677225729443e+23*cos(theta)**9 - 3.1059157266251e+22*cos(theta)**7 + 5.57472053496814e+20*cos(theta)**5 - 4.65724355469351e+18*cos(theta)**3 + 1.14522382492463e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl50_m10(theta, phi):
    return 3.9701403696069e-17*(1.0 - cos(theta)**2)**5*(3.34028813494192e+30*cos(theta)**40 - 2.63174216692394e+31*cos(theta)**38 + 9.53667393478107e+31*cos(theta)**36 - 2.10810686979371e+32*cos(theta)**34 + 3.17916116654374e+32*cos(theta)**32 - 3.46563502990263e+32*cos(theta)**30 + 2.82312965919034e+32*cos(theta)**28 - 1.75228737466987e+32*cos(theta)**26 + 8.37490289364275e+31*cos(theta)**24 - 3.09434163138608e+31*cos(theta)**22 + 8.82460391173066e+30*cos(theta)**20 - 1.92943008426792e+30*cos(theta)**18 + 3.19483552914494e+29*cos(theta)**16 - 3.93210526663993e+28*cos(theta)**14 + 3.50118962098076e+27*cos(theta)**12 - 2.16975131441061e+26*cos(theta)**10 + 8.84409503156498e+24*cos(theta)**8 - 2.17414100863757e+23*cos(theta)**6 + 2.78736026748407e+21*cos(theta)**4 - 1.39717306640805e+19*cos(theta)**2 + 1.14522382492463e+16)*cos(10*phi)

#@torch.jit.script
def Yl50_m11(theta, phi):
    return 8.0373142469886e-19*(1.0 - cos(theta)**2)**5.5*(1.33611525397677e+32*cos(theta)**39 - 1.0000620234311e+33*cos(theta)**37 + 3.43320261652119e+33*cos(theta)**35 - 7.16756335729862e+33*cos(theta)**33 + 1.017331573294e+34*cos(theta)**31 - 1.03969050897079e+34*cos(theta)**29 + 7.90476304573296e+33*cos(theta)**27 - 4.55594717414166e+33*cos(theta)**25 + 2.00997669447426e+33*cos(theta)**23 - 6.80755158904937e+32*cos(theta)**21 + 1.76492078234613e+32*cos(theta)**19 - 3.47297415168226e+31*cos(theta)**17 + 5.1117368466319e+30*cos(theta)**15 - 5.5049473732959e+29*cos(theta)**13 + 4.20142754517691e+28*cos(theta)**11 - 2.16975131441061e+27*cos(theta)**9 + 7.07527602525199e+25*cos(theta)**7 - 1.30448460518254e+24*cos(theta)**5 + 1.11494410699363e+22*cos(theta)**3 - 2.79434613281611e+19*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl50_m12(theta, phi):
    return 1.63449200523326e-20*(1.0 - cos(theta)**2)**6*(5.2108494905094e+33*cos(theta)**38 - 3.70022948669506e+34*cos(theta)**36 + 1.20162091578242e+35*cos(theta)**34 - 2.36529590790854e+35*cos(theta)**32 + 3.15372787721139e+35*cos(theta)**30 - 3.01510247601529e+35*cos(theta)**28 + 2.1342860223479e+35*cos(theta)**26 - 1.13898679353541e+35*cos(theta)**24 + 4.6229463972908e+34*cos(theta)**22 - 1.42958583370037e+34*cos(theta)**20 + 3.35334948645765e+33*cos(theta)**18 - 5.90405605785985e+32*cos(theta)**16 + 7.66760526994786e+31*cos(theta)**14 - 7.15643158528467e+30*cos(theta)**12 + 4.6215702996946e+29*cos(theta)**10 - 1.95277618296955e+28*cos(theta)**8 + 4.95269321767639e+26*cos(theta)**6 - 6.52242302591272e+24*cos(theta)**4 + 3.34483232098088e+22*cos(theta)**2 - 2.79434613281611e+19)*cos(12*phi)

#@torch.jit.script
def Yl50_m13(theta, phi):
    return 3.34057116160727e-22*(1.0 - cos(theta)**2)**6.5*(1.98012280639357e+35*cos(theta)**37 - 1.33208261521022e+36*cos(theta)**35 + 4.08551111366021e+36*cos(theta)**33 - 7.56894690530734e+36*cos(theta)**31 + 9.46118363163418e+36*cos(theta)**29 - 8.4422869328428e+36*cos(theta)**27 + 5.54914365810454e+36*cos(theta)**25 - 2.73356830448499e+36*cos(theta)**23 + 1.01704820740398e+36*cos(theta)**21 - 2.85917166740074e+35*cos(theta)**19 + 6.03602907562377e+34*cos(theta)**17 - 9.44648969257576e+33*cos(theta)**15 + 1.0734647377927e+33*cos(theta)**13 - 8.5877179023416e+31*cos(theta)**11 + 4.6215702996946e+30*cos(theta)**9 - 1.56222094637564e+29*cos(theta)**7 + 2.97161593060583e+27*cos(theta)**5 - 2.60896921036509e+25*cos(theta)**3 + 6.68966464196176e+22*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl50_m14(theta, phi):
    return 6.86483144987145e-24*(1.0 - cos(theta)**2)**7*(7.32645438365621e+36*cos(theta)**36 - 4.66228915323577e+37*cos(theta)**34 + 1.34821866750787e+38*cos(theta)**32 - 2.34637354064528e+38*cos(theta)**30 + 2.74374325317391e+38*cos(theta)**28 - 2.27941747186756e+38*cos(theta)**26 + 1.38728591452613e+38*cos(theta)**24 - 6.28720710031549e+37*cos(theta)**22 + 2.13580123554835e+37*cos(theta)**20 - 5.4324261680614e+36*cos(theta)**18 + 1.02612494285604e+36*cos(theta)**16 - 1.41697345388636e+35*cos(theta)**14 + 1.39550415913051e+34*cos(theta)**12 - 9.44648969257576e+32*cos(theta)**10 + 4.15941326972514e+31*cos(theta)**8 - 1.09355466246295e+30*cos(theta)**6 + 1.48580796530292e+28*cos(theta)**4 - 7.82690763109526e+25*cos(theta)**2 + 6.68966464196176e+22)*cos(14*phi)

#@torch.jit.script
def Yl50_m15(theta, phi):
    return 1.41912924480743e-25*(1.0 - cos(theta)**2)**7.5*(2.63752357811624e+38*cos(theta)**35 - 1.58517831210016e+39*cos(theta)**33 + 4.31429973602518e+39*cos(theta)**31 - 7.03912062193583e+39*cos(theta)**29 + 7.68248110888695e+39*cos(theta)**27 - 5.92648542685565e+39*cos(theta)**25 + 3.32948619486272e+39*cos(theta)**23 - 1.38318556206941e+39*cos(theta)**21 + 4.2716024710967e+38*cos(theta)**19 - 9.77836710251051e+37*cos(theta)**17 + 1.64179990856967e+37*cos(theta)**15 - 1.98376283544091e+36*cos(theta)**13 + 1.67460499095661e+35*cos(theta)**11 - 9.44648969257576e+33*cos(theta)**9 + 3.32753061578011e+32*cos(theta)**7 - 6.56132797477768e+30*cos(theta)**5 + 5.94323186121167e+28*cos(theta)**3 - 1.56538152621905e+26*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl50_m16(theta, phi):
    return 2.95267712809984e-27*(1.0 - cos(theta)**2)**8*(9.23133252340683e+39*cos(theta)**34 - 5.23108842993054e+40*cos(theta)**32 + 1.33743291816781e+41*cos(theta)**30 - 2.04134498036139e+41*cos(theta)**28 + 2.07426989939948e+41*cos(theta)**26 - 1.48162135671391e+41*cos(theta)**24 + 7.65781824818426e+40*cos(theta)**22 - 2.90468968034575e+40*cos(theta)**20 + 8.11604469508373e+39*cos(theta)**18 - 1.66232240742679e+39*cos(theta)**16 + 2.4626998628545e+38*cos(theta)**14 - 2.57889168607318e+37*cos(theta)**12 + 1.84206549005227e+36*cos(theta)**10 - 8.50184072331818e+34*cos(theta)**8 + 2.32927143104608e+33*cos(theta)**6 - 3.28066398738884e+31*cos(theta)**4 + 1.7829695583635e+29*cos(theta)**2 - 1.56538152621905e+26)*cos(16*phi)

#@torch.jit.script
def Yl50_m17(theta, phi):
    return 6.18641571065642e-29*(1.0 - cos(theta)**2)**8.5*(3.13865305795832e+41*cos(theta)**33 - 1.67394829757777e+42*cos(theta)**31 + 4.01229875450342e+42*cos(theta)**29 - 5.71576594501189e+42*cos(theta)**27 + 5.39310173843864e+42*cos(theta)**25 - 3.55589125611339e+42*cos(theta)**23 + 1.68472001460054e+42*cos(theta)**21 - 5.80937936069151e+41*cos(theta)**19 + 1.46088804511507e+41*cos(theta)**17 - 2.65971585188286e+40*cos(theta)**15 + 3.4477798079963e+39*cos(theta)**13 - 3.09467002328782e+38*cos(theta)**11 + 1.84206549005227e+37*cos(theta)**9 - 6.80147257865454e+35*cos(theta)**7 + 1.39756285862765e+34*cos(theta)**5 - 1.31226559495554e+32*cos(theta)**3 + 3.565939116727e+29*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl50_m18(theta, phi):
    return 1.30595338012623e-30*(1.0 - cos(theta)**2)**9*(1.03575550912625e+43*cos(theta)**32 - 5.18923972249109e+43*cos(theta)**30 + 1.16356663880599e+44*cos(theta)**28 - 1.54325680515321e+44*cos(theta)**26 + 1.34827543460966e+44*cos(theta)**24 - 8.17854988906079e+43*cos(theta)**22 + 3.53791203066113e+43*cos(theta)**20 - 1.10378207853139e+43*cos(theta)**18 + 2.48350967669562e+42*cos(theta)**16 - 3.98957377782429e+41*cos(theta)**14 + 4.48211375039519e+40*cos(theta)**12 - 3.4041370256166e+39*cos(theta)**10 + 1.65785894104705e+38*cos(theta)**8 - 4.76103080505818e+36*cos(theta)**6 + 6.98781429313823e+34*cos(theta)**4 - 3.93679678486661e+32*cos(theta)**2 + 3.565939116727e+29)*cos(18*phi)

#@torch.jit.script
def Yl50_m19(theta, phi):
    return 2.77925335924729e-32*(1.0 - cos(theta)**2)**9.5*(3.31441762920399e+44*cos(theta)**31 - 1.55677191674733e+45*cos(theta)**29 + 3.25798658865678e+45*cos(theta)**27 - 4.01246769339835e+45*cos(theta)**25 + 3.23586104306318e+45*cos(theta)**23 - 1.79928097559337e+45*cos(theta)**21 + 7.07582406132226e+44*cos(theta)**19 - 1.9868077413565e+44*cos(theta)**17 + 3.97361548271299e+43*cos(theta)**15 - 5.58540328895401e+42*cos(theta)**13 + 5.37853650047423e+41*cos(theta)**11 - 3.4041370256166e+40*cos(theta)**9 + 1.32628715283764e+39*cos(theta)**7 - 2.85661848303491e+37*cos(theta)**5 + 2.79512571725529e+35*cos(theta)**3 - 7.87359356973322e+32*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl50_m20(theta, phi):
    return 5.96620638211175e-34*(1.0 - cos(theta)**2)**10*(1.02746946505324e+46*cos(theta)**30 - 4.51463855856725e+46*cos(theta)**28 + 8.7965637893733e+46*cos(theta)**26 - 1.00311692334959e+47*cos(theta)**24 + 7.44248039904532e+46*cos(theta)**22 - 3.77849004874609e+46*cos(theta)**20 + 1.34440657165123e+46*cos(theta)**18 - 3.37757316030604e+45*cos(theta)**16 + 5.96042322406949e+44*cos(theta)**14 - 7.26102427564021e+43*cos(theta)**12 + 5.91639015052165e+42*cos(theta)**10 - 3.06372332305494e+41*cos(theta)**8 + 9.28401006986345e+39*cos(theta)**6 - 1.42830924151745e+38*cos(theta)**4 + 8.38537715176588e+35*cos(theta)**2 - 7.87359356973322e+32)*cos(20*phi)

#@torch.jit.script
def Yl50_m21(theta, phi):
    return 1.29273191440952e-35*(1.0 - cos(theta)**2)**10.5*(3.08240839515971e+47*cos(theta)**29 - 1.26409879639883e+48*cos(theta)**27 + 2.28710658523706e+48*cos(theta)**25 - 2.40748061603901e+48*cos(theta)**23 + 1.63734568778997e+48*cos(theta)**21 - 7.55698009749217e+47*cos(theta)**19 + 2.41993182897221e+47*cos(theta)**17 - 5.40411705648967e+46*cos(theta)**15 + 8.34459251369728e+45*cos(theta)**13 - 8.71322913076825e+44*cos(theta)**11 + 5.91639015052165e+43*cos(theta)**9 - 2.45097865844395e+42*cos(theta)**7 + 5.57040604191807e+40*cos(theta)**5 - 5.71323696606982e+38*cos(theta)**3 + 1.67707543035318e+36*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl50_m22(theta, phi):
    return 2.82906693875058e-37*(1.0 - cos(theta)**2)**11*(8.93898434596315e+48*cos(theta)**28 - 3.41306675027684e+49*cos(theta)**26 + 5.71776646309264e+49*cos(theta)**24 - 5.53720541688972e+49*cos(theta)**22 + 3.43842594435894e+49*cos(theta)**20 - 1.43582621852351e+49*cos(theta)**18 + 4.11388410925276e+48*cos(theta)**16 - 8.1061755847345e+47*cos(theta)**14 + 1.08479702678065e+47*cos(theta)**12 - 9.58455204384507e+45*cos(theta)**10 + 5.32475113546949e+44*cos(theta)**8 - 1.71568506091077e+43*cos(theta)**6 + 2.78520302095904e+41*cos(theta)**4 - 1.71397108982095e+39*cos(theta)**2 + 1.67707543035318e+36)*cos(22*phi)

#@torch.jit.script
def Yl50_m23(theta, phi):
    return 6.25752765615712e-39*(1.0 - cos(theta)**2)**11.5*(2.50291561686968e+50*cos(theta)**27 - 8.87397355071979e+50*cos(theta)**25 + 1.37226395114223e+51*cos(theta)**23 - 1.21818519171574e+51*cos(theta)**21 + 6.87685188871788e+50*cos(theta)**19 - 2.58448719334232e+50*cos(theta)**17 + 6.58221457480442e+49*cos(theta)**15 - 1.13486458186283e+49*cos(theta)**13 + 1.30175643213678e+48*cos(theta)**11 - 9.58455204384508e+46*cos(theta)**9 + 4.25980090837559e+45*cos(theta)**7 - 1.02941103654646e+44*cos(theta)**5 + 1.11408120838361e+42*cos(theta)**3 - 3.42794217964189e+39*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl50_m24(theta, phi):
    return 1.39992585903302e-40*(1.0 - cos(theta)**2)**12*(6.75787216554814e+51*cos(theta)**26 - 2.21849338767995e+52*cos(theta)**24 + 3.15620708762714e+52*cos(theta)**22 - 2.55818890260305e+52*cos(theta)**20 + 1.3066018588564e+52*cos(theta)**18 - 4.39362822868195e+51*cos(theta)**16 + 9.87332186220663e+50*cos(theta)**14 - 1.47532395642168e+50*cos(theta)**12 + 1.43193207535045e+49*cos(theta)**10 - 8.62609683946057e+47*cos(theta)**8 + 2.98186063586291e+46*cos(theta)**6 - 5.1470551827323e+44*cos(theta)**4 + 3.34224362515084e+42*cos(theta)**2 - 3.42794217964189e+39)*cos(24*phi)

#@torch.jit.script
def Yl50_m25(theta, phi):
    return 3.17020779937648e-42*(1.0 - cos(theta)**2)**12.5*(1.75704676304252e+53*cos(theta)**25 - 5.32438413043187e+53*cos(theta)**23 + 6.94365559277971e+53*cos(theta)**21 - 5.1163778052061e+53*cos(theta)**19 + 2.35188334594151e+53*cos(theta)**17 - 7.02980516589112e+52*cos(theta)**15 + 1.38226506070893e+52*cos(theta)**13 - 1.77038874770602e+51*cos(theta)**11 + 1.43193207535045e+50*cos(theta)**9 - 6.90087747156845e+48*cos(theta)**7 + 1.78911638151775e+47*cos(theta)**5 - 2.05882207309292e+45*cos(theta)**3 + 6.68448725030169e+42*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl50_m26(theta, phi):
    return 7.27295548816133e-44*(1.0 - cos(theta)**2)**13*(4.39261690760629e+54*cos(theta)**24 - 1.22460834999933e+55*cos(theta)**22 + 1.45816767448374e+55*cos(theta)**20 - 9.72111782989159e+54*cos(theta)**18 + 3.99820168810057e+54*cos(theta)**16 - 1.05447077488367e+54*cos(theta)**14 + 1.79694457892161e+53*cos(theta)**12 - 1.94742762247662e+52*cos(theta)**10 + 1.28873886781541e+51*cos(theta)**8 - 4.83061423009792e+49*cos(theta)**6 + 8.94558190758874e+47*cos(theta)**4 - 6.17646621927876e+45*cos(theta)**2 + 6.68448725030169e+42)*cos(26*phi)

#@torch.jit.script
def Yl50_m27(theta, phi):
    return 1.69184256116626e-45*(1.0 - cos(theta)**2)**13.5*(1.05422805782551e+56*cos(theta)**23 - 2.69413836999853e+56*cos(theta)**21 + 2.91633534896748e+56*cos(theta)**19 - 1.74980120938049e+56*cos(theta)**17 + 6.39712270096092e+55*cos(theta)**15 - 1.47625908483713e+55*cos(theta)**13 + 2.15633349470593e+54*cos(theta)**11 - 1.94742762247662e+53*cos(theta)**9 + 1.03099109425233e+52*cos(theta)**7 - 2.89836853805875e+50*cos(theta)**5 + 3.57823276303549e+48*cos(theta)**3 - 1.23529324385575e+46*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl50_m28(theta, phi):
    return 3.9943740060195e-47*(1.0 - cos(theta)**2)**14*(2.42472453299867e+57*cos(theta)**22 - 5.65769057699691e+57*cos(theta)**20 + 5.54103716303821e+57*cos(theta)**18 - 2.97466205594683e+57*cos(theta)**16 + 9.59568405144138e+56*cos(theta)**14 - 1.91913681028828e+56*cos(theta)**12 + 2.37196684417652e+55*cos(theta)**10 - 1.75268486022896e+54*cos(theta)**8 + 7.21693765976629e+52*cos(theta)**6 - 1.44918426902938e+51*cos(theta)**4 + 1.07346982891065e+49*cos(theta)**2 - 1.23529324385575e+46)*cos(28*phi)

#@torch.jit.script
def Yl50_m29(theta, phi):
    return 9.58128681137455e-49*(1.0 - cos(theta)**2)**14.5*(5.33439397259708e+58*cos(theta)**21 - 1.13153811539938e+59*cos(theta)**19 + 9.97386689346877e+58*cos(theta)**17 - 4.75945928951492e+58*cos(theta)**15 + 1.34339576720179e+58*cos(theta)**13 - 2.30296417234593e+57*cos(theta)**11 + 2.37196684417652e+56*cos(theta)**9 - 1.40214788818316e+55*cos(theta)**7 + 4.33016259585977e+53*cos(theta)**5 - 5.7967370761175e+51*cos(theta)**3 + 2.1469396578213e+49*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl50_m30(theta, phi):
    return 2.33759462454031e-50*(1.0 - cos(theta)**2)**15*(1.12022273424539e+60*cos(theta)**20 - 2.14992241925882e+60*cos(theta)**18 + 1.69555737188969e+60*cos(theta)**16 - 7.13918893427238e+59*cos(theta)**14 + 1.74641449736233e+59*cos(theta)**12 - 2.53326058958052e+58*cos(theta)**10 + 2.13477015975887e+57*cos(theta)**8 - 9.81503521728215e+55*cos(theta)**6 + 2.16508129792989e+54*cos(theta)**4 - 1.73902112283525e+52*cos(theta)**2 + 2.1469396578213e+49)*cos(30*phi)

#@torch.jit.script
def Yl50_m31(theta, phi):
    return 5.80780053812248e-52*(1.0 - cos(theta)**2)**15.5*(2.24044546849077e+61*cos(theta)**19 - 3.86986035466588e+61*cos(theta)**17 + 2.71289179502351e+61*cos(theta)**15 - 9.99486450798134e+60*cos(theta)**13 + 2.0956973968348e+60*cos(theta)**11 - 2.53326058958052e+59*cos(theta)**9 + 1.70781612780709e+58*cos(theta)**7 - 5.88902113036929e+56*cos(theta)**5 + 8.66032519171955e+54*cos(theta)**3 - 3.4780422456705e+52*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl50_m32(theta, phi):
    return 1.47139056186104e-53*(1.0 - cos(theta)**2)**16*(4.25684639013247e+62*cos(theta)**18 - 6.578762602932e+62*cos(theta)**16 + 4.06933769253526e+62*cos(theta)**14 - 1.29933238603757e+62*cos(theta)**12 + 2.30526713651828e+61*cos(theta)**10 - 2.27993453062247e+60*cos(theta)**8 + 1.19547128946497e+59*cos(theta)**6 - 2.94451056518465e+57*cos(theta)**4 + 2.59809755751586e+55*cos(theta)**2 - 3.4780422456705e+52)*cos(32*phi)

#@torch.jit.script
def Yl50_m33(theta, phi):
    return 3.80673519369261e-55*(1.0 - cos(theta)**2)**16.5*(7.66232350223845e+63*cos(theta)**17 - 1.05260201646912e+64*cos(theta)**15 + 5.69707276954936e+63*cos(theta)**13 - 1.55919886324509e+63*cos(theta)**11 + 2.30526713651828e+62*cos(theta)**9 - 1.82394762449798e+61*cos(theta)**7 + 7.1728277367898e+59*cos(theta)**5 - 1.17780422607386e+58*cos(theta)**3 + 5.19619511503173e+55*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl50_m34(theta, phi):
    return 1.00736895690158e-56*(1.0 - cos(theta)**2)**17*(1.30259499538054e+65*cos(theta)**16 - 1.57890302470368e+65*cos(theta)**14 + 7.40619460041417e+64*cos(theta)**12 - 1.7151187495696e+64*cos(theta)**10 + 2.07474042286645e+63*cos(theta)**8 - 1.27676333714858e+62*cos(theta)**6 + 3.5864138683949e+60*cos(theta)**4 - 3.53341267822157e+58*cos(theta)**2 + 5.19619511503173e+55)*cos(34*phi)

#@torch.jit.script
def Yl50_m35(theta, phi):
    return 2.73161261266203e-58*(1.0 - cos(theta)**2)**17.5*(2.08415199260886e+66*cos(theta)**15 - 2.21046423458515e+66*cos(theta)**13 + 8.88743352049701e+65*cos(theta)**11 - 1.7151187495696e+65*cos(theta)**9 + 1.65979233829316e+64*cos(theta)**7 - 7.6605800228915e+62*cos(theta)**5 + 1.43456554735796e+61*cos(theta)**3 - 7.06682535644315e+58*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl50_m36(theta, phi):
    return 7.60543841814552e-60*(1.0 - cos(theta)**2)**18*(3.12622798891329e+67*cos(theta)**14 - 2.8736035049607e+67*cos(theta)**12 + 9.77617687254671e+66*cos(theta)**10 - 1.54360687461264e+66*cos(theta)**8 + 1.16185463680521e+65*cos(theta)**6 - 3.83029001144575e+63*cos(theta)**4 + 4.30369664207388e+61*cos(theta)**2 - 7.06682535644315e+58)*cos(36*phi)

#@torch.jit.script
def Yl50_m37(theta, phi):
    return 2.17921766163123e-61*(1.0 - cos(theta)**2)**18.5*(4.3767191844786e+68*cos(theta)**13 - 3.44832420595284e+68*cos(theta)**11 + 9.77617687254671e+67*cos(theta)**9 - 1.23488549969011e+67*cos(theta)**7 + 6.97112782083127e+65*cos(theta)**5 - 1.5321160045783e+64*cos(theta)**3 + 8.60739328414776e+61*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl50_m38(theta, phi):
    return 6.44299208440446e-63*(1.0 - cos(theta)**2)**19*(5.68973493982218e+69*cos(theta)**12 - 3.79315662654812e+69*cos(theta)**10 + 8.79855918529204e+68*cos(theta)**8 - 8.64419849783077e+67*cos(theta)**6 + 3.48556391041563e+66*cos(theta)**4 - 4.5963480137349e+64*cos(theta)**2 + 8.60739328414776e+61)*cos(38*phi)

#@torch.jit.script
def Yl50_m39(theta, phi):
    return 1.97152356054512e-64*(1.0 - cos(theta)**2)**19.5*(6.82768192778662e+70*cos(theta)**11 - 3.79315662654812e+70*cos(theta)**9 + 7.03884734823363e+69*cos(theta)**7 - 5.18651909869846e+68*cos(theta)**5 + 1.39422556416625e+67*cos(theta)**3 - 9.1926960274698e+64*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl50_m40(theta, phi):
    return 6.26591319598679e-66*(1.0 - cos(theta)**2)**20*(7.51045012056528e+71*cos(theta)**10 - 3.41384096389331e+71*cos(theta)**8 + 4.92719314376354e+70*cos(theta)**6 - 2.59325954934923e+69*cos(theta)**4 + 4.18267669249876e+67*cos(theta)**2 - 9.1926960274698e+64)*cos(40*phi)

#@torch.jit.script
def Yl50_m41(theta, phi):
    return 2.07712999851474e-67*(1.0 - cos(theta)**2)**20.5*(7.51045012056528e+72*cos(theta)**9 - 2.73107277111465e+72*cos(theta)**7 + 2.95631588625812e+71*cos(theta)**5 - 1.03730381973969e+70*cos(theta)**3 + 8.36535338499752e+67*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl50_m42(theta, phi):
    return 7.21852574267788e-69*(1.0 - cos(theta)**2)**21*(6.75940510850875e+73*cos(theta)**8 - 1.91175093978025e+73*cos(theta)**6 + 1.47815794312906e+72*cos(theta)**4 - 3.11191145921908e+70*cos(theta)**2 + 8.36535338499752e+67)*cos(42*phi)

#@torch.jit.script
def Yl50_m43(theta, phi):
    return 2.64643993717771e-70*(1.0 - cos(theta)**2)**21.5*(5.407524086807e+74*cos(theta)**7 - 1.14705056386815e+74*cos(theta)**5 + 5.91263177251625e+72*cos(theta)**3 - 6.22382291843816e+70*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl50_m44(theta, phi):
    return 1.0316897006675e-71*(1.0 - cos(theta)**2)**22*(3.7852668607649e+75*cos(theta)**6 - 5.73525281934076e+74*cos(theta)**4 + 1.77378953175487e+73*cos(theta)**2 - 6.22382291843816e+70)*cos(44*phi)

#@torch.jit.script
def Yl50_m45(theta, phi):
    return 4.32127263268872e-73*(1.0 - cos(theta)**2)**22.5*(2.27116011645894e+76*cos(theta)**5 - 2.2941011277363e+75*cos(theta)**3 + 3.54757906350975e+73*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl50_m46(theta, phi):
    return 1.97238208171112e-74*(1.0 - cos(theta)**2)**23*(1.13558005822947e+77*cos(theta)**4 - 6.88230338320891e+75*cos(theta)**2 + 3.54757906350975e+73)*cos(46*phi)

#@torch.jit.script
def Yl50_m47(theta, phi):
    return 1.00132529142183e-75*(1.0 - cos(theta)**2)**23.5*(4.54232023291788e+77*cos(theta)**3 - 1.37646067664178e+76*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl50_m48(theta, phi):
    return 5.83984769173129e-77*(1.0 - cos(theta)**2)**24*(1.36269606987536e+78*cos(theta)**2 - 1.37646067664178e+76)*cos(48*phi)

#@torch.jit.script
def Yl50_m49(theta, phi):
    return 11.3109198355194*(1.0 - cos(theta)**2)**24.5*cos(49*phi)*cos(theta)

#@torch.jit.script
def Yl50_m50(theta, phi):
    return 1.13109198355194*(1.0 - cos(theta)**2)**25*cos(50*phi)

#@torch.jit.script
def Yl51_m_minus_51(theta, phi):
    return 1.1366230286804*(1.0 - cos(theta)**2)**25.5*sin(51*phi)

#@torch.jit.script
def Yl51_m_minus_50(theta, phi):
    return 11.4793298912137*(1.0 - cos(theta)**2)**25*sin(50*phi)*cos(theta)

#@torch.jit.script
def Yl51_m_minus_49(theta, phi):
    return 5.92709446013574e-79*(1.0 - cos(theta)**2)**24.5*(1.37632303057412e+80*cos(theta)**2 - 1.36269606987536e+78)*sin(49*phi)

#@torch.jit.script
def Yl51_m_minus_48(theta, phi):
    return 1.02660287462151e-77*(1.0 - cos(theta)**2)**24*(4.58774343524706e+79*cos(theta)**3 - 1.36269606987536e+78*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl51_m_minus_47(theta, phi):
    return 2.04291392629189e-76*(1.0 - cos(theta)**2)**23.5*(1.14693585881177e+79*cos(theta)**4 - 6.81348034937682e+77*cos(theta)**2 + 3.44115169160446e+75)*sin(47*phi)

#@torch.jit.script
def Yl51_m_minus_46(theta, phi):
    return 4.52218274953181e-75*(1.0 - cos(theta)**2)**23*(2.29387171762353e+78*cos(theta)**5 - 2.27116011645894e+77*cos(theta)**3 + 3.44115169160446e+75*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl51_m_minus_45(theta, phi):
    return 1.09096194385207e-73*(1.0 - cos(theta)**2)**22.5*(3.82311952937255e+77*cos(theta)**6 - 5.67790029114735e+76*cos(theta)**4 + 1.72057584580223e+75*cos(theta)**2 - 5.91263177251625e+72)*sin(45*phi)

#@torch.jit.script
def Yl51_m_minus_44(theta, phi):
    return 2.82809658797451e-72*(1.0 - cos(theta)**2)**22*(5.46159932767507e+76*cos(theta)**7 - 1.13558005822947e+76*cos(theta)**5 + 5.73525281934076e+74*cos(theta)**3 - 5.91263177251625e+72*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl51_m_minus_43(theta, phi):
    return 7.79652424885213e-71*(1.0 - cos(theta)**2)**21.5*(6.82699915959384e+75*cos(theta)**8 - 1.89263343038245e+75*cos(theta)**6 + 1.43381320483519e+74*cos(theta)**4 - 2.95631588625812e+72*cos(theta)**2 + 7.77977864804769e+69)*sin(43*phi)

#@torch.jit.script
def Yl51_m_minus_42(theta, phi):
    return 2.26770321354111e-69*(1.0 - cos(theta)**2)**21*(7.58555462177093e+74*cos(theta)**9 - 2.7037620434035e+74*cos(theta)**7 + 2.86762640967038e+73*cos(theta)**5 - 9.85438628752708e+71*cos(theta)**3 + 7.77977864804769e+69*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl51_m_minus_41(theta, phi):
    return 6.91556535228707e-68*(1.0 - cos(theta)**2)**20.5*(7.58555462177093e+73*cos(theta)**10 - 3.37970255425438e+73*cos(theta)**8 + 4.77937734945063e+72*cos(theta)**6 - 2.46359657188177e+71*cos(theta)**4 + 3.88988932402385e+69*cos(theta)**2 - 8.36535338499752e+66)*sin(41*phi)

#@torch.jit.script
def Yl51_m_minus_40(theta, phi):
    return 2.19997601512958e-66*(1.0 - cos(theta)**2)**20*(6.89595874706449e+72*cos(theta)**11 - 3.75522506028264e+72*cos(theta)**9 + 6.82768192778662e+71*cos(theta)**7 - 4.92719314376354e+70*cos(theta)**5 + 1.29662977467462e+69*cos(theta)**3 - 8.36535338499752e+66*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl51_m_minus_39(theta, phi):
    return 7.26991386339812e-65*(1.0 - cos(theta)**2)**19.5*(5.7466322892204e+71*cos(theta)**12 - 3.75522506028264e+71*cos(theta)**10 + 8.53460240973327e+70*cos(theta)**8 - 8.21198857293923e+69*cos(theta)**6 + 3.24157443668654e+68*cos(theta)**4 - 4.18267669249876e+66*cos(theta)**2 + 7.6605800228915e+63)*sin(39*phi)

#@torch.jit.script
def Yl51_m_minus_38(theta, phi):
    return 2.48669313889022e-63*(1.0 - cos(theta)**2)**19*(4.42048637632339e+70*cos(theta)**13 - 3.41384096389331e+70*cos(theta)**11 + 9.48289156637031e+69*cos(theta)**9 - 1.1731412247056e+69*cos(theta)**7 + 6.48314887337308e+67*cos(theta)**5 - 1.39422556416625e+66*cos(theta)**3 + 7.6605800228915e+63*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl51_m_minus_37(theta, phi):
    return 8.77770977401657e-62*(1.0 - cos(theta)**2)**18.5*(3.15749026880242e+69*cos(theta)**14 - 2.84486746991109e+69*cos(theta)**12 + 9.4828915663703e+68*cos(theta)**10 - 1.46642653088201e+68*cos(theta)**8 + 1.08052481222885e+67*cos(theta)**6 - 3.48556391041563e+65*cos(theta)**4 + 3.83029001144575e+63*cos(theta)**2 - 6.14813806010554e+60)*sin(37*phi)

#@torch.jit.script
def Yl51_m_minus_36(theta, phi):
    return 3.18910033265596e-60*(1.0 - cos(theta)**2)**18*(2.10499351253495e+68*cos(theta)**15 - 2.1883595922393e+68*cos(theta)**13 + 8.6208105148821e+67*cos(theta)**11 - 1.62936281209112e+67*cos(theta)**9 + 1.54360687461264e+66*cos(theta)**7 - 6.97112782083127e+64*cos(theta)**5 + 1.27676333714858e+63*cos(theta)**3 - 6.14813806010554e+60*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl51_m_minus_35(theta, phi):
    return 1.18983790564055e-58*(1.0 - cos(theta)**2)**17.5*(1.31562094533434e+67*cos(theta)**16 - 1.56311399445664e+67*cos(theta)**14 + 7.18400876240175e+66*cos(theta)**12 - 1.62936281209112e+66*cos(theta)**10 + 1.9295085932658e+65*cos(theta)**8 - 1.16185463680521e+64*cos(theta)**6 + 3.19190834287146e+62*cos(theta)**4 - 3.07406903005277e+60*cos(theta)**2 + 4.41676584777697e+57)*sin(35*phi)

#@torch.jit.script
def Yl51_m_minus_34(theta, phi):
    return 4.54947713629167e-57*(1.0 - cos(theta)**2)**17*(7.73894673726083e+65*cos(theta)**17 - 1.04207599630443e+66*cos(theta)**15 + 5.52616058646288e+65*cos(theta)**13 - 1.48123892008283e+65*cos(theta)**11 + 2.143898436962e+64*cos(theta)**9 - 1.65979233829316e+63*cos(theta)**7 + 6.38381668574292e+61*cos(theta)**5 - 1.02468967668426e+60*cos(theta)**3 + 4.41676584777697e+57*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl51_m_minus_33(theta, phi):
    return 1.77953773735963e-55*(1.0 - cos(theta)**2)**16.5*(4.2994148540338e+64*cos(theta)**18 - 6.51297497690268e+64*cos(theta)**16 + 3.9472575617592e+64*cos(theta)**14 - 1.2343657667357e+64*cos(theta)**12 + 2.143898436962e+63*cos(theta)**10 - 2.07474042286645e+62*cos(theta)**8 + 1.06396944762382e+61*cos(theta)**6 - 2.56172419171064e+59*cos(theta)**4 + 2.20838292388848e+57*cos(theta)**2 - 2.88677506390652e+54)*sin(33*phi)

#@torch.jit.script
def Yl51_m_minus_32(theta, phi):
    return 7.10924769273408e-54*(1.0 - cos(theta)**2)**16*(2.26284992317568e+63*cos(theta)**19 - 3.83116175111923e+63*cos(theta)**17 + 2.6315050411728e+63*cos(theta)**15 - 9.49512128258227e+62*cos(theta)**13 + 1.94899857905636e+62*cos(theta)**11 - 2.30526713651828e+61*cos(theta)**9 + 1.51995635374831e+60*cos(theta)**7 - 5.12344838342128e+58*cos(theta)**5 + 7.36127641296161e+56*cos(theta)**3 - 2.88677506390652e+54*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl51_m_minus_31(theta, phi):
    return 2.89652772429387e-52*(1.0 - cos(theta)**2)**15.5*(1.13142496158784e+62*cos(theta)**20 - 2.12842319506624e+62*cos(theta)**18 + 1.644690650733e+62*cos(theta)**16 - 6.78222948755877e+61*cos(theta)**14 + 1.62416548254697e+61*cos(theta)**12 - 2.30526713651828e+60*cos(theta)**10 + 1.89994544218539e+59*cos(theta)**8 - 8.53908063903547e+57*cos(theta)**6 + 1.8403191032404e+56*cos(theta)**4 - 1.44338753195326e+54*cos(theta)**2 + 1.73902112283525e+51)*sin(31*phi)

#@torch.jit.script
def Yl51_m_minus_30(theta, phi):
    return 1.20197175760466e-50*(1.0 - cos(theta)**2)**15*(5.38773791232305e+60*cos(theta)**21 - 1.12022273424539e+61*cos(theta)**19 + 9.67465088666471e+60*cos(theta)**17 - 4.52148632503918e+60*cos(theta)**15 + 1.24935806349767e+60*cos(theta)**13 - 2.0956973968348e+59*cos(theta)**11 + 2.1110504913171e+58*cos(theta)**9 - 1.21986866271935e+57*cos(theta)**7 + 3.68063820648081e+55*cos(theta)**5 - 4.81129177317753e+53*cos(theta)**3 + 1.73902112283525e+51*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl51_m_minus_29(theta, phi):
    return 5.07397254725842e-49*(1.0 - cos(theta)**2)**14.5*(2.44897177832866e+59*cos(theta)**22 - 5.60111367122694e+59*cos(theta)**20 + 5.37480604814706e+59*cos(theta)**18 - 2.82592895314949e+59*cos(theta)**16 + 8.92398616784048e+58*cos(theta)**14 - 1.74641449736233e+58*cos(theta)**12 + 2.1110504913171e+57*cos(theta)**10 - 1.52483582839919e+56*cos(theta)**8 + 6.13439701080135e+54*cos(theta)**6 - 1.20282294329438e+53*cos(theta)**4 + 8.69510561417625e+50*cos(theta)**2 - 9.75881662646044e+47)*sin(29*phi)

#@torch.jit.script
def Yl51_m_minus_28(theta, phi):
    return 2.176491746711e-47*(1.0 - cos(theta)**2)**14*(1.06477033840377e+58*cos(theta)**23 - 2.66719698629854e+58*cos(theta)**21 + 2.82884528849845e+58*cos(theta)**19 - 1.66231114891146e+58*cos(theta)**17 + 5.94932411189365e+57*cos(theta)**15 - 1.34339576720179e+57*cos(theta)**13 + 1.91913681028828e+56*cos(theta)**11 - 1.69426203155466e+55*cos(theta)**9 + 8.76342430114478e+53*cos(theta)**7 - 2.40564588658876e+52*cos(theta)**5 + 2.89836853805875e+50*cos(theta)**3 - 9.75881662646044e+47*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl51_m_minus_27(theta, phi):
    return 9.47711588478168e-46*(1.0 - cos(theta)**2)**13.5*(4.43654307668236e+56*cos(theta)**24 - 1.21236226649934e+57*cos(theta)**22 + 1.41442264424923e+57*cos(theta)**20 - 9.23506193839701e+56*cos(theta)**18 + 3.71832756993353e+56*cos(theta)**16 - 9.59568405144138e+55*cos(theta)**14 + 1.59928067524023e+55*cos(theta)**12 - 1.69426203155466e+54*cos(theta)**10 + 1.0954280376431e+53*cos(theta)**8 - 4.00940981098127e+51*cos(theta)**6 + 7.24592134514688e+49*cos(theta)**4 - 4.87940831323022e+47*cos(theta)**2 + 5.1470551827323e+44)*sin(27*phi)

#@torch.jit.script
def Yl51_m_minus_26(theta, phi):
    return 4.18498105984344e-44*(1.0 - cos(theta)**2)**13*(1.77461723067294e+55*cos(theta)**25 - 5.27114028912755e+55*cos(theta)**23 + 6.73534592499632e+55*cos(theta)**21 - 4.8605589149458e+55*cos(theta)**19 + 2.18725151172561e+55*cos(theta)**17 - 6.39712270096092e+54*cos(theta)**15 + 1.23021590403095e+54*cos(theta)**13 - 1.54023821050423e+53*cos(theta)**11 + 1.21714226404789e+52*cos(theta)**9 - 5.72772830140182e+50*cos(theta)**7 + 1.44918426902938e+49*cos(theta)**5 - 1.62646943774341e+47*cos(theta)**3 + 5.1470551827323e+44*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl51_m_minus_25(theta, phi):
    return 1.87251598325459e-42*(1.0 - cos(theta)**2)**12.5*(6.82545088720363e+53*cos(theta)**26 - 2.19630845380315e+54*cos(theta)**24 + 3.06152087499833e+54*cos(theta)**22 - 2.4302794574729e+54*cos(theta)**20 + 1.21513972873645e+54*cos(theta)**18 - 3.99820168810057e+53*cos(theta)**16 + 8.7872564573639e+52*cos(theta)**14 - 1.28353184208686e+52*cos(theta)**12 + 1.21714226404789e+51*cos(theta)**10 - 7.15966037675227e+49*cos(theta)**8 + 2.41530711504896e+48*cos(theta)**6 - 4.06617359435852e+46*cos(theta)**4 + 2.57352759136615e+44*cos(theta)**2 - 2.57095663473142e+41)*sin(25*phi)

#@torch.jit.script
def Yl51_m_minus_24(theta, phi):
    return 8.48231139058224e-41*(1.0 - cos(theta)**2)**12*(2.52794477303838e+52*cos(theta)**27 - 8.78523381521259e+52*cos(theta)**25 + 1.33109603260797e+53*cos(theta)**23 - 1.15727593212995e+53*cos(theta)**21 + 6.39547225650763e+52*cos(theta)**19 - 2.35188334594151e+52*cos(theta)**17 + 5.85817097157593e+51*cos(theta)**15 - 9.87332186220663e+50*cos(theta)**13 + 1.10649296731626e+50*cos(theta)**11 - 7.95517819639141e+48*cos(theta)**9 + 3.45043873578423e+47*cos(theta)**7 - 8.13234718871703e+45*cos(theta)**5 + 8.57842530455383e+43*cos(theta)**3 - 2.57095663473142e+41*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl51_m_minus_23(theta, phi):
    return 3.88708340155292e-39*(1.0 - cos(theta)**2)**11.5*(9.02837418942278e+50*cos(theta)**28 - 3.37893608277407e+51*cos(theta)**26 + 5.54623346919987e+51*cos(theta)**24 - 5.26034514604523e+51*cos(theta)**22 + 3.19773612825381e+51*cos(theta)**20 - 1.3066018588564e+51*cos(theta)**18 + 3.66135685723496e+50*cos(theta)**16 - 7.05237275871902e+49*cos(theta)**14 + 9.2207747276355e+48*cos(theta)**12 - 7.95517819639141e+47*cos(theta)**10 + 4.31304841973028e+46*cos(theta)**8 - 1.35539119811951e+45*cos(theta)**6 + 2.14460632613846e+43*cos(theta)**4 - 1.28547831736571e+41*cos(theta)**2 + 1.22426506415782e+38)*sin(23*phi)

#@torch.jit.script
def Yl51_m_minus_22(theta, phi):
    return 1.80068902582784e-37*(1.0 - cos(theta)**2)**11*(3.1132324791113e+49*cos(theta)**29 - 1.25145780843484e+50*cos(theta)**27 + 2.21849338767995e+50*cos(theta)**25 - 2.28710658523706e+50*cos(theta)**23 + 1.52273148964467e+50*cos(theta)**21 - 6.87685188871788e+49*cos(theta)**19 + 2.15373932778527e+49*cos(theta)**17 - 4.70158183914601e+48*cos(theta)**15 + 7.09290363664269e+47*cos(theta)**13 - 7.23198017853765e+46*cos(theta)**11 + 4.79227602192254e+45*cos(theta)**9 - 1.93627314017072e+44*cos(theta)**7 + 4.28921265227692e+42*cos(theta)**5 - 4.28492772455236e+40*cos(theta)**3 + 1.22426506415782e+38*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl51_m_minus_21(theta, phi):
    return 8.42676291309043e-36*(1.0 - cos(theta)**2)**10.5*(1.03774415970377e+48*cos(theta)**30 - 4.46949217298158e+48*cos(theta)**28 + 8.5326668756921e+48*cos(theta)**26 - 9.52961077182108e+48*cos(theta)**24 + 6.92150677111215e+48*cos(theta)**22 - 3.43842594435894e+48*cos(theta)**20 + 1.19652184876959e+48*cos(theta)**18 - 2.93848864946626e+47*cos(theta)**16 + 5.06635974045907e+46*cos(theta)**14 - 6.02665014878137e+45*cos(theta)**12 + 4.79227602192254e+44*cos(theta)**10 - 2.4203414252134e+43*cos(theta)**8 + 7.14868775379486e+41*cos(theta)**6 - 1.07123193113809e+40*cos(theta)**4 + 6.12132532078909e+37*cos(theta)**2 - 5.59025143451059e+34)*sin(21*phi)

#@torch.jit.script
def Yl51_m_minus_20(theta, phi):
    return 3.98114385180629e-34*(1.0 - cos(theta)**2)**10*(3.34756180549603e+46*cos(theta)**31 - 1.54120419757985e+47*cos(theta)**29 + 3.16024699099707e+47*cos(theta)**27 - 3.81184430872843e+47*cos(theta)**25 + 3.00935077004876e+47*cos(theta)**23 - 1.63734568778997e+47*cos(theta)**21 + 6.29748341457681e+46*cos(theta)**19 - 1.72852273498015e+46*cos(theta)**17 + 3.37757316030604e+45*cos(theta)**15 - 4.63588472983183e+44*cos(theta)**13 + 4.35661456538412e+43*cos(theta)**11 - 2.68926825023711e+42*cos(theta)**9 + 1.02124110768498e+41*cos(theta)**7 - 2.14246386227618e+39*cos(theta)**5 + 2.04044177359636e+37*cos(theta)**3 - 5.59025143451059e+34*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl51_m_minus_19(theta, phi):
    return 1.89763216851572e-32*(1.0 - cos(theta)**2)**9.5*(1.04611306421751e+45*cos(theta)**32 - 5.13734732526618e+45*cos(theta)**30 + 1.12865963964181e+46*cos(theta)**28 - 1.46609396489555e+46*cos(theta)**26 + 1.25389615418698e+46*cos(theta)**24 - 7.44248039904532e+45*cos(theta)**22 + 3.14874170728841e+45*cos(theta)**20 - 9.60290408322307e+44*cos(theta)**18 + 2.11098322519128e+44*cos(theta)**16 - 3.31134623559416e+43*cos(theta)**14 + 3.6305121378201e+42*cos(theta)**12 - 2.68926825023711e+41*cos(theta)**10 + 1.27655138460622e+40*cos(theta)**8 - 3.57077310379364e+38*cos(theta)**6 + 5.10110443399091e+36*cos(theta)**4 - 2.79512571725529e+34*cos(theta)**2 + 2.46049799054163e+31)*sin(19*phi)

#@torch.jit.script
def Yl51_m_minus_18(theta, phi):
    return 9.12048689848131e-31*(1.0 - cos(theta)**2)**9*(3.1700395885379e+43*cos(theta)**33 - 1.65720881460199e+44*cos(theta)**31 + 3.89192979186832e+44*cos(theta)**29 - 5.4299776477613e+44*cos(theta)**27 + 5.01558461674793e+44*cos(theta)**25 - 3.23586104306318e+44*cos(theta)**23 + 1.49940081299448e+44*cos(theta)**21 - 5.05416004380161e+43*cos(theta)**19 + 1.24175483834781e+43*cos(theta)**17 - 2.20756415706277e+42*cos(theta)**15 + 2.792701644477e+41*cos(theta)**13 - 2.44478931839738e+40*cos(theta)**11 + 1.41839042734025e+39*cos(theta)**9 - 5.10110443399091e+37*cos(theta)**7 + 1.02022088679818e+36*cos(theta)**5 - 9.31708572418431e+33*cos(theta)**3 + 2.46049799054163e+31*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl51_m_minus_17(theta, phi):
    return 4.41755563460786e-29*(1.0 - cos(theta)**2)**8.5*(9.3236458486409e+41*cos(theta)**34 - 5.17877754563123e+42*cos(theta)**32 + 1.29730993062277e+43*cos(theta)**30 - 1.93927773134332e+43*cos(theta)**28 + 1.92907100644151e+43*cos(theta)**26 - 1.34827543460966e+43*cos(theta)**24 + 6.81545824088399e+42*cos(theta)**22 - 2.52708002190081e+42*cos(theta)**20 + 6.89863799082117e+41*cos(theta)**18 - 1.37972759816423e+41*cos(theta)**16 + 1.99478688891214e+40*cos(theta)**14 - 2.03732443199781e+39*cos(theta)**12 + 1.41839042734025e+38*cos(theta)**10 - 6.37638054248864e+36*cos(theta)**8 + 1.70036814466364e+35*cos(theta)**6 - 2.32927143104608e+33*cos(theta)**4 + 1.23024899527082e+31*cos(theta)**2 - 1.04880562256677e+28)*sin(17*phi)

#@torch.jit.script
def Yl51_m_minus_16(theta, phi):
    return 2.15511528062785e-27*(1.0 - cos(theta)**2)**8*(2.6638988138974e+40*cos(theta)**35 - 1.56932652897916e+41*cos(theta)**33 + 4.18487074394443e+41*cos(theta)**31 - 6.68716459083903e+41*cos(theta)**29 + 7.14470743126486e+41*cos(theta)**27 - 5.39310173843864e+41*cos(theta)**25 + 2.96324271342782e+41*cos(theta)**23 - 1.20337143900038e+41*cos(theta)**21 + 3.63086210043219e+40*cos(theta)**19 - 8.11604469508373e+39*cos(theta)**17 + 1.32985792594143e+39*cos(theta)**15 - 1.56717263999832e+38*cos(theta)**13 + 1.28944584303659e+37*cos(theta)**11 - 7.08486726943182e+35*cos(theta)**9 + 2.42909734951948e+34*cos(theta)**7 - 4.65854286209215e+32*cos(theta)**5 + 4.10082998423605e+30*cos(theta)**3 - 1.04880562256677e+28*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl51_m_minus_15(theta, phi):
    return 1.05842273015951e-25*(1.0 - cos(theta)**2)**7.5*(7.39971892749277e+38*cos(theta)**36 - 4.61566626170341e+39*cos(theta)**34 + 1.30777210748263e+40*cos(theta)**32 - 2.22905486361301e+40*cos(theta)**30 + 2.55168122545174e+40*cos(theta)**28 - 2.07426989939948e+40*cos(theta)**26 + 1.23468446392826e+40*cos(theta)**24 - 5.46987017727447e+39*cos(theta)**22 + 1.8154310502161e+39*cos(theta)**20 - 4.50891371949096e+38*cos(theta)**18 + 8.31161203713394e+37*cos(theta)**16 - 1.11940902857023e+37*cos(theta)**14 + 1.07453820253049e+36*cos(theta)**12 - 7.08486726943182e+34*cos(theta)**10 + 3.03637168689935e+33*cos(theta)**8 - 7.76423810348692e+31*cos(theta)**6 + 1.02520749605901e+30*cos(theta)**4 - 5.24402811283383e+27*cos(theta)**2 + 4.34828201727515e+24)*sin(15*phi)

#@torch.jit.script
def Yl51_m_minus_14(theta, phi):
    return 5.23036488794434e-24*(1.0 - cos(theta)**2)**7*(1.99992403445751e+37*cos(theta)**37 - 1.31876178905812e+38*cos(theta)**35 + 3.96294578025041e+38*cos(theta)**33 - 7.19049956004197e+38*cos(theta)**31 + 8.79890077741978e+38*cos(theta)**29 - 7.68248110888695e+38*cos(theta)**27 + 4.93873785571304e+38*cos(theta)**25 - 2.37820442490195e+38*cos(theta)**23 + 8.64490976293379e+37*cos(theta)**21 - 2.37311248394261e+37*cos(theta)**19 + 4.88918355125526e+36*cos(theta)**17 - 7.46272685713485e+35*cos(theta)**15 + 8.26567848100379e+34*cos(theta)**13 - 6.4407884267562e+33*cos(theta)**11 + 3.37374631877706e+32*cos(theta)**9 - 1.1091768719267e+31*cos(theta)**7 + 2.05041499211803e+29*cos(theta)**5 - 1.74800937094461e+27*cos(theta)**3 + 4.34828201727515e+24*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl51_m_minus_13(theta, phi):
    return 2.59944399144839e-22*(1.0 - cos(theta)**2)**6.5*(5.26295798541449e+35*cos(theta)**38 - 3.66322719182811e+36*cos(theta)**36 + 1.16557228830894e+37*cos(theta)**34 - 2.24703111251312e+37*cos(theta)**32 + 2.93296692580659e+37*cos(theta)**30 - 2.74374325317391e+37*cos(theta)**28 + 1.89951455988963e+37*cos(theta)**26 - 9.9091851037581e+36*cos(theta)**24 + 3.92950443769718e+36*cos(theta)**22 - 1.18655624197131e+36*cos(theta)**20 + 2.7162130840307e+35*cos(theta)**18 - 4.66420428570928e+34*cos(theta)**16 + 5.90405605785985e+33*cos(theta)**14 - 5.3673236889635e+32*cos(theta)**12 + 3.37374631877706e+31*cos(theta)**10 - 1.38647108990838e+30*cos(theta)**8 + 3.41735832019671e+28*cos(theta)**6 - 4.37002342736152e+26*cos(theta)**4 + 2.17414100863757e+24*cos(theta)**2 - 1.76043806367415e+21)*sin(13*phi)

#@torch.jit.script
def Yl51_m_minus_12(theta, phi):
    return 1.29868180188352e-20*(1.0 - cos(theta)**2)**6*(1.34947640651654e+34*cos(theta)**39 - 9.90061403196785e+34*cos(theta)**37 + 3.33020653802555e+35*cos(theta)**35 - 6.80918518943369e+35*cos(theta)**33 + 9.46118363163418e+35*cos(theta)**31 - 9.46118363163418e+35*cos(theta)**29 + 7.03523911070233e+35*cos(theta)**27 - 3.96367404150324e+35*cos(theta)**25 + 1.70848019030312e+35*cos(theta)**23 - 5.65026781891098e+34*cos(theta)**21 + 1.42958583370037e+34*cos(theta)**19 - 2.74364957982899e+33*cos(theta)**17 + 3.93603737190657e+32*cos(theta)**15 - 4.12871052997192e+31*cos(theta)**13 + 3.06704210797914e+30*cos(theta)**11 - 1.54052343323153e+29*cos(theta)**9 + 4.88194045742387e+27*cos(theta)**7 - 8.74004685472304e+25*cos(theta)**5 + 7.24713669545858e+23*cos(theta)**3 - 1.76043806367415e+21*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl51_m_minus_11(theta, phi):
    return 6.5193309049391e-19*(1.0 - cos(theta)**2)**5.5*(3.37369101629134e+32*cos(theta)**40 - 2.6054247452547e+33*cos(theta)**38 + 9.25057371673764e+33*cos(theta)**36 - 2.00270152630403e+34*cos(theta)**34 + 2.95661988488568e+34*cos(theta)**32 - 3.15372787721139e+34*cos(theta)**30 + 2.51258539667941e+34*cos(theta)**28 - 1.52449001596279e+34*cos(theta)**26 + 7.11866745959634e+33*cos(theta)**24 - 2.56830355405044e+33*cos(theta)**22 + 7.14792916850184e+32*cos(theta)**20 - 1.52424976657166e+32*cos(theta)**18 + 2.4600233574416e+31*cos(theta)**16 - 2.94907894997994e+30*cos(theta)**14 + 2.55586842331595e+29*cos(theta)**12 - 1.54052343323153e+28*cos(theta)**10 + 6.10242557177984e+26*cos(theta)**8 - 1.45667447578717e+25*cos(theta)**6 + 1.81178417386464e+23*cos(theta)**4 - 8.80219031837074e+20*cos(theta)**2 + 6.98586533204027e+17)*sin(11*phi)

#@torch.jit.script
def Yl51_m_minus_10(theta, phi):
    return 3.28693259725622e-17*(1.0 - cos(theta)**2)**5*(8.22851467388132e+30*cos(theta)**41 - 6.68057626988384e+31*cos(theta)**39 + 2.50015505857774e+32*cos(theta)**37 - 5.72200436086864e+32*cos(theta)**35 + 8.95945419662327e+32*cos(theta)**33 - 1.017331573294e+33*cos(theta)**31 + 8.66408757475657e+32*cos(theta)**29 - 5.64625931838069e+32*cos(theta)**27 + 2.84746698383854e+32*cos(theta)**25 - 1.11665371915237e+32*cos(theta)**23 + 3.40377579452468e+31*cos(theta)**21 - 8.02236719248242e+30*cos(theta)**19 + 1.44707256320094e+30*cos(theta)**17 - 1.96605263331996e+29*cos(theta)**15 + 1.96605263331996e+28*cos(theta)**13 - 1.4004758483923e+27*cos(theta)**11 + 6.78047285753315e+25*cos(theta)**9 - 2.08096353683882e+24*cos(theta)**7 + 3.62356834772929e+22*cos(theta)**5 - 2.93406343945691e+20*cos(theta)**3 + 6.98586533204027e+17*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl51_m_minus_9(theta, phi):
    return 1.66372047390768e-15*(1.0 - cos(theta)**2)**4.5*(1.95917016044793e+29*cos(theta)**42 - 1.67014406747096e+30*cos(theta)**40 + 6.57935541730984e+30*cos(theta)**38 - 1.58944565579685e+31*cos(theta)**36 + 2.63513358724214e+31*cos(theta)**34 - 3.17916116654374e+31*cos(theta)**32 + 2.88802919158552e+31*cos(theta)**30 - 2.01652118513596e+31*cos(theta)**28 + 1.09517960916867e+31*cos(theta)**26 - 4.65272382980153e+30*cos(theta)**24 + 1.54717081569304e+30*cos(theta)**22 - 4.01118359624121e+29*cos(theta)**20 + 8.03929201778302e+28*cos(theta)**18 - 1.22878289582498e+28*cos(theta)**16 + 1.40432330951426e+27*cos(theta)**14 - 1.16706320699359e+26*cos(theta)**12 + 6.78047285753315e+24*cos(theta)**10 - 2.60120442104852e+23*cos(theta)**8 + 6.03928057954881e+21*cos(theta)**6 - 7.33515859864228e+19*cos(theta)**4 + 3.49293266602014e+17*cos(theta)**2 - 272672339267770.0)*sin(9*phi)

#@torch.jit.script
def Yl51_m_minus_8(theta, phi):
    return 8.45065192956907e-14*(1.0 - cos(theta)**2)**4*(4.55620967546031e+27*cos(theta)**43 - 4.07352211578283e+28*cos(theta)**41 + 1.68701420956663e+29*cos(theta)**39 - 4.2957990697212e+29*cos(theta)**37 + 7.52895310640611e+29*cos(theta)**35 - 9.63382171679922e+29*cos(theta)**33 + 9.31622319866298e+29*cos(theta)**31 - 6.95352132805503e+29*cos(theta)**29 + 4.05622077469877e+29*cos(theta)**27 - 1.86108953192061e+29*cos(theta)**25 + 6.72682963344799e+28*cos(theta)**23 - 1.91008742678153e+28*cos(theta)**21 + 4.23120632514896e+27*cos(theta)**19 - 7.22813468132339e+26*cos(theta)**17 + 9.36215539676173e+25*cos(theta)**15 - 8.97740928456604e+24*cos(theta)**13 + 6.16406623412105e+23*cos(theta)**11 - 2.89022713449836e+22*cos(theta)**9 + 8.62754368506973e+20*cos(theta)**7 - 1.46703171972846e+19*cos(theta)**5 + 1.16431088867338e+17*cos(theta)**3 - 272672339267770.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl51_m_minus_7(theta, phi):
    return 4.30568801491884e-12*(1.0 - cos(theta)**2)**3.5*(1.03550219896825e+26*cos(theta)**44 - 9.69886218043531e+26*cos(theta)**42 + 4.21753552391657e+27*cos(theta)**40 - 1.13047343940032e+28*cos(theta)**38 + 2.09137586289059e+28*cos(theta)**36 - 2.83347697552918e+28*cos(theta)**34 + 2.91131974958218e+28*cos(theta)**32 - 2.31784044268501e+28*cos(theta)**30 + 1.44865027667813e+28*cos(theta)**28 - 7.15803666123312e+27*cos(theta)**26 + 2.80284568060333e+27*cos(theta)**24 - 8.68221557627968e+26*cos(theta)**22 + 2.11560316257448e+26*cos(theta)**20 - 4.015630378513e+25*cos(theta)**18 + 5.85134712297608e+24*cos(theta)**16 - 6.41243520326146e+23*cos(theta)**14 + 5.13672186176754e+22*cos(theta)**12 - 2.89022713449836e+21*cos(theta)**10 + 1.07844296063372e+20*cos(theta)**8 - 2.44505286621409e+18*cos(theta)**6 + 2.91077722168345e+16*cos(theta)**4 - 136336169633885.0*cos(theta)**2 + 105035569825.797)*sin(7*phi)

#@torch.jit.script
def Yl51_m_minus_6(theta, phi):
    return 2.19969674331575e-10*(1.0 - cos(theta)**2)**3*(2.30111599770723e+24*cos(theta)**45 - 2.25554934428728e+25*cos(theta)**43 + 1.02866720095526e+26*cos(theta)**41 - 2.8986498446162e+26*cos(theta)**39 + 5.65236719700158e+26*cos(theta)**37 - 8.09564850151195e+26*cos(theta)**35 + 8.82218105933994e+26*cos(theta)**33 - 7.47690465382262e+26*cos(theta)**31 + 4.99534578164873e+26*cos(theta)**29 - 2.6511246893456e+26*cos(theta)**27 + 1.12113827224133e+26*cos(theta)**25 - 3.7748763375129e+25*cos(theta)**23 + 1.00743007741642e+25*cos(theta)**21 - 2.11348967290158e+24*cos(theta)**19 + 3.44196889586828e+23*cos(theta)**17 - 4.2749568021743e+22*cos(theta)**15 + 3.95132450905195e+21*cos(theta)**13 - 2.62747921318033e+20*cos(theta)**11 + 1.19826995625969e+19*cos(theta)**9 - 3.49293266602014e+17*cos(theta)**7 + 5.82155444336689e+15*cos(theta)**5 - 45445389877961.7*cos(theta)**3 + 105035569825.797*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl51_m_minus_5(theta, phi):
    return 1.12636502206951e-8*(1.0 - cos(theta)**2)**2.5*(5.00242608197223e+22*cos(theta)**46 - 5.12624850974382e+23*cos(theta)**44 + 2.44920762132205e+24*cos(theta)**42 - 7.24662461154049e+24*cos(theta)**40 + 1.48746505184252e+25*cos(theta)**38 - 2.24879125041999e+25*cos(theta)**36 + 2.59475913509998e+25*cos(theta)**34 - 2.33653270431957e+25*cos(theta)**32 + 1.66511526054958e+25*cos(theta)**30 - 9.46830246194857e+24*cos(theta)**28 + 4.31207027785128e+24*cos(theta)**26 - 1.57286514063038e+24*cos(theta)**24 + 4.57922762462008e+23*cos(theta)**22 - 1.05674483645079e+23*cos(theta)**20 + 1.91220494214905e+22*cos(theta)**18 - 2.67184800135894e+21*cos(theta)**16 + 2.82237464932282e+20*cos(theta)**14 - 2.18956601098361e+19*cos(theta)**12 + 1.19826995625969e+18*cos(theta)**10 - 4.36616583252517e+16*cos(theta)**8 + 970259073894482.0*cos(theta)**6 - 11361347469490.4*cos(theta)**4 + 52517784912.8987*cos(theta)**2 - 40059332.504118)*sin(5*phi)

#@torch.jit.script
def Yl51_m_minus_4(theta, phi):
    return 5.77859287790928e-7*(1.0 - cos(theta)**2)**2*(1.06434597488771e+21*cos(theta)**47 - 1.13916633549863e+22*cos(theta)**45 + 5.69583167749313e+22*cos(theta)**43 - 1.7674694174489e+23*cos(theta)**41 + 3.81401295344236e+23*cos(theta)**39 - 6.07781419032428e+23*cos(theta)**37 + 7.41359752885709e+23*cos(theta)**35 - 7.08040213430172e+23*cos(theta)**33 + 5.37133955015992e+23*cos(theta)**31 - 3.26493188343054e+23*cos(theta)**29 + 1.59706306587084e+23*cos(theta)**27 - 6.29146056252151e+22*cos(theta)**25 + 1.99096853244351e+22*cos(theta)**23 - 5.03211826881328e+21*cos(theta)**21 + 1.00642365376266e+21*cos(theta)**19 - 1.57167529491702e+20*cos(theta)**17 + 1.88158309954855e+19*cos(theta)**15 - 1.68428154691047e+18*cos(theta)**13 + 1.08933632387244e+17*cos(theta)**11 - 4.85129536947241e+15*cos(theta)**9 + 138608439127783.0*cos(theta)**7 - 2272269493898.08*cos(theta)**5 + 17505928304.2996*cos(theta)**3 - 40059332.504118*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl51_m_minus_3(theta, phi):
    return 2.9690947797665e-5*(1.0 - cos(theta)**2)**1.5*(2.21738744768273e+19*cos(theta)**48 - 2.4764485554318e+20*cos(theta)**46 + 1.29450719943026e+21*cos(theta)**44 - 4.20826051773548e+21*cos(theta)**42 + 9.53503238360591e+21*cos(theta)**40 - 1.59942478692744e+22*cos(theta)**38 + 2.05933264690475e+22*cos(theta)**36 - 2.08247121597109e+22*cos(theta)**34 + 1.67854360942498e+22*cos(theta)**32 - 1.08831062781018e+22*cos(theta)**30 + 5.70379666382444e+21*cos(theta)**28 - 2.41979252404673e+21*cos(theta)**26 + 8.29570221851464e+20*cos(theta)**24 - 2.28732648582422e+20*cos(theta)**22 + 5.03211826881328e+19*cos(theta)**20 - 8.73152941620569e+18*cos(theta)**18 + 1.17598943721784e+18*cos(theta)**16 - 1.20305824779319e+17*cos(theta)**14 + 9.07780269893701e+15*cos(theta)**12 - 485129536947241.0*cos(theta)**10 + 17326054890972.9*cos(theta)**8 - 378711582316.347*cos(theta)**6 + 4376482076.07489*cos(theta)**4 - 20029666.252059*cos(theta)**2 + 15173.9895848932)*sin(3*phi)

#@torch.jit.script
def Yl51_m_minus_2(theta, phi):
    return 0.00152728111376172*(1.0 - cos(theta)**2)*(4.52528050547495e+17*cos(theta)**49 - 5.26903947964212e+18*cos(theta)**47 + 2.87668266540057e+19*cos(theta)**45 - 9.78665236682669e+19*cos(theta)**43 + 2.32561765453803e+20*cos(theta)**41 - 4.10108919724985e+20*cos(theta)**39 + 5.56576391055337e+20*cos(theta)**37 - 5.94991775991741e+20*cos(theta)**35 + 5.08649578613629e+20*cos(theta)**33 - 3.51067944454897e+20*cos(theta)**31 + 1.96682643580153e+20*cos(theta)**29 - 8.96219453350642e+19*cos(theta)**27 + 3.31828088740586e+19*cos(theta)**25 - 9.94489776445312e+18*cos(theta)**23 + 2.39624679467299e+18*cos(theta)**21 - 4.59554179800299e+17*cos(theta)**19 + 6.91758492481084e+16*cos(theta)**17 - 8.02038831862127e+15*cos(theta)**15 + 698292515302847.0*cos(theta)**13 - 44102685177021.9*cos(theta)**11 + 1925117210108.1*cos(theta)**9 - 54101654616.621*cos(theta)**7 + 875296415.214978*cos(theta)**5 - 6676555.417353*cos(theta)**3 + 15173.9895848932*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl51_m_minus_1(theta, phi):
    return 0.0786216073430267*(1.0 - cos(theta)**2)**0.5*(9.05056101094991e+15*cos(theta)**50 - 1.09771655825878e+17*cos(theta)**48 + 6.25365796826212e+17*cos(theta)**46 - 2.22423917427879e+18*cos(theta)**44 + 5.53718489175721e+18*cos(theta)**42 - 1.02527229931246e+19*cos(theta)**40 + 1.46467471330352e+19*cos(theta)**38 - 1.65275493331039e+19*cos(theta)**36 + 1.49602817239303e+19*cos(theta)**34 - 1.09708732642155e+19*cos(theta)**32 + 6.55608811933844e+18*cos(theta)**30 - 3.20078376196658e+18*cos(theta)**28 + 1.27626187977148e+18*cos(theta)**26 - 4.14370740185547e+17*cos(theta)**24 + 1.08920308848772e+17*cos(theta)**22 - 2.2977708990015e+16*cos(theta)**20 + 3.84310273600602e+15*cos(theta)**18 - 501274269913829.0*cos(theta)**16 + 49878036807346.2*cos(theta)**14 - 3675223764751.83*cos(theta)**12 + 192511721010.81*cos(theta)**10 - 6762706827.07763*cos(theta)**8 + 145882735.869163*cos(theta)**6 - 1669138.85433825*cos(theta)**4 + 7586.99479244659*cos(theta)**2 - 5.72603380562007)*sin(phi)

#@torch.jit.script
def Yl51_m0(theta, phi):
    return 1.59613226708313e+15*cos(theta)**51 - 2.01491944607028e+16*cos(theta)**49 + 1.19674003463568e+17*cos(theta)**47 - 4.44562191560541e+17*cos(theta)**45 + 1.15820149906562e+18*cos(theta)**43 - 2.24915258850807e+18*cos(theta)**41 + 3.37784820984729e+18*cos(theta)**39 - 4.01763326403987e+18*cos(theta)**37 + 3.84445941645195e+18*cos(theta)**35 - 2.99013510168485e+18*cos(theta)**33 + 1.90215823336096e+18*cos(theta)**31 - 9.92708842326429e+17*cos(theta)**29 + 4.25147457789589e+17*cos(theta)**27 - 1.49077680004141e+17*cos(theta)**25 + 4.25936228583261e+16*cos(theta)**23 - 9.84126628598768e+15*cos(theta)**21 + 1.81924816906462e+15*cos(theta)**19 - 265210091142413.0*cos(theta)**17 + 29907605634633.7*cos(theta)**15 - 2542751896061.97*cos(theta)**13 + 157408450708.598*cos(theta)**11 - 6758364394.20211*cos(theta)**9 + 187443080.270629*cos(theta)**7 - 3002520.73660046*cos(theta)**5 + 22746.3692166701*cos(theta)**3 - 51.5012133207626*cos(theta)

#@torch.jit.script
def Yl51_m1(theta, phi):
    return 0.0786216073430267*(1.0 - cos(theta)**2)**0.5*(9.05056101094991e+15*cos(theta)**50 - 1.09771655825878e+17*cos(theta)**48 + 6.25365796826212e+17*cos(theta)**46 - 2.22423917427879e+18*cos(theta)**44 + 5.53718489175721e+18*cos(theta)**42 - 1.02527229931246e+19*cos(theta)**40 + 1.46467471330352e+19*cos(theta)**38 - 1.65275493331039e+19*cos(theta)**36 + 1.49602817239303e+19*cos(theta)**34 - 1.09708732642155e+19*cos(theta)**32 + 6.55608811933844e+18*cos(theta)**30 - 3.20078376196658e+18*cos(theta)**28 + 1.27626187977148e+18*cos(theta)**26 - 4.14370740185547e+17*cos(theta)**24 + 1.08920308848772e+17*cos(theta)**22 - 2.2977708990015e+16*cos(theta)**20 + 3.84310273600602e+15*cos(theta)**18 - 501274269913829.0*cos(theta)**16 + 49878036807346.2*cos(theta)**14 - 3675223764751.83*cos(theta)**12 + 192511721010.81*cos(theta)**10 - 6762706827.07763*cos(theta)**8 + 145882735.869163*cos(theta)**6 - 1669138.85433825*cos(theta)**4 + 7586.99479244659*cos(theta)**2 - 5.72603380562007)*cos(phi)

#@torch.jit.script
def Yl51_m2(theta, phi):
    return 0.00152728111376172*(1.0 - cos(theta)**2)*(4.52528050547495e+17*cos(theta)**49 - 5.26903947964212e+18*cos(theta)**47 + 2.87668266540057e+19*cos(theta)**45 - 9.78665236682669e+19*cos(theta)**43 + 2.32561765453803e+20*cos(theta)**41 - 4.10108919724985e+20*cos(theta)**39 + 5.56576391055337e+20*cos(theta)**37 - 5.94991775991741e+20*cos(theta)**35 + 5.08649578613629e+20*cos(theta)**33 - 3.51067944454897e+20*cos(theta)**31 + 1.96682643580153e+20*cos(theta)**29 - 8.96219453350642e+19*cos(theta)**27 + 3.31828088740586e+19*cos(theta)**25 - 9.94489776445312e+18*cos(theta)**23 + 2.39624679467299e+18*cos(theta)**21 - 4.59554179800299e+17*cos(theta)**19 + 6.91758492481084e+16*cos(theta)**17 - 8.02038831862127e+15*cos(theta)**15 + 698292515302847.0*cos(theta)**13 - 44102685177021.9*cos(theta)**11 + 1925117210108.1*cos(theta)**9 - 54101654616.621*cos(theta)**7 + 875296415.214978*cos(theta)**5 - 6676555.417353*cos(theta)**3 + 15173.9895848932*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl51_m3(theta, phi):
    return 2.9690947797665e-5*(1.0 - cos(theta)**2)**1.5*(2.21738744768273e+19*cos(theta)**48 - 2.4764485554318e+20*cos(theta)**46 + 1.29450719943026e+21*cos(theta)**44 - 4.20826051773548e+21*cos(theta)**42 + 9.53503238360591e+21*cos(theta)**40 - 1.59942478692744e+22*cos(theta)**38 + 2.05933264690475e+22*cos(theta)**36 - 2.08247121597109e+22*cos(theta)**34 + 1.67854360942498e+22*cos(theta)**32 - 1.08831062781018e+22*cos(theta)**30 + 5.70379666382444e+21*cos(theta)**28 - 2.41979252404673e+21*cos(theta)**26 + 8.29570221851464e+20*cos(theta)**24 - 2.28732648582422e+20*cos(theta)**22 + 5.03211826881328e+19*cos(theta)**20 - 8.73152941620569e+18*cos(theta)**18 + 1.17598943721784e+18*cos(theta)**16 - 1.20305824779319e+17*cos(theta)**14 + 9.07780269893701e+15*cos(theta)**12 - 485129536947241.0*cos(theta)**10 + 17326054890972.9*cos(theta)**8 - 378711582316.347*cos(theta)**6 + 4376482076.07489*cos(theta)**4 - 20029666.252059*cos(theta)**2 + 15173.9895848932)*cos(3*phi)

#@torch.jit.script
def Yl51_m4(theta, phi):
    return 5.77859287790928e-7*(1.0 - cos(theta)**2)**2*(1.06434597488771e+21*cos(theta)**47 - 1.13916633549863e+22*cos(theta)**45 + 5.69583167749313e+22*cos(theta)**43 - 1.7674694174489e+23*cos(theta)**41 + 3.81401295344236e+23*cos(theta)**39 - 6.07781419032428e+23*cos(theta)**37 + 7.41359752885709e+23*cos(theta)**35 - 7.08040213430172e+23*cos(theta)**33 + 5.37133955015992e+23*cos(theta)**31 - 3.26493188343054e+23*cos(theta)**29 + 1.59706306587084e+23*cos(theta)**27 - 6.29146056252151e+22*cos(theta)**25 + 1.99096853244351e+22*cos(theta)**23 - 5.03211826881328e+21*cos(theta)**21 + 1.00642365376266e+21*cos(theta)**19 - 1.57167529491702e+20*cos(theta)**17 + 1.88158309954855e+19*cos(theta)**15 - 1.68428154691047e+18*cos(theta)**13 + 1.08933632387244e+17*cos(theta)**11 - 4.85129536947241e+15*cos(theta)**9 + 138608439127783.0*cos(theta)**7 - 2272269493898.08*cos(theta)**5 + 17505928304.2996*cos(theta)**3 - 40059332.504118*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl51_m5(theta, phi):
    return 1.12636502206951e-8*(1.0 - cos(theta)**2)**2.5*(5.00242608197223e+22*cos(theta)**46 - 5.12624850974382e+23*cos(theta)**44 + 2.44920762132205e+24*cos(theta)**42 - 7.24662461154049e+24*cos(theta)**40 + 1.48746505184252e+25*cos(theta)**38 - 2.24879125041999e+25*cos(theta)**36 + 2.59475913509998e+25*cos(theta)**34 - 2.33653270431957e+25*cos(theta)**32 + 1.66511526054958e+25*cos(theta)**30 - 9.46830246194857e+24*cos(theta)**28 + 4.31207027785128e+24*cos(theta)**26 - 1.57286514063038e+24*cos(theta)**24 + 4.57922762462008e+23*cos(theta)**22 - 1.05674483645079e+23*cos(theta)**20 + 1.91220494214905e+22*cos(theta)**18 - 2.67184800135894e+21*cos(theta)**16 + 2.82237464932282e+20*cos(theta)**14 - 2.18956601098361e+19*cos(theta)**12 + 1.19826995625969e+18*cos(theta)**10 - 4.36616583252517e+16*cos(theta)**8 + 970259073894482.0*cos(theta)**6 - 11361347469490.4*cos(theta)**4 + 52517784912.8987*cos(theta)**2 - 40059332.504118)*cos(5*phi)

#@torch.jit.script
def Yl51_m6(theta, phi):
    return 2.19969674331575e-10*(1.0 - cos(theta)**2)**3*(2.30111599770723e+24*cos(theta)**45 - 2.25554934428728e+25*cos(theta)**43 + 1.02866720095526e+26*cos(theta)**41 - 2.8986498446162e+26*cos(theta)**39 + 5.65236719700158e+26*cos(theta)**37 - 8.09564850151195e+26*cos(theta)**35 + 8.82218105933994e+26*cos(theta)**33 - 7.47690465382262e+26*cos(theta)**31 + 4.99534578164873e+26*cos(theta)**29 - 2.6511246893456e+26*cos(theta)**27 + 1.12113827224133e+26*cos(theta)**25 - 3.7748763375129e+25*cos(theta)**23 + 1.00743007741642e+25*cos(theta)**21 - 2.11348967290158e+24*cos(theta)**19 + 3.44196889586828e+23*cos(theta)**17 - 4.2749568021743e+22*cos(theta)**15 + 3.95132450905195e+21*cos(theta)**13 - 2.62747921318033e+20*cos(theta)**11 + 1.19826995625969e+19*cos(theta)**9 - 3.49293266602014e+17*cos(theta)**7 + 5.82155444336689e+15*cos(theta)**5 - 45445389877961.7*cos(theta)**3 + 105035569825.797*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl51_m7(theta, phi):
    return 4.30568801491884e-12*(1.0 - cos(theta)**2)**3.5*(1.03550219896825e+26*cos(theta)**44 - 9.69886218043531e+26*cos(theta)**42 + 4.21753552391657e+27*cos(theta)**40 - 1.13047343940032e+28*cos(theta)**38 + 2.09137586289059e+28*cos(theta)**36 - 2.83347697552918e+28*cos(theta)**34 + 2.91131974958218e+28*cos(theta)**32 - 2.31784044268501e+28*cos(theta)**30 + 1.44865027667813e+28*cos(theta)**28 - 7.15803666123312e+27*cos(theta)**26 + 2.80284568060333e+27*cos(theta)**24 - 8.68221557627968e+26*cos(theta)**22 + 2.11560316257448e+26*cos(theta)**20 - 4.015630378513e+25*cos(theta)**18 + 5.85134712297608e+24*cos(theta)**16 - 6.41243520326146e+23*cos(theta)**14 + 5.13672186176754e+22*cos(theta)**12 - 2.89022713449836e+21*cos(theta)**10 + 1.07844296063372e+20*cos(theta)**8 - 2.44505286621409e+18*cos(theta)**6 + 2.91077722168345e+16*cos(theta)**4 - 136336169633885.0*cos(theta)**2 + 105035569825.797)*cos(7*phi)

#@torch.jit.script
def Yl51_m8(theta, phi):
    return 8.45065192956907e-14*(1.0 - cos(theta)**2)**4*(4.55620967546031e+27*cos(theta)**43 - 4.07352211578283e+28*cos(theta)**41 + 1.68701420956663e+29*cos(theta)**39 - 4.2957990697212e+29*cos(theta)**37 + 7.52895310640611e+29*cos(theta)**35 - 9.63382171679922e+29*cos(theta)**33 + 9.31622319866298e+29*cos(theta)**31 - 6.95352132805503e+29*cos(theta)**29 + 4.05622077469877e+29*cos(theta)**27 - 1.86108953192061e+29*cos(theta)**25 + 6.72682963344799e+28*cos(theta)**23 - 1.91008742678153e+28*cos(theta)**21 + 4.23120632514896e+27*cos(theta)**19 - 7.22813468132339e+26*cos(theta)**17 + 9.36215539676173e+25*cos(theta)**15 - 8.97740928456604e+24*cos(theta)**13 + 6.16406623412105e+23*cos(theta)**11 - 2.89022713449836e+22*cos(theta)**9 + 8.62754368506973e+20*cos(theta)**7 - 1.46703171972846e+19*cos(theta)**5 + 1.16431088867338e+17*cos(theta)**3 - 272672339267770.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl51_m9(theta, phi):
    return 1.66372047390768e-15*(1.0 - cos(theta)**2)**4.5*(1.95917016044793e+29*cos(theta)**42 - 1.67014406747096e+30*cos(theta)**40 + 6.57935541730984e+30*cos(theta)**38 - 1.58944565579685e+31*cos(theta)**36 + 2.63513358724214e+31*cos(theta)**34 - 3.17916116654374e+31*cos(theta)**32 + 2.88802919158552e+31*cos(theta)**30 - 2.01652118513596e+31*cos(theta)**28 + 1.09517960916867e+31*cos(theta)**26 - 4.65272382980153e+30*cos(theta)**24 + 1.54717081569304e+30*cos(theta)**22 - 4.01118359624121e+29*cos(theta)**20 + 8.03929201778302e+28*cos(theta)**18 - 1.22878289582498e+28*cos(theta)**16 + 1.40432330951426e+27*cos(theta)**14 - 1.16706320699359e+26*cos(theta)**12 + 6.78047285753315e+24*cos(theta)**10 - 2.60120442104852e+23*cos(theta)**8 + 6.03928057954881e+21*cos(theta)**6 - 7.33515859864228e+19*cos(theta)**4 + 3.49293266602014e+17*cos(theta)**2 - 272672339267770.0)*cos(9*phi)

#@torch.jit.script
def Yl51_m10(theta, phi):
    return 3.28693259725622e-17*(1.0 - cos(theta)**2)**5*(8.22851467388132e+30*cos(theta)**41 - 6.68057626988384e+31*cos(theta)**39 + 2.50015505857774e+32*cos(theta)**37 - 5.72200436086864e+32*cos(theta)**35 + 8.95945419662327e+32*cos(theta)**33 - 1.017331573294e+33*cos(theta)**31 + 8.66408757475657e+32*cos(theta)**29 - 5.64625931838069e+32*cos(theta)**27 + 2.84746698383854e+32*cos(theta)**25 - 1.11665371915237e+32*cos(theta)**23 + 3.40377579452468e+31*cos(theta)**21 - 8.02236719248242e+30*cos(theta)**19 + 1.44707256320094e+30*cos(theta)**17 - 1.96605263331996e+29*cos(theta)**15 + 1.96605263331996e+28*cos(theta)**13 - 1.4004758483923e+27*cos(theta)**11 + 6.78047285753315e+25*cos(theta)**9 - 2.08096353683882e+24*cos(theta)**7 + 3.62356834772929e+22*cos(theta)**5 - 2.93406343945691e+20*cos(theta)**3 + 6.98586533204027e+17*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl51_m11(theta, phi):
    return 6.5193309049391e-19*(1.0 - cos(theta)**2)**5.5*(3.37369101629134e+32*cos(theta)**40 - 2.6054247452547e+33*cos(theta)**38 + 9.25057371673764e+33*cos(theta)**36 - 2.00270152630403e+34*cos(theta)**34 + 2.95661988488568e+34*cos(theta)**32 - 3.15372787721139e+34*cos(theta)**30 + 2.51258539667941e+34*cos(theta)**28 - 1.52449001596279e+34*cos(theta)**26 + 7.11866745959634e+33*cos(theta)**24 - 2.56830355405044e+33*cos(theta)**22 + 7.14792916850184e+32*cos(theta)**20 - 1.52424976657166e+32*cos(theta)**18 + 2.4600233574416e+31*cos(theta)**16 - 2.94907894997994e+30*cos(theta)**14 + 2.55586842331595e+29*cos(theta)**12 - 1.54052343323153e+28*cos(theta)**10 + 6.10242557177984e+26*cos(theta)**8 - 1.45667447578717e+25*cos(theta)**6 + 1.81178417386464e+23*cos(theta)**4 - 8.80219031837074e+20*cos(theta)**2 + 6.98586533204027e+17)*cos(11*phi)

#@torch.jit.script
def Yl51_m12(theta, phi):
    return 1.29868180188352e-20*(1.0 - cos(theta)**2)**6*(1.34947640651654e+34*cos(theta)**39 - 9.90061403196785e+34*cos(theta)**37 + 3.33020653802555e+35*cos(theta)**35 - 6.80918518943369e+35*cos(theta)**33 + 9.46118363163418e+35*cos(theta)**31 - 9.46118363163418e+35*cos(theta)**29 + 7.03523911070233e+35*cos(theta)**27 - 3.96367404150324e+35*cos(theta)**25 + 1.70848019030312e+35*cos(theta)**23 - 5.65026781891098e+34*cos(theta)**21 + 1.42958583370037e+34*cos(theta)**19 - 2.74364957982899e+33*cos(theta)**17 + 3.93603737190657e+32*cos(theta)**15 - 4.12871052997192e+31*cos(theta)**13 + 3.06704210797914e+30*cos(theta)**11 - 1.54052343323153e+29*cos(theta)**9 + 4.88194045742387e+27*cos(theta)**7 - 8.74004685472304e+25*cos(theta)**5 + 7.24713669545858e+23*cos(theta)**3 - 1.76043806367415e+21*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl51_m13(theta, phi):
    return 2.59944399144839e-22*(1.0 - cos(theta)**2)**6.5*(5.26295798541449e+35*cos(theta)**38 - 3.66322719182811e+36*cos(theta)**36 + 1.16557228830894e+37*cos(theta)**34 - 2.24703111251312e+37*cos(theta)**32 + 2.93296692580659e+37*cos(theta)**30 - 2.74374325317391e+37*cos(theta)**28 + 1.89951455988963e+37*cos(theta)**26 - 9.9091851037581e+36*cos(theta)**24 + 3.92950443769718e+36*cos(theta)**22 - 1.18655624197131e+36*cos(theta)**20 + 2.7162130840307e+35*cos(theta)**18 - 4.66420428570928e+34*cos(theta)**16 + 5.90405605785985e+33*cos(theta)**14 - 5.3673236889635e+32*cos(theta)**12 + 3.37374631877706e+31*cos(theta)**10 - 1.38647108990838e+30*cos(theta)**8 + 3.41735832019671e+28*cos(theta)**6 - 4.37002342736152e+26*cos(theta)**4 + 2.17414100863757e+24*cos(theta)**2 - 1.76043806367415e+21)*cos(13*phi)

#@torch.jit.script
def Yl51_m14(theta, phi):
    return 5.23036488794434e-24*(1.0 - cos(theta)**2)**7*(1.99992403445751e+37*cos(theta)**37 - 1.31876178905812e+38*cos(theta)**35 + 3.96294578025041e+38*cos(theta)**33 - 7.19049956004197e+38*cos(theta)**31 + 8.79890077741978e+38*cos(theta)**29 - 7.68248110888695e+38*cos(theta)**27 + 4.93873785571304e+38*cos(theta)**25 - 2.37820442490195e+38*cos(theta)**23 + 8.64490976293379e+37*cos(theta)**21 - 2.37311248394261e+37*cos(theta)**19 + 4.88918355125526e+36*cos(theta)**17 - 7.46272685713485e+35*cos(theta)**15 + 8.26567848100379e+34*cos(theta)**13 - 6.4407884267562e+33*cos(theta)**11 + 3.37374631877706e+32*cos(theta)**9 - 1.1091768719267e+31*cos(theta)**7 + 2.05041499211803e+29*cos(theta)**5 - 1.74800937094461e+27*cos(theta)**3 + 4.34828201727515e+24*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl51_m15(theta, phi):
    return 1.05842273015951e-25*(1.0 - cos(theta)**2)**7.5*(7.39971892749277e+38*cos(theta)**36 - 4.61566626170341e+39*cos(theta)**34 + 1.30777210748263e+40*cos(theta)**32 - 2.22905486361301e+40*cos(theta)**30 + 2.55168122545174e+40*cos(theta)**28 - 2.07426989939948e+40*cos(theta)**26 + 1.23468446392826e+40*cos(theta)**24 - 5.46987017727447e+39*cos(theta)**22 + 1.8154310502161e+39*cos(theta)**20 - 4.50891371949096e+38*cos(theta)**18 + 8.31161203713394e+37*cos(theta)**16 - 1.11940902857023e+37*cos(theta)**14 + 1.07453820253049e+36*cos(theta)**12 - 7.08486726943182e+34*cos(theta)**10 + 3.03637168689935e+33*cos(theta)**8 - 7.76423810348692e+31*cos(theta)**6 + 1.02520749605901e+30*cos(theta)**4 - 5.24402811283383e+27*cos(theta)**2 + 4.34828201727515e+24)*cos(15*phi)

#@torch.jit.script
def Yl51_m16(theta, phi):
    return 2.15511528062785e-27*(1.0 - cos(theta)**2)**8*(2.6638988138974e+40*cos(theta)**35 - 1.56932652897916e+41*cos(theta)**33 + 4.18487074394443e+41*cos(theta)**31 - 6.68716459083903e+41*cos(theta)**29 + 7.14470743126486e+41*cos(theta)**27 - 5.39310173843864e+41*cos(theta)**25 + 2.96324271342782e+41*cos(theta)**23 - 1.20337143900038e+41*cos(theta)**21 + 3.63086210043219e+40*cos(theta)**19 - 8.11604469508373e+39*cos(theta)**17 + 1.32985792594143e+39*cos(theta)**15 - 1.56717263999832e+38*cos(theta)**13 + 1.28944584303659e+37*cos(theta)**11 - 7.08486726943182e+35*cos(theta)**9 + 2.42909734951948e+34*cos(theta)**7 - 4.65854286209215e+32*cos(theta)**5 + 4.10082998423605e+30*cos(theta)**3 - 1.04880562256677e+28*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl51_m17(theta, phi):
    return 4.41755563460786e-29*(1.0 - cos(theta)**2)**8.5*(9.3236458486409e+41*cos(theta)**34 - 5.17877754563123e+42*cos(theta)**32 + 1.29730993062277e+43*cos(theta)**30 - 1.93927773134332e+43*cos(theta)**28 + 1.92907100644151e+43*cos(theta)**26 - 1.34827543460966e+43*cos(theta)**24 + 6.81545824088399e+42*cos(theta)**22 - 2.52708002190081e+42*cos(theta)**20 + 6.89863799082117e+41*cos(theta)**18 - 1.37972759816423e+41*cos(theta)**16 + 1.99478688891214e+40*cos(theta)**14 - 2.03732443199781e+39*cos(theta)**12 + 1.41839042734025e+38*cos(theta)**10 - 6.37638054248864e+36*cos(theta)**8 + 1.70036814466364e+35*cos(theta)**6 - 2.32927143104608e+33*cos(theta)**4 + 1.23024899527082e+31*cos(theta)**2 - 1.04880562256677e+28)*cos(17*phi)

#@torch.jit.script
def Yl51_m18(theta, phi):
    return 9.12048689848131e-31*(1.0 - cos(theta)**2)**9*(3.1700395885379e+43*cos(theta)**33 - 1.65720881460199e+44*cos(theta)**31 + 3.89192979186832e+44*cos(theta)**29 - 5.4299776477613e+44*cos(theta)**27 + 5.01558461674793e+44*cos(theta)**25 - 3.23586104306318e+44*cos(theta)**23 + 1.49940081299448e+44*cos(theta)**21 - 5.05416004380161e+43*cos(theta)**19 + 1.24175483834781e+43*cos(theta)**17 - 2.20756415706277e+42*cos(theta)**15 + 2.792701644477e+41*cos(theta)**13 - 2.44478931839738e+40*cos(theta)**11 + 1.41839042734025e+39*cos(theta)**9 - 5.10110443399091e+37*cos(theta)**7 + 1.02022088679818e+36*cos(theta)**5 - 9.31708572418431e+33*cos(theta)**3 + 2.46049799054163e+31*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl51_m19(theta, phi):
    return 1.89763216851572e-32*(1.0 - cos(theta)**2)**9.5*(1.04611306421751e+45*cos(theta)**32 - 5.13734732526618e+45*cos(theta)**30 + 1.12865963964181e+46*cos(theta)**28 - 1.46609396489555e+46*cos(theta)**26 + 1.25389615418698e+46*cos(theta)**24 - 7.44248039904532e+45*cos(theta)**22 + 3.14874170728841e+45*cos(theta)**20 - 9.60290408322307e+44*cos(theta)**18 + 2.11098322519128e+44*cos(theta)**16 - 3.31134623559416e+43*cos(theta)**14 + 3.6305121378201e+42*cos(theta)**12 - 2.68926825023711e+41*cos(theta)**10 + 1.27655138460622e+40*cos(theta)**8 - 3.57077310379364e+38*cos(theta)**6 + 5.10110443399091e+36*cos(theta)**4 - 2.79512571725529e+34*cos(theta)**2 + 2.46049799054163e+31)*cos(19*phi)

#@torch.jit.script
def Yl51_m20(theta, phi):
    return 3.98114385180629e-34*(1.0 - cos(theta)**2)**10*(3.34756180549603e+46*cos(theta)**31 - 1.54120419757985e+47*cos(theta)**29 + 3.16024699099707e+47*cos(theta)**27 - 3.81184430872843e+47*cos(theta)**25 + 3.00935077004876e+47*cos(theta)**23 - 1.63734568778997e+47*cos(theta)**21 + 6.29748341457681e+46*cos(theta)**19 - 1.72852273498015e+46*cos(theta)**17 + 3.37757316030604e+45*cos(theta)**15 - 4.63588472983183e+44*cos(theta)**13 + 4.35661456538412e+43*cos(theta)**11 - 2.68926825023711e+42*cos(theta)**9 + 1.02124110768498e+41*cos(theta)**7 - 2.14246386227618e+39*cos(theta)**5 + 2.04044177359636e+37*cos(theta)**3 - 5.59025143451059e+34*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl51_m21(theta, phi):
    return 8.42676291309043e-36*(1.0 - cos(theta)**2)**10.5*(1.03774415970377e+48*cos(theta)**30 - 4.46949217298158e+48*cos(theta)**28 + 8.5326668756921e+48*cos(theta)**26 - 9.52961077182108e+48*cos(theta)**24 + 6.92150677111215e+48*cos(theta)**22 - 3.43842594435894e+48*cos(theta)**20 + 1.19652184876959e+48*cos(theta)**18 - 2.93848864946626e+47*cos(theta)**16 + 5.06635974045907e+46*cos(theta)**14 - 6.02665014878137e+45*cos(theta)**12 + 4.79227602192254e+44*cos(theta)**10 - 2.4203414252134e+43*cos(theta)**8 + 7.14868775379486e+41*cos(theta)**6 - 1.07123193113809e+40*cos(theta)**4 + 6.12132532078909e+37*cos(theta)**2 - 5.59025143451059e+34)*cos(21*phi)

#@torch.jit.script
def Yl51_m22(theta, phi):
    return 1.80068902582784e-37*(1.0 - cos(theta)**2)**11*(3.1132324791113e+49*cos(theta)**29 - 1.25145780843484e+50*cos(theta)**27 + 2.21849338767995e+50*cos(theta)**25 - 2.28710658523706e+50*cos(theta)**23 + 1.52273148964467e+50*cos(theta)**21 - 6.87685188871788e+49*cos(theta)**19 + 2.15373932778527e+49*cos(theta)**17 - 4.70158183914601e+48*cos(theta)**15 + 7.09290363664269e+47*cos(theta)**13 - 7.23198017853765e+46*cos(theta)**11 + 4.79227602192254e+45*cos(theta)**9 - 1.93627314017072e+44*cos(theta)**7 + 4.28921265227692e+42*cos(theta)**5 - 4.28492772455236e+40*cos(theta)**3 + 1.22426506415782e+38*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl51_m23(theta, phi):
    return 3.88708340155292e-39*(1.0 - cos(theta)**2)**11.5*(9.02837418942278e+50*cos(theta)**28 - 3.37893608277407e+51*cos(theta)**26 + 5.54623346919987e+51*cos(theta)**24 - 5.26034514604523e+51*cos(theta)**22 + 3.19773612825381e+51*cos(theta)**20 - 1.3066018588564e+51*cos(theta)**18 + 3.66135685723496e+50*cos(theta)**16 - 7.05237275871902e+49*cos(theta)**14 + 9.2207747276355e+48*cos(theta)**12 - 7.95517819639141e+47*cos(theta)**10 + 4.31304841973028e+46*cos(theta)**8 - 1.35539119811951e+45*cos(theta)**6 + 2.14460632613846e+43*cos(theta)**4 - 1.28547831736571e+41*cos(theta)**2 + 1.22426506415782e+38)*cos(23*phi)

#@torch.jit.script
def Yl51_m24(theta, phi):
    return 8.48231139058224e-41*(1.0 - cos(theta)**2)**12*(2.52794477303838e+52*cos(theta)**27 - 8.78523381521259e+52*cos(theta)**25 + 1.33109603260797e+53*cos(theta)**23 - 1.15727593212995e+53*cos(theta)**21 + 6.39547225650763e+52*cos(theta)**19 - 2.35188334594151e+52*cos(theta)**17 + 5.85817097157593e+51*cos(theta)**15 - 9.87332186220663e+50*cos(theta)**13 + 1.10649296731626e+50*cos(theta)**11 - 7.95517819639141e+48*cos(theta)**9 + 3.45043873578423e+47*cos(theta)**7 - 8.13234718871703e+45*cos(theta)**5 + 8.57842530455383e+43*cos(theta)**3 - 2.57095663473142e+41*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl51_m25(theta, phi):
    return 1.87251598325459e-42*(1.0 - cos(theta)**2)**12.5*(6.82545088720363e+53*cos(theta)**26 - 2.19630845380315e+54*cos(theta)**24 + 3.06152087499833e+54*cos(theta)**22 - 2.4302794574729e+54*cos(theta)**20 + 1.21513972873645e+54*cos(theta)**18 - 3.99820168810057e+53*cos(theta)**16 + 8.7872564573639e+52*cos(theta)**14 - 1.28353184208686e+52*cos(theta)**12 + 1.21714226404789e+51*cos(theta)**10 - 7.15966037675227e+49*cos(theta)**8 + 2.41530711504896e+48*cos(theta)**6 - 4.06617359435852e+46*cos(theta)**4 + 2.57352759136615e+44*cos(theta)**2 - 2.57095663473142e+41)*cos(25*phi)

#@torch.jit.script
def Yl51_m26(theta, phi):
    return 4.18498105984344e-44*(1.0 - cos(theta)**2)**13*(1.77461723067294e+55*cos(theta)**25 - 5.27114028912755e+55*cos(theta)**23 + 6.73534592499632e+55*cos(theta)**21 - 4.8605589149458e+55*cos(theta)**19 + 2.18725151172561e+55*cos(theta)**17 - 6.39712270096092e+54*cos(theta)**15 + 1.23021590403095e+54*cos(theta)**13 - 1.54023821050423e+53*cos(theta)**11 + 1.21714226404789e+52*cos(theta)**9 - 5.72772830140182e+50*cos(theta)**7 + 1.44918426902938e+49*cos(theta)**5 - 1.62646943774341e+47*cos(theta)**3 + 5.1470551827323e+44*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl51_m27(theta, phi):
    return 9.47711588478168e-46*(1.0 - cos(theta)**2)**13.5*(4.43654307668236e+56*cos(theta)**24 - 1.21236226649934e+57*cos(theta)**22 + 1.41442264424923e+57*cos(theta)**20 - 9.23506193839701e+56*cos(theta)**18 + 3.71832756993353e+56*cos(theta)**16 - 9.59568405144138e+55*cos(theta)**14 + 1.59928067524023e+55*cos(theta)**12 - 1.69426203155466e+54*cos(theta)**10 + 1.0954280376431e+53*cos(theta)**8 - 4.00940981098127e+51*cos(theta)**6 + 7.24592134514688e+49*cos(theta)**4 - 4.87940831323022e+47*cos(theta)**2 + 5.1470551827323e+44)*cos(27*phi)

#@torch.jit.script
def Yl51_m28(theta, phi):
    return 2.176491746711e-47*(1.0 - cos(theta)**2)**14*(1.06477033840377e+58*cos(theta)**23 - 2.66719698629854e+58*cos(theta)**21 + 2.82884528849845e+58*cos(theta)**19 - 1.66231114891146e+58*cos(theta)**17 + 5.94932411189365e+57*cos(theta)**15 - 1.34339576720179e+57*cos(theta)**13 + 1.91913681028828e+56*cos(theta)**11 - 1.69426203155466e+55*cos(theta)**9 + 8.76342430114478e+53*cos(theta)**7 - 2.40564588658876e+52*cos(theta)**5 + 2.89836853805875e+50*cos(theta)**3 - 9.75881662646044e+47*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl51_m29(theta, phi):
    return 5.07397254725842e-49*(1.0 - cos(theta)**2)**14.5*(2.44897177832866e+59*cos(theta)**22 - 5.60111367122694e+59*cos(theta)**20 + 5.37480604814706e+59*cos(theta)**18 - 2.82592895314949e+59*cos(theta)**16 + 8.92398616784048e+58*cos(theta)**14 - 1.74641449736233e+58*cos(theta)**12 + 2.1110504913171e+57*cos(theta)**10 - 1.52483582839919e+56*cos(theta)**8 + 6.13439701080135e+54*cos(theta)**6 - 1.20282294329438e+53*cos(theta)**4 + 8.69510561417625e+50*cos(theta)**2 - 9.75881662646044e+47)*cos(29*phi)

#@torch.jit.script
def Yl51_m30(theta, phi):
    return 1.20197175760466e-50*(1.0 - cos(theta)**2)**15*(5.38773791232305e+60*cos(theta)**21 - 1.12022273424539e+61*cos(theta)**19 + 9.67465088666471e+60*cos(theta)**17 - 4.52148632503918e+60*cos(theta)**15 + 1.24935806349767e+60*cos(theta)**13 - 2.0956973968348e+59*cos(theta)**11 + 2.1110504913171e+58*cos(theta)**9 - 1.21986866271935e+57*cos(theta)**7 + 3.68063820648081e+55*cos(theta)**5 - 4.81129177317753e+53*cos(theta)**3 + 1.73902112283525e+51*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl51_m31(theta, phi):
    return 2.89652772429387e-52*(1.0 - cos(theta)**2)**15.5*(1.13142496158784e+62*cos(theta)**20 - 2.12842319506624e+62*cos(theta)**18 + 1.644690650733e+62*cos(theta)**16 - 6.78222948755877e+61*cos(theta)**14 + 1.62416548254697e+61*cos(theta)**12 - 2.30526713651828e+60*cos(theta)**10 + 1.89994544218539e+59*cos(theta)**8 - 8.53908063903547e+57*cos(theta)**6 + 1.8403191032404e+56*cos(theta)**4 - 1.44338753195326e+54*cos(theta)**2 + 1.73902112283525e+51)*cos(31*phi)

#@torch.jit.script
def Yl51_m32(theta, phi):
    return 7.10924769273408e-54*(1.0 - cos(theta)**2)**16*(2.26284992317568e+63*cos(theta)**19 - 3.83116175111923e+63*cos(theta)**17 + 2.6315050411728e+63*cos(theta)**15 - 9.49512128258227e+62*cos(theta)**13 + 1.94899857905636e+62*cos(theta)**11 - 2.30526713651828e+61*cos(theta)**9 + 1.51995635374831e+60*cos(theta)**7 - 5.12344838342128e+58*cos(theta)**5 + 7.36127641296161e+56*cos(theta)**3 - 2.88677506390652e+54*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl51_m33(theta, phi):
    return 1.77953773735963e-55*(1.0 - cos(theta)**2)**16.5*(4.2994148540338e+64*cos(theta)**18 - 6.51297497690268e+64*cos(theta)**16 + 3.9472575617592e+64*cos(theta)**14 - 1.2343657667357e+64*cos(theta)**12 + 2.143898436962e+63*cos(theta)**10 - 2.07474042286645e+62*cos(theta)**8 + 1.06396944762382e+61*cos(theta)**6 - 2.56172419171064e+59*cos(theta)**4 + 2.20838292388848e+57*cos(theta)**2 - 2.88677506390652e+54)*cos(33*phi)

#@torch.jit.script
def Yl51_m34(theta, phi):
    return 4.54947713629167e-57*(1.0 - cos(theta)**2)**17*(7.73894673726083e+65*cos(theta)**17 - 1.04207599630443e+66*cos(theta)**15 + 5.52616058646288e+65*cos(theta)**13 - 1.48123892008283e+65*cos(theta)**11 + 2.143898436962e+64*cos(theta)**9 - 1.65979233829316e+63*cos(theta)**7 + 6.38381668574292e+61*cos(theta)**5 - 1.02468967668426e+60*cos(theta)**3 + 4.41676584777697e+57*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl51_m35(theta, phi):
    return 1.18983790564055e-58*(1.0 - cos(theta)**2)**17.5*(1.31562094533434e+67*cos(theta)**16 - 1.56311399445664e+67*cos(theta)**14 + 7.18400876240175e+66*cos(theta)**12 - 1.62936281209112e+66*cos(theta)**10 + 1.9295085932658e+65*cos(theta)**8 - 1.16185463680521e+64*cos(theta)**6 + 3.19190834287146e+62*cos(theta)**4 - 3.07406903005277e+60*cos(theta)**2 + 4.41676584777697e+57)*cos(35*phi)

#@torch.jit.script
def Yl51_m36(theta, phi):
    return 3.18910033265596e-60*(1.0 - cos(theta)**2)**18*(2.10499351253495e+68*cos(theta)**15 - 2.1883595922393e+68*cos(theta)**13 + 8.6208105148821e+67*cos(theta)**11 - 1.62936281209112e+67*cos(theta)**9 + 1.54360687461264e+66*cos(theta)**7 - 6.97112782083127e+64*cos(theta)**5 + 1.27676333714858e+63*cos(theta)**3 - 6.14813806010554e+60*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl51_m37(theta, phi):
    return 8.77770977401657e-62*(1.0 - cos(theta)**2)**18.5*(3.15749026880242e+69*cos(theta)**14 - 2.84486746991109e+69*cos(theta)**12 + 9.4828915663703e+68*cos(theta)**10 - 1.46642653088201e+68*cos(theta)**8 + 1.08052481222885e+67*cos(theta)**6 - 3.48556391041563e+65*cos(theta)**4 + 3.83029001144575e+63*cos(theta)**2 - 6.14813806010554e+60)*cos(37*phi)

#@torch.jit.script
def Yl51_m38(theta, phi):
    return 2.48669313889022e-63*(1.0 - cos(theta)**2)**19*(4.42048637632339e+70*cos(theta)**13 - 3.41384096389331e+70*cos(theta)**11 + 9.48289156637031e+69*cos(theta)**9 - 1.1731412247056e+69*cos(theta)**7 + 6.48314887337308e+67*cos(theta)**5 - 1.39422556416625e+66*cos(theta)**3 + 7.6605800228915e+63*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl51_m39(theta, phi):
    return 7.26991386339812e-65*(1.0 - cos(theta)**2)**19.5*(5.7466322892204e+71*cos(theta)**12 - 3.75522506028264e+71*cos(theta)**10 + 8.53460240973327e+70*cos(theta)**8 - 8.21198857293923e+69*cos(theta)**6 + 3.24157443668654e+68*cos(theta)**4 - 4.18267669249876e+66*cos(theta)**2 + 7.6605800228915e+63)*cos(39*phi)

#@torch.jit.script
def Yl51_m40(theta, phi):
    return 2.19997601512958e-66*(1.0 - cos(theta)**2)**20*(6.89595874706449e+72*cos(theta)**11 - 3.75522506028264e+72*cos(theta)**9 + 6.82768192778662e+71*cos(theta)**7 - 4.92719314376354e+70*cos(theta)**5 + 1.29662977467462e+69*cos(theta)**3 - 8.36535338499752e+66*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl51_m41(theta, phi):
    return 6.91556535228707e-68*(1.0 - cos(theta)**2)**20.5*(7.58555462177093e+73*cos(theta)**10 - 3.37970255425438e+73*cos(theta)**8 + 4.77937734945063e+72*cos(theta)**6 - 2.46359657188177e+71*cos(theta)**4 + 3.88988932402385e+69*cos(theta)**2 - 8.36535338499752e+66)*cos(41*phi)

#@torch.jit.script
def Yl51_m42(theta, phi):
    return 2.26770321354111e-69*(1.0 - cos(theta)**2)**21*(7.58555462177093e+74*cos(theta)**9 - 2.7037620434035e+74*cos(theta)**7 + 2.86762640967038e+73*cos(theta)**5 - 9.85438628752708e+71*cos(theta)**3 + 7.77977864804769e+69*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl51_m43(theta, phi):
    return 7.79652424885213e-71*(1.0 - cos(theta)**2)**21.5*(6.82699915959384e+75*cos(theta)**8 - 1.89263343038245e+75*cos(theta)**6 + 1.43381320483519e+74*cos(theta)**4 - 2.95631588625812e+72*cos(theta)**2 + 7.77977864804769e+69)*cos(43*phi)

#@torch.jit.script
def Yl51_m44(theta, phi):
    return 2.82809658797451e-72*(1.0 - cos(theta)**2)**22*(5.46159932767507e+76*cos(theta)**7 - 1.13558005822947e+76*cos(theta)**5 + 5.73525281934076e+74*cos(theta)**3 - 5.91263177251625e+72*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl51_m45(theta, phi):
    return 1.09096194385207e-73*(1.0 - cos(theta)**2)**22.5*(3.82311952937255e+77*cos(theta)**6 - 5.67790029114735e+76*cos(theta)**4 + 1.72057584580223e+75*cos(theta)**2 - 5.91263177251625e+72)*cos(45*phi)

#@torch.jit.script
def Yl51_m46(theta, phi):
    return 4.52218274953181e-75*(1.0 - cos(theta)**2)**23*(2.29387171762353e+78*cos(theta)**5 - 2.27116011645894e+77*cos(theta)**3 + 3.44115169160446e+75*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl51_m47(theta, phi):
    return 2.04291392629189e-76*(1.0 - cos(theta)**2)**23.5*(1.14693585881177e+79*cos(theta)**4 - 6.81348034937682e+77*cos(theta)**2 + 3.44115169160446e+75)*cos(47*phi)

#@torch.jit.script
def Yl51_m48(theta, phi):
    return 1.02660287462151e-77*(1.0 - cos(theta)**2)**24*(4.58774343524706e+79*cos(theta)**3 - 1.36269606987536e+78*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl51_m49(theta, phi):
    return 5.92709446013574e-79*(1.0 - cos(theta)**2)**24.5*(1.37632303057412e+80*cos(theta)**2 - 1.36269606987536e+78)*cos(49*phi)

#@torch.jit.script
def Yl51_m50(theta, phi):
    return 11.4793298912137*(1.0 - cos(theta)**2)**25*cos(50*phi)*cos(theta)

#@torch.jit.script
def Yl51_m51(theta, phi):
    return 1.1366230286804*(1.0 - cos(theta)**2)**25.5*cos(51*phi)

#@torch.jit.script
def Yl52_m_minus_52(theta, phi):
    return 1.14207448934996*(1.0 - cos(theta)**2)**26*sin(52*phi)

#@torch.jit.script
def Yl52_m_minus_51(theta, phi):
    return 11.6469202143439*(1.0 - cos(theta)**2)**25.5*sin(51*phi)*cos(theta)

#@torch.jit.script
def Yl52_m_minus_50(theta, phi):
    return 5.89599508828156e-81*(1.0 - cos(theta)**2)**25*(1.41761272149134e+82*cos(theta)**2 - 1.37632303057412e+80)*sin(50*phi)

#@torch.jit.script
def Yl52_m_minus_49(theta, phi):
    return 1.03137791196042e-79*(1.0 - cos(theta)**2)**24.5*(4.72537573830447e+81*cos(theta)**3 - 1.37632303057412e+80*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl52_m_minus_48(theta, phi):
    return 2.07304394671472e-78*(1.0 - cos(theta)**2)**24*(1.18134393457612e+81*cos(theta)**4 - 6.88161515287059e+79*cos(theta)**2 + 3.40674017468841e+77)*sin(48*phi)

#@torch.jit.script
def Yl52_m_minus_47(theta, phi):
    return 4.63546718519856e-77*(1.0 - cos(theta)**2)**23.5*(2.36268786915224e+80*cos(theta)**5 - 2.29387171762353e+79*cos(theta)**3 + 3.40674017468841e+77*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl52_m_minus_46(theta, phi):
    return 1.12976140307948e-75*(1.0 - cos(theta)**2)**23*(3.93781311525373e+79*cos(theta)**6 - 5.73467929405883e+78*cos(theta)**4 + 1.70337008734421e+77*cos(theta)**2 - 5.73525281934076e+74)*sin(46*phi)

#@torch.jit.script
def Yl52_m_minus_45(theta, phi):
    return 2.95902606938711e-74*(1.0 - cos(theta)**2)**22.5*(5.62544730750532e+78*cos(theta)**7 - 1.14693585881177e+78*cos(theta)**5 + 5.67790029114735e+76*cos(theta)**3 - 5.73525281934076e+74*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl52_m_minus_44(theta, phi):
    return 8.24289280334673e-73*(1.0 - cos(theta)**2)**22*(7.03180913438166e+77*cos(theta)**8 - 1.91155976468628e+77*cos(theta)**6 + 1.41947507278684e+76*cos(theta)**4 - 2.86762640967038e+74*cos(theta)**2 + 7.39078971564531e+71)*sin(44*phi)

#@torch.jit.script
def Yl52_m_minus_43(theta, phi):
    return 2.42290576471909e-71*(1.0 - cos(theta)**2)**21.5*(7.81312126042406e+76*cos(theta)**9 - 2.73079966383754e+76*cos(theta)**7 + 2.83895014557368e+75*cos(theta)**5 - 9.55875469890127e+73*cos(theta)**3 + 7.39078971564531e+71*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl52_m_minus_42(theta, phi):
    return 7.46789711195431e-70*(1.0 - cos(theta)**2)**21*(7.81312126042406e+75*cos(theta)**10 - 3.41349957979692e+75*cos(theta)**8 + 4.73158357595613e+74*cos(theta)**6 - 2.38968867472532e+73*cos(theta)**4 + 3.69539485782266e+71*cos(theta)**2 - 7.77977864804769e+68)*sin(42*phi)

#@torch.jit.script
def Yl52_m_minus_41(theta, phi):
    return 2.4013673155533e-68*(1.0 - cos(theta)**2)**20.5*(7.10283750947642e+74*cos(theta)**11 - 3.79277731088547e+74*cos(theta)**9 + 6.75940510850875e+73*cos(theta)**7 - 4.77937734945063e+72*cos(theta)**5 + 1.23179828594088e+71*cos(theta)**3 - 7.77977864804769e+68*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl52_m_minus_40(theta, phi):
    return 8.02214841696147e-67*(1.0 - cos(theta)**2)**20*(5.91903125789702e+73*cos(theta)**12 - 3.79277731088547e+73*cos(theta)**10 + 8.44925638563594e+72*cos(theta)**8 - 7.96562891575106e+71*cos(theta)**6 + 3.07949571485221e+70*cos(theta)**4 - 3.88988932402385e+68*cos(theta)**2 + 6.97112782083127e+65)*sin(40*phi)

#@torch.jit.script
def Yl52_m_minus_39(theta, phi):
    return 2.77431827315494e-65*(1.0 - cos(theta)**2)**19.5*(4.55310096761309e+72*cos(theta)**13 - 3.44797937353224e+72*cos(theta)**11 + 9.3880626507066e+71*cos(theta)**9 - 1.13794698796444e+71*cos(theta)**7 + 6.15899142970443e+69*cos(theta)**5 - 1.29662977467462e+68*cos(theta)**3 + 6.97112782083127e+65*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl52_m_minus_38(theta, phi):
    return 9.90241210821384e-64*(1.0 - cos(theta)**2)**19*(3.25221497686649e+71*cos(theta)**14 - 2.8733161446102e+71*cos(theta)**12 + 9.3880626507066e+70*cos(theta)**10 - 1.42243373495555e+70*cos(theta)**8 + 1.0264985716174e+69*cos(theta)**6 - 3.24157443668654e+67*cos(theta)**4 + 3.48556391041563e+65*cos(theta)**2 - 5.47184287349393e+62)*sin(38*phi)

#@torch.jit.script
def Yl52_m_minus_37(theta, phi):
    return 3.63837853318226e-62*(1.0 - cos(theta)**2)**18.5*(2.168143317911e+70*cos(theta)**15 - 2.21024318816169e+70*cos(theta)**13 + 8.53460240973327e+69*cos(theta)**11 - 1.58048192772838e+69*cos(theta)**9 + 1.46642653088201e+68*cos(theta)**7 - 6.48314887337308e+66*cos(theta)**5 + 1.16185463680521e+65*cos(theta)**3 - 5.47184287349393e+62*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl52_m_minus_36(theta, phi):
    return 1.37297577733285e-60*(1.0 - cos(theta)**2)**18*(1.35508957369437e+69*cos(theta)**16 - 1.57874513440121e+69*cos(theta)**14 + 7.11216867477773e+68*cos(theta)**12 - 1.58048192772838e+68*cos(theta)**10 + 1.83303316360251e+67*cos(theta)**8 - 1.08052481222885e+66*cos(theta)**6 + 2.90463659201303e+64*cos(theta)**4 - 2.73592143674697e+62*cos(theta)**2 + 3.84258628756596e+59)*sin(36*phi)

#@torch.jit.script
def Yl52_m_minus_35(theta, phi):
    return 5.31041757093879e-59*(1.0 - cos(theta)**2)**17.5*(7.97111513937866e+67*cos(theta)**17 - 1.05249675626747e+68*cos(theta)**15 + 5.47089898059825e+67*cos(theta)**13 - 1.43680175248035e+67*cos(theta)**11 + 2.0367035151139e+66*cos(theta)**9 - 1.54360687461264e+65*cos(theta)**7 + 5.80927318402606e+63*cos(theta)**5 - 9.11973812248989e+61*cos(theta)**3 + 3.84258628756596e+59*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl52_m_minus_34(theta, phi):
    return 2.10147656332241e-57*(1.0 - cos(theta)**2)**17*(4.42839729965481e+66*cos(theta)**18 - 6.57810472667171e+66*cos(theta)**16 + 3.90778498614161e+66*cos(theta)**14 - 1.19733479373362e+66*cos(theta)**12 + 2.0367035151139e+65*cos(theta)**10 - 1.9295085932658e+64*cos(theta)**8 + 9.68212197337676e+62*cos(theta)**6 - 2.27993453062247e+61*cos(theta)**4 + 1.92129314378298e+59*cos(theta)**2 - 2.45375880432054e+56)*sin(34*phi)

#@torch.jit.script
def Yl52_m_minus_33(theta, phi):
    return 8.49474950853759e-56*(1.0 - cos(theta)**2)**16.5*(2.33073542087095e+65*cos(theta)**19 - 3.86947336863042e+65*cos(theta)**17 + 2.60518999076107e+65*cos(theta)**15 - 9.2102676441048e+64*cos(theta)**13 + 1.85154865010354e+64*cos(theta)**11 - 2.143898436962e+63*cos(theta)**9 + 1.38316028191097e+62*cos(theta)**7 - 4.55986906124494e+60*cos(theta)**5 + 6.4043104792766e+58*cos(theta)**3 - 2.45375880432054e+56*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl52_m_minus_32(theta, phi):
    return 3.50247494868642e-54*(1.0 - cos(theta)**2)**16*(1.16536771043548e+64*cos(theta)**20 - 2.1497074270169e+64*cos(theta)**18 + 1.62824374422567e+64*cos(theta)**16 - 6.578762602932e+63*cos(theta)**14 + 1.54295720841962e+63*cos(theta)**12 - 2.143898436962e+62*cos(theta)**10 + 1.72895035238871e+61*cos(theta)**8 - 7.59978176874157e+59*cos(theta)**6 + 1.60107761981915e+58*cos(theta)**4 - 1.22687940216027e+56*cos(theta)**2 + 1.44338753195326e+53)*sin(32*phi)

#@torch.jit.script
def Yl52_m_minus_31(theta, phi):
    return 1.4710394784483e-52*(1.0 - cos(theta)**2)**15.5*(5.54937004969274e+62*cos(theta)**21 - 1.13142496158784e+63*cos(theta)**19 + 9.57790437779806e+62*cos(theta)**17 - 4.385841735288e+62*cos(theta)**15 + 1.18689016032278e+62*cos(theta)**13 - 1.94899857905636e+61*cos(theta)**11 + 1.92105594709856e+60*cos(theta)**9 - 1.08568310982022e+59*cos(theta)**7 + 3.2021552396383e+57*cos(theta)**5 - 4.0895980072009e+55*cos(theta)**3 + 1.44338753195326e+53*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl52_m_minus_30(theta, phi):
    return 6.28600489237972e-51*(1.0 - cos(theta)**2)**15*(2.52244093167852e+61*cos(theta)**22 - 5.65712480793921e+61*cos(theta)**20 + 5.32105798766559e+61*cos(theta)**18 - 2.741151084555e+61*cos(theta)**16 + 8.47778685944846e+60*cos(theta)**14 - 1.62416548254697e+60*cos(theta)**12 + 1.92105594709856e+59*cos(theta)**10 - 1.35710388727528e+58*cos(theta)**8 + 5.33692539939717e+56*cos(theta)**6 - 1.02239950180022e+55*cos(theta)**4 + 7.21693765976629e+52*cos(theta)**2 - 7.90464146743296e+49)*sin(30*phi)

#@torch.jit.script
def Yl52_m_minus_29(theta, phi):
    return 2.72989258503413e-49*(1.0 - cos(theta)**2)**14.5*(1.09671344855588e+60*cos(theta)**23 - 2.69386895616153e+60*cos(theta)**21 + 2.80055683561347e+60*cos(theta)**19 - 1.61244181444412e+60*cos(theta)**17 + 5.65185790629897e+59*cos(theta)**15 - 1.24935806349767e+59*cos(theta)**13 + 1.74641449736233e+58*cos(theta)**11 - 1.50789320808365e+57*cos(theta)**9 + 7.62417914199596e+55*cos(theta)**7 - 2.04479900360045e+54*cos(theta)**5 + 2.40564588658876e+52*cos(theta)**3 - 7.90464146743296e+49*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl52_m_minus_28(theta, phi):
    return 1.20363189946937e-47*(1.0 - cos(theta)**2)**14*(4.56963936898283e+58*cos(theta)**24 - 1.22448588916433e+59*cos(theta)**22 + 1.40027841780673e+59*cos(theta)**20 - 8.9580100802451e+58*cos(theta)**18 + 3.53241119143686e+58*cos(theta)**16 - 8.92398616784048e+57*cos(theta)**14 + 1.45534541446861e+57*cos(theta)**12 - 1.50789320808364e+56*cos(theta)**10 + 9.53022392749495e+54*cos(theta)**8 - 3.40799833933408e+53*cos(theta)**6 + 6.01411471647191e+51*cos(theta)**4 - 3.95232073371648e+49*cos(theta)**2 + 4.06617359435852e+46)*sin(28*phi)

#@torch.jit.script
def Yl52_m_minus_27(theta, phi):
    return 5.38280549420141e-46*(1.0 - cos(theta)**2)**13.5*(1.82785574759313e+57*cos(theta)**25 - 5.32385169201883e+57*cos(theta)**23 + 6.66799246574635e+57*cos(theta)**21 - 4.71474214749742e+57*cos(theta)**19 + 2.07788893613933e+57*cos(theta)**17 - 5.94932411189365e+56*cos(theta)**15 + 1.11949647266816e+56*cos(theta)**13 - 1.37081200734877e+55*cos(theta)**11 + 1.05891376972166e+54*cos(theta)**9 - 4.86856905619154e+52*cos(theta)**7 + 1.20282294329438e+51*cos(theta)**5 - 1.31744024457216e+49*cos(theta)**3 + 4.06617359435852e+46*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl52_m_minus_26(theta, phi):
    return 2.43954541064895e-44*(1.0 - cos(theta)**2)**13*(7.03021441381973e+55*cos(theta)**26 - 2.21827153834118e+56*cos(theta)**24 + 3.03090566624834e+56*cos(theta)**22 - 2.35737107374871e+56*cos(theta)**20 + 1.15438274229963e+56*cos(theta)**18 - 3.71832756993353e+55*cos(theta)**16 + 7.99640337620115e+54*cos(theta)**14 - 1.14234333945731e+54*cos(theta)**12 + 1.05891376972166e+53*cos(theta)**10 - 6.08571132023943e+51*cos(theta)**8 + 2.00470490549064e+50*cos(theta)**6 - 3.2936006114304e+48*cos(theta)**4 + 2.03308679717926e+46*cos(theta)**2 - 1.97963660874319e+43)*sin(26*phi)

#@torch.jit.script
def Yl52_m_minus_25(theta, phi):
    return 1.11953606878753e-42*(1.0 - cos(theta)**2)**12.5*(2.60378311622953e+54*cos(theta)**27 - 8.87308615336471e+54*cos(theta)**25 + 1.31778507228189e+55*cos(theta)**23 - 1.12255765416605e+55*cos(theta)**21 + 6.07569864368224e+54*cos(theta)**19 - 2.18725151172561e+54*cos(theta)**17 + 5.3309355841341e+53*cos(theta)**15 - 8.7872564573639e+52*cos(theta)**13 + 9.62648881565146e+51*cos(theta)**11 - 6.7619014669327e+50*cos(theta)**9 + 2.86386415070091e+49*cos(theta)**7 - 6.5872012228608e+47*cos(theta)**5 + 6.77695599059753e+45*cos(theta)**3 - 1.97963660874319e+43*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl52_m_minus_24(theta, phi):
    return 5.19831351121283e-41*(1.0 - cos(theta)**2)**12*(9.29922541510547e+52*cos(theta)**28 - 3.41272544360181e+53*cos(theta)**26 + 5.49077113450787e+53*cos(theta)**24 - 5.10253479166388e+53*cos(theta)**22 + 3.03784932184112e+53*cos(theta)**20 - 1.21513972873645e+53*cos(theta)**18 + 3.33183474008381e+52*cos(theta)**16 - 6.27661175525993e+51*cos(theta)**14 + 8.02207401304289e+50*cos(theta)**12 - 6.7619014669327e+49*cos(theta)**10 + 3.57983018837613e+48*cos(theta)**8 - 1.0978668704768e+47*cos(theta)**6 + 1.69423899764938e+45*cos(theta)**4 - 9.89818304371596e+42*cos(theta)**2 + 9.18198798118364e+39)*sin(24*phi)

#@torch.jit.script
def Yl52_m_minus_23(theta, phi):
    return 2.44044072346227e-39*(1.0 - cos(theta)**2)**11.5*(3.20662945348464e+51*cos(theta)**29 - 1.26397238651919e+52*cos(theta)**27 + 2.19630845380315e+52*cos(theta)**25 - 2.21849338767995e+52*cos(theta)**23 + 1.44659491516244e+52*cos(theta)**21 - 6.39547225650763e+51*cos(theta)**19 + 1.95990278828459e+51*cos(theta)**17 - 4.18440783683995e+50*cos(theta)**15 + 6.17082616387914e+49*cos(theta)**13 - 6.147183151757e+48*cos(theta)**11 + 3.97758909819571e+47*cos(theta)**9 - 1.56838124353828e+46*cos(theta)**7 + 3.38847799529876e+44*cos(theta)**5 - 3.29939434790532e+42*cos(theta)**3 + 9.18198798118364e+39*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl52_m_minus_22(theta, phi):
    return 1.15760267711549e-37*(1.0 - cos(theta)**2)**11*(1.06887648449488e+50*cos(theta)**30 - 4.51418709471139e+50*cos(theta)**28 + 8.44734020693518e+50*cos(theta)**26 - 9.24372244866644e+50*cos(theta)**24 + 6.57543143255654e+50*cos(theta)**22 - 3.19773612825381e+50*cos(theta)**20 + 1.08883488238033e+50*cos(theta)**18 - 2.61525489802497e+49*cos(theta)**16 + 4.40773297419939e+48*cos(theta)**14 - 5.12265262646417e+47*cos(theta)**12 + 3.97758909819571e+46*cos(theta)**10 - 1.96047655442286e+45*cos(theta)**8 + 5.64746332549794e+43*cos(theta)**6 - 8.2484858697633e+41*cos(theta)**4 + 4.59099399059182e+39*cos(theta)**2 - 4.08088354719273e+36)*sin(22*phi)

#@torch.jit.script
def Yl52_m_minus_21(theta, phi):
    return 5.54442137630337e-36*(1.0 - cos(theta)**2)**10.5*(3.44798865966091e+48*cos(theta)**31 - 1.55661623955565e+49*cos(theta)**29 + 3.1286445210871e+49*cos(theta)**27 - 3.69748897946658e+49*cos(theta)**25 + 2.85888323154632e+49*cos(theta)**23 - 1.52273148964467e+49*cos(theta)**21 + 5.7307099072649e+48*cos(theta)**19 - 1.53838523413234e+48*cos(theta)**17 + 2.93848864946626e+47*cos(theta)**15 - 3.94050202035705e+46*cos(theta)**13 + 3.61599008926882e+45*cos(theta)**11 - 2.17830728269206e+44*cos(theta)**9 + 8.06780475071134e+42*cos(theta)**7 - 1.64969717395266e+41*cos(theta)**5 + 1.53033133019727e+39*cos(theta)**3 - 4.08088354719273e+36*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl52_m_minus_20(theta, phi):
    return 2.67973993547416e-34*(1.0 - cos(theta)**2)**10*(1.07749645614403e+47*cos(theta)**32 - 5.18872079851884e+47*cos(theta)**30 + 1.11737304324539e+48*cos(theta)**28 - 1.42211114594868e+48*cos(theta)**26 + 1.19120134647763e+48*cos(theta)**24 - 6.92150677111215e+47*cos(theta)**22 + 2.86535495363245e+47*cos(theta)**20 - 8.54658463406853e+46*cos(theta)**18 + 1.83655540591641e+46*cos(theta)**16 - 2.81464430025504e+45*cos(theta)**14 + 3.01332507439069e+44*cos(theta)**12 - 2.17830728269206e+43*cos(theta)**10 + 1.00847559383892e+42*cos(theta)**8 - 2.7494952899211e+40*cos(theta)**6 + 3.82582832549318e+38*cos(theta)**4 - 2.04044177359636e+36*cos(theta)**2 + 1.74695357328456e+33)*sin(20*phi)

#@torch.jit.script
def Yl52_m_minus_19(theta, phi):
    return 1.30621860901373e-32*(1.0 - cos(theta)**2)**9.5*(3.26514077619404e+45*cos(theta)**33 - 1.67378090274801e+46*cos(theta)**31 + 3.85301049394963e+46*cos(theta)**29 - 5.26707831832846e+46*cos(theta)**27 + 4.76480538591054e+46*cos(theta)**25 - 3.00935077004876e+46*cos(theta)**23 + 1.36445473982498e+46*cos(theta)**21 - 4.49820243898344e+45*cos(theta)**19 + 1.08032670936259e+45*cos(theta)**17 - 1.87642953350336e+44*cos(theta)**15 + 2.31794236491591e+43*cos(theta)**13 - 1.98027934790187e+42*cos(theta)**11 + 1.1205284375988e+41*cos(theta)**9 - 3.927850414173e+39*cos(theta)**7 + 7.65165665098636e+37*cos(theta)**5 - 6.80147257865454e+35*cos(theta)**3 + 1.74695357328456e+33*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl52_m_minus_18(theta, phi):
    return 6.41777518275959e-31*(1.0 - cos(theta)**2)**9*(9.60335522410012e+43*cos(theta)**34 - 5.23056532108754e+44*cos(theta)**32 + 1.28433683131654e+45*cos(theta)**30 - 1.88109939940302e+45*cos(theta)**28 + 1.83261745611944e+45*cos(theta)**26 - 1.25389615418698e+45*cos(theta)**24 + 6.20206699920443e+44*cos(theta)**22 - 2.24910121949172e+44*cos(theta)**20 + 6.00181505201442e+43*cos(theta)**18 - 1.1727684584396e+43*cos(theta)**16 + 1.65567311779708e+42*cos(theta)**14 - 1.65023278991823e+41*cos(theta)**12 + 1.1205284375988e+40*cos(theta)**10 - 4.90981301771625e+38*cos(theta)**8 + 1.27527610849773e+37*cos(theta)**6 - 1.70036814466364e+35*cos(theta)**4 + 8.73476786642279e+32*cos(theta)**2 - 7.23675879571068e+29)*sin(18*phi)

#@torch.jit.script
def Yl52_m_minus_17(theta, phi):
    return 3.17663664630203e-29*(1.0 - cos(theta)**2)**8.5*(2.74381577831432e+42*cos(theta)**35 - 1.58501979426895e+43*cos(theta)**33 + 4.14302203650498e+43*cos(theta)**31 - 6.48654965311386e+43*cos(theta)**29 + 6.78747205970162e+43*cos(theta)**27 - 5.01558461674793e+43*cos(theta)**25 + 2.69655086921932e+43*cos(theta)**23 - 1.07100058071034e+43*cos(theta)**21 + 3.15885002737601e+42*cos(theta)**19 - 6.89863799082117e+41*cos(theta)**17 + 1.10378207853139e+41*cos(theta)**15 - 1.26940983839864e+40*cos(theta)**13 + 1.01866221599891e+39*cos(theta)**11 - 5.4553477974625e+37*cos(theta)**9 + 1.82182301213961e+36*cos(theta)**7 - 3.40073628932727e+34*cos(theta)**5 + 2.9115892888076e+32*cos(theta)**3 - 7.23675879571068e+29*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl52_m_minus_16(theta, phi):
    return 1.58322754619955e-27*(1.0 - cos(theta)**2)**8*(7.62171049531756e+40*cos(theta)**36 - 4.66182292432045e+41*cos(theta)**34 + 1.29469438640781e+42*cos(theta)**32 - 2.16218321770462e+42*cos(theta)**30 + 2.42409716417915e+42*cos(theta)**28 - 1.92907100644151e+42*cos(theta)**26 + 1.12356286217472e+42*cos(theta)**24 - 4.86818445777428e+41*cos(theta)**22 + 1.579425013688e+41*cos(theta)**20 - 3.83257666156732e+40*cos(theta)**18 + 6.89863799082117e+39*cos(theta)**16 - 9.06721313141884e+38*cos(theta)**14 + 8.48885179999089e+37*cos(theta)**12 - 5.4553477974625e+36*cos(theta)**10 + 2.27727876517451e+35*cos(theta)**8 - 5.66789381554545e+33*cos(theta)**6 + 7.27897322201899e+31*cos(theta)**4 - 3.61837939785534e+29*cos(theta)**2 + 2.91334895157435e+26)*sin(16*phi)

#@torch.jit.script
def Yl52_m_minus_15(theta, phi):
    return 7.94142897029328e-26*(1.0 - cos(theta)**2)**7.5*(2.05992175549123e+39*cos(theta)**37 - 1.3319494069487e+40*cos(theta)**35 + 3.9233163224479e+40*cos(theta)**33 - 6.97478457324071e+40*cos(theta)**31 + 8.35895573854879e+40*cos(theta)**29 - 7.14470743126486e+40*cos(theta)**27 + 4.49425144869887e+40*cos(theta)**25 - 2.11660193816273e+40*cos(theta)**23 + 7.5210714937524e+39*cos(theta)**21 - 2.01714561135122e+39*cos(theta)**19 + 4.05802234754186e+38*cos(theta)**17 - 6.04480875427923e+37*cos(theta)**15 + 6.52988599999299e+36*cos(theta)**13 - 4.95940708860227e+35*cos(theta)**11 + 2.53030973908279e+34*cos(theta)**9 - 8.09699116506493e+32*cos(theta)**7 + 1.4557946444038e+31*cos(theta)**5 - 1.20612646595178e+29*cos(theta)**3 + 2.91334895157435e+26*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl52_m_minus_14(theta, phi):
    return 4.00707854619401e-24*(1.0 - cos(theta)**2)**7*(5.42084672497692e+37*cos(theta)**38 - 3.69985946374639e+38*cos(theta)**36 + 1.15391656542585e+39*cos(theta)**34 - 2.17962017913772e+39*cos(theta)**32 + 2.78631857951626e+39*cos(theta)**30 - 2.55168122545174e+39*cos(theta)**28 + 1.72855824949956e+39*cos(theta)**26 - 8.81917474234471e+38*cos(theta)**24 + 3.41866886079655e+38*cos(theta)**22 - 1.00857280567561e+38*cos(theta)**20 + 2.25445685974548e+37*cos(theta)**18 - 3.77800547142452e+36*cos(theta)**16 + 4.66420428570928e+35*cos(theta)**14 - 4.13283924050189e+34*cos(theta)**12 + 2.53030973908279e+33*cos(theta)**10 - 1.01212389563312e+32*cos(theta)**8 + 2.42632440733966e+30*cos(theta)**6 - 3.01531616487945e+28*cos(theta)**4 + 1.45667447578717e+26*cos(theta)**2 - 1.1442847413882e+23)*sin(14*phi)

#@torch.jit.script
def Yl52_m_minus_13(theta, phi):
    return 2.032975415385e-22*(1.0 - cos(theta)**2)**6.5*(1.38996069871203e+36*cos(theta)**39 - 9.99962017228753e+36*cos(theta)**37 + 3.2969044726453e+37*cos(theta)**35 - 6.60490963375068e+37*cos(theta)**33 + 8.98812445005247e+37*cos(theta)**31 - 8.79890077741978e+37*cos(theta)**29 + 6.40206759073913e+37*cos(theta)**27 - 3.52766989693789e+37*cos(theta)**25 + 1.48637776556372e+37*cos(theta)**23 - 4.80272764607433e+36*cos(theta)**21 + 1.18655624197131e+36*cos(theta)**19 - 2.22235615966148e+35*cos(theta)**17 + 3.10946952380619e+34*cos(theta)**15 - 3.17910710807838e+33*cos(theta)**13 + 2.30028158098436e+32*cos(theta)**11 - 1.12458210625902e+31*cos(theta)**9 + 3.46617772477095e+29*cos(theta)**7 - 6.0306323297589e+27*cos(theta)**5 + 4.85558158595725e+25*cos(theta)**3 - 1.1442847413882e+23*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl52_m_minus_12(theta, phi):
    return 1.03661813137025e-20*(1.0 - cos(theta)**2)**6*(3.47490174678008e+34*cos(theta)**40 - 2.63147899270725e+35*cos(theta)**38 + 9.15806797957027e+35*cos(theta)**36 - 1.9426204805149e+36*cos(theta)**34 + 2.8087888906414e+36*cos(theta)**32 - 2.93296692580659e+36*cos(theta)**30 + 2.28645271097826e+36*cos(theta)**28 - 1.35679611420688e+36*cos(theta)**26 + 6.19324068984882e+35*cos(theta)**24 - 2.18305802094288e+35*cos(theta)**22 + 5.93278120985653e+34*cos(theta)**20 - 1.23464231092304e+34*cos(theta)**18 + 1.94341845237887e+33*cos(theta)**16 - 2.27079079148456e+32*cos(theta)**14 + 1.91690131748696e+31*cos(theta)**12 - 1.12458210625902e+30*cos(theta)**10 + 4.33272215596369e+28*cos(theta)**8 - 1.00510538829315e+27*cos(theta)**6 + 1.21389539648931e+25*cos(theta)**4 - 5.72142370694098e+22*cos(theta)**2 + 4.40109515918537e+19)*sin(12*phi)

#@torch.jit.script
def Yl52_m_minus_11(theta, phi):
    return 5.31007574555136e-19*(1.0 - cos(theta)**2)**5.5*(8.47537011409776e+32*cos(theta)**41 - 6.74738203258268e+33*cos(theta)**39 + 2.47515350799196e+34*cos(theta)**37 - 5.55034423004258e+34*cos(theta)**35 + 8.51148148679211e+34*cos(theta)**33 - 9.46118363163417e+34*cos(theta)**31 + 7.88431969302848e+34*cos(theta)**29 - 5.02517079335881e+34*cos(theta)**27 + 2.47729627593953e+34*cos(theta)**25 - 9.49155661279512e+33*cos(theta)**23 + 2.82513390945549e+33*cos(theta)**21 - 6.49811742591076e+32*cos(theta)**19 + 1.14318732492875e+32*cos(theta)**17 - 1.51386052765637e+31*cos(theta)**15 + 1.47453947498997e+30*cos(theta)**13 - 1.02234736932638e+29*cos(theta)**11 + 4.81413572884854e+27*cos(theta)**9 - 1.43586484041879e+26*cos(theta)**7 + 2.42779079297862e+24*cos(theta)**5 - 1.90714123564699e+22*cos(theta)**3 + 4.40109515918537e+19*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl52_m_minus_10(theta, phi):
    return 2.73146497514726e-17*(1.0 - cos(theta)**2)**5*(2.01794526526137e+31*cos(theta)**42 - 1.68684550814567e+32*cos(theta)**40 + 6.51356186313675e+32*cos(theta)**38 - 1.54176228612294e+33*cos(theta)**36 + 2.50337690788003e+33*cos(theta)**34 - 2.95661988488568e+33*cos(theta)**32 + 2.62810656434283e+33*cos(theta)**30 - 1.794703854771e+33*cos(theta)**28 + 9.52806259976741e+32*cos(theta)**26 - 3.9548152553313e+32*cos(theta)**24 + 1.28415177702522e+32*cos(theta)**22 - 3.24905871295538e+31*cos(theta)**20 + 6.35104069404858e+30*cos(theta)**18 - 9.46162829785232e+29*cos(theta)**16 + 1.05324248213569e+29*cos(theta)**14 - 8.51956141105317e+27*cos(theta)**12 + 4.81413572884854e+26*cos(theta)**10 - 1.79483105052348e+25*cos(theta)**8 + 4.0463179882977e+23*cos(theta)**6 - 4.76785308911748e+21*cos(theta)**4 + 2.20054757959268e+19*cos(theta)**2 - 1.6633012695334e+16)*sin(10*phi)

#@torch.jit.script
def Yl52_m_minus_9(theta, phi):
    return 1.41034612160548e-15*(1.0 - cos(theta)**2)**4.5*(4.69289596572412e+29*cos(theta)**43 - 4.11425733694066e+30*cos(theta)**41 + 1.67014406747096e+31*cos(theta)**39 - 4.16692509762957e+31*cos(theta)**37 + 7.1525054510858e+31*cos(theta)**35 - 8.95945419662327e+31*cos(theta)**33 + 8.47776311078331e+31*cos(theta)**31 - 6.18863398196898e+31*cos(theta)**29 + 3.52891207398793e+31*cos(theta)**27 - 1.58192610213252e+31*cos(theta)**25 + 5.58326859576184e+30*cos(theta)**23 - 1.54717081569304e+30*cos(theta)**21 + 3.34265299686768e+29*cos(theta)**19 - 5.56566370461901e+28*cos(theta)**17 + 7.0216165475713e+27*cos(theta)**15 - 6.55350877773321e+26*cos(theta)**13 + 4.37648702622595e+25*cos(theta)**11 - 1.99425672280387e+24*cos(theta)**9 + 5.78045426899672e+22*cos(theta)**7 - 9.53570617823497e+20*cos(theta)**5 + 7.33515859864228e+18*cos(theta)**3 - 1.6633012695334e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl52_m_minus_8(theta, phi):
    return 7.3066274535116e-14*(1.0 - cos(theta)**2)**4*(1.0665672649373e+28*cos(theta)**44 - 9.79585080223966e+28*cos(theta)**42 + 4.1753601686774e+29*cos(theta)**40 - 1.09655923621831e+30*cos(theta)**38 + 1.98680706974606e+30*cos(theta)**36 - 2.63513358724214e+30*cos(theta)**34 + 2.64930097211978e+30*cos(theta)**32 - 2.06287799398966e+30*cos(theta)**30 + 1.26032574070997e+30*cos(theta)**28 - 6.08433116204815e+29*cos(theta)**26 + 2.32636191490076e+29*cos(theta)**24 - 7.03259461678654e+28*cos(theta)**22 + 1.67132649843384e+28*cos(theta)**20 - 3.09203539145501e+27*cos(theta)**18 + 4.38851034223206e+26*cos(theta)**16 - 4.68107769838086e+25*cos(theta)**14 + 3.64707252185495e+24*cos(theta)**12 - 1.99425672280387e+23*cos(theta)**10 + 7.2255678362459e+21*cos(theta)**8 - 1.58928436303916e+20*cos(theta)**6 + 1.83378964966057e+18*cos(theta)**4 - 8.31650634766699e+15*cos(theta)**2 + 6197098619722.05)*sin(8*phi)

#@torch.jit.script
def Yl52_m_minus_7(theta, phi):
    return 3.79663499443791e-12*(1.0 - cos(theta)**2)**3.5*(2.37014947763844e+26*cos(theta)**45 - 2.27810483773015e+27*cos(theta)**43 + 1.01838052894571e+28*cos(theta)**41 - 2.81169034927771e+28*cos(theta)**39 + 5.36974883715151e+28*cos(theta)**37 - 7.52895310640611e+28*cos(theta)**35 + 8.02818476399935e+28*cos(theta)**33 - 6.65444514190213e+28*cos(theta)**31 + 4.3459508300344e+28*cos(theta)**29 - 2.25345598594376e+28*cos(theta)**27 + 9.30544765960306e+27*cos(theta)**25 - 3.05764983338545e+27*cos(theta)**23 + 7.9586976115897e+26*cos(theta)**21 - 1.62738704813421e+26*cos(theta)**19 + 2.58147667190121e+25*cos(theta)**17 - 3.12071846558724e+24*cos(theta)**15 + 2.80544040142689e+23*cos(theta)**13 - 1.81296065709443e+22*cos(theta)**11 + 8.02840870693989e+20*cos(theta)**9 - 2.27040623291309e+19*cos(theta)**7 + 3.66757929932114e+17*cos(theta)**5 - 2.77216878255566e+15*cos(theta)**3 + 6197098619722.05*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl52_m_minus_6(theta, phi):
    return 1.97789743871133e-10*(1.0 - cos(theta)**2)**3*(5.1524988644314e+24*cos(theta)**46 - 5.17751099484126e+25*cos(theta)**44 + 2.42471554510883e+26*cos(theta)**42 - 7.02922587319428e+26*cos(theta)**40 + 1.4130917992504e+27*cos(theta)**38 - 2.09137586289059e+27*cos(theta)**36 + 2.36123081294098e+27*cos(theta)**34 - 2.07951410684441e+27*cos(theta)**32 + 1.44865027667813e+27*cos(theta)**30 - 8.04805709265629e+26*cos(theta)**28 + 3.57901833061656e+26*cos(theta)**26 - 1.2740207639106e+26*cos(theta)**24 + 3.61758982344987e+25*cos(theta)**22 - 8.13693524067107e+24*cos(theta)**20 + 1.43415370661178e+24*cos(theta)**18 - 1.95044904099203e+23*cos(theta)**16 + 2.00388600101921e+22*cos(theta)**14 - 1.51080054757869e+21*cos(theta)**12 + 8.02840870693989e+19*cos(theta)**10 - 2.83800779114136e+18*cos(theta)**8 + 6.11263216553524e+16*cos(theta)**6 - 693042195638916.0*cos(theta)**4 + 3098549309861.02*cos(theta)**2 - 2283381952.73473)*sin(6*phi)

#@torch.jit.script
def Yl52_m_minus_5(theta, phi):
    return 1.03268220600501e-8*(1.0 - cos(theta)**2)**2.5*(1.09627635413434e+23*cos(theta)**47 - 1.15055799885361e+24*cos(theta)**45 + 5.6388733607182e+24*cos(theta)**43 - 1.71444533492543e+25*cos(theta)**41 + 3.62331230577025e+25*cos(theta)**39 - 5.65236719700158e+25*cos(theta)**37 + 6.74637375125996e+25*cos(theta)**35 - 6.30155789952853e+25*cos(theta)**33 + 4.67306540863913e+25*cos(theta)**31 - 2.77519210091596e+25*cos(theta)**29 + 1.3255623446728e+25*cos(theta)**27 - 5.09608305564242e+24*cos(theta)**25 + 1.57286514063038e+24*cos(theta)**23 - 3.87473106698622e+23*cos(theta)**21 + 7.54817740321992e+22*cos(theta)**19 - 1.14732296528943e+22*cos(theta)**17 + 1.33592400067947e+21*cos(theta)**15 - 1.16215426736822e+20*cos(theta)**13 + 7.29855336994536e+18*cos(theta)**11 - 3.15334199015707e+17*cos(theta)**9 + 8.73233166505034e+15*cos(theta)**7 - 138608439127783.0*cos(theta)**5 + 1032849769953.67*cos(theta)**3 - 2283381952.73473*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl52_m_minus_4(theta, phi):
    return 5.40162885212221e-7*(1.0 - cos(theta)**2)**2*(2.28390907111321e+21*cos(theta)**48 - 2.50121304098612e+22*cos(theta)**46 + 1.28156212743596e+23*cos(theta)**44 - 4.08201270220341e+23*cos(theta)**42 + 9.05828076442562e+23*cos(theta)**40 - 1.48746505184252e+24*cos(theta)**38 + 1.87399270868332e+24*cos(theta)**36 - 1.85339938221427e+24*cos(theta)**34 + 1.46033294019973e+24*cos(theta)**32 - 9.25064033638654e+23*cos(theta)**30 + 4.73415123097429e+23*cos(theta)**28 - 1.96003194447785e+23*cos(theta)**26 + 6.55360475262657e+22*cos(theta)**24 - 1.76124139408465e+22*cos(theta)**22 + 3.77408870160996e+21*cos(theta)**20 - 6.37401647383015e+20*cos(theta)**18 + 8.34952500424669e+19*cos(theta)**16 - 8.30110190977301e+18*cos(theta)**14 + 6.0821278082878e+17*cos(theta)**12 - 3.15334199015707e+16*cos(theta)**10 + 1.09154145813129e+15*cos(theta)**8 - 23101406521297.2*cos(theta)**6 + 258212442488.419*cos(theta)**4 - 1141690976.36736*cos(theta)**2 + 834569.427169125)*sin(4*phi)

#@torch.jit.script
def Yl52_m_minus_3(theta, phi):
    return 2.8295462293216e-5*(1.0 - cos(theta)**2)**1.5*(4.6610389206392e+19*cos(theta)**49 - 5.32172987443854e+20*cos(theta)**47 + 2.84791583874657e+21*cos(theta)**45 - 9.49305279582189e+21*cos(theta)**43 + 2.20933677181113e+22*cos(theta)**41 - 3.81401295344236e+22*cos(theta)**39 + 5.06484515860357e+22*cos(theta)**37 - 5.2954268063265e+22*cos(theta)**35 + 4.42525133393857e+22*cos(theta)**33 - 2.98407752786662e+22*cos(theta)**31 + 1.63246594171527e+22*cos(theta)**29 - 7.2593775721402e+21*cos(theta)**27 + 2.62144190105063e+21*cos(theta)**25 - 7.6575712786289e+20*cos(theta)**23 + 1.79718509600474e+20*cos(theta)**21 - 3.35474551254219e+19*cos(theta)**19 + 4.9114852966157e+18*cos(theta)**17 - 5.53406793984868e+17*cos(theta)**15 + 4.67855985252907e+16*cos(theta)**13 - 2.86667453650642e+15*cos(theta)**11 + 121282384236810.0*cos(theta)**9 - 3300200931613.88*cos(theta)**7 + 51642488497.6837*cos(theta)**5 - 380563658.789121*cos(theta)**3 + 834569.427169125*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl52_m_minus_2(theta, phi):
    return 0.00148382656080949*(1.0 - cos(theta)**2)*(9.3220778412784e+17*cos(theta)**50 - 1.10869372384136e+19*cos(theta)**48 + 6.1911213885795e+19*cos(theta)**46 - 2.15751199905043e+20*cos(theta)**44 + 5.26032564716935e+20*cos(theta)**42 - 9.53503238360591e+20*cos(theta)**40 + 1.3328539891062e+21*cos(theta)**38 - 1.47095189064625e+21*cos(theta)**36 + 1.30154450998193e+21*cos(theta)**34 - 9.3252422745832e+20*cos(theta)**32 + 5.4415531390509e+20*cos(theta)**30 - 2.59263484719293e+20*cos(theta)**28 + 1.00824688501947e+20*cos(theta)**26 - 3.19065469942871e+19*cos(theta)**24 + 8.16902316365792e+18*cos(theta)**22 - 1.67737275627109e+18*cos(theta)**20 + 2.72860294256428e+17*cos(theta)**18 - 3.45879246240542e+16*cos(theta)**16 + 3.3418284660922e+15*cos(theta)**14 - 238889544708869.0*cos(theta)**12 + 12128238423681.0*cos(theta)**10 - 412525116451.735*cos(theta)**8 + 8607081416.28062*cos(theta)**6 - 95140914.6972803*cos(theta)**4 + 417284.713584563*cos(theta)**2 - 303.479791697864)*sin(2*phi)

#@torch.jit.script
def Yl52_m_minus_1(theta, phi):
    return 0.0778690916673651*(1.0 - cos(theta)**2)**0.5*(1.82785840025067e+16*cos(theta)**51 - 2.26264025273748e+17*cos(theta)**49 + 1.31725986991053e+18*cos(theta)**47 - 4.79447110900096e+18*cos(theta)**45 + 1.22333154585334e+19*cos(theta)**43 - 2.32561765453803e+19*cos(theta)**41 + 3.41757433104155e+19*cos(theta)**39 - 3.97554565039527e+19*cos(theta)**37 + 3.71869859994838e+19*cos(theta)**35 - 2.82583099229794e+19*cos(theta)**33 + 1.75533972227449e+19*cos(theta)**31 - 8.94012016273423e+18*cos(theta)**29 + 3.73424772229434e+18*cos(theta)**27 - 1.27626187977148e+18*cos(theta)**25 + 3.5517492015904e+17*cos(theta)**23 - 7.98748931557663e+16*cos(theta)**21 + 1.43610681187594e+16*cos(theta)**19 - 2.03458380141495e+15*cos(theta)**17 + 222788564406146.0*cos(theta)**15 - 18376118823759.1*cos(theta)**13 + 1102567129425.55*cos(theta)**11 - 45836124050.1928*cos(theta)**9 + 1229583059.46866*cos(theta)**7 - 19028182.9394561*cos(theta)**5 + 139094.904528188*cos(theta)**3 - 303.479791697864*cos(theta))*sin(phi)

#@torch.jit.script
def Yl52_m0(theta, phi):
    return 3.19211695935471e+15*cos(theta)**52 - 4.10946319233431e+16*cos(theta)**50 + 2.49212495574729e+17*cos(theta)**48 - 9.46504023596952e+17*cos(theta)**46 + 2.52482387737847e+18*cos(theta)**44 - 5.02838608000006e+18*cos(theta)**42 + 7.75885379010763e+18*cos(theta)**40 - 9.50063729400934e+18*cos(theta)**38 + 9.38054496866372e+18*cos(theta)**36 - 7.54756491731563e+18*cos(theta)**34 + 4.98139284542832e+18*cos(theta)**32 - 2.7062112281845e+18*cos(theta)**30 + 1.21111304965047e+18*cos(theta)**28 - 4.45765075723347e+17*cos(theta)**26 + 1.34391140640156e+17*cos(theta)**24 - 3.29706265037182e+16*cos(theta)**22 + 6.52073178284152e+15*cos(theta)**20 - 1.02646150682675e+15*cos(theta)**18 + 126448156638078.0*cos(theta)**16 - 11919700547187.3*cos(theta)**14 + 834379038303.108*cos(theta)**12 - 41624351117.1618*cos(theta)**10 + 1395749478.59336*cos(theta)**8 - 28799547.0896197*cos(theta)**6 + 315784.50756162*cos(theta)**4 - 1377.96876026889*cos(theta)**2 + 0.999977329658117

#@torch.jit.script
def Yl52_m1(theta, phi):
    return 0.0778690916673651*(1.0 - cos(theta)**2)**0.5*(1.82785840025067e+16*cos(theta)**51 - 2.26264025273748e+17*cos(theta)**49 + 1.31725986991053e+18*cos(theta)**47 - 4.79447110900096e+18*cos(theta)**45 + 1.22333154585334e+19*cos(theta)**43 - 2.32561765453803e+19*cos(theta)**41 + 3.41757433104155e+19*cos(theta)**39 - 3.97554565039527e+19*cos(theta)**37 + 3.71869859994838e+19*cos(theta)**35 - 2.82583099229794e+19*cos(theta)**33 + 1.75533972227449e+19*cos(theta)**31 - 8.94012016273423e+18*cos(theta)**29 + 3.73424772229434e+18*cos(theta)**27 - 1.27626187977148e+18*cos(theta)**25 + 3.5517492015904e+17*cos(theta)**23 - 7.98748931557663e+16*cos(theta)**21 + 1.43610681187594e+16*cos(theta)**19 - 2.03458380141495e+15*cos(theta)**17 + 222788564406146.0*cos(theta)**15 - 18376118823759.1*cos(theta)**13 + 1102567129425.55*cos(theta)**11 - 45836124050.1928*cos(theta)**9 + 1229583059.46866*cos(theta)**7 - 19028182.9394561*cos(theta)**5 + 139094.904528188*cos(theta)**3 - 303.479791697864*cos(theta))*cos(phi)

#@torch.jit.script
def Yl52_m2(theta, phi):
    return 0.00148382656080949*(1.0 - cos(theta)**2)*(9.3220778412784e+17*cos(theta)**50 - 1.10869372384136e+19*cos(theta)**48 + 6.1911213885795e+19*cos(theta)**46 - 2.15751199905043e+20*cos(theta)**44 + 5.26032564716935e+20*cos(theta)**42 - 9.53503238360591e+20*cos(theta)**40 + 1.3328539891062e+21*cos(theta)**38 - 1.47095189064625e+21*cos(theta)**36 + 1.30154450998193e+21*cos(theta)**34 - 9.3252422745832e+20*cos(theta)**32 + 5.4415531390509e+20*cos(theta)**30 - 2.59263484719293e+20*cos(theta)**28 + 1.00824688501947e+20*cos(theta)**26 - 3.19065469942871e+19*cos(theta)**24 + 8.16902316365792e+18*cos(theta)**22 - 1.67737275627109e+18*cos(theta)**20 + 2.72860294256428e+17*cos(theta)**18 - 3.45879246240542e+16*cos(theta)**16 + 3.3418284660922e+15*cos(theta)**14 - 238889544708869.0*cos(theta)**12 + 12128238423681.0*cos(theta)**10 - 412525116451.735*cos(theta)**8 + 8607081416.28062*cos(theta)**6 - 95140914.6972803*cos(theta)**4 + 417284.713584563*cos(theta)**2 - 303.479791697864)*cos(2*phi)

#@torch.jit.script
def Yl52_m3(theta, phi):
    return 2.8295462293216e-5*(1.0 - cos(theta)**2)**1.5*(4.6610389206392e+19*cos(theta)**49 - 5.32172987443854e+20*cos(theta)**47 + 2.84791583874657e+21*cos(theta)**45 - 9.49305279582189e+21*cos(theta)**43 + 2.20933677181113e+22*cos(theta)**41 - 3.81401295344236e+22*cos(theta)**39 + 5.06484515860357e+22*cos(theta)**37 - 5.2954268063265e+22*cos(theta)**35 + 4.42525133393857e+22*cos(theta)**33 - 2.98407752786662e+22*cos(theta)**31 + 1.63246594171527e+22*cos(theta)**29 - 7.2593775721402e+21*cos(theta)**27 + 2.62144190105063e+21*cos(theta)**25 - 7.6575712786289e+20*cos(theta)**23 + 1.79718509600474e+20*cos(theta)**21 - 3.35474551254219e+19*cos(theta)**19 + 4.9114852966157e+18*cos(theta)**17 - 5.53406793984868e+17*cos(theta)**15 + 4.67855985252907e+16*cos(theta)**13 - 2.86667453650642e+15*cos(theta)**11 + 121282384236810.0*cos(theta)**9 - 3300200931613.88*cos(theta)**7 + 51642488497.6837*cos(theta)**5 - 380563658.789121*cos(theta)**3 + 834569.427169125*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl52_m4(theta, phi):
    return 5.40162885212221e-7*(1.0 - cos(theta)**2)**2*(2.28390907111321e+21*cos(theta)**48 - 2.50121304098612e+22*cos(theta)**46 + 1.28156212743596e+23*cos(theta)**44 - 4.08201270220341e+23*cos(theta)**42 + 9.05828076442562e+23*cos(theta)**40 - 1.48746505184252e+24*cos(theta)**38 + 1.87399270868332e+24*cos(theta)**36 - 1.85339938221427e+24*cos(theta)**34 + 1.46033294019973e+24*cos(theta)**32 - 9.25064033638654e+23*cos(theta)**30 + 4.73415123097429e+23*cos(theta)**28 - 1.96003194447785e+23*cos(theta)**26 + 6.55360475262657e+22*cos(theta)**24 - 1.76124139408465e+22*cos(theta)**22 + 3.77408870160996e+21*cos(theta)**20 - 6.37401647383015e+20*cos(theta)**18 + 8.34952500424669e+19*cos(theta)**16 - 8.30110190977301e+18*cos(theta)**14 + 6.0821278082878e+17*cos(theta)**12 - 3.15334199015707e+16*cos(theta)**10 + 1.09154145813129e+15*cos(theta)**8 - 23101406521297.2*cos(theta)**6 + 258212442488.419*cos(theta)**4 - 1141690976.36736*cos(theta)**2 + 834569.427169125)*cos(4*phi)

#@torch.jit.script
def Yl52_m5(theta, phi):
    return 1.03268220600501e-8*(1.0 - cos(theta)**2)**2.5*(1.09627635413434e+23*cos(theta)**47 - 1.15055799885361e+24*cos(theta)**45 + 5.6388733607182e+24*cos(theta)**43 - 1.71444533492543e+25*cos(theta)**41 + 3.62331230577025e+25*cos(theta)**39 - 5.65236719700158e+25*cos(theta)**37 + 6.74637375125996e+25*cos(theta)**35 - 6.30155789952853e+25*cos(theta)**33 + 4.67306540863913e+25*cos(theta)**31 - 2.77519210091596e+25*cos(theta)**29 + 1.3255623446728e+25*cos(theta)**27 - 5.09608305564242e+24*cos(theta)**25 + 1.57286514063038e+24*cos(theta)**23 - 3.87473106698622e+23*cos(theta)**21 + 7.54817740321992e+22*cos(theta)**19 - 1.14732296528943e+22*cos(theta)**17 + 1.33592400067947e+21*cos(theta)**15 - 1.16215426736822e+20*cos(theta)**13 + 7.29855336994536e+18*cos(theta)**11 - 3.15334199015707e+17*cos(theta)**9 + 8.73233166505034e+15*cos(theta)**7 - 138608439127783.0*cos(theta)**5 + 1032849769953.67*cos(theta)**3 - 2283381952.73473*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl52_m6(theta, phi):
    return 1.97789743871133e-10*(1.0 - cos(theta)**2)**3*(5.1524988644314e+24*cos(theta)**46 - 5.17751099484126e+25*cos(theta)**44 + 2.42471554510883e+26*cos(theta)**42 - 7.02922587319428e+26*cos(theta)**40 + 1.4130917992504e+27*cos(theta)**38 - 2.09137586289059e+27*cos(theta)**36 + 2.36123081294098e+27*cos(theta)**34 - 2.07951410684441e+27*cos(theta)**32 + 1.44865027667813e+27*cos(theta)**30 - 8.04805709265629e+26*cos(theta)**28 + 3.57901833061656e+26*cos(theta)**26 - 1.2740207639106e+26*cos(theta)**24 + 3.61758982344987e+25*cos(theta)**22 - 8.13693524067107e+24*cos(theta)**20 + 1.43415370661178e+24*cos(theta)**18 - 1.95044904099203e+23*cos(theta)**16 + 2.00388600101921e+22*cos(theta)**14 - 1.51080054757869e+21*cos(theta)**12 + 8.02840870693989e+19*cos(theta)**10 - 2.83800779114136e+18*cos(theta)**8 + 6.11263216553524e+16*cos(theta)**6 - 693042195638916.0*cos(theta)**4 + 3098549309861.02*cos(theta)**2 - 2283381952.73473)*cos(6*phi)

#@torch.jit.script
def Yl52_m7(theta, phi):
    return 3.79663499443791e-12*(1.0 - cos(theta)**2)**3.5*(2.37014947763844e+26*cos(theta)**45 - 2.27810483773015e+27*cos(theta)**43 + 1.01838052894571e+28*cos(theta)**41 - 2.81169034927771e+28*cos(theta)**39 + 5.36974883715151e+28*cos(theta)**37 - 7.52895310640611e+28*cos(theta)**35 + 8.02818476399935e+28*cos(theta)**33 - 6.65444514190213e+28*cos(theta)**31 + 4.3459508300344e+28*cos(theta)**29 - 2.25345598594376e+28*cos(theta)**27 + 9.30544765960306e+27*cos(theta)**25 - 3.05764983338545e+27*cos(theta)**23 + 7.9586976115897e+26*cos(theta)**21 - 1.62738704813421e+26*cos(theta)**19 + 2.58147667190121e+25*cos(theta)**17 - 3.12071846558724e+24*cos(theta)**15 + 2.80544040142689e+23*cos(theta)**13 - 1.81296065709443e+22*cos(theta)**11 + 8.02840870693989e+20*cos(theta)**9 - 2.27040623291309e+19*cos(theta)**7 + 3.66757929932114e+17*cos(theta)**5 - 2.77216878255566e+15*cos(theta)**3 + 6197098619722.05*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl52_m8(theta, phi):
    return 7.3066274535116e-14*(1.0 - cos(theta)**2)**4*(1.0665672649373e+28*cos(theta)**44 - 9.79585080223966e+28*cos(theta)**42 + 4.1753601686774e+29*cos(theta)**40 - 1.09655923621831e+30*cos(theta)**38 + 1.98680706974606e+30*cos(theta)**36 - 2.63513358724214e+30*cos(theta)**34 + 2.64930097211978e+30*cos(theta)**32 - 2.06287799398966e+30*cos(theta)**30 + 1.26032574070997e+30*cos(theta)**28 - 6.08433116204815e+29*cos(theta)**26 + 2.32636191490076e+29*cos(theta)**24 - 7.03259461678654e+28*cos(theta)**22 + 1.67132649843384e+28*cos(theta)**20 - 3.09203539145501e+27*cos(theta)**18 + 4.38851034223206e+26*cos(theta)**16 - 4.68107769838086e+25*cos(theta)**14 + 3.64707252185495e+24*cos(theta)**12 - 1.99425672280387e+23*cos(theta)**10 + 7.2255678362459e+21*cos(theta)**8 - 1.58928436303916e+20*cos(theta)**6 + 1.83378964966057e+18*cos(theta)**4 - 8.31650634766699e+15*cos(theta)**2 + 6197098619722.05)*cos(8*phi)

#@torch.jit.script
def Yl52_m9(theta, phi):
    return 1.41034612160548e-15*(1.0 - cos(theta)**2)**4.5*(4.69289596572412e+29*cos(theta)**43 - 4.11425733694066e+30*cos(theta)**41 + 1.67014406747096e+31*cos(theta)**39 - 4.16692509762957e+31*cos(theta)**37 + 7.1525054510858e+31*cos(theta)**35 - 8.95945419662327e+31*cos(theta)**33 + 8.47776311078331e+31*cos(theta)**31 - 6.18863398196898e+31*cos(theta)**29 + 3.52891207398793e+31*cos(theta)**27 - 1.58192610213252e+31*cos(theta)**25 + 5.58326859576184e+30*cos(theta)**23 - 1.54717081569304e+30*cos(theta)**21 + 3.34265299686768e+29*cos(theta)**19 - 5.56566370461901e+28*cos(theta)**17 + 7.0216165475713e+27*cos(theta)**15 - 6.55350877773321e+26*cos(theta)**13 + 4.37648702622595e+25*cos(theta)**11 - 1.99425672280387e+24*cos(theta)**9 + 5.78045426899672e+22*cos(theta)**7 - 9.53570617823497e+20*cos(theta)**5 + 7.33515859864228e+18*cos(theta)**3 - 1.6633012695334e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl52_m10(theta, phi):
    return 2.73146497514726e-17*(1.0 - cos(theta)**2)**5*(2.01794526526137e+31*cos(theta)**42 - 1.68684550814567e+32*cos(theta)**40 + 6.51356186313675e+32*cos(theta)**38 - 1.54176228612294e+33*cos(theta)**36 + 2.50337690788003e+33*cos(theta)**34 - 2.95661988488568e+33*cos(theta)**32 + 2.62810656434283e+33*cos(theta)**30 - 1.794703854771e+33*cos(theta)**28 + 9.52806259976741e+32*cos(theta)**26 - 3.9548152553313e+32*cos(theta)**24 + 1.28415177702522e+32*cos(theta)**22 - 3.24905871295538e+31*cos(theta)**20 + 6.35104069404858e+30*cos(theta)**18 - 9.46162829785232e+29*cos(theta)**16 + 1.05324248213569e+29*cos(theta)**14 - 8.51956141105317e+27*cos(theta)**12 + 4.81413572884854e+26*cos(theta)**10 - 1.79483105052348e+25*cos(theta)**8 + 4.0463179882977e+23*cos(theta)**6 - 4.76785308911748e+21*cos(theta)**4 + 2.20054757959268e+19*cos(theta)**2 - 1.6633012695334e+16)*cos(10*phi)

#@torch.jit.script
def Yl52_m11(theta, phi):
    return 5.31007574555136e-19*(1.0 - cos(theta)**2)**5.5*(8.47537011409776e+32*cos(theta)**41 - 6.74738203258268e+33*cos(theta)**39 + 2.47515350799196e+34*cos(theta)**37 - 5.55034423004258e+34*cos(theta)**35 + 8.51148148679211e+34*cos(theta)**33 - 9.46118363163417e+34*cos(theta)**31 + 7.88431969302848e+34*cos(theta)**29 - 5.02517079335881e+34*cos(theta)**27 + 2.47729627593953e+34*cos(theta)**25 - 9.49155661279512e+33*cos(theta)**23 + 2.82513390945549e+33*cos(theta)**21 - 6.49811742591076e+32*cos(theta)**19 + 1.14318732492875e+32*cos(theta)**17 - 1.51386052765637e+31*cos(theta)**15 + 1.47453947498997e+30*cos(theta)**13 - 1.02234736932638e+29*cos(theta)**11 + 4.81413572884854e+27*cos(theta)**9 - 1.43586484041879e+26*cos(theta)**7 + 2.42779079297862e+24*cos(theta)**5 - 1.90714123564699e+22*cos(theta)**3 + 4.40109515918537e+19*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl52_m12(theta, phi):
    return 1.03661813137025e-20*(1.0 - cos(theta)**2)**6*(3.47490174678008e+34*cos(theta)**40 - 2.63147899270725e+35*cos(theta)**38 + 9.15806797957027e+35*cos(theta)**36 - 1.9426204805149e+36*cos(theta)**34 + 2.8087888906414e+36*cos(theta)**32 - 2.93296692580659e+36*cos(theta)**30 + 2.28645271097826e+36*cos(theta)**28 - 1.35679611420688e+36*cos(theta)**26 + 6.19324068984882e+35*cos(theta)**24 - 2.18305802094288e+35*cos(theta)**22 + 5.93278120985653e+34*cos(theta)**20 - 1.23464231092304e+34*cos(theta)**18 + 1.94341845237887e+33*cos(theta)**16 - 2.27079079148456e+32*cos(theta)**14 + 1.91690131748696e+31*cos(theta)**12 - 1.12458210625902e+30*cos(theta)**10 + 4.33272215596369e+28*cos(theta)**8 - 1.00510538829315e+27*cos(theta)**6 + 1.21389539648931e+25*cos(theta)**4 - 5.72142370694098e+22*cos(theta)**2 + 4.40109515918537e+19)*cos(12*phi)

#@torch.jit.script
def Yl52_m13(theta, phi):
    return 2.032975415385e-22*(1.0 - cos(theta)**2)**6.5*(1.38996069871203e+36*cos(theta)**39 - 9.99962017228753e+36*cos(theta)**37 + 3.2969044726453e+37*cos(theta)**35 - 6.60490963375068e+37*cos(theta)**33 + 8.98812445005247e+37*cos(theta)**31 - 8.79890077741978e+37*cos(theta)**29 + 6.40206759073913e+37*cos(theta)**27 - 3.52766989693789e+37*cos(theta)**25 + 1.48637776556372e+37*cos(theta)**23 - 4.80272764607433e+36*cos(theta)**21 + 1.18655624197131e+36*cos(theta)**19 - 2.22235615966148e+35*cos(theta)**17 + 3.10946952380619e+34*cos(theta)**15 - 3.17910710807838e+33*cos(theta)**13 + 2.30028158098436e+32*cos(theta)**11 - 1.12458210625902e+31*cos(theta)**9 + 3.46617772477095e+29*cos(theta)**7 - 6.0306323297589e+27*cos(theta)**5 + 4.85558158595725e+25*cos(theta)**3 - 1.1442847413882e+23*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl52_m14(theta, phi):
    return 4.00707854619401e-24*(1.0 - cos(theta)**2)**7*(5.42084672497692e+37*cos(theta)**38 - 3.69985946374639e+38*cos(theta)**36 + 1.15391656542585e+39*cos(theta)**34 - 2.17962017913772e+39*cos(theta)**32 + 2.78631857951626e+39*cos(theta)**30 - 2.55168122545174e+39*cos(theta)**28 + 1.72855824949956e+39*cos(theta)**26 - 8.81917474234471e+38*cos(theta)**24 + 3.41866886079655e+38*cos(theta)**22 - 1.00857280567561e+38*cos(theta)**20 + 2.25445685974548e+37*cos(theta)**18 - 3.77800547142452e+36*cos(theta)**16 + 4.66420428570928e+35*cos(theta)**14 - 4.13283924050189e+34*cos(theta)**12 + 2.53030973908279e+33*cos(theta)**10 - 1.01212389563312e+32*cos(theta)**8 + 2.42632440733966e+30*cos(theta)**6 - 3.01531616487945e+28*cos(theta)**4 + 1.45667447578717e+26*cos(theta)**2 - 1.1442847413882e+23)*cos(14*phi)

#@torch.jit.script
def Yl52_m15(theta, phi):
    return 7.94142897029328e-26*(1.0 - cos(theta)**2)**7.5*(2.05992175549123e+39*cos(theta)**37 - 1.3319494069487e+40*cos(theta)**35 + 3.9233163224479e+40*cos(theta)**33 - 6.97478457324071e+40*cos(theta)**31 + 8.35895573854879e+40*cos(theta)**29 - 7.14470743126486e+40*cos(theta)**27 + 4.49425144869887e+40*cos(theta)**25 - 2.11660193816273e+40*cos(theta)**23 + 7.5210714937524e+39*cos(theta)**21 - 2.01714561135122e+39*cos(theta)**19 + 4.05802234754186e+38*cos(theta)**17 - 6.04480875427923e+37*cos(theta)**15 + 6.52988599999299e+36*cos(theta)**13 - 4.95940708860227e+35*cos(theta)**11 + 2.53030973908279e+34*cos(theta)**9 - 8.09699116506493e+32*cos(theta)**7 + 1.4557946444038e+31*cos(theta)**5 - 1.20612646595178e+29*cos(theta)**3 + 2.91334895157435e+26*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl52_m16(theta, phi):
    return 1.58322754619955e-27*(1.0 - cos(theta)**2)**8*(7.62171049531756e+40*cos(theta)**36 - 4.66182292432045e+41*cos(theta)**34 + 1.29469438640781e+42*cos(theta)**32 - 2.16218321770462e+42*cos(theta)**30 + 2.42409716417915e+42*cos(theta)**28 - 1.92907100644151e+42*cos(theta)**26 + 1.12356286217472e+42*cos(theta)**24 - 4.86818445777428e+41*cos(theta)**22 + 1.579425013688e+41*cos(theta)**20 - 3.83257666156732e+40*cos(theta)**18 + 6.89863799082117e+39*cos(theta)**16 - 9.06721313141884e+38*cos(theta)**14 + 8.48885179999089e+37*cos(theta)**12 - 5.4553477974625e+36*cos(theta)**10 + 2.27727876517451e+35*cos(theta)**8 - 5.66789381554545e+33*cos(theta)**6 + 7.27897322201899e+31*cos(theta)**4 - 3.61837939785534e+29*cos(theta)**2 + 2.91334895157435e+26)*cos(16*phi)

#@torch.jit.script
def Yl52_m17(theta, phi):
    return 3.17663664630203e-29*(1.0 - cos(theta)**2)**8.5*(2.74381577831432e+42*cos(theta)**35 - 1.58501979426895e+43*cos(theta)**33 + 4.14302203650498e+43*cos(theta)**31 - 6.48654965311386e+43*cos(theta)**29 + 6.78747205970162e+43*cos(theta)**27 - 5.01558461674793e+43*cos(theta)**25 + 2.69655086921932e+43*cos(theta)**23 - 1.07100058071034e+43*cos(theta)**21 + 3.15885002737601e+42*cos(theta)**19 - 6.89863799082117e+41*cos(theta)**17 + 1.10378207853139e+41*cos(theta)**15 - 1.26940983839864e+40*cos(theta)**13 + 1.01866221599891e+39*cos(theta)**11 - 5.4553477974625e+37*cos(theta)**9 + 1.82182301213961e+36*cos(theta)**7 - 3.40073628932727e+34*cos(theta)**5 + 2.9115892888076e+32*cos(theta)**3 - 7.23675879571068e+29*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl52_m18(theta, phi):
    return 6.41777518275959e-31*(1.0 - cos(theta)**2)**9*(9.60335522410012e+43*cos(theta)**34 - 5.23056532108754e+44*cos(theta)**32 + 1.28433683131654e+45*cos(theta)**30 - 1.88109939940302e+45*cos(theta)**28 + 1.83261745611944e+45*cos(theta)**26 - 1.25389615418698e+45*cos(theta)**24 + 6.20206699920443e+44*cos(theta)**22 - 2.24910121949172e+44*cos(theta)**20 + 6.00181505201442e+43*cos(theta)**18 - 1.1727684584396e+43*cos(theta)**16 + 1.65567311779708e+42*cos(theta)**14 - 1.65023278991823e+41*cos(theta)**12 + 1.1205284375988e+40*cos(theta)**10 - 4.90981301771625e+38*cos(theta)**8 + 1.27527610849773e+37*cos(theta)**6 - 1.70036814466364e+35*cos(theta)**4 + 8.73476786642279e+32*cos(theta)**2 - 7.23675879571068e+29)*cos(18*phi)

#@torch.jit.script
def Yl52_m19(theta, phi):
    return 1.30621860901373e-32*(1.0 - cos(theta)**2)**9.5*(3.26514077619404e+45*cos(theta)**33 - 1.67378090274801e+46*cos(theta)**31 + 3.85301049394963e+46*cos(theta)**29 - 5.26707831832846e+46*cos(theta)**27 + 4.76480538591054e+46*cos(theta)**25 - 3.00935077004876e+46*cos(theta)**23 + 1.36445473982498e+46*cos(theta)**21 - 4.49820243898344e+45*cos(theta)**19 + 1.08032670936259e+45*cos(theta)**17 - 1.87642953350336e+44*cos(theta)**15 + 2.31794236491591e+43*cos(theta)**13 - 1.98027934790187e+42*cos(theta)**11 + 1.1205284375988e+41*cos(theta)**9 - 3.927850414173e+39*cos(theta)**7 + 7.65165665098636e+37*cos(theta)**5 - 6.80147257865454e+35*cos(theta)**3 + 1.74695357328456e+33*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl52_m20(theta, phi):
    return 2.67973993547416e-34*(1.0 - cos(theta)**2)**10*(1.07749645614403e+47*cos(theta)**32 - 5.18872079851884e+47*cos(theta)**30 + 1.11737304324539e+48*cos(theta)**28 - 1.42211114594868e+48*cos(theta)**26 + 1.19120134647763e+48*cos(theta)**24 - 6.92150677111215e+47*cos(theta)**22 + 2.86535495363245e+47*cos(theta)**20 - 8.54658463406853e+46*cos(theta)**18 + 1.83655540591641e+46*cos(theta)**16 - 2.81464430025504e+45*cos(theta)**14 + 3.01332507439069e+44*cos(theta)**12 - 2.17830728269206e+43*cos(theta)**10 + 1.00847559383892e+42*cos(theta)**8 - 2.7494952899211e+40*cos(theta)**6 + 3.82582832549318e+38*cos(theta)**4 - 2.04044177359636e+36*cos(theta)**2 + 1.74695357328456e+33)*cos(20*phi)

#@torch.jit.script
def Yl52_m21(theta, phi):
    return 5.54442137630337e-36*(1.0 - cos(theta)**2)**10.5*(3.44798865966091e+48*cos(theta)**31 - 1.55661623955565e+49*cos(theta)**29 + 3.1286445210871e+49*cos(theta)**27 - 3.69748897946658e+49*cos(theta)**25 + 2.85888323154632e+49*cos(theta)**23 - 1.52273148964467e+49*cos(theta)**21 + 5.7307099072649e+48*cos(theta)**19 - 1.53838523413234e+48*cos(theta)**17 + 2.93848864946626e+47*cos(theta)**15 - 3.94050202035705e+46*cos(theta)**13 + 3.61599008926882e+45*cos(theta)**11 - 2.17830728269206e+44*cos(theta)**9 + 8.06780475071134e+42*cos(theta)**7 - 1.64969717395266e+41*cos(theta)**5 + 1.53033133019727e+39*cos(theta)**3 - 4.08088354719273e+36*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl52_m22(theta, phi):
    return 1.15760267711549e-37*(1.0 - cos(theta)**2)**11*(1.06887648449488e+50*cos(theta)**30 - 4.51418709471139e+50*cos(theta)**28 + 8.44734020693518e+50*cos(theta)**26 - 9.24372244866644e+50*cos(theta)**24 + 6.57543143255654e+50*cos(theta)**22 - 3.19773612825381e+50*cos(theta)**20 + 1.08883488238033e+50*cos(theta)**18 - 2.61525489802497e+49*cos(theta)**16 + 4.40773297419939e+48*cos(theta)**14 - 5.12265262646417e+47*cos(theta)**12 + 3.97758909819571e+46*cos(theta)**10 - 1.96047655442286e+45*cos(theta)**8 + 5.64746332549794e+43*cos(theta)**6 - 8.2484858697633e+41*cos(theta)**4 + 4.59099399059182e+39*cos(theta)**2 - 4.08088354719273e+36)*cos(22*phi)

#@torch.jit.script
def Yl52_m23(theta, phi):
    return 2.44044072346227e-39*(1.0 - cos(theta)**2)**11.5*(3.20662945348464e+51*cos(theta)**29 - 1.26397238651919e+52*cos(theta)**27 + 2.19630845380315e+52*cos(theta)**25 - 2.21849338767995e+52*cos(theta)**23 + 1.44659491516244e+52*cos(theta)**21 - 6.39547225650763e+51*cos(theta)**19 + 1.95990278828459e+51*cos(theta)**17 - 4.18440783683995e+50*cos(theta)**15 + 6.17082616387914e+49*cos(theta)**13 - 6.147183151757e+48*cos(theta)**11 + 3.97758909819571e+47*cos(theta)**9 - 1.56838124353828e+46*cos(theta)**7 + 3.38847799529876e+44*cos(theta)**5 - 3.29939434790532e+42*cos(theta)**3 + 9.18198798118364e+39*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl52_m24(theta, phi):
    return 5.19831351121283e-41*(1.0 - cos(theta)**2)**12*(9.29922541510547e+52*cos(theta)**28 - 3.41272544360181e+53*cos(theta)**26 + 5.49077113450787e+53*cos(theta)**24 - 5.10253479166388e+53*cos(theta)**22 + 3.03784932184112e+53*cos(theta)**20 - 1.21513972873645e+53*cos(theta)**18 + 3.33183474008381e+52*cos(theta)**16 - 6.27661175525993e+51*cos(theta)**14 + 8.02207401304289e+50*cos(theta)**12 - 6.7619014669327e+49*cos(theta)**10 + 3.57983018837613e+48*cos(theta)**8 - 1.0978668704768e+47*cos(theta)**6 + 1.69423899764938e+45*cos(theta)**4 - 9.89818304371596e+42*cos(theta)**2 + 9.18198798118364e+39)*cos(24*phi)

#@torch.jit.script
def Yl52_m25(theta, phi):
    return 1.11953606878753e-42*(1.0 - cos(theta)**2)**12.5*(2.60378311622953e+54*cos(theta)**27 - 8.87308615336471e+54*cos(theta)**25 + 1.31778507228189e+55*cos(theta)**23 - 1.12255765416605e+55*cos(theta)**21 + 6.07569864368224e+54*cos(theta)**19 - 2.18725151172561e+54*cos(theta)**17 + 5.3309355841341e+53*cos(theta)**15 - 8.7872564573639e+52*cos(theta)**13 + 9.62648881565146e+51*cos(theta)**11 - 6.7619014669327e+50*cos(theta)**9 + 2.86386415070091e+49*cos(theta)**7 - 6.5872012228608e+47*cos(theta)**5 + 6.77695599059753e+45*cos(theta)**3 - 1.97963660874319e+43*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl52_m26(theta, phi):
    return 2.43954541064895e-44*(1.0 - cos(theta)**2)**13*(7.03021441381973e+55*cos(theta)**26 - 2.21827153834118e+56*cos(theta)**24 + 3.03090566624834e+56*cos(theta)**22 - 2.35737107374871e+56*cos(theta)**20 + 1.15438274229963e+56*cos(theta)**18 - 3.71832756993353e+55*cos(theta)**16 + 7.99640337620115e+54*cos(theta)**14 - 1.14234333945731e+54*cos(theta)**12 + 1.05891376972166e+53*cos(theta)**10 - 6.08571132023943e+51*cos(theta)**8 + 2.00470490549064e+50*cos(theta)**6 - 3.2936006114304e+48*cos(theta)**4 + 2.03308679717926e+46*cos(theta)**2 - 1.97963660874319e+43)*cos(26*phi)

#@torch.jit.script
def Yl52_m27(theta, phi):
    return 5.38280549420141e-46*(1.0 - cos(theta)**2)**13.5*(1.82785574759313e+57*cos(theta)**25 - 5.32385169201883e+57*cos(theta)**23 + 6.66799246574635e+57*cos(theta)**21 - 4.71474214749742e+57*cos(theta)**19 + 2.07788893613933e+57*cos(theta)**17 - 5.94932411189365e+56*cos(theta)**15 + 1.11949647266816e+56*cos(theta)**13 - 1.37081200734877e+55*cos(theta)**11 + 1.05891376972166e+54*cos(theta)**9 - 4.86856905619154e+52*cos(theta)**7 + 1.20282294329438e+51*cos(theta)**5 - 1.31744024457216e+49*cos(theta)**3 + 4.06617359435852e+46*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl52_m28(theta, phi):
    return 1.20363189946937e-47*(1.0 - cos(theta)**2)**14*(4.56963936898283e+58*cos(theta)**24 - 1.22448588916433e+59*cos(theta)**22 + 1.40027841780673e+59*cos(theta)**20 - 8.9580100802451e+58*cos(theta)**18 + 3.53241119143686e+58*cos(theta)**16 - 8.92398616784048e+57*cos(theta)**14 + 1.45534541446861e+57*cos(theta)**12 - 1.50789320808364e+56*cos(theta)**10 + 9.53022392749495e+54*cos(theta)**8 - 3.40799833933408e+53*cos(theta)**6 + 6.01411471647191e+51*cos(theta)**4 - 3.95232073371648e+49*cos(theta)**2 + 4.06617359435852e+46)*cos(28*phi)

#@torch.jit.script
def Yl52_m29(theta, phi):
    return 2.72989258503413e-49*(1.0 - cos(theta)**2)**14.5*(1.09671344855588e+60*cos(theta)**23 - 2.69386895616153e+60*cos(theta)**21 + 2.80055683561347e+60*cos(theta)**19 - 1.61244181444412e+60*cos(theta)**17 + 5.65185790629897e+59*cos(theta)**15 - 1.24935806349767e+59*cos(theta)**13 + 1.74641449736233e+58*cos(theta)**11 - 1.50789320808365e+57*cos(theta)**9 + 7.62417914199596e+55*cos(theta)**7 - 2.04479900360045e+54*cos(theta)**5 + 2.40564588658876e+52*cos(theta)**3 - 7.90464146743296e+49*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl52_m30(theta, phi):
    return 6.28600489237972e-51*(1.0 - cos(theta)**2)**15*(2.52244093167852e+61*cos(theta)**22 - 5.65712480793921e+61*cos(theta)**20 + 5.32105798766559e+61*cos(theta)**18 - 2.741151084555e+61*cos(theta)**16 + 8.47778685944846e+60*cos(theta)**14 - 1.62416548254697e+60*cos(theta)**12 + 1.92105594709856e+59*cos(theta)**10 - 1.35710388727528e+58*cos(theta)**8 + 5.33692539939717e+56*cos(theta)**6 - 1.02239950180022e+55*cos(theta)**4 + 7.21693765976629e+52*cos(theta)**2 - 7.90464146743296e+49)*cos(30*phi)

#@torch.jit.script
def Yl52_m31(theta, phi):
    return 1.4710394784483e-52*(1.0 - cos(theta)**2)**15.5*(5.54937004969274e+62*cos(theta)**21 - 1.13142496158784e+63*cos(theta)**19 + 9.57790437779806e+62*cos(theta)**17 - 4.385841735288e+62*cos(theta)**15 + 1.18689016032278e+62*cos(theta)**13 - 1.94899857905636e+61*cos(theta)**11 + 1.92105594709856e+60*cos(theta)**9 - 1.08568310982022e+59*cos(theta)**7 + 3.2021552396383e+57*cos(theta)**5 - 4.0895980072009e+55*cos(theta)**3 + 1.44338753195326e+53*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl52_m32(theta, phi):
    return 3.50247494868642e-54*(1.0 - cos(theta)**2)**16*(1.16536771043548e+64*cos(theta)**20 - 2.1497074270169e+64*cos(theta)**18 + 1.62824374422567e+64*cos(theta)**16 - 6.578762602932e+63*cos(theta)**14 + 1.54295720841962e+63*cos(theta)**12 - 2.143898436962e+62*cos(theta)**10 + 1.72895035238871e+61*cos(theta)**8 - 7.59978176874157e+59*cos(theta)**6 + 1.60107761981915e+58*cos(theta)**4 - 1.22687940216027e+56*cos(theta)**2 + 1.44338753195326e+53)*cos(32*phi)

#@torch.jit.script
def Yl52_m33(theta, phi):
    return 8.49474950853759e-56*(1.0 - cos(theta)**2)**16.5*(2.33073542087095e+65*cos(theta)**19 - 3.86947336863042e+65*cos(theta)**17 + 2.60518999076107e+65*cos(theta)**15 - 9.2102676441048e+64*cos(theta)**13 + 1.85154865010354e+64*cos(theta)**11 - 2.143898436962e+63*cos(theta)**9 + 1.38316028191097e+62*cos(theta)**7 - 4.55986906124494e+60*cos(theta)**5 + 6.4043104792766e+58*cos(theta)**3 - 2.45375880432054e+56*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl52_m34(theta, phi):
    return 2.10147656332241e-57*(1.0 - cos(theta)**2)**17*(4.42839729965481e+66*cos(theta)**18 - 6.57810472667171e+66*cos(theta)**16 + 3.90778498614161e+66*cos(theta)**14 - 1.19733479373362e+66*cos(theta)**12 + 2.0367035151139e+65*cos(theta)**10 - 1.9295085932658e+64*cos(theta)**8 + 9.68212197337676e+62*cos(theta)**6 - 2.27993453062247e+61*cos(theta)**4 + 1.92129314378298e+59*cos(theta)**2 - 2.45375880432054e+56)*cos(34*phi)

#@torch.jit.script
def Yl52_m35(theta, phi):
    return 5.31041757093879e-59*(1.0 - cos(theta)**2)**17.5*(7.97111513937866e+67*cos(theta)**17 - 1.05249675626747e+68*cos(theta)**15 + 5.47089898059825e+67*cos(theta)**13 - 1.43680175248035e+67*cos(theta)**11 + 2.0367035151139e+66*cos(theta)**9 - 1.54360687461264e+65*cos(theta)**7 + 5.80927318402606e+63*cos(theta)**5 - 9.11973812248989e+61*cos(theta)**3 + 3.84258628756596e+59*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl52_m36(theta, phi):
    return 1.37297577733285e-60*(1.0 - cos(theta)**2)**18*(1.35508957369437e+69*cos(theta)**16 - 1.57874513440121e+69*cos(theta)**14 + 7.11216867477773e+68*cos(theta)**12 - 1.58048192772838e+68*cos(theta)**10 + 1.83303316360251e+67*cos(theta)**8 - 1.08052481222885e+66*cos(theta)**6 + 2.90463659201303e+64*cos(theta)**4 - 2.73592143674697e+62*cos(theta)**2 + 3.84258628756596e+59)*cos(36*phi)

#@torch.jit.script
def Yl52_m37(theta, phi):
    return 3.63837853318226e-62*(1.0 - cos(theta)**2)**18.5*(2.168143317911e+70*cos(theta)**15 - 2.21024318816169e+70*cos(theta)**13 + 8.53460240973327e+69*cos(theta)**11 - 1.58048192772838e+69*cos(theta)**9 + 1.46642653088201e+68*cos(theta)**7 - 6.48314887337308e+66*cos(theta)**5 + 1.16185463680521e+65*cos(theta)**3 - 5.47184287349393e+62*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl52_m38(theta, phi):
    return 9.90241210821384e-64*(1.0 - cos(theta)**2)**19*(3.25221497686649e+71*cos(theta)**14 - 2.8733161446102e+71*cos(theta)**12 + 9.3880626507066e+70*cos(theta)**10 - 1.42243373495555e+70*cos(theta)**8 + 1.0264985716174e+69*cos(theta)**6 - 3.24157443668654e+67*cos(theta)**4 + 3.48556391041563e+65*cos(theta)**2 - 5.47184287349393e+62)*cos(38*phi)

#@torch.jit.script
def Yl52_m39(theta, phi):
    return 2.77431827315494e-65*(1.0 - cos(theta)**2)**19.5*(4.55310096761309e+72*cos(theta)**13 - 3.44797937353224e+72*cos(theta)**11 + 9.3880626507066e+71*cos(theta)**9 - 1.13794698796444e+71*cos(theta)**7 + 6.15899142970443e+69*cos(theta)**5 - 1.29662977467462e+68*cos(theta)**3 + 6.97112782083127e+65*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl52_m40(theta, phi):
    return 8.02214841696147e-67*(1.0 - cos(theta)**2)**20*(5.91903125789702e+73*cos(theta)**12 - 3.79277731088547e+73*cos(theta)**10 + 8.44925638563594e+72*cos(theta)**8 - 7.96562891575106e+71*cos(theta)**6 + 3.07949571485221e+70*cos(theta)**4 - 3.88988932402385e+68*cos(theta)**2 + 6.97112782083127e+65)*cos(40*phi)

#@torch.jit.script
def Yl52_m41(theta, phi):
    return 2.4013673155533e-68*(1.0 - cos(theta)**2)**20.5*(7.10283750947642e+74*cos(theta)**11 - 3.79277731088547e+74*cos(theta)**9 + 6.75940510850875e+73*cos(theta)**7 - 4.77937734945063e+72*cos(theta)**5 + 1.23179828594088e+71*cos(theta)**3 - 7.77977864804769e+68*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl52_m42(theta, phi):
    return 7.46789711195431e-70*(1.0 - cos(theta)**2)**21*(7.81312126042406e+75*cos(theta)**10 - 3.41349957979692e+75*cos(theta)**8 + 4.73158357595613e+74*cos(theta)**6 - 2.38968867472532e+73*cos(theta)**4 + 3.69539485782266e+71*cos(theta)**2 - 7.77977864804769e+68)*cos(42*phi)

#@torch.jit.script
def Yl52_m43(theta, phi):
    return 2.42290576471909e-71*(1.0 - cos(theta)**2)**21.5*(7.81312126042406e+76*cos(theta)**9 - 2.73079966383754e+76*cos(theta)**7 + 2.83895014557368e+75*cos(theta)**5 - 9.55875469890127e+73*cos(theta)**3 + 7.39078971564531e+71*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl52_m44(theta, phi):
    return 8.24289280334673e-73*(1.0 - cos(theta)**2)**22*(7.03180913438166e+77*cos(theta)**8 - 1.91155976468628e+77*cos(theta)**6 + 1.41947507278684e+76*cos(theta)**4 - 2.86762640967038e+74*cos(theta)**2 + 7.39078971564531e+71)*cos(44*phi)

#@torch.jit.script
def Yl52_m45(theta, phi):
    return 2.95902606938711e-74*(1.0 - cos(theta)**2)**22.5*(5.62544730750532e+78*cos(theta)**7 - 1.14693585881177e+78*cos(theta)**5 + 5.67790029114735e+76*cos(theta)**3 - 5.73525281934076e+74*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl52_m46(theta, phi):
    return 1.12976140307948e-75*(1.0 - cos(theta)**2)**23*(3.93781311525373e+79*cos(theta)**6 - 5.73467929405883e+78*cos(theta)**4 + 1.70337008734421e+77*cos(theta)**2 - 5.73525281934076e+74)*cos(46*phi)

#@torch.jit.script
def Yl52_m47(theta, phi):
    return 4.63546718519856e-77*(1.0 - cos(theta)**2)**23.5*(2.36268786915224e+80*cos(theta)**5 - 2.29387171762353e+79*cos(theta)**3 + 3.40674017468841e+77*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl52_m48(theta, phi):
    return 2.07304394671472e-78*(1.0 - cos(theta)**2)**24*(1.18134393457612e+81*cos(theta)**4 - 6.88161515287059e+79*cos(theta)**2 + 3.40674017468841e+77)*cos(48*phi)

#@torch.jit.script
def Yl52_m49(theta, phi):
    return 1.03137791196042e-79*(1.0 - cos(theta)**2)**24.5*(4.72537573830447e+81*cos(theta)**3 - 1.37632303057412e+80*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl52_m50(theta, phi):
    return 5.89599508828156e-81*(1.0 - cos(theta)**2)**25*(1.41761272149134e+82*cos(theta)**2 - 1.37632303057412e+80)*cos(50*phi)

#@torch.jit.script
def Yl52_m51(theta, phi):
    return 11.6469202143439*(1.0 - cos(theta)**2)**25.5*cos(51*phi)*cos(theta)

#@torch.jit.script
def Yl52_m52(theta, phi):
    return 1.14207448934996*(1.0 - cos(theta)**2)**26*cos(52*phi)

#@torch.jit.script
def Yl53_m_minus_53(theta, phi):
    return 1.14744898722045*(1.0 - cos(theta)**2)**26.5*sin(53*phi)

#@torch.jit.script
def Yl53_m_minus_52(theta, phi):
    return 11.8137103780719*(1.0 - cos(theta)**2)**26*sin(52*phi)*cos(theta)

#@torch.jit.script
def Yl53_m_minus_51(theta, phi):
    return 5.75067826096859e-83*(1.0 - cos(theta)**2)**25.5*(1.48849335756591e+84*cos(theta)**2 - 1.41761272149134e+82)*sin(51*phi)

#@torch.jit.script
def Yl53_m_minus_50(theta, phi):
    return 1.01577230440129e-81*(1.0 - cos(theta)**2)**25*(4.9616445252197e+83*cos(theta)**3 - 1.41761272149134e+82*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl53_m_minus_49(theta, phi):
    return 2.06179259443851e-80*(1.0 - cos(theta)**2)**24.5*(1.24041113130492e+83*cos(theta)**4 - 7.08806360745671e+81*cos(theta)**2 + 3.4408075764353e+79)*sin(49*phi)

#@torch.jit.script
def Yl53_m_minus_48(theta, phi):
    return 4.65618324195425e-79*(1.0 - cos(theta)**2)**24*(2.48082226260985e+82*cos(theta)**5 - 2.36268786915224e+81*cos(theta)**3 + 3.4408075764353e+79*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl53_m_minus_47(theta, phi):
    return 1.1462157599636e-77*(1.0 - cos(theta)**2)**23.5*(4.13470377101641e+81*cos(theta)**6 - 5.90671967288059e+80*cos(theta)**4 + 1.72040378821765e+79*cos(theta)**2 - 5.67790029114735e+76)*sin(47*phi)

#@torch.jit.script
def Yl53_m_minus_46(theta, phi):
    return 3.03260184968659e-76*(1.0 - cos(theta)**2)**23*(5.90671967288059e+80*cos(theta)**7 - 1.18134393457612e+80*cos(theta)**5 + 5.73467929405883e+78*cos(theta)**3 - 5.67790029114735e+76*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl53_m_minus_45(theta, phi):
    return 8.5344981054238e-75*(1.0 - cos(theta)**2)**22.5*(7.38339959110074e+79*cos(theta)**8 - 1.96890655762686e+79*cos(theta)**6 + 1.43366982351471e+78*cos(theta)**4 - 2.83895014557368e+76*cos(theta)**2 + 7.16906602417595e+73)*sin(45*phi)

#@torch.jit.script
def Yl53_m_minus_44(theta, phi):
    return 2.53461662343494e-73*(1.0 - cos(theta)**2)**22*(8.20377732344527e+78*cos(theta)**9 - 2.81272365375266e+78*cos(theta)**7 + 2.86733964702941e+77*cos(theta)**5 - 9.46316715191225e+75*cos(theta)**3 + 7.16906602417595e+73*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl53_m_minus_43(theta, phi):
    return 7.89401861218921e-72*(1.0 - cos(theta)**2)**21.5*(8.20377732344527e+77*cos(theta)**10 - 3.51590456719083e+77*cos(theta)**8 + 4.77889941171569e+76*cos(theta)**6 - 2.36579178797806e+75*cos(theta)**4 + 3.58453301208798e+73*cos(theta)**2 - 7.39078971564531e+70)*sin(43*phi)

#@torch.jit.script
def Yl53_m_minus_42(theta, phi):
    return 2.56525241489345e-70*(1.0 - cos(theta)**2)**21*(7.45797938495024e+76*cos(theta)**11 - 3.90656063021203e+76*cos(theta)**9 + 6.82699915959384e+75*cos(theta)**7 - 4.73158357595613e+74*cos(theta)**5 + 1.19484433736266e+73*cos(theta)**3 - 7.39078971564531e+70*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl53_m_minus_41(theta, phi):
    return 8.66128901804633e-69*(1.0 - cos(theta)**2)**20.5*(6.21498282079187e+75*cos(theta)**12 - 3.90656063021203e+75*cos(theta)**10 + 8.5337489494923e+74*cos(theta)**8 - 7.88597262659355e+73*cos(theta)**6 + 2.98711084340665e+72*cos(theta)**4 - 3.69539485782266e+70*cos(theta)**2 + 6.48314887337308e+67)*sin(41*phi)

#@torch.jit.script
def Yl53_m_minus_40(theta, phi):
    return 3.02773689987996e-67*(1.0 - cos(theta)**2)**20*(4.78075601599374e+74*cos(theta)**13 - 3.55141875473821e+74*cos(theta)**11 + 9.48194327721367e+73*cos(theta)**9 - 1.12656751808479e+73*cos(theta)**7 + 5.97422168681329e+71*cos(theta)**5 - 1.23179828594089e+70*cos(theta)**3 + 6.48314887337308e+67*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl53_m_minus_39(theta, phi):
    return 1.09250548450948e-65*(1.0 - cos(theta)**2)**19.5*(3.41482572570982e+73*cos(theta)**14 - 2.95951562894851e+73*cos(theta)**12 + 9.48194327721367e+72*cos(theta)**10 - 1.40820939760599e+72*cos(theta)**8 + 9.95703614468882e+70*cos(theta)**6 - 3.07949571485221e+69*cos(theta)**4 + 3.24157443668654e+67*cos(theta)**2 - 4.97937701487948e+64)*sin(39*phi)

#@torch.jit.script
def Yl53_m_minus_38(theta, phi):
    return 4.05847774723841e-64*(1.0 - cos(theta)**2)**19*(2.27655048380654e+72*cos(theta)**15 - 2.27655048380654e+72*cos(theta)**13 + 8.61994843383061e+71*cos(theta)**11 - 1.5646771084511e+71*cos(theta)**9 + 1.42243373495555e+70*cos(theta)**7 - 6.15899142970443e+68*cos(theta)**5 + 1.08052481222885e+67*cos(theta)**3 - 4.97937701487948e+64*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl53_m_minus_37(theta, phi):
    return 1.54861640846762e-62*(1.0 - cos(theta)**2)**18.5*(1.42284405237909e+71*cos(theta)**16 - 1.62610748843325e+71*cos(theta)**14 + 7.18329036152551e+70*cos(theta)**12 - 1.5646771084511e+70*cos(theta)**10 + 1.77804216869443e+69*cos(theta)**8 - 1.0264985716174e+68*cos(theta)**6 + 2.70131203057212e+66*cos(theta)**4 - 2.48968850743974e+64*cos(theta)**2 + 3.41990179593371e+61)*sin(37*phi)

#@torch.jit.script
def Yl53_m_minus_36(theta, phi):
    return 6.05744628889105e-61*(1.0 - cos(theta)**2)**18*(8.36967089634759e+69*cos(theta)**17 - 1.0840716589555e+70*cos(theta)**15 + 5.52560797040424e+69*cos(theta)**13 - 1.42243373495555e+69*cos(theta)**11 + 1.97560240966048e+68*cos(theta)**9 - 1.46642653088201e+67*cos(theta)**7 + 5.40262406114423e+65*cos(theta)**5 - 8.29896169146579e+63*cos(theta)**3 + 3.41990179593371e+61*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl53_m_minus_35(theta, phi):
    return 2.42449240418619e-59*(1.0 - cos(theta)**2)**17.5*(4.64981716463755e+68*cos(theta)**18 - 6.77544786847186e+68*cos(theta)**16 + 3.94686283600303e+68*cos(theta)**14 - 1.18536144579629e+68*cos(theta)**12 + 1.97560240966048e+67*cos(theta)**10 - 1.83303316360251e+66*cos(theta)**8 + 9.00437343524039e+64*cos(theta)**6 - 2.07474042286645e+63*cos(theta)**4 + 1.70995089796685e+61*cos(theta)**2 - 2.13477015975887e+58)*sin(35*phi)

#@torch.jit.script
def Yl53_m_minus_34(theta, phi):
    return 9.91377286144046e-58*(1.0 - cos(theta)**2)**17*(2.4472721919145e+67*cos(theta)**19 - 3.98555756968933e+67*cos(theta)**17 + 2.63124189066868e+67*cos(theta)**15 - 9.11816496766376e+66*cos(theta)**13 + 1.79600219060044e+66*cos(theta)**11 - 2.0367035151139e+65*cos(theta)**9 + 1.2863390621772e+64*cos(theta)**7 - 4.1494808457329e+62*cos(theta)**5 + 5.69983632655618e+60*cos(theta)**3 - 2.13477015975887e+58*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl53_m_minus_33(theta, phi):
    return 4.13536253170053e-56*(1.0 - cos(theta)**2)**16.5*(1.22363609595725e+66*cos(theta)**20 - 2.21419864982741e+66*cos(theta)**18 + 1.64452618166793e+66*cos(theta)**16 - 6.51297497690268e+65*cos(theta)**14 + 1.49666849216703e+65*cos(theta)**12 - 2.0367035151139e+64*cos(theta)**10 + 1.6079238277215e+63*cos(theta)**8 - 6.91580140955483e+61*cos(theta)**6 + 1.42495908163904e+60*cos(theta)**4 - 1.06738507987943e+58*cos(theta)**2 + 1.22687940216027e+55)*sin(33*phi)

#@torch.jit.script
def Yl53_m_minus_32(theta, phi):
    return 1.75740744345409e-54*(1.0 - cos(theta)**2)**16*(5.82683855217738e+64*cos(theta)**21 - 1.16536771043548e+65*cos(theta)**19 + 9.67368342157604e+64*cos(theta)**17 - 4.34198331793512e+64*cos(theta)**15 + 1.1512834555131e+64*cos(theta)**13 - 1.85154865010354e+63*cos(theta)**11 + 1.78658203080166e+62*cos(theta)**9 - 9.87971629936404e+60*cos(theta)**7 + 2.84991816327809e+59*cos(theta)**5 - 3.55795026626478e+57*cos(theta)**3 + 1.22687940216027e+55*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl53_m_minus_31(theta, phi):
    return 7.59964428425149e-53*(1.0 - cos(theta)**2)**15.5*(2.64856297826245e+63*cos(theta)**22 - 5.82683855217738e+63*cos(theta)**20 + 5.37426856754225e+63*cos(theta)**18 - 2.71373957370945e+63*cos(theta)**16 + 8.223453253665e+62*cos(theta)**14 - 1.54295720841962e+62*cos(theta)**12 + 1.78658203080166e+61*cos(theta)**10 - 1.23496453742051e+60*cos(theta)**8 + 4.74986360546348e+58*cos(theta)**6 - 8.89487566566195e+56*cos(theta)**4 + 6.13439701080135e+54*cos(theta)**2 - 6.56085241796935e+51)*sin(31*phi)

#@torch.jit.script
def Yl53_m_minus_30(theta, phi):
    return 3.34038731517029e-51*(1.0 - cos(theta)**2)**15*(1.15154912098367e+62*cos(theta)**23 - 2.77468502484637e+62*cos(theta)**21 + 2.8285624039696e+62*cos(theta)**19 - 1.59631739629968e+62*cos(theta)**17 + 5.48230216911e+61*cos(theta)**15 - 1.18689016032278e+61*cos(theta)**13 + 1.62416548254697e+60*cos(theta)**11 - 1.37218281935612e+59*cos(theta)**9 + 6.7855194363764e+57*cos(theta)**7 - 1.77897513313239e+56*cos(theta)**5 + 2.04479900360045e+54*cos(theta)**3 - 6.56085241796935e+51*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl53_m_minus_29(theta, phi):
    return 1.49087589461291e-49*(1.0 - cos(theta)**2)**14.5*(4.79812133743197e+60*cos(theta)**24 - 1.26122046583926e+61*cos(theta)**22 + 1.4142812019848e+61*cos(theta)**20 - 8.86842997944265e+60*cos(theta)**18 + 3.42643885569375e+60*cos(theta)**16 - 8.47778685944846e+59*cos(theta)**14 + 1.35347123545581e+59*cos(theta)**12 - 1.37218281935612e+58*cos(theta)**10 + 8.4818992954705e+56*cos(theta)**8 - 2.96495855522065e+55*cos(theta)**6 + 5.11199750900112e+53*cos(theta)**4 - 3.28042620898468e+51*cos(theta)**2 + 3.2936006114304e+48)*sin(29*phi)

#@torch.jit.script
def Yl53_m_minus_28(theta, phi):
    return 6.75022770944253e-48*(1.0 - cos(theta)**2)**14*(1.91924853497279e+59*cos(theta)**25 - 5.48356724277939e+59*cos(theta)**23 + 6.73467239040382e+59*cos(theta)**21 - 4.66759472602245e+59*cos(theta)**19 + 2.01555226805515e+59*cos(theta)**17 - 5.65185790629897e+58*cos(theta)**15 + 1.04113171958139e+58*cos(theta)**13 - 1.24743892668738e+57*cos(theta)**11 + 9.42433255052278e+55*cos(theta)**9 - 4.23565507888664e+54*cos(theta)**7 + 1.02239950180022e+53*cos(theta)**5 - 1.09347540299489e+51*cos(theta)**3 + 3.2936006114304e+48*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl53_m_minus_27(theta, phi):
    return 3.0977588530478e-46*(1.0 - cos(theta)**2)**13.5*(7.38172513451072e+57*cos(theta)**26 - 2.28481968449141e+58*cos(theta)**24 + 3.06121472291083e+58*cos(theta)**22 - 2.33379736301122e+58*cos(theta)**20 + 1.11975126003064e+58*cos(theta)**18 - 3.53241119143686e+57*cos(theta)**16 + 7.43665513986707e+56*cos(theta)**14 - 1.03953243890615e+56*cos(theta)**12 + 9.42433255052278e+54*cos(theta)**10 - 5.2945688486083e+53*cos(theta)**8 + 1.70399916966704e+52*cos(theta)**6 - 2.73368850748723e+50*cos(theta)**4 + 1.6468003057152e+48*cos(theta)**2 - 1.56391292090712e+45)*sin(27*phi)

#@torch.jit.script
def Yl53_m_minus_26(theta, phi):
    return 1.43970821381048e-44*(1.0 - cos(theta)**2)**13*(2.73397227204101e+56*cos(theta)**27 - 9.13927873796566e+56*cos(theta)**25 + 1.33096292300471e+57*cos(theta)**23 - 1.11133207762439e+57*cos(theta)**21 + 5.89342768437178e+56*cos(theta)**19 - 2.07788893613933e+56*cos(theta)**17 + 4.95777009324471e+55*cos(theta)**15 - 7.99640337620115e+54*cos(theta)**13 + 8.5675750459298e+53*cos(theta)**11 - 5.88285427623145e+52*cos(theta)**9 + 2.43428452809577e+51*cos(theta)**7 - 5.46737701497446e+49*cos(theta)**5 + 5.489334352384e+47*cos(theta)**3 - 1.56391292090712e+45*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl53_m_minus_25(theta, phi):
    return 6.77122185938431e-43*(1.0 - cos(theta)**2)**12.5*(9.76418668586074e+54*cos(theta)**28 - 3.51510720690987e+55*cos(theta)**26 + 5.54567884585295e+55*cos(theta)**24 - 5.05150944374724e+55*cos(theta)**22 + 2.94671384218589e+55*cos(theta)**20 - 1.15438274229963e+55*cos(theta)**18 + 3.09860630827794e+54*cos(theta)**16 - 5.71171669728653e+53*cos(theta)**14 + 7.13964587160817e+52*cos(theta)**12 - 5.88285427623145e+51*cos(theta)**10 + 3.04285566011971e+50*cos(theta)**8 - 9.11229502495744e+48*cos(theta)**6 + 1.372333588096e+47*cos(theta)**4 - 7.81956460453561e+44*cos(theta)**2 + 7.0701307455114e+41)*sin(25*phi)

#@torch.jit.script
def Yl53_m_minus_24(theta, phi):
    return 3.22042614650432e-41*(1.0 - cos(theta)**2)**12*(3.36696092615888e+53*cos(theta)**29 - 1.30189155811477e+54*cos(theta)**27 + 2.21827153834118e+54*cos(theta)**25 - 2.19630845380315e+54*cos(theta)**23 + 1.40319706770757e+54*cos(theta)**21 - 6.07569864368224e+53*cos(theta)**19 + 1.82270959310467e+53*cos(theta)**17 - 3.80781113152436e+52*cos(theta)**15 + 5.49203528585244e+51*cos(theta)**13 - 5.34804934202859e+50*cos(theta)**11 + 3.38095073346635e+49*cos(theta)**9 - 1.30175643213678e+48*cos(theta)**7 + 2.744667176192e+46*cos(theta)**5 - 2.6065215348452e+44*cos(theta)**3 + 7.0701307455114e+41*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl53_m_minus_23(theta, phi):
    return 1.54781600797236e-39*(1.0 - cos(theta)**2)**11.5*(1.12232030871963e+52*cos(theta)**30 - 4.64961270755273e+52*cos(theta)**28 + 8.53181360900453e+52*cos(theta)**26 - 9.15128522417978e+52*cos(theta)**24 + 6.37816848957985e+52*cos(theta)**22 - 3.03784932184112e+52*cos(theta)**20 + 1.01261644061371e+52*cos(theta)**18 - 2.37988195720272e+51*cos(theta)**16 + 3.92288234703745e+50*cos(theta)**14 - 4.45670778502382e+49*cos(theta)**12 + 3.38095073346635e+48*cos(theta)**10 - 1.62719554017097e+47*cos(theta)**8 + 4.57444529365333e+45*cos(theta)**6 - 6.51630383711301e+43*cos(theta)**4 + 3.5350653727557e+41*cos(theta)**2 - 3.06066266039455e+38)*sin(23*phi)

#@torch.jit.script
def Yl53_m_minus_22(theta, phi):
    return 7.5128890804574e-38*(1.0 - cos(theta)**2)**11*(3.62038809264395e+50*cos(theta)**31 - 1.60331472674232e+51*cos(theta)**29 + 3.15993096629797e+51*cos(theta)**27 - 3.66051408967191e+51*cos(theta)**25 + 2.77311673459993e+51*cos(theta)**23 - 1.44659491516244e+51*cos(theta)**21 + 5.32956021375635e+50*cos(theta)**19 - 1.39993056306042e+50*cos(theta)**17 + 2.61525489802497e+49*cos(theta)**15 - 3.42823675771063e+48*cos(theta)**13 + 3.0735915758785e+47*cos(theta)**11 - 1.80799504463441e+46*cos(theta)**9 + 6.53492184807619e+44*cos(theta)**7 - 1.3032607674226e+43*cos(theta)**5 + 1.1783551242519e+41*cos(theta)**3 - 3.06066266039455e+38*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl53_m_minus_21(theta, phi):
    return 3.68054894824963e-36*(1.0 - cos(theta)**2)**10.5*(1.13137127895124e+49*cos(theta)**32 - 5.34438242247441e+49*cos(theta)**30 + 1.12854677367785e+50*cos(theta)**28 - 1.4078900344892e+50*cos(theta)**26 + 1.15546530608331e+50*cos(theta)**24 - 6.57543143255654e+49*cos(theta)**22 + 2.66478010687818e+49*cos(theta)**20 - 7.77739201700236e+48*cos(theta)**18 + 1.63453431126561e+48*cos(theta)**16 - 2.44874054122188e+47*cos(theta)**14 + 2.56132631323208e+46*cos(theta)**12 - 1.80799504463441e+45*cos(theta)**10 + 8.16865231009523e+43*cos(theta)**8 - 2.17210127903767e+42*cos(theta)**6 + 2.94588781062975e+40*cos(theta)**4 - 1.53033133019727e+38*cos(theta)**2 + 1.27527610849773e+35)*sin(21*phi)

#@torch.jit.script
def Yl53_m_minus_20(theta, phi):
    return 1.81880201915016e-34*(1.0 - cos(theta)**2)**10*(3.42839781500374e+47*cos(theta)**33 - 1.72399432983045e+48*cos(theta)**31 + 3.89154059888913e+48*cos(theta)**29 - 5.21440753514517e+48*cos(theta)**27 + 4.62186122433322e+48*cos(theta)**25 - 2.85888323154632e+48*cos(theta)**23 + 1.26894290803723e+48*cos(theta)**21 - 4.09336421947493e+47*cos(theta)**19 + 9.61490771332709e+46*cos(theta)**17 - 1.63249369414792e+46*cos(theta)**15 + 1.97025101017853e+45*cos(theta)**13 - 1.64363185875856e+44*cos(theta)**11 + 9.07628034455026e+42*cos(theta)**9 - 3.10300182719667e+41*cos(theta)**7 + 5.8917756212595e+39*cos(theta)**5 - 5.10110443399091e+37*cos(theta)**3 + 1.27527610849773e+35*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl53_m_minus_19(theta, phi):
    return 9.0612125171161e-33*(1.0 - cos(theta)**2)**9.5*(1.00835229853051e+46*cos(theta)**34 - 5.38748228072017e+46*cos(theta)**32 + 1.29718019962971e+47*cos(theta)**30 - 1.86228840540899e+47*cos(theta)**28 + 1.77763893243585e+47*cos(theta)**26 - 1.19120134647763e+47*cos(theta)**24 + 5.76792230926012e+46*cos(theta)**22 - 2.04668210973746e+46*cos(theta)**20 + 5.34161539629283e+45*cos(theta)**18 - 1.02030855884245e+45*cos(theta)**16 + 1.40732215012752e+44*cos(theta)**14 - 1.36969321563213e+43*cos(theta)**12 + 9.07628034455026e+41*cos(theta)**10 - 3.87875228399584e+40*cos(theta)**8 + 9.8196260354325e+38*cos(theta)**6 - 1.27527610849773e+37*cos(theta)**4 + 6.37638054248864e+34*cos(theta)**2 - 5.13809874495458e+31)*sin(19*phi)

#@torch.jit.script
def Yl53_m_minus_18(theta, phi):
    return 4.54869258300075e-31*(1.0 - cos(theta)**2)**9*(2.88100656723004e+44*cos(theta)**35 - 1.63257038809702e+45*cos(theta)**33 + 4.18445225687003e+45*cos(theta)**31 - 6.42168415658272e+45*cos(theta)**29 + 6.58384789791057e+45*cos(theta)**27 - 4.76480538591054e+45*cos(theta)**25 + 2.50779230837397e+45*cos(theta)**23 - 9.74610528446411e+44*cos(theta)**21 + 2.81137652436465e+44*cos(theta)**19 - 6.00181505201442e+43*cos(theta)**17 + 9.38214766751679e+42*cos(theta)**15 - 1.05361016587087e+42*cos(theta)**13 + 8.25116394959114e+40*cos(theta)**11 - 4.30972475999538e+39*cos(theta)**9 + 1.4028037193475e+38*cos(theta)**7 - 2.55055221699545e+36*cos(theta)**5 + 2.12546018082955e+34*cos(theta)**3 - 5.13809874495458e+31*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl53_m_minus_17(theta, phi):
    return 2.29967789859005e-29*(1.0 - cos(theta)**2)**8.5*(8.00279602008343e+42*cos(theta)**36 - 4.80167761205006e+43*cos(theta)**34 + 1.30764133027189e+44*cos(theta)**32 - 2.14056138552757e+44*cos(theta)**30 + 2.35137424925378e+44*cos(theta)**28 - 1.83261745611944e+44*cos(theta)**26 + 1.04491346182249e+44*cos(theta)**24 - 4.4300478565746e+43*cos(theta)**22 + 1.40568826218232e+43*cos(theta)**20 - 3.33434169556356e+42*cos(theta)**18 + 5.86384229219799e+41*cos(theta)**16 - 7.52578689907764e+40*cos(theta)**14 + 6.87596995799262e+39*cos(theta)**12 - 4.30972475999537e+38*cos(theta)**10 + 1.75350464918438e+37*cos(theta)**8 - 4.25092036165909e+35*cos(theta)**6 + 5.31365045207386e+33*cos(theta)**4 - 2.56904937247729e+31*cos(theta)**2 + 2.0102107765863e+28)*sin(17*phi)

#@torch.jit.script
def Yl53_m_minus_16(theta, phi):
    return 1.17035305581318e-27*(1.0 - cos(theta)**2)**8*(2.16291784326579e+41*cos(theta)**37 - 1.37190788915716e+42*cos(theta)**35 + 3.96254948567238e+42*cos(theta)**33 - 6.90503672750831e+42*cos(theta)**31 + 8.10818706639233e+42*cos(theta)**29 - 6.78747205970162e+42*cos(theta)**27 + 4.17965384728995e+42*cos(theta)**25 - 1.92610776372809e+42*cos(theta)**23 + 6.69375362943964e+41*cos(theta)**21 - 1.75491668187556e+41*cos(theta)**19 + 3.44931899541058e+40*cos(theta)**17 - 5.01719126605176e+39*cos(theta)**15 + 5.28920765999432e+38*cos(theta)**13 - 3.9179315999958e+37*cos(theta)**11 + 1.94833849909375e+36*cos(theta)**9 - 6.0727433737987e+34*cos(theta)**7 + 1.06273009041477e+33*cos(theta)**5 - 8.56349790825764e+30*cos(theta)**3 + 2.0102107765863e+28*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl53_m_minus_15(theta, phi):
    return 5.99284764841289e-26*(1.0 - cos(theta)**2)**7.5*(5.69188906122577e+39*cos(theta)**38 - 3.81085524765878e+40*cos(theta)**36 + 1.16545573108011e+41*cos(theta)**34 - 2.15782397734635e+41*cos(theta)**32 + 2.70272902213078e+41*cos(theta)**30 - 2.42409716417915e+41*cos(theta)**28 + 1.60755917203459e+41*cos(theta)**26 - 8.02544901553369e+40*cos(theta)**24 + 3.04261528610893e+40*cos(theta)**22 - 8.7745834093778e+39*cos(theta)**20 + 1.91628833078366e+39*cos(theta)**18 - 3.13574454128235e+38*cos(theta)**16 + 3.77800547142452e+37*cos(theta)**14 - 3.2649429999965e+36*cos(theta)**12 + 1.94833849909375e+35*cos(theta)**10 - 7.59092921724838e+33*cos(theta)**8 + 1.77121681735795e+32*cos(theta)**6 - 2.14087447706441e+30*cos(theta)**4 + 1.00510538829315e+28*cos(theta)**2 - 7.66670776730091e+24)*sin(15*phi)

#@torch.jit.script
def Yl53_m_minus_14(theta, phi):
    return 3.08617107803759e-24*(1.0 - cos(theta)**2)**7*(1.45945873364763e+38*cos(theta)**39 - 1.02996087774562e+39*cos(theta)**37 + 3.32987351737175e+39*cos(theta)**35 - 6.53886053741317e+39*cos(theta)**33 + 8.71848071655089e+39*cos(theta)**31 - 8.35895573854879e+39*cos(theta)**29 + 5.95392285938739e+39*cos(theta)**27 - 3.21017960621348e+39*cos(theta)**25 + 1.32287621135171e+39*cos(theta)**23 - 4.17837305208467e+38*cos(theta)**21 + 1.00857280567561e+38*cos(theta)**19 - 1.84455561251903e+37*cos(theta)**17 + 2.51867031428301e+36*cos(theta)**15 - 2.51149461538192e+35*cos(theta)**13 + 1.77121681735795e+34*cos(theta)**11 - 8.43436579694264e+32*cos(theta)**9 + 2.53030973908279e+31*cos(theta)**7 - 4.28174895412882e+29*cos(theta)**5 + 3.3503512943105e+27*cos(theta)**3 - 7.66670776730091e+24*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl53_m_minus_13(theta, phi):
    return 1.59767115369259e-22*(1.0 - cos(theta)**2)**6.5*(3.64864683411908e+36*cos(theta)**40 - 2.71042336248846e+37*cos(theta)**38 + 9.24964865936597e+37*cos(theta)**36 - 1.92319427570976e+38*cos(theta)**34 + 2.72452522392215e+38*cos(theta)**32 - 2.78631857951626e+38*cos(theta)**30 + 2.12640102120978e+38*cos(theta)**28 - 1.23468446392826e+38*cos(theta)**26 + 5.51198421396545e+37*cos(theta)**24 - 1.8992604782203e+37*cos(theta)**22 + 5.04286402837805e+36*cos(theta)**20 - 1.02475311806613e+36*cos(theta)**18 + 1.57416894642688e+35*cos(theta)**16 - 1.7939247252728e+34*cos(theta)**14 + 1.47601401446496e+33*cos(theta)**12 - 8.43436579694264e+31*cos(theta)**10 + 3.16288717385349e+30*cos(theta)**8 - 7.13624825688136e+28*cos(theta)**6 + 8.37587823577625e+26*cos(theta)**4 - 3.83335388365046e+24*cos(theta)**2 + 2.86071185347049e+21)*sin(13*phi)

#@torch.jit.script
def Yl53_m_minus_12(theta, phi):
    return 8.31096187580827e-21*(1.0 - cos(theta)**2)**6*(8.89913861980265e+34*cos(theta)**41 - 6.94980349356016e+35*cos(theta)**39 + 2.49990504307188e+36*cos(theta)**37 - 5.49484078774216e+36*cos(theta)**35 + 8.25613704218834e+36*cos(theta)**33 - 8.98812445005247e+36*cos(theta)**31 + 7.33241731451649e+36*cos(theta)**29 - 4.57290542195652e+36*cos(theta)**27 + 2.20479368558618e+36*cos(theta)**25 - 8.25765425313175e+35*cos(theta)**23 + 2.40136382303717e+35*cos(theta)**21 - 5.39343746350593e+34*cos(theta)**19 + 9.25981733192284e+33*cos(theta)**17 - 1.19594981684853e+33*cos(theta)**15 + 1.13539539574228e+32*cos(theta)**13 - 7.66760526994786e+30*cos(theta)**11 + 3.51431908205943e+29*cos(theta)**9 - 1.01946403669734e+28*cos(theta)**7 + 1.67517564715525e+26*cos(theta)**5 - 1.27778462788349e+24*cos(theta)**3 + 2.86071185347049e+21*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl53_m_minus_11(theta, phi):
    return 4.34242787311555e-19*(1.0 - cos(theta)**2)**5.5*(2.11884252852444e+33*cos(theta)**42 - 1.73745087339004e+34*cos(theta)**40 + 6.57869748176811e+34*cos(theta)**38 - 1.52634466326171e+35*cos(theta)**36 + 2.42827560064363e+35*cos(theta)**34 - 2.8087888906414e+35*cos(theta)**32 + 2.44413910483883e+35*cos(theta)**30 - 1.63318050784161e+35*cos(theta)**28 + 8.47997571379299e+34*cos(theta)**26 - 3.44068927213823e+34*cos(theta)**24 + 1.09152901047144e+34*cos(theta)**22 - 2.69671873175297e+33*cos(theta)**20 + 5.14434296217935e+32*cos(theta)**18 - 7.47468635530333e+31*cos(theta)**16 + 8.10996711244485e+30*cos(theta)**14 - 6.38967105828988e+29*cos(theta)**12 + 3.51431908205943e+28*cos(theta)**10 - 1.27433004587167e+27*cos(theta)**8 + 2.79195941192542e+25*cos(theta)**6 - 3.19446156970871e+23*cos(theta)**4 + 1.43035592673525e+21*cos(theta)**2 - 1.04787979980604e+18)*sin(11*phi)

#@torch.jit.script
def Yl53_m_minus_10(theta, phi):
    return 2.27801630593366e-17*(1.0 - cos(theta)**2)**5*(4.92754076401032e+31*cos(theta)**43 - 4.23768505704888e+32*cos(theta)**41 + 1.68684550814567e+33*cos(theta)**39 - 4.12525584665327e+33*cos(theta)**37 + 6.93793028755323e+33*cos(theta)**35 - 8.51148148679211e+33*cos(theta)**33 + 7.88431969302848e+33*cos(theta)**31 - 5.63165692359177e+33*cos(theta)**29 + 3.14073174584926e+33*cos(theta)**27 - 1.37627570885529e+33*cos(theta)**25 + 4.74577830639756e+32*cos(theta)**23 - 1.28415177702522e+32*cos(theta)**21 + 2.70754892746282e+31*cos(theta)**19 - 4.39687432664902e+30*cos(theta)**17 + 5.4066447416299e+29*cos(theta)**15 - 4.91513158329991e+28*cos(theta)**13 + 3.19483552914494e+27*cos(theta)**11 - 1.41592227319075e+26*cos(theta)**9 + 3.98851344560774e+24*cos(theta)**7 - 6.38892313941743e+22*cos(theta)**5 + 4.76785308911748e+20*cos(theta)**3 - 1.04787979980604e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl53_m_minus_9(theta, phi):
    return 1.19937071750798e-15*(1.0 - cos(theta)**2)**4.5*(1.11989562818416e+30*cos(theta)**44 - 1.00897263263069e+31*cos(theta)**42 + 4.21711377036417e+31*cos(theta)**40 - 1.08559364385612e+32*cos(theta)**38 + 1.92720285765368e+32*cos(theta)**36 - 2.50337690788003e+32*cos(theta)**34 + 2.4638499040714e+32*cos(theta)**32 - 1.87721897453059e+32*cos(theta)**30 + 1.12168990923188e+32*cos(theta)**28 - 5.29336811098189e+31*cos(theta)**26 + 1.97740762766565e+31*cos(theta)**24 - 5.83705353193283e+30*cos(theta)**22 + 1.35377446373141e+30*cos(theta)**20 - 2.44270795924946e+29*cos(theta)**18 + 3.37915296351869e+28*cos(theta)**16 - 3.51080827378565e+27*cos(theta)**14 + 2.66236294095412e+26*cos(theta)**12 - 1.41592227319075e+25*cos(theta)**10 + 4.98564180700967e+23*cos(theta)**8 - 1.06482052323624e+22*cos(theta)**6 + 1.19196327227937e+20*cos(theta)**4 - 5.2393989990302e+17*cos(theta)**2 + 378023015803045.0)*sin(9*phi)

#@torch.jit.script
def Yl53_m_minus_8(theta, phi):
    return 6.33513017171989e-14*(1.0 - cos(theta)**2)**4*(2.48865695152037e+28*cos(theta)**45 - 2.34644798286206e+29*cos(theta)**43 + 1.02856433423516e+30*cos(theta)**41 - 2.78357344578493e+30*cos(theta)**39 + 5.20865637203696e+30*cos(theta)**37 - 7.15250545108581e+30*cos(theta)**35 + 7.46621183051939e+30*cos(theta)**33 - 6.05554507913094e+30*cos(theta)**31 + 3.86789623873061e+30*cos(theta)**29 - 1.96050670777107e+30*cos(theta)**27 + 7.9096305106626e+29*cos(theta)**25 - 2.53784936170992e+29*cos(theta)**23 + 6.44654506538766e+28*cos(theta)**21 - 1.28563576802603e+28*cos(theta)**19 + 1.98773703736393e+27*cos(theta)**17 - 2.34053884919043e+26*cos(theta)**15 + 2.04797149304163e+25*cos(theta)**13 - 1.28720206653704e+24*cos(theta)**11 + 5.53960200778852e+22*cos(theta)**9 - 1.52117217605177e+21*cos(theta)**7 + 2.38392654455874e+19*cos(theta)**5 - 1.74646633301007e+17*cos(theta)**3 + 378023015803045.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl53_m_minus_7(theta, phi):
    return 3.35582555066761e-12*(1.0 - cos(theta)**2)**3.5*(5.41012380765297e+26*cos(theta)**46 - 5.3328363246865e+27*cos(theta)**44 + 2.44896270055992e+28*cos(theta)**42 - 6.95893361446234e+28*cos(theta)**40 + 1.37069904527288e+29*cos(theta)**38 - 1.98680706974606e+29*cos(theta)**36 + 2.19594465603512e+29*cos(theta)**34 - 1.89235783722842e+29*cos(theta)**32 + 1.28929874624354e+29*cos(theta)**30 - 7.00180967061097e+28*cos(theta)**28 + 3.04216558102408e+28*cos(theta)**26 - 1.0574372340458e+28*cos(theta)**24 + 2.93024775699439e+27*cos(theta)**22 - 6.42817884013015e+26*cos(theta)**20 + 1.10429835409107e+26*cos(theta)**18 - 1.46283678074402e+25*cos(theta)**16 + 1.46283678074402e+24*cos(theta)**14 - 1.07266838878087e+23*cos(theta)**12 + 5.53960200778852e+21*cos(theta)**10 - 1.90146522006471e+20*cos(theta)**8 + 3.9732109075979e+18*cos(theta)**6 - 4.36616583252517e+16*cos(theta)**4 + 189011507901522.0*cos(theta)**2 - 134719535211.349)*sin(7*phi)

#@torch.jit.script
def Yl53_m_minus_6(theta, phi):
    return 1.78206659967489e-10*(1.0 - cos(theta)**2)**3*(1.15109017184106e+25*cos(theta)**47 - 1.18507473881922e+26*cos(theta)**45 + 5.69526209432539e+26*cos(theta)**43 - 1.69730088157618e+27*cos(theta)**41 + 3.51461293659714e+27*cos(theta)**39 - 5.3697488371515e+27*cos(theta)**37 + 6.27412758867176e+27*cos(theta)**35 - 5.73441768857096e+27*cos(theta)**33 + 4.15902821368883e+27*cos(theta)**31 - 2.41441712779689e+27*cos(theta)**29 + 1.12672799297188e+27*cos(theta)**27 - 4.22974893618321e+26*cos(theta)**25 + 1.2740207639106e+26*cos(theta)**23 - 3.06103754291912e+25*cos(theta)**21 + 5.81209660047934e+24*cos(theta)**19 - 8.60492223967071e+23*cos(theta)**17 + 9.75224520496013e+22*cos(theta)**15 - 8.25129529831438e+21*cos(theta)**13 + 5.03600182526229e+20*cos(theta)**11 - 2.11273913340523e+19*cos(theta)**9 + 5.67601558228272e+17*cos(theta)**7 - 8.73233166505034e+15*cos(theta)**5 + 63003835967174.1*cos(theta)**3 - 134719535211.349*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl53_m_minus_5(theta, phi):
    return 9.48354163147754e-9*(1.0 - cos(theta)**2)**2.5*(2.39810452466887e+23*cos(theta)**48 - 2.5762494322157e+24*cos(theta)**46 + 1.29437774871031e+25*cos(theta)**44 - 4.04119257518138e+25*cos(theta)**42 + 8.78653234149285e+25*cos(theta)**40 - 1.4130917992504e+26*cos(theta)**38 + 1.74281321907549e+26*cos(theta)**36 - 1.68659343781499e+26*cos(theta)**34 + 1.29969631677776e+26*cos(theta)**32 - 8.04805709265629e+25*cos(theta)**30 + 4.02402854632814e+25*cos(theta)**28 - 1.62682651391662e+25*cos(theta)**26 + 5.30841984962752e+24*cos(theta)**24 - 1.39138070132687e+24*cos(theta)**22 + 2.90604830023967e+23*cos(theta)**20 - 4.78051235537261e+22*cos(theta)**18 + 6.09515325310008e+21*cos(theta)**16 - 5.89378235593884e+20*cos(theta)**14 + 4.19666818771858e+19*cos(theta)**12 - 2.11273913340523e+18*cos(theta)**10 + 7.0950194778534e+16*cos(theta)**8 - 1.45538861084172e+15*cos(theta)**6 + 15750958991793.5*cos(theta)**4 - 67359767605.6744*cos(theta)**2 + 47570457.3486401)*sin(5*phi)

#@torch.jit.script
def Yl53_m_minus_4(theta, phi):
    return 5.05571509137432e-7*(1.0 - cos(theta)**2)**2*(4.89409086667116e+21*cos(theta)**49 - 5.4813817706717e+22*cos(theta)**47 + 2.87639499713403e+23*cos(theta)**45 - 9.39812226786367e+23*cos(theta)**43 + 2.14305666865679e+24*cos(theta)**41 - 3.62331230577025e+24*cos(theta)**39 + 4.71030599750132e+24*cos(theta)**37 - 4.81883839375711e+24*cos(theta)**35 + 3.93847368720533e+24*cos(theta)**33 - 2.59614744924396e+24*cos(theta)**31 + 1.38759605045798e+24*cos(theta)**29 - 6.02528338487636e+23*cos(theta)**27 + 2.12336793985101e+23*cos(theta)**25 - 6.04948131011683e+22*cos(theta)**23 + 1.38383252392365e+22*cos(theta)**21 - 2.51605913440664e+21*cos(theta)**19 + 3.58538426652946e+20*cos(theta)**17 - 3.92918823729256e+19*cos(theta)**15 + 3.22820629824506e+18*cos(theta)**13 - 1.9206719394593e+17*cos(theta)**11 + 7.88335497539267e+15*cos(theta)**9 - 207912658691675.0*cos(theta)**7 + 3150191798358.71*cos(theta)**5 - 22453255868.5581*cos(theta)**3 + 47570457.3486401*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl53_m_minus_3(theta, phi):
    return 2.69901328252896e-5*(1.0 - cos(theta)**2)**1.5*(9.78818173334232e+19*cos(theta)**50 - 1.1419545355566e+21*cos(theta)**48 + 6.25303260246529e+21*cos(theta)**46 - 2.13593687905993e+22*cos(theta)**44 + 5.10251587775427e+22*cos(theta)**42 - 9.05828076442562e+22*cos(theta)**40 + 1.23955420986877e+23*cos(theta)**38 - 1.33856622048809e+23*cos(theta)**36 + 1.15837461388392e+23*cos(theta)**34 - 8.11296077888739e+22*cos(theta)**32 + 4.62532016819327e+22*cos(theta)**30 - 2.15188692317013e+22*cos(theta)**28 + 8.16679976865772e+21*cos(theta)**26 - 2.52061721254868e+21*cos(theta)**24 + 6.2901478360166e+20*cos(theta)**22 - 1.25802956720332e+20*cos(theta)**20 + 1.99188014807192e+19*cos(theta)**18 - 2.45574264830785e+18*cos(theta)**16 + 2.30586164160361e+17*cos(theta)**14 - 1.60055994954942e+16*cos(theta)**12 + 788335497539267.0*cos(theta)**10 - 25989082336459.3*cos(theta)**8 + 525031966393.118*cos(theta)**6 - 5613313967.13954*cos(theta)**4 + 23785228.6743201*cos(theta)**2 - 16691.3885433825)*sin(3*phi)

#@torch.jit.script
def Yl53_m_minus_2(theta, phi):
    return 0.00144239471813747*(1.0 - cos(theta)**2)*(1.9192513202632e+18*cos(theta)**51 - 2.3305194603196e+19*cos(theta)**49 + 1.33043246860964e+20*cos(theta)**47 - 4.74652639791095e+20*cos(theta)**45 + 1.18663159947774e+21*cos(theta)**43 - 2.20933677181113e+21*cos(theta)**41 + 3.17834412786864e+21*cos(theta)**39 - 3.61774654185969e+21*cos(theta)**37 + 3.30964175395406e+21*cos(theta)**35 - 2.45847296329921e+21*cos(theta)**33 + 1.49203876393331e+21*cos(theta)**31 - 7.42029973506942e+20*cos(theta)**29 + 3.02474065505842e+20*cos(theta)**27 - 1.00824688501947e+20*cos(theta)**25 + 2.73484688522461e+19*cos(theta)**23 - 5.99061698668247e+18*cos(theta)**21 + 1.04835797266943e+18*cos(theta)**19 - 1.44455449900462e+17*cos(theta)**17 + 1.53724109440241e+16*cos(theta)**15 - 1.23119996119186e+15*cos(theta)**13 + 71666863412660.6*cos(theta)**11 - 2887675815162.15*cos(theta)**9 + 75004566627.5883*cos(theta)**7 - 1122662793.42791*cos(theta)**5 + 7928409.55810669*cos(theta)**3 - 16691.3885433825*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl53_m_minus_1(theta, phi):
    return 0.0771377807272486*(1.0 - cos(theta)**2)**0.5*(3.69086792358308e+16*cos(theta)**52 - 4.6610389206392e+17*cos(theta)**50 + 2.77173430960341e+18*cos(theta)**48 - 1.03185356476325e+19*cos(theta)**46 + 2.69688999881304e+19*cos(theta)**44 - 5.26032564716935e+19*cos(theta)**42 + 7.94586031967159e+19*cos(theta)**40 - 9.52038563647288e+19*cos(theta)**38 + 9.19344931653905e+19*cos(theta)**36 - 7.23080283323296e+19*cos(theta)**34 + 4.6626211372916e+19*cos(theta)**32 - 2.47343324502314e+19*cos(theta)**30 + 1.08026451966372e+19*cos(theta)**28 - 3.87787263469028e+18*cos(theta)**26 + 1.13951953551025e+18*cos(theta)**24 - 2.72300772121931e+17*cos(theta)**22 + 5.24178986334716e+16*cos(theta)**20 - 8.02530277224788e+15*cos(theta)**18 + 960775684001506.0*cos(theta)**16 - 87942854370847.3*cos(theta)**14 + 5972238617721.72*cos(theta)**12 - 288767581516.215*cos(theta)**10 + 9375570828.44853*cos(theta)**8 - 187110465.571318*cos(theta)**6 + 1982102.38952667*cos(theta)**4 - 8345.69427169125*cos(theta)**2 + 5.83614984034353)*sin(phi)

#@torch.jit.script
def Yl53_m0(theta, phi):
    return 6.383949815115e+15*cos(theta)**53 - 8.37817413831283e+16*cos(theta)**51 + 5.18552040114023e+17*cos(theta)**49 - 2.01259801707621e+18*cos(theta)**47 + 5.49398600116005e+18*cos(theta)**45 - 1.12145281260793e+19*cos(theta)**43 + 1.77661735049993e+19*cos(theta)**41 - 2.23782830631327e+19*cos(theta)**39 + 2.27778952606887e+19*cos(theta)**37 - 1.89389241493366e+19*cos(theta)**35 + 1.29524826078797e+19*cos(theta)**33 - 7.31434311974381e+18*cos(theta)**31 + 3.41482886614545e+18*cos(theta)**29 - 1.31663867013775e+18*cos(theta)**27 + 4.17848257882777e+17*cos(theta)**25 - 1.08532015034487e+17*cos(theta)**23 + 2.28821665031044e+16*cos(theta)**21 - 3.87208296990486e+15*cos(theta)**19 + 518095608649242.0*cos(theta)**17 - 53745997541035.0*cos(theta)**15 + 4211440105827.37*cos(theta)**13 - 240653720332.993*cos(theta)**11 + 9549750806.86479*cos(theta)**9 - 245039935.172582*cos(theta)**7 + 3634066.8351866*cos(theta)**5 - 25502.2234048182*cos(theta)**3 + 53.5011679821361*cos(theta)

#@torch.jit.script
def Yl53_m1(theta, phi):
    return 0.0771377807272486*(1.0 - cos(theta)**2)**0.5*(3.69086792358308e+16*cos(theta)**52 - 4.6610389206392e+17*cos(theta)**50 + 2.77173430960341e+18*cos(theta)**48 - 1.03185356476325e+19*cos(theta)**46 + 2.69688999881304e+19*cos(theta)**44 - 5.26032564716935e+19*cos(theta)**42 + 7.94586031967159e+19*cos(theta)**40 - 9.52038563647288e+19*cos(theta)**38 + 9.19344931653905e+19*cos(theta)**36 - 7.23080283323296e+19*cos(theta)**34 + 4.6626211372916e+19*cos(theta)**32 - 2.47343324502314e+19*cos(theta)**30 + 1.08026451966372e+19*cos(theta)**28 - 3.87787263469028e+18*cos(theta)**26 + 1.13951953551025e+18*cos(theta)**24 - 2.72300772121931e+17*cos(theta)**22 + 5.24178986334716e+16*cos(theta)**20 - 8.02530277224788e+15*cos(theta)**18 + 960775684001506.0*cos(theta)**16 - 87942854370847.3*cos(theta)**14 + 5972238617721.72*cos(theta)**12 - 288767581516.215*cos(theta)**10 + 9375570828.44853*cos(theta)**8 - 187110465.571318*cos(theta)**6 + 1982102.38952667*cos(theta)**4 - 8345.69427169125*cos(theta)**2 + 5.83614984034353)*cos(phi)

#@torch.jit.script
def Yl53_m2(theta, phi):
    return 0.00144239471813747*(1.0 - cos(theta)**2)*(1.9192513202632e+18*cos(theta)**51 - 2.3305194603196e+19*cos(theta)**49 + 1.33043246860964e+20*cos(theta)**47 - 4.74652639791095e+20*cos(theta)**45 + 1.18663159947774e+21*cos(theta)**43 - 2.20933677181113e+21*cos(theta)**41 + 3.17834412786864e+21*cos(theta)**39 - 3.61774654185969e+21*cos(theta)**37 + 3.30964175395406e+21*cos(theta)**35 - 2.45847296329921e+21*cos(theta)**33 + 1.49203876393331e+21*cos(theta)**31 - 7.42029973506942e+20*cos(theta)**29 + 3.02474065505842e+20*cos(theta)**27 - 1.00824688501947e+20*cos(theta)**25 + 2.73484688522461e+19*cos(theta)**23 - 5.99061698668247e+18*cos(theta)**21 + 1.04835797266943e+18*cos(theta)**19 - 1.44455449900462e+17*cos(theta)**17 + 1.53724109440241e+16*cos(theta)**15 - 1.23119996119186e+15*cos(theta)**13 + 71666863412660.6*cos(theta)**11 - 2887675815162.15*cos(theta)**9 + 75004566627.5883*cos(theta)**7 - 1122662793.42791*cos(theta)**5 + 7928409.55810669*cos(theta)**3 - 16691.3885433825*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl53_m3(theta, phi):
    return 2.69901328252896e-5*(1.0 - cos(theta)**2)**1.5*(9.78818173334232e+19*cos(theta)**50 - 1.1419545355566e+21*cos(theta)**48 + 6.25303260246529e+21*cos(theta)**46 - 2.13593687905993e+22*cos(theta)**44 + 5.10251587775427e+22*cos(theta)**42 - 9.05828076442562e+22*cos(theta)**40 + 1.23955420986877e+23*cos(theta)**38 - 1.33856622048809e+23*cos(theta)**36 + 1.15837461388392e+23*cos(theta)**34 - 8.11296077888739e+22*cos(theta)**32 + 4.62532016819327e+22*cos(theta)**30 - 2.15188692317013e+22*cos(theta)**28 + 8.16679976865772e+21*cos(theta)**26 - 2.52061721254868e+21*cos(theta)**24 + 6.2901478360166e+20*cos(theta)**22 - 1.25802956720332e+20*cos(theta)**20 + 1.99188014807192e+19*cos(theta)**18 - 2.45574264830785e+18*cos(theta)**16 + 2.30586164160361e+17*cos(theta)**14 - 1.60055994954942e+16*cos(theta)**12 + 788335497539267.0*cos(theta)**10 - 25989082336459.3*cos(theta)**8 + 525031966393.118*cos(theta)**6 - 5613313967.13954*cos(theta)**4 + 23785228.6743201*cos(theta)**2 - 16691.3885433825)*cos(3*phi)

#@torch.jit.script
def Yl53_m4(theta, phi):
    return 5.05571509137432e-7*(1.0 - cos(theta)**2)**2*(4.89409086667116e+21*cos(theta)**49 - 5.4813817706717e+22*cos(theta)**47 + 2.87639499713403e+23*cos(theta)**45 - 9.39812226786367e+23*cos(theta)**43 + 2.14305666865679e+24*cos(theta)**41 - 3.62331230577025e+24*cos(theta)**39 + 4.71030599750132e+24*cos(theta)**37 - 4.81883839375711e+24*cos(theta)**35 + 3.93847368720533e+24*cos(theta)**33 - 2.59614744924396e+24*cos(theta)**31 + 1.38759605045798e+24*cos(theta)**29 - 6.02528338487636e+23*cos(theta)**27 + 2.12336793985101e+23*cos(theta)**25 - 6.04948131011683e+22*cos(theta)**23 + 1.38383252392365e+22*cos(theta)**21 - 2.51605913440664e+21*cos(theta)**19 + 3.58538426652946e+20*cos(theta)**17 - 3.92918823729256e+19*cos(theta)**15 + 3.22820629824506e+18*cos(theta)**13 - 1.9206719394593e+17*cos(theta)**11 + 7.88335497539267e+15*cos(theta)**9 - 207912658691675.0*cos(theta)**7 + 3150191798358.71*cos(theta)**5 - 22453255868.5581*cos(theta)**3 + 47570457.3486401*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl53_m5(theta, phi):
    return 9.48354163147754e-9*(1.0 - cos(theta)**2)**2.5*(2.39810452466887e+23*cos(theta)**48 - 2.5762494322157e+24*cos(theta)**46 + 1.29437774871031e+25*cos(theta)**44 - 4.04119257518138e+25*cos(theta)**42 + 8.78653234149285e+25*cos(theta)**40 - 1.4130917992504e+26*cos(theta)**38 + 1.74281321907549e+26*cos(theta)**36 - 1.68659343781499e+26*cos(theta)**34 + 1.29969631677776e+26*cos(theta)**32 - 8.04805709265629e+25*cos(theta)**30 + 4.02402854632814e+25*cos(theta)**28 - 1.62682651391662e+25*cos(theta)**26 + 5.30841984962752e+24*cos(theta)**24 - 1.39138070132687e+24*cos(theta)**22 + 2.90604830023967e+23*cos(theta)**20 - 4.78051235537261e+22*cos(theta)**18 + 6.09515325310008e+21*cos(theta)**16 - 5.89378235593884e+20*cos(theta)**14 + 4.19666818771858e+19*cos(theta)**12 - 2.11273913340523e+18*cos(theta)**10 + 7.0950194778534e+16*cos(theta)**8 - 1.45538861084172e+15*cos(theta)**6 + 15750958991793.5*cos(theta)**4 - 67359767605.6744*cos(theta)**2 + 47570457.3486401)*cos(5*phi)

#@torch.jit.script
def Yl53_m6(theta, phi):
    return 1.78206659967489e-10*(1.0 - cos(theta)**2)**3*(1.15109017184106e+25*cos(theta)**47 - 1.18507473881922e+26*cos(theta)**45 + 5.69526209432539e+26*cos(theta)**43 - 1.69730088157618e+27*cos(theta)**41 + 3.51461293659714e+27*cos(theta)**39 - 5.3697488371515e+27*cos(theta)**37 + 6.27412758867176e+27*cos(theta)**35 - 5.73441768857096e+27*cos(theta)**33 + 4.15902821368883e+27*cos(theta)**31 - 2.41441712779689e+27*cos(theta)**29 + 1.12672799297188e+27*cos(theta)**27 - 4.22974893618321e+26*cos(theta)**25 + 1.2740207639106e+26*cos(theta)**23 - 3.06103754291912e+25*cos(theta)**21 + 5.81209660047934e+24*cos(theta)**19 - 8.60492223967071e+23*cos(theta)**17 + 9.75224520496013e+22*cos(theta)**15 - 8.25129529831438e+21*cos(theta)**13 + 5.03600182526229e+20*cos(theta)**11 - 2.11273913340523e+19*cos(theta)**9 + 5.67601558228272e+17*cos(theta)**7 - 8.73233166505034e+15*cos(theta)**5 + 63003835967174.1*cos(theta)**3 - 134719535211.349*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl53_m7(theta, phi):
    return 3.35582555066761e-12*(1.0 - cos(theta)**2)**3.5*(5.41012380765297e+26*cos(theta)**46 - 5.3328363246865e+27*cos(theta)**44 + 2.44896270055992e+28*cos(theta)**42 - 6.95893361446234e+28*cos(theta)**40 + 1.37069904527288e+29*cos(theta)**38 - 1.98680706974606e+29*cos(theta)**36 + 2.19594465603512e+29*cos(theta)**34 - 1.89235783722842e+29*cos(theta)**32 + 1.28929874624354e+29*cos(theta)**30 - 7.00180967061097e+28*cos(theta)**28 + 3.04216558102408e+28*cos(theta)**26 - 1.0574372340458e+28*cos(theta)**24 + 2.93024775699439e+27*cos(theta)**22 - 6.42817884013015e+26*cos(theta)**20 + 1.10429835409107e+26*cos(theta)**18 - 1.46283678074402e+25*cos(theta)**16 + 1.46283678074402e+24*cos(theta)**14 - 1.07266838878087e+23*cos(theta)**12 + 5.53960200778852e+21*cos(theta)**10 - 1.90146522006471e+20*cos(theta)**8 + 3.9732109075979e+18*cos(theta)**6 - 4.36616583252517e+16*cos(theta)**4 + 189011507901522.0*cos(theta)**2 - 134719535211.349)*cos(7*phi)

#@torch.jit.script
def Yl53_m8(theta, phi):
    return 6.33513017171989e-14*(1.0 - cos(theta)**2)**4*(2.48865695152037e+28*cos(theta)**45 - 2.34644798286206e+29*cos(theta)**43 + 1.02856433423516e+30*cos(theta)**41 - 2.78357344578493e+30*cos(theta)**39 + 5.20865637203696e+30*cos(theta)**37 - 7.15250545108581e+30*cos(theta)**35 + 7.46621183051939e+30*cos(theta)**33 - 6.05554507913094e+30*cos(theta)**31 + 3.86789623873061e+30*cos(theta)**29 - 1.96050670777107e+30*cos(theta)**27 + 7.9096305106626e+29*cos(theta)**25 - 2.53784936170992e+29*cos(theta)**23 + 6.44654506538766e+28*cos(theta)**21 - 1.28563576802603e+28*cos(theta)**19 + 1.98773703736393e+27*cos(theta)**17 - 2.34053884919043e+26*cos(theta)**15 + 2.04797149304163e+25*cos(theta)**13 - 1.28720206653704e+24*cos(theta)**11 + 5.53960200778852e+22*cos(theta)**9 - 1.52117217605177e+21*cos(theta)**7 + 2.38392654455874e+19*cos(theta)**5 - 1.74646633301007e+17*cos(theta)**3 + 378023015803045.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl53_m9(theta, phi):
    return 1.19937071750798e-15*(1.0 - cos(theta)**2)**4.5*(1.11989562818416e+30*cos(theta)**44 - 1.00897263263069e+31*cos(theta)**42 + 4.21711377036417e+31*cos(theta)**40 - 1.08559364385612e+32*cos(theta)**38 + 1.92720285765368e+32*cos(theta)**36 - 2.50337690788003e+32*cos(theta)**34 + 2.4638499040714e+32*cos(theta)**32 - 1.87721897453059e+32*cos(theta)**30 + 1.12168990923188e+32*cos(theta)**28 - 5.29336811098189e+31*cos(theta)**26 + 1.97740762766565e+31*cos(theta)**24 - 5.83705353193283e+30*cos(theta)**22 + 1.35377446373141e+30*cos(theta)**20 - 2.44270795924946e+29*cos(theta)**18 + 3.37915296351869e+28*cos(theta)**16 - 3.51080827378565e+27*cos(theta)**14 + 2.66236294095412e+26*cos(theta)**12 - 1.41592227319075e+25*cos(theta)**10 + 4.98564180700967e+23*cos(theta)**8 - 1.06482052323624e+22*cos(theta)**6 + 1.19196327227937e+20*cos(theta)**4 - 5.2393989990302e+17*cos(theta)**2 + 378023015803045.0)*cos(9*phi)

#@torch.jit.script
def Yl53_m10(theta, phi):
    return 2.27801630593366e-17*(1.0 - cos(theta)**2)**5*(4.92754076401032e+31*cos(theta)**43 - 4.23768505704888e+32*cos(theta)**41 + 1.68684550814567e+33*cos(theta)**39 - 4.12525584665327e+33*cos(theta)**37 + 6.93793028755323e+33*cos(theta)**35 - 8.51148148679211e+33*cos(theta)**33 + 7.88431969302848e+33*cos(theta)**31 - 5.63165692359177e+33*cos(theta)**29 + 3.14073174584926e+33*cos(theta)**27 - 1.37627570885529e+33*cos(theta)**25 + 4.74577830639756e+32*cos(theta)**23 - 1.28415177702522e+32*cos(theta)**21 + 2.70754892746282e+31*cos(theta)**19 - 4.39687432664902e+30*cos(theta)**17 + 5.4066447416299e+29*cos(theta)**15 - 4.91513158329991e+28*cos(theta)**13 + 3.19483552914494e+27*cos(theta)**11 - 1.41592227319075e+26*cos(theta)**9 + 3.98851344560774e+24*cos(theta)**7 - 6.38892313941743e+22*cos(theta)**5 + 4.76785308911748e+20*cos(theta)**3 - 1.04787979980604e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl53_m11(theta, phi):
    return 4.34242787311555e-19*(1.0 - cos(theta)**2)**5.5*(2.11884252852444e+33*cos(theta)**42 - 1.73745087339004e+34*cos(theta)**40 + 6.57869748176811e+34*cos(theta)**38 - 1.52634466326171e+35*cos(theta)**36 + 2.42827560064363e+35*cos(theta)**34 - 2.8087888906414e+35*cos(theta)**32 + 2.44413910483883e+35*cos(theta)**30 - 1.63318050784161e+35*cos(theta)**28 + 8.47997571379299e+34*cos(theta)**26 - 3.44068927213823e+34*cos(theta)**24 + 1.09152901047144e+34*cos(theta)**22 - 2.69671873175297e+33*cos(theta)**20 + 5.14434296217935e+32*cos(theta)**18 - 7.47468635530333e+31*cos(theta)**16 + 8.10996711244485e+30*cos(theta)**14 - 6.38967105828988e+29*cos(theta)**12 + 3.51431908205943e+28*cos(theta)**10 - 1.27433004587167e+27*cos(theta)**8 + 2.79195941192542e+25*cos(theta)**6 - 3.19446156970871e+23*cos(theta)**4 + 1.43035592673525e+21*cos(theta)**2 - 1.04787979980604e+18)*cos(11*phi)

#@torch.jit.script
def Yl53_m12(theta, phi):
    return 8.31096187580827e-21*(1.0 - cos(theta)**2)**6*(8.89913861980265e+34*cos(theta)**41 - 6.94980349356016e+35*cos(theta)**39 + 2.49990504307188e+36*cos(theta)**37 - 5.49484078774216e+36*cos(theta)**35 + 8.25613704218834e+36*cos(theta)**33 - 8.98812445005247e+36*cos(theta)**31 + 7.33241731451649e+36*cos(theta)**29 - 4.57290542195652e+36*cos(theta)**27 + 2.20479368558618e+36*cos(theta)**25 - 8.25765425313175e+35*cos(theta)**23 + 2.40136382303717e+35*cos(theta)**21 - 5.39343746350593e+34*cos(theta)**19 + 9.25981733192284e+33*cos(theta)**17 - 1.19594981684853e+33*cos(theta)**15 + 1.13539539574228e+32*cos(theta)**13 - 7.66760526994786e+30*cos(theta)**11 + 3.51431908205943e+29*cos(theta)**9 - 1.01946403669734e+28*cos(theta)**7 + 1.67517564715525e+26*cos(theta)**5 - 1.27778462788349e+24*cos(theta)**3 + 2.86071185347049e+21*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl53_m13(theta, phi):
    return 1.59767115369259e-22*(1.0 - cos(theta)**2)**6.5*(3.64864683411908e+36*cos(theta)**40 - 2.71042336248846e+37*cos(theta)**38 + 9.24964865936597e+37*cos(theta)**36 - 1.92319427570976e+38*cos(theta)**34 + 2.72452522392215e+38*cos(theta)**32 - 2.78631857951626e+38*cos(theta)**30 + 2.12640102120978e+38*cos(theta)**28 - 1.23468446392826e+38*cos(theta)**26 + 5.51198421396545e+37*cos(theta)**24 - 1.8992604782203e+37*cos(theta)**22 + 5.04286402837805e+36*cos(theta)**20 - 1.02475311806613e+36*cos(theta)**18 + 1.57416894642688e+35*cos(theta)**16 - 1.7939247252728e+34*cos(theta)**14 + 1.47601401446496e+33*cos(theta)**12 - 8.43436579694264e+31*cos(theta)**10 + 3.16288717385349e+30*cos(theta)**8 - 7.13624825688136e+28*cos(theta)**6 + 8.37587823577625e+26*cos(theta)**4 - 3.83335388365046e+24*cos(theta)**2 + 2.86071185347049e+21)*cos(13*phi)

#@torch.jit.script
def Yl53_m14(theta, phi):
    return 3.08617107803759e-24*(1.0 - cos(theta)**2)**7*(1.45945873364763e+38*cos(theta)**39 - 1.02996087774562e+39*cos(theta)**37 + 3.32987351737175e+39*cos(theta)**35 - 6.53886053741317e+39*cos(theta)**33 + 8.71848071655089e+39*cos(theta)**31 - 8.35895573854879e+39*cos(theta)**29 + 5.95392285938739e+39*cos(theta)**27 - 3.21017960621348e+39*cos(theta)**25 + 1.32287621135171e+39*cos(theta)**23 - 4.17837305208467e+38*cos(theta)**21 + 1.00857280567561e+38*cos(theta)**19 - 1.84455561251903e+37*cos(theta)**17 + 2.51867031428301e+36*cos(theta)**15 - 2.51149461538192e+35*cos(theta)**13 + 1.77121681735795e+34*cos(theta)**11 - 8.43436579694264e+32*cos(theta)**9 + 2.53030973908279e+31*cos(theta)**7 - 4.28174895412882e+29*cos(theta)**5 + 3.3503512943105e+27*cos(theta)**3 - 7.66670776730091e+24*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl53_m15(theta, phi):
    return 5.99284764841289e-26*(1.0 - cos(theta)**2)**7.5*(5.69188906122577e+39*cos(theta)**38 - 3.81085524765878e+40*cos(theta)**36 + 1.16545573108011e+41*cos(theta)**34 - 2.15782397734635e+41*cos(theta)**32 + 2.70272902213078e+41*cos(theta)**30 - 2.42409716417915e+41*cos(theta)**28 + 1.60755917203459e+41*cos(theta)**26 - 8.02544901553369e+40*cos(theta)**24 + 3.04261528610893e+40*cos(theta)**22 - 8.7745834093778e+39*cos(theta)**20 + 1.91628833078366e+39*cos(theta)**18 - 3.13574454128235e+38*cos(theta)**16 + 3.77800547142452e+37*cos(theta)**14 - 3.2649429999965e+36*cos(theta)**12 + 1.94833849909375e+35*cos(theta)**10 - 7.59092921724838e+33*cos(theta)**8 + 1.77121681735795e+32*cos(theta)**6 - 2.14087447706441e+30*cos(theta)**4 + 1.00510538829315e+28*cos(theta)**2 - 7.66670776730091e+24)*cos(15*phi)

#@torch.jit.script
def Yl53_m16(theta, phi):
    return 1.17035305581318e-27*(1.0 - cos(theta)**2)**8*(2.16291784326579e+41*cos(theta)**37 - 1.37190788915716e+42*cos(theta)**35 + 3.96254948567238e+42*cos(theta)**33 - 6.90503672750831e+42*cos(theta)**31 + 8.10818706639233e+42*cos(theta)**29 - 6.78747205970162e+42*cos(theta)**27 + 4.17965384728995e+42*cos(theta)**25 - 1.92610776372809e+42*cos(theta)**23 + 6.69375362943964e+41*cos(theta)**21 - 1.75491668187556e+41*cos(theta)**19 + 3.44931899541058e+40*cos(theta)**17 - 5.01719126605176e+39*cos(theta)**15 + 5.28920765999432e+38*cos(theta)**13 - 3.9179315999958e+37*cos(theta)**11 + 1.94833849909375e+36*cos(theta)**9 - 6.0727433737987e+34*cos(theta)**7 + 1.06273009041477e+33*cos(theta)**5 - 8.56349790825764e+30*cos(theta)**3 + 2.0102107765863e+28*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl53_m17(theta, phi):
    return 2.29967789859005e-29*(1.0 - cos(theta)**2)**8.5*(8.00279602008343e+42*cos(theta)**36 - 4.80167761205006e+43*cos(theta)**34 + 1.30764133027189e+44*cos(theta)**32 - 2.14056138552757e+44*cos(theta)**30 + 2.35137424925378e+44*cos(theta)**28 - 1.83261745611944e+44*cos(theta)**26 + 1.04491346182249e+44*cos(theta)**24 - 4.4300478565746e+43*cos(theta)**22 + 1.40568826218232e+43*cos(theta)**20 - 3.33434169556356e+42*cos(theta)**18 + 5.86384229219799e+41*cos(theta)**16 - 7.52578689907764e+40*cos(theta)**14 + 6.87596995799262e+39*cos(theta)**12 - 4.30972475999537e+38*cos(theta)**10 + 1.75350464918438e+37*cos(theta)**8 - 4.25092036165909e+35*cos(theta)**6 + 5.31365045207386e+33*cos(theta)**4 - 2.56904937247729e+31*cos(theta)**2 + 2.0102107765863e+28)*cos(17*phi)

#@torch.jit.script
def Yl53_m18(theta, phi):
    return 4.54869258300075e-31*(1.0 - cos(theta)**2)**9*(2.88100656723004e+44*cos(theta)**35 - 1.63257038809702e+45*cos(theta)**33 + 4.18445225687003e+45*cos(theta)**31 - 6.42168415658272e+45*cos(theta)**29 + 6.58384789791057e+45*cos(theta)**27 - 4.76480538591054e+45*cos(theta)**25 + 2.50779230837397e+45*cos(theta)**23 - 9.74610528446411e+44*cos(theta)**21 + 2.81137652436465e+44*cos(theta)**19 - 6.00181505201442e+43*cos(theta)**17 + 9.38214766751679e+42*cos(theta)**15 - 1.05361016587087e+42*cos(theta)**13 + 8.25116394959114e+40*cos(theta)**11 - 4.30972475999538e+39*cos(theta)**9 + 1.4028037193475e+38*cos(theta)**7 - 2.55055221699545e+36*cos(theta)**5 + 2.12546018082955e+34*cos(theta)**3 - 5.13809874495458e+31*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl53_m19(theta, phi):
    return 9.0612125171161e-33*(1.0 - cos(theta)**2)**9.5*(1.00835229853051e+46*cos(theta)**34 - 5.38748228072017e+46*cos(theta)**32 + 1.29718019962971e+47*cos(theta)**30 - 1.86228840540899e+47*cos(theta)**28 + 1.77763893243585e+47*cos(theta)**26 - 1.19120134647763e+47*cos(theta)**24 + 5.76792230926012e+46*cos(theta)**22 - 2.04668210973746e+46*cos(theta)**20 + 5.34161539629283e+45*cos(theta)**18 - 1.02030855884245e+45*cos(theta)**16 + 1.40732215012752e+44*cos(theta)**14 - 1.36969321563213e+43*cos(theta)**12 + 9.07628034455026e+41*cos(theta)**10 - 3.87875228399584e+40*cos(theta)**8 + 9.8196260354325e+38*cos(theta)**6 - 1.27527610849773e+37*cos(theta)**4 + 6.37638054248864e+34*cos(theta)**2 - 5.13809874495458e+31)*cos(19*phi)

#@torch.jit.script
def Yl53_m20(theta, phi):
    return 1.81880201915016e-34*(1.0 - cos(theta)**2)**10*(3.42839781500374e+47*cos(theta)**33 - 1.72399432983045e+48*cos(theta)**31 + 3.89154059888913e+48*cos(theta)**29 - 5.21440753514517e+48*cos(theta)**27 + 4.62186122433322e+48*cos(theta)**25 - 2.85888323154632e+48*cos(theta)**23 + 1.26894290803723e+48*cos(theta)**21 - 4.09336421947493e+47*cos(theta)**19 + 9.61490771332709e+46*cos(theta)**17 - 1.63249369414792e+46*cos(theta)**15 + 1.97025101017853e+45*cos(theta)**13 - 1.64363185875856e+44*cos(theta)**11 + 9.07628034455026e+42*cos(theta)**9 - 3.10300182719667e+41*cos(theta)**7 + 5.8917756212595e+39*cos(theta)**5 - 5.10110443399091e+37*cos(theta)**3 + 1.27527610849773e+35*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl53_m21(theta, phi):
    return 3.68054894824963e-36*(1.0 - cos(theta)**2)**10.5*(1.13137127895124e+49*cos(theta)**32 - 5.34438242247441e+49*cos(theta)**30 + 1.12854677367785e+50*cos(theta)**28 - 1.4078900344892e+50*cos(theta)**26 + 1.15546530608331e+50*cos(theta)**24 - 6.57543143255654e+49*cos(theta)**22 + 2.66478010687818e+49*cos(theta)**20 - 7.77739201700236e+48*cos(theta)**18 + 1.63453431126561e+48*cos(theta)**16 - 2.44874054122188e+47*cos(theta)**14 + 2.56132631323208e+46*cos(theta)**12 - 1.80799504463441e+45*cos(theta)**10 + 8.16865231009523e+43*cos(theta)**8 - 2.17210127903767e+42*cos(theta)**6 + 2.94588781062975e+40*cos(theta)**4 - 1.53033133019727e+38*cos(theta)**2 + 1.27527610849773e+35)*cos(21*phi)

#@torch.jit.script
def Yl53_m22(theta, phi):
    return 7.5128890804574e-38*(1.0 - cos(theta)**2)**11*(3.62038809264395e+50*cos(theta)**31 - 1.60331472674232e+51*cos(theta)**29 + 3.15993096629797e+51*cos(theta)**27 - 3.66051408967191e+51*cos(theta)**25 + 2.77311673459993e+51*cos(theta)**23 - 1.44659491516244e+51*cos(theta)**21 + 5.32956021375635e+50*cos(theta)**19 - 1.39993056306042e+50*cos(theta)**17 + 2.61525489802497e+49*cos(theta)**15 - 3.42823675771063e+48*cos(theta)**13 + 3.0735915758785e+47*cos(theta)**11 - 1.80799504463441e+46*cos(theta)**9 + 6.53492184807619e+44*cos(theta)**7 - 1.3032607674226e+43*cos(theta)**5 + 1.1783551242519e+41*cos(theta)**3 - 3.06066266039455e+38*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl53_m23(theta, phi):
    return 1.54781600797236e-39*(1.0 - cos(theta)**2)**11.5*(1.12232030871963e+52*cos(theta)**30 - 4.64961270755273e+52*cos(theta)**28 + 8.53181360900453e+52*cos(theta)**26 - 9.15128522417978e+52*cos(theta)**24 + 6.37816848957985e+52*cos(theta)**22 - 3.03784932184112e+52*cos(theta)**20 + 1.01261644061371e+52*cos(theta)**18 - 2.37988195720272e+51*cos(theta)**16 + 3.92288234703745e+50*cos(theta)**14 - 4.45670778502382e+49*cos(theta)**12 + 3.38095073346635e+48*cos(theta)**10 - 1.62719554017097e+47*cos(theta)**8 + 4.57444529365333e+45*cos(theta)**6 - 6.51630383711301e+43*cos(theta)**4 + 3.5350653727557e+41*cos(theta)**2 - 3.06066266039455e+38)*cos(23*phi)

#@torch.jit.script
def Yl53_m24(theta, phi):
    return 3.22042614650432e-41*(1.0 - cos(theta)**2)**12*(3.36696092615888e+53*cos(theta)**29 - 1.30189155811477e+54*cos(theta)**27 + 2.21827153834118e+54*cos(theta)**25 - 2.19630845380315e+54*cos(theta)**23 + 1.40319706770757e+54*cos(theta)**21 - 6.07569864368224e+53*cos(theta)**19 + 1.82270959310467e+53*cos(theta)**17 - 3.80781113152436e+52*cos(theta)**15 + 5.49203528585244e+51*cos(theta)**13 - 5.34804934202859e+50*cos(theta)**11 + 3.38095073346635e+49*cos(theta)**9 - 1.30175643213678e+48*cos(theta)**7 + 2.744667176192e+46*cos(theta)**5 - 2.6065215348452e+44*cos(theta)**3 + 7.0701307455114e+41*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl53_m25(theta, phi):
    return 6.77122185938431e-43*(1.0 - cos(theta)**2)**12.5*(9.76418668586074e+54*cos(theta)**28 - 3.51510720690987e+55*cos(theta)**26 + 5.54567884585295e+55*cos(theta)**24 - 5.05150944374724e+55*cos(theta)**22 + 2.94671384218589e+55*cos(theta)**20 - 1.15438274229963e+55*cos(theta)**18 + 3.09860630827794e+54*cos(theta)**16 - 5.71171669728653e+53*cos(theta)**14 + 7.13964587160817e+52*cos(theta)**12 - 5.88285427623145e+51*cos(theta)**10 + 3.04285566011971e+50*cos(theta)**8 - 9.11229502495744e+48*cos(theta)**6 + 1.372333588096e+47*cos(theta)**4 - 7.81956460453561e+44*cos(theta)**2 + 7.0701307455114e+41)*cos(25*phi)

#@torch.jit.script
def Yl53_m26(theta, phi):
    return 1.43970821381048e-44*(1.0 - cos(theta)**2)**13*(2.73397227204101e+56*cos(theta)**27 - 9.13927873796566e+56*cos(theta)**25 + 1.33096292300471e+57*cos(theta)**23 - 1.11133207762439e+57*cos(theta)**21 + 5.89342768437178e+56*cos(theta)**19 - 2.07788893613933e+56*cos(theta)**17 + 4.95777009324471e+55*cos(theta)**15 - 7.99640337620115e+54*cos(theta)**13 + 8.5675750459298e+53*cos(theta)**11 - 5.88285427623145e+52*cos(theta)**9 + 2.43428452809577e+51*cos(theta)**7 - 5.46737701497446e+49*cos(theta)**5 + 5.489334352384e+47*cos(theta)**3 - 1.56391292090712e+45*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl53_m27(theta, phi):
    return 3.0977588530478e-46*(1.0 - cos(theta)**2)**13.5*(7.38172513451072e+57*cos(theta)**26 - 2.28481968449141e+58*cos(theta)**24 + 3.06121472291083e+58*cos(theta)**22 - 2.33379736301122e+58*cos(theta)**20 + 1.11975126003064e+58*cos(theta)**18 - 3.53241119143686e+57*cos(theta)**16 + 7.43665513986707e+56*cos(theta)**14 - 1.03953243890615e+56*cos(theta)**12 + 9.42433255052278e+54*cos(theta)**10 - 5.2945688486083e+53*cos(theta)**8 + 1.70399916966704e+52*cos(theta)**6 - 2.73368850748723e+50*cos(theta)**4 + 1.6468003057152e+48*cos(theta)**2 - 1.56391292090712e+45)*cos(27*phi)

#@torch.jit.script
def Yl53_m28(theta, phi):
    return 6.75022770944253e-48*(1.0 - cos(theta)**2)**14*(1.91924853497279e+59*cos(theta)**25 - 5.48356724277939e+59*cos(theta)**23 + 6.73467239040382e+59*cos(theta)**21 - 4.66759472602245e+59*cos(theta)**19 + 2.01555226805515e+59*cos(theta)**17 - 5.65185790629897e+58*cos(theta)**15 + 1.04113171958139e+58*cos(theta)**13 - 1.24743892668738e+57*cos(theta)**11 + 9.42433255052278e+55*cos(theta)**9 - 4.23565507888664e+54*cos(theta)**7 + 1.02239950180022e+53*cos(theta)**5 - 1.09347540299489e+51*cos(theta)**3 + 3.2936006114304e+48*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl53_m29(theta, phi):
    return 1.49087589461291e-49*(1.0 - cos(theta)**2)**14.5*(4.79812133743197e+60*cos(theta)**24 - 1.26122046583926e+61*cos(theta)**22 + 1.4142812019848e+61*cos(theta)**20 - 8.86842997944265e+60*cos(theta)**18 + 3.42643885569375e+60*cos(theta)**16 - 8.47778685944846e+59*cos(theta)**14 + 1.35347123545581e+59*cos(theta)**12 - 1.37218281935612e+58*cos(theta)**10 + 8.4818992954705e+56*cos(theta)**8 - 2.96495855522065e+55*cos(theta)**6 + 5.11199750900112e+53*cos(theta)**4 - 3.28042620898468e+51*cos(theta)**2 + 3.2936006114304e+48)*cos(29*phi)

#@torch.jit.script
def Yl53_m30(theta, phi):
    return 3.34038731517029e-51*(1.0 - cos(theta)**2)**15*(1.15154912098367e+62*cos(theta)**23 - 2.77468502484637e+62*cos(theta)**21 + 2.8285624039696e+62*cos(theta)**19 - 1.59631739629968e+62*cos(theta)**17 + 5.48230216911e+61*cos(theta)**15 - 1.18689016032278e+61*cos(theta)**13 + 1.62416548254697e+60*cos(theta)**11 - 1.37218281935612e+59*cos(theta)**9 + 6.7855194363764e+57*cos(theta)**7 - 1.77897513313239e+56*cos(theta)**5 + 2.04479900360045e+54*cos(theta)**3 - 6.56085241796935e+51*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl53_m31(theta, phi):
    return 7.59964428425149e-53*(1.0 - cos(theta)**2)**15.5*(2.64856297826245e+63*cos(theta)**22 - 5.82683855217738e+63*cos(theta)**20 + 5.37426856754225e+63*cos(theta)**18 - 2.71373957370945e+63*cos(theta)**16 + 8.223453253665e+62*cos(theta)**14 - 1.54295720841962e+62*cos(theta)**12 + 1.78658203080166e+61*cos(theta)**10 - 1.23496453742051e+60*cos(theta)**8 + 4.74986360546348e+58*cos(theta)**6 - 8.89487566566195e+56*cos(theta)**4 + 6.13439701080135e+54*cos(theta)**2 - 6.56085241796935e+51)*cos(31*phi)

#@torch.jit.script
def Yl53_m32(theta, phi):
    return 1.75740744345409e-54*(1.0 - cos(theta)**2)**16*(5.82683855217738e+64*cos(theta)**21 - 1.16536771043548e+65*cos(theta)**19 + 9.67368342157604e+64*cos(theta)**17 - 4.34198331793512e+64*cos(theta)**15 + 1.1512834555131e+64*cos(theta)**13 - 1.85154865010354e+63*cos(theta)**11 + 1.78658203080166e+62*cos(theta)**9 - 9.87971629936404e+60*cos(theta)**7 + 2.84991816327809e+59*cos(theta)**5 - 3.55795026626478e+57*cos(theta)**3 + 1.22687940216027e+55*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl53_m33(theta, phi):
    return 4.13536253170053e-56*(1.0 - cos(theta)**2)**16.5*(1.22363609595725e+66*cos(theta)**20 - 2.21419864982741e+66*cos(theta)**18 + 1.64452618166793e+66*cos(theta)**16 - 6.51297497690268e+65*cos(theta)**14 + 1.49666849216703e+65*cos(theta)**12 - 2.0367035151139e+64*cos(theta)**10 + 1.6079238277215e+63*cos(theta)**8 - 6.91580140955483e+61*cos(theta)**6 + 1.42495908163904e+60*cos(theta)**4 - 1.06738507987943e+58*cos(theta)**2 + 1.22687940216027e+55)*cos(33*phi)

#@torch.jit.script
def Yl53_m34(theta, phi):
    return 9.91377286144046e-58*(1.0 - cos(theta)**2)**17*(2.4472721919145e+67*cos(theta)**19 - 3.98555756968933e+67*cos(theta)**17 + 2.63124189066868e+67*cos(theta)**15 - 9.11816496766376e+66*cos(theta)**13 + 1.79600219060044e+66*cos(theta)**11 - 2.0367035151139e+65*cos(theta)**9 + 1.2863390621772e+64*cos(theta)**7 - 4.1494808457329e+62*cos(theta)**5 + 5.69983632655618e+60*cos(theta)**3 - 2.13477015975887e+58*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl53_m35(theta, phi):
    return 2.42449240418619e-59*(1.0 - cos(theta)**2)**17.5*(4.64981716463755e+68*cos(theta)**18 - 6.77544786847186e+68*cos(theta)**16 + 3.94686283600303e+68*cos(theta)**14 - 1.18536144579629e+68*cos(theta)**12 + 1.97560240966048e+67*cos(theta)**10 - 1.83303316360251e+66*cos(theta)**8 + 9.00437343524039e+64*cos(theta)**6 - 2.07474042286645e+63*cos(theta)**4 + 1.70995089796685e+61*cos(theta)**2 - 2.13477015975887e+58)*cos(35*phi)

#@torch.jit.script
def Yl53_m36(theta, phi):
    return 6.05744628889105e-61*(1.0 - cos(theta)**2)**18*(8.36967089634759e+69*cos(theta)**17 - 1.0840716589555e+70*cos(theta)**15 + 5.52560797040424e+69*cos(theta)**13 - 1.42243373495555e+69*cos(theta)**11 + 1.97560240966048e+68*cos(theta)**9 - 1.46642653088201e+67*cos(theta)**7 + 5.40262406114423e+65*cos(theta)**5 - 8.29896169146579e+63*cos(theta)**3 + 3.41990179593371e+61*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl53_m37(theta, phi):
    return 1.54861640846762e-62*(1.0 - cos(theta)**2)**18.5*(1.42284405237909e+71*cos(theta)**16 - 1.62610748843325e+71*cos(theta)**14 + 7.18329036152551e+70*cos(theta)**12 - 1.5646771084511e+70*cos(theta)**10 + 1.77804216869443e+69*cos(theta)**8 - 1.0264985716174e+68*cos(theta)**6 + 2.70131203057212e+66*cos(theta)**4 - 2.48968850743974e+64*cos(theta)**2 + 3.41990179593371e+61)*cos(37*phi)

#@torch.jit.script
def Yl53_m38(theta, phi):
    return 4.05847774723841e-64*(1.0 - cos(theta)**2)**19*(2.27655048380654e+72*cos(theta)**15 - 2.27655048380654e+72*cos(theta)**13 + 8.61994843383061e+71*cos(theta)**11 - 1.5646771084511e+71*cos(theta)**9 + 1.42243373495555e+70*cos(theta)**7 - 6.15899142970443e+68*cos(theta)**5 + 1.08052481222885e+67*cos(theta)**3 - 4.97937701487948e+64*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl53_m39(theta, phi):
    return 1.09250548450948e-65*(1.0 - cos(theta)**2)**19.5*(3.41482572570982e+73*cos(theta)**14 - 2.95951562894851e+73*cos(theta)**12 + 9.48194327721367e+72*cos(theta)**10 - 1.40820939760599e+72*cos(theta)**8 + 9.95703614468882e+70*cos(theta)**6 - 3.07949571485221e+69*cos(theta)**4 + 3.24157443668654e+67*cos(theta)**2 - 4.97937701487948e+64)*cos(39*phi)

#@torch.jit.script
def Yl53_m40(theta, phi):
    return 3.02773689987996e-67*(1.0 - cos(theta)**2)**20*(4.78075601599374e+74*cos(theta)**13 - 3.55141875473821e+74*cos(theta)**11 + 9.48194327721367e+73*cos(theta)**9 - 1.12656751808479e+73*cos(theta)**7 + 5.97422168681329e+71*cos(theta)**5 - 1.23179828594089e+70*cos(theta)**3 + 6.48314887337308e+67*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl53_m41(theta, phi):
    return 8.66128901804633e-69*(1.0 - cos(theta)**2)**20.5*(6.21498282079187e+75*cos(theta)**12 - 3.90656063021203e+75*cos(theta)**10 + 8.5337489494923e+74*cos(theta)**8 - 7.88597262659355e+73*cos(theta)**6 + 2.98711084340665e+72*cos(theta)**4 - 3.69539485782266e+70*cos(theta)**2 + 6.48314887337308e+67)*cos(41*phi)

#@torch.jit.script
def Yl53_m42(theta, phi):
    return 2.56525241489345e-70*(1.0 - cos(theta)**2)**21*(7.45797938495024e+76*cos(theta)**11 - 3.90656063021203e+76*cos(theta)**9 + 6.82699915959384e+75*cos(theta)**7 - 4.73158357595613e+74*cos(theta)**5 + 1.19484433736266e+73*cos(theta)**3 - 7.39078971564531e+70*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl53_m43(theta, phi):
    return 7.89401861218921e-72*(1.0 - cos(theta)**2)**21.5*(8.20377732344527e+77*cos(theta)**10 - 3.51590456719083e+77*cos(theta)**8 + 4.77889941171569e+76*cos(theta)**6 - 2.36579178797806e+75*cos(theta)**4 + 3.58453301208798e+73*cos(theta)**2 - 7.39078971564531e+70)*cos(43*phi)

#@torch.jit.script
def Yl53_m44(theta, phi):
    return 2.53461662343494e-73*(1.0 - cos(theta)**2)**22*(8.20377732344527e+78*cos(theta)**9 - 2.81272365375266e+78*cos(theta)**7 + 2.86733964702941e+77*cos(theta)**5 - 9.46316715191225e+75*cos(theta)**3 + 7.16906602417595e+73*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl53_m45(theta, phi):
    return 8.5344981054238e-75*(1.0 - cos(theta)**2)**22.5*(7.38339959110074e+79*cos(theta)**8 - 1.96890655762686e+79*cos(theta)**6 + 1.43366982351471e+78*cos(theta)**4 - 2.83895014557368e+76*cos(theta)**2 + 7.16906602417595e+73)*cos(45*phi)

#@torch.jit.script
def Yl53_m46(theta, phi):
    return 3.03260184968659e-76*(1.0 - cos(theta)**2)**23*(5.90671967288059e+80*cos(theta)**7 - 1.18134393457612e+80*cos(theta)**5 + 5.73467929405883e+78*cos(theta)**3 - 5.67790029114735e+76*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl53_m47(theta, phi):
    return 1.1462157599636e-77*(1.0 - cos(theta)**2)**23.5*(4.13470377101641e+81*cos(theta)**6 - 5.90671967288059e+80*cos(theta)**4 + 1.72040378821765e+79*cos(theta)**2 - 5.67790029114735e+76)*cos(47*phi)

#@torch.jit.script
def Yl53_m48(theta, phi):
    return 4.65618324195425e-79*(1.0 - cos(theta)**2)**24*(2.48082226260985e+82*cos(theta)**5 - 2.36268786915224e+81*cos(theta)**3 + 3.4408075764353e+79*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl53_m49(theta, phi):
    return 2.06179259443851e-80*(1.0 - cos(theta)**2)**24.5*(1.24041113130492e+83*cos(theta)**4 - 7.08806360745671e+81*cos(theta)**2 + 3.4408075764353e+79)*cos(49*phi)

#@torch.jit.script
def Yl53_m50(theta, phi):
    return 1.01577230440129e-81*(1.0 - cos(theta)**2)**25*(4.9616445252197e+83*cos(theta)**3 - 1.41761272149134e+82*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl53_m51(theta, phi):
    return 5.75067826096859e-83*(1.0 - cos(theta)**2)**25.5*(1.48849335756591e+84*cos(theta)**2 - 1.41761272149134e+82)*cos(51*phi)

#@torch.jit.script
def Yl53_m52(theta, phi):
    return 11.8137103780719*(1.0 - cos(theta)**2)**26*cos(52*phi)*cos(theta)

#@torch.jit.script
def Yl53_m53(theta, phi):
    return 1.14744898722045*(1.0 - cos(theta)**2)**26.5*cos(53*phi)

#@torch.jit.script
def Yl54_m_minus_54(theta, phi):
    return 1.15274901074596*(1.0 - cos(theta)**2)**27*sin(54*phi)

#@torch.jit.script
def Yl54_m_minus_53(theta, phi):
    return 11.9797191299205*(1.0 - cos(theta)**2)**26.5*sin(53*phi)*cos(theta)

#@torch.jit.script
def Yl54_m_minus_52(theta, phi):
    return 5.50164860682572e-85*(1.0 - cos(theta)**2)**26*(1.59268789259552e+86*cos(theta)**2 - 1.48849335756591e+84)*sin(52*phi)

#@torch.jit.script
def Yl54_m_minus_51(theta, phi):
    return 9.81084486217675e-84*(1.0 - cos(theta)**2)**25.5*(5.30895964198508e+85*cos(theta)**3 - 1.48849335756591e+84*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl54_m_minus_50(theta, phi):
    return 2.01062488550386e-82*(1.0 - cos(theta)**2)**25*(1.32723991049627e+85*cos(theta)**4 - 7.44246678782954e+83*cos(theta)**2 + 3.54403180372835e+81)*sin(50*phi)

#@torch.jit.script
def Yl54_m_minus_49(theta, phi):
    return 4.58493016708853e-81*(1.0 - cos(theta)**2)**24.5*(2.65447982099254e+84*cos(theta)**5 - 2.48082226260985e+83*cos(theta)**3 + 3.54403180372835e+81*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl54_m_minus_48(theta, phi):
    return 1.13979556525346e-79*(1.0 - cos(theta)**2)**24*(4.42413303498756e+83*cos(theta)**6 - 6.20205565652462e+82*cos(theta)**4 + 1.77201590186418e+81*cos(theta)**2 - 5.73467929405883e+78)*sin(48*phi)

#@torch.jit.script
def Yl54_m_minus_47(theta, phi):
    return 3.04562247566571e-78*(1.0 - cos(theta)**2)**23.5*(6.32019004998223e+82*cos(theta)**7 - 1.24041113130492e+82*cos(theta)**5 + 5.90671967288059e+80*cos(theta)**3 - 5.73467929405883e+78*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl54_m_minus_46(theta, phi):
    return 8.6572856840573e-77*(1.0 - cos(theta)**2)**23*(7.90023756247779e+81*cos(theta)**8 - 2.06735188550821e+81*cos(theta)**6 + 1.47667991822015e+80*cos(theta)**4 - 2.86733964702941e+78*cos(theta)**2 + 7.09737536393419e+75)*sin(46*phi)

#@torch.jit.script
def Yl54_m_minus_45(theta, phi):
    return 2.59718570521719e-75*(1.0 - cos(theta)**2)**22.5*(8.77804173608644e+80*cos(theta)**9 - 2.9533598364403e+80*cos(theta)**7 + 2.9533598364403e+79*cos(theta)**5 - 9.55779882343138e+77*cos(theta)**3 + 7.09737536393419e+75*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl54_m_minus_44(theta, phi):
    return 8.17185404391848e-74*(1.0 - cos(theta)**2)**22*(8.77804173608644e+79*cos(theta)**10 - 3.69169979555037e+79*cos(theta)**8 + 4.92226639406716e+78*cos(theta)**6 - 2.38944970585784e+77*cos(theta)**4 + 3.5486876819671e+75*cos(theta)**2 - 7.16906602417595e+72)*sin(44*phi)

#@torch.jit.script
def Yl54_m_minus_43(theta, phi):
    return 2.68305750962004e-72*(1.0 - cos(theta)**2)**21.5*(7.98003794189676e+78*cos(theta)**11 - 4.10188866172263e+78*cos(theta)**9 + 7.03180913438166e+77*cos(theta)**7 - 4.77889941171569e+76*cos(theta)**5 + 1.18289589398903e+75*cos(theta)**3 - 7.16906602417595e+72*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl54_m_minus_42(theta, phi):
    return 9.15390649193927e-71*(1.0 - cos(theta)**2)**21*(6.6500316182473e+77*cos(theta)**12 - 4.10188866172263e+77*cos(theta)**10 + 8.78976141797707e+76*cos(theta)**8 - 7.96483235285948e+75*cos(theta)**6 + 2.95723973497258e+74*cos(theta)**4 - 3.58453301208798e+72*cos(theta)**2 + 6.15899142970443e+69)*sin(42*phi)

#@torch.jit.script
def Yl54_m_minus_41(theta, phi):
    return 3.23380452518134e-69*(1.0 - cos(theta)**2)**20.5*(5.11540893711331e+76*cos(theta)**13 - 3.72898969247512e+76*cos(theta)**11 + 9.76640157553008e+75*cos(theta)**9 - 1.13783319326564e+75*cos(theta)**7 + 5.91447946994516e+73*cos(theta)**5 - 1.19484433736266e+72*cos(theta)**3 + 6.15899142970443e+69*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl54_m_minus_40(theta, phi):
    return 1.1793415099292e-67*(1.0 - cos(theta)**2)**20*(3.65386352650951e+75*cos(theta)**14 - 3.10749141039593e+75*cos(theta)**12 + 9.76640157553008e+74*cos(theta)**10 - 1.42229149158205e+74*cos(theta)**8 + 9.85746578324193e+72*cos(theta)**6 - 2.98711084340665e+71*cos(theta)**4 + 3.07949571485221e+69*cos(theta)**2 - 4.63082062383791e+66)*sin(40*phi)

#@torch.jit.script
def Yl54_m_minus_39(theta, phi):
    return 4.42842344387858e-66*(1.0 - cos(theta)**2)**19.5*(2.435909017673e+74*cos(theta)**15 - 2.39037800799687e+74*cos(theta)**13 + 8.87854688684553e+73*cos(theta)**11 - 1.58032387953561e+73*cos(theta)**9 + 1.40820939760599e+72*cos(theta)**7 - 5.97422168681329e+70*cos(theta)**5 + 1.0264985716174e+69*cos(theta)**3 - 4.63082062383791e+66*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl54_m_minus_38(theta, phi):
    return 1.70824676458235e-64*(1.0 - cos(theta)**2)**19*(1.52244313604563e+73*cos(theta)**16 - 1.70741286285491e+73*cos(theta)**14 + 7.39878907237127e+72*cos(theta)**12 - 1.58032387953561e+72*cos(theta)**10 + 1.76026174700749e+71*cos(theta)**8 - 9.95703614468882e+69*cos(theta)**6 + 2.56624642904351e+68*cos(theta)**4 - 2.31541031191896e+66*cos(theta)**2 + 3.11211063429967e+63)*sin(38*phi)

#@torch.jit.script
def Yl54_m_minus_37(theta, phi):
    return 6.75567861995838e-63*(1.0 - cos(theta)**2)**18.5*(8.95554785909192e+71*cos(theta)**17 - 1.13827524190327e+72*cos(theta)**15 + 5.69137620951636e+71*cos(theta)**13 - 1.4366580723051e+71*cos(theta)**11 + 1.95584638556388e+70*cos(theta)**9 - 1.42243373495555e+69*cos(theta)**7 + 5.13249285808702e+67*cos(theta)**5 - 7.71803437306319e+65*cos(theta)**3 + 3.11211063429967e+63*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl54_m_minus_36(theta, phi):
    return 2.73417261970188e-61*(1.0 - cos(theta)**2)**18*(4.97530436616218e+70*cos(theta)**18 - 7.11422026189545e+70*cos(theta)**16 + 4.06526872108312e+70*cos(theta)**14 - 1.19721506025425e+70*cos(theta)**12 + 1.95584638556388e+69*cos(theta)**10 - 1.77804216869443e+68*cos(theta)**8 + 8.55415476347837e+66*cos(theta)**6 - 1.9295085932658e+65*cos(theta)**4 + 1.55605531714984e+63*cos(theta)**2 - 1.89994544218539e+60)*sin(36*phi)

#@torch.jit.script
def Yl54_m_minus_35(theta, phi):
    return 1.13063906059803e-59*(1.0 - cos(theta)**2)**17.5*(2.61858124534852e+69*cos(theta)**19 - 4.1848354481738e+69*cos(theta)**17 + 2.71017914738874e+69*cos(theta)**15 - 9.20934661734039e+68*cos(theta)**13 + 1.77804216869443e+68*cos(theta)**11 - 1.97560240966048e+67*cos(theta)**9 + 1.22202210906834e+66*cos(theta)**7 - 3.85901718653159e+64*cos(theta)**5 + 5.18685105716612e+62*cos(theta)**3 - 1.89994544218539e+60*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl54_m_minus_34(theta, phi):
    return 4.77017142241554e-58*(1.0 - cos(theta)**2)**17*(1.30929062267426e+68*cos(theta)**20 - 2.32490858231878e+68*cos(theta)**18 + 1.69386196711797e+68*cos(theta)**16 - 6.57810472667171e+67*cos(theta)**14 + 1.48170180724536e+67*cos(theta)**12 - 1.97560240966048e+66*cos(theta)**10 + 1.52752763633542e+65*cos(theta)**8 - 6.43169531088599e+63*cos(theta)**6 + 1.29671276429153e+62*cos(theta)**4 - 9.49972721092696e+59*cos(theta)**2 + 1.06738507987943e+57)*sin(34*phi)

#@torch.jit.script
def Yl54_m_minus_33(theta, phi):
    return 2.05061896552667e-56*(1.0 - cos(theta)**2)**16.5*(6.2347172508298e+66*cos(theta)**21 - 1.22363609595725e+67*cos(theta)**19 + 9.96389392422332e+66*cos(theta)**17 - 4.38540315111447e+66*cos(theta)**15 + 1.13977062095797e+66*cos(theta)**13 - 1.79600219060044e+65*cos(theta)**11 + 1.69725292926158e+64*cos(theta)**9 - 9.18813615840856e+62*cos(theta)**7 + 2.59342552858306e+61*cos(theta)**5 - 3.16657573697565e+59*cos(theta)**3 + 1.06738507987943e+57*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl54_m_minus_32(theta, phi):
    return 8.97131150020023e-55*(1.0 - cos(theta)**2)**16*(2.83396238674082e+65*cos(theta)**22 - 6.11818047978625e+65*cos(theta)**20 + 5.53549662456851e+65*cos(theta)**18 - 2.74087696944655e+65*cos(theta)**16 + 8.14121872112835e+64*cos(theta)**14 - 1.49666849216703e+64*cos(theta)**12 + 1.69725292926158e+63*cos(theta)**10 - 1.14851701980107e+62*cos(theta)**8 + 4.32237588097177e+60*cos(theta)**6 - 7.91643934243914e+58*cos(theta)**4 + 5.33692539939717e+56*cos(theta)**2 - 5.57672455527395e+53)*sin(32*phi)

#@torch.jit.script
def Yl54_m_minus_31(theta, phi):
    return 3.98996494478974e-53*(1.0 - cos(theta)**2)**15.5*(1.23215755945253e+64*cos(theta)**23 - 2.91341927608869e+64*cos(theta)**21 + 2.91341927608869e+64*cos(theta)**19 - 1.61228057026267e+64*cos(theta)**17 + 5.4274791474189e+63*cos(theta)**15 - 1.1512834555131e+63*cos(theta)**13 + 1.54295720841962e+62*cos(theta)**11 - 1.27613002200119e+61*cos(theta)**9 + 6.17482268710253e+59*cos(theta)**7 - 1.58328786848783e+58*cos(theta)**5 + 1.77897513313239e+56*cos(theta)**3 - 5.57672455527395e+53*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl54_m_minus_30(theta, phi):
    return 1.80212189742337e-51*(1.0 - cos(theta)**2)**15*(5.13398983105221e+62*cos(theta)**24 - 1.32428148913122e+63*cos(theta)**22 + 1.45670963804435e+63*cos(theta)**20 - 8.95711427923708e+62*cos(theta)**18 + 3.39217446713681e+62*cos(theta)**16 - 8.223453253665e+61*cos(theta)**14 + 1.28579767368302e+61*cos(theta)**12 - 1.27613002200119e+60*cos(theta)**10 + 7.71852835887816e+58*cos(theta)**8 - 2.63881311414638e+57*cos(theta)**6 + 4.44743783283098e+55*cos(theta)**4 - 2.78836227763698e+53*cos(theta)**2 + 2.73368850748723e+50)*sin(30*phi)

#@torch.jit.script
def Yl54_m_minus_29(theta, phi):
    return 8.25836000648004e-50*(1.0 - cos(theta)**2)**14.5*(2.05359593242088e+61*cos(theta)**25 - 5.75774560491836e+61*cos(theta)**23 + 6.93671256211593e+61*cos(theta)**21 - 4.71427067328267e+61*cos(theta)**19 + 1.9953967453746e+61*cos(theta)**17 - 5.48230216911e+60*cos(theta)**15 + 9.8907513360232e+59*cos(theta)**13 - 1.16011820181926e+59*cos(theta)**11 + 8.57614262097573e+57*cos(theta)**9 - 3.76973302020911e+56*cos(theta)**7 + 8.89487566566195e+54*cos(theta)**5 - 9.29454092545658e+52*cos(theta)**3 + 2.73368850748723e+50*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl54_m_minus_28(theta, phi):
    return 3.83636156498218e-48*(1.0 - cos(theta)**2)**14*(7.89844589392647e+59*cos(theta)**26 - 2.39906066871598e+60*cos(theta)**24 + 3.15305116459815e+60*cos(theta)**22 - 2.35713533664134e+60*cos(theta)**20 + 1.10855374743033e+60*cos(theta)**18 - 3.42643885569375e+59*cos(theta)**16 + 7.06482238287371e+58*cos(theta)**14 - 9.66765168182719e+57*cos(theta)**12 + 8.57614262097573e+56*cos(theta)**10 - 4.71216627526139e+55*cos(theta)**8 + 1.48247927761033e+54*cos(theta)**6 - 2.32363523136415e+52*cos(theta)**4 + 1.36684425374362e+50*cos(theta)**2 - 1.26676946593477e+47)*sin(28*phi)

#@torch.jit.script
def Yl54_m_minus_27(theta, phi):
    return 1.80512939998221e-46*(1.0 - cos(theta)**2)**13.5*(2.92535033108388e+58*cos(theta)**27 - 9.59624267486394e+58*cos(theta)**25 + 1.37089181069485e+59*cos(theta)**23 - 1.12244539840064e+59*cos(theta)**21 + 5.83449340752806e+58*cos(theta)**19 - 2.01555226805515e+58*cos(theta)**17 + 4.70988158858248e+57*cos(theta)**15 - 7.43665513986707e+56*cos(theta)**13 + 7.79649329179612e+55*cos(theta)**11 - 5.23574030584599e+54*cos(theta)**9 + 2.11782753944332e+53*cos(theta)**7 - 4.64727046272829e+51*cos(theta)**5 + 4.55614751247872e+49*cos(theta)**3 - 1.26676946593477e+47*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl54_m_minus_26(theta, phi):
    return 8.59666225795951e-45*(1.0 - cos(theta)**2)**13*(1.0447679753871e+57*cos(theta)**28 - 3.69086256725536e+57*cos(theta)**26 + 5.71204921122853e+57*cos(theta)**24 - 5.10202453818471e+57*cos(theta)**22 + 2.91724670376403e+57*cos(theta)**20 - 1.11975126003064e+57*cos(theta)**18 + 2.94367599286405e+56*cos(theta)**16 - 5.31189652847648e+55*cos(theta)**14 + 6.49707774316343e+54*cos(theta)**12 - 5.23574030584599e+53*cos(theta)**10 + 2.64728442430415e+52*cos(theta)**8 - 7.74545077121382e+50*cos(theta)**6 + 1.13903687811968e+49*cos(theta)**4 - 6.33384732967384e+46*cos(theta)**2 + 5.58540328895401e+43)*sin(26*phi)

#@torch.jit.script
def Yl54_m_minus_25(theta, phi):
    return 4.14070086564614e-43*(1.0 - cos(theta)**2)**12.5*(3.60264819099e+55*cos(theta)**29 - 1.3669861360205e+56*cos(theta)**27 + 2.28481968449141e+56*cos(theta)**25 - 2.21827153834118e+56*cos(theta)**23 + 1.38916509703049e+56*cos(theta)**21 - 5.89342768437178e+55*cos(theta)**19 + 1.73157411344944e+55*cos(theta)**17 - 3.54126435231765e+54*cos(theta)**15 + 4.99775211012572e+53*cos(theta)**13 - 4.75976391440545e+52*cos(theta)**11 + 2.94142713811572e+51*cos(theta)**9 - 1.10649296731626e+50*cos(theta)**7 + 2.27807375623936e+48*cos(theta)**5 - 2.11128244322461e+46*cos(theta)**3 + 5.58540328895401e+43*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl54_m_minus_24(theta, phi):
    return 2.01580273517196e-41*(1.0 - cos(theta)**2)**12*(1.20088273033e+54*cos(theta)**30 - 4.88209334293037e+54*cos(theta)**28 + 8.78776801727467e+54*cos(theta)**26 - 9.24279807642158e+54*cos(theta)**24 + 6.31438680468405e+54*cos(theta)**22 - 2.94671384218589e+54*cos(theta)**20 + 9.61985618583022e+53*cos(theta)**18 - 2.21329022019853e+53*cos(theta)**16 + 3.56982293580408e+52*cos(theta)**14 - 3.9664699286712e+51*cos(theta)**12 + 2.94142713811572e+50*cos(theta)**10 - 1.38311620914532e+49*cos(theta)**8 + 3.79678959373226e+47*cos(theta)**6 - 5.27820610806154e+45*cos(theta)**4 + 2.792701644477e+43*cos(theta)**2 - 2.3567102485038e+40)*sin(24*phi)

#@torch.jit.script
def Yl54_m_minus_23(theta, phi):
    return 9.91233973041305e-40*(1.0 - cos(theta)**2)**11.5*(3.87381525912903e+52*cos(theta)**31 - 1.68348046307944e+53*cos(theta)**29 + 3.25472889528691e+53*cos(theta)**27 - 3.69711923056863e+53*cos(theta)**25 + 2.74538556725393e+53*cos(theta)**23 - 1.40319706770757e+53*cos(theta)**21 + 5.06308220306854e+52*cos(theta)**19 - 1.3019354236462e+52*cos(theta)**17 + 2.37988195720272e+51*cos(theta)**15 - 3.05113071436246e+50*cos(theta)**13 + 2.6740246710143e+49*cos(theta)**11 - 1.53679578793925e+48*cos(theta)**9 + 5.42398513390323e+46*cos(theta)**7 - 1.05564122161231e+45*cos(theta)**5 + 9.30900548159001e+42*cos(theta)**3 - 2.3567102485038e+40*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl54_m_minus_22(theta, phi):
    return 4.9203560449046e-38*(1.0 - cos(theta)**2)**11*(1.21056726847782e+51*cos(theta)**32 - 5.61160154359813e+51*cos(theta)**30 + 1.16240317688818e+52*cos(theta)**28 - 1.42196893483409e+52*cos(theta)**26 + 1.14391065302247e+52*cos(theta)**24 - 6.37816848957984e+51*cos(theta)**22 + 2.53154110153427e+51*cos(theta)**20 - 7.2329745758122e+50*cos(theta)**18 + 1.4874262232517e+50*cos(theta)**16 - 2.17937908168747e+49*cos(theta)**14 + 2.22835389251191e+48*cos(theta)**12 - 1.53679578793925e+47*cos(theta)**10 + 6.77998141737904e+45*cos(theta)**8 - 1.75940203602051e+44*cos(theta)**6 + 2.3272513703975e+42*cos(theta)**4 - 1.1783551242519e+40*cos(theta)**2 + 9.56457081373295e+36)*sin(22*phi)

#@torch.jit.script
def Yl54_m_minus_21(theta, phi):
    return 2.46411116328874e-36*(1.0 - cos(theta)**2)**10.5*(3.66838566205401e+49*cos(theta)**33 - 1.81019404632198e+50*cos(theta)**31 + 4.00828681685581e+50*cos(theta)**29 - 5.26655161049662e+50*cos(theta)**27 + 4.57564261208989e+50*cos(theta)**25 - 2.77311673459993e+50*cos(theta)**23 + 1.20549576263537e+50*cos(theta)**21 - 3.80682872411168e+49*cos(theta)**19 + 8.74956601912766e+48*cos(theta)**17 - 1.45291938779165e+48*cos(theta)**15 + 1.71411837885532e+47*cos(theta)**13 - 1.39708707994477e+46*cos(theta)**11 + 7.53331268597672e+44*cos(theta)**9 - 2.5134314800293e+43*cos(theta)**7 + 4.654502740795e+41*cos(theta)**5 - 3.927850414173e+39*cos(theta)**3 + 9.56457081373295e+36*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl54_m_minus_20(theta, phi):
    return 1.24431514311539e-34*(1.0 - cos(theta)**2)**10*(1.07893695942765e+48*cos(theta)**34 - 5.65685639475618e+48*cos(theta)**32 + 1.3360956056186e+49*cos(theta)**30 - 1.88091128946308e+49*cos(theta)**28 + 1.7598625431115e+49*cos(theta)**26 - 1.15546530608331e+49*cos(theta)**24 + 5.47952619379712e+48*cos(theta)**22 - 1.90341436205584e+48*cos(theta)**20 + 4.86087001062648e+47*cos(theta)**18 - 9.08074617369781e+46*cos(theta)**16 + 1.22437027061094e+46*cos(theta)**14 - 1.16423923328731e+45*cos(theta)**12 + 7.53331268597672e+43*cos(theta)**10 - 3.14178935003663e+42*cos(theta)**8 + 7.75750456799167e+40*cos(theta)**6 - 9.8196260354325e+38*cos(theta)**4 + 4.78228540686648e+36*cos(theta)**2 - 3.75081208381684e+33)*sin(20*phi)

#@torch.jit.script
def Yl54_m_minus_19(theta, phi):
    return 6.33257392712509e-33*(1.0 - cos(theta)**2)**9.5*(3.08267702693614e+46*cos(theta)**35 - 1.71419890750187e+47*cos(theta)**33 + 4.30998582457614e+47*cos(theta)**31 - 6.48590099814855e+47*cos(theta)**29 + 6.51800941893147e+47*cos(theta)**27 - 4.62186122433322e+47*cos(theta)**25 + 2.38240269295527e+47*cos(theta)**23 - 9.06387791455162e+46*cos(theta)**21 + 2.55835263717183e+46*cos(theta)**19 - 5.34161539629283e+45*cos(theta)**17 + 8.16246847073961e+44*cos(theta)**15 - 8.95568640990239e+43*cos(theta)**13 + 6.84846607816065e+42*cos(theta)**11 - 3.49087705559625e+41*cos(theta)**9 + 1.10821493828453e+40*cos(theta)**7 - 1.9639252070865e+38*cos(theta)**5 + 1.59409513562216e+36*cos(theta)**3 - 3.75081208381684e+33*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl54_m_minus_18(theta, phi):
    return 3.24633212105142e-31*(1.0 - cos(theta)**2)**9*(8.56299174148928e+44*cos(theta)**36 - 5.04176149265256e+45*cos(theta)**34 + 1.34687057018004e+46*cos(theta)**32 - 2.16196699938285e+46*cos(theta)**30 + 2.32786050676124e+46*cos(theta)**28 - 1.77763893243585e+46*cos(theta)**26 + 9.92667788731362e+45*cos(theta)**24 - 4.11994450661437e+45*cos(theta)**22 + 1.27917631858591e+45*cos(theta)**20 - 2.96756410905157e+44*cos(theta)**18 + 5.10154279421225e+43*cos(theta)**16 - 6.39691886421599e+42*cos(theta)**14 + 5.70705506513388e+41*cos(theta)**12 - 3.49087705559625e+40*cos(theta)**10 + 1.38526867285566e+39*cos(theta)**8 - 3.2732086784775e+37*cos(theta)**6 + 3.9852378390554e+35*cos(theta)**4 - 1.87540604190842e+33*cos(theta)**2 + 1.42724965137627e+30)*sin(18*phi)

#@torch.jit.script
def Yl54_m_minus_17(theta, phi):
    return 1.67556028980796e-29*(1.0 - cos(theta)**2)**8.5*(2.3143220922944e+43*cos(theta)**37 - 1.44050328361502e+44*cos(theta)**35 + 4.08142597024255e+44*cos(theta)**33 - 6.97408709478339e+44*cos(theta)**31 + 8.02710519572841e+44*cos(theta)**29 - 6.58384789791057e+44*cos(theta)**27 + 3.97067115492545e+44*cos(theta)**25 - 1.79128022026712e+44*cos(theta)**23 + 6.09131580279007e+43*cos(theta)**21 - 1.56187584686925e+43*cos(theta)**19 + 3.00090752600721e+42*cos(theta)**17 - 4.26461257614399e+41*cos(theta)**15 + 4.39004235779529e+40*cos(theta)**13 - 3.17352459599659e+39*cos(theta)**11 + 1.53918741428406e+38*cos(theta)**9 - 4.676012397825e+36*cos(theta)**7 + 7.97047567811079e+34*cos(theta)**5 - 6.25135347302808e+32*cos(theta)**3 + 1.42724965137627e+30*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl54_m_minus_16(theta, phi):
    return 8.70324144462283e-28*(1.0 - cos(theta)**2)**8*(6.09032129551158e+41*cos(theta)**38 - 4.00139801004172e+42*cos(theta)**36 + 1.20041940301252e+43*cos(theta)**34 - 2.17940221711981e+43*cos(theta)**32 + 2.67570173190947e+43*cos(theta)**30 - 2.35137424925378e+43*cos(theta)**28 + 1.52718121343286e+43*cos(theta)**26 - 7.46366758444633e+42*cos(theta)**24 + 2.76877991035912e+42*cos(theta)**22 - 7.80937923434624e+41*cos(theta)**20 + 1.66717084778178e+41*cos(theta)**18 - 2.66538286009e+40*cos(theta)**16 + 3.13574454128235e+39*cos(theta)**14 - 2.64460382999716e+38*cos(theta)**12 + 1.53918741428406e+37*cos(theta)**10 - 5.84501549728125e+35*cos(theta)**8 + 1.32841261301847e+34*cos(theta)**6 - 1.56283836825702e+32*cos(theta)**4 + 7.13624825688136e+29*cos(theta)**2 - 5.29002835943763e+26)*sin(16*phi)

#@torch.jit.script
def Yl54_m_minus_15(theta, phi):
    return 4.54739160163806e-26*(1.0 - cos(theta)**2)**7.5*(1.56162084500297e+40*cos(theta)**39 - 1.0814589216329e+41*cos(theta)**37 + 3.4297697228929e+41*cos(theta)**35 - 6.6042491427873e+41*cos(theta)**33 + 8.63129590938538e+41*cos(theta)**31 - 8.10818706639233e+41*cos(theta)**29 + 5.65622671641802e+41*cos(theta)**27 - 2.98546703377853e+41*cos(theta)**25 + 1.20381735233005e+41*cos(theta)**23 - 3.71875201635535e+40*cos(theta)**21 + 8.7745834093778e+39*cos(theta)**19 - 1.56787227064117e+39*cos(theta)**17 + 2.0904963608549e+38*cos(theta)**15 - 2.03431063845936e+37*cos(theta)**13 + 1.39926128571278e+36*cos(theta)**11 - 6.49446166364583e+34*cos(theta)**9 + 1.89773230431209e+33*cos(theta)**7 - 3.12567673651404e+31*cos(theta)**5 + 2.37874941896045e+29*cos(theta)**3 - 5.29002835943763e+26*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl54_m_minus_14(theta, phi):
    return 2.38900410726037e-24*(1.0 - cos(theta)**2)**7*(3.90405211250742e+38*cos(theta)**40 - 2.84594453061289e+39*cos(theta)**38 + 9.52713811914695e+39*cos(theta)**36 - 1.94242621846685e+40*cos(theta)**34 + 2.69727997168293e+40*cos(theta)**32 - 2.70272902213078e+40*cos(theta)**30 + 2.02008097014929e+40*cos(theta)**28 - 1.14825655145328e+40*cos(theta)**26 + 5.01590563470856e+39*cos(theta)**24 - 1.69034182561607e+39*cos(theta)**22 + 4.3872917046889e+38*cos(theta)**20 - 8.71040150356208e+37*cos(theta)**18 + 1.30656022553431e+37*cos(theta)**16 - 1.45307902747097e+36*cos(theta)**14 + 1.16605107142732e+35*cos(theta)**12 - 6.49446166364583e+33*cos(theta)**10 + 2.37216538039012e+32*cos(theta)**8 - 5.2094612275234e+30*cos(theta)**6 + 5.94687354740114e+28*cos(theta)**4 - 2.64501417971882e+26*cos(theta)**2 + 1.91667694182523e+23)*sin(14*phi)

#@torch.jit.script
def Yl54_m_minus_13(theta, phi):
    return 1.26143036514606e-22*(1.0 - cos(theta)**2)**6.5*(9.52207832318883e+36*cos(theta)**41 - 7.29729366823817e+37*cos(theta)**39 + 2.57490219436404e+38*cos(theta)**37 - 5.54978919561958e+38*cos(theta)**35 + 8.17357567176646e+38*cos(theta)**33 - 8.71848071655089e+38*cos(theta)**31 + 6.96579644879066e+38*cos(theta)**29 - 4.25280204241956e+38*cos(theta)**27 + 2.00636225388342e+38*cos(theta)**25 - 7.34931228528726e+37*cos(theta)**23 + 2.08918652604233e+37*cos(theta)**21 - 4.58442184398004e+36*cos(theta)**19 + 7.68564838549595e+35*cos(theta)**17 - 9.68719351647312e+34*cos(theta)**15 + 8.969623626364e+33*cos(theta)**13 - 5.90405605785985e+32*cos(theta)**11 + 2.63573931154458e+31*cos(theta)**9 - 7.44208746789057e+29*cos(theta)**7 + 1.18937470948023e+28*cos(theta)**5 - 8.81671393239605e+25*cos(theta)**3 + 1.91667694182523e+23*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl54_m_minus_12(theta, phi):
    return 6.69152843305673e-21*(1.0 - cos(theta)**2)**6*(2.26716150552115e+35*cos(theta)**42 - 1.82432341705954e+36*cos(theta)**40 + 6.77605840622116e+36*cos(theta)**38 - 1.54160810989433e+37*cos(theta)**36 + 2.40399284463719e+37*cos(theta)**34 - 2.72452522392215e+37*cos(theta)**32 + 2.32193214959689e+37*cos(theta)**30 - 1.5188578722927e+37*cos(theta)**28 + 7.71677789955162e+36*cos(theta)**26 - 3.06221345220303e+36*cos(theta)**24 + 9.49630239110152e+35*cos(theta)**22 - 2.29221092199002e+35*cos(theta)**20 + 4.26980465860886e+34*cos(theta)**18 - 6.0544959477957e+33*cos(theta)**16 + 6.40687401883143e+32*cos(theta)**14 - 4.92004671488321e+31*cos(theta)**12 + 2.63573931154458e+30*cos(theta)**10 - 9.30260933486321e+28*cos(theta)**8 + 1.98229118246705e+27*cos(theta)**6 - 2.20417848309901e+25*cos(theta)**4 + 9.58338470912614e+22*cos(theta)**2 - 6.81121869873926e+19)*sin(12*phi)

#@torch.jit.script
def Yl54_m_minus_11(theta, phi):
    return 3.56477007340465e-19*(1.0 - cos(theta)**2)**5.5*(5.27246861749105e+33*cos(theta)**43 - 4.44956930990132e+34*cos(theta)**41 + 1.73745087339004e+35*cos(theta)**39 - 4.16650840511981e+35*cos(theta)**37 + 6.8685509846777e+35*cos(theta)**35 - 8.25613704218834e+35*cos(theta)**33 + 7.49010370837705e+35*cos(theta)**31 - 5.23744093894035e+35*cos(theta)**29 + 2.85806588872282e+35*cos(theta)**27 - 1.22488538088121e+35*cos(theta)**25 + 4.12882712656588e+34*cos(theta)**23 - 1.09152901047144e+34*cos(theta)**21 + 2.24726560979414e+33*cos(theta)**19 - 3.56146820458571e+32*cos(theta)**17 + 4.27124934588762e+31*cos(theta)**15 - 3.78465131914093e+30*cos(theta)**13 + 2.3961266468587e+29*cos(theta)**11 - 1.03362325942925e+28*cos(theta)**9 + 2.83184454638149e+26*cos(theta)**7 - 4.40835696619803e+24*cos(theta)**5 + 3.19446156970871e+22*cos(theta)**3 - 6.81121869873926e+19*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl54_m_minus_10(theta, phi):
    return 1.90640224071549e-17*(1.0 - cos(theta)**2)**5*(1.19828832215706e+32*cos(theta)**44 - 1.05942126426222e+33*cos(theta)**42 + 4.3436271834751e+33*cos(theta)**40 - 1.09644958029469e+34*cos(theta)**38 + 1.90793082907714e+34*cos(theta)**36 - 2.42827560064363e+34*cos(theta)**34 + 2.34065740886783e+34*cos(theta)**32 - 1.74581364631345e+34*cos(theta)**30 + 1.02073781740101e+34*cos(theta)**28 - 4.71109761877389e+33*cos(theta)**26 + 1.72034463606912e+33*cos(theta)**24 - 4.9614955021429e+32*cos(theta)**22 + 1.12363280489707e+32*cos(theta)**20 - 1.97859344699206e+31*cos(theta)**18 + 2.66953084117976e+30*cos(theta)**16 - 2.70332237081495e+29*cos(theta)**14 + 1.99677220571559e+28*cos(theta)**12 - 1.03362325942925e+27*cos(theta)**10 + 3.53980568297687e+25*cos(theta)**8 - 7.34726161033004e+23*cos(theta)**6 + 7.98615392427179e+21*cos(theta)**4 - 3.40560934936963e+19*cos(theta)**2 + 2.38154499955918e+16)*sin(10*phi)

#@torch.jit.script
def Yl54_m_minus_9(theta, phi):
    return 1.02308280064746e-15*(1.0 - cos(theta)**2)**4.5*(2.66286293812679e+30*cos(theta)**45 - 2.46377038200516e+31*cos(theta)**43 + 1.05942126426222e+32*cos(theta)**41 - 2.81140918024278e+32*cos(theta)**39 + 5.15656980831659e+32*cos(theta)**37 - 6.93793028755323e+32*cos(theta)**35 + 7.09290123899342e+32*cos(theta)**33 - 5.63165692359177e+32*cos(theta)**31 + 3.51978557724486e+32*cos(theta)**29 - 1.74485096991625e+32*cos(theta)**27 + 6.88137854427646e+31*cos(theta)**25 - 2.15717195745344e+31*cos(theta)**23 + 5.35063240427176e+30*cos(theta)**21 - 1.04136497210108e+30*cos(theta)**19 + 1.57031225951751e+29*cos(theta)**17 - 1.80221491387663e+28*cos(theta)**15 + 1.53597861978122e+27*cos(theta)**13 - 9.39657508572041e+25*cos(theta)**11 + 3.93311742552985e+24*cos(theta)**9 - 1.04960880147572e+23*cos(theta)**7 + 1.59723078485436e+21*cos(theta)**5 - 1.13520311645654e+19*cos(theta)**3 + 2.38154499955918e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl54_m_minus_8(theta, phi):
    return 5.50756934809716e-14*(1.0 - cos(theta)**2)**4*(5.78883247418868e+28*cos(theta)**46 - 5.59947814092082e+29*cos(theta)**44 + 2.52243158157671e+30*cos(theta)**42 - 7.02852295060696e+30*cos(theta)**40 + 1.35699205482016e+31*cos(theta)**38 - 1.92720285765368e+31*cos(theta)**36 + 2.08614742323336e+31*cos(theta)**34 - 1.75989278862243e+31*cos(theta)**32 + 1.17326185908162e+31*cos(theta)**30 - 6.23161060684376e+30*cos(theta)**28 + 2.64668405549095e+30*cos(theta)**26 - 8.98821648938932e+29*cos(theta)**24 + 2.43210563830534e+29*cos(theta)**22 - 5.20682486050542e+28*cos(theta)**20 + 8.72395699731948e+27*cos(theta)**18 - 1.1263843211729e+27*cos(theta)**16 + 1.09712758555802e+26*cos(theta)**14 - 7.83047923810034e+24*cos(theta)**12 + 3.93311742552985e+23*cos(theta)**10 - 1.31201100184465e+22*cos(theta)**8 + 2.6620513080906e+20*cos(theta)**6 - 2.83800779114136e+18*cos(theta)**4 + 1.19077249977959e+16*cos(theta)**2 - 8217891647892.28)*sin(8*phi)

#@torch.jit.script
def Yl54_m_minus_7(theta, phi):
    return 2.97306735277937e-12*(1.0 - cos(theta)**2)**3.5*(1.23166648386993e+27*cos(theta)**47 - 1.24432847576018e+28*cos(theta)**45 + 5.86611995715515e+28*cos(theta)**43 - 1.71427389039194e+29*cos(theta)**41 + 3.47946680723117e+29*cos(theta)**39 - 5.20865637203696e+29*cos(theta)**37 + 5.96042120923817e+29*cos(theta)**35 - 5.33300845037099e+29*cos(theta)**33 + 3.78471567445684e+29*cos(theta)**31 - 2.14883124373923e+29*cos(theta)**29 + 9.80253353885536e+28*cos(theta)**27 - 3.59528659575573e+28*cos(theta)**25 + 1.0574372340458e+28*cos(theta)**23 - 2.47944040976448e+27*cos(theta)**21 + 4.59155631437868e+26*cos(theta)**19 - 6.62579012454644e+25*cos(theta)**17 + 7.3141839037201e+24*cos(theta)**15 - 6.02344556776949e+23*cos(theta)**13 + 3.57556129593623e+22*cos(theta)**11 - 1.45779000204961e+21*cos(theta)**9 + 3.80293044012942e+19*cos(theta)**7 - 5.67601558228272e+17*cos(theta)**5 + 3.96924166593197e+15*cos(theta)**3 - 8217891647892.28*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl54_m_minus_6(theta, phi):
    return 1.60875638707754e-10*(1.0 - cos(theta)**2)**3*(2.56597184139569e+25*cos(theta)**48 - 2.70506190382648e+26*cos(theta)**46 + 1.33320908117162e+27*cos(theta)**44 - 4.08160450093319e+27*cos(theta)**42 + 8.69866701807792e+27*cos(theta)**40 - 1.37069904527288e+28*cos(theta)**38 + 1.65567255812171e+28*cos(theta)**36 - 1.56853189716794e+28*cos(theta)**34 + 1.18272364826776e+28*cos(theta)**32 - 7.1627708124641e+27*cos(theta)**30 + 3.50090483530548e+27*cos(theta)**28 - 1.38280253682913e+27*cos(theta)**26 + 4.40598847519084e+26*cos(theta)**24 - 1.12701836807477e+26*cos(theta)**22 + 2.29577815718934e+25*cos(theta)**20 - 3.68099451363691e+24*cos(theta)**18 + 4.57136493982506e+23*cos(theta)**16 - 4.30246111983535e+22*cos(theta)**14 + 2.97963441328019e+21*cos(theta)**12 - 1.45779000204961e+20*cos(theta)**10 + 4.75366305016178e+18*cos(theta)**8 - 9.4600259704712e+16*cos(theta)**6 + 992310416482993.0*cos(theta)**4 - 4108945823946.14*cos(theta)**2 + 2806656983.56977)*sin(6*phi)

#@torch.jit.script
def Yl54_m_minus_5(theta, phi):
    return 8.7229613733586e-9*(1.0 - cos(theta)**2)**2.5*(5.23667722733814e+23*cos(theta)**49 - 5.75545085920529e+24*cos(theta)**47 + 2.96268684704805e+25*cos(theta)**45 - 9.49210349054231e+25*cos(theta)**43 + 2.12162610197022e+26*cos(theta)**41 - 3.51461293659714e+26*cos(theta)**39 + 4.47479069762625e+26*cos(theta)**37 - 4.48151970619411e+26*cos(theta)**35 + 3.58401105535685e+26*cos(theta)**33 - 2.31057122982713e+26*cos(theta)**31 + 1.20720856389844e+26*cos(theta)**29 - 5.12149087714491e+25*cos(theta)**27 + 1.76239539007634e+25*cos(theta)**25 - 4.90007986119463e+24*cos(theta)**23 + 1.09322769389968e+24*cos(theta)**21 - 1.93736553349311e+23*cos(theta)**19 + 2.6890381998971e+22*cos(theta)**17 - 2.86830741322357e+21*cos(theta)**15 + 2.29202647175399e+20*cos(theta)**13 - 1.32526363822692e+19*cos(theta)**11 + 5.28184783351309e+17*cos(theta)**9 - 1.35143228149589e+16*cos(theta)**7 + 198462083296599.0*cos(theta)**5 - 1369648607982.05*cos(theta)**3 + 2806656983.56977*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl54_m_minus_4(theta, phi):
    return 4.73778073160064e-7*(1.0 - cos(theta)**2)**2*(1.04733544546763e+22*cos(theta)**50 - 1.19905226233443e+23*cos(theta)**48 + 6.44062358053925e+23*cos(theta)**46 - 2.15729624785052e+24*cos(theta)**44 + 5.05149071897672e+24*cos(theta)**42 - 8.78653234149285e+24*cos(theta)**40 + 1.17757649937533e+25*cos(theta)**38 - 1.24486658505392e+25*cos(theta)**36 + 1.05412089863437e+25*cos(theta)**34 - 7.22053509320977e+24*cos(theta)**32 + 4.02402854632814e+24*cos(theta)**30 - 1.82910388469461e+24*cos(theta)**28 + 6.77844380798591e+23*cos(theta)**26 - 2.04169994216443e+23*cos(theta)**24 + 4.96921679045311e+22*cos(theta)**22 - 9.68682766746556e+21*cos(theta)**20 + 1.49391011105394e+21*cos(theta)**18 - 1.79269213326473e+20*cos(theta)**16 + 1.63716176553857e+19*cos(theta)**14 - 1.1043863651891e+18*cos(theta)**12 + 5.28184783351309e+16*cos(theta)**10 - 1.68929035186986e+15*cos(theta)**8 + 33077013882766.4*cos(theta)**6 - 342412151995.512*cos(theta)**4 + 1403328491.78488*cos(theta)**2 - 951409.146972803)*sin(4*phi)

#@torch.jit.script
def Yl54_m_minus_3(theta, phi):
    return 2.57676042734338e-5*(1.0 - cos(theta)**2)**1.5*(2.05359891268162e+20*cos(theta)**51 - 2.44704543333558e+21*cos(theta)**49 + 1.37034544266793e+22*cos(theta)**47 - 4.79399166189006e+22*cos(theta)**45 + 1.17476528348296e+23*cos(theta)**43 - 2.14305666865679e+23*cos(theta)**41 + 3.01942692147521e+23*cos(theta)**39 - 3.36450428392951e+23*cos(theta)**37 + 3.01177399609819e+23*cos(theta)**35 - 2.1880409373363e+23*cos(theta)**33 + 1.29807372462198e+23*cos(theta)**31 - 6.307254774809e+22*cos(theta)**29 + 2.51053474369849e+22*cos(theta)**27 - 8.16679976865772e+21*cos(theta)**25 + 2.16052903932744e+21*cos(theta)**23 - 4.61277507974551e+20*cos(theta)**21 + 7.86268479502075e+19*cos(theta)**19 - 1.05452478427337e+19*cos(theta)**17 + 1.09144117702571e+18*cos(theta)**15 - 8.49527973222384e+16*cos(theta)**13 + 4.80167984864826e+15*cos(theta)**11 - 187698927985540.0*cos(theta)**9 + 4725287697538.06*cos(theta)**7 - 68482430399.1023*cos(theta)**5 + 467776163.928295*cos(theta)**3 - 951409.146972803*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl54_m_minus_2(theta, phi):
    return 0.0014028561545993*(1.0 - cos(theta)**2)*(3.94922867823389e+18*cos(theta)**52 - 4.89409086667116e+19*cos(theta)**50 + 2.85488633889151e+20*cos(theta)**48 - 1.04217210041088e+21*cos(theta)**46 + 2.66992109882491e+21*cos(theta)**44 - 5.10251587775427e+21*cos(theta)**42 + 7.54856730368801e+21*cos(theta)**40 - 8.85395864191977e+21*cos(theta)**38 + 8.36603887805054e+21*cos(theta)**36 - 6.43541452157734e+21*cos(theta)**34 + 4.05648038944369e+21*cos(theta)**32 - 2.10241825826967e+21*cos(theta)**30 + 8.96619551320888e+20*cos(theta)**28 - 3.14107683409912e+20*cos(theta)**26 + 9.002204330531e+19*cos(theta)**24 - 2.09671594533887e+19*cos(theta)**22 + 3.93134239751037e+18*cos(theta)**20 - 5.85847102374095e+17*cos(theta)**18 + 6.82150735641069e+16*cos(theta)**16 - 6.06805695158846e+15*cos(theta)**14 + 400139987387355.0*cos(theta)**12 - 18769892798554.0*cos(theta)**10 + 590660962192.258*cos(theta)**8 - 11413738399.8504*cos(theta)**6 + 116944040.982074*cos(theta)**4 - 475704.573486401*cos(theta)**2 + 320.988241218894)*sin(2*phi)

#@torch.jit.script
def Yl54_m_minus_1(theta, phi):
    return 0.0764266968996795*(1.0 - cos(theta)**2)**0.5*(7.45137486459225e+16*cos(theta)**53 - 9.596256601316e+17*cos(theta)**51 + 5.826298650799e+18*cos(theta)**49 - 2.21738744768273e+19*cos(theta)**47 + 5.93315799738868e+19*cos(theta)**45 - 1.18663159947774e+20*cos(theta)**43 + 1.84111397650927e+20*cos(theta)**41 - 2.27024580562046e+20*cos(theta)**39 + 2.26109158866231e+20*cos(theta)**37 - 1.83868986330781e+20*cos(theta)**35 + 1.2292364816496e+20*cos(theta)**33 - 6.78199438151506e+19*cos(theta)**31 + 3.09179155627892e+19*cos(theta)**29 - 1.16336179040708e+19*cos(theta)**27 + 3.6008817322124e+18*cos(theta)**25 - 9.11615628408203e+17*cos(theta)**23 + 1.87206780833827e+17*cos(theta)**21 - 3.08340580196892e+16*cos(theta)**19 + 4.01265138612394e+15*cos(theta)**17 - 404537130105897.0*cos(theta)**15 + 30779999029796.5*cos(theta)**13 - 1706353890777.63*cos(theta)**11 + 65628995799.1397*cos(theta)**9 - 1630534057.12148*cos(theta)**7 + 23388808.1964147*cos(theta)**5 - 158568.191162134*cos(theta)**3 + 320.988241218894*cos(theta))*sin(phi)

#@torch.jit.script
def Yl54_m0(theta, phi):
    return 1.27673522976982e+16*cos(theta)**54 - 1.70748421850524e+17*cos(theta)**52 + 1.0781543208276e+18*cos(theta)**50 - 4.27423638515795e+18*cos(theta)**48 + 1.1934006540738e+19*cos(theta)**46 - 2.49529227669977e+19*cos(theta)**44 + 4.05592181058073e+19*cos(theta)**42 - 5.25135139685715e+19*cos(theta)**40 + 5.50544904509217e+19*cos(theta)**38 - 4.72567848437094e+19*cos(theta)**36 + 3.3451431968019e+19*cos(theta)**34 - 1.96094601191836e+19*cos(theta)**32 + 9.53558060697553e+18*cos(theta)**30 - 3.8442794847399e+18*cos(theta)**28 + 1.2814264949133e+18*cos(theta)**26 - 3.51446085102804e+17*cos(theta)**24 + 7.87330515327711e+16*cos(theta)**22 - 1.42645763953491e+16*cos(theta)**20 + 2.06260998106266e+15*cos(theta)**18 - 233935750261369.0*cos(theta)**16 + 20342239153162.5*cos(theta)**14 - 1315667208911.01*cos(theta)**12 + 60723101949.7388*cos(theta)**10 - 1885810619.55711*cos(theta)**8 + 36067416.2210375*cos(theta)**6 - 366787.283603772*cos(theta)**4 + 1484.96875952944*cos(theta)**2 - 0.999978962646087

#@torch.jit.script
def Yl54_m1(theta, phi):
    return 0.0764266968996795*(1.0 - cos(theta)**2)**0.5*(7.45137486459225e+16*cos(theta)**53 - 9.596256601316e+17*cos(theta)**51 + 5.826298650799e+18*cos(theta)**49 - 2.21738744768273e+19*cos(theta)**47 + 5.93315799738868e+19*cos(theta)**45 - 1.18663159947774e+20*cos(theta)**43 + 1.84111397650927e+20*cos(theta)**41 - 2.27024580562046e+20*cos(theta)**39 + 2.26109158866231e+20*cos(theta)**37 - 1.83868986330781e+20*cos(theta)**35 + 1.2292364816496e+20*cos(theta)**33 - 6.78199438151506e+19*cos(theta)**31 + 3.09179155627892e+19*cos(theta)**29 - 1.16336179040708e+19*cos(theta)**27 + 3.6008817322124e+18*cos(theta)**25 - 9.11615628408203e+17*cos(theta)**23 + 1.87206780833827e+17*cos(theta)**21 - 3.08340580196892e+16*cos(theta)**19 + 4.01265138612394e+15*cos(theta)**17 - 404537130105897.0*cos(theta)**15 + 30779999029796.5*cos(theta)**13 - 1706353890777.63*cos(theta)**11 + 65628995799.1397*cos(theta)**9 - 1630534057.12148*cos(theta)**7 + 23388808.1964147*cos(theta)**5 - 158568.191162134*cos(theta)**3 + 320.988241218894*cos(theta))*cos(phi)

#@torch.jit.script
def Yl54_m2(theta, phi):
    return 0.0014028561545993*(1.0 - cos(theta)**2)*(3.94922867823389e+18*cos(theta)**52 - 4.89409086667116e+19*cos(theta)**50 + 2.85488633889151e+20*cos(theta)**48 - 1.04217210041088e+21*cos(theta)**46 + 2.66992109882491e+21*cos(theta)**44 - 5.10251587775427e+21*cos(theta)**42 + 7.54856730368801e+21*cos(theta)**40 - 8.85395864191977e+21*cos(theta)**38 + 8.36603887805054e+21*cos(theta)**36 - 6.43541452157734e+21*cos(theta)**34 + 4.05648038944369e+21*cos(theta)**32 - 2.10241825826967e+21*cos(theta)**30 + 8.96619551320888e+20*cos(theta)**28 - 3.14107683409912e+20*cos(theta)**26 + 9.002204330531e+19*cos(theta)**24 - 2.09671594533887e+19*cos(theta)**22 + 3.93134239751037e+18*cos(theta)**20 - 5.85847102374095e+17*cos(theta)**18 + 6.82150735641069e+16*cos(theta)**16 - 6.06805695158846e+15*cos(theta)**14 + 400139987387355.0*cos(theta)**12 - 18769892798554.0*cos(theta)**10 + 590660962192.258*cos(theta)**8 - 11413738399.8504*cos(theta)**6 + 116944040.982074*cos(theta)**4 - 475704.573486401*cos(theta)**2 + 320.988241218894)*cos(2*phi)

#@torch.jit.script
def Yl54_m3(theta, phi):
    return 2.57676042734338e-5*(1.0 - cos(theta)**2)**1.5*(2.05359891268162e+20*cos(theta)**51 - 2.44704543333558e+21*cos(theta)**49 + 1.37034544266793e+22*cos(theta)**47 - 4.79399166189006e+22*cos(theta)**45 + 1.17476528348296e+23*cos(theta)**43 - 2.14305666865679e+23*cos(theta)**41 + 3.01942692147521e+23*cos(theta)**39 - 3.36450428392951e+23*cos(theta)**37 + 3.01177399609819e+23*cos(theta)**35 - 2.1880409373363e+23*cos(theta)**33 + 1.29807372462198e+23*cos(theta)**31 - 6.307254774809e+22*cos(theta)**29 + 2.51053474369849e+22*cos(theta)**27 - 8.16679976865772e+21*cos(theta)**25 + 2.16052903932744e+21*cos(theta)**23 - 4.61277507974551e+20*cos(theta)**21 + 7.86268479502075e+19*cos(theta)**19 - 1.05452478427337e+19*cos(theta)**17 + 1.09144117702571e+18*cos(theta)**15 - 8.49527973222384e+16*cos(theta)**13 + 4.80167984864826e+15*cos(theta)**11 - 187698927985540.0*cos(theta)**9 + 4725287697538.06*cos(theta)**7 - 68482430399.1023*cos(theta)**5 + 467776163.928295*cos(theta)**3 - 951409.146972803*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl54_m4(theta, phi):
    return 4.73778073160064e-7*(1.0 - cos(theta)**2)**2*(1.04733544546763e+22*cos(theta)**50 - 1.19905226233443e+23*cos(theta)**48 + 6.44062358053925e+23*cos(theta)**46 - 2.15729624785052e+24*cos(theta)**44 + 5.05149071897672e+24*cos(theta)**42 - 8.78653234149285e+24*cos(theta)**40 + 1.17757649937533e+25*cos(theta)**38 - 1.24486658505392e+25*cos(theta)**36 + 1.05412089863437e+25*cos(theta)**34 - 7.22053509320977e+24*cos(theta)**32 + 4.02402854632814e+24*cos(theta)**30 - 1.82910388469461e+24*cos(theta)**28 + 6.77844380798591e+23*cos(theta)**26 - 2.04169994216443e+23*cos(theta)**24 + 4.96921679045311e+22*cos(theta)**22 - 9.68682766746556e+21*cos(theta)**20 + 1.49391011105394e+21*cos(theta)**18 - 1.79269213326473e+20*cos(theta)**16 + 1.63716176553857e+19*cos(theta)**14 - 1.1043863651891e+18*cos(theta)**12 + 5.28184783351309e+16*cos(theta)**10 - 1.68929035186986e+15*cos(theta)**8 + 33077013882766.4*cos(theta)**6 - 342412151995.512*cos(theta)**4 + 1403328491.78488*cos(theta)**2 - 951409.146972803)*cos(4*phi)

#@torch.jit.script
def Yl54_m5(theta, phi):
    return 8.7229613733586e-9*(1.0 - cos(theta)**2)**2.5*(5.23667722733814e+23*cos(theta)**49 - 5.75545085920529e+24*cos(theta)**47 + 2.96268684704805e+25*cos(theta)**45 - 9.49210349054231e+25*cos(theta)**43 + 2.12162610197022e+26*cos(theta)**41 - 3.51461293659714e+26*cos(theta)**39 + 4.47479069762625e+26*cos(theta)**37 - 4.48151970619411e+26*cos(theta)**35 + 3.58401105535685e+26*cos(theta)**33 - 2.31057122982713e+26*cos(theta)**31 + 1.20720856389844e+26*cos(theta)**29 - 5.12149087714491e+25*cos(theta)**27 + 1.76239539007634e+25*cos(theta)**25 - 4.90007986119463e+24*cos(theta)**23 + 1.09322769389968e+24*cos(theta)**21 - 1.93736553349311e+23*cos(theta)**19 + 2.6890381998971e+22*cos(theta)**17 - 2.86830741322357e+21*cos(theta)**15 + 2.29202647175399e+20*cos(theta)**13 - 1.32526363822692e+19*cos(theta)**11 + 5.28184783351309e+17*cos(theta)**9 - 1.35143228149589e+16*cos(theta)**7 + 198462083296599.0*cos(theta)**5 - 1369648607982.05*cos(theta)**3 + 2806656983.56977*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl54_m6(theta, phi):
    return 1.60875638707754e-10*(1.0 - cos(theta)**2)**3*(2.56597184139569e+25*cos(theta)**48 - 2.70506190382648e+26*cos(theta)**46 + 1.33320908117162e+27*cos(theta)**44 - 4.08160450093319e+27*cos(theta)**42 + 8.69866701807792e+27*cos(theta)**40 - 1.37069904527288e+28*cos(theta)**38 + 1.65567255812171e+28*cos(theta)**36 - 1.56853189716794e+28*cos(theta)**34 + 1.18272364826776e+28*cos(theta)**32 - 7.1627708124641e+27*cos(theta)**30 + 3.50090483530548e+27*cos(theta)**28 - 1.38280253682913e+27*cos(theta)**26 + 4.40598847519084e+26*cos(theta)**24 - 1.12701836807477e+26*cos(theta)**22 + 2.29577815718934e+25*cos(theta)**20 - 3.68099451363691e+24*cos(theta)**18 + 4.57136493982506e+23*cos(theta)**16 - 4.30246111983535e+22*cos(theta)**14 + 2.97963441328019e+21*cos(theta)**12 - 1.45779000204961e+20*cos(theta)**10 + 4.75366305016178e+18*cos(theta)**8 - 9.4600259704712e+16*cos(theta)**6 + 992310416482993.0*cos(theta)**4 - 4108945823946.14*cos(theta)**2 + 2806656983.56977)*cos(6*phi)

#@torch.jit.script
def Yl54_m7(theta, phi):
    return 2.97306735277937e-12*(1.0 - cos(theta)**2)**3.5*(1.23166648386993e+27*cos(theta)**47 - 1.24432847576018e+28*cos(theta)**45 + 5.86611995715515e+28*cos(theta)**43 - 1.71427389039194e+29*cos(theta)**41 + 3.47946680723117e+29*cos(theta)**39 - 5.20865637203696e+29*cos(theta)**37 + 5.96042120923817e+29*cos(theta)**35 - 5.33300845037099e+29*cos(theta)**33 + 3.78471567445684e+29*cos(theta)**31 - 2.14883124373923e+29*cos(theta)**29 + 9.80253353885536e+28*cos(theta)**27 - 3.59528659575573e+28*cos(theta)**25 + 1.0574372340458e+28*cos(theta)**23 - 2.47944040976448e+27*cos(theta)**21 + 4.59155631437868e+26*cos(theta)**19 - 6.62579012454644e+25*cos(theta)**17 + 7.3141839037201e+24*cos(theta)**15 - 6.02344556776949e+23*cos(theta)**13 + 3.57556129593623e+22*cos(theta)**11 - 1.45779000204961e+21*cos(theta)**9 + 3.80293044012942e+19*cos(theta)**7 - 5.67601558228272e+17*cos(theta)**5 + 3.96924166593197e+15*cos(theta)**3 - 8217891647892.28*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl54_m8(theta, phi):
    return 5.50756934809716e-14*(1.0 - cos(theta)**2)**4*(5.78883247418868e+28*cos(theta)**46 - 5.59947814092082e+29*cos(theta)**44 + 2.52243158157671e+30*cos(theta)**42 - 7.02852295060696e+30*cos(theta)**40 + 1.35699205482016e+31*cos(theta)**38 - 1.92720285765368e+31*cos(theta)**36 + 2.08614742323336e+31*cos(theta)**34 - 1.75989278862243e+31*cos(theta)**32 + 1.17326185908162e+31*cos(theta)**30 - 6.23161060684376e+30*cos(theta)**28 + 2.64668405549095e+30*cos(theta)**26 - 8.98821648938932e+29*cos(theta)**24 + 2.43210563830534e+29*cos(theta)**22 - 5.20682486050542e+28*cos(theta)**20 + 8.72395699731948e+27*cos(theta)**18 - 1.1263843211729e+27*cos(theta)**16 + 1.09712758555802e+26*cos(theta)**14 - 7.83047923810034e+24*cos(theta)**12 + 3.93311742552985e+23*cos(theta)**10 - 1.31201100184465e+22*cos(theta)**8 + 2.6620513080906e+20*cos(theta)**6 - 2.83800779114136e+18*cos(theta)**4 + 1.19077249977959e+16*cos(theta)**2 - 8217891647892.28)*cos(8*phi)

#@torch.jit.script
def Yl54_m9(theta, phi):
    return 1.02308280064746e-15*(1.0 - cos(theta)**2)**4.5*(2.66286293812679e+30*cos(theta)**45 - 2.46377038200516e+31*cos(theta)**43 + 1.05942126426222e+32*cos(theta)**41 - 2.81140918024278e+32*cos(theta)**39 + 5.15656980831659e+32*cos(theta)**37 - 6.93793028755323e+32*cos(theta)**35 + 7.09290123899342e+32*cos(theta)**33 - 5.63165692359177e+32*cos(theta)**31 + 3.51978557724486e+32*cos(theta)**29 - 1.74485096991625e+32*cos(theta)**27 + 6.88137854427646e+31*cos(theta)**25 - 2.15717195745344e+31*cos(theta)**23 + 5.35063240427176e+30*cos(theta)**21 - 1.04136497210108e+30*cos(theta)**19 + 1.57031225951751e+29*cos(theta)**17 - 1.80221491387663e+28*cos(theta)**15 + 1.53597861978122e+27*cos(theta)**13 - 9.39657508572041e+25*cos(theta)**11 + 3.93311742552985e+24*cos(theta)**9 - 1.04960880147572e+23*cos(theta)**7 + 1.59723078485436e+21*cos(theta)**5 - 1.13520311645654e+19*cos(theta)**3 + 2.38154499955918e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl54_m10(theta, phi):
    return 1.90640224071549e-17*(1.0 - cos(theta)**2)**5*(1.19828832215706e+32*cos(theta)**44 - 1.05942126426222e+33*cos(theta)**42 + 4.3436271834751e+33*cos(theta)**40 - 1.09644958029469e+34*cos(theta)**38 + 1.90793082907714e+34*cos(theta)**36 - 2.42827560064363e+34*cos(theta)**34 + 2.34065740886783e+34*cos(theta)**32 - 1.74581364631345e+34*cos(theta)**30 + 1.02073781740101e+34*cos(theta)**28 - 4.71109761877389e+33*cos(theta)**26 + 1.72034463606912e+33*cos(theta)**24 - 4.9614955021429e+32*cos(theta)**22 + 1.12363280489707e+32*cos(theta)**20 - 1.97859344699206e+31*cos(theta)**18 + 2.66953084117976e+30*cos(theta)**16 - 2.70332237081495e+29*cos(theta)**14 + 1.99677220571559e+28*cos(theta)**12 - 1.03362325942925e+27*cos(theta)**10 + 3.53980568297687e+25*cos(theta)**8 - 7.34726161033004e+23*cos(theta)**6 + 7.98615392427179e+21*cos(theta)**4 - 3.40560934936963e+19*cos(theta)**2 + 2.38154499955918e+16)*cos(10*phi)

#@torch.jit.script
def Yl54_m11(theta, phi):
    return 3.56477007340465e-19*(1.0 - cos(theta)**2)**5.5*(5.27246861749105e+33*cos(theta)**43 - 4.44956930990132e+34*cos(theta)**41 + 1.73745087339004e+35*cos(theta)**39 - 4.16650840511981e+35*cos(theta)**37 + 6.8685509846777e+35*cos(theta)**35 - 8.25613704218834e+35*cos(theta)**33 + 7.49010370837705e+35*cos(theta)**31 - 5.23744093894035e+35*cos(theta)**29 + 2.85806588872282e+35*cos(theta)**27 - 1.22488538088121e+35*cos(theta)**25 + 4.12882712656588e+34*cos(theta)**23 - 1.09152901047144e+34*cos(theta)**21 + 2.24726560979414e+33*cos(theta)**19 - 3.56146820458571e+32*cos(theta)**17 + 4.27124934588762e+31*cos(theta)**15 - 3.78465131914093e+30*cos(theta)**13 + 2.3961266468587e+29*cos(theta)**11 - 1.03362325942925e+28*cos(theta)**9 + 2.83184454638149e+26*cos(theta)**7 - 4.40835696619803e+24*cos(theta)**5 + 3.19446156970871e+22*cos(theta)**3 - 6.81121869873926e+19*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl54_m12(theta, phi):
    return 6.69152843305673e-21*(1.0 - cos(theta)**2)**6*(2.26716150552115e+35*cos(theta)**42 - 1.82432341705954e+36*cos(theta)**40 + 6.77605840622116e+36*cos(theta)**38 - 1.54160810989433e+37*cos(theta)**36 + 2.40399284463719e+37*cos(theta)**34 - 2.72452522392215e+37*cos(theta)**32 + 2.32193214959689e+37*cos(theta)**30 - 1.5188578722927e+37*cos(theta)**28 + 7.71677789955162e+36*cos(theta)**26 - 3.06221345220303e+36*cos(theta)**24 + 9.49630239110152e+35*cos(theta)**22 - 2.29221092199002e+35*cos(theta)**20 + 4.26980465860886e+34*cos(theta)**18 - 6.0544959477957e+33*cos(theta)**16 + 6.40687401883143e+32*cos(theta)**14 - 4.92004671488321e+31*cos(theta)**12 + 2.63573931154458e+30*cos(theta)**10 - 9.30260933486321e+28*cos(theta)**8 + 1.98229118246705e+27*cos(theta)**6 - 2.20417848309901e+25*cos(theta)**4 + 9.58338470912614e+22*cos(theta)**2 - 6.81121869873926e+19)*cos(12*phi)

#@torch.jit.script
def Yl54_m13(theta, phi):
    return 1.26143036514606e-22*(1.0 - cos(theta)**2)**6.5*(9.52207832318883e+36*cos(theta)**41 - 7.29729366823817e+37*cos(theta)**39 + 2.57490219436404e+38*cos(theta)**37 - 5.54978919561958e+38*cos(theta)**35 + 8.17357567176646e+38*cos(theta)**33 - 8.71848071655089e+38*cos(theta)**31 + 6.96579644879066e+38*cos(theta)**29 - 4.25280204241956e+38*cos(theta)**27 + 2.00636225388342e+38*cos(theta)**25 - 7.34931228528726e+37*cos(theta)**23 + 2.08918652604233e+37*cos(theta)**21 - 4.58442184398004e+36*cos(theta)**19 + 7.68564838549595e+35*cos(theta)**17 - 9.68719351647312e+34*cos(theta)**15 + 8.969623626364e+33*cos(theta)**13 - 5.90405605785985e+32*cos(theta)**11 + 2.63573931154458e+31*cos(theta)**9 - 7.44208746789057e+29*cos(theta)**7 + 1.18937470948023e+28*cos(theta)**5 - 8.81671393239605e+25*cos(theta)**3 + 1.91667694182523e+23*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl54_m14(theta, phi):
    return 2.38900410726037e-24*(1.0 - cos(theta)**2)**7*(3.90405211250742e+38*cos(theta)**40 - 2.84594453061289e+39*cos(theta)**38 + 9.52713811914695e+39*cos(theta)**36 - 1.94242621846685e+40*cos(theta)**34 + 2.69727997168293e+40*cos(theta)**32 - 2.70272902213078e+40*cos(theta)**30 + 2.02008097014929e+40*cos(theta)**28 - 1.14825655145328e+40*cos(theta)**26 + 5.01590563470856e+39*cos(theta)**24 - 1.69034182561607e+39*cos(theta)**22 + 4.3872917046889e+38*cos(theta)**20 - 8.71040150356208e+37*cos(theta)**18 + 1.30656022553431e+37*cos(theta)**16 - 1.45307902747097e+36*cos(theta)**14 + 1.16605107142732e+35*cos(theta)**12 - 6.49446166364583e+33*cos(theta)**10 + 2.37216538039012e+32*cos(theta)**8 - 5.2094612275234e+30*cos(theta)**6 + 5.94687354740114e+28*cos(theta)**4 - 2.64501417971882e+26*cos(theta)**2 + 1.91667694182523e+23)*cos(14*phi)

#@torch.jit.script
def Yl54_m15(theta, phi):
    return 4.54739160163806e-26*(1.0 - cos(theta)**2)**7.5*(1.56162084500297e+40*cos(theta)**39 - 1.0814589216329e+41*cos(theta)**37 + 3.4297697228929e+41*cos(theta)**35 - 6.6042491427873e+41*cos(theta)**33 + 8.63129590938538e+41*cos(theta)**31 - 8.10818706639233e+41*cos(theta)**29 + 5.65622671641802e+41*cos(theta)**27 - 2.98546703377853e+41*cos(theta)**25 + 1.20381735233005e+41*cos(theta)**23 - 3.71875201635535e+40*cos(theta)**21 + 8.7745834093778e+39*cos(theta)**19 - 1.56787227064117e+39*cos(theta)**17 + 2.0904963608549e+38*cos(theta)**15 - 2.03431063845936e+37*cos(theta)**13 + 1.39926128571278e+36*cos(theta)**11 - 6.49446166364583e+34*cos(theta)**9 + 1.89773230431209e+33*cos(theta)**7 - 3.12567673651404e+31*cos(theta)**5 + 2.37874941896045e+29*cos(theta)**3 - 5.29002835943763e+26*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl54_m16(theta, phi):
    return 8.70324144462283e-28*(1.0 - cos(theta)**2)**8*(6.09032129551158e+41*cos(theta)**38 - 4.00139801004172e+42*cos(theta)**36 + 1.20041940301252e+43*cos(theta)**34 - 2.17940221711981e+43*cos(theta)**32 + 2.67570173190947e+43*cos(theta)**30 - 2.35137424925378e+43*cos(theta)**28 + 1.52718121343286e+43*cos(theta)**26 - 7.46366758444633e+42*cos(theta)**24 + 2.76877991035912e+42*cos(theta)**22 - 7.80937923434624e+41*cos(theta)**20 + 1.66717084778178e+41*cos(theta)**18 - 2.66538286009e+40*cos(theta)**16 + 3.13574454128235e+39*cos(theta)**14 - 2.64460382999716e+38*cos(theta)**12 + 1.53918741428406e+37*cos(theta)**10 - 5.84501549728125e+35*cos(theta)**8 + 1.32841261301847e+34*cos(theta)**6 - 1.56283836825702e+32*cos(theta)**4 + 7.13624825688136e+29*cos(theta)**2 - 5.29002835943763e+26)*cos(16*phi)

#@torch.jit.script
def Yl54_m17(theta, phi):
    return 1.67556028980796e-29*(1.0 - cos(theta)**2)**8.5*(2.3143220922944e+43*cos(theta)**37 - 1.44050328361502e+44*cos(theta)**35 + 4.08142597024255e+44*cos(theta)**33 - 6.97408709478339e+44*cos(theta)**31 + 8.02710519572841e+44*cos(theta)**29 - 6.58384789791057e+44*cos(theta)**27 + 3.97067115492545e+44*cos(theta)**25 - 1.79128022026712e+44*cos(theta)**23 + 6.09131580279007e+43*cos(theta)**21 - 1.56187584686925e+43*cos(theta)**19 + 3.00090752600721e+42*cos(theta)**17 - 4.26461257614399e+41*cos(theta)**15 + 4.39004235779529e+40*cos(theta)**13 - 3.17352459599659e+39*cos(theta)**11 + 1.53918741428406e+38*cos(theta)**9 - 4.676012397825e+36*cos(theta)**7 + 7.97047567811079e+34*cos(theta)**5 - 6.25135347302808e+32*cos(theta)**3 + 1.42724965137627e+30*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl54_m18(theta, phi):
    return 3.24633212105142e-31*(1.0 - cos(theta)**2)**9*(8.56299174148928e+44*cos(theta)**36 - 5.04176149265256e+45*cos(theta)**34 + 1.34687057018004e+46*cos(theta)**32 - 2.16196699938285e+46*cos(theta)**30 + 2.32786050676124e+46*cos(theta)**28 - 1.77763893243585e+46*cos(theta)**26 + 9.92667788731362e+45*cos(theta)**24 - 4.11994450661437e+45*cos(theta)**22 + 1.27917631858591e+45*cos(theta)**20 - 2.96756410905157e+44*cos(theta)**18 + 5.10154279421225e+43*cos(theta)**16 - 6.39691886421599e+42*cos(theta)**14 + 5.70705506513388e+41*cos(theta)**12 - 3.49087705559625e+40*cos(theta)**10 + 1.38526867285566e+39*cos(theta)**8 - 3.2732086784775e+37*cos(theta)**6 + 3.9852378390554e+35*cos(theta)**4 - 1.87540604190842e+33*cos(theta)**2 + 1.42724965137627e+30)*cos(18*phi)

#@torch.jit.script
def Yl54_m19(theta, phi):
    return 6.33257392712509e-33*(1.0 - cos(theta)**2)**9.5*(3.08267702693614e+46*cos(theta)**35 - 1.71419890750187e+47*cos(theta)**33 + 4.30998582457614e+47*cos(theta)**31 - 6.48590099814855e+47*cos(theta)**29 + 6.51800941893147e+47*cos(theta)**27 - 4.62186122433322e+47*cos(theta)**25 + 2.38240269295527e+47*cos(theta)**23 - 9.06387791455162e+46*cos(theta)**21 + 2.55835263717183e+46*cos(theta)**19 - 5.34161539629283e+45*cos(theta)**17 + 8.16246847073961e+44*cos(theta)**15 - 8.95568640990239e+43*cos(theta)**13 + 6.84846607816065e+42*cos(theta)**11 - 3.49087705559625e+41*cos(theta)**9 + 1.10821493828453e+40*cos(theta)**7 - 1.9639252070865e+38*cos(theta)**5 + 1.59409513562216e+36*cos(theta)**3 - 3.75081208381684e+33*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl54_m20(theta, phi):
    return 1.24431514311539e-34*(1.0 - cos(theta)**2)**10*(1.07893695942765e+48*cos(theta)**34 - 5.65685639475618e+48*cos(theta)**32 + 1.3360956056186e+49*cos(theta)**30 - 1.88091128946308e+49*cos(theta)**28 + 1.7598625431115e+49*cos(theta)**26 - 1.15546530608331e+49*cos(theta)**24 + 5.47952619379712e+48*cos(theta)**22 - 1.90341436205584e+48*cos(theta)**20 + 4.86087001062648e+47*cos(theta)**18 - 9.08074617369781e+46*cos(theta)**16 + 1.22437027061094e+46*cos(theta)**14 - 1.16423923328731e+45*cos(theta)**12 + 7.53331268597672e+43*cos(theta)**10 - 3.14178935003663e+42*cos(theta)**8 + 7.75750456799167e+40*cos(theta)**6 - 9.8196260354325e+38*cos(theta)**4 + 4.78228540686648e+36*cos(theta)**2 - 3.75081208381684e+33)*cos(20*phi)

#@torch.jit.script
def Yl54_m21(theta, phi):
    return 2.46411116328874e-36*(1.0 - cos(theta)**2)**10.5*(3.66838566205401e+49*cos(theta)**33 - 1.81019404632198e+50*cos(theta)**31 + 4.00828681685581e+50*cos(theta)**29 - 5.26655161049662e+50*cos(theta)**27 + 4.57564261208989e+50*cos(theta)**25 - 2.77311673459993e+50*cos(theta)**23 + 1.20549576263537e+50*cos(theta)**21 - 3.80682872411168e+49*cos(theta)**19 + 8.74956601912766e+48*cos(theta)**17 - 1.45291938779165e+48*cos(theta)**15 + 1.71411837885532e+47*cos(theta)**13 - 1.39708707994477e+46*cos(theta)**11 + 7.53331268597672e+44*cos(theta)**9 - 2.5134314800293e+43*cos(theta)**7 + 4.654502740795e+41*cos(theta)**5 - 3.927850414173e+39*cos(theta)**3 + 9.56457081373295e+36*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl54_m22(theta, phi):
    return 4.9203560449046e-38*(1.0 - cos(theta)**2)**11*(1.21056726847782e+51*cos(theta)**32 - 5.61160154359813e+51*cos(theta)**30 + 1.16240317688818e+52*cos(theta)**28 - 1.42196893483409e+52*cos(theta)**26 + 1.14391065302247e+52*cos(theta)**24 - 6.37816848957984e+51*cos(theta)**22 + 2.53154110153427e+51*cos(theta)**20 - 7.2329745758122e+50*cos(theta)**18 + 1.4874262232517e+50*cos(theta)**16 - 2.17937908168747e+49*cos(theta)**14 + 2.22835389251191e+48*cos(theta)**12 - 1.53679578793925e+47*cos(theta)**10 + 6.77998141737904e+45*cos(theta)**8 - 1.75940203602051e+44*cos(theta)**6 + 2.3272513703975e+42*cos(theta)**4 - 1.1783551242519e+40*cos(theta)**2 + 9.56457081373295e+36)*cos(22*phi)

#@torch.jit.script
def Yl54_m23(theta, phi):
    return 9.91233973041305e-40*(1.0 - cos(theta)**2)**11.5*(3.87381525912903e+52*cos(theta)**31 - 1.68348046307944e+53*cos(theta)**29 + 3.25472889528691e+53*cos(theta)**27 - 3.69711923056863e+53*cos(theta)**25 + 2.74538556725393e+53*cos(theta)**23 - 1.40319706770757e+53*cos(theta)**21 + 5.06308220306854e+52*cos(theta)**19 - 1.3019354236462e+52*cos(theta)**17 + 2.37988195720272e+51*cos(theta)**15 - 3.05113071436246e+50*cos(theta)**13 + 2.6740246710143e+49*cos(theta)**11 - 1.53679578793925e+48*cos(theta)**9 + 5.42398513390323e+46*cos(theta)**7 - 1.05564122161231e+45*cos(theta)**5 + 9.30900548159001e+42*cos(theta)**3 - 2.3567102485038e+40*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl54_m24(theta, phi):
    return 2.01580273517196e-41*(1.0 - cos(theta)**2)**12*(1.20088273033e+54*cos(theta)**30 - 4.88209334293037e+54*cos(theta)**28 + 8.78776801727467e+54*cos(theta)**26 - 9.24279807642158e+54*cos(theta)**24 + 6.31438680468405e+54*cos(theta)**22 - 2.94671384218589e+54*cos(theta)**20 + 9.61985618583022e+53*cos(theta)**18 - 2.21329022019853e+53*cos(theta)**16 + 3.56982293580408e+52*cos(theta)**14 - 3.9664699286712e+51*cos(theta)**12 + 2.94142713811572e+50*cos(theta)**10 - 1.38311620914532e+49*cos(theta)**8 + 3.79678959373226e+47*cos(theta)**6 - 5.27820610806154e+45*cos(theta)**4 + 2.792701644477e+43*cos(theta)**2 - 2.3567102485038e+40)*cos(24*phi)

#@torch.jit.script
def Yl54_m25(theta, phi):
    return 4.14070086564614e-43*(1.0 - cos(theta)**2)**12.5*(3.60264819099e+55*cos(theta)**29 - 1.3669861360205e+56*cos(theta)**27 + 2.28481968449141e+56*cos(theta)**25 - 2.21827153834118e+56*cos(theta)**23 + 1.38916509703049e+56*cos(theta)**21 - 5.89342768437178e+55*cos(theta)**19 + 1.73157411344944e+55*cos(theta)**17 - 3.54126435231765e+54*cos(theta)**15 + 4.99775211012572e+53*cos(theta)**13 - 4.75976391440545e+52*cos(theta)**11 + 2.94142713811572e+51*cos(theta)**9 - 1.10649296731626e+50*cos(theta)**7 + 2.27807375623936e+48*cos(theta)**5 - 2.11128244322461e+46*cos(theta)**3 + 5.58540328895401e+43*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl54_m26(theta, phi):
    return 8.59666225795951e-45*(1.0 - cos(theta)**2)**13*(1.0447679753871e+57*cos(theta)**28 - 3.69086256725536e+57*cos(theta)**26 + 5.71204921122853e+57*cos(theta)**24 - 5.10202453818471e+57*cos(theta)**22 + 2.91724670376403e+57*cos(theta)**20 - 1.11975126003064e+57*cos(theta)**18 + 2.94367599286405e+56*cos(theta)**16 - 5.31189652847648e+55*cos(theta)**14 + 6.49707774316343e+54*cos(theta)**12 - 5.23574030584599e+53*cos(theta)**10 + 2.64728442430415e+52*cos(theta)**8 - 7.74545077121382e+50*cos(theta)**6 + 1.13903687811968e+49*cos(theta)**4 - 6.33384732967384e+46*cos(theta)**2 + 5.58540328895401e+43)*cos(26*phi)

#@torch.jit.script
def Yl54_m27(theta, phi):
    return 1.80512939998221e-46*(1.0 - cos(theta)**2)**13.5*(2.92535033108388e+58*cos(theta)**27 - 9.59624267486394e+58*cos(theta)**25 + 1.37089181069485e+59*cos(theta)**23 - 1.12244539840064e+59*cos(theta)**21 + 5.83449340752806e+58*cos(theta)**19 - 2.01555226805515e+58*cos(theta)**17 + 4.70988158858248e+57*cos(theta)**15 - 7.43665513986707e+56*cos(theta)**13 + 7.79649329179612e+55*cos(theta)**11 - 5.23574030584599e+54*cos(theta)**9 + 2.11782753944332e+53*cos(theta)**7 - 4.64727046272829e+51*cos(theta)**5 + 4.55614751247872e+49*cos(theta)**3 - 1.26676946593477e+47*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl54_m28(theta, phi):
    return 3.83636156498218e-48*(1.0 - cos(theta)**2)**14*(7.89844589392647e+59*cos(theta)**26 - 2.39906066871598e+60*cos(theta)**24 + 3.15305116459815e+60*cos(theta)**22 - 2.35713533664134e+60*cos(theta)**20 + 1.10855374743033e+60*cos(theta)**18 - 3.42643885569375e+59*cos(theta)**16 + 7.06482238287371e+58*cos(theta)**14 - 9.66765168182719e+57*cos(theta)**12 + 8.57614262097573e+56*cos(theta)**10 - 4.71216627526139e+55*cos(theta)**8 + 1.48247927761033e+54*cos(theta)**6 - 2.32363523136415e+52*cos(theta)**4 + 1.36684425374362e+50*cos(theta)**2 - 1.26676946593477e+47)*cos(28*phi)

#@torch.jit.script
def Yl54_m29(theta, phi):
    return 8.25836000648004e-50*(1.0 - cos(theta)**2)**14.5*(2.05359593242088e+61*cos(theta)**25 - 5.75774560491836e+61*cos(theta)**23 + 6.93671256211593e+61*cos(theta)**21 - 4.71427067328267e+61*cos(theta)**19 + 1.9953967453746e+61*cos(theta)**17 - 5.48230216911e+60*cos(theta)**15 + 9.8907513360232e+59*cos(theta)**13 - 1.16011820181926e+59*cos(theta)**11 + 8.57614262097573e+57*cos(theta)**9 - 3.76973302020911e+56*cos(theta)**7 + 8.89487566566195e+54*cos(theta)**5 - 9.29454092545658e+52*cos(theta)**3 + 2.73368850748723e+50*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl54_m30(theta, phi):
    return 1.80212189742337e-51*(1.0 - cos(theta)**2)**15*(5.13398983105221e+62*cos(theta)**24 - 1.32428148913122e+63*cos(theta)**22 + 1.45670963804435e+63*cos(theta)**20 - 8.95711427923708e+62*cos(theta)**18 + 3.39217446713681e+62*cos(theta)**16 - 8.223453253665e+61*cos(theta)**14 + 1.28579767368302e+61*cos(theta)**12 - 1.27613002200119e+60*cos(theta)**10 + 7.71852835887816e+58*cos(theta)**8 - 2.63881311414638e+57*cos(theta)**6 + 4.44743783283098e+55*cos(theta)**4 - 2.78836227763698e+53*cos(theta)**2 + 2.73368850748723e+50)*cos(30*phi)

#@torch.jit.script
def Yl54_m31(theta, phi):
    return 3.98996494478974e-53*(1.0 - cos(theta)**2)**15.5*(1.23215755945253e+64*cos(theta)**23 - 2.91341927608869e+64*cos(theta)**21 + 2.91341927608869e+64*cos(theta)**19 - 1.61228057026267e+64*cos(theta)**17 + 5.4274791474189e+63*cos(theta)**15 - 1.1512834555131e+63*cos(theta)**13 + 1.54295720841962e+62*cos(theta)**11 - 1.27613002200119e+61*cos(theta)**9 + 6.17482268710253e+59*cos(theta)**7 - 1.58328786848783e+58*cos(theta)**5 + 1.77897513313239e+56*cos(theta)**3 - 5.57672455527395e+53*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl54_m32(theta, phi):
    return 8.97131150020023e-55*(1.0 - cos(theta)**2)**16*(2.83396238674082e+65*cos(theta)**22 - 6.11818047978625e+65*cos(theta)**20 + 5.53549662456851e+65*cos(theta)**18 - 2.74087696944655e+65*cos(theta)**16 + 8.14121872112835e+64*cos(theta)**14 - 1.49666849216703e+64*cos(theta)**12 + 1.69725292926158e+63*cos(theta)**10 - 1.14851701980107e+62*cos(theta)**8 + 4.32237588097177e+60*cos(theta)**6 - 7.91643934243914e+58*cos(theta)**4 + 5.33692539939717e+56*cos(theta)**2 - 5.57672455527395e+53)*cos(32*phi)

#@torch.jit.script
def Yl54_m33(theta, phi):
    return 2.05061896552667e-56*(1.0 - cos(theta)**2)**16.5*(6.2347172508298e+66*cos(theta)**21 - 1.22363609595725e+67*cos(theta)**19 + 9.96389392422332e+66*cos(theta)**17 - 4.38540315111447e+66*cos(theta)**15 + 1.13977062095797e+66*cos(theta)**13 - 1.79600219060044e+65*cos(theta)**11 + 1.69725292926158e+64*cos(theta)**9 - 9.18813615840856e+62*cos(theta)**7 + 2.59342552858306e+61*cos(theta)**5 - 3.16657573697565e+59*cos(theta)**3 + 1.06738507987943e+57*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl54_m34(theta, phi):
    return 4.77017142241554e-58*(1.0 - cos(theta)**2)**17*(1.30929062267426e+68*cos(theta)**20 - 2.32490858231878e+68*cos(theta)**18 + 1.69386196711797e+68*cos(theta)**16 - 6.57810472667171e+67*cos(theta)**14 + 1.48170180724536e+67*cos(theta)**12 - 1.97560240966048e+66*cos(theta)**10 + 1.52752763633542e+65*cos(theta)**8 - 6.43169531088599e+63*cos(theta)**6 + 1.29671276429153e+62*cos(theta)**4 - 9.49972721092696e+59*cos(theta)**2 + 1.06738507987943e+57)*cos(34*phi)

#@torch.jit.script
def Yl54_m35(theta, phi):
    return 1.13063906059803e-59*(1.0 - cos(theta)**2)**17.5*(2.61858124534852e+69*cos(theta)**19 - 4.1848354481738e+69*cos(theta)**17 + 2.71017914738874e+69*cos(theta)**15 - 9.20934661734039e+68*cos(theta)**13 + 1.77804216869443e+68*cos(theta)**11 - 1.97560240966048e+67*cos(theta)**9 + 1.22202210906834e+66*cos(theta)**7 - 3.85901718653159e+64*cos(theta)**5 + 5.18685105716612e+62*cos(theta)**3 - 1.89994544218539e+60*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl54_m36(theta, phi):
    return 2.73417261970188e-61*(1.0 - cos(theta)**2)**18*(4.97530436616218e+70*cos(theta)**18 - 7.11422026189545e+70*cos(theta)**16 + 4.06526872108312e+70*cos(theta)**14 - 1.19721506025425e+70*cos(theta)**12 + 1.95584638556388e+69*cos(theta)**10 - 1.77804216869443e+68*cos(theta)**8 + 8.55415476347837e+66*cos(theta)**6 - 1.9295085932658e+65*cos(theta)**4 + 1.55605531714984e+63*cos(theta)**2 - 1.89994544218539e+60)*cos(36*phi)

#@torch.jit.script
def Yl54_m37(theta, phi):
    return 6.75567861995838e-63*(1.0 - cos(theta)**2)**18.5*(8.95554785909192e+71*cos(theta)**17 - 1.13827524190327e+72*cos(theta)**15 + 5.69137620951636e+71*cos(theta)**13 - 1.4366580723051e+71*cos(theta)**11 + 1.95584638556388e+70*cos(theta)**9 - 1.42243373495555e+69*cos(theta)**7 + 5.13249285808702e+67*cos(theta)**5 - 7.71803437306319e+65*cos(theta)**3 + 3.11211063429967e+63*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl54_m38(theta, phi):
    return 1.70824676458235e-64*(1.0 - cos(theta)**2)**19*(1.52244313604563e+73*cos(theta)**16 - 1.70741286285491e+73*cos(theta)**14 + 7.39878907237127e+72*cos(theta)**12 - 1.58032387953561e+72*cos(theta)**10 + 1.76026174700749e+71*cos(theta)**8 - 9.95703614468882e+69*cos(theta)**6 + 2.56624642904351e+68*cos(theta)**4 - 2.31541031191896e+66*cos(theta)**2 + 3.11211063429967e+63)*cos(38*phi)

#@torch.jit.script
def Yl54_m39(theta, phi):
    return 4.42842344387858e-66*(1.0 - cos(theta)**2)**19.5*(2.435909017673e+74*cos(theta)**15 - 2.39037800799687e+74*cos(theta)**13 + 8.87854688684553e+73*cos(theta)**11 - 1.58032387953561e+73*cos(theta)**9 + 1.40820939760599e+72*cos(theta)**7 - 5.97422168681329e+70*cos(theta)**5 + 1.0264985716174e+69*cos(theta)**3 - 4.63082062383791e+66*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl54_m40(theta, phi):
    return 1.1793415099292e-67*(1.0 - cos(theta)**2)**20*(3.65386352650951e+75*cos(theta)**14 - 3.10749141039593e+75*cos(theta)**12 + 9.76640157553008e+74*cos(theta)**10 - 1.42229149158205e+74*cos(theta)**8 + 9.85746578324193e+72*cos(theta)**6 - 2.98711084340665e+71*cos(theta)**4 + 3.07949571485221e+69*cos(theta)**2 - 4.63082062383791e+66)*cos(40*phi)

#@torch.jit.script
def Yl54_m41(theta, phi):
    return 3.23380452518134e-69*(1.0 - cos(theta)**2)**20.5*(5.11540893711331e+76*cos(theta)**13 - 3.72898969247512e+76*cos(theta)**11 + 9.76640157553008e+75*cos(theta)**9 - 1.13783319326564e+75*cos(theta)**7 + 5.91447946994516e+73*cos(theta)**5 - 1.19484433736266e+72*cos(theta)**3 + 6.15899142970443e+69*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl54_m42(theta, phi):
    return 9.15390649193927e-71*(1.0 - cos(theta)**2)**21*(6.6500316182473e+77*cos(theta)**12 - 4.10188866172263e+77*cos(theta)**10 + 8.78976141797707e+76*cos(theta)**8 - 7.96483235285948e+75*cos(theta)**6 + 2.95723973497258e+74*cos(theta)**4 - 3.58453301208798e+72*cos(theta)**2 + 6.15899142970443e+69)*cos(42*phi)

#@torch.jit.script
def Yl54_m43(theta, phi):
    return 2.68305750962004e-72*(1.0 - cos(theta)**2)**21.5*(7.98003794189676e+78*cos(theta)**11 - 4.10188866172263e+78*cos(theta)**9 + 7.03180913438166e+77*cos(theta)**7 - 4.77889941171569e+76*cos(theta)**5 + 1.18289589398903e+75*cos(theta)**3 - 7.16906602417595e+72*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl54_m44(theta, phi):
    return 8.17185404391848e-74*(1.0 - cos(theta)**2)**22*(8.77804173608644e+79*cos(theta)**10 - 3.69169979555037e+79*cos(theta)**8 + 4.92226639406716e+78*cos(theta)**6 - 2.38944970585784e+77*cos(theta)**4 + 3.5486876819671e+75*cos(theta)**2 - 7.16906602417595e+72)*cos(44*phi)

#@torch.jit.script
def Yl54_m45(theta, phi):
    return 2.59718570521719e-75*(1.0 - cos(theta)**2)**22.5*(8.77804173608644e+80*cos(theta)**9 - 2.9533598364403e+80*cos(theta)**7 + 2.9533598364403e+79*cos(theta)**5 - 9.55779882343138e+77*cos(theta)**3 + 7.09737536393419e+75*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl54_m46(theta, phi):
    return 8.6572856840573e-77*(1.0 - cos(theta)**2)**23*(7.90023756247779e+81*cos(theta)**8 - 2.06735188550821e+81*cos(theta)**6 + 1.47667991822015e+80*cos(theta)**4 - 2.86733964702941e+78*cos(theta)**2 + 7.09737536393419e+75)*cos(46*phi)

#@torch.jit.script
def Yl54_m47(theta, phi):
    return 3.04562247566571e-78*(1.0 - cos(theta)**2)**23.5*(6.32019004998223e+82*cos(theta)**7 - 1.24041113130492e+82*cos(theta)**5 + 5.90671967288059e+80*cos(theta)**3 - 5.73467929405883e+78*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl54_m48(theta, phi):
    return 1.13979556525346e-79*(1.0 - cos(theta)**2)**24*(4.42413303498756e+83*cos(theta)**6 - 6.20205565652462e+82*cos(theta)**4 + 1.77201590186418e+81*cos(theta)**2 - 5.73467929405883e+78)*cos(48*phi)

#@torch.jit.script
def Yl54_m49(theta, phi):
    return 4.58493016708853e-81*(1.0 - cos(theta)**2)**24.5*(2.65447982099254e+84*cos(theta)**5 - 2.48082226260985e+83*cos(theta)**3 + 3.54403180372835e+81*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl54_m50(theta, phi):
    return 2.01062488550386e-82*(1.0 - cos(theta)**2)**25*(1.32723991049627e+85*cos(theta)**4 - 7.44246678782954e+83*cos(theta)**2 + 3.54403180372835e+81)*cos(50*phi)

#@torch.jit.script
def Yl54_m51(theta, phi):
    return 9.81084486217675e-84*(1.0 - cos(theta)**2)**25.5*(5.30895964198508e+85*cos(theta)**3 - 1.48849335756591e+84*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl54_m52(theta, phi):
    return 5.50164860682572e-85*(1.0 - cos(theta)**2)**26*(1.59268789259552e+86*cos(theta)**2 - 1.48849335756591e+84)*cos(52*phi)

#@torch.jit.script
def Yl54_m53(theta, phi):
    return 11.9797191299205*(1.0 - cos(theta)**2)**26.5*cos(53*phi)*cos(theta)

#@torch.jit.script
def Yl54_m54(theta, phi):
    return 1.15274901074596*(1.0 - cos(theta)**2)**27*cos(54*phi)

#@torch.jit.script
def Yl55_m_minus_55(theta, phi):
    return 1.15797692423668*(1.0 - cos(theta)**2)**27.5*sin(55*phi)

#@torch.jit.script
def Yl55_m_minus_54(theta, phi):
    return 12.1449644411629*(1.0 - cos(theta)**2)**27*sin(54*phi)*cos(theta)

#@torch.jit.script
def Yl55_m_minus_53(theta, phi):
    return 5.1646075068539e-87*(1.0 - cos(theta)**2)**26.5*(1.73602980292912e+88*cos(theta)**2 - 1.59268789259552e+86)*sin(53*phi)

#@torch.jit.script
def Yl55_m_minus_52(theta, phi):
    return 9.29629351233703e-86*(1.0 - cos(theta)**2)**26*(5.78676600976373e+87*cos(theta)**3 - 1.59268789259552e+86*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl55_m_minus_51(theta, phi):
    return 1.9232321563685e-84*(1.0 - cos(theta)**2)**25.5*(1.44669150244093e+87*cos(theta)**4 - 7.96343946297761e+85*cos(theta)**2 + 3.72123339391477e+83)*sin(51*phi)

#@torch.jit.script
def Yl55_m_minus_50(theta, phi):
    return 4.42761292511395e-83*(1.0 - cos(theta)**2)**25*(2.89338300488187e+86*cos(theta)**5 - 2.65447982099254e+85*cos(theta)**3 + 3.72123339391477e+83*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl55_m_minus_49(theta, phi):
    return 1.11132202422254e-81*(1.0 - cos(theta)**2)**24.5*(4.82230500813644e+85*cos(theta)**6 - 6.63619955248134e+84*cos(theta)**4 + 1.86061669695739e+83*cos(theta)**2 - 5.90671967288059e+80)*sin(49*phi)

#@torch.jit.script
def Yl55_m_minus_48(theta, phi):
    return 2.99851075540521e-80*(1.0 - cos(theta)**2)**24*(6.88900715448063e+84*cos(theta)**7 - 1.32723991049627e+84*cos(theta)**5 + 6.20205565652462e+82*cos(theta)**3 - 5.90671967288059e+80*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl55_m_minus_47(theta, phi):
    return 8.60734512043714e-79*(1.0 - cos(theta)**2)**23.5*(8.61125894310079e+83*cos(theta)**8 - 2.21206651749378e+83*cos(theta)**6 + 1.55051391413116e+82*cos(theta)**4 - 2.9533598364403e+80*cos(theta)**2 + 7.16834911757353e+77)*sin(47*phi)

#@torch.jit.script
def Yl55_m_minus_46(theta, phi):
    return 2.60789773650125e-77*(1.0 - cos(theta)**2)**23*(9.56806549233421e+82*cos(theta)**9 - 3.16009502499112e+82*cos(theta)**7 + 3.10102782826231e+81*cos(theta)**5 - 9.84453278813432e+79*cos(theta)**3 + 7.16834911757353e+77*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl55_m_minus_45(theta, phi):
    return 8.28802866192487e-76*(1.0 - cos(theta)**2)**22.5*(9.56806549233421e+81*cos(theta)**10 - 3.9501187812389e+81*cos(theta)**8 + 5.16837971377052e+80*cos(theta)**6 - 2.46113319703358e+79*cos(theta)**4 + 3.58417455878677e+77*cos(theta)**2 - 7.09737536393419e+74)*sin(45*phi)

#@torch.jit.script
def Yl55_m_minus_44(theta, phi):
    return 2.74882813233161e-74*(1.0 - cos(theta)**2)**22*(8.69824135666747e+80*cos(theta)**11 - 4.38902086804322e+80*cos(theta)**9 + 7.38339959110074e+79*cos(theta)**7 - 4.92226639406716e+78*cos(theta)**5 + 1.19472485292892e+77*cos(theta)**3 - 7.09737536393419e+74*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl55_m_minus_43(theta, phi):
    return 9.47448924644705e-73*(1.0 - cos(theta)**2)**21.5*(7.24853446388956e+79*cos(theta)**12 - 4.38902086804322e+79*cos(theta)**10 + 9.22924948887592e+78*cos(theta)**8 - 8.20377732344527e+77*cos(theta)**6 + 2.98681213232231e+76*cos(theta)**4 - 3.5486876819671e+74*cos(theta)**2 + 5.97422168681329e+71)*sin(43*phi)

#@torch.jit.script
def Yl55_m_minus_42(theta, phi):
    return 3.38174238842709e-71*(1.0 - cos(theta)**2)**21*(5.5757957414535e+78*cos(theta)**13 - 3.99001897094838e+78*cos(theta)**11 + 1.02547216543066e+78*cos(theta)**9 - 1.17196818906361e+77*cos(theta)**7 + 5.97362426464461e+75*cos(theta)**5 - 1.18289589398903e+74*cos(theta)**3 + 5.97422168681329e+71*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl55_m_minus_41(theta, phi):
    return 1.24620763069112e-69*(1.0 - cos(theta)**2)**20.5*(3.98271124389536e+77*cos(theta)**14 - 3.32501580912365e+77*cos(theta)**12 + 1.02547216543066e+77*cos(theta)**10 - 1.46496023632951e+76*cos(theta)**8 + 9.95604044107435e+74*cos(theta)**6 - 2.95723973497258e+73*cos(theta)**4 + 2.98711084340665e+71*cos(theta)**2 - 4.39927959264602e+68)*sin(41*phi)

#@torch.jit.script
def Yl55_m_minus_40(theta, phi):
    return 4.72902546055906e-68*(1.0 - cos(theta)**2)**20*(2.65514082926357e+76*cos(theta)**15 - 2.55770446855665e+76*cos(theta)**13 + 9.3224742311878e+75*cos(theta)**11 - 1.62773359592168e+75*cos(theta)**9 + 1.42229149158205e+74*cos(theta)**7 - 5.91447946994516e+72*cos(theta)**5 + 9.95703614468882e+70*cos(theta)**3 - 4.39927959264602e+68*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl55_m_minus_39(theta, phi):
    return 1.84371354461739e-66*(1.0 - cos(theta)**2)**19.5*(1.65946301828973e+75*cos(theta)**16 - 1.82693176325475e+75*cos(theta)**14 + 7.76872852598984e+74*cos(theta)**12 - 1.62773359592168e+74*cos(theta)**10 + 1.77786436447756e+73*cos(theta)**8 - 9.85746578324193e+71*cos(theta)**6 + 2.48925903617221e+70*cos(theta)**4 - 2.19963979632301e+68*cos(theta)**2 + 2.8942628898987e+65)*sin(39*phi)

#@torch.jit.script
def Yl55_m_minus_38(theta, phi):
    return 7.37024345330584e-65*(1.0 - cos(theta)**2)**19*(9.7615471664102e+73*cos(theta)**17 - 1.2179545088365e+74*cos(theta)**15 + 5.97594501999218e+73*cos(theta)**13 - 1.47975781447425e+73*cos(theta)**11 + 1.97540484941951e+72*cos(theta)**9 - 1.40820939760599e+71*cos(theta)**7 + 4.97851807234441e+69*cos(theta)**5 - 7.33213265441003e+67*cos(theta)**3 + 2.8942628898987e+65*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl55_m_minus_37(theta, phi):
    return 3.01550158101617e-63*(1.0 - cos(theta)**2)**18.5*(5.42308175911678e+72*cos(theta)**18 - 7.61221568022814e+72*cos(theta)**16 + 4.26853215713727e+72*cos(theta)**14 - 1.23313151206188e+72*cos(theta)**12 + 1.97540484941951e+71*cos(theta)**10 - 1.76026174700749e+70*cos(theta)**8 + 8.29753012057402e+68*cos(theta)**6 - 1.83303316360251e+67*cos(theta)**4 + 1.44713144494935e+65*cos(theta)**2 - 1.72895035238871e+62)*sin(37*phi)

#@torch.jit.script
def Yl55_m_minus_36(theta, phi):
    return 1.2607537675682e-61*(1.0 - cos(theta)**2)**18*(2.85425355742988e+71*cos(theta)**19 - 4.47777392954596e+71*cos(theta)**17 + 2.84568810475818e+71*cos(theta)**15 - 9.4856270158606e+70*cos(theta)**13 + 1.79582259038138e+70*cos(theta)**11 - 1.95584638556388e+69*cos(theta)**9 + 1.18536144579629e+68*cos(theta)**7 - 3.66606632720501e+66*cos(theta)**5 + 4.82377148316449e+64*cos(theta)**3 - 1.72895035238871e+62*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl55_m_minus_35(theta, phi):
    return 5.37855939228719e-60*(1.0 - cos(theta)**2)**17.5*(1.42712677871494e+70*cos(theta)**20 - 2.48765218308109e+70*cos(theta)**18 + 1.77855506547386e+70*cos(theta)**16 - 6.77544786847186e+69*cos(theta)**14 + 1.49651882531781e+69*cos(theta)**12 - 1.95584638556388e+68*cos(theta)**10 + 1.48170180724536e+67*cos(theta)**8 - 6.11011054534169e+65*cos(theta)**6 + 1.20594287079112e+64*cos(theta)**4 - 8.64475176194354e+61*cos(theta)**2 + 9.49972721092696e+58)*sin(35*phi)

#@torch.jit.script
def Yl55_m_minus_34(theta, phi):
    return 2.33828191516168e-58*(1.0 - cos(theta)**2)**17*(6.79584180340448e+68*cos(theta)**21 - 1.30929062267426e+69*cos(theta)**19 + 1.04620886204345e+69*cos(theta)**17 - 4.51696524564791e+68*cos(theta)**15 + 1.15116832716755e+68*cos(theta)**13 - 1.77804216869443e+67*cos(theta)**11 + 1.64633534138373e+66*cos(theta)**9 - 8.72872935048813e+64*cos(theta)**7 + 2.41188574158225e+63*cos(theta)**5 - 2.88158392064785e+61*cos(theta)**3 + 9.49972721092696e+58*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl55_m_minus_33(theta, phi):
    return 1.03467323403691e-56*(1.0 - cos(theta)**2)**16.5*(3.08901900154749e+67*cos(theta)**22 - 6.54645311337129e+67*cos(theta)**20 + 5.81227145579694e+67*cos(theta)**18 - 2.82310327852994e+67*cos(theta)**16 + 8.22263090833964e+66*cos(theta)**14 - 1.48170180724536e+66*cos(theta)**12 + 1.64633534138373e+65*cos(theta)**10 - 1.09109116881102e+64*cos(theta)**8 + 4.01980956930374e+62*cos(theta)**6 - 7.20395980161961e+60*cos(theta)**4 + 4.74986360546348e+58*cos(theta)**2 - 4.85175036308834e+55)*sin(33*phi)

#@torch.jit.script
def Yl55_m_minus_32(theta, phi):
    return 4.65487977427384e-55*(1.0 - cos(theta)**2)**16*(1.34305173980326e+66*cos(theta)**23 - 3.1173586254149e+66*cos(theta)**21 + 3.05909023989313e+66*cos(theta)**19 - 1.66064898737055e+66*cos(theta)**17 + 5.48175393889309e+65*cos(theta)**15 - 1.13977062095797e+65*cos(theta)**13 + 1.49666849216703e+64*cos(theta)**11 - 1.21232352090113e+63*cos(theta)**9 + 5.74258509900535e+61*cos(theta)**7 - 1.44079196032392e+60*cos(theta)**5 + 1.58328786848783e+58*cos(theta)**3 - 4.85175036308834e+55*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl55_m_minus_31(theta, phi):
    return 2.12703049175667e-53*(1.0 - cos(theta)**2)**15.5*(5.5960489158469e+64*cos(theta)**24 - 1.41698119337041e+65*cos(theta)**22 + 1.52954511994656e+65*cos(theta)**20 - 9.22582770761419e+64*cos(theta)**18 + 3.42609621180818e+64*cos(theta)**16 - 8.14121872112835e+63*cos(theta)**14 + 1.24722374347253e+63*cos(theta)**12 - 1.21232352090113e+62*cos(theta)**10 + 7.17823137375669e+60*cos(theta)**8 - 2.4013199338732e+59*cos(theta)**6 + 3.95821967121957e+57*cos(theta)**4 - 2.42587518154417e+55*cos(theta)**2 + 2.32363523136415e+52)*sin(31*phi)

#@torch.jit.script
def Yl55_m_minus_30(theta, phi):
    return 9.862634654419e-52*(1.0 - cos(theta)**2)**15*(2.23841956633876e+63*cos(theta)**25 - 6.16078779726265e+63*cos(theta)**23 + 7.28354819022173e+63*cos(theta)**21 - 4.85569879348115e+63*cos(theta)**19 + 2.01535071282834e+63*cos(theta)**17 - 5.4274791474189e+62*cos(theta)**15 + 9.5940287959425e+61*cos(theta)**13 - 1.1021122917283e+61*cos(theta)**11 + 7.97581263750743e+59*cos(theta)**9 - 3.43045704839029e+58*cos(theta)**7 + 7.91643934243914e+56*cos(theta)**5 - 8.08625060514723e+54*cos(theta)**3 + 2.32363523136415e+52*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl55_m_minus_29(theta, phi):
    return 4.63648738531302e-50*(1.0 - cos(theta)**2)**14.5*(8.60930602437985e+61*cos(theta)**26 - 2.5669949155261e+62*cos(theta)**24 + 3.31070372282806e+62*cos(theta)**22 - 2.42784939674058e+62*cos(theta)**20 + 1.11963928490463e+62*cos(theta)**18 - 3.39217446713681e+61*cos(theta)**16 + 6.8528777113875e+60*cos(theta)**14 - 9.18426909773583e+59*cos(theta)**12 + 7.97581263750743e+58*cos(theta)**10 - 4.28807131048787e+57*cos(theta)**8 + 1.31940655707319e+56*cos(theta)**6 - 2.02156265128681e+54*cos(theta)**4 + 1.16181761568207e+52*cos(theta)**2 - 1.05141865672586e+49)*sin(29*phi)

#@torch.jit.script
def Yl55_m_minus_28(theta, phi):
    return 2.20805866411675e-48*(1.0 - cos(theta)**2)**14*(3.18863186088143e+60*cos(theta)**27 - 1.02679796621044e+61*cos(theta)**25 + 1.43943640122959e+61*cos(theta)**23 - 1.15611876035266e+61*cos(theta)**21 + 5.89283834160334e+60*cos(theta)**19 - 1.9953967453746e+60*cos(theta)**17 + 4.568585140925e+59*cos(theta)**15 - 7.06482238287371e+58*cos(theta)**13 + 7.25073876137039e+57*cos(theta)**11 - 4.76452367831985e+56*cos(theta)**9 + 1.88486651010456e+55*cos(theta)**7 - 4.04312530257361e+53*cos(theta)**5 + 3.87272538560691e+51*cos(theta)**3 - 1.05141865672586e+49*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl55_m_minus_27(theta, phi):
    return 1.06445834118375e-46*(1.0 - cos(theta)**2)**13.5*(1.13879709317194e+59*cos(theta)**28 - 3.94922294696324e+59*cos(theta)**26 + 5.99765167178996e+59*cos(theta)**24 - 5.25508527433025e+59*cos(theta)**22 + 2.94641917080167e+59*cos(theta)**20 - 1.10855374743033e+59*cos(theta)**18 + 2.85536571307813e+58*cos(theta)**16 - 5.04630170205265e+57*cos(theta)**14 + 6.04228230114199e+56*cos(theta)**12 - 4.76452367831985e+55*cos(theta)**10 + 2.3560831376307e+54*cos(theta)**8 - 6.73854217095602e+52*cos(theta)**6 + 9.68181346401727e+50*cos(theta)**4 - 5.25709328362929e+48*cos(theta)**2 + 4.52417666405274e+45)*sin(27*phi)

#@torch.jit.script
def Yl55_m_minus_26(theta, phi):
    return 5.19080356973279e-45*(1.0 - cos(theta)**2)**13*(3.9268865281791e+57*cos(theta)**29 - 1.46267516554194e+58*cos(theta)**27 + 2.39906066871598e+58*cos(theta)**25 - 2.28481968449141e+58*cos(theta)**23 + 1.4030567480008e+58*cos(theta)**21 - 5.83449340752806e+57*cos(theta)**19 + 1.67962689004596e+57*cos(theta)**17 - 3.36420113470177e+56*cos(theta)**15 + 4.64790946241692e+55*cos(theta)**13 - 4.33138516210895e+54*cos(theta)**11 + 2.61787015292299e+53*cos(theta)**9 - 9.62648881565146e+51*cos(theta)**7 + 1.93636269280345e+50*cos(theta)**5 - 1.75236442787643e+48*cos(theta)**3 + 4.52417666405274e+45*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl55_m_minus_25(theta, phi):
    return 2.55880818604889e-43*(1.0 - cos(theta)**2)**12.5*(1.3089621760597e+56*cos(theta)**30 - 5.2238398769355e+56*cos(theta)**28 + 9.2271564181384e+56*cos(theta)**26 - 9.52008201871422e+56*cos(theta)**24 + 6.37753067273089e+56*cos(theta)**22 - 2.91724670376403e+56*cos(theta)**20 + 9.33126050025531e+55*cos(theta)**18 - 2.10262570918861e+55*cos(theta)**16 + 3.3199353302978e+54*cos(theta)**14 - 3.6094876350908e+53*cos(theta)**12 + 2.61787015292299e+52*cos(theta)**10 - 1.20331110195643e+51*cos(theta)**8 + 3.22727115467243e+49*cos(theta)**6 - 4.38091106969107e+47*cos(theta)**4 + 2.26208833202637e+45*cos(theta)**2 - 1.861801096318e+42)*sin(25*phi)

#@torch.jit.script
def Yl55_m_minus_24(theta, phi):
    return 1.27427620027281e-41*(1.0 - cos(theta)**2)**12*(4.22245863245064e+54*cos(theta)**31 - 1.801324095495e+55*cos(theta)**29 + 3.41746534005126e+55*cos(theta)**27 - 3.80803280748569e+55*cos(theta)**25 + 2.77283942292647e+55*cos(theta)**23 - 1.38916509703049e+55*cos(theta)**21 + 4.91118973697648e+54*cos(theta)**19 - 1.23683865246389e+54*cos(theta)**17 + 2.21329022019853e+53*cos(theta)**15 - 2.77652895006984e+52*cos(theta)**13 + 2.37988195720272e+51*cos(theta)**11 - 1.33701233550715e+50*cos(theta)**9 + 4.61038736381775e+48*cos(theta)**7 - 8.76182213938215e+46*cos(theta)**5 + 7.54029444008791e+44*cos(theta)**3 - 1.861801096318e+42*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl55_m_minus_23(theta, phi):
    return 6.40696138729007e-40*(1.0 - cos(theta)**2)**11.5*(1.31951832264083e+53*cos(theta)**32 - 6.00441365165e+53*cos(theta)**30 + 1.22052333573259e+54*cos(theta)**28 - 1.46462800287911e+54*cos(theta)**26 + 1.1553497595527e+54*cos(theta)**24 - 6.31438680468405e+53*cos(theta)**22 + 2.45559486848824e+53*cos(theta)**20 - 6.87132584702159e+52*cos(theta)**18 + 1.38330638762408e+52*cos(theta)**16 - 1.9832349643356e+51*cos(theta)**14 + 1.9832349643356e+50*cos(theta)**12 - 1.33701233550715e+49*cos(theta)**10 + 5.76298420477219e+47*cos(theta)**8 - 1.46030368989702e+46*cos(theta)**6 + 1.88507361002198e+44*cos(theta)**4 - 9.30900548159001e+41*cos(theta)**2 + 7.36471952657437e+38)*sin(23*phi)

#@torch.jit.script
def Yl55_m_minus_22(theta, phi):
    return 3.25054646110025e-38*(1.0 - cos(theta)**2)**11*(3.99854037163887e+51*cos(theta)**33 - 1.93690762956452e+52*cos(theta)**31 + 4.2087011576986e+52*cos(theta)**29 - 5.42454815881152e+52*cos(theta)**27 + 4.62139903821079e+52*cos(theta)**25 - 2.74538556725393e+52*cos(theta)**23 + 1.16933088975631e+52*cos(theta)**21 - 3.6164872879061e+51*cos(theta)**19 + 8.13709639778872e+50*cos(theta)**17 - 1.3221566428904e+50*cos(theta)**15 + 1.52556535718123e+49*cos(theta)**13 - 1.21546575955195e+48*cos(theta)**11 + 6.40331578308021e+46*cos(theta)**9 - 2.08614812842432e+45*cos(theta)**7 + 3.77014722004395e+43*cos(theta)**5 - 3.10300182719667e+41*cos(theta)**3 + 7.36471952657437e+38*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl55_m_minus_21(theta, phi):
    return 1.66318744915687e-36*(1.0 - cos(theta)**2)**10.5*(1.17604128577614e+50*cos(theta)**34 - 6.05283634238911e+50*cos(theta)**32 + 1.40290038589953e+51*cos(theta)**30 - 1.93733862814697e+51*cos(theta)**28 + 1.77746116854261e+51*cos(theta)**26 - 1.14391065302247e+51*cos(theta)**24 + 5.3151404079832e+50*cos(theta)**22 - 1.80824364395305e+50*cos(theta)**20 + 4.52060910988262e+49*cos(theta)**18 - 8.26347901806501e+48*cos(theta)**16 + 1.08968954084374e+48*cos(theta)**14 - 1.01288813295996e+47*cos(theta)**12 + 6.40331578308021e+45*cos(theta)**10 - 2.6076851605304e+44*cos(theta)**8 + 6.28357870007326e+42*cos(theta)**6 - 7.75750456799167e+40*cos(theta)**4 + 3.68235976328719e+38*cos(theta)**2 - 2.81310906286263e+35)*sin(21*phi)

#@torch.jit.script
def Yl55_m_minus_20(theta, phi):
    return 8.57792050916049e-35*(1.0 - cos(theta)**2)**10*(3.36011795936039e+48*cos(theta)**35 - 1.834192831027e+49*cos(theta)**33 + 4.52548511580494e+49*cos(theta)**31 - 6.68047802809301e+49*cos(theta)**29 + 6.58318951312078e+49*cos(theta)**27 - 4.57564261208989e+49*cos(theta)**25 + 2.31093061216661e+49*cos(theta)**23 - 8.61068401882404e+48*cos(theta)**21 + 2.3792679525698e+48*cos(theta)**19 - 4.86087001062648e+47*cos(theta)**17 + 7.26459693895825e+46*cos(theta)**15 - 7.79144717661508e+45*cos(theta)**13 + 5.82119616643655e+44*cos(theta)**11 - 2.89742795614489e+43*cos(theta)**9 + 8.97654100010465e+41*cos(theta)**7 - 1.55150091359833e+40*cos(theta)**5 + 1.22745325442906e+38*cos(theta)**3 - 2.81310906286263e+35*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl55_m_minus_19(theta, phi):
    return 4.45721824354592e-33*(1.0 - cos(theta)**2)**9.5*(9.33366099822331e+46*cos(theta)**36 - 5.39468479713824e+47*cos(theta)**34 + 1.41421409868904e+48*cos(theta)**32 - 2.22682600936434e+48*cos(theta)**30 + 2.35113911182885e+48*cos(theta)**28 - 1.7598625431115e+48*cos(theta)**26 + 9.62887755069421e+47*cos(theta)**24 - 3.91394728128366e+47*cos(theta)**22 + 1.1896339762849e+47*cos(theta)**20 - 2.70048333923693e+46*cos(theta)**18 + 4.54037308684891e+45*cos(theta)**16 - 5.56531941186791e+44*cos(theta)**14 + 4.85099680536379e+43*cos(theta)**12 - 2.89742795614489e+42*cos(theta)**10 + 1.12206762501308e+41*cos(theta)**8 - 2.58583485599723e+39*cos(theta)**6 + 3.06863313607266e+37*cos(theta)**4 - 1.40655453143132e+35*cos(theta)**2 + 1.04189224550468e+32)*sin(19*phi)

#@torch.jit.script
def Yl55_m_minus_18(theta, phi):
    return 2.33227964147739e-31*(1.0 - cos(theta)**2)**9*(2.52261108060089e+45*cos(theta)**37 - 1.54133851346807e+46*cos(theta)**35 + 4.28549726875468e+46*cos(theta)**33 - 7.18330970762689e+46*cos(theta)**31 + 8.10737624768569e+46*cos(theta)**29 - 6.51800941893147e+46*cos(theta)**27 + 3.85155102027768e+46*cos(theta)**25 - 1.70171620925376e+46*cos(theta)**23 + 5.66492369659476e+45*cos(theta)**21 - 1.42130702065102e+45*cos(theta)**19 + 2.67080769814642e+44*cos(theta)**17 - 3.71021294124528e+43*cos(theta)**15 + 3.731536004126e+42*cos(theta)**13 - 2.63402541467717e+41*cos(theta)**11 + 1.24674180557009e+40*cos(theta)**9 - 3.69404979428175e+38*cos(theta)**7 + 6.13726627214531e+36*cos(theta)**5 - 4.68851510477106e+34*cos(theta)**3 + 1.04189224550468e+32*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl55_m_minus_17(theta, phi):
    return 1.22838314773781e-29*(1.0 - cos(theta)**2)**8.5*(6.63845021210762e+43*cos(theta)**38 - 4.28149587074464e+44*cos(theta)**36 + 1.26044037316314e+45*cos(theta)**34 - 2.2447842836334e+45*cos(theta)**32 + 2.70245874922856e+45*cos(theta)**30 - 2.32786050676124e+45*cos(theta)**28 + 1.48136577702988e+45*cos(theta)**26 - 7.09048420522401e+44*cos(theta)**24 + 2.57496531663398e+44*cos(theta)**22 - 7.10653510325508e+43*cos(theta)**20 + 1.48378205452579e+43*cos(theta)**18 - 2.3188830882783e+42*cos(theta)**16 + 2.66538286009e+41*cos(theta)**14 - 2.19502117889764e+40*cos(theta)**12 + 1.24674180557009e+39*cos(theta)**10 - 4.61756224285219e+37*cos(theta)**8 + 1.02287771202422e+36*cos(theta)**6 - 1.17212877619276e+34*cos(theta)**4 + 5.2094612275234e+31*cos(theta)**2 - 3.75592013520072e+28)*sin(17*phi)

#@torch.jit.script
def Yl55_m_minus_16(theta, phi):
    return 6.50927172782842e-28*(1.0 - cos(theta)**2)**8*(1.70216672105324e+42*cos(theta)**39 - 1.1571610461472e+43*cos(theta)**37 + 3.60125820903755e+43*cos(theta)**35 - 6.80237661707092e+43*cos(theta)**33 + 8.71760886847924e+43*cos(theta)**31 - 8.02710519572841e+43*cos(theta)**29 + 5.48653991492548e+43*cos(theta)**27 - 2.83619368208961e+43*cos(theta)**25 + 1.11955013766695e+43*cos(theta)**23 - 3.38406433488337e+42*cos(theta)**21 + 7.80937923434624e+41*cos(theta)**19 - 1.36404887545782e+41*cos(theta)**17 + 1.77692190672666e+40*cos(theta)**15 - 1.68847782992126e+39*cos(theta)**13 + 1.13340164142736e+38*cos(theta)**11 - 5.13062471428021e+36*cos(theta)**9 + 1.46125387432031e+35*cos(theta)**7 - 2.34425755238553e+33*cos(theta)**5 + 1.73648707584113e+31*cos(theta)**3 - 3.75592013520072e+28*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl55_m_minus_15(theta, phi):
    return 3.46889833134161e-26*(1.0 - cos(theta)**2)**7.5*(4.25541680263309e+40*cos(theta)**40 - 3.04516064775579e+41*cos(theta)**38 + 1.00034950251043e+42*cos(theta)**36 - 2.00069900502086e+42*cos(theta)**34 + 2.72425277139976e+42*cos(theta)**32 - 2.67570173190947e+42*cos(theta)**30 + 1.95947854104481e+42*cos(theta)**28 - 1.09084372388062e+42*cos(theta)**26 + 4.66479224027896e+41*cos(theta)**24 - 1.53821106131062e+41*cos(theta)**22 + 3.90468961717312e+40*cos(theta)**20 - 7.57804930809901e+39*cos(theta)**18 + 1.11057619170417e+39*cos(theta)**16 - 1.2060555928009e+38*cos(theta)**14 + 9.44501367856129e+36*cos(theta)**12 - 5.13062471428021e+35*cos(theta)**10 + 1.82656734290039e+34*cos(theta)**8 - 3.90709592064255e+32*cos(theta)**6 + 4.34121768960283e+30*cos(theta)**4 - 1.87796006760036e+28*cos(theta)**2 + 1.32250708985941e+25)*sin(15*phi)

#@torch.jit.script
def Yl55_m_minus_14(theta, phi):
    return 1.85837142862346e-24*(1.0 - cos(theta)**2)**7*(1.03790653722758e+39*cos(theta)**41 - 7.80810422501484e+39*cos(theta)**39 + 2.70364730408224e+40*cos(theta)**37 - 5.71628287148817e+40*cos(theta)**35 + 8.25531142848413e+40*cos(theta)**33 - 8.63129590938538e+40*cos(theta)**31 + 6.75682255532694e+40*cos(theta)**29 - 4.04016194029858e+40*cos(theta)**27 + 1.86591689611158e+40*cos(theta)**25 - 6.68787417961141e+39*cos(theta)**23 + 1.85937600817768e+39*cos(theta)**21 - 3.98844700426264e+38*cos(theta)**19 + 6.53280112767156e+37*cos(theta)**17 - 8.04037061867269e+36*cos(theta)**15 + 7.26539513735484e+35*cos(theta)**13 - 4.66420428570928e+34*cos(theta)**11 + 2.02951926988932e+33*cos(theta)**9 - 5.58156560091792e+31*cos(theta)**7 + 8.68243537920566e+29*cos(theta)**5 - 6.2598668920012e+27*cos(theta)**3 + 1.32250708985941e+25*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl55_m_minus_13(theta, phi):
    return 1.00041849117088e-22*(1.0 - cos(theta)**2)**6.5*(2.47120604101805e+37*cos(theta)**42 - 1.95202605625371e+38*cos(theta)**40 + 7.11486132653221e+38*cos(theta)**38 - 1.58785635319116e+39*cos(theta)**36 + 2.42803277308357e+39*cos(theta)**34 - 2.69727997168293e+39*cos(theta)**32 + 2.25227418510898e+39*cos(theta)**30 - 1.44291497867807e+39*cos(theta)**28 + 7.17660344658301e+38*cos(theta)**26 - 2.78661424150475e+38*cos(theta)**24 + 8.45170912808035e+37*cos(theta)**22 - 1.99422350213132e+37*cos(theta)**20 + 3.62933395981753e+36*cos(theta)**18 - 5.02523163667043e+35*cos(theta)**16 + 5.18956795525346e+34*cos(theta)**14 - 3.88683690475773e+33*cos(theta)**12 + 2.02951926988932e+32*cos(theta)**10 - 6.9769570011474e+30*cos(theta)**8 + 1.44707256320094e+29*cos(theta)**6 - 1.5649667230003e+27*cos(theta)**4 + 6.61253544929704e+24*cos(theta)**2 - 4.56351652815531e+21)*sin(13*phi)

#@torch.jit.script
def Yl55_m_minus_12(theta, phi):
    return 5.40966528397239e-21*(1.0 - cos(theta)**2)**6*(5.74699079306524e+35*cos(theta)**43 - 4.76103916159442e+36*cos(theta)**41 + 1.82432341705954e+37*cos(theta)**39 - 4.2915036572734e+37*cos(theta)**37 + 6.93723649452448e+37*cos(theta)**35 - 8.17357567176646e+37*cos(theta)**33 + 7.26540059712574e+37*cos(theta)**31 - 4.97556889199333e+37*cos(theta)**29 + 2.65800127651223e+37*cos(theta)**27 - 1.1146456966019e+37*cos(theta)**25 + 3.67465614264363e+36*cos(theta)**23 - 9.49630239110152e+35*cos(theta)**21 + 1.91017576832502e+35*cos(theta)**19 - 2.95601860980614e+34*cos(theta)**17 + 3.45971197016897e+33*cos(theta)**15 - 2.98987454212133e+32*cos(theta)**13 + 1.8450175180812e+31*cos(theta)**11 - 7.75217444571934e+29*cos(theta)**9 + 2.06724651885849e+28*cos(theta)**7 - 3.1299334460006e+26*cos(theta)**5 + 2.20417848309901e+24*cos(theta)**3 - 4.56351652815531e+21*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl55_m_minus_11(theta, phi):
    return 2.93720415655174e-19*(1.0 - cos(theta)**2)**5.5*(1.30613427115119e+34*cos(theta)**44 - 1.13358075276057e+35*cos(theta)**42 + 4.56080854264886e+35*cos(theta)**40 - 1.12934306770353e+36*cos(theta)**38 + 1.92701013736791e+36*cos(theta)**36 - 2.40399284463719e+36*cos(theta)**34 + 2.27043768660179e+36*cos(theta)**32 - 1.65852296399778e+36*cos(theta)**30 + 9.49286170182938e+35*cos(theta)**28 - 4.28709883308424e+35*cos(theta)**26 + 1.53110672610151e+35*cos(theta)**24 - 4.31650108686433e+34*cos(theta)**22 + 9.55087884162509e+33*cos(theta)**20 - 1.64223256100341e+33*cos(theta)**18 + 2.16231998135561e+32*cos(theta)**16 - 2.13562467294381e+31*cos(theta)**14 + 1.537514598401e+30*cos(theta)**12 - 7.75217444571934e+28*cos(theta)**10 + 2.58405814857311e+27*cos(theta)**8 - 5.21655574333433e+25*cos(theta)**6 + 5.51044620774753e+23*cos(theta)**4 - 2.28175826407765e+21*cos(theta)**2 + 1.54800424971347e+18)*sin(11*phi)

#@torch.jit.script
def Yl55_m_minus_10(theta, phi):
    return 1.60070889683529e-17*(1.0 - cos(theta)**2)**5*(2.9025206025582e+32*cos(theta)**45 - 2.63623430874552e+33*cos(theta)**43 + 1.11239232747533e+34*cos(theta)**41 - 2.89575145565007e+34*cos(theta)**39 + 5.20813550639976e+34*cos(theta)**37 - 6.8685509846777e+34*cos(theta)**35 + 6.88011420182362e+34*cos(theta)**33 - 5.35007407741218e+34*cos(theta)**31 + 3.27340058683772e+34*cos(theta)**29 - 1.58781438262379e+34*cos(theta)**27 + 6.12442690440605e+33*cos(theta)**25 - 1.87673960298449e+33*cos(theta)**23 + 4.54803754363099e+32*cos(theta)**21 - 8.64332926843899e+31*cos(theta)**19 + 1.27195293020918e+31*cos(theta)**17 - 1.42374978196254e+30*cos(theta)**15 + 1.18270353723154e+29*cos(theta)**13 - 7.04743131429031e+27*cos(theta)**11 + 2.87117572063679e+26*cos(theta)**9 - 7.45222249047762e+24*cos(theta)**7 + 1.10208924154951e+23*cos(theta)**5 - 7.60586088025884e+20*cos(theta)**3 + 1.54800424971347e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl55_m_minus_9(theta, phi):
    return 8.75281910443651e-16*(1.0 - cos(theta)**2)**4.5*(6.30982739686566e+30*cos(theta)**46 - 5.99144161078528e+31*cos(theta)**44 + 2.64855316065555e+32*cos(theta)**42 - 7.23937863912517e+32*cos(theta)**40 + 1.37056197536836e+33*cos(theta)**38 - 1.90793082907714e+33*cos(theta)**36 + 2.02356300053636e+33*cos(theta)**34 - 1.67189814919131e+33*cos(theta)**32 + 1.09113352894591e+33*cos(theta)**30 - 5.67076565222782e+32*cos(theta)**28 + 2.35554880938694e+32*cos(theta)**26 - 7.81974834576871e+31*cos(theta)**24 + 2.06728979255954e+31*cos(theta)**22 - 4.3216646342195e+30*cos(theta)**20 + 7.06640516782878e+29*cos(theta)**18 - 8.89843613726587e+28*cos(theta)**16 + 8.44788240879672e+27*cos(theta)**14 - 5.87285942857526e+26*cos(theta)**12 + 2.87117572063679e+25*cos(theta)**10 - 9.31527811309702e+23*cos(theta)**8 + 1.83681540258251e+22*cos(theta)**6 - 1.90146522006471e+20*cos(theta)**4 + 7.74002124856734e+17*cos(theta)**2 - 517727173817214.0)*sin(9*phi)

#@torch.jit.script
def Yl55_m_minus_8(theta, phi):
    return 4.80050436478467e-14*(1.0 - cos(theta)**2)**4*(1.34251646741823e+29*cos(theta)**47 - 1.3314314690634e+30*cos(theta)**45 + 6.1594259550129e+30*cos(theta)**43 - 1.7657021071037e+31*cos(theta)**41 + 3.51426147530348e+31*cos(theta)**39 - 5.15656980831659e+31*cos(theta)**37 + 5.78160857296103e+31*cos(theta)**35 - 5.06635802785245e+31*cos(theta)**33 + 3.51978557724486e+31*cos(theta)**31 - 1.9554364318027e+31*cos(theta)**29 + 8.72425484958127e+30*cos(theta)**27 - 3.12789933830748e+30*cos(theta)**25 + 8.98821648938932e+29*cos(theta)**23 - 2.05793554010452e+29*cos(theta)**21 + 3.71916061464673e+28*cos(theta)**19 - 5.23437419839169e+27*cos(theta)**17 + 5.63192160586448e+26*cos(theta)**15 - 4.51758417582712e+25*cos(theta)**13 + 2.61015974603345e+24*cos(theta)**11 - 1.03503090145522e+23*cos(theta)**9 + 2.6240220036893e+21*cos(theta)**7 - 3.80293044012942e+19*cos(theta)**5 + 2.58000708285578e+17*cos(theta)**3 - 517727173817214.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl55_m_minus_7(theta, phi):
    return 2.639840955071e-12*(1.0 - cos(theta)**2)**3.5*(2.7969093071213e+27*cos(theta)**48 - 2.89441623709434e+28*cos(theta)**46 + 1.39986953523021e+29*cos(theta)**44 - 4.20405263596119e+29*cos(theta)**42 + 8.7856536882587e+29*cos(theta)**40 - 1.35699205482016e+30*cos(theta)**38 + 1.60600238137806e+30*cos(theta)**36 - 1.49010530230954e+30*cos(theta)**34 + 1.09993299288902e+30*cos(theta)**32 - 6.51812143934233e+29*cos(theta)**30 + 3.11580530342188e+29*cos(theta)**28 - 1.20303820704134e+29*cos(theta)**26 + 3.74509020391222e+28*cos(theta)**24 - 9.35425245502056e+27*cos(theta)**22 + 1.85958030732336e+27*cos(theta)**20 - 2.90798566577316e+26*cos(theta)**18 + 3.5199510036653e+25*cos(theta)**16 - 3.22684583987651e+24*cos(theta)**14 + 2.17513312169454e+23*cos(theta)**12 - 1.03503090145522e+22*cos(theta)**10 + 3.28002750461163e+20*cos(theta)**8 - 6.3382174002157e+18*cos(theta)**6 + 6.45001770713945e+16*cos(theta)**4 - 258863586908607.0*cos(theta)**2 + 171206075997.756)*sin(7*phi)

#@torch.jit.script
def Yl55_m_minus_6(theta, phi):
    return 1.45502899264575e-10*(1.0 - cos(theta)**2)**3*(5.70797817779858e+25*cos(theta)**49 - 6.15833241934966e+26*cos(theta)**47 + 3.11082118940046e+27*cos(theta)**45 - 9.77686659525858e+27*cos(theta)**43 + 2.14284236298993e+28*cos(theta)**41 - 3.47946680723117e+28*cos(theta)**39 + 4.34054697669747e+28*cos(theta)**37 - 4.25744372088441e+28*cos(theta)**35 + 3.33313028148187e+28*cos(theta)**33 - 2.10261981914269e+28*cos(theta)**31 + 1.07441562186961e+28*cos(theta)**29 - 4.45569706311607e+27*cos(theta)**27 + 1.49803608156489e+27*cos(theta)**25 - 4.06706628479155e+26*cos(theta)**23 + 8.85514432058745e+25*cos(theta)**21 - 1.53051877145956e+25*cos(theta)**19 + 2.07055941392076e+24*cos(theta)**17 - 2.15123055991768e+23*cos(theta)**15 + 1.67317932438041e+22*cos(theta)**13 - 9.40937183141113e+20*cos(theta)**11 + 3.64447500512403e+19*cos(theta)**9 - 9.05459628602243e+17*cos(theta)**7 + 1.29000354142789e+16*cos(theta)**5 - 86287862302868.9*cos(theta)**3 + 171206075997.756*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl55_m_minus_5(theta, phi):
    return 8.03566025712332e-9*(1.0 - cos(theta)**2)**2.5*(1.14159563555972e+24*cos(theta)**50 - 1.28298592069785e+25*cos(theta)**48 + 6.76265475956621e+25*cos(theta)**46 - 2.22201513528604e+26*cos(theta)**44 + 5.10200562616649e+26*cos(theta)**42 - 8.69866701807792e+26*cos(theta)**40 + 1.14224920439407e+27*cos(theta)**38 - 1.18262325580122e+27*cos(theta)**36 + 9.80332435729962e+26*cos(theta)**34 - 6.57068693482089e+26*cos(theta)**32 + 3.58138540623205e+26*cos(theta)**30 - 1.59132037968431e+26*cos(theta)**28 + 5.76167723678802e+25*cos(theta)**26 - 1.69461095199648e+25*cos(theta)**24 + 4.02506560026702e+24*cos(theta)**22 - 7.65259385729779e+23*cos(theta)**20 + 1.15031078551154e+23*cos(theta)**18 - 1.34451909994855e+22*cos(theta)**16 + 1.19512808884315e+21*cos(theta)**14 - 7.84114319284261e+19*cos(theta)**12 + 3.64447500512403e+18*cos(theta)**10 - 1.1318245357528e+17*cos(theta)**8 + 2.15000590237982e+15*cos(theta)**6 - 21571965575717.2*cos(theta)**4 + 85603037998.8779*cos(theta)**2 - 56133139.6713954)*sin(5*phi)

#@torch.jit.script
def Yl55_m_minus_4(theta, phi):
    return 4.445107619055e-7*(1.0 - cos(theta)**2)**2*(2.23842281482297e+22*cos(theta)**51 - 2.61833861366907e+23*cos(theta)**49 + 1.43886271480132e+24*cos(theta)**47 - 4.93781141174676e+24*cos(theta)**45 + 1.18651293631779e+25*cos(theta)**43 - 2.12162610197022e+25*cos(theta)**41 + 2.92884411383095e+25*cos(theta)**39 - 3.19627906973304e+25*cos(theta)**37 + 2.80094981637132e+25*cos(theta)**35 - 1.99111725297603e+25*cos(theta)**33 + 1.15528561491356e+25*cos(theta)**31 - 5.48731165408383e+24*cos(theta)**29 + 2.13395453214371e+24*cos(theta)**27 - 6.77844380798591e+23*cos(theta)**25 + 1.75002852185523e+23*cos(theta)**23 - 3.64409231299895e+22*cos(theta)**21 + 6.05426729216598e+21*cos(theta)**19 - 7.90893588205028e+20*cos(theta)**17 + 7.96752059228769e+19*cos(theta)**15 - 6.03164860987893e+18*cos(theta)**13 + 3.3131590955673e+17*cos(theta)**11 - 1.25758281750312e+16*cos(theta)**9 + 307143700339974.0*cos(theta)**7 - 4314393115143.45*cos(theta)**5 + 28534345999.626*cos(theta)**3 - 56133139.6713954*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl55_m_minus_3(theta, phi):
    return 2.46212420469807e-5*(1.0 - cos(theta)**2)**1.5*(4.30465925927494e+20*cos(theta)**52 - 5.23667722733814e+21*cos(theta)**50 + 2.99763065583609e+22*cos(theta)**48 - 1.07343726342321e+23*cos(theta)**46 + 2.69662030981316e+23*cos(theta)**44 - 5.05149071897672e+23*cos(theta)**42 + 7.32211028457737e+23*cos(theta)**40 - 8.41126070982379e+23*cos(theta)**38 + 7.780416156587e+23*cos(theta)**36 - 5.85622721463538e+23*cos(theta)**34 + 3.61026754660489e+23*cos(theta)**32 - 1.82910388469461e+23*cos(theta)**30 + 7.62126618622755e+22*cos(theta)**28 - 2.60709377230227e+22*cos(theta)**26 + 7.29178550773011e+21*cos(theta)**24 - 1.6564055968177e+21*cos(theta)**22 + 3.02713364608299e+20*cos(theta)**20 - 4.39385326780571e+19*cos(theta)**18 + 4.97970037017981e+18*cos(theta)**16 - 4.30832043562781e+17*cos(theta)**14 + 2.76096591297275e+16*cos(theta)**12 - 1.25758281750312e+15*cos(theta)**10 + 38392962542496.8*cos(theta)**8 - 719065519190.574*cos(theta)**6 + 7133586499.90649*cos(theta)**4 - 28066569.8356977*cos(theta)**2 + 18296.329749477)*sin(3*phi)

#@torch.jit.script
def Yl55_m_minus_2(theta, phi):
    return 0.0013650918984608*(1.0 - cos(theta)**2)*(8.12199860240555e+18*cos(theta)**53 - 1.02679945634081e+20*cos(theta)**51 + 6.11761358333895e+20*cos(theta)**49 - 2.28390907111321e+21*cos(theta)**47 + 5.99248957736257e+21*cos(theta)**45 - 1.17476528348296e+22*cos(theta)**43 + 1.78588055721399e+22*cos(theta)**41 - 2.15673351533943e+22*cos(theta)**39 + 2.10281517745595e+22*cos(theta)**37 - 1.67320777561011e+22*cos(theta)**35 + 1.09402046866815e+22*cos(theta)**33 - 5.9003351119181e+21*cos(theta)**31 + 2.62802282283708e+21*cos(theta)**29 - 9.65590286037879e+20*cos(theta)**27 + 2.91671420309204e+20*cos(theta)**25 - 7.2017634644248e+19*cos(theta)**23 + 1.44149221242047e+19*cos(theta)**21 - 2.31255435147669e+18*cos(theta)**19 + 2.92923551187047e+17*cos(theta)**17 - 2.87221362375187e+16*cos(theta)**15 + 2.12381993305596e+15*cos(theta)**13 - 114325710682101.0*cos(theta)**11 + 4265884726944.08*cos(theta)**9 - 102723645598.654*cos(theta)**7 + 1426717299.9813*cos(theta)**5 - 9355523.27856589*cos(theta)**3 + 18296.329749477*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl55_m_minus_1(theta, phi):
    return 0.0757349245279011*(1.0 - cos(theta)**2)**0.5*(1.50407381526029e+17*cos(theta)**54 - 1.97461433911695e+18*cos(theta)**52 + 1.22352271666779e+19*cos(theta)**50 - 4.75814389815252e+19*cos(theta)**48 + 1.3027151255136e+20*cos(theta)**46 - 2.66992109882491e+20*cos(theta)**44 + 4.25209656479522e+20*cos(theta)**42 - 5.39183378834858e+20*cos(theta)**40 + 5.53372415119986e+20*cos(theta)**38 - 4.64779937669474e+20*cos(theta)**36 + 3.21770726078867e+20*cos(theta)**34 - 1.84385472247441e+20*cos(theta)**32 + 8.76007607612361e+19*cos(theta)**30 - 3.44853673584957e+19*cos(theta)**28 + 1.1218131550354e+19*cos(theta)**26 - 3.00073477684367e+18*cos(theta)**24 + 6.55223732918396e+17*cos(theta)**22 - 1.15627717573835e+17*cos(theta)**20 + 1.62735306215026e+16*cos(theta)**18 - 1.79513351484492e+15*cos(theta)**16 + 151701423789712.0*cos(theta)**14 - 9527142556841.79*cos(theta)**12 + 426588472694.408*cos(theta)**10 - 12840455699.8317*cos(theta)**8 + 237786216.66355*cos(theta)**6 - 2338880.81964147*cos(theta)**4 + 9148.16487473849*cos(theta)**2 - 5.94422668923878)*sin(phi)

#@torch.jit.script
def Yl55_m0(theta, phi):
    return 2.55336494205123e+16*cos(theta)**55 - 3.47866691646429e+17*cos(theta)**53 + 2.24000140695692e+18*cos(theta)**51 - 9.06667236149228e+18*cos(theta)**49 + 2.58796279056187e+19*cos(theta)**47 - 5.53977777544037e+19*cos(theta)**45 + 9.23296295906728e+19*cos(theta)**43 - 1.2278888883708e+20*cos(theta)**41 + 1.32482748482113e+20*cos(theta)**39 - 1.17287594534344e+20*cos(theta)**37 + 8.5839052703157e+19*cos(theta)**35 - 5.21698022046766e+19*cos(theta)**33 + 2.63847275517905e+19*cos(theta)**31 - 1.11030753950974e+19*cos(theta)**29 + 3.87938778864847e+18*cos(theta)**27 - 1.12071202783178e+18*cos(theta)**25 + 2.65991778757543e+17*cos(theta)**23 - 5.14101757262478e+16*cos(theta)**21 + 7.99713844630521e+15*cos(theta)**19 - 985948575571876.0*cos(theta)**17 + 94428877660405.0*cos(theta)**15 - 6842672294232.25*cos(theta)**13 + 362095277442.412*cos(theta)**11 - 13321230942.6974*cos(theta)**9 + 317172165.30232*cos(theta)**7 - 4367616.70252375*cos(theta)**5 + 28472.0775914195*cos(theta)**3 - 55.5011259091998*cos(theta)

#@torch.jit.script
def Yl55_m1(theta, phi):
    return 0.0757349245279011*(1.0 - cos(theta)**2)**0.5*(1.50407381526029e+17*cos(theta)**54 - 1.97461433911695e+18*cos(theta)**52 + 1.22352271666779e+19*cos(theta)**50 - 4.75814389815252e+19*cos(theta)**48 + 1.3027151255136e+20*cos(theta)**46 - 2.66992109882491e+20*cos(theta)**44 + 4.25209656479522e+20*cos(theta)**42 - 5.39183378834858e+20*cos(theta)**40 + 5.53372415119986e+20*cos(theta)**38 - 4.64779937669474e+20*cos(theta)**36 + 3.21770726078867e+20*cos(theta)**34 - 1.84385472247441e+20*cos(theta)**32 + 8.76007607612361e+19*cos(theta)**30 - 3.44853673584957e+19*cos(theta)**28 + 1.1218131550354e+19*cos(theta)**26 - 3.00073477684367e+18*cos(theta)**24 + 6.55223732918396e+17*cos(theta)**22 - 1.15627717573835e+17*cos(theta)**20 + 1.62735306215026e+16*cos(theta)**18 - 1.79513351484492e+15*cos(theta)**16 + 151701423789712.0*cos(theta)**14 - 9527142556841.79*cos(theta)**12 + 426588472694.408*cos(theta)**10 - 12840455699.8317*cos(theta)**8 + 237786216.66355*cos(theta)**6 - 2338880.81964147*cos(theta)**4 + 9148.16487473849*cos(theta)**2 - 5.94422668923878)*cos(phi)

#@torch.jit.script
def Yl55_m2(theta, phi):
    return 0.0013650918984608*(1.0 - cos(theta)**2)*(8.12199860240555e+18*cos(theta)**53 - 1.02679945634081e+20*cos(theta)**51 + 6.11761358333895e+20*cos(theta)**49 - 2.28390907111321e+21*cos(theta)**47 + 5.99248957736257e+21*cos(theta)**45 - 1.17476528348296e+22*cos(theta)**43 + 1.78588055721399e+22*cos(theta)**41 - 2.15673351533943e+22*cos(theta)**39 + 2.10281517745595e+22*cos(theta)**37 - 1.67320777561011e+22*cos(theta)**35 + 1.09402046866815e+22*cos(theta)**33 - 5.9003351119181e+21*cos(theta)**31 + 2.62802282283708e+21*cos(theta)**29 - 9.65590286037879e+20*cos(theta)**27 + 2.91671420309204e+20*cos(theta)**25 - 7.2017634644248e+19*cos(theta)**23 + 1.44149221242047e+19*cos(theta)**21 - 2.31255435147669e+18*cos(theta)**19 + 2.92923551187047e+17*cos(theta)**17 - 2.87221362375187e+16*cos(theta)**15 + 2.12381993305596e+15*cos(theta)**13 - 114325710682101.0*cos(theta)**11 + 4265884726944.08*cos(theta)**9 - 102723645598.654*cos(theta)**7 + 1426717299.9813*cos(theta)**5 - 9355523.27856589*cos(theta)**3 + 18296.329749477*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl55_m3(theta, phi):
    return 2.46212420469807e-5*(1.0 - cos(theta)**2)**1.5*(4.30465925927494e+20*cos(theta)**52 - 5.23667722733814e+21*cos(theta)**50 + 2.99763065583609e+22*cos(theta)**48 - 1.07343726342321e+23*cos(theta)**46 + 2.69662030981316e+23*cos(theta)**44 - 5.05149071897672e+23*cos(theta)**42 + 7.32211028457737e+23*cos(theta)**40 - 8.41126070982379e+23*cos(theta)**38 + 7.780416156587e+23*cos(theta)**36 - 5.85622721463538e+23*cos(theta)**34 + 3.61026754660489e+23*cos(theta)**32 - 1.82910388469461e+23*cos(theta)**30 + 7.62126618622755e+22*cos(theta)**28 - 2.60709377230227e+22*cos(theta)**26 + 7.29178550773011e+21*cos(theta)**24 - 1.6564055968177e+21*cos(theta)**22 + 3.02713364608299e+20*cos(theta)**20 - 4.39385326780571e+19*cos(theta)**18 + 4.97970037017981e+18*cos(theta)**16 - 4.30832043562781e+17*cos(theta)**14 + 2.76096591297275e+16*cos(theta)**12 - 1.25758281750312e+15*cos(theta)**10 + 38392962542496.8*cos(theta)**8 - 719065519190.574*cos(theta)**6 + 7133586499.90649*cos(theta)**4 - 28066569.8356977*cos(theta)**2 + 18296.329749477)*cos(3*phi)

#@torch.jit.script
def Yl55_m4(theta, phi):
    return 4.445107619055e-7*(1.0 - cos(theta)**2)**2*(2.23842281482297e+22*cos(theta)**51 - 2.61833861366907e+23*cos(theta)**49 + 1.43886271480132e+24*cos(theta)**47 - 4.93781141174676e+24*cos(theta)**45 + 1.18651293631779e+25*cos(theta)**43 - 2.12162610197022e+25*cos(theta)**41 + 2.92884411383095e+25*cos(theta)**39 - 3.19627906973304e+25*cos(theta)**37 + 2.80094981637132e+25*cos(theta)**35 - 1.99111725297603e+25*cos(theta)**33 + 1.15528561491356e+25*cos(theta)**31 - 5.48731165408383e+24*cos(theta)**29 + 2.13395453214371e+24*cos(theta)**27 - 6.77844380798591e+23*cos(theta)**25 + 1.75002852185523e+23*cos(theta)**23 - 3.64409231299895e+22*cos(theta)**21 + 6.05426729216598e+21*cos(theta)**19 - 7.90893588205028e+20*cos(theta)**17 + 7.96752059228769e+19*cos(theta)**15 - 6.03164860987893e+18*cos(theta)**13 + 3.3131590955673e+17*cos(theta)**11 - 1.25758281750312e+16*cos(theta)**9 + 307143700339974.0*cos(theta)**7 - 4314393115143.45*cos(theta)**5 + 28534345999.626*cos(theta)**3 - 56133139.6713954*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl55_m5(theta, phi):
    return 8.03566025712332e-9*(1.0 - cos(theta)**2)**2.5*(1.14159563555972e+24*cos(theta)**50 - 1.28298592069785e+25*cos(theta)**48 + 6.76265475956621e+25*cos(theta)**46 - 2.22201513528604e+26*cos(theta)**44 + 5.10200562616649e+26*cos(theta)**42 - 8.69866701807792e+26*cos(theta)**40 + 1.14224920439407e+27*cos(theta)**38 - 1.18262325580122e+27*cos(theta)**36 + 9.80332435729962e+26*cos(theta)**34 - 6.57068693482089e+26*cos(theta)**32 + 3.58138540623205e+26*cos(theta)**30 - 1.59132037968431e+26*cos(theta)**28 + 5.76167723678802e+25*cos(theta)**26 - 1.69461095199648e+25*cos(theta)**24 + 4.02506560026702e+24*cos(theta)**22 - 7.65259385729779e+23*cos(theta)**20 + 1.15031078551154e+23*cos(theta)**18 - 1.34451909994855e+22*cos(theta)**16 + 1.19512808884315e+21*cos(theta)**14 - 7.84114319284261e+19*cos(theta)**12 + 3.64447500512403e+18*cos(theta)**10 - 1.1318245357528e+17*cos(theta)**8 + 2.15000590237982e+15*cos(theta)**6 - 21571965575717.2*cos(theta)**4 + 85603037998.8779*cos(theta)**2 - 56133139.6713954)*cos(5*phi)

#@torch.jit.script
def Yl55_m6(theta, phi):
    return 1.45502899264575e-10*(1.0 - cos(theta)**2)**3*(5.70797817779858e+25*cos(theta)**49 - 6.15833241934966e+26*cos(theta)**47 + 3.11082118940046e+27*cos(theta)**45 - 9.77686659525858e+27*cos(theta)**43 + 2.14284236298993e+28*cos(theta)**41 - 3.47946680723117e+28*cos(theta)**39 + 4.34054697669747e+28*cos(theta)**37 - 4.25744372088441e+28*cos(theta)**35 + 3.33313028148187e+28*cos(theta)**33 - 2.10261981914269e+28*cos(theta)**31 + 1.07441562186961e+28*cos(theta)**29 - 4.45569706311607e+27*cos(theta)**27 + 1.49803608156489e+27*cos(theta)**25 - 4.06706628479155e+26*cos(theta)**23 + 8.85514432058745e+25*cos(theta)**21 - 1.53051877145956e+25*cos(theta)**19 + 2.07055941392076e+24*cos(theta)**17 - 2.15123055991768e+23*cos(theta)**15 + 1.67317932438041e+22*cos(theta)**13 - 9.40937183141113e+20*cos(theta)**11 + 3.64447500512403e+19*cos(theta)**9 - 9.05459628602243e+17*cos(theta)**7 + 1.29000354142789e+16*cos(theta)**5 - 86287862302868.9*cos(theta)**3 + 171206075997.756*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl55_m7(theta, phi):
    return 2.639840955071e-12*(1.0 - cos(theta)**2)**3.5*(2.7969093071213e+27*cos(theta)**48 - 2.89441623709434e+28*cos(theta)**46 + 1.39986953523021e+29*cos(theta)**44 - 4.20405263596119e+29*cos(theta)**42 + 8.7856536882587e+29*cos(theta)**40 - 1.35699205482016e+30*cos(theta)**38 + 1.60600238137806e+30*cos(theta)**36 - 1.49010530230954e+30*cos(theta)**34 + 1.09993299288902e+30*cos(theta)**32 - 6.51812143934233e+29*cos(theta)**30 + 3.11580530342188e+29*cos(theta)**28 - 1.20303820704134e+29*cos(theta)**26 + 3.74509020391222e+28*cos(theta)**24 - 9.35425245502056e+27*cos(theta)**22 + 1.85958030732336e+27*cos(theta)**20 - 2.90798566577316e+26*cos(theta)**18 + 3.5199510036653e+25*cos(theta)**16 - 3.22684583987651e+24*cos(theta)**14 + 2.17513312169454e+23*cos(theta)**12 - 1.03503090145522e+22*cos(theta)**10 + 3.28002750461163e+20*cos(theta)**8 - 6.3382174002157e+18*cos(theta)**6 + 6.45001770713945e+16*cos(theta)**4 - 258863586908607.0*cos(theta)**2 + 171206075997.756)*cos(7*phi)

#@torch.jit.script
def Yl55_m8(theta, phi):
    return 4.80050436478467e-14*(1.0 - cos(theta)**2)**4*(1.34251646741823e+29*cos(theta)**47 - 1.3314314690634e+30*cos(theta)**45 + 6.1594259550129e+30*cos(theta)**43 - 1.7657021071037e+31*cos(theta)**41 + 3.51426147530348e+31*cos(theta)**39 - 5.15656980831659e+31*cos(theta)**37 + 5.78160857296103e+31*cos(theta)**35 - 5.06635802785245e+31*cos(theta)**33 + 3.51978557724486e+31*cos(theta)**31 - 1.9554364318027e+31*cos(theta)**29 + 8.72425484958127e+30*cos(theta)**27 - 3.12789933830748e+30*cos(theta)**25 + 8.98821648938932e+29*cos(theta)**23 - 2.05793554010452e+29*cos(theta)**21 + 3.71916061464673e+28*cos(theta)**19 - 5.23437419839169e+27*cos(theta)**17 + 5.63192160586448e+26*cos(theta)**15 - 4.51758417582712e+25*cos(theta)**13 + 2.61015974603345e+24*cos(theta)**11 - 1.03503090145522e+23*cos(theta)**9 + 2.6240220036893e+21*cos(theta)**7 - 3.80293044012942e+19*cos(theta)**5 + 2.58000708285578e+17*cos(theta)**3 - 517727173817214.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl55_m9(theta, phi):
    return 8.75281910443651e-16*(1.0 - cos(theta)**2)**4.5*(6.30982739686566e+30*cos(theta)**46 - 5.99144161078528e+31*cos(theta)**44 + 2.64855316065555e+32*cos(theta)**42 - 7.23937863912517e+32*cos(theta)**40 + 1.37056197536836e+33*cos(theta)**38 - 1.90793082907714e+33*cos(theta)**36 + 2.02356300053636e+33*cos(theta)**34 - 1.67189814919131e+33*cos(theta)**32 + 1.09113352894591e+33*cos(theta)**30 - 5.67076565222782e+32*cos(theta)**28 + 2.35554880938694e+32*cos(theta)**26 - 7.81974834576871e+31*cos(theta)**24 + 2.06728979255954e+31*cos(theta)**22 - 4.3216646342195e+30*cos(theta)**20 + 7.06640516782878e+29*cos(theta)**18 - 8.89843613726587e+28*cos(theta)**16 + 8.44788240879672e+27*cos(theta)**14 - 5.87285942857526e+26*cos(theta)**12 + 2.87117572063679e+25*cos(theta)**10 - 9.31527811309702e+23*cos(theta)**8 + 1.83681540258251e+22*cos(theta)**6 - 1.90146522006471e+20*cos(theta)**4 + 7.74002124856734e+17*cos(theta)**2 - 517727173817214.0)*cos(9*phi)

#@torch.jit.script
def Yl55_m10(theta, phi):
    return 1.60070889683529e-17*(1.0 - cos(theta)**2)**5*(2.9025206025582e+32*cos(theta)**45 - 2.63623430874552e+33*cos(theta)**43 + 1.11239232747533e+34*cos(theta)**41 - 2.89575145565007e+34*cos(theta)**39 + 5.20813550639976e+34*cos(theta)**37 - 6.8685509846777e+34*cos(theta)**35 + 6.88011420182362e+34*cos(theta)**33 - 5.35007407741218e+34*cos(theta)**31 + 3.27340058683772e+34*cos(theta)**29 - 1.58781438262379e+34*cos(theta)**27 + 6.12442690440605e+33*cos(theta)**25 - 1.87673960298449e+33*cos(theta)**23 + 4.54803754363099e+32*cos(theta)**21 - 8.64332926843899e+31*cos(theta)**19 + 1.27195293020918e+31*cos(theta)**17 - 1.42374978196254e+30*cos(theta)**15 + 1.18270353723154e+29*cos(theta)**13 - 7.04743131429031e+27*cos(theta)**11 + 2.87117572063679e+26*cos(theta)**9 - 7.45222249047762e+24*cos(theta)**7 + 1.10208924154951e+23*cos(theta)**5 - 7.60586088025884e+20*cos(theta)**3 + 1.54800424971347e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl55_m11(theta, phi):
    return 2.93720415655174e-19*(1.0 - cos(theta)**2)**5.5*(1.30613427115119e+34*cos(theta)**44 - 1.13358075276057e+35*cos(theta)**42 + 4.56080854264886e+35*cos(theta)**40 - 1.12934306770353e+36*cos(theta)**38 + 1.92701013736791e+36*cos(theta)**36 - 2.40399284463719e+36*cos(theta)**34 + 2.27043768660179e+36*cos(theta)**32 - 1.65852296399778e+36*cos(theta)**30 + 9.49286170182938e+35*cos(theta)**28 - 4.28709883308424e+35*cos(theta)**26 + 1.53110672610151e+35*cos(theta)**24 - 4.31650108686433e+34*cos(theta)**22 + 9.55087884162509e+33*cos(theta)**20 - 1.64223256100341e+33*cos(theta)**18 + 2.16231998135561e+32*cos(theta)**16 - 2.13562467294381e+31*cos(theta)**14 + 1.537514598401e+30*cos(theta)**12 - 7.75217444571934e+28*cos(theta)**10 + 2.58405814857311e+27*cos(theta)**8 - 5.21655574333433e+25*cos(theta)**6 + 5.51044620774753e+23*cos(theta)**4 - 2.28175826407765e+21*cos(theta)**2 + 1.54800424971347e+18)*cos(11*phi)

#@torch.jit.script
def Yl55_m12(theta, phi):
    return 5.40966528397239e-21*(1.0 - cos(theta)**2)**6*(5.74699079306524e+35*cos(theta)**43 - 4.76103916159442e+36*cos(theta)**41 + 1.82432341705954e+37*cos(theta)**39 - 4.2915036572734e+37*cos(theta)**37 + 6.93723649452448e+37*cos(theta)**35 - 8.17357567176646e+37*cos(theta)**33 + 7.26540059712574e+37*cos(theta)**31 - 4.97556889199333e+37*cos(theta)**29 + 2.65800127651223e+37*cos(theta)**27 - 1.1146456966019e+37*cos(theta)**25 + 3.67465614264363e+36*cos(theta)**23 - 9.49630239110152e+35*cos(theta)**21 + 1.91017576832502e+35*cos(theta)**19 - 2.95601860980614e+34*cos(theta)**17 + 3.45971197016897e+33*cos(theta)**15 - 2.98987454212133e+32*cos(theta)**13 + 1.8450175180812e+31*cos(theta)**11 - 7.75217444571934e+29*cos(theta)**9 + 2.06724651885849e+28*cos(theta)**7 - 3.1299334460006e+26*cos(theta)**5 + 2.20417848309901e+24*cos(theta)**3 - 4.56351652815531e+21*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl55_m13(theta, phi):
    return 1.00041849117088e-22*(1.0 - cos(theta)**2)**6.5*(2.47120604101805e+37*cos(theta)**42 - 1.95202605625371e+38*cos(theta)**40 + 7.11486132653221e+38*cos(theta)**38 - 1.58785635319116e+39*cos(theta)**36 + 2.42803277308357e+39*cos(theta)**34 - 2.69727997168293e+39*cos(theta)**32 + 2.25227418510898e+39*cos(theta)**30 - 1.44291497867807e+39*cos(theta)**28 + 7.17660344658301e+38*cos(theta)**26 - 2.78661424150475e+38*cos(theta)**24 + 8.45170912808035e+37*cos(theta)**22 - 1.99422350213132e+37*cos(theta)**20 + 3.62933395981753e+36*cos(theta)**18 - 5.02523163667043e+35*cos(theta)**16 + 5.18956795525346e+34*cos(theta)**14 - 3.88683690475773e+33*cos(theta)**12 + 2.02951926988932e+32*cos(theta)**10 - 6.9769570011474e+30*cos(theta)**8 + 1.44707256320094e+29*cos(theta)**6 - 1.5649667230003e+27*cos(theta)**4 + 6.61253544929704e+24*cos(theta)**2 - 4.56351652815531e+21)*cos(13*phi)

#@torch.jit.script
def Yl55_m14(theta, phi):
    return 1.85837142862346e-24*(1.0 - cos(theta)**2)**7*(1.03790653722758e+39*cos(theta)**41 - 7.80810422501484e+39*cos(theta)**39 + 2.70364730408224e+40*cos(theta)**37 - 5.71628287148817e+40*cos(theta)**35 + 8.25531142848413e+40*cos(theta)**33 - 8.63129590938538e+40*cos(theta)**31 + 6.75682255532694e+40*cos(theta)**29 - 4.04016194029858e+40*cos(theta)**27 + 1.86591689611158e+40*cos(theta)**25 - 6.68787417961141e+39*cos(theta)**23 + 1.85937600817768e+39*cos(theta)**21 - 3.98844700426264e+38*cos(theta)**19 + 6.53280112767156e+37*cos(theta)**17 - 8.04037061867269e+36*cos(theta)**15 + 7.26539513735484e+35*cos(theta)**13 - 4.66420428570928e+34*cos(theta)**11 + 2.02951926988932e+33*cos(theta)**9 - 5.58156560091792e+31*cos(theta)**7 + 8.68243537920566e+29*cos(theta)**5 - 6.2598668920012e+27*cos(theta)**3 + 1.32250708985941e+25*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl55_m15(theta, phi):
    return 3.46889833134161e-26*(1.0 - cos(theta)**2)**7.5*(4.25541680263309e+40*cos(theta)**40 - 3.04516064775579e+41*cos(theta)**38 + 1.00034950251043e+42*cos(theta)**36 - 2.00069900502086e+42*cos(theta)**34 + 2.72425277139976e+42*cos(theta)**32 - 2.67570173190947e+42*cos(theta)**30 + 1.95947854104481e+42*cos(theta)**28 - 1.09084372388062e+42*cos(theta)**26 + 4.66479224027896e+41*cos(theta)**24 - 1.53821106131062e+41*cos(theta)**22 + 3.90468961717312e+40*cos(theta)**20 - 7.57804930809901e+39*cos(theta)**18 + 1.11057619170417e+39*cos(theta)**16 - 1.2060555928009e+38*cos(theta)**14 + 9.44501367856129e+36*cos(theta)**12 - 5.13062471428021e+35*cos(theta)**10 + 1.82656734290039e+34*cos(theta)**8 - 3.90709592064255e+32*cos(theta)**6 + 4.34121768960283e+30*cos(theta)**4 - 1.87796006760036e+28*cos(theta)**2 + 1.32250708985941e+25)*cos(15*phi)

#@torch.jit.script
def Yl55_m16(theta, phi):
    return 6.50927172782842e-28*(1.0 - cos(theta)**2)**8*(1.70216672105324e+42*cos(theta)**39 - 1.1571610461472e+43*cos(theta)**37 + 3.60125820903755e+43*cos(theta)**35 - 6.80237661707092e+43*cos(theta)**33 + 8.71760886847924e+43*cos(theta)**31 - 8.02710519572841e+43*cos(theta)**29 + 5.48653991492548e+43*cos(theta)**27 - 2.83619368208961e+43*cos(theta)**25 + 1.11955013766695e+43*cos(theta)**23 - 3.38406433488337e+42*cos(theta)**21 + 7.80937923434624e+41*cos(theta)**19 - 1.36404887545782e+41*cos(theta)**17 + 1.77692190672666e+40*cos(theta)**15 - 1.68847782992126e+39*cos(theta)**13 + 1.13340164142736e+38*cos(theta)**11 - 5.13062471428021e+36*cos(theta)**9 + 1.46125387432031e+35*cos(theta)**7 - 2.34425755238553e+33*cos(theta)**5 + 1.73648707584113e+31*cos(theta)**3 - 3.75592013520072e+28*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl55_m17(theta, phi):
    return 1.22838314773781e-29*(1.0 - cos(theta)**2)**8.5*(6.63845021210762e+43*cos(theta)**38 - 4.28149587074464e+44*cos(theta)**36 + 1.26044037316314e+45*cos(theta)**34 - 2.2447842836334e+45*cos(theta)**32 + 2.70245874922856e+45*cos(theta)**30 - 2.32786050676124e+45*cos(theta)**28 + 1.48136577702988e+45*cos(theta)**26 - 7.09048420522401e+44*cos(theta)**24 + 2.57496531663398e+44*cos(theta)**22 - 7.10653510325508e+43*cos(theta)**20 + 1.48378205452579e+43*cos(theta)**18 - 2.3188830882783e+42*cos(theta)**16 + 2.66538286009e+41*cos(theta)**14 - 2.19502117889764e+40*cos(theta)**12 + 1.24674180557009e+39*cos(theta)**10 - 4.61756224285219e+37*cos(theta)**8 + 1.02287771202422e+36*cos(theta)**6 - 1.17212877619276e+34*cos(theta)**4 + 5.2094612275234e+31*cos(theta)**2 - 3.75592013520072e+28)*cos(17*phi)

#@torch.jit.script
def Yl55_m18(theta, phi):
    return 2.33227964147739e-31*(1.0 - cos(theta)**2)**9*(2.52261108060089e+45*cos(theta)**37 - 1.54133851346807e+46*cos(theta)**35 + 4.28549726875468e+46*cos(theta)**33 - 7.18330970762689e+46*cos(theta)**31 + 8.10737624768569e+46*cos(theta)**29 - 6.51800941893147e+46*cos(theta)**27 + 3.85155102027768e+46*cos(theta)**25 - 1.70171620925376e+46*cos(theta)**23 + 5.66492369659476e+45*cos(theta)**21 - 1.42130702065102e+45*cos(theta)**19 + 2.67080769814642e+44*cos(theta)**17 - 3.71021294124528e+43*cos(theta)**15 + 3.731536004126e+42*cos(theta)**13 - 2.63402541467717e+41*cos(theta)**11 + 1.24674180557009e+40*cos(theta)**9 - 3.69404979428175e+38*cos(theta)**7 + 6.13726627214531e+36*cos(theta)**5 - 4.68851510477106e+34*cos(theta)**3 + 1.04189224550468e+32*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl55_m19(theta, phi):
    return 4.45721824354592e-33*(1.0 - cos(theta)**2)**9.5*(9.33366099822331e+46*cos(theta)**36 - 5.39468479713824e+47*cos(theta)**34 + 1.41421409868904e+48*cos(theta)**32 - 2.22682600936434e+48*cos(theta)**30 + 2.35113911182885e+48*cos(theta)**28 - 1.7598625431115e+48*cos(theta)**26 + 9.62887755069421e+47*cos(theta)**24 - 3.91394728128366e+47*cos(theta)**22 + 1.1896339762849e+47*cos(theta)**20 - 2.70048333923693e+46*cos(theta)**18 + 4.54037308684891e+45*cos(theta)**16 - 5.56531941186791e+44*cos(theta)**14 + 4.85099680536379e+43*cos(theta)**12 - 2.89742795614489e+42*cos(theta)**10 + 1.12206762501308e+41*cos(theta)**8 - 2.58583485599723e+39*cos(theta)**6 + 3.06863313607266e+37*cos(theta)**4 - 1.40655453143132e+35*cos(theta)**2 + 1.04189224550468e+32)*cos(19*phi)

#@torch.jit.script
def Yl55_m20(theta, phi):
    return 8.57792050916049e-35*(1.0 - cos(theta)**2)**10*(3.36011795936039e+48*cos(theta)**35 - 1.834192831027e+49*cos(theta)**33 + 4.52548511580494e+49*cos(theta)**31 - 6.68047802809301e+49*cos(theta)**29 + 6.58318951312078e+49*cos(theta)**27 - 4.57564261208989e+49*cos(theta)**25 + 2.31093061216661e+49*cos(theta)**23 - 8.61068401882404e+48*cos(theta)**21 + 2.3792679525698e+48*cos(theta)**19 - 4.86087001062648e+47*cos(theta)**17 + 7.26459693895825e+46*cos(theta)**15 - 7.79144717661508e+45*cos(theta)**13 + 5.82119616643655e+44*cos(theta)**11 - 2.89742795614489e+43*cos(theta)**9 + 8.97654100010465e+41*cos(theta)**7 - 1.55150091359833e+40*cos(theta)**5 + 1.22745325442906e+38*cos(theta)**3 - 2.81310906286263e+35*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl55_m21(theta, phi):
    return 1.66318744915687e-36*(1.0 - cos(theta)**2)**10.5*(1.17604128577614e+50*cos(theta)**34 - 6.05283634238911e+50*cos(theta)**32 + 1.40290038589953e+51*cos(theta)**30 - 1.93733862814697e+51*cos(theta)**28 + 1.77746116854261e+51*cos(theta)**26 - 1.14391065302247e+51*cos(theta)**24 + 5.3151404079832e+50*cos(theta)**22 - 1.80824364395305e+50*cos(theta)**20 + 4.52060910988262e+49*cos(theta)**18 - 8.26347901806501e+48*cos(theta)**16 + 1.08968954084374e+48*cos(theta)**14 - 1.01288813295996e+47*cos(theta)**12 + 6.40331578308021e+45*cos(theta)**10 - 2.6076851605304e+44*cos(theta)**8 + 6.28357870007326e+42*cos(theta)**6 - 7.75750456799167e+40*cos(theta)**4 + 3.68235976328719e+38*cos(theta)**2 - 2.81310906286263e+35)*cos(21*phi)

#@torch.jit.script
def Yl55_m22(theta, phi):
    return 3.25054646110025e-38*(1.0 - cos(theta)**2)**11*(3.99854037163887e+51*cos(theta)**33 - 1.93690762956452e+52*cos(theta)**31 + 4.2087011576986e+52*cos(theta)**29 - 5.42454815881152e+52*cos(theta)**27 + 4.62139903821079e+52*cos(theta)**25 - 2.74538556725393e+52*cos(theta)**23 + 1.16933088975631e+52*cos(theta)**21 - 3.6164872879061e+51*cos(theta)**19 + 8.13709639778872e+50*cos(theta)**17 - 1.3221566428904e+50*cos(theta)**15 + 1.52556535718123e+49*cos(theta)**13 - 1.21546575955195e+48*cos(theta)**11 + 6.40331578308021e+46*cos(theta)**9 - 2.08614812842432e+45*cos(theta)**7 + 3.77014722004395e+43*cos(theta)**5 - 3.10300182719667e+41*cos(theta)**3 + 7.36471952657437e+38*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl55_m23(theta, phi):
    return 6.40696138729007e-40*(1.0 - cos(theta)**2)**11.5*(1.31951832264083e+53*cos(theta)**32 - 6.00441365165e+53*cos(theta)**30 + 1.22052333573259e+54*cos(theta)**28 - 1.46462800287911e+54*cos(theta)**26 + 1.1553497595527e+54*cos(theta)**24 - 6.31438680468405e+53*cos(theta)**22 + 2.45559486848824e+53*cos(theta)**20 - 6.87132584702159e+52*cos(theta)**18 + 1.38330638762408e+52*cos(theta)**16 - 1.9832349643356e+51*cos(theta)**14 + 1.9832349643356e+50*cos(theta)**12 - 1.33701233550715e+49*cos(theta)**10 + 5.76298420477219e+47*cos(theta)**8 - 1.46030368989702e+46*cos(theta)**6 + 1.88507361002198e+44*cos(theta)**4 - 9.30900548159001e+41*cos(theta)**2 + 7.36471952657437e+38)*cos(23*phi)

#@torch.jit.script
def Yl55_m24(theta, phi):
    return 1.27427620027281e-41*(1.0 - cos(theta)**2)**12*(4.22245863245064e+54*cos(theta)**31 - 1.801324095495e+55*cos(theta)**29 + 3.41746534005126e+55*cos(theta)**27 - 3.80803280748569e+55*cos(theta)**25 + 2.77283942292647e+55*cos(theta)**23 - 1.38916509703049e+55*cos(theta)**21 + 4.91118973697648e+54*cos(theta)**19 - 1.23683865246389e+54*cos(theta)**17 + 2.21329022019853e+53*cos(theta)**15 - 2.77652895006984e+52*cos(theta)**13 + 2.37988195720272e+51*cos(theta)**11 - 1.33701233550715e+50*cos(theta)**9 + 4.61038736381775e+48*cos(theta)**7 - 8.76182213938215e+46*cos(theta)**5 + 7.54029444008791e+44*cos(theta)**3 - 1.861801096318e+42*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl55_m25(theta, phi):
    return 2.55880818604889e-43*(1.0 - cos(theta)**2)**12.5*(1.3089621760597e+56*cos(theta)**30 - 5.2238398769355e+56*cos(theta)**28 + 9.2271564181384e+56*cos(theta)**26 - 9.52008201871422e+56*cos(theta)**24 + 6.37753067273089e+56*cos(theta)**22 - 2.91724670376403e+56*cos(theta)**20 + 9.33126050025531e+55*cos(theta)**18 - 2.10262570918861e+55*cos(theta)**16 + 3.3199353302978e+54*cos(theta)**14 - 3.6094876350908e+53*cos(theta)**12 + 2.61787015292299e+52*cos(theta)**10 - 1.20331110195643e+51*cos(theta)**8 + 3.22727115467243e+49*cos(theta)**6 - 4.38091106969107e+47*cos(theta)**4 + 2.26208833202637e+45*cos(theta)**2 - 1.861801096318e+42)*cos(25*phi)

#@torch.jit.script
def Yl55_m26(theta, phi):
    return 5.19080356973279e-45*(1.0 - cos(theta)**2)**13*(3.9268865281791e+57*cos(theta)**29 - 1.46267516554194e+58*cos(theta)**27 + 2.39906066871598e+58*cos(theta)**25 - 2.28481968449141e+58*cos(theta)**23 + 1.4030567480008e+58*cos(theta)**21 - 5.83449340752806e+57*cos(theta)**19 + 1.67962689004596e+57*cos(theta)**17 - 3.36420113470177e+56*cos(theta)**15 + 4.64790946241692e+55*cos(theta)**13 - 4.33138516210895e+54*cos(theta)**11 + 2.61787015292299e+53*cos(theta)**9 - 9.62648881565146e+51*cos(theta)**7 + 1.93636269280345e+50*cos(theta)**5 - 1.75236442787643e+48*cos(theta)**3 + 4.52417666405274e+45*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl55_m27(theta, phi):
    return 1.06445834118375e-46*(1.0 - cos(theta)**2)**13.5*(1.13879709317194e+59*cos(theta)**28 - 3.94922294696324e+59*cos(theta)**26 + 5.99765167178996e+59*cos(theta)**24 - 5.25508527433025e+59*cos(theta)**22 + 2.94641917080167e+59*cos(theta)**20 - 1.10855374743033e+59*cos(theta)**18 + 2.85536571307813e+58*cos(theta)**16 - 5.04630170205265e+57*cos(theta)**14 + 6.04228230114199e+56*cos(theta)**12 - 4.76452367831985e+55*cos(theta)**10 + 2.3560831376307e+54*cos(theta)**8 - 6.73854217095602e+52*cos(theta)**6 + 9.68181346401727e+50*cos(theta)**4 - 5.25709328362929e+48*cos(theta)**2 + 4.52417666405274e+45)*cos(27*phi)

#@torch.jit.script
def Yl55_m28(theta, phi):
    return 2.20805866411675e-48*(1.0 - cos(theta)**2)**14*(3.18863186088143e+60*cos(theta)**27 - 1.02679796621044e+61*cos(theta)**25 + 1.43943640122959e+61*cos(theta)**23 - 1.15611876035266e+61*cos(theta)**21 + 5.89283834160334e+60*cos(theta)**19 - 1.9953967453746e+60*cos(theta)**17 + 4.568585140925e+59*cos(theta)**15 - 7.06482238287371e+58*cos(theta)**13 + 7.25073876137039e+57*cos(theta)**11 - 4.76452367831985e+56*cos(theta)**9 + 1.88486651010456e+55*cos(theta)**7 - 4.04312530257361e+53*cos(theta)**5 + 3.87272538560691e+51*cos(theta)**3 - 1.05141865672586e+49*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl55_m29(theta, phi):
    return 4.63648738531302e-50*(1.0 - cos(theta)**2)**14.5*(8.60930602437985e+61*cos(theta)**26 - 2.5669949155261e+62*cos(theta)**24 + 3.31070372282806e+62*cos(theta)**22 - 2.42784939674058e+62*cos(theta)**20 + 1.11963928490463e+62*cos(theta)**18 - 3.39217446713681e+61*cos(theta)**16 + 6.8528777113875e+60*cos(theta)**14 - 9.18426909773583e+59*cos(theta)**12 + 7.97581263750743e+58*cos(theta)**10 - 4.28807131048787e+57*cos(theta)**8 + 1.31940655707319e+56*cos(theta)**6 - 2.02156265128681e+54*cos(theta)**4 + 1.16181761568207e+52*cos(theta)**2 - 1.05141865672586e+49)*cos(29*phi)

#@torch.jit.script
def Yl55_m30(theta, phi):
    return 9.862634654419e-52*(1.0 - cos(theta)**2)**15*(2.23841956633876e+63*cos(theta)**25 - 6.16078779726265e+63*cos(theta)**23 + 7.28354819022173e+63*cos(theta)**21 - 4.85569879348115e+63*cos(theta)**19 + 2.01535071282834e+63*cos(theta)**17 - 5.4274791474189e+62*cos(theta)**15 + 9.5940287959425e+61*cos(theta)**13 - 1.1021122917283e+61*cos(theta)**11 + 7.97581263750743e+59*cos(theta)**9 - 3.43045704839029e+58*cos(theta)**7 + 7.91643934243914e+56*cos(theta)**5 - 8.08625060514723e+54*cos(theta)**3 + 2.32363523136415e+52*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl55_m31(theta, phi):
    return 2.12703049175667e-53*(1.0 - cos(theta)**2)**15.5*(5.5960489158469e+64*cos(theta)**24 - 1.41698119337041e+65*cos(theta)**22 + 1.52954511994656e+65*cos(theta)**20 - 9.22582770761419e+64*cos(theta)**18 + 3.42609621180818e+64*cos(theta)**16 - 8.14121872112835e+63*cos(theta)**14 + 1.24722374347253e+63*cos(theta)**12 - 1.21232352090113e+62*cos(theta)**10 + 7.17823137375669e+60*cos(theta)**8 - 2.4013199338732e+59*cos(theta)**6 + 3.95821967121957e+57*cos(theta)**4 - 2.42587518154417e+55*cos(theta)**2 + 2.32363523136415e+52)*cos(31*phi)

#@torch.jit.script
def Yl55_m32(theta, phi):
    return 4.65487977427384e-55*(1.0 - cos(theta)**2)**16*(1.34305173980326e+66*cos(theta)**23 - 3.1173586254149e+66*cos(theta)**21 + 3.05909023989313e+66*cos(theta)**19 - 1.66064898737055e+66*cos(theta)**17 + 5.48175393889309e+65*cos(theta)**15 - 1.13977062095797e+65*cos(theta)**13 + 1.49666849216703e+64*cos(theta)**11 - 1.21232352090113e+63*cos(theta)**9 + 5.74258509900535e+61*cos(theta)**7 - 1.44079196032392e+60*cos(theta)**5 + 1.58328786848783e+58*cos(theta)**3 - 4.85175036308834e+55*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl55_m33(theta, phi):
    return 1.03467323403691e-56*(1.0 - cos(theta)**2)**16.5*(3.08901900154749e+67*cos(theta)**22 - 6.54645311337129e+67*cos(theta)**20 + 5.81227145579694e+67*cos(theta)**18 - 2.82310327852994e+67*cos(theta)**16 + 8.22263090833964e+66*cos(theta)**14 - 1.48170180724536e+66*cos(theta)**12 + 1.64633534138373e+65*cos(theta)**10 - 1.09109116881102e+64*cos(theta)**8 + 4.01980956930374e+62*cos(theta)**6 - 7.20395980161961e+60*cos(theta)**4 + 4.74986360546348e+58*cos(theta)**2 - 4.85175036308834e+55)*cos(33*phi)

#@torch.jit.script
def Yl55_m34(theta, phi):
    return 2.33828191516168e-58*(1.0 - cos(theta)**2)**17*(6.79584180340448e+68*cos(theta)**21 - 1.30929062267426e+69*cos(theta)**19 + 1.04620886204345e+69*cos(theta)**17 - 4.51696524564791e+68*cos(theta)**15 + 1.15116832716755e+68*cos(theta)**13 - 1.77804216869443e+67*cos(theta)**11 + 1.64633534138373e+66*cos(theta)**9 - 8.72872935048813e+64*cos(theta)**7 + 2.41188574158225e+63*cos(theta)**5 - 2.88158392064785e+61*cos(theta)**3 + 9.49972721092696e+58*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl55_m35(theta, phi):
    return 5.37855939228719e-60*(1.0 - cos(theta)**2)**17.5*(1.42712677871494e+70*cos(theta)**20 - 2.48765218308109e+70*cos(theta)**18 + 1.77855506547386e+70*cos(theta)**16 - 6.77544786847186e+69*cos(theta)**14 + 1.49651882531781e+69*cos(theta)**12 - 1.95584638556388e+68*cos(theta)**10 + 1.48170180724536e+67*cos(theta)**8 - 6.11011054534169e+65*cos(theta)**6 + 1.20594287079112e+64*cos(theta)**4 - 8.64475176194354e+61*cos(theta)**2 + 9.49972721092696e+58)*cos(35*phi)

#@torch.jit.script
def Yl55_m36(theta, phi):
    return 1.2607537675682e-61*(1.0 - cos(theta)**2)**18*(2.85425355742988e+71*cos(theta)**19 - 4.47777392954596e+71*cos(theta)**17 + 2.84568810475818e+71*cos(theta)**15 - 9.4856270158606e+70*cos(theta)**13 + 1.79582259038138e+70*cos(theta)**11 - 1.95584638556388e+69*cos(theta)**9 + 1.18536144579629e+68*cos(theta)**7 - 3.66606632720501e+66*cos(theta)**5 + 4.82377148316449e+64*cos(theta)**3 - 1.72895035238871e+62*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl55_m37(theta, phi):
    return 3.01550158101617e-63*(1.0 - cos(theta)**2)**18.5*(5.42308175911678e+72*cos(theta)**18 - 7.61221568022814e+72*cos(theta)**16 + 4.26853215713727e+72*cos(theta)**14 - 1.23313151206188e+72*cos(theta)**12 + 1.97540484941951e+71*cos(theta)**10 - 1.76026174700749e+70*cos(theta)**8 + 8.29753012057402e+68*cos(theta)**6 - 1.83303316360251e+67*cos(theta)**4 + 1.44713144494935e+65*cos(theta)**2 - 1.72895035238871e+62)*cos(37*phi)

#@torch.jit.script
def Yl55_m38(theta, phi):
    return 7.37024345330584e-65*(1.0 - cos(theta)**2)**19*(9.7615471664102e+73*cos(theta)**17 - 1.2179545088365e+74*cos(theta)**15 + 5.97594501999218e+73*cos(theta)**13 - 1.47975781447425e+73*cos(theta)**11 + 1.97540484941951e+72*cos(theta)**9 - 1.40820939760599e+71*cos(theta)**7 + 4.97851807234441e+69*cos(theta)**5 - 7.33213265441003e+67*cos(theta)**3 + 2.8942628898987e+65*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl55_m39(theta, phi):
    return 1.84371354461739e-66*(1.0 - cos(theta)**2)**19.5*(1.65946301828973e+75*cos(theta)**16 - 1.82693176325475e+75*cos(theta)**14 + 7.76872852598984e+74*cos(theta)**12 - 1.62773359592168e+74*cos(theta)**10 + 1.77786436447756e+73*cos(theta)**8 - 9.85746578324193e+71*cos(theta)**6 + 2.48925903617221e+70*cos(theta)**4 - 2.19963979632301e+68*cos(theta)**2 + 2.8942628898987e+65)*cos(39*phi)

#@torch.jit.script
def Yl55_m40(theta, phi):
    return 4.72902546055906e-68*(1.0 - cos(theta)**2)**20*(2.65514082926357e+76*cos(theta)**15 - 2.55770446855665e+76*cos(theta)**13 + 9.3224742311878e+75*cos(theta)**11 - 1.62773359592168e+75*cos(theta)**9 + 1.42229149158205e+74*cos(theta)**7 - 5.91447946994516e+72*cos(theta)**5 + 9.95703614468882e+70*cos(theta)**3 - 4.39927959264602e+68*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl55_m41(theta, phi):
    return 1.24620763069112e-69*(1.0 - cos(theta)**2)**20.5*(3.98271124389536e+77*cos(theta)**14 - 3.32501580912365e+77*cos(theta)**12 + 1.02547216543066e+77*cos(theta)**10 - 1.46496023632951e+76*cos(theta)**8 + 9.95604044107435e+74*cos(theta)**6 - 2.95723973497258e+73*cos(theta)**4 + 2.98711084340665e+71*cos(theta)**2 - 4.39927959264602e+68)*cos(41*phi)

#@torch.jit.script
def Yl55_m42(theta, phi):
    return 3.38174238842709e-71*(1.0 - cos(theta)**2)**21*(5.5757957414535e+78*cos(theta)**13 - 3.99001897094838e+78*cos(theta)**11 + 1.02547216543066e+78*cos(theta)**9 - 1.17196818906361e+77*cos(theta)**7 + 5.97362426464461e+75*cos(theta)**5 - 1.18289589398903e+74*cos(theta)**3 + 5.97422168681329e+71*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl55_m43(theta, phi):
    return 9.47448924644705e-73*(1.0 - cos(theta)**2)**21.5*(7.24853446388956e+79*cos(theta)**12 - 4.38902086804322e+79*cos(theta)**10 + 9.22924948887592e+78*cos(theta)**8 - 8.20377732344527e+77*cos(theta)**6 + 2.98681213232231e+76*cos(theta)**4 - 3.5486876819671e+74*cos(theta)**2 + 5.97422168681329e+71)*cos(43*phi)

#@torch.jit.script
def Yl55_m44(theta, phi):
    return 2.74882813233161e-74*(1.0 - cos(theta)**2)**22*(8.69824135666747e+80*cos(theta)**11 - 4.38902086804322e+80*cos(theta)**9 + 7.38339959110074e+79*cos(theta)**7 - 4.92226639406716e+78*cos(theta)**5 + 1.19472485292892e+77*cos(theta)**3 - 7.09737536393419e+74*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl55_m45(theta, phi):
    return 8.28802866192487e-76*(1.0 - cos(theta)**2)**22.5*(9.56806549233421e+81*cos(theta)**10 - 3.9501187812389e+81*cos(theta)**8 + 5.16837971377052e+80*cos(theta)**6 - 2.46113319703358e+79*cos(theta)**4 + 3.58417455878677e+77*cos(theta)**2 - 7.09737536393419e+74)*cos(45*phi)

#@torch.jit.script
def Yl55_m46(theta, phi):
    return 2.60789773650125e-77*(1.0 - cos(theta)**2)**23*(9.56806549233421e+82*cos(theta)**9 - 3.16009502499112e+82*cos(theta)**7 + 3.10102782826231e+81*cos(theta)**5 - 9.84453278813432e+79*cos(theta)**3 + 7.16834911757353e+77*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl55_m47(theta, phi):
    return 8.60734512043714e-79*(1.0 - cos(theta)**2)**23.5*(8.61125894310079e+83*cos(theta)**8 - 2.21206651749378e+83*cos(theta)**6 + 1.55051391413116e+82*cos(theta)**4 - 2.9533598364403e+80*cos(theta)**2 + 7.16834911757353e+77)*cos(47*phi)

#@torch.jit.script
def Yl55_m48(theta, phi):
    return 2.99851075540521e-80*(1.0 - cos(theta)**2)**24*(6.88900715448063e+84*cos(theta)**7 - 1.32723991049627e+84*cos(theta)**5 + 6.20205565652462e+82*cos(theta)**3 - 5.90671967288059e+80*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl55_m49(theta, phi):
    return 1.11132202422254e-81*(1.0 - cos(theta)**2)**24.5*(4.82230500813644e+85*cos(theta)**6 - 6.63619955248134e+84*cos(theta)**4 + 1.86061669695739e+83*cos(theta)**2 - 5.90671967288059e+80)*cos(49*phi)

#@torch.jit.script
def Yl55_m50(theta, phi):
    return 4.42761292511395e-83*(1.0 - cos(theta)**2)**25*(2.89338300488187e+86*cos(theta)**5 - 2.65447982099254e+85*cos(theta)**3 + 3.72123339391477e+83*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl55_m51(theta, phi):
    return 1.9232321563685e-84*(1.0 - cos(theta)**2)**25.5*(1.44669150244093e+87*cos(theta)**4 - 7.96343946297761e+85*cos(theta)**2 + 3.72123339391477e+83)*cos(51*phi)

#@torch.jit.script
def Yl55_m52(theta, phi):
    return 9.29629351233703e-86*(1.0 - cos(theta)**2)**26*(5.78676600976373e+87*cos(theta)**3 - 1.59268789259552e+86*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl55_m53(theta, phi):
    return 5.1646075068539e-87*(1.0 - cos(theta)**2)**26.5*(1.73602980292912e+88*cos(theta)**2 - 1.59268789259552e+86)*cos(53*phi)

#@torch.jit.script
def Yl55_m54(theta, phi):
    return 12.1449644411629*(1.0 - cos(theta)**2)**27*cos(54*phi)*cos(theta)

#@torch.jit.script
def Yl55_m55(theta, phi):
    return 1.15797692423668*(1.0 - cos(theta)**2)**27.5*cos(55*phi)

#@torch.jit.script
def Yl56_m_minus_56(theta, phi):
    return 1.16313497615398*(1.0 - cos(theta)**2)**28*sin(56*phi)

#@torch.jit.script
def Yl56_m_minus_55(theta, phi):
    return 12.3094635524179*(1.0 - cos(theta)**2)**27.5*sin(55*phi)*cos(theta)

#@torch.jit.script
def Yl56_m_minus_54(theta, phi):
    return 4.75888777122505e-89*(1.0 - cos(theta)**2)**27*(1.92699308125132e+90*cos(theta)**2 - 1.73602980292912e+88)*sin(54*phi)

#@torch.jit.script
def Yl56_m_minus_53(theta, phi):
    return 8.64494894739585e-88*(1.0 - cos(theta)**2)**26.5*(6.42331027083774e+89*cos(theta)**3 - 1.73602980292912e+88*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl56_m_minus_52(theta, phi):
    return 1.80511833529393e-86*(1.0 - cos(theta)**2)**26*(1.60582756770944e+89*cos(theta)**4 - 8.6801490146456e+87*cos(theta)**2 + 3.98171973148881e+85)*sin(52*phi)

#@torch.jit.script
def Yl56_m_minus_51(theta, phi):
    return 4.19471595031622e-85*(1.0 - cos(theta)**2)**25.5*(3.21165513541887e+88*cos(theta)**5 - 2.89338300488187e+87*cos(theta)**3 + 3.98171973148881e+85*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl56_m_minus_50(theta, phi):
    return 1.06284533692648e-83*(1.0 - cos(theta)**2)**25*(5.35275855903145e+87*cos(theta)**6 - 7.23345751220467e+86*cos(theta)**4 + 1.9908598657444e+85*cos(theta)**2 - 6.20205565652462e+82)*sin(50*phi)

#@torch.jit.script
def Yl56_m_minus_49(theta, phi):
    return 2.8951563619051e-82*(1.0 - cos(theta)**2)**24.5*(7.6467979414735e+86*cos(theta)**7 - 1.44669150244093e+86*cos(theta)**5 + 6.63619955248134e+84*cos(theta)**3 - 6.20205565652462e+82*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl56_m_minus_48(theta, phi):
    return 8.39096031589878e-81*(1.0 - cos(theta)**2)**24*(9.55849742684188e+85*cos(theta)**8 - 2.41115250406822e+85*cos(theta)**6 + 1.65904988812034e+84*cos(theta)**4 - 3.10102782826231e+82*cos(theta)**2 + 7.38339959110074e+79)*sin(48*phi)

#@torch.jit.script
def Yl56_m_minus_47(theta, phi):
    return 2.56714022331303e-79*(1.0 - cos(theta)**2)**23.5*(1.0620552696491e+85*cos(theta)**9 - 3.44450357724032e+84*cos(theta)**7 + 3.31809977624067e+83*cos(theta)**5 - 1.0336759427541e+82*cos(theta)**3 + 7.38339959110074e+79*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl56_m_minus_46(theta, phi):
    return 8.23888050279663e-78*(1.0 - cos(theta)**2)**23*(1.0620552696491e+84*cos(theta)**10 - 4.3056294715504e+83*cos(theta)**8 + 5.53016629373445e+82*cos(theta)**6 - 2.58418985688526e+81*cos(theta)**4 + 3.69169979555037e+79*cos(theta)**2 - 7.16834911757353e+76)*sin(46*phi)

#@torch.jit.script
def Yl56_m_minus_45(theta, phi):
    return 2.75971753039989e-76*(1.0 - cos(theta)**2)**22.5*(9.65504790590089e+82*cos(theta)**11 - 4.78403274616711e+82*cos(theta)**9 + 7.90023756247779e+81*cos(theta)**7 - 5.16837971377052e+80*cos(theta)**5 + 1.23056659851679e+79*cos(theta)**3 - 7.16834911757353e+76*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl56_m_minus_44(theta, phi):
    return 9.60762275866768e-75*(1.0 - cos(theta)**2)**22*(8.04587325491741e+81*cos(theta)**12 - 4.78403274616711e+81*cos(theta)**10 + 9.87529695309724e+80*cos(theta)**8 - 8.61396618961753e+79*cos(theta)**6 + 3.07641649629197e+78*cos(theta)**4 - 3.58417455878677e+76*cos(theta)**2 + 5.91447946994516e+73)*sin(44*phi)

#@torch.jit.script
def Yl56_m_minus_43(theta, phi):
    return 3.46407764916911e-73*(1.0 - cos(theta)**2)**21.5*(6.18913327301339e+80*cos(theta)**13 - 4.34912067833373e+80*cos(theta)**11 + 1.0972552170108e+80*cos(theta)**9 - 1.23056659851679e+79*cos(theta)**7 + 6.15283299258395e+77*cos(theta)**5 - 1.19472485292892e+76*cos(theta)**3 + 5.91447946994516e+73*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl56_m_minus_42(theta, phi):
    return 1.2896421933168e-71*(1.0 - cos(theta)**2)**21*(4.42080948072385e+79*cos(theta)**14 - 3.62426723194478e+79*cos(theta)**12 + 1.0972552170108e+79*cos(theta)**10 - 1.53820824814599e+78*cos(theta)**8 + 1.02547216543066e+77*cos(theta)**6 - 2.98681213232231e+75*cos(theta)**4 + 2.95723973497258e+73*cos(theta)**2 - 4.26730120486664e+70)*sin(42*phi)

#@torch.jit.script
def Yl56_m_minus_41(theta, phi):
    return 4.94456284273033e-70*(1.0 - cos(theta)**2)**20.5*(2.94720632048257e+78*cos(theta)**15 - 2.78789787072675e+78*cos(theta)**13 + 9.97504742737095e+77*cos(theta)**11 - 1.70912027571776e+77*cos(theta)**9 + 1.46496023632951e+76*cos(theta)**7 - 5.97362426464461e+74*cos(theta)**5 + 9.85746578324193e+72*cos(theta)**3 - 4.26730120486664e+70*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl56_m_minus_40(theta, phi):
    return 1.94793185320383e-68*(1.0 - cos(theta)**2)**20*(1.8420039503016e+77*cos(theta)**16 - 1.99135562194768e+77*cos(theta)**14 + 8.31253952280912e+76*cos(theta)**12 - 1.70912027571776e+76*cos(theta)**10 + 1.83120029541189e+75*cos(theta)**8 - 9.95604044107435e+73*cos(theta)**6 + 2.46436644581048e+72*cos(theta)**4 - 2.13365060243332e+70*cos(theta)**2 + 2.74954974540376e+67)*sin(40*phi)

#@torch.jit.script
def Yl56_m_minus_39(theta, phi):
    return 7.86925894840995e-67*(1.0 - cos(theta)**2)**19.5*(1.08353173547153e+76*cos(theta)**17 - 1.32757041463179e+76*cos(theta)**15 + 6.39426117139163e+75*cos(theta)**13 - 1.55374570519797e+75*cos(theta)**11 + 2.0346669949021e+74*cos(theta)**9 - 1.42229149158205e+73*cos(theta)**7 + 4.92873289162097e+71*cos(theta)**5 - 7.11216867477773e+69*cos(theta)**3 + 2.74954974540376e+67*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl56_m_minus_38(theta, phi):
    return 3.25410746963115e-65*(1.0 - cos(theta)**2)**19*(6.01962075261962e+74*cos(theta)**18 - 8.29731509144867e+74*cos(theta)**16 + 4.56732940813688e+74*cos(theta)**14 - 1.29478808766497e+74*cos(theta)**12 + 2.0346669949021e+73*cos(theta)**10 - 1.77786436447756e+72*cos(theta)**8 + 8.21455481936828e+70*cos(theta)**6 - 1.77804216869443e+69*cos(theta)**4 + 1.37477487270188e+67*cos(theta)**2 - 1.6079238277215e+64)*sin(38*phi)

#@torch.jit.script
def Yl56_m_minus_37(theta, phi):
    return 1.37522139116224e-63*(1.0 - cos(theta)**2)**18.5*(3.16822144874717e+73*cos(theta)**19 - 4.8807735832051e+73*cos(theta)**17 + 3.04488627209125e+73*cos(theta)**15 - 9.95990836665363e+72*cos(theta)**13 + 1.84969726809282e+72*cos(theta)**11 - 1.97540484941951e+71*cos(theta)**9 + 1.17350783133833e+70*cos(theta)**7 - 3.55608433738886e+68*cos(theta)**5 + 4.58258290900627e+66*cos(theta)**3 - 1.6079238277215e+64*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl56_m_minus_36(theta, phi):
    return 5.93101593907904e-62*(1.0 - cos(theta)**2)**18*(1.58411072437358e+72*cos(theta)**20 - 2.71154087955839e+72*cos(theta)**18 + 1.90305392005703e+72*cos(theta)**16 - 7.11422026189545e+71*cos(theta)**14 + 1.54141439007735e+71*cos(theta)**12 - 1.97540484941951e+70*cos(theta)**10 + 1.46688478917291e+69*cos(theta)**8 - 5.92680722898144e+67*cos(theta)**6 + 1.14564572725157e+66*cos(theta)**4 - 8.03961913860749e+63*cos(theta)**2 + 8.64475176194354e+60)*sin(36*phi)

#@torch.jit.script
def Yl56_m_minus_35(theta, phi):
    return 2.60694970289965e-60*(1.0 - cos(theta)**2)**17.5*(7.54338440177897e+70*cos(theta)**21 - 1.42712677871494e+71*cos(theta)**19 + 1.11944348238649e+71*cos(theta)**17 - 4.7428135079303e+70*cos(theta)**15 + 1.18570337698258e+70*cos(theta)**13 - 1.79582259038138e+69*cos(theta)**11 + 1.6298719879699e+68*cos(theta)**9 - 8.46686746997349e+66*cos(theta)**7 + 2.29129145450313e+65*cos(theta)**5 - 2.6798730462025e+63*cos(theta)**3 + 8.64475176194354e+60*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl56_m_minus_34(theta, phi):
    return 1.16644613593616e-58*(1.0 - cos(theta)**2)**17*(3.42881109171772e+69*cos(theta)**22 - 7.1356338935747e+69*cos(theta)**20 + 6.21913045770272e+69*cos(theta)**18 - 2.96425844245644e+69*cos(theta)**16 + 8.46930983558983e+68*cos(theta)**14 - 1.49651882531781e+68*cos(theta)**12 + 1.6298719879699e+67*cos(theta)**10 - 1.05835843374669e+66*cos(theta)**8 + 3.81881909083856e+64*cos(theta)**6 - 6.69968261550624e+62*cos(theta)**4 + 4.32237588097177e+60*cos(theta)**2 - 4.31805782314862e+57)*sin(34*phi)

#@torch.jit.script
def Yl56_m_minus_33(theta, phi):
    return 5.30700945659949e-57*(1.0 - cos(theta)**2)**16.5*(1.49078743118162e+68*cos(theta)**23 - 3.39792090170224e+68*cos(theta)**21 + 3.27322655668564e+68*cos(theta)**19 - 1.74368143673908e+68*cos(theta)**17 + 5.64620655705988e+67*cos(theta)**15 - 1.15116832716755e+67*cos(theta)**13 + 1.48170180724536e+66*cos(theta)**11 - 1.1759538152741e+65*cos(theta)**9 + 5.45545584405508e+63*cos(theta)**7 - 1.33993652310125e+62*cos(theta)**5 + 1.44079196032392e+60*cos(theta)**3 - 4.31805782314862e+57*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl56_m_minus_32(theta, phi):
    return 2.45273419390533e-55*(1.0 - cos(theta)**2)**16*(6.21161429659006e+66*cos(theta)**24 - 1.54450950077375e+67*cos(theta)**22 + 1.63661327834282e+67*cos(theta)**20 - 9.6871190929949e+66*cos(theta)**18 + 3.52887909816243e+66*cos(theta)**16 - 8.22263090833964e+65*cos(theta)**14 + 1.2347515060378e+65*cos(theta)**12 - 1.1759538152741e+64*cos(theta)**10 + 6.81931980506885e+62*cos(theta)**8 - 2.23322753850208e+61*cos(theta)**6 + 3.60197990080981e+59*cos(theta)**4 - 2.15902891157431e+57*cos(theta)**2 + 2.02156265128681e+54)*sin(32*phi)

#@torch.jit.script
def Yl56_m_minus_31(theta, phi):
    return 1.15043431177514e-53*(1.0 - cos(theta)**2)**15.5*(2.48464571863603e+65*cos(theta)**25 - 6.71525869901629e+65*cos(theta)**23 + 7.79339656353725e+65*cos(theta)**21 - 5.09848373315521e+65*cos(theta)**19 + 2.07581123421319e+65*cos(theta)**17 - 5.48175393889309e+64*cos(theta)**15 + 9.49808850798308e+63*cos(theta)**13 - 1.06904892297645e+63*cos(theta)**11 + 7.57702200563206e+61*cos(theta)**9 - 3.19032505500297e+60*cos(theta)**7 + 7.20395980161961e+58*cos(theta)**5 - 7.19676303858103e+56*cos(theta)**3 + 2.02156265128681e+54*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl56_m_minus_30(theta, phi):
    return 5.47152170526167e-52*(1.0 - cos(theta)**2)**15*(9.55632968706164e+63*cos(theta)**26 - 2.79802445792345e+64*cos(theta)**24 + 3.54245298342602e+64*cos(theta)**22 - 2.5492418665776e+64*cos(theta)**20 + 1.15322846345177e+64*cos(theta)**18 - 3.42609621180818e+63*cos(theta)**16 + 6.78434893427363e+62*cos(theta)**14 - 8.90874102480375e+61*cos(theta)**12 + 7.57702200563206e+60*cos(theta)**10 - 3.98790631875371e+59*cos(theta)**8 + 1.2006599669366e+58*cos(theta)**6 - 1.79919075964526e+56*cos(theta)**4 + 1.0107813256434e+54*cos(theta)**2 - 8.93705858216979e+50)*sin(30*phi)

#@torch.jit.script
def Yl56_m_minus_29(theta, phi):
    return 2.63656956230268e-50*(1.0 - cos(theta)**2)**14.5*(3.53938136557838e+62*cos(theta)**27 - 1.11920978316938e+63*cos(theta)**25 + 1.54019694931566e+63*cos(theta)**23 - 1.21392469837029e+63*cos(theta)**21 + 6.06962349185144e+62*cos(theta)**19 - 2.01535071282834e+62*cos(theta)**17 + 4.52289928951575e+61*cos(theta)**15 - 6.8528777113875e+60*cos(theta)**13 + 6.88820182330187e+59*cos(theta)**11 - 4.43100702083746e+58*cos(theta)**9 + 1.71522852419515e+57*cos(theta)**7 - 3.59838151929052e+55*cos(theta)**5 + 3.36927108547801e+53*cos(theta)**3 - 8.93705858216979e+50*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl56_m_minus_28(theta, phi):
    return 1.28625688551428e-48*(1.0 - cos(theta)**2)**14*(1.26406477342085e+61*cos(theta)**28 - 4.30465301218993e+61*cos(theta)**26 + 6.41748728881526e+61*cos(theta)**24 - 5.51783953804676e+61*cos(theta)**22 + 3.03481174592572e+61*cos(theta)**20 - 1.11963928490463e+61*cos(theta)**18 + 2.82681205594734e+60*cos(theta)**16 - 4.89491265099107e+59*cos(theta)**14 + 5.74016818608489e+58*cos(theta)**12 - 4.43100702083746e+57*cos(theta)**10 + 2.14403565524393e+56*cos(theta)**8 - 5.99730253215086e+54*cos(theta)**6 + 8.42317771369503e+52*cos(theta)**4 - 4.4685292910849e+50*cos(theta)**2 + 3.75506663116378e+47)*sin(28*phi)

#@torch.jit.script
def Yl56_m_minus_27(theta, phi):
    return 6.3484302825172e-47*(1.0 - cos(theta)**2)**13.5*(4.3588440462788e+59*cos(theta)**29 - 1.59431593044071e+60*cos(theta)**27 + 2.5669949155261e+60*cos(theta)**25 - 2.39906066871598e+60*cos(theta)**23 + 1.44514845044082e+60*cos(theta)**21 - 5.89283834160334e+59*cos(theta)**19 + 1.6628306211455e+59*cos(theta)**17 - 3.26327510066072e+58*cos(theta)**15 + 4.41551398929607e+57*cos(theta)**13 - 4.02818820076133e+56*cos(theta)**11 + 2.38226183915993e+55*cos(theta)**9 - 8.5675750459298e+53*cos(theta)**7 + 1.68463554273901e+52*cos(theta)**5 - 1.48950976369497e+50*cos(theta)**3 + 3.75506663116378e+47*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl56_m_minus_26(theta, phi):
    return 3.16786034981711e-45*(1.0 - cos(theta)**2)**13*(1.45294801542627e+58*cos(theta)**30 - 5.69398546585969e+58*cos(theta)**28 + 9.87305736740809e+58*cos(theta)**26 - 9.99608611964993e+58*cos(theta)**24 + 6.56885659291281e+58*cos(theta)**22 - 2.94641917080167e+58*cos(theta)**20 + 9.23794789525276e+57*cos(theta)**18 - 2.03954693791295e+57*cos(theta)**16 + 3.15393856378291e+56*cos(theta)**14 - 3.35682350063444e+55*cos(theta)**12 + 2.38226183915993e+54*cos(theta)**10 - 1.07094688074123e+53*cos(theta)**8 + 2.80772590456501e+51*cos(theta)**6 - 3.72377440923741e+49*cos(theta)**4 + 1.87753331558189e+47*cos(theta)**2 - 1.50805888801758e+44)*sin(26*phi)

#@torch.jit.script
def Yl56_m_minus_25(theta, phi):
    return 1.59717977185062e-43*(1.0 - cos(theta)**2)**12.5*(4.68692908202021e+56*cos(theta)**31 - 1.96344326408955e+57*cos(theta)**29 + 3.65668791385485e+57*cos(theta)**27 - 3.99843444785997e+57*cos(theta)**25 + 2.85602460561427e+57*cos(theta)**23 - 1.4030567480008e+57*cos(theta)**21 + 4.86207783960672e+56*cos(theta)**19 - 1.19973349288997e+56*cos(theta)**17 + 2.10262570918861e+55*cos(theta)**15 - 2.58217192356495e+54*cos(theta)**13 + 2.16569258105448e+53*cos(theta)**11 - 1.18994097860136e+52*cos(theta)**9 + 4.01103700652144e+50*cos(theta)**7 - 7.44754881847483e+48*cos(theta)**5 + 6.25844438527296e+46*cos(theta)**3 - 1.50805888801758e+44*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl56_m_minus_24(theta, phi):
    return 8.13151186163682e-42*(1.0 - cos(theta)**2)**12*(1.46466533813132e+55*cos(theta)**32 - 6.5448108802985e+55*cos(theta)**30 + 1.30595996923387e+56*cos(theta)**28 - 1.53785940302307e+56*cos(theta)**26 + 1.19001025233928e+56*cos(theta)**24 - 6.37753067273089e+55*cos(theta)**22 + 2.43103891980336e+55*cos(theta)**20 - 6.66518607161094e+54*cos(theta)**18 + 1.31414106824288e+54*cos(theta)**16 - 1.84440851683211e+53*cos(theta)**14 + 1.8047438175454e+52*cos(theta)**12 - 1.18994097860136e+51*cos(theta)**10 + 5.0137962581518e+49*cos(theta)**8 - 1.24125813641247e+48*cos(theta)**6 + 1.56461109631824e+46*cos(theta)**4 - 7.54029444008791e+43*cos(theta)**2 + 5.81812842599376e+40)*sin(24*phi)

#@torch.jit.script
def Yl56_m_minus_23(theta, phi):
    return 4.17804644315597e-40*(1.0 - cos(theta)**2)**11.5*(4.43837981251914e+53*cos(theta)**33 - 2.11122931622532e+54*cos(theta)**31 + 4.5033102387375e+54*cos(theta)**29 - 5.6957755667521e+54*cos(theta)**27 + 4.76004100935711e+54*cos(theta)**25 - 2.77283942292647e+54*cos(theta)**23 + 1.15763758085874e+54*cos(theta)**21 - 3.50799266926891e+53*cos(theta)**19 + 7.73024157789928e+52*cos(theta)**17 - 1.22960567788807e+52*cos(theta)**15 + 1.38826447503492e+51*cos(theta)**13 - 1.08176452600124e+50*cos(theta)**11 + 5.57088473127978e+48*cos(theta)**9 - 1.77322590916067e+47*cos(theta)**7 + 3.12922219263648e+45*cos(theta)**5 - 2.5134314800293e+43*cos(theta)**3 + 5.81812842599376e+40*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl56_m_minus_22(theta, phi):
    return 2.16534084176182e-38*(1.0 - cos(theta)**2)**11*(1.30540582721151e+52*cos(theta)**34 - 6.59759161320413e+52*cos(theta)**32 + 1.5011034129125e+53*cos(theta)**30 - 2.03420555955432e+53*cos(theta)**28 + 1.83078500359889e+53*cos(theta)**26 - 1.1553497595527e+53*cos(theta)**24 + 5.26198900390337e+52*cos(theta)**22 - 1.75399633463446e+52*cos(theta)**20 + 4.29457865438849e+51*cos(theta)**18 - 7.68503548680046e+50*cos(theta)**16 + 9.91617482167801e+49*cos(theta)**14 - 9.01470438334365e+48*cos(theta)**12 + 5.57088473127978e+47*cos(theta)**10 - 2.21653238645084e+46*cos(theta)**8 + 5.2153703210608e+44*cos(theta)**6 - 6.28357870007326e+42*cos(theta)**4 + 2.90906421299688e+40*cos(theta)**2 - 2.16609397840423e+37)*sin(22*phi)

#@torch.jit.script
def Yl56_m_minus_21(theta, phi):
    return 1.13137763914331e-36*(1.0 - cos(theta)**2)**10.5*(3.72973093489003e+50*cos(theta)**35 - 1.99927018581943e+51*cos(theta)**33 + 4.84226907391129e+51*cos(theta)**31 - 7.01450192949766e+51*cos(theta)**29 + 6.7806851985144e+51*cos(theta)**27 - 4.62139903821079e+51*cos(theta)**25 + 2.28782130604494e+51*cos(theta)**23 - 8.35236349825932e+50*cos(theta)**21 + 2.26030455494131e+50*cos(theta)**19 - 4.52060910988262e+49*cos(theta)**17 + 6.61078321445201e+48*cos(theta)**15 - 6.93438798718742e+47*cos(theta)**13 + 5.0644406647998e+46*cos(theta)**11 - 2.46281376272316e+45*cos(theta)**9 + 7.45052903008686e+43*cos(theta)**7 - 1.25671574001465e+42*cos(theta)**5 + 9.69688070998959e+39*cos(theta)**3 - 2.16609397840423e+37*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl56_m_minus_20(theta, phi):
    return 5.95667909530459e-35*(1.0 - cos(theta)**2)**10*(1.03603637080279e+49*cos(theta)**36 - 5.88020642888069e+49*cos(theta)**34 + 1.51320908559728e+50*cos(theta)**32 - 2.33816730983255e+50*cos(theta)**30 + 2.42167328518372e+50*cos(theta)**28 - 1.77746116854261e+50*cos(theta)**26 + 9.53258877518727e+49*cos(theta)**24 - 3.79652886284515e+49*cos(theta)**22 + 1.13015227747066e+49*cos(theta)**20 - 2.51144950549035e+48*cos(theta)**18 + 4.1317395090325e+47*cos(theta)**16 - 4.95313427656244e+46*cos(theta)**14 + 4.2203672206665e+45*cos(theta)**12 - 2.46281376272316e+44*cos(theta)**10 + 9.31316128760858e+42*cos(theta)**8 - 2.09452623335775e+41*cos(theta)**6 + 2.4242201774974e+39*cos(theta)**4 - 1.08304698920211e+37*cos(theta)**2 + 7.81419184128509e+33)*sin(20*phi)

#@torch.jit.script
def Yl56_m_minus_19(theta, phi):
    return 3.15872532320494e-33*(1.0 - cos(theta)**2)**9.5*(2.80009829946699e+47*cos(theta)**37 - 1.6800589796802e+48*cos(theta)**35 + 4.58548207756751e+48*cos(theta)**33 - 7.54247519300824e+48*cos(theta)**31 + 8.35059753511626e+48*cos(theta)**29 - 6.58318951312078e+48*cos(theta)**27 + 3.81303551007491e+48*cos(theta)**25 - 1.65066472297615e+48*cos(theta)**23 + 5.38167751176503e+47*cos(theta)**21 - 1.32181552920545e+47*cos(theta)**19 + 2.43043500531324e+46*cos(theta)**17 - 3.3020895177083e+45*cos(theta)**15 + 3.24643632358962e+44*cos(theta)**13 - 2.2389216024756e+43*cos(theta)**11 + 1.03479569862318e+42*cos(theta)**9 - 2.99218033336822e+40*cos(theta)**7 + 4.8484403549948e+38*cos(theta)**5 - 3.61015663067371e+36*cos(theta)**3 + 7.81419184128509e+33*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl56_m_minus_18(theta, phi):
    return 1.6862978726266e-31*(1.0 - cos(theta)**2)**9*(7.36867973543946e+45*cos(theta)**38 - 4.66683049911165e+46*cos(theta)**36 + 1.34867119928456e+47*cos(theta)**34 - 2.35702349781507e+47*cos(theta)**32 + 2.78353251170542e+47*cos(theta)**30 - 2.35113911182885e+47*cos(theta)**28 + 1.46655211925958e+47*cos(theta)**26 - 6.87776967906729e+46*cos(theta)**24 + 2.44621705080229e+46*cos(theta)**22 - 6.60907764602723e+45*cos(theta)**20 + 1.35024166961847e+45*cos(theta)**18 - 2.06380594856768e+44*cos(theta)**16 + 2.3188830882783e+43*cos(theta)**14 - 1.865768002063e+42*cos(theta)**12 + 1.03479569862318e+41*cos(theta)**10 - 3.74022541671027e+39*cos(theta)**8 + 8.08073392499133e+37*cos(theta)**6 - 9.02539157668428e+35*cos(theta)**4 + 3.90709592064255e+33*cos(theta)**2 - 2.74182169869652e+30)*sin(18*phi)

#@torch.jit.script
def Yl56_m_minus_17(theta, phi):
    return 9.05904580347145e-30*(1.0 - cos(theta)**2)**8.5*(1.88940506036909e+44*cos(theta)**39 - 1.26130554030045e+45*cos(theta)**37 + 3.85334628367017e+45*cos(theta)**35 - 7.14249544792447e+45*cos(theta)**33 + 8.97913713453361e+45*cos(theta)**31 - 8.10737624768569e+45*cos(theta)**29 + 5.43167451577622e+45*cos(theta)**27 - 2.75110787162692e+45*cos(theta)**25 + 1.0635726307836e+45*cos(theta)**23 - 3.14717983144154e+44*cos(theta)**21 + 7.10653510325508e+43*cos(theta)**19 - 1.21400349915746e+43*cos(theta)**17 + 1.5459220588522e+42*cos(theta)**15 - 1.43520615543308e+41*cos(theta)**13 + 9.40723362384705e+39*cos(theta)**11 - 4.15580601856697e+38*cos(theta)**9 + 1.15439056071305e+37*cos(theta)**7 - 1.80507831533686e+35*cos(theta)**5 + 1.30236530688085e+33*cos(theta)**3 - 2.74182169869652e+30*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl56_m_minus_16(theta, phi):
    return 4.8952387861945e-28*(1.0 - cos(theta)**2)**8*(4.72351265092273e+42*cos(theta)**40 - 3.31922510605381e+43*cos(theta)**38 + 1.07037396768616e+44*cos(theta)**36 - 2.1007339552719e+44*cos(theta)**34 + 2.80598035454175e+44*cos(theta)**32 - 2.70245874922856e+44*cos(theta)**30 + 1.93988375563437e+44*cos(theta)**28 - 1.0581184121642e+44*cos(theta)**26 + 4.43155262826501e+43*cos(theta)**24 - 1.43053628701888e+43*cos(theta)**22 + 3.55326755162754e+42*cos(theta)**20 - 6.74446388420812e+41*cos(theta)**18 + 9.66201286782624e+40*cos(theta)**16 - 1.02514725388077e+40*cos(theta)**14 + 7.83936135320587e+38*cos(theta)**12 - 4.15580601856697e+37*cos(theta)**10 + 1.44298820089131e+36*cos(theta)**8 - 3.00846385889476e+34*cos(theta)**6 + 3.25591326720212e+32*cos(theta)**4 - 1.37091084934826e+30*cos(theta)**2 + 9.38980033800179e+26)*sin(16*phi)

#@torch.jit.script
def Yl56_m_minus_15(theta, phi):
    return 2.65969635312837e-26*(1.0 - cos(theta)**2)**7.5*(1.15207625632262e+41*cos(theta)**41 - 8.51083360526618e+41*cos(theta)**39 + 2.892902615368e+42*cos(theta)**37 - 6.00209701506258e+42*cos(theta)**35 + 8.50297077133865e+42*cos(theta)**33 - 8.71760886847924e+42*cos(theta)**31 + 6.68925432977367e+42*cos(theta)**29 - 3.91895708208963e+42*cos(theta)**27 + 1.772621051306e+42*cos(theta)**25 - 6.21972298703861e+41*cos(theta)**23 + 1.69203216744169e+41*cos(theta)**21 - 3.54971783379375e+40*cos(theta)**19 + 5.68353698107426e+39*cos(theta)**17 - 6.83431502587179e+38*cos(theta)**15 + 6.03027796400452e+37*cos(theta)**13 - 3.77800547142452e+36*cos(theta)**11 + 1.60332022321257e+35*cos(theta)**9 - 4.2978055127068e+33*cos(theta)**7 + 6.51182653440424e+31*cos(theta)**5 - 4.56970283116087e+29*cos(theta)**3 + 9.38980033800179e+26*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl56_m_minus_14(theta, phi):
    return 1.45239878642533e-24*(1.0 - cos(theta)**2)**7*(2.74303870553004e+39*cos(theta)**42 - 2.12770840131654e+40*cos(theta)**40 + 7.61290161938947e+40*cos(theta)**38 - 1.66724917085072e+41*cos(theta)**36 + 2.50087375627607e+41*cos(theta)**34 - 2.72425277139976e+41*cos(theta)**32 + 2.22975144325789e+41*cos(theta)**30 - 1.39962752931772e+41*cos(theta)**28 + 6.81777327425386e+40*cos(theta)**26 - 2.59155124459942e+40*cos(theta)**24 + 7.69105530655312e+39*cos(theta)**22 - 1.77485891689687e+39*cos(theta)**20 + 3.15752054504125e+38*cos(theta)**18 - 4.27144689116987e+37*cos(theta)**16 + 4.30734140286037e+36*cos(theta)**14 - 3.14833789285376e+35*cos(theta)**12 + 1.60332022321257e+34*cos(theta)**10 - 5.3722568908835e+32*cos(theta)**8 + 1.08530442240071e+31*cos(theta)**6 - 1.14242570779022e+29*cos(theta)**4 + 4.6949001690009e+26*cos(theta)**2 - 3.14882640442716e+23)*sin(14*phi)

#@torch.jit.script
def Yl56_m_minus_13(theta, phi):
    return 7.96836327408424e-23*(1.0 - cos(theta)**2)**6.5*(6.37915978030242e+37*cos(theta)**43 - 5.18953268613791e+38*cos(theta)**41 + 1.95202605625371e+39*cos(theta)**39 - 4.50607884013707e+39*cos(theta)**37 + 7.14535358936021e+39*cos(theta)**35 - 8.25531142848413e+39*cos(theta)**33 + 7.19274659115449e+39*cos(theta)**31 - 4.82630182523353e+39*cos(theta)**29 + 2.52510121268661e+39*cos(theta)**27 - 1.03662049783977e+39*cos(theta)**25 + 3.3439370898057e+38*cos(theta)**23 - 8.45170912808035e+37*cos(theta)**21 + 1.66185291844277e+37*cos(theta)**19 - 2.51261581833522e+36*cos(theta)**17 + 2.87156093524025e+35*cos(theta)**15 - 2.42179837911828e+34*cos(theta)**13 + 1.45756383928415e+33*cos(theta)**11 - 5.96917432320389e+31*cos(theta)**9 + 1.55043488914387e+30*cos(theta)**7 - 2.28485141558044e+28*cos(theta)**5 + 1.5649667230003e+26*cos(theta)**3 - 3.14882640442716e+23*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl56_m_minus_12(theta, phi):
    return 4.39056093319479e-21*(1.0 - cos(theta)**2)**6*(1.44980904097782e+36*cos(theta)**44 - 1.23560302050903e+37*cos(theta)**42 + 4.88006514063427e+37*cos(theta)**40 - 1.1858102210887e+38*cos(theta)**38 + 1.98482044148895e+38*cos(theta)**36 - 2.42803277308357e+38*cos(theta)**34 + 2.24773330973578e+38*cos(theta)**32 - 1.60876727507784e+38*cos(theta)**30 + 9.01821861673791e+37*cos(theta)**28 - 3.98700191476834e+37*cos(theta)**26 + 1.39330712075238e+37*cos(theta)**24 - 3.84168596730925e+36*cos(theta)**22 + 8.30926459221383e+35*cos(theta)**20 - 1.3958976768529e+35*cos(theta)**18 + 1.79472558452515e+34*cos(theta)**16 - 1.72985598508449e+33*cos(theta)**14 + 1.21463653273679e+32*cos(theta)**12 - 5.96917432320389e+30*cos(theta)**10 + 1.93804361142983e+29*cos(theta)**8 - 3.80808569263406e+27*cos(theta)**6 + 3.91241680750075e+25*cos(theta)**4 - 1.57441320221358e+23*cos(theta)**2 + 1.03716284730802e+20)*sin(12*phi)

#@torch.jit.script
def Yl56_m_minus_11(theta, phi):
    return 2.42873830296257e-19*(1.0 - cos(theta)**2)**5.5*(3.2217978688396e+34*cos(theta)**45 - 2.87349539653262e+35*cos(theta)**43 + 1.1902597903986e+36*cos(theta)**41 - 3.04053902843257e+36*cos(theta)**39 + 5.36437957159175e+36*cos(theta)**37 - 6.93723649452447e+36*cos(theta)**35 + 6.81131305980538e+36*cos(theta)**33 - 5.18957185508982e+36*cos(theta)**31 + 3.10973055749583e+36*cos(theta)**29 - 1.47666737584013e+36*cos(theta)**27 + 5.57322848300951e+35*cos(theta)**25 - 1.6702982466562e+35*cos(theta)**23 + 3.95679266295897e+34*cos(theta)**21 - 7.34682987817314e+33*cos(theta)**19 + 1.05572093207362e+33*cos(theta)**17 - 1.15323732338966e+32*cos(theta)**15 + 9.34335794412917e+30*cos(theta)**13 - 5.42652211200354e+29*cos(theta)**11 + 2.15338179047759e+28*cos(theta)**9 - 5.44012241804866e+26*cos(theta)**7 + 7.8248336150015e+24*cos(theta)**5 - 5.2480440073786e+22*cos(theta)**3 + 1.03716284730802e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl56_m_minus_10(theta, phi):
    return 1.34833261296548e-17*(1.0 - cos(theta)**2)**5*(7.00390841052088e+32*cos(theta)**46 - 6.53067135575596e+33*cos(theta)**44 + 2.83395188190144e+34*cos(theta)**42 - 7.60134757108143e+34*cos(theta)**40 + 1.41167883462941e+35*cos(theta)**38 - 1.92701013736791e+35*cos(theta)**36 + 2.003327370531e+35*cos(theta)**34 - 1.62174120471557e+35*cos(theta)**32 + 1.03657685249861e+35*cos(theta)**30 - 5.27381205657188e+34*cos(theta)**28 + 2.14354941654212e+34*cos(theta)**26 - 6.95957602773415e+33*cos(theta)**24 + 1.7985421195268e+33*cos(theta)**22 - 3.67341493908657e+32*cos(theta)**20 + 5.86511628929789e+31*cos(theta)**18 - 7.20773327118536e+30*cos(theta)**16 + 6.6738271029494e+29*cos(theta)**14 - 4.52210176000295e+28*cos(theta)**12 + 2.15338179047759e+27*cos(theta)**10 - 6.80015302256082e+25*cos(theta)**8 + 1.30413893583358e+24*cos(theta)**6 - 1.31201100184465e+22*cos(theta)**4 + 5.18581423654012e+19*cos(theta)**2 - 3.36522662981189e+16)*sin(10*phi)

#@torch.jit.script
def Yl56_m_minus_9(theta, phi):
    return 7.50961955810543e-16*(1.0 - cos(theta)**2)**4.5*(1.49019327883423e+31*cos(theta)**47 - 1.4512603012791e+32*cos(theta)**45 + 6.59058577186381e+32*cos(theta)**43 - 1.85398721245888e+33*cos(theta)**41 + 3.61968931956258e+33*cos(theta)**39 - 5.20813550639976e+33*cos(theta)**37 + 5.72379248723142e+33*cos(theta)**35 - 4.91436728701687e+33*cos(theta)**33 + 3.34379629838261e+33*cos(theta)**31 - 1.81855588157651e+33*cos(theta)**29 + 7.93907191311895e+32*cos(theta)**27 - 2.78383041109366e+32*cos(theta)**25 + 7.81974834576871e+31*cos(theta)**23 - 1.74924520908884e+31*cos(theta)**21 + 3.08690331015678e+30*cos(theta)**19 - 4.23984310069727e+29*cos(theta)**17 + 4.44921806863294e+28*cos(theta)**15 - 3.47853981538688e+27*cos(theta)**13 + 1.95761980952509e+26*cos(theta)**11 - 7.55572558062314e+24*cos(theta)**9 + 1.8630556226194e+23*cos(theta)**7 - 2.6240220036893e+21*cos(theta)**5 + 1.72860474551337e+19*cos(theta)**3 - 3.36522662981189e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl56_m_minus_8(theta, phi):
    return 4.19464520587065e-14*(1.0 - cos(theta)**2)**4*(3.10456933090465e+29*cos(theta)**48 - 3.15491369843283e+30*cos(theta)**46 + 1.49786040269632e+31*cos(theta)**44 - 4.41425526775925e+31*cos(theta)**42 + 9.04922329890646e+31*cos(theta)**40 - 1.37056197536836e+32*cos(theta)**38 + 1.58994235756428e+32*cos(theta)**36 - 1.44540214324026e+32*cos(theta)**34 + 1.04493634324457e+32*cos(theta)**32 - 6.06185293858836e+31*cos(theta)**30 + 2.83538282611391e+31*cos(theta)**28 - 1.07070400426679e+31*cos(theta)**26 + 3.25822847740363e+30*cos(theta)**24 - 7.95111458676747e+29*cos(theta)**22 + 1.54345165507839e+29*cos(theta)**20 - 2.35546838927626e+28*cos(theta)**18 + 2.78076129289559e+27*cos(theta)**16 - 2.48467129670492e+26*cos(theta)**14 + 1.6313498412709e+25*cos(theta)**12 - 7.55572558062314e+23*cos(theta)**10 + 2.32881952827425e+22*cos(theta)**8 - 4.37337000614883e+20*cos(theta)**6 + 4.32151186378343e+18*cos(theta)**4 - 1.68261331490594e+16*cos(theta)**2 + 10785982787858.6)*sin(8*phi)

#@torch.jit.script
def Yl56_m_minus_7(theta, phi):
    return 2.34900131528757e-12*(1.0 - cos(theta)**2)**3.5*(6.33585577735642e+27*cos(theta)**49 - 6.71258233709113e+28*cos(theta)**47 + 3.32857867265849e+29*cos(theta)**45 - 1.02657099250215e+30*cos(theta)**43 + 2.20712763387962e+30*cos(theta)**41 - 3.51426147530348e+30*cos(theta)**39 + 4.29714150693049e+30*cos(theta)**37 - 4.12972040925788e+30*cos(theta)**35 + 3.16647376740778e+30*cos(theta)**33 - 1.9554364318027e+30*cos(theta)**31 + 9.77718215901349e+29*cos(theta)**29 - 3.9655703861733e+29*cos(theta)**27 + 1.30329139096145e+29*cos(theta)**25 - 3.45700634207281e+28*cos(theta)**23 + 7.34976978608758e+27*cos(theta)**21 - 1.23972020488224e+27*cos(theta)**19 + 1.6357419369974e+26*cos(theta)**17 - 1.65644753113661e+25*cos(theta)**15 + 1.25488449328531e+24*cos(theta)**13 - 6.86884143693012e+22*cos(theta)**11 + 2.58757725363806e+21*cos(theta)**9 - 6.24767143735548e+19*cos(theta)**7 + 8.64302372756687e+17*cos(theta)**5 - 5.60871104968648e+15*cos(theta)**3 + 10785982787858.6*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl56_m_minus_6(theta, phi):
    return 1.31837371843311e-10*(1.0 - cos(theta)**2)**3*(1.26717115547128e+26*cos(theta)**50 - 1.39845465356065e+27*cos(theta)**48 + 7.23604059273585e+27*cos(theta)**46 - 2.33311589205034e+28*cos(theta)**44 + 5.25506579495149e+28*cos(theta)**42 - 8.7856536882587e+28*cos(theta)**40 + 1.13082671235013e+29*cos(theta)**38 - 1.14714455812719e+29*cos(theta)**36 + 9.31315813943464e+28*cos(theta)**34 - 6.11073884938343e+28*cos(theta)**32 + 3.25906071967116e+28*cos(theta)**30 - 1.41627513791904e+28*cos(theta)**28 + 5.01265919600558e+27*cos(theta)**26 - 1.44041930919701e+27*cos(theta)**24 + 3.34080444822163e+26*cos(theta)**22 - 6.19860102441121e+25*cos(theta)**20 + 9.08745520554113e+24*cos(theta)**18 - 1.03527970696038e+24*cos(theta)**16 + 8.96346066632365e+22*cos(theta)**14 - 5.7240345307751e+21*cos(theta)**12 + 2.58757725363806e+20*cos(theta)**10 - 7.80958929669435e+18*cos(theta)**8 + 1.44050395459448e+17*cos(theta)**6 - 1.40217776242162e+15*cos(theta)**4 + 5392991393929.31*cos(theta)**2 - 3424121519.95512)*sin(6*phi)

#@torch.jit.script
def Yl56_m_minus_5(theta, phi):
    return 7.41343475368955e-9*(1.0 - cos(theta)**2)**2.5*(2.4846493244535e+24*cos(theta)**51 - 2.85398908889929e+25*cos(theta)**49 + 1.53958310483741e+26*cos(theta)**47 - 5.18470198233409e+26*cos(theta)**45 + 1.22210832440732e+27*cos(theta)**43 - 2.14284236298993e+27*cos(theta)**41 + 2.89955567269264e+27*cos(theta)**39 - 3.10039069764105e+27*cos(theta)**37 + 2.66090232555275e+27*cos(theta)**35 - 1.85173904526771e+27*cos(theta)**33 + 1.05130990957134e+27*cos(theta)**31 - 4.88370737213461e+26*cos(theta)**29 + 1.85654044296503e+26*cos(theta)**27 - 5.76167723678802e+25*cos(theta)**25 + 1.45252367313984e+25*cos(theta)**23 - 2.95171477352915e+24*cos(theta)**21 + 4.78287116081112e+23*cos(theta)**19 - 6.08988062917872e+22*cos(theta)**17 + 5.97564044421577e+21*cos(theta)**15 - 4.40310348521162e+20*cos(theta)**13 + 2.35234295785278e+19*cos(theta)**11 - 8.6773214407715e+17*cos(theta)**9 + 2.05786279227783e+16*cos(theta)**7 - 280435552484324.0*cos(theta)**5 + 1797663797976.44*cos(theta)**3 - 3424121519.95512*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl56_m_minus_4(theta, phi):
    return 4.17528436271539e-7*(1.0 - cos(theta)**2)**2*(4.77817177779519e+22*cos(theta)**52 - 5.70797817779858e+23*cos(theta)**50 + 3.20746480174461e+24*cos(theta)**48 - 1.12710912659437e+25*cos(theta)**46 + 2.77751891910755e+25*cos(theta)**44 - 5.10200562616649e+25*cos(theta)**42 + 7.2488891817316e+25*cos(theta)**40 - 8.15892288852907e+25*cos(theta)**38 + 7.39139534875765e+25*cos(theta)**36 - 5.4462913096109e+25*cos(theta)**34 + 3.28534346741045e+25*cos(theta)**32 - 1.6279024573782e+25*cos(theta)**30 + 6.63050158201796e+24*cos(theta)**28 - 2.21602970645693e+24*cos(theta)**26 + 6.05218197141599e+23*cos(theta)**24 - 1.34168853342234e+23*cos(theta)**22 + 2.39143558040556e+22*cos(theta)**20 - 3.3832670162104e+21*cos(theta)**18 + 3.73477527763485e+20*cos(theta)**16 - 3.1450739180083e+19*cos(theta)**14 + 1.96028579821065e+18*cos(theta)**12 - 8.6773214407715e+16*cos(theta)**10 + 2.57232849034728e+15*cos(theta)**8 - 46739258747387.3*cos(theta)**6 + 449415949494.109*cos(theta)**4 - 1712060759.97756*cos(theta)**2 + 1079483.45521914)*sin(4*phi)

#@torch.jit.script
def Yl56_m_minus_3(theta, phi):
    return 2.35450501040714e-5*(1.0 - cos(theta)**2)**1.5*(9.01541844867017e+20*cos(theta)**53 - 1.11921140741149e+22*cos(theta)**51 + 6.54584653417268e+22*cos(theta)**49 - 2.39810452466887e+23*cos(theta)**47 + 6.17226426468345e+23*cos(theta)**45 - 1.18651293631779e+24*cos(theta)**43 + 1.76802175164185e+24*cos(theta)**41 - 2.09203150987925e+24*cos(theta)**39 + 1.99767441858315e+24*cos(theta)**37 - 1.5560832313174e+24*cos(theta)**35 + 9.95558626488014e+23*cos(theta)**33 - 5.25129824960711e+23*cos(theta)**31 + 2.28637985586826e+23*cos(theta)**29 - 8.20751743132197e+22*cos(theta)**27 + 2.4208727885664e+22*cos(theta)**25 - 5.83342840618409e+21*cos(theta)**23 + 1.13877884781217e+21*cos(theta)**21 - 1.78066685063705e+20*cos(theta)**19 + 2.19692663390286e+19*cos(theta)**17 - 2.09671594533887e+18*cos(theta)**15 + 1.50791215246973e+17*cos(theta)**13 - 7.888474037065e+15*cos(theta)**11 + 285814276705254.0*cos(theta)**9 - 6677036963912.48*cos(theta)**7 + 89883189898.8218*cos(theta)**5 - 570686919.992519*cos(theta)**3 + 1079483.45521914*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl56_m_minus_2(theta, phi):
    return 0.00132899242236692*(1.0 - cos(theta)**2)*(1.66952193493892e+19*cos(theta)**54 - 2.15232962963747e+20*cos(theta)**52 + 1.30916930683454e+21*cos(theta)**50 - 4.99605109306014e+21*cos(theta)**48 + 1.34179657927901e+22*cos(theta)**46 - 2.69662030981316e+22*cos(theta)**44 + 4.20957559914727e+22*cos(theta)**42 - 5.23007877469812e+22*cos(theta)**40 + 5.25703794363987e+22*cos(theta)**38 - 4.32245342032611e+22*cos(theta)**36 + 2.92811360731769e+22*cos(theta)**34 - 1.64103070300222e+22*cos(theta)**32 + 7.62126618622755e+21*cos(theta)**30 - 2.93125622547213e+21*cos(theta)**28 + 9.31104918679383e+20*cos(theta)**26 - 2.43059516924337e+20*cos(theta)**24 + 5.17626749005533e+19*cos(theta)**22 - 8.90333425318526e+18*cos(theta)**20 + 1.2205147966127e+18*cos(theta)**18 - 1.31044746583679e+17*cos(theta)**16 + 1.07708010890695e+16*cos(theta)**14 - 657372836422083.0*cos(theta)**12 + 28581427670525.4*cos(theta)**10 - 834629620489.06*cos(theta)**8 + 14980531649.8036*cos(theta)**6 - 142671729.99813*cos(theta)**4 + 539741.727609571*cos(theta)**2 - 338.820921286611)*sin(2*phi)

#@torch.jit.script
def Yl56_m_minus_1(theta, phi):
    return 0.0750616049607305*(1.0 - cos(theta)**2)**0.5*(3.03549442716167e+17*cos(theta)**55 - 4.06099930120278e+18*cos(theta)**53 + 2.56699864085203e+19*cos(theta)**51 - 1.01960226388983e+20*cos(theta)**49 + 2.85488633889151e+20*cos(theta)**47 - 5.99248957736257e+20*cos(theta)**45 + 9.78971069569133e+20*cos(theta)**43 - 1.27562896943857e+21*cos(theta)**41 + 1.34795844708715e+21*cos(theta)**39 - 1.16823065414219e+21*cos(theta)**37 + 8.36603887805054e+20*cos(theta)**35 - 4.97282031212794e+20*cos(theta)**33 + 2.45847296329921e+20*cos(theta)**31 - 1.01077800878349e+20*cos(theta)**29 + 3.44853673584957e+19*cos(theta)**27 - 9.72238067697348e+18*cos(theta)**25 + 2.25055108263275e+18*cos(theta)**23 - 4.23968297770727e+17*cos(theta)**21 + 6.42376208743525e+16*cos(theta)**19 - 7.7085145049223e+15*cos(theta)**17 + 718053405937968.0*cos(theta)**15 - 50567141263237.2*cos(theta)**13 + 2598311606411.4*cos(theta)**11 - 92736624498.7844*cos(theta)**9 + 2140075949.97195*cos(theta)**7 - 28534345.999626*cos(theta)**5 + 179913.90920319*cos(theta)**3 - 338.820921286611*cos(theta))*sin(phi)

#@torch.jit.script
def Yl56_m0(theta, phi):
    return 5.10652632735564e+16*cos(theta)**56 - 7.08473021993485e+17*cos(theta)**54 + 4.65057291042512e+18*cos(theta)**52 - 1.92107778168963e+19*cos(theta)**50 + 5.60314352992809e+19*cos(theta)**48 - 1.22725163140949e+20*cos(theta)**46 + 2.0960485783974e+20*cos(theta)**44 - 2.86127266257423e+20*cos(theta)**42 + 3.17468526092321e+20*cos(theta)**40 - 2.89620409768433e+20*cos(theta)**38 + 2.18928116201299e+20*cos(theta)**36 - 1.37786926280538e+20*cos(theta)**34 + 7.23768404900579e+19*cos(theta)**32 - 3.17408601972314e+19*cos(theta)**30 + 1.1602751416635e+19*cos(theta)**28 - 3.52276308071328e+18*cos(theta)**26 + 8.83408951567759e+17*cos(theta)**24 - 1.81549419681833e+17*cos(theta)**22 + 3.02582366136388e+16*cos(theta)**20 - 4.03443154848518e+15*cos(theta)**18 + 422786319807008.0*cos(theta)**16 - 34027067992515.8*cos(theta)**14 + 2039830821685.73*cos(theta)**12 - 87364590675.7028*cos(theta)**10 + 2520132423.33758*cos(theta)**8 - 44802354.1926681*cos(theta)**6 + 423729.705479206*cos(theta)**4 - 1595.96875886707*cos(theta)**2 + 0.999980425355305

#@torch.jit.script
def Yl56_m1(theta, phi):
    return 0.0750616049607305*(1.0 - cos(theta)**2)**0.5*(3.03549442716167e+17*cos(theta)**55 - 4.06099930120278e+18*cos(theta)**53 + 2.56699864085203e+19*cos(theta)**51 - 1.01960226388983e+20*cos(theta)**49 + 2.85488633889151e+20*cos(theta)**47 - 5.99248957736257e+20*cos(theta)**45 + 9.78971069569133e+20*cos(theta)**43 - 1.27562896943857e+21*cos(theta)**41 + 1.34795844708715e+21*cos(theta)**39 - 1.16823065414219e+21*cos(theta)**37 + 8.36603887805054e+20*cos(theta)**35 - 4.97282031212794e+20*cos(theta)**33 + 2.45847296329921e+20*cos(theta)**31 - 1.01077800878349e+20*cos(theta)**29 + 3.44853673584957e+19*cos(theta)**27 - 9.72238067697348e+18*cos(theta)**25 + 2.25055108263275e+18*cos(theta)**23 - 4.23968297770727e+17*cos(theta)**21 + 6.42376208743525e+16*cos(theta)**19 - 7.7085145049223e+15*cos(theta)**17 + 718053405937968.0*cos(theta)**15 - 50567141263237.2*cos(theta)**13 + 2598311606411.4*cos(theta)**11 - 92736624498.7844*cos(theta)**9 + 2140075949.97195*cos(theta)**7 - 28534345.999626*cos(theta)**5 + 179913.90920319*cos(theta)**3 - 338.820921286611*cos(theta))*cos(phi)

#@torch.jit.script
def Yl56_m2(theta, phi):
    return 0.00132899242236692*(1.0 - cos(theta)**2)*(1.66952193493892e+19*cos(theta)**54 - 2.15232962963747e+20*cos(theta)**52 + 1.30916930683454e+21*cos(theta)**50 - 4.99605109306014e+21*cos(theta)**48 + 1.34179657927901e+22*cos(theta)**46 - 2.69662030981316e+22*cos(theta)**44 + 4.20957559914727e+22*cos(theta)**42 - 5.23007877469812e+22*cos(theta)**40 + 5.25703794363987e+22*cos(theta)**38 - 4.32245342032611e+22*cos(theta)**36 + 2.92811360731769e+22*cos(theta)**34 - 1.64103070300222e+22*cos(theta)**32 + 7.62126618622755e+21*cos(theta)**30 - 2.93125622547213e+21*cos(theta)**28 + 9.31104918679383e+20*cos(theta)**26 - 2.43059516924337e+20*cos(theta)**24 + 5.17626749005533e+19*cos(theta)**22 - 8.90333425318526e+18*cos(theta)**20 + 1.2205147966127e+18*cos(theta)**18 - 1.31044746583679e+17*cos(theta)**16 + 1.07708010890695e+16*cos(theta)**14 - 657372836422083.0*cos(theta)**12 + 28581427670525.4*cos(theta)**10 - 834629620489.06*cos(theta)**8 + 14980531649.8036*cos(theta)**6 - 142671729.99813*cos(theta)**4 + 539741.727609571*cos(theta)**2 - 338.820921286611)*cos(2*phi)

#@torch.jit.script
def Yl56_m3(theta, phi):
    return 2.35450501040714e-5*(1.0 - cos(theta)**2)**1.5*(9.01541844867017e+20*cos(theta)**53 - 1.11921140741149e+22*cos(theta)**51 + 6.54584653417268e+22*cos(theta)**49 - 2.39810452466887e+23*cos(theta)**47 + 6.17226426468345e+23*cos(theta)**45 - 1.18651293631779e+24*cos(theta)**43 + 1.76802175164185e+24*cos(theta)**41 - 2.09203150987925e+24*cos(theta)**39 + 1.99767441858315e+24*cos(theta)**37 - 1.5560832313174e+24*cos(theta)**35 + 9.95558626488014e+23*cos(theta)**33 - 5.25129824960711e+23*cos(theta)**31 + 2.28637985586826e+23*cos(theta)**29 - 8.20751743132197e+22*cos(theta)**27 + 2.4208727885664e+22*cos(theta)**25 - 5.83342840618409e+21*cos(theta)**23 + 1.13877884781217e+21*cos(theta)**21 - 1.78066685063705e+20*cos(theta)**19 + 2.19692663390286e+19*cos(theta)**17 - 2.09671594533887e+18*cos(theta)**15 + 1.50791215246973e+17*cos(theta)**13 - 7.888474037065e+15*cos(theta)**11 + 285814276705254.0*cos(theta)**9 - 6677036963912.48*cos(theta)**7 + 89883189898.8218*cos(theta)**5 - 570686919.992519*cos(theta)**3 + 1079483.45521914*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl56_m4(theta, phi):
    return 4.17528436271539e-7*(1.0 - cos(theta)**2)**2*(4.77817177779519e+22*cos(theta)**52 - 5.70797817779858e+23*cos(theta)**50 + 3.20746480174461e+24*cos(theta)**48 - 1.12710912659437e+25*cos(theta)**46 + 2.77751891910755e+25*cos(theta)**44 - 5.10200562616649e+25*cos(theta)**42 + 7.2488891817316e+25*cos(theta)**40 - 8.15892288852907e+25*cos(theta)**38 + 7.39139534875765e+25*cos(theta)**36 - 5.4462913096109e+25*cos(theta)**34 + 3.28534346741045e+25*cos(theta)**32 - 1.6279024573782e+25*cos(theta)**30 + 6.63050158201796e+24*cos(theta)**28 - 2.21602970645693e+24*cos(theta)**26 + 6.05218197141599e+23*cos(theta)**24 - 1.34168853342234e+23*cos(theta)**22 + 2.39143558040556e+22*cos(theta)**20 - 3.3832670162104e+21*cos(theta)**18 + 3.73477527763485e+20*cos(theta)**16 - 3.1450739180083e+19*cos(theta)**14 + 1.96028579821065e+18*cos(theta)**12 - 8.6773214407715e+16*cos(theta)**10 + 2.57232849034728e+15*cos(theta)**8 - 46739258747387.3*cos(theta)**6 + 449415949494.109*cos(theta)**4 - 1712060759.97756*cos(theta)**2 + 1079483.45521914)*cos(4*phi)

#@torch.jit.script
def Yl56_m5(theta, phi):
    return 7.41343475368955e-9*(1.0 - cos(theta)**2)**2.5*(2.4846493244535e+24*cos(theta)**51 - 2.85398908889929e+25*cos(theta)**49 + 1.53958310483741e+26*cos(theta)**47 - 5.18470198233409e+26*cos(theta)**45 + 1.22210832440732e+27*cos(theta)**43 - 2.14284236298993e+27*cos(theta)**41 + 2.89955567269264e+27*cos(theta)**39 - 3.10039069764105e+27*cos(theta)**37 + 2.66090232555275e+27*cos(theta)**35 - 1.85173904526771e+27*cos(theta)**33 + 1.05130990957134e+27*cos(theta)**31 - 4.88370737213461e+26*cos(theta)**29 + 1.85654044296503e+26*cos(theta)**27 - 5.76167723678802e+25*cos(theta)**25 + 1.45252367313984e+25*cos(theta)**23 - 2.95171477352915e+24*cos(theta)**21 + 4.78287116081112e+23*cos(theta)**19 - 6.08988062917872e+22*cos(theta)**17 + 5.97564044421577e+21*cos(theta)**15 - 4.40310348521162e+20*cos(theta)**13 + 2.35234295785278e+19*cos(theta)**11 - 8.6773214407715e+17*cos(theta)**9 + 2.05786279227783e+16*cos(theta)**7 - 280435552484324.0*cos(theta)**5 + 1797663797976.44*cos(theta)**3 - 3424121519.95512*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl56_m6(theta, phi):
    return 1.31837371843311e-10*(1.0 - cos(theta)**2)**3*(1.26717115547128e+26*cos(theta)**50 - 1.39845465356065e+27*cos(theta)**48 + 7.23604059273585e+27*cos(theta)**46 - 2.33311589205034e+28*cos(theta)**44 + 5.25506579495149e+28*cos(theta)**42 - 8.7856536882587e+28*cos(theta)**40 + 1.13082671235013e+29*cos(theta)**38 - 1.14714455812719e+29*cos(theta)**36 + 9.31315813943464e+28*cos(theta)**34 - 6.11073884938343e+28*cos(theta)**32 + 3.25906071967116e+28*cos(theta)**30 - 1.41627513791904e+28*cos(theta)**28 + 5.01265919600558e+27*cos(theta)**26 - 1.44041930919701e+27*cos(theta)**24 + 3.34080444822163e+26*cos(theta)**22 - 6.19860102441121e+25*cos(theta)**20 + 9.08745520554113e+24*cos(theta)**18 - 1.03527970696038e+24*cos(theta)**16 + 8.96346066632365e+22*cos(theta)**14 - 5.7240345307751e+21*cos(theta)**12 + 2.58757725363806e+20*cos(theta)**10 - 7.80958929669435e+18*cos(theta)**8 + 1.44050395459448e+17*cos(theta)**6 - 1.40217776242162e+15*cos(theta)**4 + 5392991393929.31*cos(theta)**2 - 3424121519.95512)*cos(6*phi)

#@torch.jit.script
def Yl56_m7(theta, phi):
    return 2.34900131528757e-12*(1.0 - cos(theta)**2)**3.5*(6.33585577735642e+27*cos(theta)**49 - 6.71258233709113e+28*cos(theta)**47 + 3.32857867265849e+29*cos(theta)**45 - 1.02657099250215e+30*cos(theta)**43 + 2.20712763387962e+30*cos(theta)**41 - 3.51426147530348e+30*cos(theta)**39 + 4.29714150693049e+30*cos(theta)**37 - 4.12972040925788e+30*cos(theta)**35 + 3.16647376740778e+30*cos(theta)**33 - 1.9554364318027e+30*cos(theta)**31 + 9.77718215901349e+29*cos(theta)**29 - 3.9655703861733e+29*cos(theta)**27 + 1.30329139096145e+29*cos(theta)**25 - 3.45700634207281e+28*cos(theta)**23 + 7.34976978608758e+27*cos(theta)**21 - 1.23972020488224e+27*cos(theta)**19 + 1.6357419369974e+26*cos(theta)**17 - 1.65644753113661e+25*cos(theta)**15 + 1.25488449328531e+24*cos(theta)**13 - 6.86884143693012e+22*cos(theta)**11 + 2.58757725363806e+21*cos(theta)**9 - 6.24767143735548e+19*cos(theta)**7 + 8.64302372756687e+17*cos(theta)**5 - 5.60871104968648e+15*cos(theta)**3 + 10785982787858.6*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl56_m8(theta, phi):
    return 4.19464520587065e-14*(1.0 - cos(theta)**2)**4*(3.10456933090465e+29*cos(theta)**48 - 3.15491369843283e+30*cos(theta)**46 + 1.49786040269632e+31*cos(theta)**44 - 4.41425526775925e+31*cos(theta)**42 + 9.04922329890646e+31*cos(theta)**40 - 1.37056197536836e+32*cos(theta)**38 + 1.58994235756428e+32*cos(theta)**36 - 1.44540214324026e+32*cos(theta)**34 + 1.04493634324457e+32*cos(theta)**32 - 6.06185293858836e+31*cos(theta)**30 + 2.83538282611391e+31*cos(theta)**28 - 1.07070400426679e+31*cos(theta)**26 + 3.25822847740363e+30*cos(theta)**24 - 7.95111458676747e+29*cos(theta)**22 + 1.54345165507839e+29*cos(theta)**20 - 2.35546838927626e+28*cos(theta)**18 + 2.78076129289559e+27*cos(theta)**16 - 2.48467129670492e+26*cos(theta)**14 + 1.6313498412709e+25*cos(theta)**12 - 7.55572558062314e+23*cos(theta)**10 + 2.32881952827425e+22*cos(theta)**8 - 4.37337000614883e+20*cos(theta)**6 + 4.32151186378343e+18*cos(theta)**4 - 1.68261331490594e+16*cos(theta)**2 + 10785982787858.6)*cos(8*phi)

#@torch.jit.script
def Yl56_m9(theta, phi):
    return 7.50961955810543e-16*(1.0 - cos(theta)**2)**4.5*(1.49019327883423e+31*cos(theta)**47 - 1.4512603012791e+32*cos(theta)**45 + 6.59058577186381e+32*cos(theta)**43 - 1.85398721245888e+33*cos(theta)**41 + 3.61968931956258e+33*cos(theta)**39 - 5.20813550639976e+33*cos(theta)**37 + 5.72379248723142e+33*cos(theta)**35 - 4.91436728701687e+33*cos(theta)**33 + 3.34379629838261e+33*cos(theta)**31 - 1.81855588157651e+33*cos(theta)**29 + 7.93907191311895e+32*cos(theta)**27 - 2.78383041109366e+32*cos(theta)**25 + 7.81974834576871e+31*cos(theta)**23 - 1.74924520908884e+31*cos(theta)**21 + 3.08690331015678e+30*cos(theta)**19 - 4.23984310069727e+29*cos(theta)**17 + 4.44921806863294e+28*cos(theta)**15 - 3.47853981538688e+27*cos(theta)**13 + 1.95761980952509e+26*cos(theta)**11 - 7.55572558062314e+24*cos(theta)**9 + 1.8630556226194e+23*cos(theta)**7 - 2.6240220036893e+21*cos(theta)**5 + 1.72860474551337e+19*cos(theta)**3 - 3.36522662981189e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl56_m10(theta, phi):
    return 1.34833261296548e-17*(1.0 - cos(theta)**2)**5*(7.00390841052088e+32*cos(theta)**46 - 6.53067135575596e+33*cos(theta)**44 + 2.83395188190144e+34*cos(theta)**42 - 7.60134757108143e+34*cos(theta)**40 + 1.41167883462941e+35*cos(theta)**38 - 1.92701013736791e+35*cos(theta)**36 + 2.003327370531e+35*cos(theta)**34 - 1.62174120471557e+35*cos(theta)**32 + 1.03657685249861e+35*cos(theta)**30 - 5.27381205657188e+34*cos(theta)**28 + 2.14354941654212e+34*cos(theta)**26 - 6.95957602773415e+33*cos(theta)**24 + 1.7985421195268e+33*cos(theta)**22 - 3.67341493908657e+32*cos(theta)**20 + 5.86511628929789e+31*cos(theta)**18 - 7.20773327118536e+30*cos(theta)**16 + 6.6738271029494e+29*cos(theta)**14 - 4.52210176000295e+28*cos(theta)**12 + 2.15338179047759e+27*cos(theta)**10 - 6.80015302256082e+25*cos(theta)**8 + 1.30413893583358e+24*cos(theta)**6 - 1.31201100184465e+22*cos(theta)**4 + 5.18581423654012e+19*cos(theta)**2 - 3.36522662981189e+16)*cos(10*phi)

#@torch.jit.script
def Yl56_m11(theta, phi):
    return 2.42873830296257e-19*(1.0 - cos(theta)**2)**5.5*(3.2217978688396e+34*cos(theta)**45 - 2.87349539653262e+35*cos(theta)**43 + 1.1902597903986e+36*cos(theta)**41 - 3.04053902843257e+36*cos(theta)**39 + 5.36437957159175e+36*cos(theta)**37 - 6.93723649452447e+36*cos(theta)**35 + 6.81131305980538e+36*cos(theta)**33 - 5.18957185508982e+36*cos(theta)**31 + 3.10973055749583e+36*cos(theta)**29 - 1.47666737584013e+36*cos(theta)**27 + 5.57322848300951e+35*cos(theta)**25 - 1.6702982466562e+35*cos(theta)**23 + 3.95679266295897e+34*cos(theta)**21 - 7.34682987817314e+33*cos(theta)**19 + 1.05572093207362e+33*cos(theta)**17 - 1.15323732338966e+32*cos(theta)**15 + 9.34335794412917e+30*cos(theta)**13 - 5.42652211200354e+29*cos(theta)**11 + 2.15338179047759e+28*cos(theta)**9 - 5.44012241804866e+26*cos(theta)**7 + 7.8248336150015e+24*cos(theta)**5 - 5.2480440073786e+22*cos(theta)**3 + 1.03716284730802e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl56_m12(theta, phi):
    return 4.39056093319479e-21*(1.0 - cos(theta)**2)**6*(1.44980904097782e+36*cos(theta)**44 - 1.23560302050903e+37*cos(theta)**42 + 4.88006514063427e+37*cos(theta)**40 - 1.1858102210887e+38*cos(theta)**38 + 1.98482044148895e+38*cos(theta)**36 - 2.42803277308357e+38*cos(theta)**34 + 2.24773330973578e+38*cos(theta)**32 - 1.60876727507784e+38*cos(theta)**30 + 9.01821861673791e+37*cos(theta)**28 - 3.98700191476834e+37*cos(theta)**26 + 1.39330712075238e+37*cos(theta)**24 - 3.84168596730925e+36*cos(theta)**22 + 8.30926459221383e+35*cos(theta)**20 - 1.3958976768529e+35*cos(theta)**18 + 1.79472558452515e+34*cos(theta)**16 - 1.72985598508449e+33*cos(theta)**14 + 1.21463653273679e+32*cos(theta)**12 - 5.96917432320389e+30*cos(theta)**10 + 1.93804361142983e+29*cos(theta)**8 - 3.80808569263406e+27*cos(theta)**6 + 3.91241680750075e+25*cos(theta)**4 - 1.57441320221358e+23*cos(theta)**2 + 1.03716284730802e+20)*cos(12*phi)

#@torch.jit.script
def Yl56_m13(theta, phi):
    return 7.96836327408424e-23*(1.0 - cos(theta)**2)**6.5*(6.37915978030242e+37*cos(theta)**43 - 5.18953268613791e+38*cos(theta)**41 + 1.95202605625371e+39*cos(theta)**39 - 4.50607884013707e+39*cos(theta)**37 + 7.14535358936021e+39*cos(theta)**35 - 8.25531142848413e+39*cos(theta)**33 + 7.19274659115449e+39*cos(theta)**31 - 4.82630182523353e+39*cos(theta)**29 + 2.52510121268661e+39*cos(theta)**27 - 1.03662049783977e+39*cos(theta)**25 + 3.3439370898057e+38*cos(theta)**23 - 8.45170912808035e+37*cos(theta)**21 + 1.66185291844277e+37*cos(theta)**19 - 2.51261581833522e+36*cos(theta)**17 + 2.87156093524025e+35*cos(theta)**15 - 2.42179837911828e+34*cos(theta)**13 + 1.45756383928415e+33*cos(theta)**11 - 5.96917432320389e+31*cos(theta)**9 + 1.55043488914387e+30*cos(theta)**7 - 2.28485141558044e+28*cos(theta)**5 + 1.5649667230003e+26*cos(theta)**3 - 3.14882640442716e+23*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl56_m14(theta, phi):
    return 1.45239878642533e-24*(1.0 - cos(theta)**2)**7*(2.74303870553004e+39*cos(theta)**42 - 2.12770840131654e+40*cos(theta)**40 + 7.61290161938947e+40*cos(theta)**38 - 1.66724917085072e+41*cos(theta)**36 + 2.50087375627607e+41*cos(theta)**34 - 2.72425277139976e+41*cos(theta)**32 + 2.22975144325789e+41*cos(theta)**30 - 1.39962752931772e+41*cos(theta)**28 + 6.81777327425386e+40*cos(theta)**26 - 2.59155124459942e+40*cos(theta)**24 + 7.69105530655312e+39*cos(theta)**22 - 1.77485891689687e+39*cos(theta)**20 + 3.15752054504125e+38*cos(theta)**18 - 4.27144689116987e+37*cos(theta)**16 + 4.30734140286037e+36*cos(theta)**14 - 3.14833789285376e+35*cos(theta)**12 + 1.60332022321257e+34*cos(theta)**10 - 5.3722568908835e+32*cos(theta)**8 + 1.08530442240071e+31*cos(theta)**6 - 1.14242570779022e+29*cos(theta)**4 + 4.6949001690009e+26*cos(theta)**2 - 3.14882640442716e+23)*cos(14*phi)

#@torch.jit.script
def Yl56_m15(theta, phi):
    return 2.65969635312837e-26*(1.0 - cos(theta)**2)**7.5*(1.15207625632262e+41*cos(theta)**41 - 8.51083360526618e+41*cos(theta)**39 + 2.892902615368e+42*cos(theta)**37 - 6.00209701506258e+42*cos(theta)**35 + 8.50297077133865e+42*cos(theta)**33 - 8.71760886847924e+42*cos(theta)**31 + 6.68925432977367e+42*cos(theta)**29 - 3.91895708208963e+42*cos(theta)**27 + 1.772621051306e+42*cos(theta)**25 - 6.21972298703861e+41*cos(theta)**23 + 1.69203216744169e+41*cos(theta)**21 - 3.54971783379375e+40*cos(theta)**19 + 5.68353698107426e+39*cos(theta)**17 - 6.83431502587179e+38*cos(theta)**15 + 6.03027796400452e+37*cos(theta)**13 - 3.77800547142452e+36*cos(theta)**11 + 1.60332022321257e+35*cos(theta)**9 - 4.2978055127068e+33*cos(theta)**7 + 6.51182653440424e+31*cos(theta)**5 - 4.56970283116087e+29*cos(theta)**3 + 9.38980033800179e+26*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl56_m16(theta, phi):
    return 4.8952387861945e-28*(1.0 - cos(theta)**2)**8*(4.72351265092273e+42*cos(theta)**40 - 3.31922510605381e+43*cos(theta)**38 + 1.07037396768616e+44*cos(theta)**36 - 2.1007339552719e+44*cos(theta)**34 + 2.80598035454175e+44*cos(theta)**32 - 2.70245874922856e+44*cos(theta)**30 + 1.93988375563437e+44*cos(theta)**28 - 1.0581184121642e+44*cos(theta)**26 + 4.43155262826501e+43*cos(theta)**24 - 1.43053628701888e+43*cos(theta)**22 + 3.55326755162754e+42*cos(theta)**20 - 6.74446388420812e+41*cos(theta)**18 + 9.66201286782624e+40*cos(theta)**16 - 1.02514725388077e+40*cos(theta)**14 + 7.83936135320587e+38*cos(theta)**12 - 4.15580601856697e+37*cos(theta)**10 + 1.44298820089131e+36*cos(theta)**8 - 3.00846385889476e+34*cos(theta)**6 + 3.25591326720212e+32*cos(theta)**4 - 1.37091084934826e+30*cos(theta)**2 + 9.38980033800179e+26)*cos(16*phi)

#@torch.jit.script
def Yl56_m17(theta, phi):
    return 9.05904580347145e-30*(1.0 - cos(theta)**2)**8.5*(1.88940506036909e+44*cos(theta)**39 - 1.26130554030045e+45*cos(theta)**37 + 3.85334628367017e+45*cos(theta)**35 - 7.14249544792447e+45*cos(theta)**33 + 8.97913713453361e+45*cos(theta)**31 - 8.10737624768569e+45*cos(theta)**29 + 5.43167451577622e+45*cos(theta)**27 - 2.75110787162692e+45*cos(theta)**25 + 1.0635726307836e+45*cos(theta)**23 - 3.14717983144154e+44*cos(theta)**21 + 7.10653510325508e+43*cos(theta)**19 - 1.21400349915746e+43*cos(theta)**17 + 1.5459220588522e+42*cos(theta)**15 - 1.43520615543308e+41*cos(theta)**13 + 9.40723362384705e+39*cos(theta)**11 - 4.15580601856697e+38*cos(theta)**9 + 1.15439056071305e+37*cos(theta)**7 - 1.80507831533686e+35*cos(theta)**5 + 1.30236530688085e+33*cos(theta)**3 - 2.74182169869652e+30*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl56_m18(theta, phi):
    return 1.6862978726266e-31*(1.0 - cos(theta)**2)**9*(7.36867973543946e+45*cos(theta)**38 - 4.66683049911165e+46*cos(theta)**36 + 1.34867119928456e+47*cos(theta)**34 - 2.35702349781507e+47*cos(theta)**32 + 2.78353251170542e+47*cos(theta)**30 - 2.35113911182885e+47*cos(theta)**28 + 1.46655211925958e+47*cos(theta)**26 - 6.87776967906729e+46*cos(theta)**24 + 2.44621705080229e+46*cos(theta)**22 - 6.60907764602723e+45*cos(theta)**20 + 1.35024166961847e+45*cos(theta)**18 - 2.06380594856768e+44*cos(theta)**16 + 2.3188830882783e+43*cos(theta)**14 - 1.865768002063e+42*cos(theta)**12 + 1.03479569862318e+41*cos(theta)**10 - 3.74022541671027e+39*cos(theta)**8 + 8.08073392499133e+37*cos(theta)**6 - 9.02539157668428e+35*cos(theta)**4 + 3.90709592064255e+33*cos(theta)**2 - 2.74182169869652e+30)*cos(18*phi)

#@torch.jit.script
def Yl56_m19(theta, phi):
    return 3.15872532320494e-33*(1.0 - cos(theta)**2)**9.5*(2.80009829946699e+47*cos(theta)**37 - 1.6800589796802e+48*cos(theta)**35 + 4.58548207756751e+48*cos(theta)**33 - 7.54247519300824e+48*cos(theta)**31 + 8.35059753511626e+48*cos(theta)**29 - 6.58318951312078e+48*cos(theta)**27 + 3.81303551007491e+48*cos(theta)**25 - 1.65066472297615e+48*cos(theta)**23 + 5.38167751176503e+47*cos(theta)**21 - 1.32181552920545e+47*cos(theta)**19 + 2.43043500531324e+46*cos(theta)**17 - 3.3020895177083e+45*cos(theta)**15 + 3.24643632358962e+44*cos(theta)**13 - 2.2389216024756e+43*cos(theta)**11 + 1.03479569862318e+42*cos(theta)**9 - 2.99218033336822e+40*cos(theta)**7 + 4.8484403549948e+38*cos(theta)**5 - 3.61015663067371e+36*cos(theta)**3 + 7.81419184128509e+33*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl56_m20(theta, phi):
    return 5.95667909530459e-35*(1.0 - cos(theta)**2)**10*(1.03603637080279e+49*cos(theta)**36 - 5.88020642888069e+49*cos(theta)**34 + 1.51320908559728e+50*cos(theta)**32 - 2.33816730983255e+50*cos(theta)**30 + 2.42167328518372e+50*cos(theta)**28 - 1.77746116854261e+50*cos(theta)**26 + 9.53258877518727e+49*cos(theta)**24 - 3.79652886284515e+49*cos(theta)**22 + 1.13015227747066e+49*cos(theta)**20 - 2.51144950549035e+48*cos(theta)**18 + 4.1317395090325e+47*cos(theta)**16 - 4.95313427656244e+46*cos(theta)**14 + 4.2203672206665e+45*cos(theta)**12 - 2.46281376272316e+44*cos(theta)**10 + 9.31316128760858e+42*cos(theta)**8 - 2.09452623335775e+41*cos(theta)**6 + 2.4242201774974e+39*cos(theta)**4 - 1.08304698920211e+37*cos(theta)**2 + 7.81419184128509e+33)*cos(20*phi)

#@torch.jit.script
def Yl56_m21(theta, phi):
    return 1.13137763914331e-36*(1.0 - cos(theta)**2)**10.5*(3.72973093489003e+50*cos(theta)**35 - 1.99927018581943e+51*cos(theta)**33 + 4.84226907391129e+51*cos(theta)**31 - 7.01450192949766e+51*cos(theta)**29 + 6.7806851985144e+51*cos(theta)**27 - 4.62139903821079e+51*cos(theta)**25 + 2.28782130604494e+51*cos(theta)**23 - 8.35236349825932e+50*cos(theta)**21 + 2.26030455494131e+50*cos(theta)**19 - 4.52060910988262e+49*cos(theta)**17 + 6.61078321445201e+48*cos(theta)**15 - 6.93438798718742e+47*cos(theta)**13 + 5.0644406647998e+46*cos(theta)**11 - 2.46281376272316e+45*cos(theta)**9 + 7.45052903008686e+43*cos(theta)**7 - 1.25671574001465e+42*cos(theta)**5 + 9.69688070998959e+39*cos(theta)**3 - 2.16609397840423e+37*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl56_m22(theta, phi):
    return 2.16534084176182e-38*(1.0 - cos(theta)**2)**11*(1.30540582721151e+52*cos(theta)**34 - 6.59759161320413e+52*cos(theta)**32 + 1.5011034129125e+53*cos(theta)**30 - 2.03420555955432e+53*cos(theta)**28 + 1.83078500359889e+53*cos(theta)**26 - 1.1553497595527e+53*cos(theta)**24 + 5.26198900390337e+52*cos(theta)**22 - 1.75399633463446e+52*cos(theta)**20 + 4.29457865438849e+51*cos(theta)**18 - 7.68503548680046e+50*cos(theta)**16 + 9.91617482167801e+49*cos(theta)**14 - 9.01470438334365e+48*cos(theta)**12 + 5.57088473127978e+47*cos(theta)**10 - 2.21653238645084e+46*cos(theta)**8 + 5.2153703210608e+44*cos(theta)**6 - 6.28357870007326e+42*cos(theta)**4 + 2.90906421299688e+40*cos(theta)**2 - 2.16609397840423e+37)*cos(22*phi)

#@torch.jit.script
def Yl56_m23(theta, phi):
    return 4.17804644315597e-40*(1.0 - cos(theta)**2)**11.5*(4.43837981251914e+53*cos(theta)**33 - 2.11122931622532e+54*cos(theta)**31 + 4.5033102387375e+54*cos(theta)**29 - 5.6957755667521e+54*cos(theta)**27 + 4.76004100935711e+54*cos(theta)**25 - 2.77283942292647e+54*cos(theta)**23 + 1.15763758085874e+54*cos(theta)**21 - 3.50799266926891e+53*cos(theta)**19 + 7.73024157789928e+52*cos(theta)**17 - 1.22960567788807e+52*cos(theta)**15 + 1.38826447503492e+51*cos(theta)**13 - 1.08176452600124e+50*cos(theta)**11 + 5.57088473127978e+48*cos(theta)**9 - 1.77322590916067e+47*cos(theta)**7 + 3.12922219263648e+45*cos(theta)**5 - 2.5134314800293e+43*cos(theta)**3 + 5.81812842599376e+40*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl56_m24(theta, phi):
    return 8.13151186163682e-42*(1.0 - cos(theta)**2)**12*(1.46466533813132e+55*cos(theta)**32 - 6.5448108802985e+55*cos(theta)**30 + 1.30595996923387e+56*cos(theta)**28 - 1.53785940302307e+56*cos(theta)**26 + 1.19001025233928e+56*cos(theta)**24 - 6.37753067273089e+55*cos(theta)**22 + 2.43103891980336e+55*cos(theta)**20 - 6.66518607161094e+54*cos(theta)**18 + 1.31414106824288e+54*cos(theta)**16 - 1.84440851683211e+53*cos(theta)**14 + 1.8047438175454e+52*cos(theta)**12 - 1.18994097860136e+51*cos(theta)**10 + 5.0137962581518e+49*cos(theta)**8 - 1.24125813641247e+48*cos(theta)**6 + 1.56461109631824e+46*cos(theta)**4 - 7.54029444008791e+43*cos(theta)**2 + 5.81812842599376e+40)*cos(24*phi)

#@torch.jit.script
def Yl56_m25(theta, phi):
    return 1.59717977185062e-43*(1.0 - cos(theta)**2)**12.5*(4.68692908202021e+56*cos(theta)**31 - 1.96344326408955e+57*cos(theta)**29 + 3.65668791385485e+57*cos(theta)**27 - 3.99843444785997e+57*cos(theta)**25 + 2.85602460561427e+57*cos(theta)**23 - 1.4030567480008e+57*cos(theta)**21 + 4.86207783960672e+56*cos(theta)**19 - 1.19973349288997e+56*cos(theta)**17 + 2.10262570918861e+55*cos(theta)**15 - 2.58217192356495e+54*cos(theta)**13 + 2.16569258105448e+53*cos(theta)**11 - 1.18994097860136e+52*cos(theta)**9 + 4.01103700652144e+50*cos(theta)**7 - 7.44754881847483e+48*cos(theta)**5 + 6.25844438527296e+46*cos(theta)**3 - 1.50805888801758e+44*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl56_m26(theta, phi):
    return 3.16786034981711e-45*(1.0 - cos(theta)**2)**13*(1.45294801542627e+58*cos(theta)**30 - 5.69398546585969e+58*cos(theta)**28 + 9.87305736740809e+58*cos(theta)**26 - 9.99608611964993e+58*cos(theta)**24 + 6.56885659291281e+58*cos(theta)**22 - 2.94641917080167e+58*cos(theta)**20 + 9.23794789525276e+57*cos(theta)**18 - 2.03954693791295e+57*cos(theta)**16 + 3.15393856378291e+56*cos(theta)**14 - 3.35682350063444e+55*cos(theta)**12 + 2.38226183915993e+54*cos(theta)**10 - 1.07094688074123e+53*cos(theta)**8 + 2.80772590456501e+51*cos(theta)**6 - 3.72377440923741e+49*cos(theta)**4 + 1.87753331558189e+47*cos(theta)**2 - 1.50805888801758e+44)*cos(26*phi)

#@torch.jit.script
def Yl56_m27(theta, phi):
    return 6.3484302825172e-47*(1.0 - cos(theta)**2)**13.5*(4.3588440462788e+59*cos(theta)**29 - 1.59431593044071e+60*cos(theta)**27 + 2.5669949155261e+60*cos(theta)**25 - 2.39906066871598e+60*cos(theta)**23 + 1.44514845044082e+60*cos(theta)**21 - 5.89283834160334e+59*cos(theta)**19 + 1.6628306211455e+59*cos(theta)**17 - 3.26327510066072e+58*cos(theta)**15 + 4.41551398929607e+57*cos(theta)**13 - 4.02818820076133e+56*cos(theta)**11 + 2.38226183915993e+55*cos(theta)**9 - 8.5675750459298e+53*cos(theta)**7 + 1.68463554273901e+52*cos(theta)**5 - 1.48950976369497e+50*cos(theta)**3 + 3.75506663116378e+47*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl56_m28(theta, phi):
    return 1.28625688551428e-48*(1.0 - cos(theta)**2)**14*(1.26406477342085e+61*cos(theta)**28 - 4.30465301218993e+61*cos(theta)**26 + 6.41748728881526e+61*cos(theta)**24 - 5.51783953804676e+61*cos(theta)**22 + 3.03481174592572e+61*cos(theta)**20 - 1.11963928490463e+61*cos(theta)**18 + 2.82681205594734e+60*cos(theta)**16 - 4.89491265099107e+59*cos(theta)**14 + 5.74016818608489e+58*cos(theta)**12 - 4.43100702083746e+57*cos(theta)**10 + 2.14403565524393e+56*cos(theta)**8 - 5.99730253215086e+54*cos(theta)**6 + 8.42317771369503e+52*cos(theta)**4 - 4.4685292910849e+50*cos(theta)**2 + 3.75506663116378e+47)*cos(28*phi)

#@torch.jit.script
def Yl56_m29(theta, phi):
    return 2.63656956230268e-50*(1.0 - cos(theta)**2)**14.5*(3.53938136557838e+62*cos(theta)**27 - 1.11920978316938e+63*cos(theta)**25 + 1.54019694931566e+63*cos(theta)**23 - 1.21392469837029e+63*cos(theta)**21 + 6.06962349185144e+62*cos(theta)**19 - 2.01535071282834e+62*cos(theta)**17 + 4.52289928951575e+61*cos(theta)**15 - 6.8528777113875e+60*cos(theta)**13 + 6.88820182330187e+59*cos(theta)**11 - 4.43100702083746e+58*cos(theta)**9 + 1.71522852419515e+57*cos(theta)**7 - 3.59838151929052e+55*cos(theta)**5 + 3.36927108547801e+53*cos(theta)**3 - 8.93705858216979e+50*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl56_m30(theta, phi):
    return 5.47152170526167e-52*(1.0 - cos(theta)**2)**15*(9.55632968706164e+63*cos(theta)**26 - 2.79802445792345e+64*cos(theta)**24 + 3.54245298342602e+64*cos(theta)**22 - 2.5492418665776e+64*cos(theta)**20 + 1.15322846345177e+64*cos(theta)**18 - 3.42609621180818e+63*cos(theta)**16 + 6.78434893427363e+62*cos(theta)**14 - 8.90874102480375e+61*cos(theta)**12 + 7.57702200563206e+60*cos(theta)**10 - 3.98790631875371e+59*cos(theta)**8 + 1.2006599669366e+58*cos(theta)**6 - 1.79919075964526e+56*cos(theta)**4 + 1.0107813256434e+54*cos(theta)**2 - 8.93705858216979e+50)*cos(30*phi)

#@torch.jit.script
def Yl56_m31(theta, phi):
    return 1.15043431177514e-53*(1.0 - cos(theta)**2)**15.5*(2.48464571863603e+65*cos(theta)**25 - 6.71525869901629e+65*cos(theta)**23 + 7.79339656353725e+65*cos(theta)**21 - 5.09848373315521e+65*cos(theta)**19 + 2.07581123421319e+65*cos(theta)**17 - 5.48175393889309e+64*cos(theta)**15 + 9.49808850798308e+63*cos(theta)**13 - 1.06904892297645e+63*cos(theta)**11 + 7.57702200563206e+61*cos(theta)**9 - 3.19032505500297e+60*cos(theta)**7 + 7.20395980161961e+58*cos(theta)**5 - 7.19676303858103e+56*cos(theta)**3 + 2.02156265128681e+54*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl56_m32(theta, phi):
    return 2.45273419390533e-55*(1.0 - cos(theta)**2)**16*(6.21161429659006e+66*cos(theta)**24 - 1.54450950077375e+67*cos(theta)**22 + 1.63661327834282e+67*cos(theta)**20 - 9.6871190929949e+66*cos(theta)**18 + 3.52887909816243e+66*cos(theta)**16 - 8.22263090833964e+65*cos(theta)**14 + 1.2347515060378e+65*cos(theta)**12 - 1.1759538152741e+64*cos(theta)**10 + 6.81931980506885e+62*cos(theta)**8 - 2.23322753850208e+61*cos(theta)**6 + 3.60197990080981e+59*cos(theta)**4 - 2.15902891157431e+57*cos(theta)**2 + 2.02156265128681e+54)*cos(32*phi)

#@torch.jit.script
def Yl56_m33(theta, phi):
    return 5.30700945659949e-57*(1.0 - cos(theta)**2)**16.5*(1.49078743118162e+68*cos(theta)**23 - 3.39792090170224e+68*cos(theta)**21 + 3.27322655668564e+68*cos(theta)**19 - 1.74368143673908e+68*cos(theta)**17 + 5.64620655705988e+67*cos(theta)**15 - 1.15116832716755e+67*cos(theta)**13 + 1.48170180724536e+66*cos(theta)**11 - 1.1759538152741e+65*cos(theta)**9 + 5.45545584405508e+63*cos(theta)**7 - 1.33993652310125e+62*cos(theta)**5 + 1.44079196032392e+60*cos(theta)**3 - 4.31805782314862e+57*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl56_m34(theta, phi):
    return 1.16644613593616e-58*(1.0 - cos(theta)**2)**17*(3.42881109171772e+69*cos(theta)**22 - 7.1356338935747e+69*cos(theta)**20 + 6.21913045770272e+69*cos(theta)**18 - 2.96425844245644e+69*cos(theta)**16 + 8.46930983558983e+68*cos(theta)**14 - 1.49651882531781e+68*cos(theta)**12 + 1.6298719879699e+67*cos(theta)**10 - 1.05835843374669e+66*cos(theta)**8 + 3.81881909083856e+64*cos(theta)**6 - 6.69968261550624e+62*cos(theta)**4 + 4.32237588097177e+60*cos(theta)**2 - 4.31805782314862e+57)*cos(34*phi)

#@torch.jit.script
def Yl56_m35(theta, phi):
    return 2.60694970289965e-60*(1.0 - cos(theta)**2)**17.5*(7.54338440177897e+70*cos(theta)**21 - 1.42712677871494e+71*cos(theta)**19 + 1.11944348238649e+71*cos(theta)**17 - 4.7428135079303e+70*cos(theta)**15 + 1.18570337698258e+70*cos(theta)**13 - 1.79582259038138e+69*cos(theta)**11 + 1.6298719879699e+68*cos(theta)**9 - 8.46686746997349e+66*cos(theta)**7 + 2.29129145450313e+65*cos(theta)**5 - 2.6798730462025e+63*cos(theta)**3 + 8.64475176194354e+60*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl56_m36(theta, phi):
    return 5.93101593907904e-62*(1.0 - cos(theta)**2)**18*(1.58411072437358e+72*cos(theta)**20 - 2.71154087955839e+72*cos(theta)**18 + 1.90305392005703e+72*cos(theta)**16 - 7.11422026189545e+71*cos(theta)**14 + 1.54141439007735e+71*cos(theta)**12 - 1.97540484941951e+70*cos(theta)**10 + 1.46688478917291e+69*cos(theta)**8 - 5.92680722898144e+67*cos(theta)**6 + 1.14564572725157e+66*cos(theta)**4 - 8.03961913860749e+63*cos(theta)**2 + 8.64475176194354e+60)*cos(36*phi)

#@torch.jit.script
def Yl56_m37(theta, phi):
    return 1.37522139116224e-63*(1.0 - cos(theta)**2)**18.5*(3.16822144874717e+73*cos(theta)**19 - 4.8807735832051e+73*cos(theta)**17 + 3.04488627209125e+73*cos(theta)**15 - 9.95990836665363e+72*cos(theta)**13 + 1.84969726809282e+72*cos(theta)**11 - 1.97540484941951e+71*cos(theta)**9 + 1.17350783133833e+70*cos(theta)**7 - 3.55608433738886e+68*cos(theta)**5 + 4.58258290900627e+66*cos(theta)**3 - 1.6079238277215e+64*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl56_m38(theta, phi):
    return 3.25410746963115e-65*(1.0 - cos(theta)**2)**19*(6.01962075261962e+74*cos(theta)**18 - 8.29731509144867e+74*cos(theta)**16 + 4.56732940813688e+74*cos(theta)**14 - 1.29478808766497e+74*cos(theta)**12 + 2.0346669949021e+73*cos(theta)**10 - 1.77786436447756e+72*cos(theta)**8 + 8.21455481936828e+70*cos(theta)**6 - 1.77804216869443e+69*cos(theta)**4 + 1.37477487270188e+67*cos(theta)**2 - 1.6079238277215e+64)*cos(38*phi)

#@torch.jit.script
def Yl56_m39(theta, phi):
    return 7.86925894840995e-67*(1.0 - cos(theta)**2)**19.5*(1.08353173547153e+76*cos(theta)**17 - 1.32757041463179e+76*cos(theta)**15 + 6.39426117139163e+75*cos(theta)**13 - 1.55374570519797e+75*cos(theta)**11 + 2.0346669949021e+74*cos(theta)**9 - 1.42229149158205e+73*cos(theta)**7 + 4.92873289162097e+71*cos(theta)**5 - 7.11216867477773e+69*cos(theta)**3 + 2.74954974540376e+67*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl56_m40(theta, phi):
    return 1.94793185320383e-68*(1.0 - cos(theta)**2)**20*(1.8420039503016e+77*cos(theta)**16 - 1.99135562194768e+77*cos(theta)**14 + 8.31253952280912e+76*cos(theta)**12 - 1.70912027571776e+76*cos(theta)**10 + 1.83120029541189e+75*cos(theta)**8 - 9.95604044107435e+73*cos(theta)**6 + 2.46436644581048e+72*cos(theta)**4 - 2.13365060243332e+70*cos(theta)**2 + 2.74954974540376e+67)*cos(40*phi)

#@torch.jit.script
def Yl56_m41(theta, phi):
    return 4.94456284273033e-70*(1.0 - cos(theta)**2)**20.5*(2.94720632048257e+78*cos(theta)**15 - 2.78789787072675e+78*cos(theta)**13 + 9.97504742737095e+77*cos(theta)**11 - 1.70912027571776e+77*cos(theta)**9 + 1.46496023632951e+76*cos(theta)**7 - 5.97362426464461e+74*cos(theta)**5 + 9.85746578324193e+72*cos(theta)**3 - 4.26730120486664e+70*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl56_m42(theta, phi):
    return 1.2896421933168e-71*(1.0 - cos(theta)**2)**21*(4.42080948072385e+79*cos(theta)**14 - 3.62426723194478e+79*cos(theta)**12 + 1.0972552170108e+79*cos(theta)**10 - 1.53820824814599e+78*cos(theta)**8 + 1.02547216543066e+77*cos(theta)**6 - 2.98681213232231e+75*cos(theta)**4 + 2.95723973497258e+73*cos(theta)**2 - 4.26730120486664e+70)*cos(42*phi)

#@torch.jit.script
def Yl56_m43(theta, phi):
    return 3.46407764916911e-73*(1.0 - cos(theta)**2)**21.5*(6.18913327301339e+80*cos(theta)**13 - 4.34912067833373e+80*cos(theta)**11 + 1.0972552170108e+80*cos(theta)**9 - 1.23056659851679e+79*cos(theta)**7 + 6.15283299258395e+77*cos(theta)**5 - 1.19472485292892e+76*cos(theta)**3 + 5.91447946994516e+73*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl56_m44(theta, phi):
    return 9.60762275866768e-75*(1.0 - cos(theta)**2)**22*(8.04587325491741e+81*cos(theta)**12 - 4.78403274616711e+81*cos(theta)**10 + 9.87529695309724e+80*cos(theta)**8 - 8.61396618961753e+79*cos(theta)**6 + 3.07641649629197e+78*cos(theta)**4 - 3.58417455878677e+76*cos(theta)**2 + 5.91447946994516e+73)*cos(44*phi)

#@torch.jit.script
def Yl56_m45(theta, phi):
    return 2.75971753039989e-76*(1.0 - cos(theta)**2)**22.5*(9.65504790590089e+82*cos(theta)**11 - 4.78403274616711e+82*cos(theta)**9 + 7.90023756247779e+81*cos(theta)**7 - 5.16837971377052e+80*cos(theta)**5 + 1.23056659851679e+79*cos(theta)**3 - 7.16834911757353e+76*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl56_m46(theta, phi):
    return 8.23888050279663e-78*(1.0 - cos(theta)**2)**23*(1.0620552696491e+84*cos(theta)**10 - 4.3056294715504e+83*cos(theta)**8 + 5.53016629373445e+82*cos(theta)**6 - 2.58418985688526e+81*cos(theta)**4 + 3.69169979555037e+79*cos(theta)**2 - 7.16834911757353e+76)*cos(46*phi)

#@torch.jit.script
def Yl56_m47(theta, phi):
    return 2.56714022331303e-79*(1.0 - cos(theta)**2)**23.5*(1.0620552696491e+85*cos(theta)**9 - 3.44450357724032e+84*cos(theta)**7 + 3.31809977624067e+83*cos(theta)**5 - 1.0336759427541e+82*cos(theta)**3 + 7.38339959110074e+79*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl56_m48(theta, phi):
    return 8.39096031589878e-81*(1.0 - cos(theta)**2)**24*(9.55849742684188e+85*cos(theta)**8 - 2.41115250406822e+85*cos(theta)**6 + 1.65904988812034e+84*cos(theta)**4 - 3.10102782826231e+82*cos(theta)**2 + 7.38339959110074e+79)*cos(48*phi)

#@torch.jit.script
def Yl56_m49(theta, phi):
    return 2.8951563619051e-82*(1.0 - cos(theta)**2)**24.5*(7.6467979414735e+86*cos(theta)**7 - 1.44669150244093e+86*cos(theta)**5 + 6.63619955248134e+84*cos(theta)**3 - 6.20205565652462e+82*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl56_m50(theta, phi):
    return 1.06284533692648e-83*(1.0 - cos(theta)**2)**25*(5.35275855903145e+87*cos(theta)**6 - 7.23345751220467e+86*cos(theta)**4 + 1.9908598657444e+85*cos(theta)**2 - 6.20205565652462e+82)*cos(50*phi)

#@torch.jit.script
def Yl56_m51(theta, phi):
    return 4.19471595031622e-85*(1.0 - cos(theta)**2)**25.5*(3.21165513541887e+88*cos(theta)**5 - 2.89338300488187e+87*cos(theta)**3 + 3.98171973148881e+85*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl56_m52(theta, phi):
    return 1.80511833529393e-86*(1.0 - cos(theta)**2)**26*(1.60582756770944e+89*cos(theta)**4 - 8.6801490146456e+87*cos(theta)**2 + 3.98171973148881e+85)*cos(52*phi)

#@torch.jit.script
def Yl56_m53(theta, phi):
    return 8.64494894739585e-88*(1.0 - cos(theta)**2)**26.5*(6.42331027083774e+89*cos(theta)**3 - 1.73602980292912e+88*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl56_m54(theta, phi):
    return 4.75888777122505e-89*(1.0 - cos(theta)**2)**27*(1.92699308125132e+90*cos(theta)**2 - 1.73602980292912e+88)*cos(54*phi)

#@torch.jit.script
def Yl56_m55(theta, phi):
    return 12.3094635524179*(1.0 - cos(theta)**2)**27.5*cos(55*phi)*cos(theta)

#@torch.jit.script
def Yl56_m56(theta, phi):
    return 1.16313497615398*(1.0 - cos(theta)**2)**28*cos(56*phi)

#@torch.jit.script
def Yl57_m_minus_57(theta, phi):
    return 1.16822530671551*(1.0 - cos(theta)**2)**28.5*sin(57*phi)

#@torch.jit.script
def Yl57_m_minus_56(theta, phi):
    return 12.4732330158048*(1.0 - cos(theta)**2)**28*sin(56*phi)*cos(theta)

#@torch.jit.script
def Yl57_m_minus_55(theta, phi):
    return 4.30570885965518e-91*(1.0 - cos(theta)**2)**27.5*(2.17750218181399e+92*cos(theta)**2 - 1.92699308125132e+90)*sin(55*phi)

#@torch.jit.script
def Yl57_m_minus_54(theta, phi):
    return 7.89249470792474e-90*(1.0 - cos(theta)**2)**27*(7.25834060604665e+91*cos(theta)**3 - 1.92699308125132e+90*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl57_m_minus_53(theta, phi):
    return 1.66305182977835e-88*(1.0 - cos(theta)**2)**26.5*(1.81458515151166e+91*cos(theta)**4 - 9.63496540625661e+89*cos(theta)**2 + 4.3400745073228e+87)*sin(53*phi)

#@torch.jit.script
def Yl57_m_minus_52(theta, phi):
    return 3.90020225589779e-87*(1.0 - cos(theta)**2)**26*(3.62917030302332e+90*cos(theta)**5 - 3.21165513541887e+89*cos(theta)**3 + 4.3400745073228e+87*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl57_m_minus_51(theta, phi):
    return 9.97415248256175e-86*(1.0 - cos(theta)**2)**25.5*(6.04861717170554e+89*cos(theta)**6 - 8.02913783854718e+88*cos(theta)**4 + 2.1700372536614e+87*cos(theta)**2 - 6.63619955248134e+84)*sin(51*phi)

#@torch.jit.script
def Yl57_m_minus_50(theta, phi):
    return 2.74243852466226e-84*(1.0 - cos(theta)**2)**25*(8.64088167386506e+88*cos(theta)**7 - 1.60582756770944e+88*cos(theta)**5 + 7.23345751220467e+86*cos(theta)**3 - 6.63619955248134e+84*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl57_m_minus_49(theta, phi):
    return 8.02368339149063e-83*(1.0 - cos(theta)**2)**24.5*(1.08011020923313e+88*cos(theta)**8 - 2.67637927951573e+87*cos(theta)**6 + 1.80836437805117e+86*cos(theta)**4 - 3.31809977624067e+84*cos(theta)**2 + 7.75256957065578e+81)*sin(49*phi)

#@torch.jit.script
def Yl57_m_minus_48(theta, phi):
    return 2.47826629701503e-81*(1.0 - cos(theta)**2)**24*(1.20012245470348e+87*cos(theta)**9 - 3.82339897073675e+86*cos(theta)**7 + 3.61672875610233e+85*cos(theta)**5 - 1.10603325874689e+84*cos(theta)**3 + 7.75256957065578e+81*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl57_m_minus_47(theta, phi):
    return 8.03050062627893e-80*(1.0 - cos(theta)**2)**23.5*(1.20012245470348e+86*cos(theta)**10 - 4.77924871342094e+85*cos(theta)**8 + 6.02788126017056e+84*cos(theta)**6 - 2.76508314686723e+83*cos(theta)**4 + 3.87628478532789e+81*cos(theta)**2 - 7.38339959110074e+78)*sin(47*phi)

#@torch.jit.script
def Yl57_m_minus_46(theta, phi):
    return 2.71616177193322e-78*(1.0 - cos(theta)**2)**23*(1.0910204133668e+85*cos(theta)**11 - 5.31027634824549e+84*cos(theta)**9 + 8.61125894310079e+83*cos(theta)**7 - 5.53016629373445e+82*cos(theta)**5 + 1.29209492844263e+81*cos(theta)**3 - 7.38339959110074e+78*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl57_m_minus_45(theta, phi):
    return 9.54915335374865e-77*(1.0 - cos(theta)**2)**22.5*(9.09183677805667e+83*cos(theta)**12 - 5.31027634824549e+83*cos(theta)**10 + 1.0764073678876e+83*cos(theta)**8 - 9.21694382289076e+81*cos(theta)**6 + 3.23023732110657e+80*cos(theta)**4 - 3.69169979555037e+78*cos(theta)**2 + 5.97362426464461e+75)*sin(45*phi)

#@torch.jit.script
def Yl57_m_minus_44(theta, phi):
    return 3.4772557179411e-75*(1.0 - cos(theta)**2)**22*(6.99372059850513e+82*cos(theta)**13 - 4.82752395295044e+82*cos(theta)**11 + 1.19600818654178e+82*cos(theta)**9 - 1.31670626041297e+81*cos(theta)**7 + 6.46047464221315e+79*cos(theta)**5 - 1.23056659851679e+78*cos(theta)**3 + 5.97362426464461e+75*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl57_m_minus_43(theta, phi):
    return 1.30755912148274e-73*(1.0 - cos(theta)**2)**21.5*(4.99551471321795e+81*cos(theta)**14 - 4.0229366274587e+81*cos(theta)**12 + 1.19600818654178e+81*cos(theta)**10 - 1.64588282551621e+80*cos(theta)**8 + 1.07674577370219e+79*cos(theta)**6 - 3.07641649629197e+77*cos(theta)**4 + 2.98681213232231e+75*cos(theta)**2 - 4.22462819281797e+72)*sin(43*phi)

#@torch.jit.script
def Yl57_m_minus_42(theta, phi):
    return 5.06415470168423e-72*(1.0 - cos(theta)**2)**21*(3.3303431421453e+80*cos(theta)**15 - 3.09456663650669e+80*cos(theta)**13 + 1.08728016958343e+80*cos(theta)**11 - 1.82875869501801e+79*cos(theta)**9 + 1.53820824814599e+78*cos(theta)**7 - 6.15283299258395e+76*cos(theta)**5 + 9.95604044107435e+74*cos(theta)**3 - 4.22462819281797e+72*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl57_m_minus_41(theta, phi):
    return 2.01550812309609e-70*(1.0 - cos(theta)**2)**20.5*(2.08146446384081e+79*cos(theta)**16 - 2.21040474036192e+79*cos(theta)**14 + 9.06066807986194e+78*cos(theta)**12 - 1.82875869501801e+78*cos(theta)**10 + 1.92276031018248e+77*cos(theta)**8 - 1.02547216543066e+76*cos(theta)**6 + 2.48901011026859e+74*cos(theta)**4 - 2.11231409640899e+72*cos(theta)**2 + 2.66706325304165e+69)*sin(41*phi)

#@torch.jit.script
def Yl57_m_minus_40(theta, phi):
    return 8.22663163661029e-69*(1.0 - cos(theta)**2)**20*(1.22439086108283e+78*cos(theta)**17 - 1.47360316024128e+78*cos(theta)**15 + 6.96974467681688e+77*cos(theta)**13 - 1.66250790456182e+77*cos(theta)**11 + 2.1364003446472e+76*cos(theta)**9 - 1.46496023632951e+75*cos(theta)**7 + 4.97802022053718e+73*cos(theta)**5 - 7.04104698802995e+71*cos(theta)**3 + 2.66706325304165e+69*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl57_m_minus_39(theta, phi):
    return 3.43751158944224e-67*(1.0 - cos(theta)**2)**19.5*(6.80217145046017e+76*cos(theta)**18 - 9.21001975150802e+76*cos(theta)**16 + 4.9783890548692e+76*cos(theta)**14 - 1.38542325380152e+76*cos(theta)**12 + 2.1364003446472e+75*cos(theta)**10 - 1.83120029541189e+74*cos(theta)**8 + 8.29670036756196e+72*cos(theta)**6 - 1.76026174700749e+71*cos(theta)**4 + 1.33353162652082e+69*cos(theta)**2 - 1.52752763633542e+66)*sin(39*phi)

#@torch.jit.script
def Yl57_m_minus_38(theta, phi):
    return 1.46810320930957e-65*(1.0 - cos(theta)**2)**19*(3.5800902370843e+75*cos(theta)**19 - 5.41765867735766e+75*cos(theta)**17 + 3.31892603657947e+75*cos(theta)**15 - 1.06571019523194e+75*cos(theta)**13 + 1.94218213149746e+74*cos(theta)**11 - 2.0346669949021e+73*cos(theta)**9 + 1.18524290965171e+72*cos(theta)**7 - 3.52052349401498e+70*cos(theta)**5 + 4.44510542173608e+68*cos(theta)**3 - 1.52752763633542e+66*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl57_m_minus_37(theta, phi):
    return 6.39931352806817e-64*(1.0 - cos(theta)**2)**18.5*(1.79004511854215e+74*cos(theta)**20 - 3.00981037630981e+74*cos(theta)**18 + 2.07432877286217e+74*cos(theta)**16 - 7.61221568022814e+73*cos(theta)**14 + 1.61848510958122e+73*cos(theta)**12 - 2.0346669949021e+72*cos(theta)**10 + 1.48155363706464e+71*cos(theta)**8 - 5.86753915669163e+69*cos(theta)**6 + 1.11127635543402e+68*cos(theta)**4 - 7.63763818167711e+65*cos(theta)**2 + 8.03961913860749e+62)*sin(37*phi)

#@torch.jit.script
def Yl57_m_minus_36(theta, phi):
    return 2.84319706855925e-62*(1.0 - cos(theta)**2)**18*(8.52402437401024e+72*cos(theta)**21 - 1.58411072437358e+73*cos(theta)**19 + 1.22019339580127e+73*cos(theta)**17 - 5.07481045348542e+72*cos(theta)**15 + 1.2449885458317e+72*cos(theta)**13 - 1.84969726809282e+71*cos(theta)**11 + 1.6461707078496e+70*cos(theta)**9 - 8.38219879527375e+68*cos(theta)**7 + 2.22255271086804e+67*cos(theta)**5 - 2.54587939389237e+65*cos(theta)**3 + 8.03961913860749e+62*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl57_m_minus_35(theta, phi):
    return 1.28605569636693e-60*(1.0 - cos(theta)**2)**17.5*(3.87455653364102e+71*cos(theta)**22 - 7.92055362186792e+71*cos(theta)**20 + 6.77885219889597e+71*cos(theta)**18 - 3.17175653342839e+71*cos(theta)**16 + 8.89277532736932e+70*cos(theta)**14 - 1.54141439007735e+70*cos(theta)**12 + 1.6461707078496e+69*cos(theta)**10 - 1.04777484940922e+68*cos(theta)**8 + 3.7042545181134e+66*cos(theta)**6 - 6.36469848473093e+64*cos(theta)**4 + 4.01980956930374e+62*cos(theta)**2 - 3.92943261906524e+59)*sin(35*phi)

#@torch.jit.script
def Yl57_m_minus_34(theta, phi):
    return 5.91585620328789e-59*(1.0 - cos(theta)**2)**17*(1.68458979723523e+70*cos(theta)**23 - 3.77169220088949e+70*cos(theta)**21 + 3.56781694678735e+70*cos(theta)**19 - 1.86573913731082e+70*cos(theta)**17 + 5.92851688491288e+69*cos(theta)**15 - 1.18570337698258e+69*cos(theta)**13 + 1.49651882531781e+68*cos(theta)**11 - 1.16419427712135e+67*cos(theta)**9 + 5.29179216873343e+65*cos(theta)**7 - 1.27293969694619e+64*cos(theta)**5 + 1.33993652310125e+62*cos(theta)**3 - 3.92943261906524e+59*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl57_m_minus_33(theta, phi):
    return 2.76467398594605e-57*(1.0 - cos(theta)**2)**16.5*(7.01912415514677e+68*cos(theta)**24 - 1.71440554585886e+69*cos(theta)**22 + 1.78390847339368e+69*cos(theta)**20 - 1.03652174295045e+69*cos(theta)**18 + 3.70532305307055e+68*cos(theta)**16 - 8.46930983558983e+67*cos(theta)**14 + 1.24709902109818e+67*cos(theta)**12 - 1.16419427712135e+66*cos(theta)**10 + 6.61474021091679e+64*cos(theta)**8 - 2.12156616157698e+63*cos(theta)**6 + 3.34984130775312e+61*cos(theta)**4 - 1.96471630953262e+59*cos(theta)**2 + 1.79919075964526e+56)*sin(33*phi)

#@torch.jit.script
def Yl57_m_minus_32(theta, phi):
    return 1.31140001751088e-55*(1.0 - cos(theta)**2)**16*(2.80764966205871e+67*cos(theta)**25 - 7.45393715590808e+67*cos(theta)**23 + 8.4948022542556e+67*cos(theta)**21 - 5.45537759447607e+67*cos(theta)**19 + 2.17960179592385e+67*cos(theta)**17 - 5.64620655705988e+66*cos(theta)**15 + 9.59306939306291e+65*cos(theta)**13 - 1.05835843374669e+65*cos(theta)**11 + 7.3497113454631e+63*cos(theta)**9 - 3.03080880225282e+62*cos(theta)**7 + 6.69968261550624e+60*cos(theta)**5 - 6.54905436510874e+58*cos(theta)**3 + 1.79919075964526e+56*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl57_m_minus_31(theta, phi):
    return 6.30836571048026e-54*(1.0 - cos(theta)**2)**15.5*(1.07986525463796e+66*cos(theta)**26 - 3.10580714829503e+66*cos(theta)**24 + 3.86127375193436e+66*cos(theta)**22 - 2.72768879723804e+66*cos(theta)**20 + 1.21088988662436e+66*cos(theta)**18 - 3.52887909816243e+65*cos(theta)**16 + 6.85219242361636e+64*cos(theta)**14 - 8.81965361455572e+63*cos(theta)**12 + 7.3497113454631e+62*cos(theta)**10 - 3.78851100281603e+61*cos(theta)**8 + 1.11661376925104e+60*cos(theta)**6 - 1.63726359127718e+58*cos(theta)**4 + 8.99595379822629e+55*cos(theta)**2 - 7.77524096648772e+52)*sin(31*phi)

#@torch.jit.script
def Yl57_m_minus_30(theta, phi):
    return 3.07496431814581e-52*(1.0 - cos(theta)**2)**15*(3.99950094310357e+64*cos(theta)**27 - 1.24232285931801e+65*cos(theta)**25 + 1.67881467475407e+65*cos(theta)**23 - 1.29889942725621e+65*cos(theta)**21 + 6.37310466644401e+64*cos(theta)**19 - 2.07581123421319e+64*cos(theta)**17 + 4.56812828241091e+63*cos(theta)**15 - 6.78434893427363e+62*cos(theta)**13 + 6.68155576860281e+61*cos(theta)**11 - 4.20945666979559e+60*cos(theta)**9 + 1.59516252750149e+59*cos(theta)**7 - 3.27452718255437e+57*cos(theta)**5 + 2.99865126607543e+55*cos(theta)**3 - 7.77524096648772e+52*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl57_m_minus_29(theta, phi):
    return 1.51767479846544e-50*(1.0 - cos(theta)**2)**14.5*(1.42839319396556e+63*cos(theta)**28 - 4.77816484353082e+63*cos(theta)**26 + 6.99506114480863e+63*cos(theta)**24 - 5.90408830571004e+63*cos(theta)**22 + 3.18655233322201e+63*cos(theta)**20 - 1.15322846345177e+63*cos(theta)**18 + 2.85508017650682e+62*cos(theta)**16 - 4.84596352448116e+61*cos(theta)**14 + 5.56796314050235e+60*cos(theta)**12 - 4.20945666979559e+59*cos(theta)**10 + 1.99395315937686e+58*cos(theta)**8 - 5.45754530425728e+56*cos(theta)**6 + 7.49662816518858e+54*cos(theta)**4 - 3.88762048324386e+52*cos(theta)**2 + 3.19180663648921e+49)*sin(29*phi)

#@torch.jit.script
def Yl57_m_minus_28(theta, phi):
    return 7.57926247334093e-49*(1.0 - cos(theta)**2)**14*(4.92549377229504e+61*cos(theta)**29 - 1.76969068278919e+62*cos(theta)**27 + 2.79802445792345e+62*cos(theta)**25 - 2.5669949155261e+62*cos(theta)**23 + 1.51740587296286e+62*cos(theta)**21 - 6.06962349185144e+61*cos(theta)**19 + 1.67945892735695e+61*cos(theta)**17 - 3.23064234965411e+60*cos(theta)**15 + 4.28304856961719e+59*cos(theta)**13 - 3.82677879072326e+58*cos(theta)**11 + 2.21550351041873e+57*cos(theta)**9 - 7.79649329179612e+55*cos(theta)**7 + 1.49932563303772e+54*cos(theta)**5 - 1.29587349441462e+52*cos(theta)**3 + 3.19180663648921e+49*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl57_m_minus_27(theta, phi):
    return 3.82733993893246e-47*(1.0 - cos(theta)**2)**13.5*(1.64183125743168e+60*cos(theta)**30 - 6.32032386710426e+60*cos(theta)**28 + 1.07616325304748e+61*cos(theta)**26 - 1.06958121480254e+61*cos(theta)**24 + 6.89729942255845e+60*cos(theta)**22 - 3.03481174592572e+60*cos(theta)**20 + 9.33032737420529e+59*cos(theta)**18 - 2.01915146853382e+59*cos(theta)**16 + 3.05932040686942e+58*cos(theta)**14 - 3.18898232560272e+57*cos(theta)**12 + 2.21550351041873e+56*cos(theta)**10 - 9.74561661474515e+54*cos(theta)**8 + 2.49887605506286e+53*cos(theta)**6 - 3.23968373603655e+51*cos(theta)**4 + 1.59590331824461e+49*cos(theta)**2 - 1.25168887705459e+46)*sin(27*phi)

#@torch.jit.script
def Yl57_m_minus_26(theta, phi):
    return 1.95306873266703e-45*(1.0 - cos(theta)**2)**13*(5.29622986268284e+58*cos(theta)**31 - 2.1794220231394e+59*cos(theta)**29 + 3.98578982610178e+59*cos(theta)**27 - 4.27832485921017e+59*cos(theta)**25 + 2.99882583589498e+59*cos(theta)**23 - 1.44514845044082e+59*cos(theta)**21 + 4.91069861800278e+58*cos(theta)**19 - 1.18773615796107e+58*cos(theta)**17 + 2.03954693791295e+57*cos(theta)**15 - 2.45306332738671e+56*cos(theta)**13 + 2.01409410038066e+55*cos(theta)**11 - 1.08284629052724e+54*cos(theta)**9 + 3.56982293580408e+52*cos(theta)**7 - 6.4793674720731e+50*cos(theta)**5 + 5.31967772748202e+48*cos(theta)**3 - 1.25168887705459e+46*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl57_m_minus_25(theta, phi):
    return 1.00654121487048e-43*(1.0 - cos(theta)**2)**12.5*(1.65507183208839e+57*cos(theta)**32 - 7.26474007713133e+57*cos(theta)**30 + 1.42349636646492e+58*cos(theta)**28 - 1.64550956123468e+58*cos(theta)**26 + 1.24951076495624e+58*cos(theta)**24 - 6.56885659291281e+57*cos(theta)**22 + 2.45534930900139e+57*cos(theta)**20 - 6.59853421089483e+56*cos(theta)**18 + 1.27471683619559e+56*cos(theta)**16 - 1.7521880909905e+55*cos(theta)**14 + 1.67841175031722e+54*cos(theta)**12 - 1.08284629052724e+53*cos(theta)**10 + 4.4622786697551e+51*cos(theta)**8 - 1.07989457867885e+50*cos(theta)**6 + 1.3299194318705e+48*cos(theta)**4 - 6.25844438527296e+45*cos(theta)**2 + 4.71268402505494e+42)*sin(25*phi)

#@torch.jit.script
def Yl57_m_minus_24(theta, phi):
    return 5.23594961571665e-42*(1.0 - cos(theta)**2)**12*(5.01536918814663e+55*cos(theta)**33 - 2.34346454101011e+56*cos(theta)**31 + 4.90860816022387e+56*cos(theta)**29 - 6.09447985642475e+56*cos(theta)**27 + 4.99804305982497e+56*cos(theta)**25 - 2.85602460561427e+56*cos(theta)**23 + 1.16921395666733e+56*cos(theta)**21 - 3.47291274257623e+55*cos(theta)**19 + 7.49833433056231e+54*cos(theta)**17 - 1.16812539399367e+54*cos(theta)**15 + 1.29108596178248e+53*cos(theta)**13 - 9.84405718661126e+51*cos(theta)**11 + 4.95808741083901e+50*cos(theta)**9 - 1.54270654096979e+49*cos(theta)**7 + 2.65983886374101e+47*cos(theta)**5 - 2.08614812842432e+45*cos(theta)**3 + 4.71268402505494e+42*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl57_m_minus_23(theta, phi):
    return 2.74775132997698e-40*(1.0 - cos(theta)**2)**11.5*(1.47510858474901e+54*cos(theta)**34 - 7.32332669065658e+54*cos(theta)**32 + 1.63620272007462e+55*cos(theta)**30 - 2.17659994872312e+55*cos(theta)**28 + 1.92232425377883e+55*cos(theta)**26 - 1.19001025233928e+55*cos(theta)**24 + 5.31460889394241e+54*cos(theta)**22 - 1.73645637128811e+54*cos(theta)**20 + 4.16574129475684e+53*cos(theta)**18 - 7.30078371246043e+52*cos(theta)**16 + 9.22204258416055e+51*cos(theta)**14 - 8.20338098884272e+50*cos(theta)**12 + 4.95808741083901e+49*cos(theta)**10 - 1.92838317621223e+48*cos(theta)**8 + 4.43306477290168e+46*cos(theta)**6 - 5.2153703210608e+44*cos(theta)**4 + 2.35634201252747e+42*cos(theta)**2 - 1.71121424293934e+39)*sin(23*phi)

#@torch.jit.script
def Yl57_m_minus_22(theta, phi):
    return 1.45397333675321e-38*(1.0 - cos(theta)**2)**11*(4.21459595642574e+52*cos(theta)**35 - 2.21918990625957e+53*cos(theta)**33 + 5.2780732905633e+53*cos(theta)**31 - 7.5055170645625e+53*cos(theta)**29 + 7.11971945844012e+53*cos(theta)**27 - 4.76004100935711e+53*cos(theta)**25 + 2.31069951910539e+53*cos(theta)**23 - 8.26883986327673e+52*cos(theta)**21 + 2.19249541829307e+52*cos(theta)**19 - 4.29457865438849e+51*cos(theta)**17 + 6.14802838944037e+50*cos(theta)**15 - 6.31029306834055e+49*cos(theta)**13 + 4.50735219167182e+48*cos(theta)**11 - 2.14264797356915e+47*cos(theta)**9 + 6.33294967557383e+45*cos(theta)**7 - 1.04307406421216e+44*cos(theta)**5 + 7.85447337509157e+41*cos(theta)**3 - 1.71121424293934e+39*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl57_m_minus_21(theta, phi):
    return 7.75391861679337e-37*(1.0 - cos(theta)**2)**10.5*(1.17072109900715e+51*cos(theta)**36 - 6.52702913605756e+51*cos(theta)**34 + 1.64939790330103e+52*cos(theta)**32 - 2.50183902152083e+52*cos(theta)**30 + 2.5427569494429e+52*cos(theta)**28 - 1.83078500359889e+52*cos(theta)**26 + 9.62791466293914e+51*cos(theta)**24 - 3.75856357421669e+51*cos(theta)**22 + 1.09624770914654e+51*cos(theta)**20 - 2.38587703021583e+50*cos(theta)**18 + 3.84251774340023e+49*cos(theta)**16 - 4.50735219167182e+48*cos(theta)**14 + 3.75612682639319e+47*cos(theta)**12 - 2.14264797356915e+46*cos(theta)**10 + 7.91618709446729e+44*cos(theta)**8 - 1.73845677368693e+43*cos(theta)**6 + 1.96361834377289e+41*cos(theta)**4 - 8.5560712146967e+38*cos(theta)**2 + 6.01692771778952e+35)*sin(21*phi)

#@torch.jit.script
def Yl57_m_minus_20(theta, phi):
    return 4.16552170563493e-35*(1.0 - cos(theta)**2)**10*(3.1641110783977e+49*cos(theta)**37 - 1.86486546744502e+50*cos(theta)**35 + 4.99817546454858e+50*cos(theta)**33 - 8.07044845651881e+50*cos(theta)**31 + 8.76812741187207e+50*cos(theta)**29 - 6.7806851985144e+50*cos(theta)**27 + 3.85116586517566e+50*cos(theta)**25 - 1.63415807574639e+50*cos(theta)**23 + 5.22022718641208e+49*cos(theta)**21 - 1.25572475274517e+49*cos(theta)**19 + 2.26030455494131e+48*cos(theta)**17 - 3.00490146111455e+47*cos(theta)**15 + 2.88932832799476e+46*cos(theta)**13 - 1.94786179415377e+45*cos(theta)**11 + 8.79576343829699e+43*cos(theta)**9 - 2.48350967669562e+42*cos(theta)**7 + 3.92723668754579e+40*cos(theta)**5 - 2.85202373823223e+38*cos(theta)**3 + 6.01692771778952e+35*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl57_m_minus_19(theta, phi):
    return 2.25323538451753e-33*(1.0 - cos(theta)**2)**9.5*(8.32660810104658e+47*cos(theta)**38 - 5.18018185401394e+48*cos(theta)**36 + 1.47005160722017e+49*cos(theta)**34 - 2.52201514266213e+49*cos(theta)**32 + 2.92270913729069e+49*cos(theta)**30 - 2.42167328518372e+49*cos(theta)**28 + 1.48121764045218e+49*cos(theta)**26 - 6.80899198227662e+48*cos(theta)**24 + 2.37283053927822e+48*cos(theta)**22 - 6.27862376372586e+47*cos(theta)**20 + 1.25572475274517e+47*cos(theta)**18 - 1.87806341319659e+46*cos(theta)**16 + 2.06380594856768e+45*cos(theta)**14 - 1.62321816179481e+44*cos(theta)**12 + 8.79576343829699e+42*cos(theta)**10 - 3.10438709586953e+41*cos(theta)**8 + 6.54539447924298e+39*cos(theta)**6 - 7.13005934558058e+37*cos(theta)**4 + 3.00846385889476e+35*cos(theta)**2 - 2.05636627402239e+32)*sin(19*phi)

#@torch.jit.script
def Yl57_m_minus_18(theta, phi):
    return 1.22672061142691e-31*(1.0 - cos(theta)**2)**9*(2.13502771821707e+46*cos(theta)**39 - 1.4000491497335e+47*cos(theta)**37 + 4.20014744920049e+47*cos(theta)**35 - 7.64247012927918e+47*cos(theta)**33 + 9.42809399126029e+47*cos(theta)**31 - 8.35059753511626e+47*cos(theta)**29 + 5.48599126093398e+47*cos(theta)**27 - 2.72359679291065e+47*cos(theta)**25 + 1.03166545186009e+47*cos(theta)**23 - 2.98982083986946e+46*cos(theta)**21 + 6.60907764602723e+45*cos(theta)**19 - 1.10474318423329e+45*cos(theta)**17 + 1.37587063237846e+44*cos(theta)**15 - 1.24862935522678e+43*cos(theta)**13 + 7.99614858026999e+41*cos(theta)**11 - 3.44931899541058e+40*cos(theta)**9 + 9.35056354177568e+38*cos(theta)**7 - 1.42601186911612e+37*cos(theta)**5 + 1.00282128629825e+35*cos(theta)**3 - 2.05636627402239e+32*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl57_m_minus_17(theta, phi):
    return 6.71902550635047e-30*(1.0 - cos(theta)**2)**8.5*(5.33756929554268e+44*cos(theta)**40 - 3.68433986771973e+45*cos(theta)**38 + 1.16670762477791e+46*cos(theta)**36 - 2.24778533214093e+46*cos(theta)**34 + 2.94627937226884e+46*cos(theta)**32 - 2.78353251170542e+46*cos(theta)**30 + 1.95928259319071e+46*cos(theta)**28 - 1.04753722804256e+46*cos(theta)**26 + 4.29860604941706e+45*cos(theta)**24 - 1.35900947266794e+45*cos(theta)**22 + 3.30453882301361e+44*cos(theta)**20 - 6.13746213462939e+43*cos(theta)**18 + 8.59919145236535e+42*cos(theta)**16 - 8.91878110876268e+41*cos(theta)**14 + 6.66345715022499e+40*cos(theta)**12 - 3.44931899541058e+39*cos(theta)**10 + 1.16882044272196e+38*cos(theta)**8 - 2.37668644852686e+36*cos(theta)**6 + 2.50705321574563e+34*cos(theta)**4 - 1.0281831370112e+32*cos(theta)**2 + 6.85455424674131e+28)*sin(17*phi)

#@torch.jit.script
def Yl57_m_minus_16(theta, phi):
    return 3.70095733010574e-28*(1.0 - cos(theta)**2)**8*(1.30184616964456e+43*cos(theta)**41 - 9.44702530184545e+43*cos(theta)**39 + 3.15326385075112e+44*cos(theta)**37 - 6.42224380611696e+44*cos(theta)**35 + 8.92811930990558e+44*cos(theta)**33 - 8.97913713453361e+44*cos(theta)**31 + 6.75614687307141e+44*cos(theta)**29 - 3.87976751126873e+44*cos(theta)**27 + 1.71944241976682e+44*cos(theta)**25 - 5.90873683768668e+43*cos(theta)**23 + 1.57358991572077e+43*cos(theta)**21 - 3.23024322875231e+42*cos(theta)**19 + 5.05834791315609e+41*cos(theta)**17 - 5.94585407250845e+40*cos(theta)**15 + 5.12573626940384e+39*cos(theta)**13 - 3.13574454128235e+38*cos(theta)**11 + 1.29868938080218e+37*cos(theta)**9 - 3.39526635503837e+35*cos(theta)**7 + 5.01410643149127e+33*cos(theta)**5 - 3.42727712337066e+31*cos(theta)**3 + 6.85455424674131e+28*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl57_m_minus_15(theta, phi):
    return 2.04927458136536e-26*(1.0 - cos(theta)**2)**7.5*(3.09963373724894e+41*cos(theta)**42 - 2.36175632546136e+42*cos(theta)**40 + 8.29806276513452e+42*cos(theta)**38 - 1.78395661281027e+43*cos(theta)**36 + 2.62591744408988e+43*cos(theta)**34 - 2.80598035454175e+43*cos(theta)**32 + 2.25204895769047e+43*cos(theta)**30 - 1.38563125402455e+43*cos(theta)**28 + 6.61324007602624e+42*cos(theta)**26 - 2.46197368236945e+42*cos(theta)**24 + 7.1526814350944e+41*cos(theta)**22 - 1.61512161437615e+41*cos(theta)**20 + 2.81019328508672e+40*cos(theta)**18 - 3.71615879531778e+39*cos(theta)**16 + 3.66124019243131e+38*cos(theta)**14 - 2.61312045106862e+37*cos(theta)**12 + 1.29868938080218e+36*cos(theta)**10 - 4.24408294379797e+34*cos(theta)**8 + 8.35684405248545e+32*cos(theta)**6 - 8.56819280842664e+30*cos(theta)**4 + 3.42727712337065e+28*cos(theta)**2 - 2.23566674714328e+25)*sin(15*phi)

#@torch.jit.script
def Yl57_m_minus_14(theta, phi):
    return 1.14025143960594e-24*(1.0 - cos(theta)**2)**7*(7.20845055174173e+39*cos(theta)**43 - 5.76038128161308e+40*cos(theta)**41 + 2.12770840131654e+41*cos(theta)**39 - 4.82150435894666e+41*cos(theta)**37 + 7.50262126882822e+41*cos(theta)**35 - 8.50297077133865e+41*cos(theta)**33 + 7.26467405706603e+41*cos(theta)**31 - 4.77803880698119e+41*cos(theta)**29 + 2.44934817630602e+41*cos(theta)**27 - 9.8478947294778e+40*cos(theta)**25 + 3.1098614935193e+40*cos(theta)**23 - 7.69105530655312e+39*cos(theta)**21 + 1.47904909741406e+39*cos(theta)**19 - 2.18597576195164e+38*cos(theta)**17 + 2.44082679495421e+37*cos(theta)**15 - 2.01009265466817e+36*cos(theta)**13 + 1.18062670982016e+35*cos(theta)**11 - 4.71564771533107e+33*cos(theta)**9 + 1.19383486464078e+32*cos(theta)**7 - 1.71363856168533e+30*cos(theta)**5 + 1.14242570779022e+28*cos(theta)**3 - 2.23566674714328e+25*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl57_m_minus_13(theta, phi):
    return 6.37317937250722e-23*(1.0 - cos(theta)**2)**6.5*(1.63828421630494e+38*cos(theta)**44 - 1.37151935276502e+39*cos(theta)**42 + 5.31927100329136e+39*cos(theta)**40 - 1.26881693656491e+40*cos(theta)**38 + 2.08406146356339e+40*cos(theta)**36 - 2.50087375627607e+40*cos(theta)**34 + 2.27021064283313e+40*cos(theta)**32 - 1.59267960232706e+40*cos(theta)**30 + 8.74767205823577e+39*cos(theta)**28 - 3.78765181902992e+39*cos(theta)**26 + 1.29577562229971e+39*cos(theta)**24 - 3.49593423025142e+38*cos(theta)**22 + 7.39524548707031e+37*cos(theta)**20 - 1.21443097886202e+37*cos(theta)**18 + 1.52551674684638e+36*cos(theta)**16 - 1.43578046762012e+35*cos(theta)**14 + 9.83855591516801e+33*cos(theta)**12 - 4.71564771533107e+32*cos(theta)**10 + 1.49229358080097e+31*cos(theta)**8 - 2.85606426947555e+29*cos(theta)**6 + 2.85606426947555e+27*cos(theta)**4 - 1.11783337357164e+25*cos(theta)**2 + 7.15642364642537e+21)*sin(13*phi)

#@torch.jit.script
def Yl57_m_minus_12(theta, phi):
    return 3.57693805145655e-21*(1.0 - cos(theta)**2)**6*(3.64063159178875e+36*cos(theta)**45 - 3.18957989015121e+37*cos(theta)**43 + 1.29738317153448e+38*cos(theta)**41 - 3.25337676042285e+38*cos(theta)**39 + 5.63259855017134e+38*cos(theta)**37 - 7.14535358936021e+38*cos(theta)**35 + 6.87942619040344e+38*cos(theta)**33 - 5.13767613653892e+38*cos(theta)**31 + 3.01643864077096e+38*cos(theta)**29 - 1.40283400704812e+38*cos(theta)**27 + 5.18310248919884e+37*cos(theta)**25 - 1.51997140445714e+37*cos(theta)**23 + 3.52154547003348e+36*cos(theta)**21 - 6.39174199401064e+35*cos(theta)**19 + 8.97362792262577e+34*cos(theta)**17 - 9.57186978413416e+33*cos(theta)**15 + 7.56811993474463e+32*cos(theta)**13 - 4.28695246848279e+31*cos(theta)**11 + 1.65810397866775e+30*cos(theta)**9 - 4.08009181353649e+28*cos(theta)**7 + 5.71212853895109e+26*cos(theta)**5 - 3.72611124523881e+24*cos(theta)**3 + 7.15642364642537e+21*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl57_m_minus_11(theta, phi):
    return 2.01518480555114e-19*(1.0 - cos(theta)**2)**5.5*(7.91441650388859e+34*cos(theta)**46 - 7.24904520488911e+35*cos(theta)**44 + 3.08900755127257e+36*cos(theta)**42 - 8.13344190105713e+36*cos(theta)**40 + 1.48226277636088e+37*cos(theta)**38 - 1.98482044148895e+37*cos(theta)**36 + 2.02336064423631e+37*cos(theta)**34 - 1.60552379266841e+37*cos(theta)**32 + 1.00547954692365e+37*cos(theta)**30 - 5.01012145374328e+36*cos(theta)**28 + 1.99350095738417e+36*cos(theta)**26 - 6.33321418523808e+35*cos(theta)**24 + 1.60070248637885e+35*cos(theta)**22 - 3.19587099700532e+34*cos(theta)**20 + 4.98534884590321e+33*cos(theta)**18 - 5.98241861508385e+32*cos(theta)**16 + 5.40579995338902e+31*cos(theta)**14 - 3.57246039040233e+30*cos(theta)**12 + 1.65810397866775e+29*cos(theta)**10 - 5.10011476692062e+27*cos(theta)**8 + 9.52021423158515e+25*cos(theta)**6 - 9.31527811309702e+23*cos(theta)**4 + 3.57821182321268e+21*cos(theta)**2 - 2.25470184197397e+18)*sin(11*phi)

#@torch.jit.script
def Yl57_m_minus_10(theta, phi):
    return 1.13924797487094e-17*(1.0 - cos(theta)**2)**5*(1.68391840508268e+33*cos(theta)**47 - 1.6108989344198e+34*cos(theta)**45 + 7.18373849133155e+34*cos(theta)**43 - 1.98376631733101e+35*cos(theta)**41 + 3.80067378554071e+35*cos(theta)**39 - 5.36437957159175e+35*cos(theta)**37 + 5.78103041210373e+35*cos(theta)**35 - 4.8652236141467e+35*cos(theta)**33 + 3.24348240943114e+35*cos(theta)**31 - 1.72762808749768e+35*cos(theta)**29 + 7.38333687920063e+34*cos(theta)**27 - 2.53328567409523e+34*cos(theta)**25 + 6.95957602773415e+33*cos(theta)**23 - 1.52184333190729e+33*cos(theta)**21 + 2.62386781363327e+32*cos(theta)**19 - 3.51906977357873e+31*cos(theta)**17 + 3.60386663559268e+30*cos(theta)**15 - 2.74804645415564e+29*cos(theta)**13 + 1.50736725333432e+28*cos(theta)**11 - 5.66679418546735e+26*cos(theta)**9 + 1.36003060451216e+25*cos(theta)**7 - 1.8630556226194e+23*cos(theta)**5 + 1.19273727440423e+21*cos(theta)**3 - 2.25470184197397e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl57_m_minus_9(theta, phi):
    return 6.46065105818606e-16*(1.0 - cos(theta)**2)**4.5*(3.50816334392225e+31*cos(theta)**48 - 3.50195420526044e+32*cos(theta)**46 + 1.63266783893899e+33*cos(theta)**44 - 4.7232531365024e+33*cos(theta)**42 + 9.50168446385178e+33*cos(theta)**40 - 1.41167883462941e+34*cos(theta)**38 + 1.60584178113992e+34*cos(theta)**36 - 1.43094812180785e+34*cos(theta)**34 + 1.01358825294723e+34*cos(theta)**32 - 5.75876029165895e+33*cos(theta)**30 + 2.63690602828594e+33*cos(theta)**28 - 9.74340643882781e+32*cos(theta)**26 + 2.89982334488923e+32*cos(theta)**24 - 6.9174696904877e+31*cos(theta)**22 + 1.31193390681663e+31*cos(theta)**20 - 1.9550387630993e+30*cos(theta)**18 + 2.25241664724542e+29*cos(theta)**16 - 1.96289032439688e+28*cos(theta)**14 + 1.2561393777786e+27*cos(theta)**12 - 5.66679418546735e+25*cos(theta)**10 + 1.70003825564021e+24*cos(theta)**8 - 3.10509270436567e+22*cos(theta)**6 + 2.98184318601057e+20*cos(theta)**4 - 1.12735092098698e+18*cos(theta)**2 + 701088881210810.0)*sin(9*phi)

#@torch.jit.script
def Yl57_m_minus_8(theta, phi):
    return 3.67406041209588e-14*(1.0 - cos(theta)**2)**4*(7.15951702841275e+29*cos(theta)**49 - 7.45096639417115e+30*cos(theta)**47 + 3.62815075319775e+31*cos(theta)**45 - 1.0984309619773e+32*cos(theta)**43 + 2.31748401557361e+32*cos(theta)**41 - 3.61968931956258e+32*cos(theta)**39 + 4.3401129219998e+32*cos(theta)**37 - 4.0884232051653e+32*cos(theta)**35 + 3.07147955438554e+32*cos(theta)**33 - 1.85766461021256e+32*cos(theta)**31 + 9.09277940788255e+31*cos(theta)**29 - 3.60866905141771e+31*cos(theta)**27 + 1.15992933795569e+31*cos(theta)**25 - 3.00759551760335e+30*cos(theta)**23 + 6.24730431817444e+29*cos(theta)**21 - 1.02896777005226e+29*cos(theta)**19 + 1.3249509689679e+28*cos(theta)**17 - 1.30859354959792e+27*cos(theta)**15 + 9.6626105982969e+25*cos(theta)**13 - 5.15163107769759e+24*cos(theta)**11 + 1.88893139515578e+23*cos(theta)**9 - 4.43584672052239e+21*cos(theta)**7 + 5.96368637202114e+19*cos(theta)**5 - 3.75783640328994e+17*cos(theta)**3 + 701088881210810.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl57_m_minus_7(theta, phi):
    return 2.09453669610067e-12*(1.0 - cos(theta)**2)**3.5*(1.43190340568255e+28*cos(theta)**50 - 1.55228466545232e+29*cos(theta)**48 + 7.88728424608207e+29*cos(theta)**46 - 2.49643400449387e+30*cos(theta)**44 + 5.51781908469906e+30*cos(theta)**42 - 9.04922329890646e+30*cos(theta)**40 + 1.14213497947363e+31*cos(theta)**38 - 1.13567311254592e+31*cos(theta)**36 + 9.0337633952516e+30*cos(theta)**34 - 5.80520190691426e+30*cos(theta)**32 + 3.03092646929418e+30*cos(theta)**30 - 1.28881037550632e+30*cos(theta)**28 + 4.46126668444497e+29*cos(theta)**26 - 1.2531647990014e+29*cos(theta)**24 + 2.83968378098838e+28*cos(theta)**22 - 5.14483885026131e+27*cos(theta)**20 + 7.36083871648831e+26*cos(theta)**18 - 8.17870968498702e+25*cos(theta)**16 + 6.90186471306921e+24*cos(theta)**14 - 4.29302589808133e+23*cos(theta)**12 + 1.88893139515578e+22*cos(theta)**10 - 5.54480840065299e+20*cos(theta)**8 + 9.9394772867019e+18*cos(theta)**6 - 9.39459100822486e+16*cos(theta)**4 + 350544440605405.0*cos(theta)**2 - 215719655757.172)*sin(7*phi)

#@torch.jit.script
def Yl57_m_minus_6(theta, phi):
    return 1.19663871249276e-10*(1.0 - cos(theta)**2)**3*(2.80765373663245e+26*cos(theta)**51 - 3.16792788867821e+27*cos(theta)**49 + 1.67814558427278e+28*cos(theta)**47 - 5.54763112109748e+28*cos(theta)**45 + 1.28321374062769e+29*cos(theta)**43 - 2.20712763387962e+29*cos(theta)**41 + 2.92855122941957e+29*cos(theta)**39 - 3.06938679066464e+29*cos(theta)**37 + 2.58107525578617e+29*cos(theta)**35 - 1.75915209300432e+29*cos(theta)**33 + 9.77718215901349e+28*cos(theta)**31 - 4.4441737086425e+28*cos(theta)**29 + 1.65232099423888e+28*cos(theta)**27 - 5.01265919600558e+27*cos(theta)**25 + 1.23464512216886e+27*cos(theta)**23 - 2.44992326202919e+26*cos(theta)**21 + 3.87412564025701e+25*cos(theta)**19 - 4.81100569705119e+24*cos(theta)**17 + 4.60124314204614e+23*cos(theta)**15 - 3.30232761390871e+22*cos(theta)**13 + 1.71721035923253e+21*cos(theta)**11 - 6.16089822294776e+19*cos(theta)**9 + 1.4199253266717e+18*cos(theta)**7 - 1.87891820164497e+16*cos(theta)**5 + 116848146868468.0*cos(theta)**3 - 215719655757.172*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl57_m_minus_5(theta, phi):
    return 6.84912346667969e-9*(1.0 - cos(theta)**2)**2.5*(5.39933410890856e+24*cos(theta)**52 - 6.33585577735642e+25*cos(theta)**50 + 3.49613663390163e+26*cos(theta)**48 - 1.20600676545597e+27*cos(theta)**46 + 2.91639486506293e+27*cos(theta)**44 - 5.25506579495149e+27*cos(theta)**42 + 7.32137807354892e+27*cos(theta)**40 - 8.07733365964378e+27*cos(theta)**38 + 7.16965348829492e+27*cos(theta)**36 - 5.17397674413036e+27*cos(theta)**34 + 3.05536942469172e+27*cos(theta)**32 - 1.48139123621417e+27*cos(theta)**30 + 5.90114640799599e+26*cos(theta)**28 - 1.92794584461753e+26*cos(theta)**26 + 5.14435467570359e+25*cos(theta)**24 - 1.11360148274054e+25*cos(theta)**22 + 1.9370628201285e+24*cos(theta)**20 - 2.67278094280621e+23*cos(theta)**18 + 2.87577696377884e+22*cos(theta)**16 - 2.35880543850622e+21*cos(theta)**14 + 1.43100863269378e+20*cos(theta)**12 - 6.16089822294776e+18*cos(theta)**10 + 1.77490665833962e+17*cos(theta)**8 - 3.13153033607495e+15*cos(theta)**6 + 29212036717117.1*cos(theta)**4 - 107859827878.586*cos(theta)**2 + 65848490.7683676)*sin(5*phi)

#@torch.jit.script
def Yl57_m_minus_4(theta, phi):
    return 3.92616705671509e-7*(1.0 - cos(theta)**2)**2*(1.01874228469973e+23*cos(theta)**53 - 1.24232466222675e+24*cos(theta)**51 + 7.13497272224822e+24*cos(theta)**49 - 2.56597184139569e+25*cos(theta)**47 + 6.48087747791762e+25*cos(theta)**45 - 1.22210832440732e+26*cos(theta)**43 + 1.78570196915827e+26*cos(theta)**41 - 2.07111119478046e+26*cos(theta)**39 + 1.93774418602565e+26*cos(theta)**37 - 1.47827906975153e+26*cos(theta)**35 + 9.25869522633853e+25*cos(theta)**33 - 4.77868140714247e+25*cos(theta)**31 + 2.03487807172275e+25*cos(theta)**29 - 7.14054016525012e+24*cos(theta)**27 + 2.05774187028144e+24*cos(theta)**25 - 4.84174557713279e+23*cos(theta)**23 + 9.22410866727859e+22*cos(theta)**21 - 1.40672681200327e+22*cos(theta)**19 + 1.6916335081052e+21*cos(theta)**17 - 1.57253695900415e+20*cos(theta)**15 + 1.1007758713029e+19*cos(theta)**13 - 5.60081656631615e+17*cos(theta)**11 + 1.97211850926625e+16*cos(theta)**9 - 447361476582136.0*cos(theta)**7 + 5842407343423.42*cos(theta)**5 - 35953275959.5287*cos(theta)**3 + 65848490.7683676*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl57_m_minus_3(theta, phi):
    return 2.25335995509665e-5*(1.0 - cos(theta)**2)**1.5*(1.88655978648098e+21*cos(theta)**54 - 2.38908588889759e+22*cos(theta)**52 + 1.42699454444964e+23*cos(theta)**50 - 5.34577466957435e+23*cos(theta)**48 + 1.40888640824296e+24*cos(theta)**46 - 2.77751891910755e+24*cos(theta)**44 + 4.25167135513874e+24*cos(theta)**42 - 5.17777798695114e+24*cos(theta)**40 + 5.09932680533067e+24*cos(theta)**38 - 4.10633074930981e+24*cos(theta)**36 + 2.72314565480545e+24*cos(theta)**34 - 1.49333793973202e+24*cos(theta)**32 + 6.78292690574251e+23*cos(theta)**30 - 2.55019291616076e+23*cos(theta)**28 + 7.91439180877476e+22*cos(theta)**26 - 2.017393990472e+22*cos(theta)**24 + 4.19277666694481e+21*cos(theta)**22 - 7.03363406001635e+20*cos(theta)**20 + 9.39796393391777e+19*cos(theta)**18 - 9.82835599377593e+18*cos(theta)**16 + 7.86268479502075e+17*cos(theta)**14 - 4.66734713859679e+16*cos(theta)**12 + 1.97211850926625e+15*cos(theta)**10 - 55920184572767.0*cos(theta)**8 + 973734557237.236*cos(theta)**6 - 8988318989.88218*cos(theta)**4 + 32924245.3841838*cos(theta)**2 - 19990.43435591)*sin(3*phi)

#@torch.jit.script
def Yl57_m_minus_2(theta, phi):
    return 0.00129445674272528*(1.0 - cos(theta)**2)*(3.43010870269269e+19*cos(theta)**55 - 4.50770922433508e+20*cos(theta)**53 + 2.79802851852871e+21*cos(theta)**51 - 1.09097442236211e+22*cos(theta)**49 + 2.99763065583609e+22*cos(theta)**47 - 6.17226426468345e+22*cos(theta)**45 + 9.88760780264824e+22*cos(theta)**43 - 1.26287267974418e+23*cos(theta)**41 + 1.30751969367453e+23*cos(theta)**39 - 1.10981912143508e+23*cos(theta)**37 + 7.780416156587e+22*cos(theta)**35 - 4.52526648403643e+22*cos(theta)**33 + 2.18804093733629e+22*cos(theta)**31 - 8.7937686764164e+21*cos(theta)**29 + 2.93125622547213e+21*cos(theta)**27 - 8.06957596188799e+20*cos(theta)**25 + 1.82294637693253e+20*cos(theta)**23 - 3.34934955238874e+19*cos(theta)**21 + 4.94629680732514e+18*cos(theta)**19 - 5.78138587869173e+17*cos(theta)**17 + 5.24178986334716e+16*cos(theta)**15 - 3.59026702968984e+15*cos(theta)**13 + 179283500842386.0*cos(theta)**11 - 6213353841418.56*cos(theta)**9 + 139104936748.177*cos(theta)**7 - 1797663797.97644*cos(theta)**5 + 10974748.4613946*cos(theta)**3 - 19990.43435591*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl57_m_minus_1(theta, phi):
    return 0.0744059320688348*(1.0 - cos(theta)**2)**0.5*(6.12519411195123e+17*cos(theta)**56 - 8.3476096746946e+18*cos(theta)**54 + 5.38082407409368e+19*cos(theta)**52 - 2.18194884472423e+20*cos(theta)**50 + 6.24506386632518e+20*cos(theta)**48 - 1.34179657927901e+21*cos(theta)**46 + 2.24718359151096e+21*cos(theta)**44 - 3.00683971367662e+21*cos(theta)**42 + 3.26879923418633e+21*cos(theta)**40 - 2.92057663535548e+21*cos(theta)**38 + 2.16122671016306e+21*cos(theta)**36 - 1.33096073059895e+21*cos(theta)**34 + 6.83762792917592e+20*cos(theta)**32 - 2.93125622547213e+20*cos(theta)**30 + 1.0468772233829e+20*cos(theta)**28 - 3.10368306226461e+19*cos(theta)**26 + 7.59560990388553e+18*cos(theta)**24 - 1.52243161472215e+18*cos(theta)**22 + 2.47314840366257e+17*cos(theta)**20 - 3.21188104371763e+16*cos(theta)**18 + 3.27611866459198e+15*cos(theta)**16 - 256447644977846.0*cos(theta)**14 + 14940291736865.5*cos(theta)**12 - 621335384141.856*cos(theta)**10 + 17388117093.5221*cos(theta)**8 - 299610632.996073*cos(theta)**6 + 2743687.11534865*cos(theta)**4 - 9995.21717795501*cos(theta)**2 + 6.05037359440376)*sin(phi)

#@torch.jit.script
def Yl57_m0(theta, phi):
    return 1.02126597165331e+17*cos(theta)**57 - 1.44242521306078e+18*cos(theta)**55 + 9.64865514142007e+18*cos(theta)**53 - 4.06600819109384e+19*cos(theta)**51 + 1.21125244010389e+20*cos(theta)**49 - 2.71320546583271e+20*cos(theta)**47 + 4.74591441515398e+20*cos(theta)**45 - 6.64562273126229e+20*cos(theta)**43 + 7.57701682617406e+20*cos(theta)**41 - 7.11701465917838e+20*cos(theta)**39 + 5.55127143415914e+20*cos(theta)**37 - 3.61402421813293e+20*cos(theta)**35 + 1.96917986244422e+20*cos(theta)**33 - 8.9864042123643e+19*cos(theta)**31 + 3.43077008107504e+19*cos(theta)**29 - 1.09246482581684e+19*cos(theta)**27 + 2.8874635079948e+18*cos(theta)**25 - 6.29077016992332e+17*cos(theta)**23 + 1.11924391912138e+17*cos(theta)**21 - 1.60657021883451e+16*cos(theta)**19 + 1.83149004947135e+15*cos(theta)**17 - 162480526241424.0*cos(theta)**15 + 10922186463091.9*cos(theta)**13 - 536818238261.605*cos(theta)**11 + 18361320338.5499*cos(theta)**9 - 406773865.961721*cos(theta)**7 + 5215049.56361181*cos(theta)**5 - 31663.9317766352*cos(theta)**3 + 57.501086761444*cos(theta)

#@torch.jit.script
def Yl57_m1(theta, phi):
    return 0.0744059320688348*(1.0 - cos(theta)**2)**0.5*(6.12519411195123e+17*cos(theta)**56 - 8.3476096746946e+18*cos(theta)**54 + 5.38082407409368e+19*cos(theta)**52 - 2.18194884472423e+20*cos(theta)**50 + 6.24506386632518e+20*cos(theta)**48 - 1.34179657927901e+21*cos(theta)**46 + 2.24718359151096e+21*cos(theta)**44 - 3.00683971367662e+21*cos(theta)**42 + 3.26879923418633e+21*cos(theta)**40 - 2.92057663535548e+21*cos(theta)**38 + 2.16122671016306e+21*cos(theta)**36 - 1.33096073059895e+21*cos(theta)**34 + 6.83762792917592e+20*cos(theta)**32 - 2.93125622547213e+20*cos(theta)**30 + 1.0468772233829e+20*cos(theta)**28 - 3.10368306226461e+19*cos(theta)**26 + 7.59560990388553e+18*cos(theta)**24 - 1.52243161472215e+18*cos(theta)**22 + 2.47314840366257e+17*cos(theta)**20 - 3.21188104371763e+16*cos(theta)**18 + 3.27611866459198e+15*cos(theta)**16 - 256447644977846.0*cos(theta)**14 + 14940291736865.5*cos(theta)**12 - 621335384141.856*cos(theta)**10 + 17388117093.5221*cos(theta)**8 - 299610632.996073*cos(theta)**6 + 2743687.11534865*cos(theta)**4 - 9995.21717795501*cos(theta)**2 + 6.05037359440376)*cos(phi)

#@torch.jit.script
def Yl57_m2(theta, phi):
    return 0.00129445674272528*(1.0 - cos(theta)**2)*(3.43010870269269e+19*cos(theta)**55 - 4.50770922433508e+20*cos(theta)**53 + 2.79802851852871e+21*cos(theta)**51 - 1.09097442236211e+22*cos(theta)**49 + 2.99763065583609e+22*cos(theta)**47 - 6.17226426468345e+22*cos(theta)**45 + 9.88760780264824e+22*cos(theta)**43 - 1.26287267974418e+23*cos(theta)**41 + 1.30751969367453e+23*cos(theta)**39 - 1.10981912143508e+23*cos(theta)**37 + 7.780416156587e+22*cos(theta)**35 - 4.52526648403643e+22*cos(theta)**33 + 2.18804093733629e+22*cos(theta)**31 - 8.7937686764164e+21*cos(theta)**29 + 2.93125622547213e+21*cos(theta)**27 - 8.06957596188799e+20*cos(theta)**25 + 1.82294637693253e+20*cos(theta)**23 - 3.34934955238874e+19*cos(theta)**21 + 4.94629680732514e+18*cos(theta)**19 - 5.78138587869173e+17*cos(theta)**17 + 5.24178986334716e+16*cos(theta)**15 - 3.59026702968984e+15*cos(theta)**13 + 179283500842386.0*cos(theta)**11 - 6213353841418.56*cos(theta)**9 + 139104936748.177*cos(theta)**7 - 1797663797.97644*cos(theta)**5 + 10974748.4613946*cos(theta)**3 - 19990.43435591*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl57_m3(theta, phi):
    return 2.25335995509665e-5*(1.0 - cos(theta)**2)**1.5*(1.88655978648098e+21*cos(theta)**54 - 2.38908588889759e+22*cos(theta)**52 + 1.42699454444964e+23*cos(theta)**50 - 5.34577466957435e+23*cos(theta)**48 + 1.40888640824296e+24*cos(theta)**46 - 2.77751891910755e+24*cos(theta)**44 + 4.25167135513874e+24*cos(theta)**42 - 5.17777798695114e+24*cos(theta)**40 + 5.09932680533067e+24*cos(theta)**38 - 4.10633074930981e+24*cos(theta)**36 + 2.72314565480545e+24*cos(theta)**34 - 1.49333793973202e+24*cos(theta)**32 + 6.78292690574251e+23*cos(theta)**30 - 2.55019291616076e+23*cos(theta)**28 + 7.91439180877476e+22*cos(theta)**26 - 2.017393990472e+22*cos(theta)**24 + 4.19277666694481e+21*cos(theta)**22 - 7.03363406001635e+20*cos(theta)**20 + 9.39796393391777e+19*cos(theta)**18 - 9.82835599377593e+18*cos(theta)**16 + 7.86268479502075e+17*cos(theta)**14 - 4.66734713859679e+16*cos(theta)**12 + 1.97211850926625e+15*cos(theta)**10 - 55920184572767.0*cos(theta)**8 + 973734557237.236*cos(theta)**6 - 8988318989.88218*cos(theta)**4 + 32924245.3841838*cos(theta)**2 - 19990.43435591)*cos(3*phi)

#@torch.jit.script
def Yl57_m4(theta, phi):
    return 3.92616705671509e-7*(1.0 - cos(theta)**2)**2*(1.01874228469973e+23*cos(theta)**53 - 1.24232466222675e+24*cos(theta)**51 + 7.13497272224822e+24*cos(theta)**49 - 2.56597184139569e+25*cos(theta)**47 + 6.48087747791762e+25*cos(theta)**45 - 1.22210832440732e+26*cos(theta)**43 + 1.78570196915827e+26*cos(theta)**41 - 2.07111119478046e+26*cos(theta)**39 + 1.93774418602565e+26*cos(theta)**37 - 1.47827906975153e+26*cos(theta)**35 + 9.25869522633853e+25*cos(theta)**33 - 4.77868140714247e+25*cos(theta)**31 + 2.03487807172275e+25*cos(theta)**29 - 7.14054016525012e+24*cos(theta)**27 + 2.05774187028144e+24*cos(theta)**25 - 4.84174557713279e+23*cos(theta)**23 + 9.22410866727859e+22*cos(theta)**21 - 1.40672681200327e+22*cos(theta)**19 + 1.6916335081052e+21*cos(theta)**17 - 1.57253695900415e+20*cos(theta)**15 + 1.1007758713029e+19*cos(theta)**13 - 5.60081656631615e+17*cos(theta)**11 + 1.97211850926625e+16*cos(theta)**9 - 447361476582136.0*cos(theta)**7 + 5842407343423.42*cos(theta)**5 - 35953275959.5287*cos(theta)**3 + 65848490.7683676*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl57_m5(theta, phi):
    return 6.84912346667969e-9*(1.0 - cos(theta)**2)**2.5*(5.39933410890856e+24*cos(theta)**52 - 6.33585577735642e+25*cos(theta)**50 + 3.49613663390163e+26*cos(theta)**48 - 1.20600676545597e+27*cos(theta)**46 + 2.91639486506293e+27*cos(theta)**44 - 5.25506579495149e+27*cos(theta)**42 + 7.32137807354892e+27*cos(theta)**40 - 8.07733365964378e+27*cos(theta)**38 + 7.16965348829492e+27*cos(theta)**36 - 5.17397674413036e+27*cos(theta)**34 + 3.05536942469172e+27*cos(theta)**32 - 1.48139123621417e+27*cos(theta)**30 + 5.90114640799599e+26*cos(theta)**28 - 1.92794584461753e+26*cos(theta)**26 + 5.14435467570359e+25*cos(theta)**24 - 1.11360148274054e+25*cos(theta)**22 + 1.9370628201285e+24*cos(theta)**20 - 2.67278094280621e+23*cos(theta)**18 + 2.87577696377884e+22*cos(theta)**16 - 2.35880543850622e+21*cos(theta)**14 + 1.43100863269378e+20*cos(theta)**12 - 6.16089822294776e+18*cos(theta)**10 + 1.77490665833962e+17*cos(theta)**8 - 3.13153033607495e+15*cos(theta)**6 + 29212036717117.1*cos(theta)**4 - 107859827878.586*cos(theta)**2 + 65848490.7683676)*cos(5*phi)

#@torch.jit.script
def Yl57_m6(theta, phi):
    return 1.19663871249276e-10*(1.0 - cos(theta)**2)**3*(2.80765373663245e+26*cos(theta)**51 - 3.16792788867821e+27*cos(theta)**49 + 1.67814558427278e+28*cos(theta)**47 - 5.54763112109748e+28*cos(theta)**45 + 1.28321374062769e+29*cos(theta)**43 - 2.20712763387962e+29*cos(theta)**41 + 2.92855122941957e+29*cos(theta)**39 - 3.06938679066464e+29*cos(theta)**37 + 2.58107525578617e+29*cos(theta)**35 - 1.75915209300432e+29*cos(theta)**33 + 9.77718215901349e+28*cos(theta)**31 - 4.4441737086425e+28*cos(theta)**29 + 1.65232099423888e+28*cos(theta)**27 - 5.01265919600558e+27*cos(theta)**25 + 1.23464512216886e+27*cos(theta)**23 - 2.44992326202919e+26*cos(theta)**21 + 3.87412564025701e+25*cos(theta)**19 - 4.81100569705119e+24*cos(theta)**17 + 4.60124314204614e+23*cos(theta)**15 - 3.30232761390871e+22*cos(theta)**13 + 1.71721035923253e+21*cos(theta)**11 - 6.16089822294776e+19*cos(theta)**9 + 1.4199253266717e+18*cos(theta)**7 - 1.87891820164497e+16*cos(theta)**5 + 116848146868468.0*cos(theta)**3 - 215719655757.172*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl57_m7(theta, phi):
    return 2.09453669610067e-12*(1.0 - cos(theta)**2)**3.5*(1.43190340568255e+28*cos(theta)**50 - 1.55228466545232e+29*cos(theta)**48 + 7.88728424608207e+29*cos(theta)**46 - 2.49643400449387e+30*cos(theta)**44 + 5.51781908469906e+30*cos(theta)**42 - 9.04922329890646e+30*cos(theta)**40 + 1.14213497947363e+31*cos(theta)**38 - 1.13567311254592e+31*cos(theta)**36 + 9.0337633952516e+30*cos(theta)**34 - 5.80520190691426e+30*cos(theta)**32 + 3.03092646929418e+30*cos(theta)**30 - 1.28881037550632e+30*cos(theta)**28 + 4.46126668444497e+29*cos(theta)**26 - 1.2531647990014e+29*cos(theta)**24 + 2.83968378098838e+28*cos(theta)**22 - 5.14483885026131e+27*cos(theta)**20 + 7.36083871648831e+26*cos(theta)**18 - 8.17870968498702e+25*cos(theta)**16 + 6.90186471306921e+24*cos(theta)**14 - 4.29302589808133e+23*cos(theta)**12 + 1.88893139515578e+22*cos(theta)**10 - 5.54480840065299e+20*cos(theta)**8 + 9.9394772867019e+18*cos(theta)**6 - 9.39459100822486e+16*cos(theta)**4 + 350544440605405.0*cos(theta)**2 - 215719655757.172)*cos(7*phi)

#@torch.jit.script
def Yl57_m8(theta, phi):
    return 3.67406041209588e-14*(1.0 - cos(theta)**2)**4*(7.15951702841275e+29*cos(theta)**49 - 7.45096639417115e+30*cos(theta)**47 + 3.62815075319775e+31*cos(theta)**45 - 1.0984309619773e+32*cos(theta)**43 + 2.31748401557361e+32*cos(theta)**41 - 3.61968931956258e+32*cos(theta)**39 + 4.3401129219998e+32*cos(theta)**37 - 4.0884232051653e+32*cos(theta)**35 + 3.07147955438554e+32*cos(theta)**33 - 1.85766461021256e+32*cos(theta)**31 + 9.09277940788255e+31*cos(theta)**29 - 3.60866905141771e+31*cos(theta)**27 + 1.15992933795569e+31*cos(theta)**25 - 3.00759551760335e+30*cos(theta)**23 + 6.24730431817444e+29*cos(theta)**21 - 1.02896777005226e+29*cos(theta)**19 + 1.3249509689679e+28*cos(theta)**17 - 1.30859354959792e+27*cos(theta)**15 + 9.6626105982969e+25*cos(theta)**13 - 5.15163107769759e+24*cos(theta)**11 + 1.88893139515578e+23*cos(theta)**9 - 4.43584672052239e+21*cos(theta)**7 + 5.96368637202114e+19*cos(theta)**5 - 3.75783640328994e+17*cos(theta)**3 + 701088881210810.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl57_m9(theta, phi):
    return 6.46065105818606e-16*(1.0 - cos(theta)**2)**4.5*(3.50816334392225e+31*cos(theta)**48 - 3.50195420526044e+32*cos(theta)**46 + 1.63266783893899e+33*cos(theta)**44 - 4.7232531365024e+33*cos(theta)**42 + 9.50168446385178e+33*cos(theta)**40 - 1.41167883462941e+34*cos(theta)**38 + 1.60584178113992e+34*cos(theta)**36 - 1.43094812180785e+34*cos(theta)**34 + 1.01358825294723e+34*cos(theta)**32 - 5.75876029165895e+33*cos(theta)**30 + 2.63690602828594e+33*cos(theta)**28 - 9.74340643882781e+32*cos(theta)**26 + 2.89982334488923e+32*cos(theta)**24 - 6.9174696904877e+31*cos(theta)**22 + 1.31193390681663e+31*cos(theta)**20 - 1.9550387630993e+30*cos(theta)**18 + 2.25241664724542e+29*cos(theta)**16 - 1.96289032439688e+28*cos(theta)**14 + 1.2561393777786e+27*cos(theta)**12 - 5.66679418546735e+25*cos(theta)**10 + 1.70003825564021e+24*cos(theta)**8 - 3.10509270436567e+22*cos(theta)**6 + 2.98184318601057e+20*cos(theta)**4 - 1.12735092098698e+18*cos(theta)**2 + 701088881210810.0)*cos(9*phi)

#@torch.jit.script
def Yl57_m10(theta, phi):
    return 1.13924797487094e-17*(1.0 - cos(theta)**2)**5*(1.68391840508268e+33*cos(theta)**47 - 1.6108989344198e+34*cos(theta)**45 + 7.18373849133155e+34*cos(theta)**43 - 1.98376631733101e+35*cos(theta)**41 + 3.80067378554071e+35*cos(theta)**39 - 5.36437957159175e+35*cos(theta)**37 + 5.78103041210373e+35*cos(theta)**35 - 4.8652236141467e+35*cos(theta)**33 + 3.24348240943114e+35*cos(theta)**31 - 1.72762808749768e+35*cos(theta)**29 + 7.38333687920063e+34*cos(theta)**27 - 2.53328567409523e+34*cos(theta)**25 + 6.95957602773415e+33*cos(theta)**23 - 1.52184333190729e+33*cos(theta)**21 + 2.62386781363327e+32*cos(theta)**19 - 3.51906977357873e+31*cos(theta)**17 + 3.60386663559268e+30*cos(theta)**15 - 2.74804645415564e+29*cos(theta)**13 + 1.50736725333432e+28*cos(theta)**11 - 5.66679418546735e+26*cos(theta)**9 + 1.36003060451216e+25*cos(theta)**7 - 1.8630556226194e+23*cos(theta)**5 + 1.19273727440423e+21*cos(theta)**3 - 2.25470184197397e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl57_m11(theta, phi):
    return 2.01518480555114e-19*(1.0 - cos(theta)**2)**5.5*(7.91441650388859e+34*cos(theta)**46 - 7.24904520488911e+35*cos(theta)**44 + 3.08900755127257e+36*cos(theta)**42 - 8.13344190105713e+36*cos(theta)**40 + 1.48226277636088e+37*cos(theta)**38 - 1.98482044148895e+37*cos(theta)**36 + 2.02336064423631e+37*cos(theta)**34 - 1.60552379266841e+37*cos(theta)**32 + 1.00547954692365e+37*cos(theta)**30 - 5.01012145374328e+36*cos(theta)**28 + 1.99350095738417e+36*cos(theta)**26 - 6.33321418523808e+35*cos(theta)**24 + 1.60070248637885e+35*cos(theta)**22 - 3.19587099700532e+34*cos(theta)**20 + 4.98534884590321e+33*cos(theta)**18 - 5.98241861508385e+32*cos(theta)**16 + 5.40579995338902e+31*cos(theta)**14 - 3.57246039040233e+30*cos(theta)**12 + 1.65810397866775e+29*cos(theta)**10 - 5.10011476692062e+27*cos(theta)**8 + 9.52021423158515e+25*cos(theta)**6 - 9.31527811309702e+23*cos(theta)**4 + 3.57821182321268e+21*cos(theta)**2 - 2.25470184197397e+18)*cos(11*phi)

#@torch.jit.script
def Yl57_m12(theta, phi):
    return 3.57693805145655e-21*(1.0 - cos(theta)**2)**6*(3.64063159178875e+36*cos(theta)**45 - 3.18957989015121e+37*cos(theta)**43 + 1.29738317153448e+38*cos(theta)**41 - 3.25337676042285e+38*cos(theta)**39 + 5.63259855017134e+38*cos(theta)**37 - 7.14535358936021e+38*cos(theta)**35 + 6.87942619040344e+38*cos(theta)**33 - 5.13767613653892e+38*cos(theta)**31 + 3.01643864077096e+38*cos(theta)**29 - 1.40283400704812e+38*cos(theta)**27 + 5.18310248919884e+37*cos(theta)**25 - 1.51997140445714e+37*cos(theta)**23 + 3.52154547003348e+36*cos(theta)**21 - 6.39174199401064e+35*cos(theta)**19 + 8.97362792262577e+34*cos(theta)**17 - 9.57186978413416e+33*cos(theta)**15 + 7.56811993474463e+32*cos(theta)**13 - 4.28695246848279e+31*cos(theta)**11 + 1.65810397866775e+30*cos(theta)**9 - 4.08009181353649e+28*cos(theta)**7 + 5.71212853895109e+26*cos(theta)**5 - 3.72611124523881e+24*cos(theta)**3 + 7.15642364642537e+21*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl57_m13(theta, phi):
    return 6.37317937250722e-23*(1.0 - cos(theta)**2)**6.5*(1.63828421630494e+38*cos(theta)**44 - 1.37151935276502e+39*cos(theta)**42 + 5.31927100329136e+39*cos(theta)**40 - 1.26881693656491e+40*cos(theta)**38 + 2.08406146356339e+40*cos(theta)**36 - 2.50087375627607e+40*cos(theta)**34 + 2.27021064283313e+40*cos(theta)**32 - 1.59267960232706e+40*cos(theta)**30 + 8.74767205823577e+39*cos(theta)**28 - 3.78765181902992e+39*cos(theta)**26 + 1.29577562229971e+39*cos(theta)**24 - 3.49593423025142e+38*cos(theta)**22 + 7.39524548707031e+37*cos(theta)**20 - 1.21443097886202e+37*cos(theta)**18 + 1.52551674684638e+36*cos(theta)**16 - 1.43578046762012e+35*cos(theta)**14 + 9.83855591516801e+33*cos(theta)**12 - 4.71564771533107e+32*cos(theta)**10 + 1.49229358080097e+31*cos(theta)**8 - 2.85606426947555e+29*cos(theta)**6 + 2.85606426947555e+27*cos(theta)**4 - 1.11783337357164e+25*cos(theta)**2 + 7.15642364642537e+21)*cos(13*phi)

#@torch.jit.script
def Yl57_m14(theta, phi):
    return 1.14025143960594e-24*(1.0 - cos(theta)**2)**7*(7.20845055174173e+39*cos(theta)**43 - 5.76038128161308e+40*cos(theta)**41 + 2.12770840131654e+41*cos(theta)**39 - 4.82150435894666e+41*cos(theta)**37 + 7.50262126882822e+41*cos(theta)**35 - 8.50297077133865e+41*cos(theta)**33 + 7.26467405706603e+41*cos(theta)**31 - 4.77803880698119e+41*cos(theta)**29 + 2.44934817630602e+41*cos(theta)**27 - 9.8478947294778e+40*cos(theta)**25 + 3.1098614935193e+40*cos(theta)**23 - 7.69105530655312e+39*cos(theta)**21 + 1.47904909741406e+39*cos(theta)**19 - 2.18597576195164e+38*cos(theta)**17 + 2.44082679495421e+37*cos(theta)**15 - 2.01009265466817e+36*cos(theta)**13 + 1.18062670982016e+35*cos(theta)**11 - 4.71564771533107e+33*cos(theta)**9 + 1.19383486464078e+32*cos(theta)**7 - 1.71363856168533e+30*cos(theta)**5 + 1.14242570779022e+28*cos(theta)**3 - 2.23566674714328e+25*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl57_m15(theta, phi):
    return 2.04927458136536e-26*(1.0 - cos(theta)**2)**7.5*(3.09963373724894e+41*cos(theta)**42 - 2.36175632546136e+42*cos(theta)**40 + 8.29806276513452e+42*cos(theta)**38 - 1.78395661281027e+43*cos(theta)**36 + 2.62591744408988e+43*cos(theta)**34 - 2.80598035454175e+43*cos(theta)**32 + 2.25204895769047e+43*cos(theta)**30 - 1.38563125402455e+43*cos(theta)**28 + 6.61324007602624e+42*cos(theta)**26 - 2.46197368236945e+42*cos(theta)**24 + 7.1526814350944e+41*cos(theta)**22 - 1.61512161437615e+41*cos(theta)**20 + 2.81019328508672e+40*cos(theta)**18 - 3.71615879531778e+39*cos(theta)**16 + 3.66124019243131e+38*cos(theta)**14 - 2.61312045106862e+37*cos(theta)**12 + 1.29868938080218e+36*cos(theta)**10 - 4.24408294379797e+34*cos(theta)**8 + 8.35684405248545e+32*cos(theta)**6 - 8.56819280842664e+30*cos(theta)**4 + 3.42727712337065e+28*cos(theta)**2 - 2.23566674714328e+25)*cos(15*phi)

#@torch.jit.script
def Yl57_m16(theta, phi):
    return 3.70095733010574e-28*(1.0 - cos(theta)**2)**8*(1.30184616964456e+43*cos(theta)**41 - 9.44702530184545e+43*cos(theta)**39 + 3.15326385075112e+44*cos(theta)**37 - 6.42224380611696e+44*cos(theta)**35 + 8.92811930990558e+44*cos(theta)**33 - 8.97913713453361e+44*cos(theta)**31 + 6.75614687307141e+44*cos(theta)**29 - 3.87976751126873e+44*cos(theta)**27 + 1.71944241976682e+44*cos(theta)**25 - 5.90873683768668e+43*cos(theta)**23 + 1.57358991572077e+43*cos(theta)**21 - 3.23024322875231e+42*cos(theta)**19 + 5.05834791315609e+41*cos(theta)**17 - 5.94585407250845e+40*cos(theta)**15 + 5.12573626940384e+39*cos(theta)**13 - 3.13574454128235e+38*cos(theta)**11 + 1.29868938080218e+37*cos(theta)**9 - 3.39526635503837e+35*cos(theta)**7 + 5.01410643149127e+33*cos(theta)**5 - 3.42727712337066e+31*cos(theta)**3 + 6.85455424674131e+28*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl57_m17(theta, phi):
    return 6.71902550635047e-30*(1.0 - cos(theta)**2)**8.5*(5.33756929554268e+44*cos(theta)**40 - 3.68433986771973e+45*cos(theta)**38 + 1.16670762477791e+46*cos(theta)**36 - 2.24778533214093e+46*cos(theta)**34 + 2.94627937226884e+46*cos(theta)**32 - 2.78353251170542e+46*cos(theta)**30 + 1.95928259319071e+46*cos(theta)**28 - 1.04753722804256e+46*cos(theta)**26 + 4.29860604941706e+45*cos(theta)**24 - 1.35900947266794e+45*cos(theta)**22 + 3.30453882301361e+44*cos(theta)**20 - 6.13746213462939e+43*cos(theta)**18 + 8.59919145236535e+42*cos(theta)**16 - 8.91878110876268e+41*cos(theta)**14 + 6.66345715022499e+40*cos(theta)**12 - 3.44931899541058e+39*cos(theta)**10 + 1.16882044272196e+38*cos(theta)**8 - 2.37668644852686e+36*cos(theta)**6 + 2.50705321574563e+34*cos(theta)**4 - 1.0281831370112e+32*cos(theta)**2 + 6.85455424674131e+28)*cos(17*phi)

#@torch.jit.script
def Yl57_m18(theta, phi):
    return 1.22672061142691e-31*(1.0 - cos(theta)**2)**9*(2.13502771821707e+46*cos(theta)**39 - 1.4000491497335e+47*cos(theta)**37 + 4.20014744920049e+47*cos(theta)**35 - 7.64247012927918e+47*cos(theta)**33 + 9.42809399126029e+47*cos(theta)**31 - 8.35059753511626e+47*cos(theta)**29 + 5.48599126093398e+47*cos(theta)**27 - 2.72359679291065e+47*cos(theta)**25 + 1.03166545186009e+47*cos(theta)**23 - 2.98982083986946e+46*cos(theta)**21 + 6.60907764602723e+45*cos(theta)**19 - 1.10474318423329e+45*cos(theta)**17 + 1.37587063237846e+44*cos(theta)**15 - 1.24862935522678e+43*cos(theta)**13 + 7.99614858026999e+41*cos(theta)**11 - 3.44931899541058e+40*cos(theta)**9 + 9.35056354177568e+38*cos(theta)**7 - 1.42601186911612e+37*cos(theta)**5 + 1.00282128629825e+35*cos(theta)**3 - 2.05636627402239e+32*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl57_m19(theta, phi):
    return 2.25323538451753e-33*(1.0 - cos(theta)**2)**9.5*(8.32660810104658e+47*cos(theta)**38 - 5.18018185401394e+48*cos(theta)**36 + 1.47005160722017e+49*cos(theta)**34 - 2.52201514266213e+49*cos(theta)**32 + 2.92270913729069e+49*cos(theta)**30 - 2.42167328518372e+49*cos(theta)**28 + 1.48121764045218e+49*cos(theta)**26 - 6.80899198227662e+48*cos(theta)**24 + 2.37283053927822e+48*cos(theta)**22 - 6.27862376372586e+47*cos(theta)**20 + 1.25572475274517e+47*cos(theta)**18 - 1.87806341319659e+46*cos(theta)**16 + 2.06380594856768e+45*cos(theta)**14 - 1.62321816179481e+44*cos(theta)**12 + 8.79576343829699e+42*cos(theta)**10 - 3.10438709586953e+41*cos(theta)**8 + 6.54539447924298e+39*cos(theta)**6 - 7.13005934558058e+37*cos(theta)**4 + 3.00846385889476e+35*cos(theta)**2 - 2.05636627402239e+32)*cos(19*phi)

#@torch.jit.script
def Yl57_m20(theta, phi):
    return 4.16552170563493e-35*(1.0 - cos(theta)**2)**10*(3.1641110783977e+49*cos(theta)**37 - 1.86486546744502e+50*cos(theta)**35 + 4.99817546454858e+50*cos(theta)**33 - 8.07044845651881e+50*cos(theta)**31 + 8.76812741187207e+50*cos(theta)**29 - 6.7806851985144e+50*cos(theta)**27 + 3.85116586517566e+50*cos(theta)**25 - 1.63415807574639e+50*cos(theta)**23 + 5.22022718641208e+49*cos(theta)**21 - 1.25572475274517e+49*cos(theta)**19 + 2.26030455494131e+48*cos(theta)**17 - 3.00490146111455e+47*cos(theta)**15 + 2.88932832799476e+46*cos(theta)**13 - 1.94786179415377e+45*cos(theta)**11 + 8.79576343829699e+43*cos(theta)**9 - 2.48350967669562e+42*cos(theta)**7 + 3.92723668754579e+40*cos(theta)**5 - 2.85202373823223e+38*cos(theta)**3 + 6.01692771778952e+35*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl57_m21(theta, phi):
    return 7.75391861679337e-37*(1.0 - cos(theta)**2)**10.5*(1.17072109900715e+51*cos(theta)**36 - 6.52702913605756e+51*cos(theta)**34 + 1.64939790330103e+52*cos(theta)**32 - 2.50183902152083e+52*cos(theta)**30 + 2.5427569494429e+52*cos(theta)**28 - 1.83078500359889e+52*cos(theta)**26 + 9.62791466293914e+51*cos(theta)**24 - 3.75856357421669e+51*cos(theta)**22 + 1.09624770914654e+51*cos(theta)**20 - 2.38587703021583e+50*cos(theta)**18 + 3.84251774340023e+49*cos(theta)**16 - 4.50735219167182e+48*cos(theta)**14 + 3.75612682639319e+47*cos(theta)**12 - 2.14264797356915e+46*cos(theta)**10 + 7.91618709446729e+44*cos(theta)**8 - 1.73845677368693e+43*cos(theta)**6 + 1.96361834377289e+41*cos(theta)**4 - 8.5560712146967e+38*cos(theta)**2 + 6.01692771778952e+35)*cos(21*phi)

#@torch.jit.script
def Yl57_m22(theta, phi):
    return 1.45397333675321e-38*(1.0 - cos(theta)**2)**11*(4.21459595642574e+52*cos(theta)**35 - 2.21918990625957e+53*cos(theta)**33 + 5.2780732905633e+53*cos(theta)**31 - 7.5055170645625e+53*cos(theta)**29 + 7.11971945844012e+53*cos(theta)**27 - 4.76004100935711e+53*cos(theta)**25 + 2.31069951910539e+53*cos(theta)**23 - 8.26883986327673e+52*cos(theta)**21 + 2.19249541829307e+52*cos(theta)**19 - 4.29457865438849e+51*cos(theta)**17 + 6.14802838944037e+50*cos(theta)**15 - 6.31029306834055e+49*cos(theta)**13 + 4.50735219167182e+48*cos(theta)**11 - 2.14264797356915e+47*cos(theta)**9 + 6.33294967557383e+45*cos(theta)**7 - 1.04307406421216e+44*cos(theta)**5 + 7.85447337509157e+41*cos(theta)**3 - 1.71121424293934e+39*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl57_m23(theta, phi):
    return 2.74775132997698e-40*(1.0 - cos(theta)**2)**11.5*(1.47510858474901e+54*cos(theta)**34 - 7.32332669065658e+54*cos(theta)**32 + 1.63620272007462e+55*cos(theta)**30 - 2.17659994872312e+55*cos(theta)**28 + 1.92232425377883e+55*cos(theta)**26 - 1.19001025233928e+55*cos(theta)**24 + 5.31460889394241e+54*cos(theta)**22 - 1.73645637128811e+54*cos(theta)**20 + 4.16574129475684e+53*cos(theta)**18 - 7.30078371246043e+52*cos(theta)**16 + 9.22204258416055e+51*cos(theta)**14 - 8.20338098884272e+50*cos(theta)**12 + 4.95808741083901e+49*cos(theta)**10 - 1.92838317621223e+48*cos(theta)**8 + 4.43306477290168e+46*cos(theta)**6 - 5.2153703210608e+44*cos(theta)**4 + 2.35634201252747e+42*cos(theta)**2 - 1.71121424293934e+39)*cos(23*phi)

#@torch.jit.script
def Yl57_m24(theta, phi):
    return 5.23594961571665e-42*(1.0 - cos(theta)**2)**12*(5.01536918814663e+55*cos(theta)**33 - 2.34346454101011e+56*cos(theta)**31 + 4.90860816022387e+56*cos(theta)**29 - 6.09447985642475e+56*cos(theta)**27 + 4.99804305982497e+56*cos(theta)**25 - 2.85602460561427e+56*cos(theta)**23 + 1.16921395666733e+56*cos(theta)**21 - 3.47291274257623e+55*cos(theta)**19 + 7.49833433056231e+54*cos(theta)**17 - 1.16812539399367e+54*cos(theta)**15 + 1.29108596178248e+53*cos(theta)**13 - 9.84405718661126e+51*cos(theta)**11 + 4.95808741083901e+50*cos(theta)**9 - 1.54270654096979e+49*cos(theta)**7 + 2.65983886374101e+47*cos(theta)**5 - 2.08614812842432e+45*cos(theta)**3 + 4.71268402505494e+42*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl57_m25(theta, phi):
    return 1.00654121487048e-43*(1.0 - cos(theta)**2)**12.5*(1.65507183208839e+57*cos(theta)**32 - 7.26474007713133e+57*cos(theta)**30 + 1.42349636646492e+58*cos(theta)**28 - 1.64550956123468e+58*cos(theta)**26 + 1.24951076495624e+58*cos(theta)**24 - 6.56885659291281e+57*cos(theta)**22 + 2.45534930900139e+57*cos(theta)**20 - 6.59853421089483e+56*cos(theta)**18 + 1.27471683619559e+56*cos(theta)**16 - 1.7521880909905e+55*cos(theta)**14 + 1.67841175031722e+54*cos(theta)**12 - 1.08284629052724e+53*cos(theta)**10 + 4.4622786697551e+51*cos(theta)**8 - 1.07989457867885e+50*cos(theta)**6 + 1.3299194318705e+48*cos(theta)**4 - 6.25844438527296e+45*cos(theta)**2 + 4.71268402505494e+42)*cos(25*phi)

#@torch.jit.script
def Yl57_m26(theta, phi):
    return 1.95306873266703e-45*(1.0 - cos(theta)**2)**13*(5.29622986268284e+58*cos(theta)**31 - 2.1794220231394e+59*cos(theta)**29 + 3.98578982610178e+59*cos(theta)**27 - 4.27832485921017e+59*cos(theta)**25 + 2.99882583589498e+59*cos(theta)**23 - 1.44514845044082e+59*cos(theta)**21 + 4.91069861800278e+58*cos(theta)**19 - 1.18773615796107e+58*cos(theta)**17 + 2.03954693791295e+57*cos(theta)**15 - 2.45306332738671e+56*cos(theta)**13 + 2.01409410038066e+55*cos(theta)**11 - 1.08284629052724e+54*cos(theta)**9 + 3.56982293580408e+52*cos(theta)**7 - 6.4793674720731e+50*cos(theta)**5 + 5.31967772748202e+48*cos(theta)**3 - 1.25168887705459e+46*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl57_m27(theta, phi):
    return 3.82733993893246e-47*(1.0 - cos(theta)**2)**13.5*(1.64183125743168e+60*cos(theta)**30 - 6.32032386710426e+60*cos(theta)**28 + 1.07616325304748e+61*cos(theta)**26 - 1.06958121480254e+61*cos(theta)**24 + 6.89729942255845e+60*cos(theta)**22 - 3.03481174592572e+60*cos(theta)**20 + 9.33032737420529e+59*cos(theta)**18 - 2.01915146853382e+59*cos(theta)**16 + 3.05932040686942e+58*cos(theta)**14 - 3.18898232560272e+57*cos(theta)**12 + 2.21550351041873e+56*cos(theta)**10 - 9.74561661474515e+54*cos(theta)**8 + 2.49887605506286e+53*cos(theta)**6 - 3.23968373603655e+51*cos(theta)**4 + 1.59590331824461e+49*cos(theta)**2 - 1.25168887705459e+46)*cos(27*phi)

#@torch.jit.script
def Yl57_m28(theta, phi):
    return 7.57926247334093e-49*(1.0 - cos(theta)**2)**14*(4.92549377229504e+61*cos(theta)**29 - 1.76969068278919e+62*cos(theta)**27 + 2.79802445792345e+62*cos(theta)**25 - 2.5669949155261e+62*cos(theta)**23 + 1.51740587296286e+62*cos(theta)**21 - 6.06962349185144e+61*cos(theta)**19 + 1.67945892735695e+61*cos(theta)**17 - 3.23064234965411e+60*cos(theta)**15 + 4.28304856961719e+59*cos(theta)**13 - 3.82677879072326e+58*cos(theta)**11 + 2.21550351041873e+57*cos(theta)**9 - 7.79649329179612e+55*cos(theta)**7 + 1.49932563303772e+54*cos(theta)**5 - 1.29587349441462e+52*cos(theta)**3 + 3.19180663648921e+49*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl57_m29(theta, phi):
    return 1.51767479846544e-50*(1.0 - cos(theta)**2)**14.5*(1.42839319396556e+63*cos(theta)**28 - 4.77816484353082e+63*cos(theta)**26 + 6.99506114480863e+63*cos(theta)**24 - 5.90408830571004e+63*cos(theta)**22 + 3.18655233322201e+63*cos(theta)**20 - 1.15322846345177e+63*cos(theta)**18 + 2.85508017650682e+62*cos(theta)**16 - 4.84596352448116e+61*cos(theta)**14 + 5.56796314050235e+60*cos(theta)**12 - 4.20945666979559e+59*cos(theta)**10 + 1.99395315937686e+58*cos(theta)**8 - 5.45754530425728e+56*cos(theta)**6 + 7.49662816518858e+54*cos(theta)**4 - 3.88762048324386e+52*cos(theta)**2 + 3.19180663648921e+49)*cos(29*phi)

#@torch.jit.script
def Yl57_m30(theta, phi):
    return 3.07496431814581e-52*(1.0 - cos(theta)**2)**15*(3.99950094310357e+64*cos(theta)**27 - 1.24232285931801e+65*cos(theta)**25 + 1.67881467475407e+65*cos(theta)**23 - 1.29889942725621e+65*cos(theta)**21 + 6.37310466644401e+64*cos(theta)**19 - 2.07581123421319e+64*cos(theta)**17 + 4.56812828241091e+63*cos(theta)**15 - 6.78434893427363e+62*cos(theta)**13 + 6.68155576860281e+61*cos(theta)**11 - 4.20945666979559e+60*cos(theta)**9 + 1.59516252750149e+59*cos(theta)**7 - 3.27452718255437e+57*cos(theta)**5 + 2.99865126607543e+55*cos(theta)**3 - 7.77524096648772e+52*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl57_m31(theta, phi):
    return 6.30836571048026e-54*(1.0 - cos(theta)**2)**15.5*(1.07986525463796e+66*cos(theta)**26 - 3.10580714829503e+66*cos(theta)**24 + 3.86127375193436e+66*cos(theta)**22 - 2.72768879723804e+66*cos(theta)**20 + 1.21088988662436e+66*cos(theta)**18 - 3.52887909816243e+65*cos(theta)**16 + 6.85219242361636e+64*cos(theta)**14 - 8.81965361455572e+63*cos(theta)**12 + 7.3497113454631e+62*cos(theta)**10 - 3.78851100281603e+61*cos(theta)**8 + 1.11661376925104e+60*cos(theta)**6 - 1.63726359127718e+58*cos(theta)**4 + 8.99595379822629e+55*cos(theta)**2 - 7.77524096648772e+52)*cos(31*phi)

#@torch.jit.script
def Yl57_m32(theta, phi):
    return 1.31140001751088e-55*(1.0 - cos(theta)**2)**16*(2.80764966205871e+67*cos(theta)**25 - 7.45393715590808e+67*cos(theta)**23 + 8.4948022542556e+67*cos(theta)**21 - 5.45537759447607e+67*cos(theta)**19 + 2.17960179592385e+67*cos(theta)**17 - 5.64620655705988e+66*cos(theta)**15 + 9.59306939306291e+65*cos(theta)**13 - 1.05835843374669e+65*cos(theta)**11 + 7.3497113454631e+63*cos(theta)**9 - 3.03080880225282e+62*cos(theta)**7 + 6.69968261550624e+60*cos(theta)**5 - 6.54905436510874e+58*cos(theta)**3 + 1.79919075964526e+56*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl57_m33(theta, phi):
    return 2.76467398594605e-57*(1.0 - cos(theta)**2)**16.5*(7.01912415514677e+68*cos(theta)**24 - 1.71440554585886e+69*cos(theta)**22 + 1.78390847339368e+69*cos(theta)**20 - 1.03652174295045e+69*cos(theta)**18 + 3.70532305307055e+68*cos(theta)**16 - 8.46930983558983e+67*cos(theta)**14 + 1.24709902109818e+67*cos(theta)**12 - 1.16419427712135e+66*cos(theta)**10 + 6.61474021091679e+64*cos(theta)**8 - 2.12156616157698e+63*cos(theta)**6 + 3.34984130775312e+61*cos(theta)**4 - 1.96471630953262e+59*cos(theta)**2 + 1.79919075964526e+56)*cos(33*phi)

#@torch.jit.script
def Yl57_m34(theta, phi):
    return 5.91585620328789e-59*(1.0 - cos(theta)**2)**17*(1.68458979723523e+70*cos(theta)**23 - 3.77169220088949e+70*cos(theta)**21 + 3.56781694678735e+70*cos(theta)**19 - 1.86573913731082e+70*cos(theta)**17 + 5.92851688491288e+69*cos(theta)**15 - 1.18570337698258e+69*cos(theta)**13 + 1.49651882531781e+68*cos(theta)**11 - 1.16419427712135e+67*cos(theta)**9 + 5.29179216873343e+65*cos(theta)**7 - 1.27293969694619e+64*cos(theta)**5 + 1.33993652310125e+62*cos(theta)**3 - 3.92943261906524e+59*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl57_m35(theta, phi):
    return 1.28605569636693e-60*(1.0 - cos(theta)**2)**17.5*(3.87455653364102e+71*cos(theta)**22 - 7.92055362186792e+71*cos(theta)**20 + 6.77885219889597e+71*cos(theta)**18 - 3.17175653342839e+71*cos(theta)**16 + 8.89277532736932e+70*cos(theta)**14 - 1.54141439007735e+70*cos(theta)**12 + 1.6461707078496e+69*cos(theta)**10 - 1.04777484940922e+68*cos(theta)**8 + 3.7042545181134e+66*cos(theta)**6 - 6.36469848473093e+64*cos(theta)**4 + 4.01980956930374e+62*cos(theta)**2 - 3.92943261906524e+59)*cos(35*phi)

#@torch.jit.script
def Yl57_m36(theta, phi):
    return 2.84319706855925e-62*(1.0 - cos(theta)**2)**18*(8.52402437401024e+72*cos(theta)**21 - 1.58411072437358e+73*cos(theta)**19 + 1.22019339580127e+73*cos(theta)**17 - 5.07481045348542e+72*cos(theta)**15 + 1.2449885458317e+72*cos(theta)**13 - 1.84969726809282e+71*cos(theta)**11 + 1.6461707078496e+70*cos(theta)**9 - 8.38219879527375e+68*cos(theta)**7 + 2.22255271086804e+67*cos(theta)**5 - 2.54587939389237e+65*cos(theta)**3 + 8.03961913860749e+62*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl57_m37(theta, phi):
    return 6.39931352806817e-64*(1.0 - cos(theta)**2)**18.5*(1.79004511854215e+74*cos(theta)**20 - 3.00981037630981e+74*cos(theta)**18 + 2.07432877286217e+74*cos(theta)**16 - 7.61221568022814e+73*cos(theta)**14 + 1.61848510958122e+73*cos(theta)**12 - 2.0346669949021e+72*cos(theta)**10 + 1.48155363706464e+71*cos(theta)**8 - 5.86753915669163e+69*cos(theta)**6 + 1.11127635543402e+68*cos(theta)**4 - 7.63763818167711e+65*cos(theta)**2 + 8.03961913860749e+62)*cos(37*phi)

#@torch.jit.script
def Yl57_m38(theta, phi):
    return 1.46810320930957e-65*(1.0 - cos(theta)**2)**19*(3.5800902370843e+75*cos(theta)**19 - 5.41765867735766e+75*cos(theta)**17 + 3.31892603657947e+75*cos(theta)**15 - 1.06571019523194e+75*cos(theta)**13 + 1.94218213149746e+74*cos(theta)**11 - 2.0346669949021e+73*cos(theta)**9 + 1.18524290965171e+72*cos(theta)**7 - 3.52052349401498e+70*cos(theta)**5 + 4.44510542173608e+68*cos(theta)**3 - 1.52752763633542e+66*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl57_m39(theta, phi):
    return 3.43751158944224e-67*(1.0 - cos(theta)**2)**19.5*(6.80217145046017e+76*cos(theta)**18 - 9.21001975150802e+76*cos(theta)**16 + 4.9783890548692e+76*cos(theta)**14 - 1.38542325380152e+76*cos(theta)**12 + 2.1364003446472e+75*cos(theta)**10 - 1.83120029541189e+74*cos(theta)**8 + 8.29670036756196e+72*cos(theta)**6 - 1.76026174700749e+71*cos(theta)**4 + 1.33353162652082e+69*cos(theta)**2 - 1.52752763633542e+66)*cos(39*phi)

#@torch.jit.script
def Yl57_m40(theta, phi):
    return 8.22663163661029e-69*(1.0 - cos(theta)**2)**20*(1.22439086108283e+78*cos(theta)**17 - 1.47360316024128e+78*cos(theta)**15 + 6.96974467681688e+77*cos(theta)**13 - 1.66250790456182e+77*cos(theta)**11 + 2.1364003446472e+76*cos(theta)**9 - 1.46496023632951e+75*cos(theta)**7 + 4.97802022053718e+73*cos(theta)**5 - 7.04104698802995e+71*cos(theta)**3 + 2.66706325304165e+69*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl57_m41(theta, phi):
    return 2.01550812309609e-70*(1.0 - cos(theta)**2)**20.5*(2.08146446384081e+79*cos(theta)**16 - 2.21040474036192e+79*cos(theta)**14 + 9.06066807986194e+78*cos(theta)**12 - 1.82875869501801e+78*cos(theta)**10 + 1.92276031018248e+77*cos(theta)**8 - 1.02547216543066e+76*cos(theta)**6 + 2.48901011026859e+74*cos(theta)**4 - 2.11231409640899e+72*cos(theta)**2 + 2.66706325304165e+69)*cos(41*phi)

#@torch.jit.script
def Yl57_m42(theta, phi):
    return 5.06415470168423e-72*(1.0 - cos(theta)**2)**21*(3.3303431421453e+80*cos(theta)**15 - 3.09456663650669e+80*cos(theta)**13 + 1.08728016958343e+80*cos(theta)**11 - 1.82875869501801e+79*cos(theta)**9 + 1.53820824814599e+78*cos(theta)**7 - 6.15283299258395e+76*cos(theta)**5 + 9.95604044107435e+74*cos(theta)**3 - 4.22462819281797e+72*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl57_m43(theta, phi):
    return 1.30755912148274e-73*(1.0 - cos(theta)**2)**21.5*(4.99551471321795e+81*cos(theta)**14 - 4.0229366274587e+81*cos(theta)**12 + 1.19600818654178e+81*cos(theta)**10 - 1.64588282551621e+80*cos(theta)**8 + 1.07674577370219e+79*cos(theta)**6 - 3.07641649629197e+77*cos(theta)**4 + 2.98681213232231e+75*cos(theta)**2 - 4.22462819281797e+72)*cos(43*phi)

#@torch.jit.script
def Yl57_m44(theta, phi):
    return 3.4772557179411e-75*(1.0 - cos(theta)**2)**22*(6.99372059850513e+82*cos(theta)**13 - 4.82752395295044e+82*cos(theta)**11 + 1.19600818654178e+82*cos(theta)**9 - 1.31670626041297e+81*cos(theta)**7 + 6.46047464221315e+79*cos(theta)**5 - 1.23056659851679e+78*cos(theta)**3 + 5.97362426464461e+75*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl57_m45(theta, phi):
    return 9.54915335374865e-77*(1.0 - cos(theta)**2)**22.5*(9.09183677805667e+83*cos(theta)**12 - 5.31027634824549e+83*cos(theta)**10 + 1.0764073678876e+83*cos(theta)**8 - 9.21694382289076e+81*cos(theta)**6 + 3.23023732110657e+80*cos(theta)**4 - 3.69169979555037e+78*cos(theta)**2 + 5.97362426464461e+75)*cos(45*phi)

#@torch.jit.script
def Yl57_m46(theta, phi):
    return 2.71616177193322e-78*(1.0 - cos(theta)**2)**23*(1.0910204133668e+85*cos(theta)**11 - 5.31027634824549e+84*cos(theta)**9 + 8.61125894310079e+83*cos(theta)**7 - 5.53016629373445e+82*cos(theta)**5 + 1.29209492844263e+81*cos(theta)**3 - 7.38339959110074e+78*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl57_m47(theta, phi):
    return 8.03050062627893e-80*(1.0 - cos(theta)**2)**23.5*(1.20012245470348e+86*cos(theta)**10 - 4.77924871342094e+85*cos(theta)**8 + 6.02788126017056e+84*cos(theta)**6 - 2.76508314686723e+83*cos(theta)**4 + 3.87628478532789e+81*cos(theta)**2 - 7.38339959110074e+78)*cos(47*phi)

#@torch.jit.script
def Yl57_m48(theta, phi):
    return 2.47826629701503e-81*(1.0 - cos(theta)**2)**24*(1.20012245470348e+87*cos(theta)**9 - 3.82339897073675e+86*cos(theta)**7 + 3.61672875610233e+85*cos(theta)**5 - 1.10603325874689e+84*cos(theta)**3 + 7.75256957065578e+81*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl57_m49(theta, phi):
    return 8.02368339149063e-83*(1.0 - cos(theta)**2)**24.5*(1.08011020923313e+88*cos(theta)**8 - 2.67637927951573e+87*cos(theta)**6 + 1.80836437805117e+86*cos(theta)**4 - 3.31809977624067e+84*cos(theta)**2 + 7.75256957065578e+81)*cos(49*phi)

#@torch.jit.script
def Yl57_m50(theta, phi):
    return 2.74243852466226e-84*(1.0 - cos(theta)**2)**25*(8.64088167386506e+88*cos(theta)**7 - 1.60582756770944e+88*cos(theta)**5 + 7.23345751220467e+86*cos(theta)**3 - 6.63619955248134e+84*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl57_m51(theta, phi):
    return 9.97415248256175e-86*(1.0 - cos(theta)**2)**25.5*(6.04861717170554e+89*cos(theta)**6 - 8.02913783854718e+88*cos(theta)**4 + 2.1700372536614e+87*cos(theta)**2 - 6.63619955248134e+84)*cos(51*phi)

#@torch.jit.script
def Yl57_m52(theta, phi):
    return 3.90020225589779e-87*(1.0 - cos(theta)**2)**26*(3.62917030302332e+90*cos(theta)**5 - 3.21165513541887e+89*cos(theta)**3 + 4.3400745073228e+87*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl57_m53(theta, phi):
    return 1.66305182977835e-88*(1.0 - cos(theta)**2)**26.5*(1.81458515151166e+91*cos(theta)**4 - 9.63496540625661e+89*cos(theta)**2 + 4.3400745073228e+87)*cos(53*phi)

#@torch.jit.script
def Yl57_m54(theta, phi):
    return 7.89249470792474e-90*(1.0 - cos(theta)**2)**27*(7.25834060604665e+91*cos(theta)**3 - 1.92699308125132e+90*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl57_m55(theta, phi):
    return 4.30570885965518e-91*(1.0 - cos(theta)**2)**27.5*(2.17750218181399e+92*cos(theta)**2 - 1.92699308125132e+90)*cos(55*phi)

#@torch.jit.script
def Yl57_m56(theta, phi):
    return 12.4732330158048*(1.0 - cos(theta)**2)**28*cos(56*phi)*cos(theta)

#@torch.jit.script
def Yl57_m57(theta, phi):
    return 1.16822530671551*(1.0 - cos(theta)**2)**28.5*cos(57*phi)

#@torch.jit.script
def Yl58_m_minus_58(theta, phi):
    return 1.17324995487893*(1.0 - cos(theta)**2)**29*sin(58*phi)

#@torch.jit.script
def Yl58_m_minus_57(theta, phi):
    return 12.6362887339723*(1.0 - cos(theta)**2)**28.5*sin(57*phi)*cos(theta)

#@torch.jit.script
def Yl58_m_minus_56(theta, phi):
    return 3.82645864466199e-93*(1.0 - cos(theta)**2)**28*(2.50412750908609e+94*cos(theta)**2 - 2.17750218181399e+92)*sin(56*phi)

#@torch.jit.script
def Yl58_m_minus_55(theta, phi):
    return 7.07636257528082e-92*(1.0 - cos(theta)**2)**27.5*(8.34709169695365e+93*cos(theta)**3 - 2.17750218181399e+92*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl58_m_minus_54(theta, phi):
    return 1.50445531998027e-90*(1.0 - cos(theta)**2)**27*(2.08677292423841e+93*cos(theta)**4 - 1.088751090907e+92*cos(theta)**2 + 4.81748270312831e+89)*sin(54*phi)

#@torch.jit.script
def Yl58_m_minus_53(theta, phi):
    return 3.56019108124478e-89*(1.0 - cos(theta)**2)**26.5*(4.17354584847682e+92*cos(theta)**5 - 3.62917030302332e+91*cos(theta)**3 + 4.81748270312831e+89*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl58_m_minus_52(theta, phi):
    return 9.18777650810753e-88*(1.0 - cos(theta)**2)**26*(6.95590974746137e+91*cos(theta)**6 - 9.07292575755831e+90*cos(theta)**4 + 2.40874135156415e+89*cos(theta)**2 - 7.23345751220467e+86)*sin(52*phi)

#@torch.jit.script
def Yl58_m_minus_51(theta, phi):
    return 2.5495045129487e-86*(1.0 - cos(theta)**2)**25.5*(9.93701392494482e+90*cos(theta)**7 - 1.81458515151166e+90*cos(theta)**5 + 8.02913783854718e+88*cos(theta)**3 - 7.23345751220467e+86*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl58_m_minus_50(theta, phi):
    return 7.52859660499083e-85*(1.0 - cos(theta)**2)**25*(1.2421267406181e+90*cos(theta)**8 - 3.02430858585277e+89*cos(theta)**6 + 2.00728445963679e+88*cos(theta)**4 - 3.61672875610233e+86*cos(theta)**2 + 8.29524944060168e+83)*sin(50*phi)

#@torch.jit.script
def Yl58_m_minus_49(theta, phi):
    return 2.34718412931624e-83*(1.0 - cos(theta)**2)**24.5*(1.380140822909e+89*cos(theta)**9 - 4.32044083693253e+88*cos(theta)**7 + 4.01456891927359e+87*cos(theta)**5 - 1.20557625203411e+86*cos(theta)**3 + 8.29524944060168e+83*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl58_m_minus_48(theta, phi):
    return 7.67783984627058e-82*(1.0 - cos(theta)**2)**24*(1.380140822909e+88*cos(theta)**10 - 5.40055104616566e+87*cos(theta)**8 + 6.69094819878932e+86*cos(theta)**6 - 3.01394063008528e+85*cos(theta)**4 + 4.14762472030084e+83*cos(theta)**2 - 7.75256957065578e+80)*sin(48*phi)

#@torch.jit.script
def Yl58_m_minus_47(theta, phi):
    return 2.62173217560465e-80*(1.0 - cos(theta)**2)**23.5*(1.25467347537182e+87*cos(theta)**11 - 6.0006122735174e+86*cos(theta)**9 + 9.55849742684188e+85*cos(theta)**7 - 6.02788126017056e+84*cos(theta)**5 + 1.38254157343361e+83*cos(theta)**3 - 7.75256957065578e+80*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl58_m_minus_46(theta, phi):
    return 9.30622603247787e-79*(1.0 - cos(theta)**2)**23*(1.04556122947652e+86*cos(theta)**12 - 6.0006122735174e+85*cos(theta)**10 + 1.19481217835523e+85*cos(theta)**8 - 1.00464687669509e+84*cos(theta)**6 + 3.45635393358403e+82*cos(theta)**4 - 3.87628478532789e+80*cos(theta)**2 + 6.15283299258395e+77)*sin(46*phi)

#@torch.jit.script
def Yl58_m_minus_45(theta, phi):
    return 3.42185767810634e-77*(1.0 - cos(theta)**2)**22.5*(8.0427786882809e+84*cos(theta)**13 - 5.455102066834e+84*cos(theta)**11 + 1.32756908706137e+84*cos(theta)**9 - 1.43520982385013e+83*cos(theta)**7 + 6.91270786716807e+81*cos(theta)**5 - 1.29209492844263e+80*cos(theta)**3 + 6.15283299258395e+77*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl58_m_minus_44(theta, phi):
    return 1.29940511679801e-75*(1.0 - cos(theta)**2)**22*(5.74484192020064e+83*cos(theta)**14 - 4.54591838902833e+83*cos(theta)**12 + 1.32756908706137e+83*cos(theta)**10 - 1.79401227981266e+82*cos(theta)**8 + 1.15211797786134e+81*cos(theta)**6 - 3.23023732110657e+79*cos(theta)**4 + 3.07641649629197e+77*cos(theta)**2 - 4.26687447474615e+74)*sin(44*phi)

#@torch.jit.script
def Yl58_m_minus_43(theta, phi):
    return 5.08265097765732e-74*(1.0 - cos(theta)**2)**21.5*(3.8298946134671e+82*cos(theta)**15 - 3.49686029925257e+82*cos(theta)**13 + 1.20688098823761e+82*cos(theta)**11 - 1.99334697756963e+81*cos(theta)**9 + 1.64588282551621e+80*cos(theta)**7 - 6.46047464221315e+78*cos(theta)**5 + 1.02547216543066e+77*cos(theta)**3 - 4.26687447474615e+74*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl58_m_minus_42(theta, phi):
    return 2.04320040604098e-72*(1.0 - cos(theta)**2)**21*(2.39368413341693e+81*cos(theta)**16 - 2.49775735660898e+81*cos(theta)**14 + 1.00573415686468e+81*cos(theta)**12 - 1.99334697756963e+80*cos(theta)**10 + 2.05735353189526e+79*cos(theta)**8 - 1.07674577370219e+78*cos(theta)**6 + 2.56368041357665e+76*cos(theta)**4 - 2.13343723737308e+74*cos(theta)**2 + 2.64039262051123e+71)*sin(42*phi)

#@torch.jit.script
def Yl58_m_minus_41(theta, phi):
    return 8.42433108841187e-71*(1.0 - cos(theta)**2)**20.5*(1.40804949024526e+80*cos(theta)**17 - 1.66517157107265e+80*cos(theta)**15 + 7.73641659126674e+79*cos(theta)**13 - 1.81213361597239e+79*cos(theta)**11 + 2.28594836877251e+78*cos(theta)**9 - 1.53820824814599e+77*cos(theta)**7 + 5.12736082715329e+75*cos(theta)**5 - 7.11145745791025e+73*cos(theta)**3 + 2.64039262051123e+71*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl58_m_minus_40(theta, phi):
    return 3.55622537727517e-69*(1.0 - cos(theta)**2)**20*(7.8224971680292e+78*cos(theta)**18 - 1.04073223192041e+79*cos(theta)**16 + 5.52601185090481e+78*cos(theta)**14 - 1.51011134664366e+78*cos(theta)**12 + 2.28594836877251e+77*cos(theta)**10 - 1.92276031018248e+76*cos(theta)**8 + 8.54560137858882e+74*cos(theta)**6 - 1.77786436447756e+73*cos(theta)**4 + 1.32019631025562e+71*cos(theta)**2 - 1.48170180724536e+68)*sin(40*phi)

#@torch.jit.script
def Yl58_m_minus_39(theta, phi):
    return 1.53454318593721e-67*(1.0 - cos(theta)**2)**19.5*(4.11710377264695e+77*cos(theta)**19 - 6.12195430541416e+77*cos(theta)**17 + 3.68400790060321e+77*cos(theta)**15 - 1.16162411280281e+77*cos(theta)**13 + 2.07813488070228e+76*cos(theta)**11 - 2.1364003446472e+75*cos(theta)**9 + 1.22080019694126e+74*cos(theta)**7 - 3.55572872895513e+72*cos(theta)**5 + 4.40065436751872e+70*cos(theta)**3 - 1.48170180724536e+68*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl58_m_minus_38(theta, phi):
    return 6.75896161524998e-66*(1.0 - cos(theta)**2)**19*(2.05855188632347e+76*cos(theta)**20 - 3.40108572523009e+76*cos(theta)**18 + 2.30250493787701e+76*cos(theta)**16 - 8.29731509144867e+75*cos(theta)**14 + 1.7317790672519e+75*cos(theta)**12 - 2.1364003446472e+74*cos(theta)**10 + 1.52600024617657e+73*cos(theta)**8 - 5.92621454825854e+71*cos(theta)**6 + 1.10016359187968e+70*cos(theta)**4 - 7.4085090362268e+67*cos(theta)**2 + 7.63763818167712e+64)*sin(38*phi)

#@torch.jit.script
def Yl58_m_minus_37(theta, phi):
    return 3.0347662385546e-64*(1.0 - cos(theta)**2)**18.5*(9.80262803011178e+74*cos(theta)**21 - 1.79004511854215e+75*cos(theta)**19 + 1.35441466933941e+75*cos(theta)**17 - 5.53154339429911e+74*cos(theta)**15 + 1.33213774403992e+74*cos(theta)**13 - 1.94218213149746e+73*cos(theta)**11 + 1.69555582908508e+72*cos(theta)**9 - 8.46602078322649e+70*cos(theta)**7 + 2.20032718375936e+69*cos(theta)**5 - 2.4695030120756e+67*cos(theta)**3 + 7.63763818167712e+64*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl58_m_minus_36(theta, phi):
    return 1.38738944771762e-62*(1.0 - cos(theta)**2)**18*(4.45574001368717e+73*cos(theta)**22 - 8.95022559271075e+73*cos(theta)**20 + 7.52452594077453e+73*cos(theta)**18 - 3.45721462143694e+73*cos(theta)**16 + 9.51526960028517e+72*cos(theta)**14 - 1.61848510958122e+72*cos(theta)**12 + 1.69555582908508e+71*cos(theta)**10 - 1.05825259790331e+70*cos(theta)**8 + 3.66721197293227e+68*cos(theta)**6 - 6.173757530189e+66*cos(theta)**4 + 3.81881909083856e+64*cos(theta)**2 - 3.65437233573068e+61)*sin(36*phi)

#@torch.jit.script
def Yl58_m_minus_35(theta, phi):
    return 6.45098796695342e-61*(1.0 - cos(theta)**2)**17.5*(1.93727826682051e+72*cos(theta)**23 - 4.26201218700512e+72*cos(theta)**21 + 3.96027681093396e+72*cos(theta)**19 - 2.03365565966879e+72*cos(theta)**17 + 6.34351306685678e+71*cos(theta)**15 - 1.2449885458317e+71*cos(theta)**13 + 1.54141439007735e+70*cos(theta)**11 - 1.17583621989257e+69*cos(theta)**9 + 5.23887424704609e+67*cos(theta)**7 - 1.2347515060378e+66*cos(theta)**5 + 1.27293969694619e+64*cos(theta)**3 - 3.65437233573068e+61*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl58_m_minus_34(theta, phi):
    return 3.0477078028168e-59*(1.0 - cos(theta)**2)**17*(8.07199277841879e+70*cos(theta)**24 - 1.93727826682051e+71*cos(theta)**22 + 1.98013840546698e+71*cos(theta)**20 - 1.129808699816e+71*cos(theta)**18 + 3.96469566678549e+70*cos(theta)**16 - 8.89277532736932e+69*cos(theta)**14 + 1.28451199173112e+69*cos(theta)**12 - 1.17583621989257e+68*cos(theta)**10 + 6.54859280880762e+66*cos(theta)**8 - 2.05791917672967e+65*cos(theta)**6 + 3.18234924236546e+63*cos(theta)**4 - 1.82718616786534e+61*cos(theta)**2 + 1.63726359127718e+58)*sin(34*phi)

#@torch.jit.script
def Yl58_m_minus_33(theta, phi):
    return 1.4616293154595e-57*(1.0 - cos(theta)**2)**16.5*(3.22879711136752e+69*cos(theta)**25 - 8.42294898617613e+69*cos(theta)**23 + 9.42923050222372e+69*cos(theta)**21 - 5.94636157797892e+69*cos(theta)**19 + 2.33217392163852e+69*cos(theta)**17 - 5.92851688491288e+68*cos(theta)**15 + 9.8808614748548e+67*cos(theta)**13 - 1.06894201808415e+67*cos(theta)**11 + 7.27621423200847e+65*cos(theta)**9 - 2.93988453818524e+64*cos(theta)**7 + 6.36469848473093e+62*cos(theta)**5 - 6.09062055955113e+60*cos(theta)**3 + 1.63726359127718e+58*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl58_m_minus_32(theta, phi):
    return 7.10959096238867e-56*(1.0 - cos(theta)**2)**16*(1.24184504283366e+68*cos(theta)**26 - 3.50956207757339e+68*cos(theta)**24 + 4.28601386464714e+68*cos(theta)**22 - 2.97318078898946e+68*cos(theta)**20 + 1.29565217868807e+68*cos(theta)**18 - 3.70532305307055e+67*cos(theta)**16 + 7.05775819632485e+66*cos(theta)**14 - 8.90785015070127e+65*cos(theta)**12 + 7.27621423200846e+64*cos(theta)**10 - 3.67485567273155e+63*cos(theta)**8 + 1.06078308078849e+62*cos(theta)**6 - 1.52265513988778e+60*cos(theta)**4 + 8.18631795638592e+57*cos(theta)**2 - 6.91996446017407e+54)*sin(32*phi)

#@torch.jit.script
def Yl58_m_minus_31(theta, phi):
    return 3.50467501026163e-54*(1.0 - cos(theta)**2)**15.5*(4.59942608456911e+66*cos(theta)**27 - 1.40382483102935e+67*cos(theta)**25 + 1.86348428897702e+67*cos(theta)**23 - 1.41580037570927e+67*cos(theta)**21 + 6.81922199309509e+66*cos(theta)**19 - 2.17960179592385e+66*cos(theta)**17 + 4.70517213088324e+65*cos(theta)**15 - 6.85219242361636e+64*cos(theta)**13 + 6.61474021091679e+63*cos(theta)**11 - 4.08317296970172e+62*cos(theta)**9 + 1.51540440112641e+61*cos(theta)**7 - 3.04531027977556e+59*cos(theta)**5 + 2.72877265212864e+57*cos(theta)**3 - 6.91996446017407e+54*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl58_m_minus_30(theta, phi):
    return 1.74953151853462e-52*(1.0 - cos(theta)**2)**15*(1.6426521730604e+65*cos(theta)**28 - 5.39932627318982e+65*cos(theta)**26 + 7.76451787073758e+65*cos(theta)**24 - 6.43545625322394e+65*cos(theta)**22 + 3.40961099654755e+65*cos(theta)**20 - 1.21088988662436e+65*cos(theta)**18 + 2.94073258180202e+64*cos(theta)**16 - 4.89442315972597e+63*cos(theta)**14 + 5.51228350909732e+62*cos(theta)**12 - 4.08317296970172e+61*cos(theta)**10 + 1.89425550140801e+60*cos(theta)**8 - 5.07551713295927e+58*cos(theta)**6 + 6.8219316303216e+56*cos(theta)**4 - 3.45998223008703e+54*cos(theta)**2 + 2.77687177374561e+51)*sin(30*phi)

#@torch.jit.script
def Yl58_m_minus_29(theta, phi):
    return 8.83816501523427e-51*(1.0 - cos(theta)**2)**14.5*(5.6643178381393e+63*cos(theta)**29 - 1.99975047155179e+64*cos(theta)**27 + 3.10580714829503e+64*cos(theta)**25 - 2.79802445792345e+64*cos(theta)**23 + 1.62362428407026e+64*cos(theta)**21 - 6.37310466644401e+63*cos(theta)**19 + 1.72984269517766e+63*cos(theta)**17 - 3.26294877315065e+62*cos(theta)**15 + 4.24021808392102e+61*cos(theta)**13 - 3.71197542700156e+60*cos(theta)**11 + 2.10472833489779e+59*cos(theta)**9 - 7.25073876137039e+57*cos(theta)**7 + 1.36438632606432e+56*cos(theta)**5 - 1.15332741002901e+54*cos(theta)**3 + 2.77687177374561e+51*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl58_m_minus_28(theta, phi):
    return 4.51525580430714e-49*(1.0 - cos(theta)**2)**14*(1.88810594604643e+62*cos(theta)**30 - 7.14196596982781e+62*cos(theta)**28 + 1.1945412108827e+63*cos(theta)**26 - 1.16584352413477e+63*cos(theta)**24 + 7.38011038213755e+62*cos(theta)**22 - 3.18655233322201e+62*cos(theta)**20 + 9.61023719543145e+61*cos(theta)**18 - 2.03934298321916e+61*cos(theta)**16 + 3.02872720280073e+60*cos(theta)**14 - 3.09331285583464e+59*cos(theta)**12 + 2.10472833489779e+58*cos(theta)**10 - 9.06342345171299e+56*cos(theta)**8 + 2.2739772101072e+55*cos(theta)**6 - 2.88331852507253e+53*cos(theta)**4 + 1.38843588687281e+51*cos(theta)**2 - 1.0639355454964e+48)*sin(28*phi)

#@torch.jit.script
def Yl58_m_minus_27(theta, phi):
    return 2.33137659446573e-47*(1.0 - cos(theta)**2)**13.5*(6.09066434208527e+60*cos(theta)**31 - 2.46274688614752e+61*cos(theta)**29 + 4.42422670697298e+61*cos(theta)**27 - 4.66337409653909e+61*cos(theta)**25 + 3.20874364440763e+61*cos(theta)**23 - 1.51740587296286e+61*cos(theta)**21 + 5.05801957654287e+60*cos(theta)**19 - 1.19961351954068e+60*cos(theta)**17 + 2.01915146853382e+59*cos(theta)**15 - 2.3794714275651e+58*cos(theta)**13 + 1.91338939536163e+57*cos(theta)**11 - 1.00704705019033e+56*cos(theta)**9 + 3.24853887158172e+54*cos(theta)**7 - 5.76663705014506e+52*cos(theta)**5 + 4.62811962290936e+50*cos(theta)**3 - 1.0639355454964e+48*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl58_m_minus_26(theta, phi):
    return 1.21589727216593e-45*(1.0 - cos(theta)**2)**13*(1.90333260690165e+59*cos(theta)**32 - 8.2091562871584e+59*cos(theta)**30 + 1.58008096677606e+60*cos(theta)**28 - 1.7936054217458e+60*cos(theta)**26 + 1.33697651850318e+60*cos(theta)**24 - 6.89729942255845e+59*cos(theta)**22 + 2.52900978827143e+59*cos(theta)**20 - 6.66451955300378e+58*cos(theta)**18 + 1.26196966783364e+58*cos(theta)**16 - 1.69962244826079e+57*cos(theta)**14 + 1.59449116280136e+56*cos(theta)**12 - 1.00704705019033e+55*cos(theta)**10 + 4.06067358947715e+53*cos(theta)**8 - 9.61106175024176e+51*cos(theta)**6 + 1.15702990572734e+50*cos(theta)**4 - 5.31967772748202e+47*cos(theta)**2 + 3.9115277407956e+44)*sin(26*phi)

#@torch.jit.script
def Yl58_m_minus_25(theta, phi):
    return 6.40167315718996e-44*(1.0 - cos(theta)**2)**12.5*(5.76767456636862e+57*cos(theta)**33 - 2.64811493134142e+58*cos(theta)**31 + 5.4485550578485e+58*cos(theta)**29 - 6.64298304350297e+58*cos(theta)**27 + 5.34790607401271e+58*cos(theta)**25 - 2.99882583589498e+58*cos(theta)**23 + 1.20429037536735e+58*cos(theta)**21 - 3.50764187000199e+57*cos(theta)**19 + 7.42335098725668e+56*cos(theta)**17 - 1.13308163217386e+56*cos(theta)**15 + 1.22653166369335e+55*cos(theta)**13 - 9.15497318354847e+53*cos(theta)**11 + 4.51185954386349e+52*cos(theta)**9 - 1.37300882146311e+51*cos(theta)**7 + 2.31405981145468e+49*cos(theta)**5 - 1.77322590916067e+47*cos(theta)**3 + 3.9115277407956e+44*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl58_m_minus_24(theta, phi):
    return 3.40072881916237e-42*(1.0 - cos(theta)**2)**12*(1.69637487246136e+56*cos(theta)**34 - 8.27535916044194e+56*cos(theta)**32 + 1.81618501928283e+57*cos(theta)**30 - 2.3724939441082e+57*cos(theta)**28 + 2.05688695154335e+57*cos(theta)**26 - 1.24951076495624e+57*cos(theta)**24 + 5.47404716076068e+56*cos(theta)**22 - 1.75382093500099e+56*cos(theta)**20 + 4.12408388180927e+55*cos(theta)**18 - 7.08176020108662e+54*cos(theta)**16 + 8.76094045495252e+53*cos(theta)**14 - 7.62914431962373e+52*cos(theta)**12 + 4.51185954386349e+51*cos(theta)**10 - 1.71626102682889e+50*cos(theta)**8 + 3.85676635242446e+48*cos(theta)**6 - 4.43306477290168e+46*cos(theta)**4 + 1.9557638703978e+44*cos(theta)**2 - 1.38608353678087e+41)*sin(24*phi)

#@torch.jit.script
def Yl58_m_minus_23(theta, phi):
    return 1.82185139787118e-40*(1.0 - cos(theta)**2)**11.5*(4.8467853498896e+54*cos(theta)**35 - 2.50768459407331e+55*cos(theta)**33 + 5.85866135252527e+55*cos(theta)**31 - 8.18101360037312e+55*cos(theta)**29 + 7.61809982053093e+55*cos(theta)**27 - 4.99804305982497e+55*cos(theta)**25 + 2.38002050467856e+55*cos(theta)**23 - 8.3515282619095e+54*cos(theta)**21 + 2.17057046411014e+54*cos(theta)**19 - 4.16574129475684e+53*cos(theta)**17 + 5.84062696996835e+52*cos(theta)**15 - 5.86857255355671e+51*cos(theta)**13 + 4.10169049442136e+50*cos(theta)**11 - 1.90695669647654e+49*cos(theta)**9 + 5.50966621774923e+47*cos(theta)**7 - 8.86612954580337e+45*cos(theta)**5 + 6.519212901326e+43*cos(theta)**3 - 1.38608353678087e+41*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl58_m_minus_22(theta, phi):
    return 9.83799754850438e-39*(1.0 - cos(theta)**2)**11*(1.34632926385822e+53*cos(theta)**36 - 7.37554292374504e+53*cos(theta)**34 + 1.83083167266415e+54*cos(theta)**32 - 2.72700453345771e+54*cos(theta)**30 + 2.7207499359039e+54*cos(theta)**28 - 1.92232425377883e+54*cos(theta)**26 + 9.91675210282732e+53*cos(theta)**24 - 3.79614920995886e+53*cos(theta)**22 + 1.08528523205507e+53*cos(theta)**20 - 2.31430071930935e+52*cos(theta)**18 + 3.65039185623022e+51*cos(theta)**16 - 4.1918375382548e+50*cos(theta)**14 + 3.4180754120178e+49*cos(theta)**12 - 1.90695669647654e+48*cos(theta)**10 + 6.88708277218654e+46*cos(theta)**8 - 1.47768825763389e+45*cos(theta)**6 + 1.6298032253315e+43*cos(theta)**4 - 6.93041768390433e+40*cos(theta)**2 + 4.75337289705372e+37)*sin(22*phi)

#@torch.jit.script
def Yl58_m_minus_21(theta, phi):
    return 5.35244934083976e-37*(1.0 - cos(theta)**2)**10.5*(3.63872774015736e+51*cos(theta)**37 - 2.10729797821287e+52*cos(theta)**35 + 5.54797476564893e+52*cos(theta)**33 - 8.79678881760551e+52*cos(theta)**31 + 9.38189633070312e+52*cos(theta)**29 - 7.11971945844012e+52*cos(theta)**27 + 3.96670084113093e+52*cos(theta)**25 - 1.65049965650385e+52*cos(theta)**23 + 5.16802491454796e+51*cos(theta)**21 - 1.21805301016282e+51*cos(theta)**19 + 2.14728932719425e+50*cos(theta)**17 - 2.79455835883653e+49*cos(theta)**15 + 2.62928877847523e+48*cos(theta)**13 - 1.73359699679686e+47*cos(theta)**11 + 7.65231419131838e+45*cos(theta)**9 - 2.11098322519128e+44*cos(theta)**7 + 3.259606450663e+42*cos(theta)**5 - 2.31013922796811e+40*cos(theta)**3 + 4.75337289705372e+37*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl58_m_minus_20(theta, phi):
    return 2.93263429814664e-35*(1.0 - cos(theta)**2)**10*(9.57559931620357e+49*cos(theta)**38 - 5.85360549503575e+50*cos(theta)**36 + 1.63175728401439e+51*cos(theta)**34 - 2.74899650550172e+51*cos(theta)**32 + 3.12729877690104e+51*cos(theta)**30 - 2.5427569494429e+51*cos(theta)**28 + 1.52565416966574e+51*cos(theta)**26 - 6.87708190209939e+50*cos(theta)**24 + 2.34910223388543e+50*cos(theta)**22 - 6.09026505081409e+49*cos(theta)**20 + 1.19293851510791e+49*cos(theta)**18 - 1.74659897427283e+48*cos(theta)**16 + 1.87806341319659e+47*cos(theta)**14 - 1.44466416399738e+46*cos(theta)**12 + 7.65231419131838e+44*cos(theta)**10 - 2.6387290314891e+43*cos(theta)**8 + 5.43267741777167e+41*cos(theta)**6 - 5.77534806992027e+39*cos(theta)**4 + 2.37668644852686e+37*cos(theta)**2 - 1.58340203099724e+34)*sin(20*phi)

#@torch.jit.script
def Yl58_m_minus_19(theta, phi):
    return 1.6174747671886e-33*(1.0 - cos(theta)**2)**9.5*(2.45528187594963e+48*cos(theta)**39 - 1.58205553919885e+49*cos(theta)**37 + 4.66216366861254e+49*cos(theta)**35 - 8.3302924409143e+49*cos(theta)**33 + 1.00880605706485e+50*cos(theta)**31 - 8.76812741187207e+49*cos(theta)**29 + 5.650570998762e+49*cos(theta)**27 - 2.75083276083975e+49*cos(theta)**25 + 1.02134879734149e+49*cos(theta)**23 - 2.90012621467338e+48*cos(theta)**21 + 6.27862376372586e+47*cos(theta)**19 - 1.02741116133696e+47*cos(theta)**17 + 1.2520422754644e+46*cos(theta)**15 - 1.11128012615183e+45*cos(theta)**13 + 6.95664926483489e+43*cos(theta)**11 - 2.931921146099e+42*cos(theta)**9 + 7.76096773967381e+40*cos(theta)**7 - 1.15506961398405e+39*cos(theta)**5 + 7.9222881617562e+36*cos(theta)**3 - 1.58340203099724e+34*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl58_m_minus_18(theta, phi):
    return 8.97662065438591e-32*(1.0 - cos(theta)**2)**9*(6.13820468987408e+46*cos(theta)**40 - 4.16330405052329e+47*cos(theta)**38 + 1.29504546350348e+48*cos(theta)**36 - 2.45008601203362e+48*cos(theta)**34 + 3.15251892832766e+48*cos(theta)**32 - 2.92270913729069e+48*cos(theta)**30 + 2.01806107098643e+48*cos(theta)**28 - 1.05801260032298e+48*cos(theta)**26 + 4.25561998892289e+47*cos(theta)**24 - 1.3182391884879e+47*cos(theta)**22 + 3.13931188186293e+46*cos(theta)**20 - 5.70783978520533e+45*cos(theta)**18 + 7.82526422165247e+44*cos(theta)**16 - 7.93771518679879e+43*cos(theta)**14 + 5.79720772069574e+42*cos(theta)**12 - 2.931921146099e+41*cos(theta)**10 + 9.70120967459227e+39*cos(theta)**8 - 1.92511602330676e+38*cos(theta)**6 + 1.98057204043905e+36*cos(theta)**4 - 7.91701015498621e+33*cos(theta)**2 + 5.14091568505598e+30)*sin(18*phi)

#@torch.jit.script
def Yl58_m_minus_17(theta, phi):
    return 5.01085224736753e-30*(1.0 - cos(theta)**2)**8.5*(1.49712309509124e+45*cos(theta)**41 - 1.06751385910854e+46*cos(theta)**39 + 3.50012287433374e+46*cos(theta)**37 - 7.00024574866748e+46*cos(theta)**35 + 9.55308766159897e+46*cos(theta)**33 - 9.42809399126029e+46*cos(theta)**31 + 6.95883127926355e+46*cos(theta)**29 - 3.91856518638142e+46*cos(theta)**27 + 1.70224799556916e+46*cos(theta)**25 - 5.73147473255608e+45*cos(theta)**23 + 1.49491041993473e+45*cos(theta)**21 - 3.00412620273965e+44*cos(theta)**19 + 4.60309660097204e+43*cos(theta)**17 - 5.29181012453252e+42*cos(theta)**15 + 4.45939055438134e+41*cos(theta)**13 - 2.66538286009e+40*cos(theta)**11 + 1.07791218606581e+39*cos(theta)**9 - 2.75016574758108e+37*cos(theta)**7 + 3.9611440808781e+35*cos(theta)**5 - 2.6390033849954e+33*cos(theta)**3 + 5.14091568505598e+30*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl58_m_minus_16(theta, phi):
    return 2.81233384880933e-28*(1.0 - cos(theta)**2)**8*(3.56457879783629e+43*cos(theta)**42 - 2.66878464777134e+44*cos(theta)**40 + 9.21084966929932e+44*cos(theta)**38 - 1.94451270796319e+45*cos(theta)**36 + 2.80973166517617e+45*cos(theta)**34 - 2.94627937226884e+45*cos(theta)**32 + 2.31961042642118e+45*cos(theta)**30 - 1.39948756656479e+45*cos(theta)**28 + 6.54710767526598e+44*cos(theta)**26 - 2.38811447189837e+44*cos(theta)**24 + 6.79504736333968e+43*cos(theta)**22 - 1.50206310136982e+43*cos(theta)**20 + 2.55727588942891e+42*cos(theta)**18 - 3.30738132783283e+41*cos(theta)**16 + 3.18527896741524e+40*cos(theta)**14 - 2.22115238340833e+39*cos(theta)**12 + 1.07791218606581e+38*cos(theta)**10 - 3.43770718447635e+36*cos(theta)**8 + 6.6019068014635e+34*cos(theta)**6 - 6.59750846248851e+32*cos(theta)**4 + 2.57045784252799e+30*cos(theta)**2 - 1.6320367254146e+27)*sin(16*phi)

#@torch.jit.script
def Yl58_m_minus_15(theta, phi):
    return 1.58641556272998e-26*(1.0 - cos(theta)**2)**7.5*(8.28971813450299e+41*cos(theta)**43 - 6.50923084822278e+42*cos(theta)**41 + 2.36175632546136e+43*cos(theta)**39 - 5.25543975125186e+43*cos(theta)**37 + 8.0278047576462e+43*cos(theta)**35 - 8.92811930990558e+43*cos(theta)**33 + 7.48261427877801e+43*cos(theta)**31 - 4.82581919505101e+43*cos(theta)**29 + 2.42485469454296e+43*cos(theta)**27 - 9.55245788759346e+42*cos(theta)**25 + 2.95436841884334e+42*cos(theta)**23 - 7.1526814350944e+41*cos(theta)**21 + 1.3459346786468e+41*cos(theta)**19 - 1.94551842813696e+40*cos(theta)**17 + 2.12351931161016e+39*cos(theta)**15 - 1.70857875646795e+38*cos(theta)**13 + 9.79920169150734e+36*cos(theta)**11 - 3.81967464941817e+35*cos(theta)**9 + 9.43129543066215e+33*cos(theta)**7 - 1.3195016924977e+32*cos(theta)**5 + 8.56819280842664e+29*cos(theta)**3 - 1.6320367254146e+27*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl58_m_minus_14(theta, phi):
    return 8.99093235020825e-25*(1.0 - cos(theta)**2)**7*(1.88402684875068e+40*cos(theta)**44 - 1.54981686862447e+41*cos(theta)**42 + 5.90439081365341e+41*cos(theta)**40 - 1.38301046085575e+42*cos(theta)**38 + 2.22994576601283e+42*cos(theta)**36 - 2.62591744408988e+42*cos(theta)**34 + 2.33831696211813e+42*cos(theta)**32 - 1.60860639835034e+42*cos(theta)**30 + 8.66019533765341e+41*cos(theta)**28 - 3.67402226445902e+41*cos(theta)**26 + 1.23098684118472e+41*cos(theta)**24 - 3.25121883413382e+40*cos(theta)**22 + 6.72967339323398e+39*cos(theta)**20 - 1.0808435711872e+39*cos(theta)**18 + 1.32719956975635e+38*cos(theta)**16 - 1.2204133974771e+37*cos(theta)**14 + 8.16600140958945e+35*cos(theta)**12 - 3.81967464941817e+34*cos(theta)**10 + 1.17891192883277e+33*cos(theta)**8 - 2.19916948749617e+31*cos(theta)**6 + 2.14204820210666e+29*cos(theta)**4 - 8.16018362707299e+26*cos(theta)**2 + 5.08106078896201e+23)*sin(14*phi)

#@torch.jit.script
def Yl58_m_minus_13(theta, phi):
    return 5.11772841272677e-23*(1.0 - cos(theta)**2)**6.5*(4.18672633055707e+38*cos(theta)**45 - 3.60422527587087e+39*cos(theta)**43 + 1.44009532040327e+40*cos(theta)**41 - 3.54618066886091e+40*cos(theta)**39 + 6.02688044868333e+40*cos(theta)**37 - 7.50262126882822e+40*cos(theta)**35 + 7.08580897611554e+40*cos(theta)**33 - 5.18905289790431e+40*cos(theta)**31 + 2.98627425436325e+40*cos(theta)**29 - 1.36074898683668e+40*cos(theta)**27 + 4.9239473647389e+39*cos(theta)**25 - 1.41357340614514e+39*cos(theta)**23 + 3.20460637773047e+38*cos(theta)**21 - 5.68865037466947e+37*cos(theta)**19 + 7.80705629268442e+36*cos(theta)**17 - 8.13608931651403e+35*cos(theta)**15 + 6.28153954583804e+34*cos(theta)**13 - 3.47243149947106e+33*cos(theta)**11 + 1.30990214314752e+32*cos(theta)**9 - 3.1416706964231e+30*cos(theta)**7 + 4.28409640421332e+28*cos(theta)**5 - 2.72006120902433e+26*cos(theta)**3 + 5.08106078896201e+23*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl58_m_minus_12(theta, phi):
    return 2.92472693856372e-21*(1.0 - cos(theta)**2)**6*(9.10157897947188e+36*cos(theta)**46 - 8.19142108152469e+37*cos(theta)**44 + 3.42879838191255e+38*cos(theta)**42 - 8.86545167215227e+38*cos(theta)**40 + 1.58602117070614e+39*cos(theta)**38 - 2.08406146356339e+39*cos(theta)**36 + 2.08406146356339e+39*cos(theta)**34 - 1.6215790305951e+39*cos(theta)**32 + 9.95424751454416e+38*cos(theta)**30 - 4.85981781013098e+38*cos(theta)**28 + 1.89382590951496e+38*cos(theta)**26 - 5.88988919227141e+37*cos(theta)**24 + 1.45663926260476e+37*cos(theta)**22 - 2.84432518733473e+36*cos(theta)**20 + 4.33725349593579e+35*cos(theta)**18 - 5.08505582282127e+34*cos(theta)**16 + 4.48681396131288e+33*cos(theta)**14 - 2.89369291622589e+32*cos(theta)**12 + 1.30990214314752e+31*cos(theta)**10 - 3.92708837052888e+29*cos(theta)**8 + 7.14016067368886e+27*cos(theta)**6 - 6.80015302256082e+25*cos(theta)**4 + 2.54053039448101e+23*cos(theta)**2 - 1.55574427096204e+20)*sin(12*phi)

#@torch.jit.script
def Yl58_m_minus_11(theta, phi):
    return 1.67758013276199e-19*(1.0 - cos(theta)**2)**5.5*(1.93650616584508e+35*cos(theta)**47 - 1.82031579589438e+36*cos(theta)**45 + 7.97394972537802e+36*cos(theta)**43 - 2.1623052858908e+37*cos(theta)**41 + 4.06672095052856e+37*cos(theta)**39 - 5.63259855017134e+37*cos(theta)**37 + 5.95446132446684e+37*cos(theta)**35 - 4.91387585028817e+37*cos(theta)**33 + 3.21104758533682e+37*cos(theta)**31 - 1.67579924487275e+37*cos(theta)**29 + 7.0141700352406e+36*cos(theta)**27 - 2.35595567690856e+36*cos(theta)**25 + 6.33321418523808e+35*cos(theta)**23 - 1.35444056539749e+35*cos(theta)**21 + 2.28276499786094e+34*cos(theta)**19 - 2.99120930754192e+33*cos(theta)**17 + 2.99120930754192e+32*cos(theta)**15 - 2.22591762786607e+31*cos(theta)**13 + 1.19082013013411e+30*cos(theta)**11 - 4.36343152280986e+28*cos(theta)**9 + 1.02002295338412e+27*cos(theta)**7 - 1.36003060451216e+25*cos(theta)**5 + 8.46843464827002e+22*cos(theta)**3 - 1.55574427096204e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl58_m_minus_10(theta, phi):
    return 9.65447002029972e-18*(1.0 - cos(theta)**2)**5*(4.03438784551059e+33*cos(theta)**48 - 3.9572082519443e+34*cos(theta)**46 + 1.81226130122228e+35*cos(theta)**44 - 5.14834591878761e+35*cos(theta)**42 + 1.01668023763214e+36*cos(theta)**40 - 1.48226277636088e+36*cos(theta)**38 + 1.65401703457412e+36*cos(theta)**36 - 1.44525760302593e+36*cos(theta)**34 + 1.00345237041776e+36*cos(theta)**32 - 5.58599748290918e+35*cos(theta)**30 + 2.50506072687164e+35*cos(theta)**28 - 9.06136798810986e+34*cos(theta)**26 + 2.6388392438492e+34*cos(theta)**24 - 6.15654802453405e+33*cos(theta)**22 + 1.14138249893047e+33*cos(theta)**20 - 1.6617829486344e+32*cos(theta)**18 + 1.8695058172137e+31*cos(theta)**16 - 1.58994116276148e+30*cos(theta)**14 + 9.92350108445091e+28*cos(theta)**12 - 4.36343152280986e+27*cos(theta)**10 + 1.27502869173015e+26*cos(theta)**8 - 2.26671767418694e+24*cos(theta)**6 + 2.1171086620675e+22*cos(theta)**4 - 7.77872135481018e+19*cos(theta)**2 + 4.69729550411243e+16)*sin(10*phi)

#@torch.jit.script
def Yl58_m_minus_9(theta, phi):
    return 5.57289595142768e-16*(1.0 - cos(theta)**2)**4.5*(8.23344458267467e+31*cos(theta)**49 - 8.4195920254134e+32*cos(theta)**47 + 4.02724733604951e+33*cos(theta)**45 - 1.19728974855526e+34*cos(theta)**43 + 2.47970789666376e+34*cos(theta)**41 - 3.80067378554071e+34*cos(theta)**39 + 4.47031630965979e+34*cos(theta)**37 - 4.12930743721695e+34*cos(theta)**35 + 3.04076475884169e+34*cos(theta)**33 - 1.80193467190619e+34*cos(theta)**31 + 8.63814043748842e+33*cos(theta)**29 - 3.35606221781847e+33*cos(theta)**27 + 1.05553569753968e+33*cos(theta)**25 - 2.67676001066698e+32*cos(theta)**23 + 5.43515475681177e+31*cos(theta)**21 - 8.74622604544422e+30*cos(theta)**19 + 1.09970930424335e+30*cos(theta)**17 - 1.05996077517432e+29*cos(theta)**15 + 7.63346237265455e+27*cos(theta)**13 - 3.96675592982715e+26*cos(theta)**11 + 1.41669854636684e+25*cos(theta)**9 - 3.23816810598134e+23*cos(theta)**7 + 4.23421732413501e+21*cos(theta)**5 - 2.59290711827006e+19*cos(theta)**3 + 4.69729550411243e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl58_m_minus_8(theta, phi):
    return 3.22554673049734e-14*(1.0 - cos(theta)**2)**4*(1.64668891653493e+30*cos(theta)**50 - 1.75408167196112e+31*cos(theta)**48 + 8.7548855131511e+31*cos(theta)**46 - 2.72111306489831e+32*cos(theta)**44 + 5.904066420628e+32*cos(theta)**42 - 9.50168446385178e+32*cos(theta)**40 + 1.17639902885784e+33*cos(theta)**38 - 1.14702984367137e+33*cos(theta)**36 + 8.94342576129909e+32*cos(theta)**34 - 5.63104584970683e+32*cos(theta)**32 + 2.87938014582947e+32*cos(theta)**30 - 1.19859364922088e+32*cos(theta)**28 + 4.05975268284492e+31*cos(theta)**26 - 1.11531667111124e+31*cos(theta)**24 + 2.47052488945989e+30*cos(theta)**22 - 4.37311302272211e+29*cos(theta)**20 + 6.1094961346853e+28*cos(theta)**18 - 6.62475484483948e+27*cos(theta)**16 + 5.45247312332468e+26*cos(theta)**14 - 3.30562994152262e+25*cos(theta)**12 + 1.41669854636684e+24*cos(theta)**10 - 4.04771013247668e+22*cos(theta)**8 + 7.05702887355835e+20*cos(theta)**6 - 6.48226779567515e+18*cos(theta)**4 + 2.34864775205621e+16*cos(theta)**2 - 14021777624216.2)*sin(8*phi)

#@torch.jit.script
def Yl58_m_minus_7(theta, phi):
    return 1.87137314980081e-12*(1.0 - cos(theta)**2)**3.5*(3.22880179712732e+28*cos(theta)**51 - 3.57975851420638e+29*cos(theta)**49 + 1.86274159854279e+30*cos(theta)**47 - 6.04691792199626e+30*cos(theta)**45 + 1.37303870247163e+31*cos(theta)**43 - 2.31748401557361e+31*cos(theta)**41 + 3.01640776630215e+31*cos(theta)**39 - 3.10008065857128e+31*cos(theta)**37 + 2.55526450322831e+31*cos(theta)**35 - 1.70637753021419e+31*cos(theta)**33 + 9.28832305106282e+30*cos(theta)**31 - 4.13308154903752e+30*cos(theta)**29 + 1.50361210475738e+30*cos(theta)**27 - 4.46126668444497e+29*cos(theta)**25 + 1.07414125628691e+29*cos(theta)**23 - 2.08243477272481e+28*cos(theta)**21 + 3.21552428141332e+27*cos(theta)**19 - 3.89691461461146e+26*cos(theta)**17 + 3.63498208221645e+25*cos(theta)**15 - 2.54279226270971e+24*cos(theta)**13 + 1.2879077694244e+23*cos(theta)**11 - 4.49745570275187e+21*cos(theta)**9 + 1.00814698193691e+20*cos(theta)**7 - 1.29645355913503e+18*cos(theta)**5 + 7.82882584018738e+15*cos(theta)**3 - 14021777624216.2*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl58_m_minus_6(theta, phi):
    return 1.08797456929785e-10*(1.0 - cos(theta)**2)**3*(6.20923422524485e+26*cos(theta)**52 - 7.15951702841275e+27*cos(theta)**50 + 3.88071166363081e+28*cos(theta)**48 - 1.31454737434701e+29*cos(theta)**46 + 3.12054250561733e+29*cos(theta)**44 - 5.51781908469906e+29*cos(theta)**42 + 7.54101941575538e+29*cos(theta)**40 - 8.15810699624022e+29*cos(theta)**38 + 7.09795695341197e+29*cos(theta)**36 - 5.01875744180645e+29*cos(theta)**34 + 2.90260095345713e+29*cos(theta)**32 - 1.37769384967917e+29*cos(theta)**30 + 5.37004323127635e+28*cos(theta)**28 - 1.7158718017096e+28*cos(theta)**26 + 4.47558856786213e+27*cos(theta)**24 - 9.46561260329461e+26*cos(theta)**22 + 1.60776214070666e+26*cos(theta)**20 - 2.16495256367303e+25*cos(theta)**18 + 2.27186380138528e+24*cos(theta)**16 - 1.81628018764979e+23*cos(theta)**14 + 1.07325647452033e+22*cos(theta)**12 - 4.49745570275187e+20*cos(theta)**10 + 1.26018372742113e+19*cos(theta)**8 - 2.16075593189172e+17*cos(theta)**6 + 1.95720646004685e+15*cos(theta)**4 - 7010888812108.1*cos(theta)**2 + 4148454918.40716)*sin(6*phi)

#@torch.jit.script
def Yl58_m_minus_5(theta, phi):
    return 6.33645953698479e-9*(1.0 - cos(theta)**2)**2.5*(1.17155362740469e+25*cos(theta)**53 - 1.40382686831623e+26*cos(theta)**51 + 7.91981972169552e+26*cos(theta)**49 - 2.7969093071213e+27*cos(theta)**47 + 6.93453890137185e+27*cos(theta)**45 - 1.28321374062769e+28*cos(theta)**43 + 1.83927302823302e+28*cos(theta)**41 - 2.09182230672826e+28*cos(theta)**39 + 1.9183667441654e+28*cos(theta)**37 - 1.43393069765898e+28*cos(theta)**35 + 8.79576046502161e+27*cos(theta)**33 - 4.4441737086425e+27*cos(theta)**31 + 1.85173904526771e+27*cos(theta)**29 - 6.3550807470726e+26*cos(theta)**27 + 1.79023542714485e+26*cos(theta)**25 - 4.11548374056287e+25*cos(theta)**23 + 7.65601019384123e+24*cos(theta)**21 - 1.13944871772265e+24*cos(theta)**19 + 1.33639047140311e+23*cos(theta)**17 - 1.2108534584332e+22*cos(theta)**15 + 8.25581903477178e+20*cos(theta)**13 - 4.08859609341079e+19*cos(theta)**11 + 1.40020414157904e+18*cos(theta)**9 - 3.08679418841674e+16*cos(theta)**7 + 391441292009369.0*cos(theta)**5 - 2336962937369.37*cos(theta)**3 + 4148454918.40716*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl58_m_minus_4(theta, phi):
    return 3.69584560846368e-7*(1.0 - cos(theta)**2)**2*(2.16954375445313e+23*cos(theta)**54 - 2.69966705445428e+24*cos(theta)**52 + 1.5839639443391e+25*cos(theta)**50 - 5.82689438983605e+25*cos(theta)**48 + 1.50750845681997e+26*cos(theta)**46 - 2.91639486506293e+26*cos(theta)**44 + 4.37922149579291e+26*cos(theta)**42 - 5.22955576682065e+26*cos(theta)**40 + 5.04833353727736e+26*cos(theta)**38 - 3.98314082683051e+26*cos(theta)**36 + 2.58698837206518e+26*cos(theta)**34 - 1.38880428395078e+26*cos(theta)**32 + 6.17246348422569e+25*cos(theta)**30 - 2.26967169538307e+25*cos(theta)**28 + 6.88552087363404e+24*cos(theta)**26 - 1.7147848919012e+24*cos(theta)**24 + 3.4800046335642e+23*cos(theta)**22 - 5.69724358861325e+22*cos(theta)**20 + 7.42439150779504e+21*cos(theta)**18 - 7.56783411520747e+20*cos(theta)**16 + 5.89701359626556e+19*cos(theta)**14 - 3.40716341117566e+18*cos(theta)**12 + 1.40020414157904e+17*cos(theta)**10 - 3.85849273552092e+15*cos(theta)**8 + 65240215334894.8*cos(theta)**6 - 584240734342.342*cos(theta)**4 + 2074227459.20358*cos(theta)**2 - 1219416.49571051)*sin(4*phi)

#@torch.jit.script
def Yl58_m_minus_3(theta, phi):
    return 2.15819662999127e-5*(1.0 - cos(theta)**2)**1.5*(3.94462500809659e+21*cos(theta)**55 - 5.09371142349864e+22*cos(theta)**53 + 3.10581165556687e+23*cos(theta)**51 - 1.1891621203747e+24*cos(theta)**49 + 3.20746480174461e+24*cos(theta)**47 - 6.48087747791762e+24*cos(theta)**45 + 1.01842360367277e+25*cos(theta)**43 - 1.27550140654162e+25*cos(theta)**41 + 1.29444449673779e+25*cos(theta)**39 - 1.07652454779203e+25*cos(theta)**37 + 7.39139534875765e+24*cos(theta)**35 - 4.20849783015388e+24*cos(theta)**33 + 1.99111725297603e+24*cos(theta)**31 - 7.82645412201059e+23*cos(theta)**29 + 2.55019291616076e+23*cos(theta)**27 - 6.85913956760479e+22*cos(theta)**25 + 1.513045492854e+22*cos(theta)**23 - 2.71297313743488e+21*cos(theta)**21 + 3.90757447778686e+20*cos(theta)**19 - 4.45166712659263e+19*cos(theta)**17 + 3.93134239751037e+18*cos(theta)**15 - 2.62089493167358e+17*cos(theta)**13 + 1.27291285598094e+16*cos(theta)**11 - 428721415057880.0*cos(theta)**9 + 9320030762127.83*cos(theta)**7 - 116848146868.468*cos(theta)**5 + 691409153.06786*cos(theta)**3 - 1219416.49571051*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl58_m_minus_2(theta, phi):
    return 0.0012613916188757*(1.0 - cos(theta)**2)*(7.04397322874392e+19*cos(theta)**56 - 9.4327989324049e+20*cos(theta)**54 + 5.97271472224398e+21*cos(theta)**52 - 2.37832424074941e+22*cos(theta)**50 + 6.68221833696794e+22*cos(theta)**48 - 1.40888640824296e+23*cos(theta)**46 + 2.31459909925629e+23*cos(theta)**44 - 3.03690811081339e+23*cos(theta)**42 + 3.23611124184446e+23*cos(theta)**40 - 2.83295933629482e+23*cos(theta)**38 + 2.0531653746549e+23*cos(theta)**36 - 1.23779347945702e+23*cos(theta)**34 + 6.22224141555009e+22*cos(theta)**32 - 2.6088180406702e+22*cos(theta)**30 + 9.10783184343127e+21*cos(theta)**28 - 2.63813060292492e+21*cos(theta)**26 + 6.30435622022499e+20*cos(theta)**24 - 1.23316960792495e+20*cos(theta)**22 + 1.95378723889343e+19*cos(theta)**20 - 2.47314840366257e+18*cos(theta)**18 + 2.45708899844398e+17*cos(theta)**16 - 1.87206780833827e+16*cos(theta)**14 + 1.06076071331745e+15*cos(theta)**12 - 42872141505788.0*cos(theta)**10 + 1165003845265.98*cos(theta)**8 - 19474691144.7447*cos(theta)**6 + 172852288.266965*cos(theta)**4 - 609708.247855256*cos(theta)**2 + 356.972042069822)*sin(2*phi)

#@torch.jit.script
def Yl58_m_minus_1(theta, phi):
    return 0.0737671481846826*(1.0 - cos(theta)**2)**0.5*(1.23578477697262e+18*cos(theta)**57 - 1.71505435134634e+19*cos(theta)**55 + 1.12692730608377e+20*cos(theta)**53 - 4.66338086421452e+20*cos(theta)**51 + 1.36371802795264e+21*cos(theta)**49 - 2.99763065583609e+21*cos(theta)**47 + 5.14355355390287e+21*cos(theta)**45 - 7.0625770018916e+21*cos(theta)**43 + 7.89295424840113e+21*cos(theta)**41 - 7.26399829819184e+21*cos(theta)**39 + 5.54909560717541e+21*cos(theta)**37 - 3.53655279844864e+21*cos(theta)**35 + 1.88552770168185e+21*cos(theta)**33 - 8.41554206667806e+20*cos(theta)**31 + 3.14063167014871e+20*cos(theta)**29 - 9.77085408490711e+19*cos(theta)**27 + 2.52174248809e+19*cos(theta)**25 - 5.36160699097802e+18*cos(theta)**23 + 9.30374875663539e+17*cos(theta)**21 - 1.30165705455925e+17*cos(theta)**19 + 1.44534646967293e+16*cos(theta)**17 - 1.24804520555885e+15*cos(theta)**15 + 81596977947496.3*cos(theta)**13 - 3897467409617.09*cos(theta)**11 + 129444871696.22*cos(theta)**9 - 2782098734.96353*cos(theta)**7 + 34570457.653393*cos(theta)**5 - 203236.082618419*cos(theta)**3 + 356.972042069822*cos(theta))*sin(phi)

#@torch.jit.script
def Yl58_m0(theta, phi):
    return 2.04245604519822e+17*cos(theta)**58 - 2.93580855888058e+18*cos(theta)**56 + 2.00050671711331e+19*cos(theta)**54 - 8.59677210867613e+19*cos(theta)**52 + 2.61452289360196e+20*cos(theta)**50 - 5.98652438254654e+20*cos(theta)**48 + 1.07187293706548e+21*cos(theta)**46 - 1.5386802910718e+21*cos(theta)**44 + 1.8014746972202e+21*cos(theta)**42 - 1.74081898350908e+21*cos(theta)**40 + 1.39983382179081e+21*cos(theta)**38 - 9.41706389204727e+20*cos(theta)**36 + 5.31608445518797e+20*cos(theta)**34 - 2.52098341450588e+20*cos(theta)**32 + 1.00353753900073e+20*cos(theta)**30 - 3.34512513000245e+19*cos(theta)**28 + 9.2974801407421e+18*cos(theta)**26 - 2.1415173959895e+18*cos(theta)**24 + 4.05390124343691e+17*cos(theta)**22 - 6.23884868243788e+16*cos(theta)**20 + 7.69728084196882e+15*cos(theta)**18 - 747735853219828.0*cos(theta)**16 + 55870673964121.6*cos(theta)**14 - 3113430086181.92*cos(theta)**12 + 124085981695.656*cos(theta)**10 - 3333653239.58479*cos(theta)**8 + 55232124.6795113*cos(theta)**6 - 487055.773187931*cos(theta)**4 + 1710.96875827142*cos(theta)**2 - 0.999981740661262

#@torch.jit.script
def Yl58_m1(theta, phi):
    return 0.0737671481846826*(1.0 - cos(theta)**2)**0.5*(1.23578477697262e+18*cos(theta)**57 - 1.71505435134634e+19*cos(theta)**55 + 1.12692730608377e+20*cos(theta)**53 - 4.66338086421452e+20*cos(theta)**51 + 1.36371802795264e+21*cos(theta)**49 - 2.99763065583609e+21*cos(theta)**47 + 5.14355355390287e+21*cos(theta)**45 - 7.0625770018916e+21*cos(theta)**43 + 7.89295424840113e+21*cos(theta)**41 - 7.26399829819184e+21*cos(theta)**39 + 5.54909560717541e+21*cos(theta)**37 - 3.53655279844864e+21*cos(theta)**35 + 1.88552770168185e+21*cos(theta)**33 - 8.41554206667806e+20*cos(theta)**31 + 3.14063167014871e+20*cos(theta)**29 - 9.77085408490711e+19*cos(theta)**27 + 2.52174248809e+19*cos(theta)**25 - 5.36160699097802e+18*cos(theta)**23 + 9.30374875663539e+17*cos(theta)**21 - 1.30165705455925e+17*cos(theta)**19 + 1.44534646967293e+16*cos(theta)**17 - 1.24804520555885e+15*cos(theta)**15 + 81596977947496.3*cos(theta)**13 - 3897467409617.09*cos(theta)**11 + 129444871696.22*cos(theta)**9 - 2782098734.96353*cos(theta)**7 + 34570457.653393*cos(theta)**5 - 203236.082618419*cos(theta)**3 + 356.972042069822*cos(theta))*cos(phi)

#@torch.jit.script
def Yl58_m2(theta, phi):
    return 0.0012613916188757*(1.0 - cos(theta)**2)*(7.04397322874392e+19*cos(theta)**56 - 9.4327989324049e+20*cos(theta)**54 + 5.97271472224398e+21*cos(theta)**52 - 2.37832424074941e+22*cos(theta)**50 + 6.68221833696794e+22*cos(theta)**48 - 1.40888640824296e+23*cos(theta)**46 + 2.31459909925629e+23*cos(theta)**44 - 3.03690811081339e+23*cos(theta)**42 + 3.23611124184446e+23*cos(theta)**40 - 2.83295933629482e+23*cos(theta)**38 + 2.0531653746549e+23*cos(theta)**36 - 1.23779347945702e+23*cos(theta)**34 + 6.22224141555009e+22*cos(theta)**32 - 2.6088180406702e+22*cos(theta)**30 + 9.10783184343127e+21*cos(theta)**28 - 2.63813060292492e+21*cos(theta)**26 + 6.30435622022499e+20*cos(theta)**24 - 1.23316960792495e+20*cos(theta)**22 + 1.95378723889343e+19*cos(theta)**20 - 2.47314840366257e+18*cos(theta)**18 + 2.45708899844398e+17*cos(theta)**16 - 1.87206780833827e+16*cos(theta)**14 + 1.06076071331745e+15*cos(theta)**12 - 42872141505788.0*cos(theta)**10 + 1165003845265.98*cos(theta)**8 - 19474691144.7447*cos(theta)**6 + 172852288.266965*cos(theta)**4 - 609708.247855256*cos(theta)**2 + 356.972042069822)*cos(2*phi)

#@torch.jit.script
def Yl58_m3(theta, phi):
    return 2.15819662999127e-5*(1.0 - cos(theta)**2)**1.5*(3.94462500809659e+21*cos(theta)**55 - 5.09371142349864e+22*cos(theta)**53 + 3.10581165556687e+23*cos(theta)**51 - 1.1891621203747e+24*cos(theta)**49 + 3.20746480174461e+24*cos(theta)**47 - 6.48087747791762e+24*cos(theta)**45 + 1.01842360367277e+25*cos(theta)**43 - 1.27550140654162e+25*cos(theta)**41 + 1.29444449673779e+25*cos(theta)**39 - 1.07652454779203e+25*cos(theta)**37 + 7.39139534875765e+24*cos(theta)**35 - 4.20849783015388e+24*cos(theta)**33 + 1.99111725297603e+24*cos(theta)**31 - 7.82645412201059e+23*cos(theta)**29 + 2.55019291616076e+23*cos(theta)**27 - 6.85913956760479e+22*cos(theta)**25 + 1.513045492854e+22*cos(theta)**23 - 2.71297313743488e+21*cos(theta)**21 + 3.90757447778686e+20*cos(theta)**19 - 4.45166712659263e+19*cos(theta)**17 + 3.93134239751037e+18*cos(theta)**15 - 2.62089493167358e+17*cos(theta)**13 + 1.27291285598094e+16*cos(theta)**11 - 428721415057880.0*cos(theta)**9 + 9320030762127.83*cos(theta)**7 - 116848146868.468*cos(theta)**5 + 691409153.06786*cos(theta)**3 - 1219416.49571051*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl58_m4(theta, phi):
    return 3.69584560846368e-7*(1.0 - cos(theta)**2)**2*(2.16954375445313e+23*cos(theta)**54 - 2.69966705445428e+24*cos(theta)**52 + 1.5839639443391e+25*cos(theta)**50 - 5.82689438983605e+25*cos(theta)**48 + 1.50750845681997e+26*cos(theta)**46 - 2.91639486506293e+26*cos(theta)**44 + 4.37922149579291e+26*cos(theta)**42 - 5.22955576682065e+26*cos(theta)**40 + 5.04833353727736e+26*cos(theta)**38 - 3.98314082683051e+26*cos(theta)**36 + 2.58698837206518e+26*cos(theta)**34 - 1.38880428395078e+26*cos(theta)**32 + 6.17246348422569e+25*cos(theta)**30 - 2.26967169538307e+25*cos(theta)**28 + 6.88552087363404e+24*cos(theta)**26 - 1.7147848919012e+24*cos(theta)**24 + 3.4800046335642e+23*cos(theta)**22 - 5.69724358861325e+22*cos(theta)**20 + 7.42439150779504e+21*cos(theta)**18 - 7.56783411520747e+20*cos(theta)**16 + 5.89701359626556e+19*cos(theta)**14 - 3.40716341117566e+18*cos(theta)**12 + 1.40020414157904e+17*cos(theta)**10 - 3.85849273552092e+15*cos(theta)**8 + 65240215334894.8*cos(theta)**6 - 584240734342.342*cos(theta)**4 + 2074227459.20358*cos(theta)**2 - 1219416.49571051)*cos(4*phi)

#@torch.jit.script
def Yl58_m5(theta, phi):
    return 6.33645953698479e-9*(1.0 - cos(theta)**2)**2.5*(1.17155362740469e+25*cos(theta)**53 - 1.40382686831623e+26*cos(theta)**51 + 7.91981972169552e+26*cos(theta)**49 - 2.7969093071213e+27*cos(theta)**47 + 6.93453890137185e+27*cos(theta)**45 - 1.28321374062769e+28*cos(theta)**43 + 1.83927302823302e+28*cos(theta)**41 - 2.09182230672826e+28*cos(theta)**39 + 1.9183667441654e+28*cos(theta)**37 - 1.43393069765898e+28*cos(theta)**35 + 8.79576046502161e+27*cos(theta)**33 - 4.4441737086425e+27*cos(theta)**31 + 1.85173904526771e+27*cos(theta)**29 - 6.3550807470726e+26*cos(theta)**27 + 1.79023542714485e+26*cos(theta)**25 - 4.11548374056287e+25*cos(theta)**23 + 7.65601019384123e+24*cos(theta)**21 - 1.13944871772265e+24*cos(theta)**19 + 1.33639047140311e+23*cos(theta)**17 - 1.2108534584332e+22*cos(theta)**15 + 8.25581903477178e+20*cos(theta)**13 - 4.08859609341079e+19*cos(theta)**11 + 1.40020414157904e+18*cos(theta)**9 - 3.08679418841674e+16*cos(theta)**7 + 391441292009369.0*cos(theta)**5 - 2336962937369.37*cos(theta)**3 + 4148454918.40716*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl58_m6(theta, phi):
    return 1.08797456929785e-10*(1.0 - cos(theta)**2)**3*(6.20923422524485e+26*cos(theta)**52 - 7.15951702841275e+27*cos(theta)**50 + 3.88071166363081e+28*cos(theta)**48 - 1.31454737434701e+29*cos(theta)**46 + 3.12054250561733e+29*cos(theta)**44 - 5.51781908469906e+29*cos(theta)**42 + 7.54101941575538e+29*cos(theta)**40 - 8.15810699624022e+29*cos(theta)**38 + 7.09795695341197e+29*cos(theta)**36 - 5.01875744180645e+29*cos(theta)**34 + 2.90260095345713e+29*cos(theta)**32 - 1.37769384967917e+29*cos(theta)**30 + 5.37004323127635e+28*cos(theta)**28 - 1.7158718017096e+28*cos(theta)**26 + 4.47558856786213e+27*cos(theta)**24 - 9.46561260329461e+26*cos(theta)**22 + 1.60776214070666e+26*cos(theta)**20 - 2.16495256367303e+25*cos(theta)**18 + 2.27186380138528e+24*cos(theta)**16 - 1.81628018764979e+23*cos(theta)**14 + 1.07325647452033e+22*cos(theta)**12 - 4.49745570275187e+20*cos(theta)**10 + 1.26018372742113e+19*cos(theta)**8 - 2.16075593189172e+17*cos(theta)**6 + 1.95720646004685e+15*cos(theta)**4 - 7010888812108.1*cos(theta)**2 + 4148454918.40716)*cos(6*phi)

#@torch.jit.script
def Yl58_m7(theta, phi):
    return 1.87137314980081e-12*(1.0 - cos(theta)**2)**3.5*(3.22880179712732e+28*cos(theta)**51 - 3.57975851420638e+29*cos(theta)**49 + 1.86274159854279e+30*cos(theta)**47 - 6.04691792199626e+30*cos(theta)**45 + 1.37303870247163e+31*cos(theta)**43 - 2.31748401557361e+31*cos(theta)**41 + 3.01640776630215e+31*cos(theta)**39 - 3.10008065857128e+31*cos(theta)**37 + 2.55526450322831e+31*cos(theta)**35 - 1.70637753021419e+31*cos(theta)**33 + 9.28832305106282e+30*cos(theta)**31 - 4.13308154903752e+30*cos(theta)**29 + 1.50361210475738e+30*cos(theta)**27 - 4.46126668444497e+29*cos(theta)**25 + 1.07414125628691e+29*cos(theta)**23 - 2.08243477272481e+28*cos(theta)**21 + 3.21552428141332e+27*cos(theta)**19 - 3.89691461461146e+26*cos(theta)**17 + 3.63498208221645e+25*cos(theta)**15 - 2.54279226270971e+24*cos(theta)**13 + 1.2879077694244e+23*cos(theta)**11 - 4.49745570275187e+21*cos(theta)**9 + 1.00814698193691e+20*cos(theta)**7 - 1.29645355913503e+18*cos(theta)**5 + 7.82882584018738e+15*cos(theta)**3 - 14021777624216.2*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl58_m8(theta, phi):
    return 3.22554673049734e-14*(1.0 - cos(theta)**2)**4*(1.64668891653493e+30*cos(theta)**50 - 1.75408167196112e+31*cos(theta)**48 + 8.7548855131511e+31*cos(theta)**46 - 2.72111306489831e+32*cos(theta)**44 + 5.904066420628e+32*cos(theta)**42 - 9.50168446385178e+32*cos(theta)**40 + 1.17639902885784e+33*cos(theta)**38 - 1.14702984367137e+33*cos(theta)**36 + 8.94342576129909e+32*cos(theta)**34 - 5.63104584970683e+32*cos(theta)**32 + 2.87938014582947e+32*cos(theta)**30 - 1.19859364922088e+32*cos(theta)**28 + 4.05975268284492e+31*cos(theta)**26 - 1.11531667111124e+31*cos(theta)**24 + 2.47052488945989e+30*cos(theta)**22 - 4.37311302272211e+29*cos(theta)**20 + 6.1094961346853e+28*cos(theta)**18 - 6.62475484483948e+27*cos(theta)**16 + 5.45247312332468e+26*cos(theta)**14 - 3.30562994152262e+25*cos(theta)**12 + 1.41669854636684e+24*cos(theta)**10 - 4.04771013247668e+22*cos(theta)**8 + 7.05702887355835e+20*cos(theta)**6 - 6.48226779567515e+18*cos(theta)**4 + 2.34864775205621e+16*cos(theta)**2 - 14021777624216.2)*cos(8*phi)

#@torch.jit.script
def Yl58_m9(theta, phi):
    return 5.57289595142768e-16*(1.0 - cos(theta)**2)**4.5*(8.23344458267467e+31*cos(theta)**49 - 8.4195920254134e+32*cos(theta)**47 + 4.02724733604951e+33*cos(theta)**45 - 1.19728974855526e+34*cos(theta)**43 + 2.47970789666376e+34*cos(theta)**41 - 3.80067378554071e+34*cos(theta)**39 + 4.47031630965979e+34*cos(theta)**37 - 4.12930743721695e+34*cos(theta)**35 + 3.04076475884169e+34*cos(theta)**33 - 1.80193467190619e+34*cos(theta)**31 + 8.63814043748842e+33*cos(theta)**29 - 3.35606221781847e+33*cos(theta)**27 + 1.05553569753968e+33*cos(theta)**25 - 2.67676001066698e+32*cos(theta)**23 + 5.43515475681177e+31*cos(theta)**21 - 8.74622604544422e+30*cos(theta)**19 + 1.09970930424335e+30*cos(theta)**17 - 1.05996077517432e+29*cos(theta)**15 + 7.63346237265455e+27*cos(theta)**13 - 3.96675592982715e+26*cos(theta)**11 + 1.41669854636684e+25*cos(theta)**9 - 3.23816810598134e+23*cos(theta)**7 + 4.23421732413501e+21*cos(theta)**5 - 2.59290711827006e+19*cos(theta)**3 + 4.69729550411243e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl58_m10(theta, phi):
    return 9.65447002029972e-18*(1.0 - cos(theta)**2)**5*(4.03438784551059e+33*cos(theta)**48 - 3.9572082519443e+34*cos(theta)**46 + 1.81226130122228e+35*cos(theta)**44 - 5.14834591878761e+35*cos(theta)**42 + 1.01668023763214e+36*cos(theta)**40 - 1.48226277636088e+36*cos(theta)**38 + 1.65401703457412e+36*cos(theta)**36 - 1.44525760302593e+36*cos(theta)**34 + 1.00345237041776e+36*cos(theta)**32 - 5.58599748290918e+35*cos(theta)**30 + 2.50506072687164e+35*cos(theta)**28 - 9.06136798810986e+34*cos(theta)**26 + 2.6388392438492e+34*cos(theta)**24 - 6.15654802453405e+33*cos(theta)**22 + 1.14138249893047e+33*cos(theta)**20 - 1.6617829486344e+32*cos(theta)**18 + 1.8695058172137e+31*cos(theta)**16 - 1.58994116276148e+30*cos(theta)**14 + 9.92350108445091e+28*cos(theta)**12 - 4.36343152280986e+27*cos(theta)**10 + 1.27502869173015e+26*cos(theta)**8 - 2.26671767418694e+24*cos(theta)**6 + 2.1171086620675e+22*cos(theta)**4 - 7.77872135481018e+19*cos(theta)**2 + 4.69729550411243e+16)*cos(10*phi)

#@torch.jit.script
def Yl58_m11(theta, phi):
    return 1.67758013276199e-19*(1.0 - cos(theta)**2)**5.5*(1.93650616584508e+35*cos(theta)**47 - 1.82031579589438e+36*cos(theta)**45 + 7.97394972537802e+36*cos(theta)**43 - 2.1623052858908e+37*cos(theta)**41 + 4.06672095052856e+37*cos(theta)**39 - 5.63259855017134e+37*cos(theta)**37 + 5.95446132446684e+37*cos(theta)**35 - 4.91387585028817e+37*cos(theta)**33 + 3.21104758533682e+37*cos(theta)**31 - 1.67579924487275e+37*cos(theta)**29 + 7.0141700352406e+36*cos(theta)**27 - 2.35595567690856e+36*cos(theta)**25 + 6.33321418523808e+35*cos(theta)**23 - 1.35444056539749e+35*cos(theta)**21 + 2.28276499786094e+34*cos(theta)**19 - 2.99120930754192e+33*cos(theta)**17 + 2.99120930754192e+32*cos(theta)**15 - 2.22591762786607e+31*cos(theta)**13 + 1.19082013013411e+30*cos(theta)**11 - 4.36343152280986e+28*cos(theta)**9 + 1.02002295338412e+27*cos(theta)**7 - 1.36003060451216e+25*cos(theta)**5 + 8.46843464827002e+22*cos(theta)**3 - 1.55574427096204e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl58_m12(theta, phi):
    return 2.92472693856372e-21*(1.0 - cos(theta)**2)**6*(9.10157897947188e+36*cos(theta)**46 - 8.19142108152469e+37*cos(theta)**44 + 3.42879838191255e+38*cos(theta)**42 - 8.86545167215227e+38*cos(theta)**40 + 1.58602117070614e+39*cos(theta)**38 - 2.08406146356339e+39*cos(theta)**36 + 2.08406146356339e+39*cos(theta)**34 - 1.6215790305951e+39*cos(theta)**32 + 9.95424751454416e+38*cos(theta)**30 - 4.85981781013098e+38*cos(theta)**28 + 1.89382590951496e+38*cos(theta)**26 - 5.88988919227141e+37*cos(theta)**24 + 1.45663926260476e+37*cos(theta)**22 - 2.84432518733473e+36*cos(theta)**20 + 4.33725349593579e+35*cos(theta)**18 - 5.08505582282127e+34*cos(theta)**16 + 4.48681396131288e+33*cos(theta)**14 - 2.89369291622589e+32*cos(theta)**12 + 1.30990214314752e+31*cos(theta)**10 - 3.92708837052888e+29*cos(theta)**8 + 7.14016067368886e+27*cos(theta)**6 - 6.80015302256082e+25*cos(theta)**4 + 2.54053039448101e+23*cos(theta)**2 - 1.55574427096204e+20)*cos(12*phi)

#@torch.jit.script
def Yl58_m13(theta, phi):
    return 5.11772841272677e-23*(1.0 - cos(theta)**2)**6.5*(4.18672633055707e+38*cos(theta)**45 - 3.60422527587087e+39*cos(theta)**43 + 1.44009532040327e+40*cos(theta)**41 - 3.54618066886091e+40*cos(theta)**39 + 6.02688044868333e+40*cos(theta)**37 - 7.50262126882822e+40*cos(theta)**35 + 7.08580897611554e+40*cos(theta)**33 - 5.18905289790431e+40*cos(theta)**31 + 2.98627425436325e+40*cos(theta)**29 - 1.36074898683668e+40*cos(theta)**27 + 4.9239473647389e+39*cos(theta)**25 - 1.41357340614514e+39*cos(theta)**23 + 3.20460637773047e+38*cos(theta)**21 - 5.68865037466947e+37*cos(theta)**19 + 7.80705629268442e+36*cos(theta)**17 - 8.13608931651403e+35*cos(theta)**15 + 6.28153954583804e+34*cos(theta)**13 - 3.47243149947106e+33*cos(theta)**11 + 1.30990214314752e+32*cos(theta)**9 - 3.1416706964231e+30*cos(theta)**7 + 4.28409640421332e+28*cos(theta)**5 - 2.72006120902433e+26*cos(theta)**3 + 5.08106078896201e+23*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl58_m14(theta, phi):
    return 8.99093235020825e-25*(1.0 - cos(theta)**2)**7*(1.88402684875068e+40*cos(theta)**44 - 1.54981686862447e+41*cos(theta)**42 + 5.90439081365341e+41*cos(theta)**40 - 1.38301046085575e+42*cos(theta)**38 + 2.22994576601283e+42*cos(theta)**36 - 2.62591744408988e+42*cos(theta)**34 + 2.33831696211813e+42*cos(theta)**32 - 1.60860639835034e+42*cos(theta)**30 + 8.66019533765341e+41*cos(theta)**28 - 3.67402226445902e+41*cos(theta)**26 + 1.23098684118472e+41*cos(theta)**24 - 3.25121883413382e+40*cos(theta)**22 + 6.72967339323398e+39*cos(theta)**20 - 1.0808435711872e+39*cos(theta)**18 + 1.32719956975635e+38*cos(theta)**16 - 1.2204133974771e+37*cos(theta)**14 + 8.16600140958945e+35*cos(theta)**12 - 3.81967464941817e+34*cos(theta)**10 + 1.17891192883277e+33*cos(theta)**8 - 2.19916948749617e+31*cos(theta)**6 + 2.14204820210666e+29*cos(theta)**4 - 8.16018362707299e+26*cos(theta)**2 + 5.08106078896201e+23)*cos(14*phi)

#@torch.jit.script
def Yl58_m15(theta, phi):
    return 1.58641556272998e-26*(1.0 - cos(theta)**2)**7.5*(8.28971813450299e+41*cos(theta)**43 - 6.50923084822278e+42*cos(theta)**41 + 2.36175632546136e+43*cos(theta)**39 - 5.25543975125186e+43*cos(theta)**37 + 8.0278047576462e+43*cos(theta)**35 - 8.92811930990558e+43*cos(theta)**33 + 7.48261427877801e+43*cos(theta)**31 - 4.82581919505101e+43*cos(theta)**29 + 2.42485469454296e+43*cos(theta)**27 - 9.55245788759346e+42*cos(theta)**25 + 2.95436841884334e+42*cos(theta)**23 - 7.1526814350944e+41*cos(theta)**21 + 1.3459346786468e+41*cos(theta)**19 - 1.94551842813696e+40*cos(theta)**17 + 2.12351931161016e+39*cos(theta)**15 - 1.70857875646795e+38*cos(theta)**13 + 9.79920169150734e+36*cos(theta)**11 - 3.81967464941817e+35*cos(theta)**9 + 9.43129543066215e+33*cos(theta)**7 - 1.3195016924977e+32*cos(theta)**5 + 8.56819280842664e+29*cos(theta)**3 - 1.6320367254146e+27*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl58_m16(theta, phi):
    return 2.81233384880933e-28*(1.0 - cos(theta)**2)**8*(3.56457879783629e+43*cos(theta)**42 - 2.66878464777134e+44*cos(theta)**40 + 9.21084966929932e+44*cos(theta)**38 - 1.94451270796319e+45*cos(theta)**36 + 2.80973166517617e+45*cos(theta)**34 - 2.94627937226884e+45*cos(theta)**32 + 2.31961042642118e+45*cos(theta)**30 - 1.39948756656479e+45*cos(theta)**28 + 6.54710767526598e+44*cos(theta)**26 - 2.38811447189837e+44*cos(theta)**24 + 6.79504736333968e+43*cos(theta)**22 - 1.50206310136982e+43*cos(theta)**20 + 2.55727588942891e+42*cos(theta)**18 - 3.30738132783283e+41*cos(theta)**16 + 3.18527896741524e+40*cos(theta)**14 - 2.22115238340833e+39*cos(theta)**12 + 1.07791218606581e+38*cos(theta)**10 - 3.43770718447635e+36*cos(theta)**8 + 6.6019068014635e+34*cos(theta)**6 - 6.59750846248851e+32*cos(theta)**4 + 2.57045784252799e+30*cos(theta)**2 - 1.6320367254146e+27)*cos(16*phi)

#@torch.jit.script
def Yl58_m17(theta, phi):
    return 5.01085224736753e-30*(1.0 - cos(theta)**2)**8.5*(1.49712309509124e+45*cos(theta)**41 - 1.06751385910854e+46*cos(theta)**39 + 3.50012287433374e+46*cos(theta)**37 - 7.00024574866748e+46*cos(theta)**35 + 9.55308766159897e+46*cos(theta)**33 - 9.42809399126029e+46*cos(theta)**31 + 6.95883127926355e+46*cos(theta)**29 - 3.91856518638142e+46*cos(theta)**27 + 1.70224799556916e+46*cos(theta)**25 - 5.73147473255608e+45*cos(theta)**23 + 1.49491041993473e+45*cos(theta)**21 - 3.00412620273965e+44*cos(theta)**19 + 4.60309660097204e+43*cos(theta)**17 - 5.29181012453252e+42*cos(theta)**15 + 4.45939055438134e+41*cos(theta)**13 - 2.66538286009e+40*cos(theta)**11 + 1.07791218606581e+39*cos(theta)**9 - 2.75016574758108e+37*cos(theta)**7 + 3.9611440808781e+35*cos(theta)**5 - 2.6390033849954e+33*cos(theta)**3 + 5.14091568505598e+30*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl58_m18(theta, phi):
    return 8.97662065438591e-32*(1.0 - cos(theta)**2)**9*(6.13820468987408e+46*cos(theta)**40 - 4.16330405052329e+47*cos(theta)**38 + 1.29504546350348e+48*cos(theta)**36 - 2.45008601203362e+48*cos(theta)**34 + 3.15251892832766e+48*cos(theta)**32 - 2.92270913729069e+48*cos(theta)**30 + 2.01806107098643e+48*cos(theta)**28 - 1.05801260032298e+48*cos(theta)**26 + 4.25561998892289e+47*cos(theta)**24 - 1.3182391884879e+47*cos(theta)**22 + 3.13931188186293e+46*cos(theta)**20 - 5.70783978520533e+45*cos(theta)**18 + 7.82526422165247e+44*cos(theta)**16 - 7.93771518679879e+43*cos(theta)**14 + 5.79720772069574e+42*cos(theta)**12 - 2.931921146099e+41*cos(theta)**10 + 9.70120967459227e+39*cos(theta)**8 - 1.92511602330676e+38*cos(theta)**6 + 1.98057204043905e+36*cos(theta)**4 - 7.91701015498621e+33*cos(theta)**2 + 5.14091568505598e+30)*cos(18*phi)

#@torch.jit.script
def Yl58_m19(theta, phi):
    return 1.6174747671886e-33*(1.0 - cos(theta)**2)**9.5*(2.45528187594963e+48*cos(theta)**39 - 1.58205553919885e+49*cos(theta)**37 + 4.66216366861254e+49*cos(theta)**35 - 8.3302924409143e+49*cos(theta)**33 + 1.00880605706485e+50*cos(theta)**31 - 8.76812741187207e+49*cos(theta)**29 + 5.650570998762e+49*cos(theta)**27 - 2.75083276083975e+49*cos(theta)**25 + 1.02134879734149e+49*cos(theta)**23 - 2.90012621467338e+48*cos(theta)**21 + 6.27862376372586e+47*cos(theta)**19 - 1.02741116133696e+47*cos(theta)**17 + 1.2520422754644e+46*cos(theta)**15 - 1.11128012615183e+45*cos(theta)**13 + 6.95664926483489e+43*cos(theta)**11 - 2.931921146099e+42*cos(theta)**9 + 7.76096773967381e+40*cos(theta)**7 - 1.15506961398405e+39*cos(theta)**5 + 7.9222881617562e+36*cos(theta)**3 - 1.58340203099724e+34*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl58_m20(theta, phi):
    return 2.93263429814664e-35*(1.0 - cos(theta)**2)**10*(9.57559931620357e+49*cos(theta)**38 - 5.85360549503575e+50*cos(theta)**36 + 1.63175728401439e+51*cos(theta)**34 - 2.74899650550172e+51*cos(theta)**32 + 3.12729877690104e+51*cos(theta)**30 - 2.5427569494429e+51*cos(theta)**28 + 1.52565416966574e+51*cos(theta)**26 - 6.87708190209939e+50*cos(theta)**24 + 2.34910223388543e+50*cos(theta)**22 - 6.09026505081409e+49*cos(theta)**20 + 1.19293851510791e+49*cos(theta)**18 - 1.74659897427283e+48*cos(theta)**16 + 1.87806341319659e+47*cos(theta)**14 - 1.44466416399738e+46*cos(theta)**12 + 7.65231419131838e+44*cos(theta)**10 - 2.6387290314891e+43*cos(theta)**8 + 5.43267741777167e+41*cos(theta)**6 - 5.77534806992027e+39*cos(theta)**4 + 2.37668644852686e+37*cos(theta)**2 - 1.58340203099724e+34)*cos(20*phi)

#@torch.jit.script
def Yl58_m21(theta, phi):
    return 5.35244934083976e-37*(1.0 - cos(theta)**2)**10.5*(3.63872774015736e+51*cos(theta)**37 - 2.10729797821287e+52*cos(theta)**35 + 5.54797476564893e+52*cos(theta)**33 - 8.79678881760551e+52*cos(theta)**31 + 9.38189633070312e+52*cos(theta)**29 - 7.11971945844012e+52*cos(theta)**27 + 3.96670084113093e+52*cos(theta)**25 - 1.65049965650385e+52*cos(theta)**23 + 5.16802491454796e+51*cos(theta)**21 - 1.21805301016282e+51*cos(theta)**19 + 2.14728932719425e+50*cos(theta)**17 - 2.79455835883653e+49*cos(theta)**15 + 2.62928877847523e+48*cos(theta)**13 - 1.73359699679686e+47*cos(theta)**11 + 7.65231419131838e+45*cos(theta)**9 - 2.11098322519128e+44*cos(theta)**7 + 3.259606450663e+42*cos(theta)**5 - 2.31013922796811e+40*cos(theta)**3 + 4.75337289705372e+37*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl58_m22(theta, phi):
    return 9.83799754850438e-39*(1.0 - cos(theta)**2)**11*(1.34632926385822e+53*cos(theta)**36 - 7.37554292374504e+53*cos(theta)**34 + 1.83083167266415e+54*cos(theta)**32 - 2.72700453345771e+54*cos(theta)**30 + 2.7207499359039e+54*cos(theta)**28 - 1.92232425377883e+54*cos(theta)**26 + 9.91675210282732e+53*cos(theta)**24 - 3.79614920995886e+53*cos(theta)**22 + 1.08528523205507e+53*cos(theta)**20 - 2.31430071930935e+52*cos(theta)**18 + 3.65039185623022e+51*cos(theta)**16 - 4.1918375382548e+50*cos(theta)**14 + 3.4180754120178e+49*cos(theta)**12 - 1.90695669647654e+48*cos(theta)**10 + 6.88708277218654e+46*cos(theta)**8 - 1.47768825763389e+45*cos(theta)**6 + 1.6298032253315e+43*cos(theta)**4 - 6.93041768390433e+40*cos(theta)**2 + 4.75337289705372e+37)*cos(22*phi)

#@torch.jit.script
def Yl58_m23(theta, phi):
    return 1.82185139787118e-40*(1.0 - cos(theta)**2)**11.5*(4.8467853498896e+54*cos(theta)**35 - 2.50768459407331e+55*cos(theta)**33 + 5.85866135252527e+55*cos(theta)**31 - 8.18101360037312e+55*cos(theta)**29 + 7.61809982053093e+55*cos(theta)**27 - 4.99804305982497e+55*cos(theta)**25 + 2.38002050467856e+55*cos(theta)**23 - 8.3515282619095e+54*cos(theta)**21 + 2.17057046411014e+54*cos(theta)**19 - 4.16574129475684e+53*cos(theta)**17 + 5.84062696996835e+52*cos(theta)**15 - 5.86857255355671e+51*cos(theta)**13 + 4.10169049442136e+50*cos(theta)**11 - 1.90695669647654e+49*cos(theta)**9 + 5.50966621774923e+47*cos(theta)**7 - 8.86612954580337e+45*cos(theta)**5 + 6.519212901326e+43*cos(theta)**3 - 1.38608353678087e+41*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl58_m24(theta, phi):
    return 3.40072881916237e-42*(1.0 - cos(theta)**2)**12*(1.69637487246136e+56*cos(theta)**34 - 8.27535916044194e+56*cos(theta)**32 + 1.81618501928283e+57*cos(theta)**30 - 2.3724939441082e+57*cos(theta)**28 + 2.05688695154335e+57*cos(theta)**26 - 1.24951076495624e+57*cos(theta)**24 + 5.47404716076068e+56*cos(theta)**22 - 1.75382093500099e+56*cos(theta)**20 + 4.12408388180927e+55*cos(theta)**18 - 7.08176020108662e+54*cos(theta)**16 + 8.76094045495252e+53*cos(theta)**14 - 7.62914431962373e+52*cos(theta)**12 + 4.51185954386349e+51*cos(theta)**10 - 1.71626102682889e+50*cos(theta)**8 + 3.85676635242446e+48*cos(theta)**6 - 4.43306477290168e+46*cos(theta)**4 + 1.9557638703978e+44*cos(theta)**2 - 1.38608353678087e+41)*cos(24*phi)

#@torch.jit.script
def Yl58_m25(theta, phi):
    return 6.40167315718996e-44*(1.0 - cos(theta)**2)**12.5*(5.76767456636862e+57*cos(theta)**33 - 2.64811493134142e+58*cos(theta)**31 + 5.4485550578485e+58*cos(theta)**29 - 6.64298304350297e+58*cos(theta)**27 + 5.34790607401271e+58*cos(theta)**25 - 2.99882583589498e+58*cos(theta)**23 + 1.20429037536735e+58*cos(theta)**21 - 3.50764187000199e+57*cos(theta)**19 + 7.42335098725668e+56*cos(theta)**17 - 1.13308163217386e+56*cos(theta)**15 + 1.22653166369335e+55*cos(theta)**13 - 9.15497318354847e+53*cos(theta)**11 + 4.51185954386349e+52*cos(theta)**9 - 1.37300882146311e+51*cos(theta)**7 + 2.31405981145468e+49*cos(theta)**5 - 1.77322590916067e+47*cos(theta)**3 + 3.9115277407956e+44*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl58_m26(theta, phi):
    return 1.21589727216593e-45*(1.0 - cos(theta)**2)**13*(1.90333260690165e+59*cos(theta)**32 - 8.2091562871584e+59*cos(theta)**30 + 1.58008096677606e+60*cos(theta)**28 - 1.7936054217458e+60*cos(theta)**26 + 1.33697651850318e+60*cos(theta)**24 - 6.89729942255845e+59*cos(theta)**22 + 2.52900978827143e+59*cos(theta)**20 - 6.66451955300378e+58*cos(theta)**18 + 1.26196966783364e+58*cos(theta)**16 - 1.69962244826079e+57*cos(theta)**14 + 1.59449116280136e+56*cos(theta)**12 - 1.00704705019033e+55*cos(theta)**10 + 4.06067358947715e+53*cos(theta)**8 - 9.61106175024176e+51*cos(theta)**6 + 1.15702990572734e+50*cos(theta)**4 - 5.31967772748202e+47*cos(theta)**2 + 3.9115277407956e+44)*cos(26*phi)

#@torch.jit.script
def Yl58_m27(theta, phi):
    return 2.33137659446573e-47*(1.0 - cos(theta)**2)**13.5*(6.09066434208527e+60*cos(theta)**31 - 2.46274688614752e+61*cos(theta)**29 + 4.42422670697298e+61*cos(theta)**27 - 4.66337409653909e+61*cos(theta)**25 + 3.20874364440763e+61*cos(theta)**23 - 1.51740587296286e+61*cos(theta)**21 + 5.05801957654287e+60*cos(theta)**19 - 1.19961351954068e+60*cos(theta)**17 + 2.01915146853382e+59*cos(theta)**15 - 2.3794714275651e+58*cos(theta)**13 + 1.91338939536163e+57*cos(theta)**11 - 1.00704705019033e+56*cos(theta)**9 + 3.24853887158172e+54*cos(theta)**7 - 5.76663705014506e+52*cos(theta)**5 + 4.62811962290936e+50*cos(theta)**3 - 1.0639355454964e+48*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl58_m28(theta, phi):
    return 4.51525580430714e-49*(1.0 - cos(theta)**2)**14*(1.88810594604643e+62*cos(theta)**30 - 7.14196596982781e+62*cos(theta)**28 + 1.1945412108827e+63*cos(theta)**26 - 1.16584352413477e+63*cos(theta)**24 + 7.38011038213755e+62*cos(theta)**22 - 3.18655233322201e+62*cos(theta)**20 + 9.61023719543145e+61*cos(theta)**18 - 2.03934298321916e+61*cos(theta)**16 + 3.02872720280073e+60*cos(theta)**14 - 3.09331285583464e+59*cos(theta)**12 + 2.10472833489779e+58*cos(theta)**10 - 9.06342345171299e+56*cos(theta)**8 + 2.2739772101072e+55*cos(theta)**6 - 2.88331852507253e+53*cos(theta)**4 + 1.38843588687281e+51*cos(theta)**2 - 1.0639355454964e+48)*cos(28*phi)

#@torch.jit.script
def Yl58_m29(theta, phi):
    return 8.83816501523427e-51*(1.0 - cos(theta)**2)**14.5*(5.6643178381393e+63*cos(theta)**29 - 1.99975047155179e+64*cos(theta)**27 + 3.10580714829503e+64*cos(theta)**25 - 2.79802445792345e+64*cos(theta)**23 + 1.62362428407026e+64*cos(theta)**21 - 6.37310466644401e+63*cos(theta)**19 + 1.72984269517766e+63*cos(theta)**17 - 3.26294877315065e+62*cos(theta)**15 + 4.24021808392102e+61*cos(theta)**13 - 3.71197542700156e+60*cos(theta)**11 + 2.10472833489779e+59*cos(theta)**9 - 7.25073876137039e+57*cos(theta)**7 + 1.36438632606432e+56*cos(theta)**5 - 1.15332741002901e+54*cos(theta)**3 + 2.77687177374561e+51*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl58_m30(theta, phi):
    return 1.74953151853462e-52*(1.0 - cos(theta)**2)**15*(1.6426521730604e+65*cos(theta)**28 - 5.39932627318982e+65*cos(theta)**26 + 7.76451787073758e+65*cos(theta)**24 - 6.43545625322394e+65*cos(theta)**22 + 3.40961099654755e+65*cos(theta)**20 - 1.21088988662436e+65*cos(theta)**18 + 2.94073258180202e+64*cos(theta)**16 - 4.89442315972597e+63*cos(theta)**14 + 5.51228350909732e+62*cos(theta)**12 - 4.08317296970172e+61*cos(theta)**10 + 1.89425550140801e+60*cos(theta)**8 - 5.07551713295927e+58*cos(theta)**6 + 6.8219316303216e+56*cos(theta)**4 - 3.45998223008703e+54*cos(theta)**2 + 2.77687177374561e+51)*cos(30*phi)

#@torch.jit.script
def Yl58_m31(theta, phi):
    return 3.50467501026163e-54*(1.0 - cos(theta)**2)**15.5*(4.59942608456911e+66*cos(theta)**27 - 1.40382483102935e+67*cos(theta)**25 + 1.86348428897702e+67*cos(theta)**23 - 1.41580037570927e+67*cos(theta)**21 + 6.81922199309509e+66*cos(theta)**19 - 2.17960179592385e+66*cos(theta)**17 + 4.70517213088324e+65*cos(theta)**15 - 6.85219242361636e+64*cos(theta)**13 + 6.61474021091679e+63*cos(theta)**11 - 4.08317296970172e+62*cos(theta)**9 + 1.51540440112641e+61*cos(theta)**7 - 3.04531027977556e+59*cos(theta)**5 + 2.72877265212864e+57*cos(theta)**3 - 6.91996446017407e+54*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl58_m32(theta, phi):
    return 7.10959096238867e-56*(1.0 - cos(theta)**2)**16*(1.24184504283366e+68*cos(theta)**26 - 3.50956207757339e+68*cos(theta)**24 + 4.28601386464714e+68*cos(theta)**22 - 2.97318078898946e+68*cos(theta)**20 + 1.29565217868807e+68*cos(theta)**18 - 3.70532305307055e+67*cos(theta)**16 + 7.05775819632485e+66*cos(theta)**14 - 8.90785015070127e+65*cos(theta)**12 + 7.27621423200846e+64*cos(theta)**10 - 3.67485567273155e+63*cos(theta)**8 + 1.06078308078849e+62*cos(theta)**6 - 1.52265513988778e+60*cos(theta)**4 + 8.18631795638592e+57*cos(theta)**2 - 6.91996446017407e+54)*cos(32*phi)

#@torch.jit.script
def Yl58_m33(theta, phi):
    return 1.4616293154595e-57*(1.0 - cos(theta)**2)**16.5*(3.22879711136752e+69*cos(theta)**25 - 8.42294898617613e+69*cos(theta)**23 + 9.42923050222372e+69*cos(theta)**21 - 5.94636157797892e+69*cos(theta)**19 + 2.33217392163852e+69*cos(theta)**17 - 5.92851688491288e+68*cos(theta)**15 + 9.8808614748548e+67*cos(theta)**13 - 1.06894201808415e+67*cos(theta)**11 + 7.27621423200847e+65*cos(theta)**9 - 2.93988453818524e+64*cos(theta)**7 + 6.36469848473093e+62*cos(theta)**5 - 6.09062055955113e+60*cos(theta)**3 + 1.63726359127718e+58*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl58_m34(theta, phi):
    return 3.0477078028168e-59*(1.0 - cos(theta)**2)**17*(8.07199277841879e+70*cos(theta)**24 - 1.93727826682051e+71*cos(theta)**22 + 1.98013840546698e+71*cos(theta)**20 - 1.129808699816e+71*cos(theta)**18 + 3.96469566678549e+70*cos(theta)**16 - 8.89277532736932e+69*cos(theta)**14 + 1.28451199173112e+69*cos(theta)**12 - 1.17583621989257e+68*cos(theta)**10 + 6.54859280880762e+66*cos(theta)**8 - 2.05791917672967e+65*cos(theta)**6 + 3.18234924236546e+63*cos(theta)**4 - 1.82718616786534e+61*cos(theta)**2 + 1.63726359127718e+58)*cos(34*phi)

#@torch.jit.script
def Yl58_m35(theta, phi):
    return 6.45098796695342e-61*(1.0 - cos(theta)**2)**17.5*(1.93727826682051e+72*cos(theta)**23 - 4.26201218700512e+72*cos(theta)**21 + 3.96027681093396e+72*cos(theta)**19 - 2.03365565966879e+72*cos(theta)**17 + 6.34351306685678e+71*cos(theta)**15 - 1.2449885458317e+71*cos(theta)**13 + 1.54141439007735e+70*cos(theta)**11 - 1.17583621989257e+69*cos(theta)**9 + 5.23887424704609e+67*cos(theta)**7 - 1.2347515060378e+66*cos(theta)**5 + 1.27293969694619e+64*cos(theta)**3 - 3.65437233573068e+61*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl58_m36(theta, phi):
    return 1.38738944771762e-62*(1.0 - cos(theta)**2)**18*(4.45574001368717e+73*cos(theta)**22 - 8.95022559271075e+73*cos(theta)**20 + 7.52452594077453e+73*cos(theta)**18 - 3.45721462143694e+73*cos(theta)**16 + 9.51526960028517e+72*cos(theta)**14 - 1.61848510958122e+72*cos(theta)**12 + 1.69555582908508e+71*cos(theta)**10 - 1.05825259790331e+70*cos(theta)**8 + 3.66721197293227e+68*cos(theta)**6 - 6.173757530189e+66*cos(theta)**4 + 3.81881909083856e+64*cos(theta)**2 - 3.65437233573068e+61)*cos(36*phi)

#@torch.jit.script
def Yl58_m37(theta, phi):
    return 3.0347662385546e-64*(1.0 - cos(theta)**2)**18.5*(9.80262803011178e+74*cos(theta)**21 - 1.79004511854215e+75*cos(theta)**19 + 1.35441466933941e+75*cos(theta)**17 - 5.53154339429911e+74*cos(theta)**15 + 1.33213774403992e+74*cos(theta)**13 - 1.94218213149746e+73*cos(theta)**11 + 1.69555582908508e+72*cos(theta)**9 - 8.46602078322649e+70*cos(theta)**7 + 2.20032718375936e+69*cos(theta)**5 - 2.4695030120756e+67*cos(theta)**3 + 7.63763818167712e+64*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl58_m38(theta, phi):
    return 6.75896161524998e-66*(1.0 - cos(theta)**2)**19*(2.05855188632347e+76*cos(theta)**20 - 3.40108572523009e+76*cos(theta)**18 + 2.30250493787701e+76*cos(theta)**16 - 8.29731509144867e+75*cos(theta)**14 + 1.7317790672519e+75*cos(theta)**12 - 2.1364003446472e+74*cos(theta)**10 + 1.52600024617657e+73*cos(theta)**8 - 5.92621454825854e+71*cos(theta)**6 + 1.10016359187968e+70*cos(theta)**4 - 7.4085090362268e+67*cos(theta)**2 + 7.63763818167712e+64)*cos(38*phi)

#@torch.jit.script
def Yl58_m39(theta, phi):
    return 1.53454318593721e-67*(1.0 - cos(theta)**2)**19.5*(4.11710377264695e+77*cos(theta)**19 - 6.12195430541416e+77*cos(theta)**17 + 3.68400790060321e+77*cos(theta)**15 - 1.16162411280281e+77*cos(theta)**13 + 2.07813488070228e+76*cos(theta)**11 - 2.1364003446472e+75*cos(theta)**9 + 1.22080019694126e+74*cos(theta)**7 - 3.55572872895513e+72*cos(theta)**5 + 4.40065436751872e+70*cos(theta)**3 - 1.48170180724536e+68*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl58_m40(theta, phi):
    return 3.55622537727517e-69*(1.0 - cos(theta)**2)**20*(7.8224971680292e+78*cos(theta)**18 - 1.04073223192041e+79*cos(theta)**16 + 5.52601185090481e+78*cos(theta)**14 - 1.51011134664366e+78*cos(theta)**12 + 2.28594836877251e+77*cos(theta)**10 - 1.92276031018248e+76*cos(theta)**8 + 8.54560137858882e+74*cos(theta)**6 - 1.77786436447756e+73*cos(theta)**4 + 1.32019631025562e+71*cos(theta)**2 - 1.48170180724536e+68)*cos(40*phi)

#@torch.jit.script
def Yl58_m41(theta, phi):
    return 8.42433108841187e-71*(1.0 - cos(theta)**2)**20.5*(1.40804949024526e+80*cos(theta)**17 - 1.66517157107265e+80*cos(theta)**15 + 7.73641659126674e+79*cos(theta)**13 - 1.81213361597239e+79*cos(theta)**11 + 2.28594836877251e+78*cos(theta)**9 - 1.53820824814599e+77*cos(theta)**7 + 5.12736082715329e+75*cos(theta)**5 - 7.11145745791025e+73*cos(theta)**3 + 2.64039262051123e+71*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl58_m42(theta, phi):
    return 2.04320040604098e-72*(1.0 - cos(theta)**2)**21*(2.39368413341693e+81*cos(theta)**16 - 2.49775735660898e+81*cos(theta)**14 + 1.00573415686468e+81*cos(theta)**12 - 1.99334697756963e+80*cos(theta)**10 + 2.05735353189526e+79*cos(theta)**8 - 1.07674577370219e+78*cos(theta)**6 + 2.56368041357665e+76*cos(theta)**4 - 2.13343723737308e+74*cos(theta)**2 + 2.64039262051123e+71)*cos(42*phi)

#@torch.jit.script
def Yl58_m43(theta, phi):
    return 5.08265097765732e-74*(1.0 - cos(theta)**2)**21.5*(3.8298946134671e+82*cos(theta)**15 - 3.49686029925257e+82*cos(theta)**13 + 1.20688098823761e+82*cos(theta)**11 - 1.99334697756963e+81*cos(theta)**9 + 1.64588282551621e+80*cos(theta)**7 - 6.46047464221315e+78*cos(theta)**5 + 1.02547216543066e+77*cos(theta)**3 - 4.26687447474615e+74*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl58_m44(theta, phi):
    return 1.29940511679801e-75*(1.0 - cos(theta)**2)**22*(5.74484192020064e+83*cos(theta)**14 - 4.54591838902833e+83*cos(theta)**12 + 1.32756908706137e+83*cos(theta)**10 - 1.79401227981266e+82*cos(theta)**8 + 1.15211797786134e+81*cos(theta)**6 - 3.23023732110657e+79*cos(theta)**4 + 3.07641649629197e+77*cos(theta)**2 - 4.26687447474615e+74)*cos(44*phi)

#@torch.jit.script
def Yl58_m45(theta, phi):
    return 3.42185767810634e-77*(1.0 - cos(theta)**2)**22.5*(8.0427786882809e+84*cos(theta)**13 - 5.455102066834e+84*cos(theta)**11 + 1.32756908706137e+84*cos(theta)**9 - 1.43520982385013e+83*cos(theta)**7 + 6.91270786716807e+81*cos(theta)**5 - 1.29209492844263e+80*cos(theta)**3 + 6.15283299258395e+77*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl58_m46(theta, phi):
    return 9.30622603247787e-79*(1.0 - cos(theta)**2)**23*(1.04556122947652e+86*cos(theta)**12 - 6.0006122735174e+85*cos(theta)**10 + 1.19481217835523e+85*cos(theta)**8 - 1.00464687669509e+84*cos(theta)**6 + 3.45635393358403e+82*cos(theta)**4 - 3.87628478532789e+80*cos(theta)**2 + 6.15283299258395e+77)*cos(46*phi)

#@torch.jit.script
def Yl58_m47(theta, phi):
    return 2.62173217560465e-80*(1.0 - cos(theta)**2)**23.5*(1.25467347537182e+87*cos(theta)**11 - 6.0006122735174e+86*cos(theta)**9 + 9.55849742684188e+85*cos(theta)**7 - 6.02788126017056e+84*cos(theta)**5 + 1.38254157343361e+83*cos(theta)**3 - 7.75256957065578e+80*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl58_m48(theta, phi):
    return 7.67783984627058e-82*(1.0 - cos(theta)**2)**24*(1.380140822909e+88*cos(theta)**10 - 5.40055104616566e+87*cos(theta)**8 + 6.69094819878932e+86*cos(theta)**6 - 3.01394063008528e+85*cos(theta)**4 + 4.14762472030084e+83*cos(theta)**2 - 7.75256957065578e+80)*cos(48*phi)

#@torch.jit.script
def Yl58_m49(theta, phi):
    return 2.34718412931624e-83*(1.0 - cos(theta)**2)**24.5*(1.380140822909e+89*cos(theta)**9 - 4.32044083693253e+88*cos(theta)**7 + 4.01456891927359e+87*cos(theta)**5 - 1.20557625203411e+86*cos(theta)**3 + 8.29524944060168e+83*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl58_m50(theta, phi):
    return 7.52859660499083e-85*(1.0 - cos(theta)**2)**25*(1.2421267406181e+90*cos(theta)**8 - 3.02430858585277e+89*cos(theta)**6 + 2.00728445963679e+88*cos(theta)**4 - 3.61672875610233e+86*cos(theta)**2 + 8.29524944060168e+83)*cos(50*phi)

#@torch.jit.script
def Yl58_m51(theta, phi):
    return 2.5495045129487e-86*(1.0 - cos(theta)**2)**25.5*(9.93701392494482e+90*cos(theta)**7 - 1.81458515151166e+90*cos(theta)**5 + 8.02913783854718e+88*cos(theta)**3 - 7.23345751220467e+86*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl58_m52(theta, phi):
    return 9.18777650810753e-88*(1.0 - cos(theta)**2)**26*(6.95590974746137e+91*cos(theta)**6 - 9.07292575755831e+90*cos(theta)**4 + 2.40874135156415e+89*cos(theta)**2 - 7.23345751220467e+86)*cos(52*phi)

#@torch.jit.script
def Yl58_m53(theta, phi):
    return 3.56019108124478e-89*(1.0 - cos(theta)**2)**26.5*(4.17354584847682e+92*cos(theta)**5 - 3.62917030302332e+91*cos(theta)**3 + 4.81748270312831e+89*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl58_m54(theta, phi):
    return 1.50445531998027e-90*(1.0 - cos(theta)**2)**27*(2.08677292423841e+93*cos(theta)**4 - 1.088751090907e+92*cos(theta)**2 + 4.81748270312831e+89)*cos(54*phi)

#@torch.jit.script
def Yl58_m55(theta, phi):
    return 7.07636257528082e-92*(1.0 - cos(theta)**2)**27.5*(8.34709169695365e+93*cos(theta)**3 - 2.17750218181399e+92*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl58_m56(theta, phi):
    return 3.82645864466199e-93*(1.0 - cos(theta)**2)**28*(2.50412750908609e+94*cos(theta)**2 - 2.17750218181399e+92)*cos(56*phi)

#@torch.jit.script
def Yl58_m57(theta, phi):
    return 12.6362887339723*(1.0 - cos(theta)**2)**28.5*cos(57*phi)*cos(theta)

#@torch.jit.script
def Yl58_m58(theta, phi):
    return 1.17324995487893*(1.0 - cos(theta)**2)**29*cos(58*phi)

#@torch.jit.script
def Yl59_m_minus_59(theta, phi):
    return 1.17821086476446*(1.0 - cos(theta)**2)**29.5*sin(59*phi)

#@torch.jit.script
def Yl59_m_minus_58(theta, phi):
    return 12.7986459962836*(1.0 - cos(theta)**2)**29*sin(58*phi)*cos(theta)

#@torch.jit.script
def Yl59_m_minus_57(theta, phi):
    return 3.34117835278681e-95*(1.0 - cos(theta)**2)**28.5*(2.92982918563073e+96*cos(theta)**2 - 2.50412750908609e+94)*sin(57*phi)

#@torch.jit.script
def Yl59_m_minus_56(theta, phi):
    return 6.2328873960835e-94*(1.0 - cos(theta)**2)**28*(9.76609728543577e+95*cos(theta)**3 - 2.50412750908609e+94*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl59_m_minus_55(theta, phi):
    return 1.33680541719571e-92*(1.0 - cos(theta)**2)**27.5*(2.44152432135894e+95*cos(theta)**4 - 1.25206375454305e+94*cos(theta)**2 + 5.44375545453499e+91)*sin(55*phi)

#@torch.jit.script
def Yl59_m_minus_54(theta, phi):
    return 3.19157918962223e-91*(1.0 - cos(theta)**2)**27*(4.88304864271788e+94*cos(theta)**5 - 4.17354584847682e+93*cos(theta)**3 + 5.44375545453499e+91*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl59_m_minus_53(theta, phi):
    return 8.3103721316322e-90*(1.0 - cos(theta)**2)**26.5*(8.13841440452981e+93*cos(theta)**6 - 1.04338646211921e+93*cos(theta)**4 + 2.72187772726749e+91*cos(theta)**2 - 8.02913783854718e+88)*sin(53*phi)

#@torch.jit.script
def Yl59_m_minus_52(theta, phi):
    return 2.32690419685702e-88*(1.0 - cos(theta)**2)**26*(1.16263062921854e+93*cos(theta)**7 - 2.08677292423841e+92*cos(theta)**5 + 9.07292575755831e+90*cos(theta)**3 - 8.02913783854718e+88*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl59_m_minus_51(theta, phi):
    return 6.9340183368084e-87*(1.0 - cos(theta)**2)**25.5*(1.45328828652318e+92*cos(theta)**8 - 3.47795487373069e+91*cos(theta)**6 + 2.26823143938958e+90*cos(theta)**4 - 4.01456891927359e+88*cos(theta)**2 + 9.04182189025583e+85)*sin(51*phi)

#@torch.jit.script
def Yl59_m_minus_50(theta, phi):
    return 2.18173793550562e-85*(1.0 - cos(theta)**2)**25*(1.61476476280353e+91*cos(theta)**9 - 4.96850696247241e+90*cos(theta)**7 + 4.53646287877916e+89*cos(theta)**5 - 1.33818963975786e+88*cos(theta)**3 + 9.04182189025583e+85*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl59_m_minus_49(theta, phi):
    return 7.20304009217948e-84*(1.0 - cos(theta)**2)**24.5*(1.61476476280353e+90*cos(theta)**10 - 6.21063370309051e+89*cos(theta)**8 + 7.56077146463193e+88*cos(theta)**6 - 3.34547409939466e+87*cos(theta)**4 + 4.52091094512792e+85*cos(theta)**2 - 8.29524944060168e+82)*sin(49*phi)

#@torch.jit.script
def Yl59_m_minus_48(theta, phi):
    return 2.48269890330301e-82*(1.0 - cos(theta)**2)**24*(1.46796796618503e+89*cos(theta)**11 - 6.90070411454501e+88*cos(theta)**9 + 1.08011020923313e+88*cos(theta)**7 - 6.69094819878932e+86*cos(theta)**5 + 1.50697031504264e+85*cos(theta)**3 - 8.29524944060168e+82*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl59_m_minus_47(theta, phi):
    return 8.89624150767567e-81*(1.0 - cos(theta)**2)**23.5*(1.22330663848752e+88*cos(theta)**12 - 6.90070411454501e+87*cos(theta)**10 + 1.35013776154142e+87*cos(theta)**8 - 1.11515803313155e+86*cos(theta)**6 + 3.7674257876066e+84*cos(theta)**4 - 4.14762472030084e+82*cos(theta)**2 + 6.46047464221315e+79)*sin(47*phi)

#@torch.jit.script
def Yl59_m_minus_46(theta, phi):
    return 3.30241138659108e-79*(1.0 - cos(theta)**2)**23*(9.41005106528865e+86*cos(theta)**13 - 6.2733673768591e+86*cos(theta)**11 + 1.50015306837935e+86*cos(theta)**9 - 1.59308290447365e+85*cos(theta)**7 + 7.53485157521319e+83*cos(theta)**5 - 1.38254157343361e+82*cos(theta)**3 + 6.46047464221315e+79*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl59_m_minus_45(theta, phi):
    return 1.26616364741849e-77*(1.0 - cos(theta)**2)**22.5*(6.72146504663475e+85*cos(theta)**14 - 5.22780614738258e+85*cos(theta)**12 + 1.50015306837935e+85*cos(theta)**10 - 1.99135363059206e+84*cos(theta)**8 + 1.25580859586887e+83*cos(theta)**6 - 3.45635393358403e+81*cos(theta)**4 + 3.23023732110657e+79*cos(theta)**2 - 4.39488070898854e+76)*sin(45*phi)

#@torch.jit.script
def Yl59_m_minus_44(theta, phi):
    return 5.00094570655272e-76*(1.0 - cos(theta)**2)**22*(4.4809766977565e+84*cos(theta)**15 - 4.02138934414045e+84*cos(theta)**13 + 1.3637755167085e+84*cos(theta)**11 - 2.21261514510229e+83*cos(theta)**9 + 1.79401227981266e+82*cos(theta)**7 - 6.91270786716807e+80*cos(theta)**5 + 1.07674577370219e+79*cos(theta)**3 - 4.39488070898854e+76*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl59_m_minus_43(theta, phi):
    return 2.03016222794868e-74*(1.0 - cos(theta)**2)**21.5*(2.80061043609781e+83*cos(theta)**16 - 2.87242096010032e+83*cos(theta)**14 + 1.13647959725708e+83*cos(theta)**12 - 2.21261514510229e+82*cos(theta)**10 + 2.24251534976583e+81*cos(theta)**8 - 1.15211797786134e+80*cos(theta)**6 + 2.69186443425548e+78*cos(theta)**4 - 2.19744035449427e+76*cos(theta)**2 + 2.66679654671634e+73)*sin(43*phi)

#@torch.jit.script
def Yl59_m_minus_42(theta, phi):
    return 8.45386464102844e-73*(1.0 - cos(theta)**2)**21*(1.64741790358695e+82*cos(theta)**17 - 1.91494730673355e+82*cos(theta)**15 + 8.74215074813141e+81*cos(theta)**13 - 2.01146831372935e+81*cos(theta)**11 + 2.49168372196203e+80*cos(theta)**9 - 1.64588282551621e+79*cos(theta)**7 + 5.38372886851096e+77*cos(theta)**5 - 7.32480118164756e+75*cos(theta)**3 + 2.66679654671634e+73*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl59_m_minus_41(theta, phi):
    return 3.60455975337536e-71*(1.0 - cos(theta)**2)**20.5*(9.15232168659416e+80*cos(theta)**18 - 1.19684206670847e+81*cos(theta)**16 + 6.24439339152244e+80*cos(theta)**14 - 1.67622359477446e+80*cos(theta)**12 + 2.49168372196203e+79*cos(theta)**10 - 2.05735353189526e+78*cos(theta)**8 + 8.97288144751826e+76*cos(theta)**6 - 1.83120029541189e+75*cos(theta)**4 + 1.33339827335817e+73*cos(theta)**2 - 1.46688478917291e+70)*sin(41*phi)

#@torch.jit.script
def Yl59_m_minus_40(theta, phi):
    return 1.57119117009171e-69*(1.0 - cos(theta)**2)**20*(4.81701141399693e+79*cos(theta)**19 - 7.04024745122628e+79*cos(theta)**17 + 4.16292892768163e+79*cos(theta)**15 - 1.28940276521112e+79*cos(theta)**13 + 2.26516701996549e+78*cos(theta)**11 - 2.28594836877251e+77*cos(theta)**9 + 1.28184020678832e+76*cos(theta)**7 - 3.66240059082378e+74*cos(theta)**5 + 4.44466091119391e+72*cos(theta)**3 - 1.46688478917291e+70*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl59_m_minus_39(theta, phi):
    return 6.99135934714332e-68*(1.0 - cos(theta)**2)**19.5*(2.40850570699846e+78*cos(theta)**20 - 3.9112485840146e+78*cos(theta)**18 + 2.60183057980102e+78*cos(theta)**16 - 9.21001975150802e+77*cos(theta)**14 + 1.88763918330457e+77*cos(theta)**12 - 2.28594836877251e+76*cos(theta)**10 + 1.6023002584854e+75*cos(theta)**8 - 6.1040009847063e+73*cos(theta)**6 + 1.11116522779848e+72*cos(theta)**4 - 7.33442394586453e+69*cos(theta)**2 + 7.4085090362268e+66)*sin(39*phi)

#@torch.jit.script
def Yl59_m_minus_38(theta, phi):
    return 3.17164309407581e-66*(1.0 - cos(theta)**2)**19*(1.14690747952308e+77*cos(theta)**21 - 2.05855188632347e+77*cos(theta)**19 + 1.53048857635354e+77*cos(theta)**17 - 6.14001316767201e+76*cos(theta)**15 + 1.45203014100352e+76*cos(theta)**13 - 2.07813488070228e+75*cos(theta)**11 + 1.78033362053934e+74*cos(theta)**9 - 8.72000140672328e+72*cos(theta)**7 + 2.22233045559695e+71*cos(theta)**5 - 2.44480798195484e+69*cos(theta)**3 + 7.4085090362268e+66*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl59_m_minus_37(theta, phi):
    return 1.46514807105522e-64*(1.0 - cos(theta)**2)**18.5*(5.21321581601399e+75*cos(theta)**22 - 1.02927594316174e+76*cos(theta)**20 + 8.50271431307522e+75*cos(theta)**18 - 3.83750822979501e+75*cos(theta)**16 + 1.03716438643108e+75*cos(theta)**14 - 1.7317790672519e+74*cos(theta)**12 + 1.78033362053934e+73*cos(theta)**10 - 1.09000017584041e+72*cos(theta)**8 + 3.70388409266159e+70*cos(theta)**6 - 6.11201995488711e+68*cos(theta)**4 + 3.7042545181134e+66*cos(theta)**2 - 3.47165371894414e+63)*sin(37*phi)

#@torch.jit.script
def Yl59_m_minus_36(theta, phi):
    return 6.88463708935914e-63*(1.0 - cos(theta)**2)**18*(2.26661557218e+74*cos(theta)**23 - 4.90131401505589e+74*cos(theta)**21 + 4.47511279635538e+74*cos(theta)**19 - 2.25735778223236e+74*cos(theta)**17 + 6.91442924287389e+73*cos(theta)**15 - 1.33213774403992e+73*cos(theta)**13 + 1.61848510958122e+72*cos(theta)**11 - 1.21111130648935e+71*cos(theta)**9 + 5.29126298951656e+69*cos(theta)**7 - 1.22240399097742e+68*cos(theta)**5 + 1.2347515060378e+66*cos(theta)**3 - 3.47165371894414e+63*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl59_m_minus_35(theta, phi):
    return 3.28736915333476e-61*(1.0 - cos(theta)**2)**17.5*(9.44423155074998e+72*cos(theta)**24 - 2.22787000684359e+73*cos(theta)**22 + 2.23755639817769e+73*cos(theta)**20 - 1.25408765679575e+73*cos(theta)**18 + 4.32151827679618e+72*cos(theta)**16 - 9.51526960028517e+71*cos(theta)**14 + 1.34873759131768e+71*cos(theta)**12 - 1.21111130648935e+70*cos(theta)**10 + 6.6140787368957e+68*cos(theta)**8 - 2.03733998496237e+67*cos(theta)**6 + 3.0868787650945e+65*cos(theta)**4 - 1.73582685947207e+63*cos(theta)**2 + 1.52265513988778e+60)*sin(35*phi)

#@torch.jit.script
def Yl59_m_minus_34(theta, phi):
    return 1.59361132285127e-59*(1.0 - cos(theta)**2)**17*(3.77769262029999e+71*cos(theta)**25 - 9.68639133410255e+71*cos(theta)**23 + 1.06550304675128e+72*cos(theta)**21 - 6.6004613515566e+71*cos(theta)**19 + 2.54206957458599e+71*cos(theta)**17 - 6.34351306685678e+70*cos(theta)**15 + 1.03749045485975e+70*cos(theta)**13 - 1.10101027862668e+69*cos(theta)**11 + 7.34897637432855e+67*cos(theta)**9 - 2.91048569280339e+66*cos(theta)**7 + 6.173757530189e+64*cos(theta)**5 - 5.78608953157357e+62*cos(theta)**3 + 1.52265513988778e+60*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl59_m_minus_33(theta, phi):
    return 7.83629099946985e-58*(1.0 - cos(theta)**2)**16.5*(1.45295870011538e+70*cos(theta)**26 - 4.03599638920939e+70*cos(theta)**24 + 4.84319566705127e+70*cos(theta)**22 - 3.3002306757783e+70*cos(theta)**20 + 1.41226087476999e+70*cos(theta)**18 - 3.96469566678549e+69*cos(theta)**16 + 7.4106461061411e+68*cos(theta)**14 - 9.17508565522231e+67*cos(theta)**12 + 7.34897637432855e+66*cos(theta)**10 - 3.63810711600423e+65*cos(theta)**8 + 1.02895958836483e+64*cos(theta)**6 - 1.44652238289339e+62*cos(theta)**4 + 7.61327569943891e+59*cos(theta)**2 - 6.2971676587584e+56)*sin(33*phi)

#@torch.jit.script
def Yl59_m_minus_32(theta, phi):
    return 3.90558730877798e-56*(1.0 - cos(theta)**2)**16*(5.38132851894586e+68*cos(theta)**27 - 1.61439855568376e+69*cos(theta)**25 + 2.10573724654403e+69*cos(theta)**23 - 1.57153841703729e+69*cos(theta)**21 + 7.43295197247365e+68*cos(theta)**19 - 2.33217392163852e+68*cos(theta)**17 + 4.9404307374274e+67*cos(theta)**15 - 7.05775819632485e+66*cos(theta)**13 + 6.68088761302595e+65*cos(theta)**11 - 4.0423412400047e+64*cos(theta)**9 + 1.46994226909262e+63*cos(theta)**7 - 2.89304476578679e+61*cos(theta)**5 + 2.53775856647964e+59*cos(theta)**3 - 6.2971676587584e+56*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl59_m_minus_31(theta, phi):
    return 1.97145134236406e-54*(1.0 - cos(theta)**2)**15.5*(1.92190304248066e+67*cos(theta)**28 - 6.2092252141683e+67*cos(theta)**26 + 8.77390519393347e+67*cos(theta)**24 - 7.14335644107857e+67*cos(theta)**22 + 3.71647598623683e+67*cos(theta)**20 - 1.29565217868807e+67*cos(theta)**18 + 3.08776921089212e+66*cos(theta)**16 - 5.04125585451775e+65*cos(theta)**14 + 5.5674063441883e+64*cos(theta)**12 - 4.0423412400047e+63*cos(theta)**10 + 1.83742783636577e+62*cos(theta)**8 - 4.82174127631131e+60*cos(theta)**6 + 6.34439641619909e+58*cos(theta)**4 - 3.1485838293792e+56*cos(theta)**2 + 2.4714158786336e+53)*sin(31*phi)

#@torch.jit.script
def Yl59_m_minus_30(theta, phi):
    return 1.00717819832226e-52*(1.0 - cos(theta)**2)**15*(6.62725187062298e+65*cos(theta)**29 - 2.29971304228456e+66*cos(theta)**27 + 3.50956207757339e+66*cos(theta)**25 - 3.10580714829503e+66*cos(theta)**23 + 1.76975046963658e+66*cos(theta)**21 - 6.81922199309509e+65*cos(theta)**19 + 1.81633482993654e+65*cos(theta)**17 - 3.36083723634517e+64*cos(theta)**15 + 4.28262026476023e+63*cos(theta)**13 - 3.67485567273155e+62*cos(theta)**11 + 2.04158648485086e+61*cos(theta)**9 - 6.88820182330187e+59*cos(theta)**7 + 1.26887928323982e+58*cos(theta)**5 - 1.0495279431264e+56*cos(theta)**3 + 2.4714158786336e+53*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl59_m_minus_29(theta, phi):
    return 5.20429549014948e-51*(1.0 - cos(theta)**2)**14.5*(2.20908395687433e+64*cos(theta)**30 - 8.21326086530198e+64*cos(theta)**28 + 1.34983156829746e+65*cos(theta)**26 - 1.2940863117896e+65*cos(theta)**24 + 8.04432031652993e+64*cos(theta)**22 - 3.40961099654755e+64*cos(theta)**20 + 1.0090749055203e+64*cos(theta)**18 - 2.10052327271573e+63*cos(theta)**16 + 3.05901447482873e+62*cos(theta)**14 - 3.06237972727629e+61*cos(theta)**12 + 2.04158648485086e+60*cos(theta)**10 - 8.61025227912734e+58*cos(theta)**8 + 2.1147988053997e+57*cos(theta)**6 - 2.623819857816e+55*cos(theta)**4 + 1.2357079393168e+53*cos(theta)**2 - 9.25623924581871e+49)*sin(29*phi)

#@torch.jit.script
def Yl59_m_minus_28(theta, phi):
    return 2.71821703594654e-49*(1.0 - cos(theta)**2)**14*(7.12607728023976e+62*cos(theta)**31 - 2.83215891906965e+63*cos(theta)**29 + 4.99937617887947e+63*cos(theta)**27 - 5.17634524715839e+63*cos(theta)**25 + 3.49753057240432e+63*cos(theta)**23 - 1.62362428407026e+63*cos(theta)**21 + 5.31092055537001e+62*cos(theta)**19 - 1.2356019251269e+62*cos(theta)**17 + 2.03934298321916e+61*cos(theta)**15 - 2.35567671328945e+60*cos(theta)**13 + 1.85598771350078e+59*cos(theta)**11 - 9.56694697680815e+57*cos(theta)**9 + 3.021141150571e+56*cos(theta)**7 - 5.247639715632e+54*cos(theta)**5 + 4.11902646438933e+52*cos(theta)**3 - 9.25623924581871e+49*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl59_m_minus_27(theta, phi):
    return 1.43422981181384e-47*(1.0 - cos(theta)**2)**13.5*(2.22689915007493e+61*cos(theta)**32 - 9.44052973023216e+61*cos(theta)**30 + 1.78549149245695e+62*cos(theta)**28 - 1.99090201813784e+62*cos(theta)**26 + 1.45730440516846e+62*cos(theta)**24 - 7.38011038213755e+61*cos(theta)**22 + 2.655460277685e+61*cos(theta)**20 - 6.86445513959389e+60*cos(theta)**18 + 1.27458936451197e+60*cos(theta)**16 - 1.68262622377818e+59*cos(theta)**14 + 1.54665642791732e+58*cos(theta)**12 - 9.56694697680815e+56*cos(theta)**10 + 3.77642643821374e+55*cos(theta)**8 - 8.74606619272001e+53*cos(theta)**6 + 1.02975661609733e+52*cos(theta)**4 - 4.62811962290936e+49*cos(theta)**2 + 3.32479857967626e+46)*sin(27*phi)

#@torch.jit.script
def Yl59_m_minus_26(theta, phi):
    return 7.64055561100451e-46*(1.0 - cos(theta)**2)**13*(6.74817924265129e+59*cos(theta)**33 - 3.04533217104263e+60*cos(theta)**31 + 6.1568672153688e+60*cos(theta)**29 - 7.3737111782883e+60*cos(theta)**27 + 5.82921762067386e+60*cos(theta)**25 - 3.20874364440763e+60*cos(theta)**23 + 1.26450489413572e+60*cos(theta)**21 - 3.61287112610205e+59*cos(theta)**19 + 7.49758449712925e+58*cos(theta)**17 - 1.12175081585212e+58*cos(theta)**15 + 1.18973571378255e+57*cos(theta)**13 - 8.69722452437105e+55*cos(theta)**11 + 4.19602937579305e+54*cos(theta)**9 - 1.24943802753143e+53*cos(theta)**7 + 2.05951323219466e+51*cos(theta)**5 - 1.54270654096979e+49*cos(theta)**3 + 3.32479857967626e+46*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl59_m_minus_25(theta, phi):
    return 4.10746491439213e-44*(1.0 - cos(theta)**2)**12.5*(1.98475860077979e+58*cos(theta)**34 - 9.51666303450823e+58*cos(theta)**32 + 2.0522890717896e+59*cos(theta)**30 - 2.63346827796011e+59*cos(theta)**28 + 2.24200677718225e+59*cos(theta)**26 - 1.33697651850318e+59*cos(theta)**24 + 5.74774951879871e+58*cos(theta)**22 - 1.80643556305102e+58*cos(theta)**20 + 4.16532472062736e+57*cos(theta)**18 - 7.01094259907576e+56*cos(theta)**16 + 8.49811224130395e+55*cos(theta)**14 - 7.24768710364254e+54*cos(theta)**12 + 4.19602937579305e+53*cos(theta)**10 - 1.56179753441429e+52*cos(theta)**8 + 3.43252205365777e+50*cos(theta)**6 - 3.85676635242446e+48*cos(theta)**4 + 1.66239928983813e+46*cos(theta)**2 - 1.15044933552812e+43)*sin(25*phi)

#@torch.jit.script
def Yl59_m_minus_24(theta, phi):
    return 2.22714004920008e-42*(1.0 - cos(theta)**2)**12*(5.67073885937083e+56*cos(theta)**35 - 2.88383728318431e+57*cos(theta)**33 + 6.62028732835355e+57*cos(theta)**31 - 9.08092509641416e+57*cos(theta)**29 + 8.30372880437872e+57*cos(theta)**27 - 5.34790607401271e+57*cos(theta)**25 + 2.49902152991248e+57*cos(theta)**23 - 8.60207410976678e+56*cos(theta)**21 + 2.19227616875124e+56*cos(theta)**19 - 4.12408388180927e+55*cos(theta)**17 + 5.6654081608693e+54*cos(theta)**15 - 5.57514392587888e+53*cos(theta)**13 + 3.81457215981186e+52*cos(theta)**11 - 1.73533059379365e+51*cos(theta)**9 + 4.90360293379682e+49*cos(theta)**7 - 7.71353270484893e+47*cos(theta)**5 + 5.5413309661271e+45*cos(theta)**3 - 1.15044933552812e+43*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl59_m_minus_23(theta, phi):
    return 1.21741268938137e-40*(1.0 - cos(theta)**2)**11.5*(1.57520523871412e+55*cos(theta)**36 - 8.4818743623068e+55*cos(theta)**34 + 2.06883979011048e+56*cos(theta)**32 - 3.02697503213805e+56*cos(theta)**30 + 2.96561743013526e+56*cos(theta)**28 - 2.05688695154335e+56*cos(theta)**26 + 1.04125897079687e+56*cos(theta)**24 - 3.91003368625763e+55*cos(theta)**22 + 1.09613808437562e+55*cos(theta)**20 - 2.29115771211626e+54*cos(theta)**18 + 3.54088010054331e+53*cos(theta)**16 - 3.98224566134206e+52*cos(theta)**14 + 3.17881013317655e+51*cos(theta)**12 - 1.73533059379365e+50*cos(theta)**10 + 6.12950366724602e+48*cos(theta)**8 - 1.28558878414149e+47*cos(theta)**6 + 1.38533274153178e+45*cos(theta)**4 - 5.75224667764059e+42*cos(theta)**2 + 3.85023204661352e+39)*sin(23*phi)

#@torch.jit.script
def Yl59_m_minus_22(theta, phi):
    return 6.70572304312772e-39*(1.0 - cos(theta)**2)**11*(4.25731145598411e+53*cos(theta)**37 - 2.4233926749448e+54*cos(theta)**35 + 6.26921148518329e+54*cos(theta)**33 - 9.76443558754211e+54*cos(theta)**31 + 1.02262670004664e+55*cos(theta)**29 - 7.61809982053093e+54*cos(theta)**27 + 4.16503588318747e+54*cos(theta)**25 - 1.70001464619897e+54*cos(theta)**23 + 5.21970516369343e+53*cos(theta)**21 - 1.20587248006119e+53*cos(theta)**19 + 2.08287064737842e+52*cos(theta)**17 - 2.6548304408947e+51*cos(theta)**15 + 2.44523856398196e+50*cos(theta)**13 - 1.57757326708514e+49*cos(theta)**11 + 6.81055963027336e+47*cos(theta)**9 - 1.83655540591641e+46*cos(theta)**7 + 2.77066548306355e+44*cos(theta)**5 - 1.91741555921353e+42*cos(theta)**3 + 3.85023204661352e+39*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl59_m_minus_21(theta, phi):
    return 3.72031677243794e-37*(1.0 - cos(theta)**2)**10.5*(1.12034511999582e+52*cos(theta)**38 - 6.73164631929111e+52*cos(theta)**36 + 1.84388573093626e+53*cos(theta)**34 - 3.05138612110691e+53*cos(theta)**32 + 3.40875566682213e+53*cos(theta)**30 - 2.7207499359039e+53*cos(theta)**28 + 1.60193687814903e+53*cos(theta)**26 - 7.08339435916237e+52*cos(theta)**24 + 2.37259325622429e+52*cos(theta)**22 - 6.02936240030595e+51*cos(theta)**20 + 1.15715035965468e+51*cos(theta)**18 - 1.65926902555919e+50*cos(theta)**16 + 1.74659897427283e+49*cos(theta)**14 - 1.31464438923762e+48*cos(theta)**12 + 6.81055963027336e+46*cos(theta)**10 - 2.29569425739551e+45*cos(theta)**8 + 4.61777580510592e+43*cos(theta)**6 - 4.79353889803383e+41*cos(theta)**4 + 1.92511602330676e+39*cos(theta)**2 - 1.25088760448782e+36)*sin(21*phi)

#@torch.jit.script
def Yl59_m_minus_20(theta, phi):
    return 2.07805585796733e-35*(1.0 - cos(theta)**2)**10*(2.87267979486107e+50*cos(theta)**39 - 1.81936387007868e+51*cos(theta)**37 + 5.26824494553217e+51*cos(theta)**35 - 9.24662460941488e+51*cos(theta)**33 + 1.09959860220069e+52*cos(theta)**31 - 9.38189633070312e+51*cos(theta)**29 + 5.9330995487001e+51*cos(theta)**27 - 2.83335774366495e+51*cos(theta)**25 + 1.03156228531491e+51*cos(theta)**23 - 2.87112495252664e+50*cos(theta)**21 + 6.09026505081409e+49*cos(theta)**19 - 9.76040603270112e+48*cos(theta)**17 + 1.16439931618189e+48*cos(theta)**15 - 1.01126491479817e+47*cos(theta)**13 + 6.19141784570305e+45*cos(theta)**11 - 2.55077139710613e+44*cos(theta)**9 + 6.59682257872274e+42*cos(theta)**7 - 9.58707779606765e+40*cos(theta)**5 + 6.41705341102253e+38*cos(theta)**3 - 1.25088760448782e+36*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl59_m_minus_19(theta, phi):
    return 1.16815577002e-33*(1.0 - cos(theta)**2)**9.5*(7.18169948715268e+48*cos(theta)**40 - 4.78779965810179e+49*cos(theta)**38 + 1.46340137375894e+50*cos(theta)**36 - 2.71959547335732e+50*cos(theta)**34 + 3.43624563187715e+50*cos(theta)**32 - 3.12729877690104e+50*cos(theta)**30 + 2.11896412453575e+50*cos(theta)**28 - 1.08975297833267e+50*cos(theta)**26 + 4.29817618881212e+49*cos(theta)**24 - 1.30505679660302e+49*cos(theta)**22 + 3.04513252540704e+48*cos(theta)**20 - 5.42244779594507e+47*cos(theta)**18 + 7.2774957261368e+46*cos(theta)**16 - 7.2233208199869e+45*cos(theta)**14 + 5.15951487141921e+44*cos(theta)**12 - 2.55077139710613e+43*cos(theta)**10 + 8.24602822340343e+41*cos(theta)**8 - 1.59784629934461e+40*cos(theta)**6 + 1.60426335275563e+38*cos(theta)**4 - 6.25443802243911e+35*cos(theta)**2 + 3.95850507749311e+32)*sin(19*phi)

#@torch.jit.script
def Yl59_m_minus_18(theta, phi):
    return 6.60602158177914e-32*(1.0 - cos(theta)**2)**9*(1.75163402125675e+47*cos(theta)**41 - 1.22764093797482e+48*cos(theta)**39 + 3.95513884799713e+48*cos(theta)**37 - 7.77027278102091e+48*cos(theta)**35 + 1.04128655511429e+49*cos(theta)**33 - 1.00880605706485e+49*cos(theta)**31 + 7.30677284322673e+48*cos(theta)**29 - 4.03612214197286e+48*cos(theta)**27 + 1.71927047552485e+48*cos(theta)**25 - 5.67415998523052e+47*cos(theta)**23 + 1.45006310733669e+47*cos(theta)**21 - 2.85391989260267e+46*cos(theta)**19 + 4.280879838904e+45*cos(theta)**17 - 4.8155472133246e+44*cos(theta)**15 + 3.96885759339939e+43*cos(theta)**13 - 2.3188830882783e+42*cos(theta)**11 + 9.16225358155936e+40*cos(theta)**9 - 2.2826375704923e+39*cos(theta)**7 + 3.20852670551126e+37*cos(theta)**5 - 2.08481267414637e+35*cos(theta)**3 + 3.95850507749311e+32*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl59_m_minus_17(theta, phi):
    return 3.75673011225594e-30*(1.0 - cos(theta)**2)**8.5*(4.17055719346846e+45*cos(theta)**42 - 3.06910234493704e+46*cos(theta)**40 + 1.04082601263082e+47*cos(theta)**38 - 2.15840910583914e+47*cos(theta)**36 + 3.06260751504202e+47*cos(theta)**34 - 3.15251892832766e+47*cos(theta)**32 + 2.43559094774224e+47*cos(theta)**30 - 1.44147219356174e+47*cos(theta)**28 + 6.61257875201864e+46*cos(theta)**26 - 2.36423332717938e+46*cos(theta)**24 + 6.59119594243949e+45*cos(theta)**22 - 1.42695994630133e+45*cos(theta)**20 + 2.37826657716889e+44*cos(theta)**18 - 3.00971700832787e+43*cos(theta)**16 + 2.83489828099957e+42*cos(theta)**14 - 1.93240257356525e+41*cos(theta)**12 + 9.16225358155936e+39*cos(theta)**10 - 2.85329696311537e+38*cos(theta)**8 + 5.34754450918544e+36*cos(theta)**6 - 5.21203168536592e+34*cos(theta)**4 + 1.97925253874655e+32*cos(theta)**2 - 1.22402754406095e+29)*sin(17*phi)

#@torch.jit.script
def Yl59_m_minus_16(theta, phi):
    return 2.14758825368198e-28*(1.0 - cos(theta)**2)**8*(9.6989702173685e+43*cos(theta)**43 - 7.4856154754562e+44*cos(theta)**41 + 2.66878464777134e+45*cos(theta)**39 - 5.83353812388957e+45*cos(theta)**37 + 8.75030718583435e+45*cos(theta)**35 - 9.55308766159897e+45*cos(theta)**33 + 7.85674499271691e+45*cos(theta)**31 - 4.97059377090254e+45*cos(theta)**29 + 2.44910324148839e+45*cos(theta)**27 - 9.45693330871753e+44*cos(theta)**25 + 2.86573736627804e+44*cos(theta)**23 - 6.79504736333968e+43*cos(theta)**21 + 1.25171925114152e+43*cos(theta)**19 - 1.77042176960463e+42*cos(theta)**17 + 1.88993218733304e+41*cos(theta)**15 - 1.48646351812711e+40*cos(theta)**13 + 8.32932143778124e+38*cos(theta)**11 - 3.17032995901708e+37*cos(theta)**9 + 7.63934929883634e+35*cos(theta)**7 - 1.04240633707318e+34*cos(theta)**5 + 6.59750846248851e+31*cos(theta)**3 - 1.22402754406095e+29*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl59_m_minus_15(theta, phi):
    return 1.23369552622453e-26*(1.0 - cos(theta)**2)**7.5*(2.2043114130383e+42*cos(theta)**44 - 1.78228939891814e+43*cos(theta)**42 + 6.67196161942835e+43*cos(theta)**40 - 1.53514161154989e+44*cos(theta)**38 + 2.43064088495399e+44*cos(theta)**36 - 2.80973166517617e+44*cos(theta)**34 + 2.45523281022403e+44*cos(theta)**32 - 1.65686459030085e+44*cos(theta)**30 + 8.74679729102995e+43*cos(theta)**28 - 3.63728204181443e+43*cos(theta)**26 + 1.19405723594918e+43*cos(theta)**24 - 3.08865789242713e+42*cos(theta)**22 + 6.2585962557076e+41*cos(theta)**20 - 9.83567649780351e+40*cos(theta)**18 + 1.18120761708315e+40*cos(theta)**16 - 1.06175965580508e+39*cos(theta)**14 + 6.94110119815103e+37*cos(theta)**12 - 3.17032995901708e+36*cos(theta)**10 + 9.54918662354542e+34*cos(theta)**8 - 1.73734389512197e+33*cos(theta)**6 + 1.64937711562213e+31*cos(theta)**4 - 6.12013772030474e+28*cos(theta)**2 + 3.70917437594227e+25)*sin(15*phi)

#@torch.jit.script
def Yl59_m_minus_14(theta, phi):
    return 7.11918217862839e-25*(1.0 - cos(theta)**2)**7*(4.89846980675177e+40*cos(theta)**45 - 4.1448590672515e+41*cos(theta)**43 + 1.6273077120557e+42*cos(theta)**41 - 3.93626054243561e+42*cos(theta)**39 + 6.56929968906483e+42*cos(theta)**37 - 8.0278047576462e+42*cos(theta)**35 + 7.44009942492132e+42*cos(theta)**33 - 5.34472448484144e+42*cos(theta)**31 + 3.01613699690688e+42*cos(theta)**29 - 1.34714149696831e+42*cos(theta)**27 + 4.77622894379673e+41*cos(theta)**25 - 1.34289473583788e+41*cos(theta)**23 + 2.98028393128933e+40*cos(theta)**21 - 5.17667184094921e+39*cos(theta)**19 + 6.94828010048913e+38*cos(theta)**17 - 7.07839770536721e+37*cos(theta)**15 + 5.33930861396233e+36*cos(theta)**13 - 2.88211814456098e+35*cos(theta)**11 + 1.06102073594949e+34*cos(theta)**9 - 2.48191985017425e+32*cos(theta)**7 + 3.29875423124426e+30*cos(theta)**5 - 2.04004590676825e+28*cos(theta)**3 + 3.70917437594227e+25*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl59_m_minus_13(theta, phi):
    return 4.12544168458379e-23*(1.0 - cos(theta)**2)**6.5*(1.06488474059821e+39*cos(theta)**46 - 9.4201342437534e+39*cos(theta)**44 + 3.87454217156118e+40*cos(theta)**42 - 9.84065135608902e+40*cos(theta)**40 + 1.72876307606969e+41*cos(theta)**38 - 2.22994576601283e+41*cos(theta)**36 + 2.18826453674156e+41*cos(theta)**34 - 1.67022640151295e+41*cos(theta)**32 + 1.00537899896896e+41*cos(theta)**30 - 4.81121963202967e+40*cos(theta)**28 + 1.83701113222951e+40*cos(theta)**26 - 5.59539473265784e+39*cos(theta)**24 + 1.35467451422242e+39*cos(theta)**22 - 2.58833592047461e+38*cos(theta)**20 + 3.86015561138285e+37*cos(theta)**18 - 4.4239985658545e+36*cos(theta)**16 + 3.81379186711595e+35*cos(theta)**14 - 2.40176512046749e+34*cos(theta)**12 + 1.06102073594949e+33*cos(theta)**10 - 3.10239981271781e+31*cos(theta)**8 + 5.49792371874043e+29*cos(theta)**6 - 5.10011476692062e+27*cos(theta)**4 + 1.85458718797113e+25*cos(theta)**2 - 1.10457843238305e+22)*sin(13*phi)

#@torch.jit.script
def Yl59_m_minus_12(theta, phi):
    return 2.3998584668763e-21*(1.0 - cos(theta)**2)**6*(2.26571221403875e+37*cos(theta)**47 - 2.09336316527853e+38*cos(theta)**45 + 9.01056318967716e+38*cos(theta)**43 - 2.40015886733878e+39*cos(theta)**41 + 4.43272583607613e+39*cos(theta)**39 - 6.02688044868333e+39*cos(theta)**37 + 6.25218439069018e+39*cos(theta)**35 - 5.06129212579682e+39*cos(theta)**33 + 3.24315806119019e+39*cos(theta)**31 - 1.65904125242403e+39*cos(theta)**29 + 6.80374493418338e+38*cos(theta)**27 - 2.23815789306314e+38*cos(theta)**25 + 5.88988919227141e+37*cos(theta)**23 - 1.23254091451172e+37*cos(theta)**21 + 2.03166084809624e+36*cos(theta)**19 - 2.60235209756147e+35*cos(theta)**17 + 2.54252791141063e+34*cos(theta)**15 - 1.84751163112884e+33*cos(theta)**13 + 9.64564305408629e+31*cos(theta)**11 - 3.44711090301979e+30*cos(theta)**9 + 7.85417674105775e+28*cos(theta)**7 - 1.02002295338412e+27*cos(theta)**5 + 6.18195729323711e+24*cos(theta)**3 - 1.10457843238305e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl59_m_minus_11(theta, phi):
    return 1.40099124953788e-19*(1.0 - cos(theta)**2)**5.5*(4.72023377924739e+35*cos(theta)**48 - 4.55078948973594e+36*cos(theta)**46 + 2.04785527038117e+37*cos(theta)**44 - 5.71466396985425e+37*cos(theta)**42 + 1.10818145901903e+38*cos(theta)**40 - 1.58602117070614e+38*cos(theta)**38 + 1.73671788630283e+38*cos(theta)**36 - 1.48861533111671e+38*cos(theta)**34 + 1.01348689412194e+38*cos(theta)**32 - 5.53013750808009e+37*cos(theta)**30 + 2.42990890506549e+37*cos(theta)**28 - 8.60829958870437e+36*cos(theta)**26 + 2.45412049677975e+36*cos(theta)**24 - 5.60245870232599e+35*cos(theta)**22 + 1.01583042404812e+35*cos(theta)**20 - 1.44575116531193e+34*cos(theta)**18 + 1.58907994463165e+33*cos(theta)**16 - 1.31965116509203e+32*cos(theta)**14 + 8.03803587840524e+30*cos(theta)**12 - 3.44711090301979e+29*cos(theta)**10 + 9.81772092632219e+27*cos(theta)**8 - 1.70003825564021e+26*cos(theta)**6 + 1.54548932330928e+24*cos(theta)**4 - 5.52289216191523e+21*cos(theta)**2 + 3.24113389783758e+18)*sin(11*phi)

#@torch.jit.script
def Yl59_m_minus_10(theta, phi):
    return 8.20507363208659e-18*(1.0 - cos(theta)**2)**5*(9.63313016172936e+33*cos(theta)**49 - 9.68253082922541e+34*cos(theta)**47 + 4.55078948973594e+35*cos(theta)**45 - 1.32899162089634e+36*cos(theta)**43 + 2.7028816073635e+36*cos(theta)**41 - 4.06672095052856e+36*cos(theta)**39 + 4.69383212514278e+36*cos(theta)**37 - 4.25318666033346e+36*cos(theta)**35 + 3.07117240643011e+36*cos(theta)**33 - 1.78391532518712e+36*cos(theta)**31 + 8.37899622436377e+35*cos(theta)**29 - 3.18825910692754e+35*cos(theta)**27 + 9.81648198711902e+34*cos(theta)**25 - 2.43585160970695e+34*cos(theta)**23 + 4.83728773356247e+33*cos(theta)**21 - 7.60921665953647e+32*cos(theta)**19 + 9.34752908606851e+31*cos(theta)**17 - 8.79767443394683e+30*cos(theta)**15 + 6.18310452185018e+29*cos(theta)**13 - 3.13373718456345e+28*cos(theta)**11 + 1.09085788070247e+27*cos(theta)**9 - 2.42862607948601e+25*cos(theta)**7 + 3.09097864661856e+23*cos(theta)**5 - 1.84096405397174e+21*cos(theta)**3 + 3.24113389783758e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl59_m_minus_9(theta, phi):
    return 4.81938953512238e-16*(1.0 - cos(theta)**2)**4.5*(1.92662603234587e+32*cos(theta)**50 - 2.01719392275529e+33*cos(theta)**48 + 9.89302062986074e+33*cos(theta)**46 - 3.02043550203713e+34*cos(theta)**44 + 6.43543239848451e+34*cos(theta)**42 - 1.01668023763214e+35*cos(theta)**40 + 1.23521898030073e+35*cos(theta)**38 - 1.18144073898152e+35*cos(theta)**36 + 9.03286001891208e+34*cos(theta)**34 - 5.57473539120976e+34*cos(theta)**32 + 2.79299874145459e+34*cos(theta)**30 - 1.13866396675984e+34*cos(theta)**28 + 3.77556999504578e+33*cos(theta)**26 - 1.01493817071123e+33*cos(theta)**24 + 2.19876715161931e+32*cos(theta)**22 - 3.80460832976824e+31*cos(theta)**20 + 5.19307171448251e+30*cos(theta)**18 - 5.49854652121677e+29*cos(theta)**16 + 4.41650322989299e+28*cos(theta)**14 - 2.61144765380287e+27*cos(theta)**12 + 1.09085788070247e+26*cos(theta)**10 - 3.03578259935751e+24*cos(theta)**8 + 5.15163107769759e+22*cos(theta)**6 - 4.60241013492936e+20*cos(theta)**4 + 1.62056694891879e+18*cos(theta)**2 - 939459100822486.0)*sin(9*phi)

#@torch.jit.script
def Yl59_m_minus_8(theta, phi):
    return 2.83812536234122e-14*(1.0 - cos(theta)**2)**4*(3.77769810263896e+30*cos(theta)**51 - 4.11672229133733e+31*cos(theta)**49 + 2.10489800635335e+32*cos(theta)**47 - 6.71207889341584e+32*cos(theta)**45 + 1.49661218569407e+33*cos(theta)**43 - 2.47970789666376e+33*cos(theta)**41 + 3.16722815461726e+33*cos(theta)**39 - 3.19308307832842e+33*cos(theta)**37 + 2.58081714826059e+33*cos(theta)**35 - 1.68931375491205e+33*cos(theta)**33 + 9.00967335953093e+32*cos(theta)**31 - 3.92642747158565e+32*cos(theta)**29 + 1.39835925742436e+32*cos(theta)**27 - 4.05975268284492e+31*cos(theta)**25 + 9.5598571809535e+30*cos(theta)**23 - 1.81171825227059e+30*cos(theta)**21 + 2.73319563920132e+29*cos(theta)**19 - 3.23443913012751e+28*cos(theta)**17 + 2.94433548659533e+27*cos(theta)**15 - 2.00880588754067e+26*cos(theta)**13 + 9.91688982456787e+24*cos(theta)**11 - 3.3730917770639e+23*cos(theta)**9 + 7.35947296813942e+21*cos(theta)**7 - 9.20482026985871e+19*cos(theta)**5 + 5.40188982972929e+17*cos(theta)**3 - 939459100822486.0*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl59_m_minus_7(theta, phi):
    return 1.67521536568042e-12*(1.0 - cos(theta)**2)**3.5*(7.26480404353647e+28*cos(theta)**52 - 8.23344458267467e+29*cos(theta)**50 + 4.38520417990281e+30*cos(theta)**48 - 1.45914758552518e+31*cos(theta)**46 + 3.40139133112289e+31*cos(theta)**44 - 5.90406642062799e+31*cos(theta)**42 + 7.91807038654315e+31*cos(theta)**40 - 8.40285020612743e+31*cos(theta)**38 + 7.16893652294609e+31*cos(theta)**36 - 4.96856986738838e+31*cos(theta)**34 + 2.81552292485342e+31*cos(theta)**32 - 1.30880915719521e+31*cos(theta)**30 + 4.994140205087e+30*cos(theta)**28 - 1.56144333955574e+30*cos(theta)**26 + 3.98327382539729e+29*cos(theta)**24 - 8.23508296486631e+28*cos(theta)**22 + 1.36659781960066e+28*cos(theta)**20 - 1.79691062784862e+27*cos(theta)**18 + 1.84020967912208e+26*cos(theta)**16 - 1.43486134824334e+25*cos(theta)**14 + 8.26407485380656e+23*cos(theta)**12 - 3.3730917770639e+22*cos(theta)**10 + 9.19934121017427e+20*cos(theta)**8 - 1.53413671164312e+19*cos(theta)**6 + 1.35047245743232e+17*cos(theta)**4 - 469729550411243.0*cos(theta)**2 + 269649569696.465)*sin(7*phi)

#@torch.jit.script
def Yl59_m_minus_6(theta, phi):
    return 9.90787572181769e-11*(1.0 - cos(theta)**2)**3*(1.37071774406348e+27*cos(theta)**53 - 1.61440089856366e+28*cos(theta)**51 + 8.94939628551594e+28*cos(theta)**49 - 3.10456933090465e+29*cos(theta)**47 + 7.55864740249532e+29*cos(theta)**45 - 1.37303870247163e+30*cos(theta)**43 + 1.93123667964467e+30*cos(theta)**41 - 2.15457697593011e+30*cos(theta)**39 + 1.93755041160705e+30*cos(theta)**37 - 1.41959139068239e+30*cos(theta)**35 + 8.53188765107096e+29*cos(theta)**33 - 4.22196502321037e+29*cos(theta)**31 + 1.72211731209897e+29*cos(theta)**29 - 5.78312347983607e+28*cos(theta)**27 + 1.59330953015892e+28*cos(theta)**25 - 3.5804708542897e+27*cos(theta)**23 + 6.50760866476505e+26*cos(theta)**21 - 9.45742435709799e+25*cos(theta)**19 + 1.08247628183652e+25*cos(theta)**17 - 9.56574232162224e+23*cos(theta)**15 + 6.35698065677427e+22*cos(theta)**13 - 3.06644707005809e+21*cos(theta)**11 + 1.0221490233527e+20*cos(theta)**9 - 2.19162387377588e+18*cos(theta)**7 + 2.70094491486465e+16*cos(theta)**5 - 156576516803748.0*cos(theta)**3 + 269649569696.465*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl59_m_minus_5(theta, phi):
    return 5.86994603577951e-9*(1.0 - cos(theta)**2)**2.5*(2.53836619271016e+25*cos(theta)**54 - 3.10461711262242e+26*cos(theta)**52 + 1.78987925710319e+27*cos(theta)**50 - 6.46785277271801e+27*cos(theta)**48 + 1.64318421793376e+28*cos(theta)**46 - 3.12054250561733e+28*cos(theta)**44 + 4.59818257058255e+28*cos(theta)**42 - 5.38644243982527e+28*cos(theta)**40 + 5.09881687265014e+28*cos(theta)**38 - 3.94330941856221e+28*cos(theta)**36 + 2.50937872090322e+28*cos(theta)**34 - 1.31936406975324e+28*cos(theta)**32 + 5.74039104032989e+27*cos(theta)**30 - 2.0654012427986e+27*cos(theta)**28 + 6.1281135775343e+26*cos(theta)**26 - 1.49186285595404e+26*cos(theta)**24 + 2.95800393852957e+25*cos(theta)**22 - 4.72871217854899e+24*cos(theta)**20 + 6.01375712131398e+23*cos(theta)**18 - 5.9785889510139e+22*cos(theta)**16 + 4.54070046912448e+21*cos(theta)**14 - 2.55537255838174e+20*cos(theta)**12 + 1.0221490233527e+19*cos(theta)**10 - 2.73952984221986e+17*cos(theta)**8 + 4.50157485810774e+15*cos(theta)**6 - 39144129200936.9*cos(theta)**4 + 134824784848.233*cos(theta)**2 - 76823239.2297622)*sin(5*phi)

#@torch.jit.script
def Yl59_m_minus_4(theta, phi):
    return 3.48261479279049e-7*(1.0 - cos(theta)**2)**2*(4.61521125947301e+23*cos(theta)**55 - 5.85776813702344e+24*cos(theta)**53 + 3.50956717079057e+25*cos(theta)**51 - 1.31996995361592e+26*cos(theta)**49 + 3.49613663390163e+26*cos(theta)**47 - 6.93453890137185e+26*cos(theta)**45 + 1.06934478385641e+27*cos(theta)**43 - 1.31376644873787e+27*cos(theta)**41 + 1.30738894170516e+27*cos(theta)**39 - 1.06575930231411e+27*cos(theta)**37 + 7.16965348829492e+26*cos(theta)**35 - 3.99807293864618e+26*cos(theta)**33 + 1.85173904526771e+26*cos(theta)**31 - 7.12207325102964e+25*cos(theta)**29 + 2.26967169538307e+25*cos(theta)**27 - 5.96745142381617e+24*cos(theta)**25 + 1.2860886689259e+24*cos(theta)**23 - 2.25176770407095e+23*cos(theta)**21 + 3.16513532700736e+22*cos(theta)**19 - 3.51681703000818e+21*cos(theta)**17 + 3.02713364608299e+20*cos(theta)**15 - 1.96567119875519e+19*cos(theta)**13 + 9.29226384866088e+17*cos(theta)**11 - 3.04392204691095e+16*cos(theta)**9 + 643082122586821.0*cos(theta)**7 - 7828825840187.38*cos(theta)**5 + 44941594949.4109*cos(theta)**3 - 76823239.2297622*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl59_m_minus_3(theta, phi):
    return 2.0685676504439e-5*(1.0 - cos(theta)**2)**1.5*(8.24144867763038e+21*cos(theta)**56 - 1.08477187722656e+23*cos(theta)**54 + 6.7491676361357e+23*cos(theta)**52 - 2.63993990723184e+24*cos(theta)**50 + 7.28361798729506e+24*cos(theta)**48 - 1.50750845681997e+25*cos(theta)**46 + 2.43032905421911e+25*cos(theta)**44 - 3.12801535413779e+25*cos(theta)**42 + 3.26847235426291e+25*cos(theta)**40 - 2.80462974293187e+25*cos(theta)**38 + 1.99157041341526e+25*cos(theta)**36 - 1.17590380548417e+25*cos(theta)**34 + 5.78668451646158e+24*cos(theta)**32 - 2.37402441700988e+24*cos(theta)**30 + 8.10597034065383e+23*cos(theta)**28 - 2.29517362454468e+23*cos(theta)**26 + 5.35870278719124e+22*cos(theta)**24 - 1.0235307745777e+22*cos(theta)**22 + 1.58256766350368e+21*cos(theta)**20 - 1.95378723889343e+20*cos(theta)**18 + 1.89195852880187e+19*cos(theta)**16 - 1.4040508562537e+18*cos(theta)**14 + 7.7435532072174e+16*cos(theta)**12 - 3.04392204691095e+15*cos(theta)**10 + 80385265323352.6*cos(theta)**8 - 1304804306697.9*cos(theta)**6 + 11235398737.3527*cos(theta)**4 - 38411619.6148811*cos(theta)**2 + 21775.2945662591)*sin(3*phi)

#@torch.jit.script
def Yl59_m_minus_2(theta, phi):
    return 0.00122971083950058*(1.0 - cos(theta)**2)*(1.44586818905796e+20*cos(theta)**57 - 1.9723125040483e+21*cos(theta)**55 + 1.27342785587466e+22*cos(theta)**53 - 5.17635275927812e+22*cos(theta)**51 + 1.48645265046838e+23*cos(theta)**49 - 3.20746480174461e+23*cos(theta)**47 + 5.40073123159802e+23*cos(theta)**45 - 7.27445431194835e+23*cos(theta)**43 + 7.97188379088514e+23*cos(theta)**41 - 7.19135831520992e+23*cos(theta)**39 + 5.38262273896015e+23*cos(theta)**37 - 3.35972515852621e+23*cos(theta)**35 + 1.75354076256412e+23*cos(theta)**33 - 7.65814328067703e+22*cos(theta)**31 + 2.79516218643235e+22*cos(theta)**29 - 8.50064305386918e+21*cos(theta)**27 + 2.1434811148765e+21*cos(theta)**25 - 4.45013380251176e+20*cos(theta)**23 + 7.53603649287467e+19*cos(theta)**21 - 1.02830907310181e+19*cos(theta)**19 + 1.11291678164816e+18*cos(theta)**17 - 9.36033904169137e+16*cos(theta)**15 + 5.95657939016723e+15*cos(theta)**13 - 276720186082814.0*cos(theta)**11 + 8931696147039.17*cos(theta)**9 - 186400615242.557*cos(theta)**7 + 2247079747.47055*cos(theta)**5 - 12803873.2049604*cos(theta)**3 + 21775.2945662591*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl59_m_minus_1(theta, phi):
    return 0.0731445404196522*(1.0 - cos(theta)**2)**0.5*(2.49287618803097e+18*cos(theta)**58 - 3.52198661437196e+19*cos(theta)**56 + 2.35819973310122e+20*cos(theta)**54 - 9.95452453707331e+20*cos(theta)**52 + 2.97290530093676e+21*cos(theta)**50 - 6.68221833696794e+21*cos(theta)**48 + 1.17407200686913e+22*cos(theta)**46 - 1.65328507089735e+22*cos(theta)**44 + 1.89806756925837e+22*cos(theta)**42 - 1.79783957880248e+22*cos(theta)**40 + 1.41647966814741e+22*cos(theta)**38 - 9.33256988479502e+21*cos(theta)**36 + 5.15747283107093e+21*cos(theta)**34 - 2.39316977521157e+21*cos(theta)**32 + 9.31720728810785e+20*cos(theta)**30 - 3.03594394781042e+20*cos(theta)**28 + 8.24415813414037e+19*cos(theta)**26 - 1.85422241771323e+19*cos(theta)**24 + 3.42547113312485e+18*cos(theta)**22 - 5.14154536550903e+17*cos(theta)**20 + 6.18287100915643e+16*cos(theta)**18 - 5.8502119010571e+15*cos(theta)**16 + 425469956440517.0*cos(theta)**14 - 23060015506901.1*cos(theta)**12 + 893169614703.917*cos(theta)**10 - 23300076905.3196*cos(theta)**8 + 374513291.245091*cos(theta)**6 - 3200968.30124009*cos(theta)**4 + 10887.6472831296*cos(theta)**2 - 6.15469038051417)*sin(phi)

#@torch.jit.script
def Yl59_m0(theta, phi):
    return 4.08476540174965e+17*cos(theta)**59 - 5.97353299349884e+18*cos(theta)**57 + 4.14511245983659e+19*cos(theta)**55 - 1.81577935187532e+20*cos(theta)**53 + 5.63545933982926e+20*cos(theta)**51 - 1.31838727674905e+21*cos(theta)**49 + 2.41498977797022e+21*cos(theta)**47 - 3.55184210882422e+21*cos(theta)**45 + 4.26738311618444e+21*cos(theta)**43 - 4.23921557086309e+21*cos(theta)**41 + 3.51126946273509e+21*cos(theta)**39 - 2.43847298208688e+21*cos(theta)**37 + 1.42458158427181e+21*cos(theta)**35 - 7.01096809463793e+20*cos(theta)**33 + 2.90564454785622e+20*cos(theta)**31 - 1.01207843801734e+20*cos(theta)**29 + 2.95189544421723e+19*cos(theta)**27 - 7.17034810325431e+18*cos(theta)**25 + 1.43982893639645e+18*cos(theta)**23 - 2.36697024631775e+17*cos(theta)**21 + 3.14597311219447e+16*cos(theta)**19 - 3.32691034128173e+15*cos(theta)**17 + 274218064493524.0*cos(theta)**15 - 17148836671721.3*cos(theta)**13 + 784981960325.27*cos(theta)**11 - 25028410329.2115*cos(theta)**9 + 517234656.631236*cos(theta)**7 - 6189132.64345069*cos(theta)**5 + 35085.7859606048*cos(theta)**3 - 59.5010502441009*cos(theta)

#@torch.jit.script
def Yl59_m1(theta, phi):
    return 0.0731445404196522*(1.0 - cos(theta)**2)**0.5*(2.49287618803097e+18*cos(theta)**58 - 3.52198661437196e+19*cos(theta)**56 + 2.35819973310122e+20*cos(theta)**54 - 9.95452453707331e+20*cos(theta)**52 + 2.97290530093676e+21*cos(theta)**50 - 6.68221833696794e+21*cos(theta)**48 + 1.17407200686913e+22*cos(theta)**46 - 1.65328507089735e+22*cos(theta)**44 + 1.89806756925837e+22*cos(theta)**42 - 1.79783957880248e+22*cos(theta)**40 + 1.41647966814741e+22*cos(theta)**38 - 9.33256988479502e+21*cos(theta)**36 + 5.15747283107093e+21*cos(theta)**34 - 2.39316977521157e+21*cos(theta)**32 + 9.31720728810785e+20*cos(theta)**30 - 3.03594394781042e+20*cos(theta)**28 + 8.24415813414037e+19*cos(theta)**26 - 1.85422241771323e+19*cos(theta)**24 + 3.42547113312485e+18*cos(theta)**22 - 5.14154536550903e+17*cos(theta)**20 + 6.18287100915643e+16*cos(theta)**18 - 5.8502119010571e+15*cos(theta)**16 + 425469956440517.0*cos(theta)**14 - 23060015506901.1*cos(theta)**12 + 893169614703.917*cos(theta)**10 - 23300076905.3196*cos(theta)**8 + 374513291.245091*cos(theta)**6 - 3200968.30124009*cos(theta)**4 + 10887.6472831296*cos(theta)**2 - 6.15469038051417)*cos(phi)

#@torch.jit.script
def Yl59_m2(theta, phi):
    return 0.00122971083950058*(1.0 - cos(theta)**2)*(1.44586818905796e+20*cos(theta)**57 - 1.9723125040483e+21*cos(theta)**55 + 1.27342785587466e+22*cos(theta)**53 - 5.17635275927812e+22*cos(theta)**51 + 1.48645265046838e+23*cos(theta)**49 - 3.20746480174461e+23*cos(theta)**47 + 5.40073123159802e+23*cos(theta)**45 - 7.27445431194835e+23*cos(theta)**43 + 7.97188379088514e+23*cos(theta)**41 - 7.19135831520992e+23*cos(theta)**39 + 5.38262273896015e+23*cos(theta)**37 - 3.35972515852621e+23*cos(theta)**35 + 1.75354076256412e+23*cos(theta)**33 - 7.65814328067703e+22*cos(theta)**31 + 2.79516218643235e+22*cos(theta)**29 - 8.50064305386918e+21*cos(theta)**27 + 2.1434811148765e+21*cos(theta)**25 - 4.45013380251176e+20*cos(theta)**23 + 7.53603649287467e+19*cos(theta)**21 - 1.02830907310181e+19*cos(theta)**19 + 1.11291678164816e+18*cos(theta)**17 - 9.36033904169137e+16*cos(theta)**15 + 5.95657939016723e+15*cos(theta)**13 - 276720186082814.0*cos(theta)**11 + 8931696147039.17*cos(theta)**9 - 186400615242.557*cos(theta)**7 + 2247079747.47055*cos(theta)**5 - 12803873.2049604*cos(theta)**3 + 21775.2945662591*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl59_m3(theta, phi):
    return 2.0685676504439e-5*(1.0 - cos(theta)**2)**1.5*(8.24144867763038e+21*cos(theta)**56 - 1.08477187722656e+23*cos(theta)**54 + 6.7491676361357e+23*cos(theta)**52 - 2.63993990723184e+24*cos(theta)**50 + 7.28361798729506e+24*cos(theta)**48 - 1.50750845681997e+25*cos(theta)**46 + 2.43032905421911e+25*cos(theta)**44 - 3.12801535413779e+25*cos(theta)**42 + 3.26847235426291e+25*cos(theta)**40 - 2.80462974293187e+25*cos(theta)**38 + 1.99157041341526e+25*cos(theta)**36 - 1.17590380548417e+25*cos(theta)**34 + 5.78668451646158e+24*cos(theta)**32 - 2.37402441700988e+24*cos(theta)**30 + 8.10597034065383e+23*cos(theta)**28 - 2.29517362454468e+23*cos(theta)**26 + 5.35870278719124e+22*cos(theta)**24 - 1.0235307745777e+22*cos(theta)**22 + 1.58256766350368e+21*cos(theta)**20 - 1.95378723889343e+20*cos(theta)**18 + 1.89195852880187e+19*cos(theta)**16 - 1.4040508562537e+18*cos(theta)**14 + 7.7435532072174e+16*cos(theta)**12 - 3.04392204691095e+15*cos(theta)**10 + 80385265323352.6*cos(theta)**8 - 1304804306697.9*cos(theta)**6 + 11235398737.3527*cos(theta)**4 - 38411619.6148811*cos(theta)**2 + 21775.2945662591)*cos(3*phi)

#@torch.jit.script
def Yl59_m4(theta, phi):
    return 3.48261479279049e-7*(1.0 - cos(theta)**2)**2*(4.61521125947301e+23*cos(theta)**55 - 5.85776813702344e+24*cos(theta)**53 + 3.50956717079057e+25*cos(theta)**51 - 1.31996995361592e+26*cos(theta)**49 + 3.49613663390163e+26*cos(theta)**47 - 6.93453890137185e+26*cos(theta)**45 + 1.06934478385641e+27*cos(theta)**43 - 1.31376644873787e+27*cos(theta)**41 + 1.30738894170516e+27*cos(theta)**39 - 1.06575930231411e+27*cos(theta)**37 + 7.16965348829492e+26*cos(theta)**35 - 3.99807293864618e+26*cos(theta)**33 + 1.85173904526771e+26*cos(theta)**31 - 7.12207325102964e+25*cos(theta)**29 + 2.26967169538307e+25*cos(theta)**27 - 5.96745142381617e+24*cos(theta)**25 + 1.2860886689259e+24*cos(theta)**23 - 2.25176770407095e+23*cos(theta)**21 + 3.16513532700736e+22*cos(theta)**19 - 3.51681703000818e+21*cos(theta)**17 + 3.02713364608299e+20*cos(theta)**15 - 1.96567119875519e+19*cos(theta)**13 + 9.29226384866088e+17*cos(theta)**11 - 3.04392204691095e+16*cos(theta)**9 + 643082122586821.0*cos(theta)**7 - 7828825840187.38*cos(theta)**5 + 44941594949.4109*cos(theta)**3 - 76823239.2297622*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl59_m5(theta, phi):
    return 5.86994603577951e-9*(1.0 - cos(theta)**2)**2.5*(2.53836619271016e+25*cos(theta)**54 - 3.10461711262242e+26*cos(theta)**52 + 1.78987925710319e+27*cos(theta)**50 - 6.46785277271801e+27*cos(theta)**48 + 1.64318421793376e+28*cos(theta)**46 - 3.12054250561733e+28*cos(theta)**44 + 4.59818257058255e+28*cos(theta)**42 - 5.38644243982527e+28*cos(theta)**40 + 5.09881687265014e+28*cos(theta)**38 - 3.94330941856221e+28*cos(theta)**36 + 2.50937872090322e+28*cos(theta)**34 - 1.31936406975324e+28*cos(theta)**32 + 5.74039104032989e+27*cos(theta)**30 - 2.0654012427986e+27*cos(theta)**28 + 6.1281135775343e+26*cos(theta)**26 - 1.49186285595404e+26*cos(theta)**24 + 2.95800393852957e+25*cos(theta)**22 - 4.72871217854899e+24*cos(theta)**20 + 6.01375712131398e+23*cos(theta)**18 - 5.9785889510139e+22*cos(theta)**16 + 4.54070046912448e+21*cos(theta)**14 - 2.55537255838174e+20*cos(theta)**12 + 1.0221490233527e+19*cos(theta)**10 - 2.73952984221986e+17*cos(theta)**8 + 4.50157485810774e+15*cos(theta)**6 - 39144129200936.9*cos(theta)**4 + 134824784848.233*cos(theta)**2 - 76823239.2297622)*cos(5*phi)

#@torch.jit.script
def Yl59_m6(theta, phi):
    return 9.90787572181769e-11*(1.0 - cos(theta)**2)**3*(1.37071774406348e+27*cos(theta)**53 - 1.61440089856366e+28*cos(theta)**51 + 8.94939628551594e+28*cos(theta)**49 - 3.10456933090465e+29*cos(theta)**47 + 7.55864740249532e+29*cos(theta)**45 - 1.37303870247163e+30*cos(theta)**43 + 1.93123667964467e+30*cos(theta)**41 - 2.15457697593011e+30*cos(theta)**39 + 1.93755041160705e+30*cos(theta)**37 - 1.41959139068239e+30*cos(theta)**35 + 8.53188765107096e+29*cos(theta)**33 - 4.22196502321037e+29*cos(theta)**31 + 1.72211731209897e+29*cos(theta)**29 - 5.78312347983607e+28*cos(theta)**27 + 1.59330953015892e+28*cos(theta)**25 - 3.5804708542897e+27*cos(theta)**23 + 6.50760866476505e+26*cos(theta)**21 - 9.45742435709799e+25*cos(theta)**19 + 1.08247628183652e+25*cos(theta)**17 - 9.56574232162224e+23*cos(theta)**15 + 6.35698065677427e+22*cos(theta)**13 - 3.06644707005809e+21*cos(theta)**11 + 1.0221490233527e+20*cos(theta)**9 - 2.19162387377588e+18*cos(theta)**7 + 2.70094491486465e+16*cos(theta)**5 - 156576516803748.0*cos(theta)**3 + 269649569696.465*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl59_m7(theta, phi):
    return 1.67521536568042e-12*(1.0 - cos(theta)**2)**3.5*(7.26480404353647e+28*cos(theta)**52 - 8.23344458267467e+29*cos(theta)**50 + 4.38520417990281e+30*cos(theta)**48 - 1.45914758552518e+31*cos(theta)**46 + 3.40139133112289e+31*cos(theta)**44 - 5.90406642062799e+31*cos(theta)**42 + 7.91807038654315e+31*cos(theta)**40 - 8.40285020612743e+31*cos(theta)**38 + 7.16893652294609e+31*cos(theta)**36 - 4.96856986738838e+31*cos(theta)**34 + 2.81552292485342e+31*cos(theta)**32 - 1.30880915719521e+31*cos(theta)**30 + 4.994140205087e+30*cos(theta)**28 - 1.56144333955574e+30*cos(theta)**26 + 3.98327382539729e+29*cos(theta)**24 - 8.23508296486631e+28*cos(theta)**22 + 1.36659781960066e+28*cos(theta)**20 - 1.79691062784862e+27*cos(theta)**18 + 1.84020967912208e+26*cos(theta)**16 - 1.43486134824334e+25*cos(theta)**14 + 8.26407485380656e+23*cos(theta)**12 - 3.3730917770639e+22*cos(theta)**10 + 9.19934121017427e+20*cos(theta)**8 - 1.53413671164312e+19*cos(theta)**6 + 1.35047245743232e+17*cos(theta)**4 - 469729550411243.0*cos(theta)**2 + 269649569696.465)*cos(7*phi)

#@torch.jit.script
def Yl59_m8(theta, phi):
    return 2.83812536234122e-14*(1.0 - cos(theta)**2)**4*(3.77769810263896e+30*cos(theta)**51 - 4.11672229133733e+31*cos(theta)**49 + 2.10489800635335e+32*cos(theta)**47 - 6.71207889341584e+32*cos(theta)**45 + 1.49661218569407e+33*cos(theta)**43 - 2.47970789666376e+33*cos(theta)**41 + 3.16722815461726e+33*cos(theta)**39 - 3.19308307832842e+33*cos(theta)**37 + 2.58081714826059e+33*cos(theta)**35 - 1.68931375491205e+33*cos(theta)**33 + 9.00967335953093e+32*cos(theta)**31 - 3.92642747158565e+32*cos(theta)**29 + 1.39835925742436e+32*cos(theta)**27 - 4.05975268284492e+31*cos(theta)**25 + 9.5598571809535e+30*cos(theta)**23 - 1.81171825227059e+30*cos(theta)**21 + 2.73319563920132e+29*cos(theta)**19 - 3.23443913012751e+28*cos(theta)**17 + 2.94433548659533e+27*cos(theta)**15 - 2.00880588754067e+26*cos(theta)**13 + 9.91688982456787e+24*cos(theta)**11 - 3.3730917770639e+23*cos(theta)**9 + 7.35947296813942e+21*cos(theta)**7 - 9.20482026985871e+19*cos(theta)**5 + 5.40188982972929e+17*cos(theta)**3 - 939459100822486.0*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl59_m9(theta, phi):
    return 4.81938953512238e-16*(1.0 - cos(theta)**2)**4.5*(1.92662603234587e+32*cos(theta)**50 - 2.01719392275529e+33*cos(theta)**48 + 9.89302062986074e+33*cos(theta)**46 - 3.02043550203713e+34*cos(theta)**44 + 6.43543239848451e+34*cos(theta)**42 - 1.01668023763214e+35*cos(theta)**40 + 1.23521898030073e+35*cos(theta)**38 - 1.18144073898152e+35*cos(theta)**36 + 9.03286001891208e+34*cos(theta)**34 - 5.57473539120976e+34*cos(theta)**32 + 2.79299874145459e+34*cos(theta)**30 - 1.13866396675984e+34*cos(theta)**28 + 3.77556999504578e+33*cos(theta)**26 - 1.01493817071123e+33*cos(theta)**24 + 2.19876715161931e+32*cos(theta)**22 - 3.80460832976824e+31*cos(theta)**20 + 5.19307171448251e+30*cos(theta)**18 - 5.49854652121677e+29*cos(theta)**16 + 4.41650322989299e+28*cos(theta)**14 - 2.61144765380287e+27*cos(theta)**12 + 1.09085788070247e+26*cos(theta)**10 - 3.03578259935751e+24*cos(theta)**8 + 5.15163107769759e+22*cos(theta)**6 - 4.60241013492936e+20*cos(theta)**4 + 1.62056694891879e+18*cos(theta)**2 - 939459100822486.0)*cos(9*phi)

#@torch.jit.script
def Yl59_m10(theta, phi):
    return 8.20507363208659e-18*(1.0 - cos(theta)**2)**5*(9.63313016172936e+33*cos(theta)**49 - 9.68253082922541e+34*cos(theta)**47 + 4.55078948973594e+35*cos(theta)**45 - 1.32899162089634e+36*cos(theta)**43 + 2.7028816073635e+36*cos(theta)**41 - 4.06672095052856e+36*cos(theta)**39 + 4.69383212514278e+36*cos(theta)**37 - 4.25318666033346e+36*cos(theta)**35 + 3.07117240643011e+36*cos(theta)**33 - 1.78391532518712e+36*cos(theta)**31 + 8.37899622436377e+35*cos(theta)**29 - 3.18825910692754e+35*cos(theta)**27 + 9.81648198711902e+34*cos(theta)**25 - 2.43585160970695e+34*cos(theta)**23 + 4.83728773356247e+33*cos(theta)**21 - 7.60921665953647e+32*cos(theta)**19 + 9.34752908606851e+31*cos(theta)**17 - 8.79767443394683e+30*cos(theta)**15 + 6.18310452185018e+29*cos(theta)**13 - 3.13373718456345e+28*cos(theta)**11 + 1.09085788070247e+27*cos(theta)**9 - 2.42862607948601e+25*cos(theta)**7 + 3.09097864661856e+23*cos(theta)**5 - 1.84096405397174e+21*cos(theta)**3 + 3.24113389783758e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl59_m11(theta, phi):
    return 1.40099124953788e-19*(1.0 - cos(theta)**2)**5.5*(4.72023377924739e+35*cos(theta)**48 - 4.55078948973594e+36*cos(theta)**46 + 2.04785527038117e+37*cos(theta)**44 - 5.71466396985425e+37*cos(theta)**42 + 1.10818145901903e+38*cos(theta)**40 - 1.58602117070614e+38*cos(theta)**38 + 1.73671788630283e+38*cos(theta)**36 - 1.48861533111671e+38*cos(theta)**34 + 1.01348689412194e+38*cos(theta)**32 - 5.53013750808009e+37*cos(theta)**30 + 2.42990890506549e+37*cos(theta)**28 - 8.60829958870437e+36*cos(theta)**26 + 2.45412049677975e+36*cos(theta)**24 - 5.60245870232599e+35*cos(theta)**22 + 1.01583042404812e+35*cos(theta)**20 - 1.44575116531193e+34*cos(theta)**18 + 1.58907994463165e+33*cos(theta)**16 - 1.31965116509203e+32*cos(theta)**14 + 8.03803587840524e+30*cos(theta)**12 - 3.44711090301979e+29*cos(theta)**10 + 9.81772092632219e+27*cos(theta)**8 - 1.70003825564021e+26*cos(theta)**6 + 1.54548932330928e+24*cos(theta)**4 - 5.52289216191523e+21*cos(theta)**2 + 3.24113389783758e+18)*cos(11*phi)

#@torch.jit.script
def Yl59_m12(theta, phi):
    return 2.3998584668763e-21*(1.0 - cos(theta)**2)**6*(2.26571221403875e+37*cos(theta)**47 - 2.09336316527853e+38*cos(theta)**45 + 9.01056318967716e+38*cos(theta)**43 - 2.40015886733878e+39*cos(theta)**41 + 4.43272583607613e+39*cos(theta)**39 - 6.02688044868333e+39*cos(theta)**37 + 6.25218439069018e+39*cos(theta)**35 - 5.06129212579682e+39*cos(theta)**33 + 3.24315806119019e+39*cos(theta)**31 - 1.65904125242403e+39*cos(theta)**29 + 6.80374493418338e+38*cos(theta)**27 - 2.23815789306314e+38*cos(theta)**25 + 5.88988919227141e+37*cos(theta)**23 - 1.23254091451172e+37*cos(theta)**21 + 2.03166084809624e+36*cos(theta)**19 - 2.60235209756147e+35*cos(theta)**17 + 2.54252791141063e+34*cos(theta)**15 - 1.84751163112884e+33*cos(theta)**13 + 9.64564305408629e+31*cos(theta)**11 - 3.44711090301979e+30*cos(theta)**9 + 7.85417674105775e+28*cos(theta)**7 - 1.02002295338412e+27*cos(theta)**5 + 6.18195729323711e+24*cos(theta)**3 - 1.10457843238305e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl59_m13(theta, phi):
    return 4.12544168458379e-23*(1.0 - cos(theta)**2)**6.5*(1.06488474059821e+39*cos(theta)**46 - 9.4201342437534e+39*cos(theta)**44 + 3.87454217156118e+40*cos(theta)**42 - 9.84065135608902e+40*cos(theta)**40 + 1.72876307606969e+41*cos(theta)**38 - 2.22994576601283e+41*cos(theta)**36 + 2.18826453674156e+41*cos(theta)**34 - 1.67022640151295e+41*cos(theta)**32 + 1.00537899896896e+41*cos(theta)**30 - 4.81121963202967e+40*cos(theta)**28 + 1.83701113222951e+40*cos(theta)**26 - 5.59539473265784e+39*cos(theta)**24 + 1.35467451422242e+39*cos(theta)**22 - 2.58833592047461e+38*cos(theta)**20 + 3.86015561138285e+37*cos(theta)**18 - 4.4239985658545e+36*cos(theta)**16 + 3.81379186711595e+35*cos(theta)**14 - 2.40176512046749e+34*cos(theta)**12 + 1.06102073594949e+33*cos(theta)**10 - 3.10239981271781e+31*cos(theta)**8 + 5.49792371874043e+29*cos(theta)**6 - 5.10011476692062e+27*cos(theta)**4 + 1.85458718797113e+25*cos(theta)**2 - 1.10457843238305e+22)*cos(13*phi)

#@torch.jit.script
def Yl59_m14(theta, phi):
    return 7.11918217862839e-25*(1.0 - cos(theta)**2)**7*(4.89846980675177e+40*cos(theta)**45 - 4.1448590672515e+41*cos(theta)**43 + 1.6273077120557e+42*cos(theta)**41 - 3.93626054243561e+42*cos(theta)**39 + 6.56929968906483e+42*cos(theta)**37 - 8.0278047576462e+42*cos(theta)**35 + 7.44009942492132e+42*cos(theta)**33 - 5.34472448484144e+42*cos(theta)**31 + 3.01613699690688e+42*cos(theta)**29 - 1.34714149696831e+42*cos(theta)**27 + 4.77622894379673e+41*cos(theta)**25 - 1.34289473583788e+41*cos(theta)**23 + 2.98028393128933e+40*cos(theta)**21 - 5.17667184094921e+39*cos(theta)**19 + 6.94828010048913e+38*cos(theta)**17 - 7.07839770536721e+37*cos(theta)**15 + 5.33930861396233e+36*cos(theta)**13 - 2.88211814456098e+35*cos(theta)**11 + 1.06102073594949e+34*cos(theta)**9 - 2.48191985017425e+32*cos(theta)**7 + 3.29875423124426e+30*cos(theta)**5 - 2.04004590676825e+28*cos(theta)**3 + 3.70917437594227e+25*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl59_m15(theta, phi):
    return 1.23369552622453e-26*(1.0 - cos(theta)**2)**7.5*(2.2043114130383e+42*cos(theta)**44 - 1.78228939891814e+43*cos(theta)**42 + 6.67196161942835e+43*cos(theta)**40 - 1.53514161154989e+44*cos(theta)**38 + 2.43064088495399e+44*cos(theta)**36 - 2.80973166517617e+44*cos(theta)**34 + 2.45523281022403e+44*cos(theta)**32 - 1.65686459030085e+44*cos(theta)**30 + 8.74679729102995e+43*cos(theta)**28 - 3.63728204181443e+43*cos(theta)**26 + 1.19405723594918e+43*cos(theta)**24 - 3.08865789242713e+42*cos(theta)**22 + 6.2585962557076e+41*cos(theta)**20 - 9.83567649780351e+40*cos(theta)**18 + 1.18120761708315e+40*cos(theta)**16 - 1.06175965580508e+39*cos(theta)**14 + 6.94110119815103e+37*cos(theta)**12 - 3.17032995901708e+36*cos(theta)**10 + 9.54918662354542e+34*cos(theta)**8 - 1.73734389512197e+33*cos(theta)**6 + 1.64937711562213e+31*cos(theta)**4 - 6.12013772030474e+28*cos(theta)**2 + 3.70917437594227e+25)*cos(15*phi)

#@torch.jit.script
def Yl59_m16(theta, phi):
    return 2.14758825368198e-28*(1.0 - cos(theta)**2)**8*(9.6989702173685e+43*cos(theta)**43 - 7.4856154754562e+44*cos(theta)**41 + 2.66878464777134e+45*cos(theta)**39 - 5.83353812388957e+45*cos(theta)**37 + 8.75030718583435e+45*cos(theta)**35 - 9.55308766159897e+45*cos(theta)**33 + 7.85674499271691e+45*cos(theta)**31 - 4.97059377090254e+45*cos(theta)**29 + 2.44910324148839e+45*cos(theta)**27 - 9.45693330871753e+44*cos(theta)**25 + 2.86573736627804e+44*cos(theta)**23 - 6.79504736333968e+43*cos(theta)**21 + 1.25171925114152e+43*cos(theta)**19 - 1.77042176960463e+42*cos(theta)**17 + 1.88993218733304e+41*cos(theta)**15 - 1.48646351812711e+40*cos(theta)**13 + 8.32932143778124e+38*cos(theta)**11 - 3.17032995901708e+37*cos(theta)**9 + 7.63934929883634e+35*cos(theta)**7 - 1.04240633707318e+34*cos(theta)**5 + 6.59750846248851e+31*cos(theta)**3 - 1.22402754406095e+29*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl59_m17(theta, phi):
    return 3.75673011225594e-30*(1.0 - cos(theta)**2)**8.5*(4.17055719346846e+45*cos(theta)**42 - 3.06910234493704e+46*cos(theta)**40 + 1.04082601263082e+47*cos(theta)**38 - 2.15840910583914e+47*cos(theta)**36 + 3.06260751504202e+47*cos(theta)**34 - 3.15251892832766e+47*cos(theta)**32 + 2.43559094774224e+47*cos(theta)**30 - 1.44147219356174e+47*cos(theta)**28 + 6.61257875201864e+46*cos(theta)**26 - 2.36423332717938e+46*cos(theta)**24 + 6.59119594243949e+45*cos(theta)**22 - 1.42695994630133e+45*cos(theta)**20 + 2.37826657716889e+44*cos(theta)**18 - 3.00971700832787e+43*cos(theta)**16 + 2.83489828099957e+42*cos(theta)**14 - 1.93240257356525e+41*cos(theta)**12 + 9.16225358155936e+39*cos(theta)**10 - 2.85329696311537e+38*cos(theta)**8 + 5.34754450918544e+36*cos(theta)**6 - 5.21203168536592e+34*cos(theta)**4 + 1.97925253874655e+32*cos(theta)**2 - 1.22402754406095e+29)*cos(17*phi)

#@torch.jit.script
def Yl59_m18(theta, phi):
    return 6.60602158177914e-32*(1.0 - cos(theta)**2)**9*(1.75163402125675e+47*cos(theta)**41 - 1.22764093797482e+48*cos(theta)**39 + 3.95513884799713e+48*cos(theta)**37 - 7.77027278102091e+48*cos(theta)**35 + 1.04128655511429e+49*cos(theta)**33 - 1.00880605706485e+49*cos(theta)**31 + 7.30677284322673e+48*cos(theta)**29 - 4.03612214197286e+48*cos(theta)**27 + 1.71927047552485e+48*cos(theta)**25 - 5.67415998523052e+47*cos(theta)**23 + 1.45006310733669e+47*cos(theta)**21 - 2.85391989260267e+46*cos(theta)**19 + 4.280879838904e+45*cos(theta)**17 - 4.8155472133246e+44*cos(theta)**15 + 3.96885759339939e+43*cos(theta)**13 - 2.3188830882783e+42*cos(theta)**11 + 9.16225358155936e+40*cos(theta)**9 - 2.2826375704923e+39*cos(theta)**7 + 3.20852670551126e+37*cos(theta)**5 - 2.08481267414637e+35*cos(theta)**3 + 3.95850507749311e+32*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl59_m19(theta, phi):
    return 1.16815577002e-33*(1.0 - cos(theta)**2)**9.5*(7.18169948715268e+48*cos(theta)**40 - 4.78779965810179e+49*cos(theta)**38 + 1.46340137375894e+50*cos(theta)**36 - 2.71959547335732e+50*cos(theta)**34 + 3.43624563187715e+50*cos(theta)**32 - 3.12729877690104e+50*cos(theta)**30 + 2.11896412453575e+50*cos(theta)**28 - 1.08975297833267e+50*cos(theta)**26 + 4.29817618881212e+49*cos(theta)**24 - 1.30505679660302e+49*cos(theta)**22 + 3.04513252540704e+48*cos(theta)**20 - 5.42244779594507e+47*cos(theta)**18 + 7.2774957261368e+46*cos(theta)**16 - 7.2233208199869e+45*cos(theta)**14 + 5.15951487141921e+44*cos(theta)**12 - 2.55077139710613e+43*cos(theta)**10 + 8.24602822340343e+41*cos(theta)**8 - 1.59784629934461e+40*cos(theta)**6 + 1.60426335275563e+38*cos(theta)**4 - 6.25443802243911e+35*cos(theta)**2 + 3.95850507749311e+32)*cos(19*phi)

#@torch.jit.script
def Yl59_m20(theta, phi):
    return 2.07805585796733e-35*(1.0 - cos(theta)**2)**10*(2.87267979486107e+50*cos(theta)**39 - 1.81936387007868e+51*cos(theta)**37 + 5.26824494553217e+51*cos(theta)**35 - 9.24662460941488e+51*cos(theta)**33 + 1.09959860220069e+52*cos(theta)**31 - 9.38189633070312e+51*cos(theta)**29 + 5.9330995487001e+51*cos(theta)**27 - 2.83335774366495e+51*cos(theta)**25 + 1.03156228531491e+51*cos(theta)**23 - 2.87112495252664e+50*cos(theta)**21 + 6.09026505081409e+49*cos(theta)**19 - 9.76040603270112e+48*cos(theta)**17 + 1.16439931618189e+48*cos(theta)**15 - 1.01126491479817e+47*cos(theta)**13 + 6.19141784570305e+45*cos(theta)**11 - 2.55077139710613e+44*cos(theta)**9 + 6.59682257872274e+42*cos(theta)**7 - 9.58707779606765e+40*cos(theta)**5 + 6.41705341102253e+38*cos(theta)**3 - 1.25088760448782e+36*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl59_m21(theta, phi):
    return 3.72031677243794e-37*(1.0 - cos(theta)**2)**10.5*(1.12034511999582e+52*cos(theta)**38 - 6.73164631929111e+52*cos(theta)**36 + 1.84388573093626e+53*cos(theta)**34 - 3.05138612110691e+53*cos(theta)**32 + 3.40875566682213e+53*cos(theta)**30 - 2.7207499359039e+53*cos(theta)**28 + 1.60193687814903e+53*cos(theta)**26 - 7.08339435916237e+52*cos(theta)**24 + 2.37259325622429e+52*cos(theta)**22 - 6.02936240030595e+51*cos(theta)**20 + 1.15715035965468e+51*cos(theta)**18 - 1.65926902555919e+50*cos(theta)**16 + 1.74659897427283e+49*cos(theta)**14 - 1.31464438923762e+48*cos(theta)**12 + 6.81055963027336e+46*cos(theta)**10 - 2.29569425739551e+45*cos(theta)**8 + 4.61777580510592e+43*cos(theta)**6 - 4.79353889803383e+41*cos(theta)**4 + 1.92511602330676e+39*cos(theta)**2 - 1.25088760448782e+36)*cos(21*phi)

#@torch.jit.script
def Yl59_m22(theta, phi):
    return 6.70572304312772e-39*(1.0 - cos(theta)**2)**11*(4.25731145598411e+53*cos(theta)**37 - 2.4233926749448e+54*cos(theta)**35 + 6.26921148518329e+54*cos(theta)**33 - 9.76443558754211e+54*cos(theta)**31 + 1.02262670004664e+55*cos(theta)**29 - 7.61809982053093e+54*cos(theta)**27 + 4.16503588318747e+54*cos(theta)**25 - 1.70001464619897e+54*cos(theta)**23 + 5.21970516369343e+53*cos(theta)**21 - 1.20587248006119e+53*cos(theta)**19 + 2.08287064737842e+52*cos(theta)**17 - 2.6548304408947e+51*cos(theta)**15 + 2.44523856398196e+50*cos(theta)**13 - 1.57757326708514e+49*cos(theta)**11 + 6.81055963027336e+47*cos(theta)**9 - 1.83655540591641e+46*cos(theta)**7 + 2.77066548306355e+44*cos(theta)**5 - 1.91741555921353e+42*cos(theta)**3 + 3.85023204661352e+39*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl59_m23(theta, phi):
    return 1.21741268938137e-40*(1.0 - cos(theta)**2)**11.5*(1.57520523871412e+55*cos(theta)**36 - 8.4818743623068e+55*cos(theta)**34 + 2.06883979011048e+56*cos(theta)**32 - 3.02697503213805e+56*cos(theta)**30 + 2.96561743013526e+56*cos(theta)**28 - 2.05688695154335e+56*cos(theta)**26 + 1.04125897079687e+56*cos(theta)**24 - 3.91003368625763e+55*cos(theta)**22 + 1.09613808437562e+55*cos(theta)**20 - 2.29115771211626e+54*cos(theta)**18 + 3.54088010054331e+53*cos(theta)**16 - 3.98224566134206e+52*cos(theta)**14 + 3.17881013317655e+51*cos(theta)**12 - 1.73533059379365e+50*cos(theta)**10 + 6.12950366724602e+48*cos(theta)**8 - 1.28558878414149e+47*cos(theta)**6 + 1.38533274153178e+45*cos(theta)**4 - 5.75224667764059e+42*cos(theta)**2 + 3.85023204661352e+39)*cos(23*phi)

#@torch.jit.script
def Yl59_m24(theta, phi):
    return 2.22714004920008e-42*(1.0 - cos(theta)**2)**12*(5.67073885937083e+56*cos(theta)**35 - 2.88383728318431e+57*cos(theta)**33 + 6.62028732835355e+57*cos(theta)**31 - 9.08092509641416e+57*cos(theta)**29 + 8.30372880437872e+57*cos(theta)**27 - 5.34790607401271e+57*cos(theta)**25 + 2.49902152991248e+57*cos(theta)**23 - 8.60207410976678e+56*cos(theta)**21 + 2.19227616875124e+56*cos(theta)**19 - 4.12408388180927e+55*cos(theta)**17 + 5.6654081608693e+54*cos(theta)**15 - 5.57514392587888e+53*cos(theta)**13 + 3.81457215981186e+52*cos(theta)**11 - 1.73533059379365e+51*cos(theta)**9 + 4.90360293379682e+49*cos(theta)**7 - 7.71353270484893e+47*cos(theta)**5 + 5.5413309661271e+45*cos(theta)**3 - 1.15044933552812e+43*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl59_m25(theta, phi):
    return 4.10746491439213e-44*(1.0 - cos(theta)**2)**12.5*(1.98475860077979e+58*cos(theta)**34 - 9.51666303450823e+58*cos(theta)**32 + 2.0522890717896e+59*cos(theta)**30 - 2.63346827796011e+59*cos(theta)**28 + 2.24200677718225e+59*cos(theta)**26 - 1.33697651850318e+59*cos(theta)**24 + 5.74774951879871e+58*cos(theta)**22 - 1.80643556305102e+58*cos(theta)**20 + 4.16532472062736e+57*cos(theta)**18 - 7.01094259907576e+56*cos(theta)**16 + 8.49811224130395e+55*cos(theta)**14 - 7.24768710364254e+54*cos(theta)**12 + 4.19602937579305e+53*cos(theta)**10 - 1.56179753441429e+52*cos(theta)**8 + 3.43252205365777e+50*cos(theta)**6 - 3.85676635242446e+48*cos(theta)**4 + 1.66239928983813e+46*cos(theta)**2 - 1.15044933552812e+43)*cos(25*phi)

#@torch.jit.script
def Yl59_m26(theta, phi):
    return 7.64055561100451e-46*(1.0 - cos(theta)**2)**13*(6.74817924265129e+59*cos(theta)**33 - 3.04533217104263e+60*cos(theta)**31 + 6.1568672153688e+60*cos(theta)**29 - 7.3737111782883e+60*cos(theta)**27 + 5.82921762067386e+60*cos(theta)**25 - 3.20874364440763e+60*cos(theta)**23 + 1.26450489413572e+60*cos(theta)**21 - 3.61287112610205e+59*cos(theta)**19 + 7.49758449712925e+58*cos(theta)**17 - 1.12175081585212e+58*cos(theta)**15 + 1.18973571378255e+57*cos(theta)**13 - 8.69722452437105e+55*cos(theta)**11 + 4.19602937579305e+54*cos(theta)**9 - 1.24943802753143e+53*cos(theta)**7 + 2.05951323219466e+51*cos(theta)**5 - 1.54270654096979e+49*cos(theta)**3 + 3.32479857967626e+46*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl59_m27(theta, phi):
    return 1.43422981181384e-47*(1.0 - cos(theta)**2)**13.5*(2.22689915007493e+61*cos(theta)**32 - 9.44052973023216e+61*cos(theta)**30 + 1.78549149245695e+62*cos(theta)**28 - 1.99090201813784e+62*cos(theta)**26 + 1.45730440516846e+62*cos(theta)**24 - 7.38011038213755e+61*cos(theta)**22 + 2.655460277685e+61*cos(theta)**20 - 6.86445513959389e+60*cos(theta)**18 + 1.27458936451197e+60*cos(theta)**16 - 1.68262622377818e+59*cos(theta)**14 + 1.54665642791732e+58*cos(theta)**12 - 9.56694697680815e+56*cos(theta)**10 + 3.77642643821374e+55*cos(theta)**8 - 8.74606619272001e+53*cos(theta)**6 + 1.02975661609733e+52*cos(theta)**4 - 4.62811962290936e+49*cos(theta)**2 + 3.32479857967626e+46)*cos(27*phi)

#@torch.jit.script
def Yl59_m28(theta, phi):
    return 2.71821703594654e-49*(1.0 - cos(theta)**2)**14*(7.12607728023976e+62*cos(theta)**31 - 2.83215891906965e+63*cos(theta)**29 + 4.99937617887947e+63*cos(theta)**27 - 5.17634524715839e+63*cos(theta)**25 + 3.49753057240432e+63*cos(theta)**23 - 1.62362428407026e+63*cos(theta)**21 + 5.31092055537001e+62*cos(theta)**19 - 1.2356019251269e+62*cos(theta)**17 + 2.03934298321916e+61*cos(theta)**15 - 2.35567671328945e+60*cos(theta)**13 + 1.85598771350078e+59*cos(theta)**11 - 9.56694697680815e+57*cos(theta)**9 + 3.021141150571e+56*cos(theta)**7 - 5.247639715632e+54*cos(theta)**5 + 4.11902646438933e+52*cos(theta)**3 - 9.25623924581871e+49*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl59_m29(theta, phi):
    return 5.20429549014948e-51*(1.0 - cos(theta)**2)**14.5*(2.20908395687433e+64*cos(theta)**30 - 8.21326086530198e+64*cos(theta)**28 + 1.34983156829746e+65*cos(theta)**26 - 1.2940863117896e+65*cos(theta)**24 + 8.04432031652993e+64*cos(theta)**22 - 3.40961099654755e+64*cos(theta)**20 + 1.0090749055203e+64*cos(theta)**18 - 2.10052327271573e+63*cos(theta)**16 + 3.05901447482873e+62*cos(theta)**14 - 3.06237972727629e+61*cos(theta)**12 + 2.04158648485086e+60*cos(theta)**10 - 8.61025227912734e+58*cos(theta)**8 + 2.1147988053997e+57*cos(theta)**6 - 2.623819857816e+55*cos(theta)**4 + 1.2357079393168e+53*cos(theta)**2 - 9.25623924581871e+49)*cos(29*phi)

#@torch.jit.script
def Yl59_m30(theta, phi):
    return 1.00717819832226e-52*(1.0 - cos(theta)**2)**15*(6.62725187062298e+65*cos(theta)**29 - 2.29971304228456e+66*cos(theta)**27 + 3.50956207757339e+66*cos(theta)**25 - 3.10580714829503e+66*cos(theta)**23 + 1.76975046963658e+66*cos(theta)**21 - 6.81922199309509e+65*cos(theta)**19 + 1.81633482993654e+65*cos(theta)**17 - 3.36083723634517e+64*cos(theta)**15 + 4.28262026476023e+63*cos(theta)**13 - 3.67485567273155e+62*cos(theta)**11 + 2.04158648485086e+61*cos(theta)**9 - 6.88820182330187e+59*cos(theta)**7 + 1.26887928323982e+58*cos(theta)**5 - 1.0495279431264e+56*cos(theta)**3 + 2.4714158786336e+53*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl59_m31(theta, phi):
    return 1.97145134236406e-54*(1.0 - cos(theta)**2)**15.5*(1.92190304248066e+67*cos(theta)**28 - 6.2092252141683e+67*cos(theta)**26 + 8.77390519393347e+67*cos(theta)**24 - 7.14335644107857e+67*cos(theta)**22 + 3.71647598623683e+67*cos(theta)**20 - 1.29565217868807e+67*cos(theta)**18 + 3.08776921089212e+66*cos(theta)**16 - 5.04125585451775e+65*cos(theta)**14 + 5.5674063441883e+64*cos(theta)**12 - 4.0423412400047e+63*cos(theta)**10 + 1.83742783636577e+62*cos(theta)**8 - 4.82174127631131e+60*cos(theta)**6 + 6.34439641619909e+58*cos(theta)**4 - 3.1485838293792e+56*cos(theta)**2 + 2.4714158786336e+53)*cos(31*phi)

#@torch.jit.script
def Yl59_m32(theta, phi):
    return 3.90558730877798e-56*(1.0 - cos(theta)**2)**16*(5.38132851894586e+68*cos(theta)**27 - 1.61439855568376e+69*cos(theta)**25 + 2.10573724654403e+69*cos(theta)**23 - 1.57153841703729e+69*cos(theta)**21 + 7.43295197247365e+68*cos(theta)**19 - 2.33217392163852e+68*cos(theta)**17 + 4.9404307374274e+67*cos(theta)**15 - 7.05775819632485e+66*cos(theta)**13 + 6.68088761302595e+65*cos(theta)**11 - 4.0423412400047e+64*cos(theta)**9 + 1.46994226909262e+63*cos(theta)**7 - 2.89304476578679e+61*cos(theta)**5 + 2.53775856647964e+59*cos(theta)**3 - 6.2971676587584e+56*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl59_m33(theta, phi):
    return 7.83629099946985e-58*(1.0 - cos(theta)**2)**16.5*(1.45295870011538e+70*cos(theta)**26 - 4.03599638920939e+70*cos(theta)**24 + 4.84319566705127e+70*cos(theta)**22 - 3.3002306757783e+70*cos(theta)**20 + 1.41226087476999e+70*cos(theta)**18 - 3.96469566678549e+69*cos(theta)**16 + 7.4106461061411e+68*cos(theta)**14 - 9.17508565522231e+67*cos(theta)**12 + 7.34897637432855e+66*cos(theta)**10 - 3.63810711600423e+65*cos(theta)**8 + 1.02895958836483e+64*cos(theta)**6 - 1.44652238289339e+62*cos(theta)**4 + 7.61327569943891e+59*cos(theta)**2 - 6.2971676587584e+56)*cos(33*phi)

#@torch.jit.script
def Yl59_m34(theta, phi):
    return 1.59361132285127e-59*(1.0 - cos(theta)**2)**17*(3.77769262029999e+71*cos(theta)**25 - 9.68639133410255e+71*cos(theta)**23 + 1.06550304675128e+72*cos(theta)**21 - 6.6004613515566e+71*cos(theta)**19 + 2.54206957458599e+71*cos(theta)**17 - 6.34351306685678e+70*cos(theta)**15 + 1.03749045485975e+70*cos(theta)**13 - 1.10101027862668e+69*cos(theta)**11 + 7.34897637432855e+67*cos(theta)**9 - 2.91048569280339e+66*cos(theta)**7 + 6.173757530189e+64*cos(theta)**5 - 5.78608953157357e+62*cos(theta)**3 + 1.52265513988778e+60*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl59_m35(theta, phi):
    return 3.28736915333476e-61*(1.0 - cos(theta)**2)**17.5*(9.44423155074998e+72*cos(theta)**24 - 2.22787000684359e+73*cos(theta)**22 + 2.23755639817769e+73*cos(theta)**20 - 1.25408765679575e+73*cos(theta)**18 + 4.32151827679618e+72*cos(theta)**16 - 9.51526960028517e+71*cos(theta)**14 + 1.34873759131768e+71*cos(theta)**12 - 1.21111130648935e+70*cos(theta)**10 + 6.6140787368957e+68*cos(theta)**8 - 2.03733998496237e+67*cos(theta)**6 + 3.0868787650945e+65*cos(theta)**4 - 1.73582685947207e+63*cos(theta)**2 + 1.52265513988778e+60)*cos(35*phi)

#@torch.jit.script
def Yl59_m36(theta, phi):
    return 6.88463708935914e-63*(1.0 - cos(theta)**2)**18*(2.26661557218e+74*cos(theta)**23 - 4.90131401505589e+74*cos(theta)**21 + 4.47511279635538e+74*cos(theta)**19 - 2.25735778223236e+74*cos(theta)**17 + 6.91442924287389e+73*cos(theta)**15 - 1.33213774403992e+73*cos(theta)**13 + 1.61848510958122e+72*cos(theta)**11 - 1.21111130648935e+71*cos(theta)**9 + 5.29126298951656e+69*cos(theta)**7 - 1.22240399097742e+68*cos(theta)**5 + 1.2347515060378e+66*cos(theta)**3 - 3.47165371894414e+63*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl59_m37(theta, phi):
    return 1.46514807105522e-64*(1.0 - cos(theta)**2)**18.5*(5.21321581601399e+75*cos(theta)**22 - 1.02927594316174e+76*cos(theta)**20 + 8.50271431307522e+75*cos(theta)**18 - 3.83750822979501e+75*cos(theta)**16 + 1.03716438643108e+75*cos(theta)**14 - 1.7317790672519e+74*cos(theta)**12 + 1.78033362053934e+73*cos(theta)**10 - 1.09000017584041e+72*cos(theta)**8 + 3.70388409266159e+70*cos(theta)**6 - 6.11201995488711e+68*cos(theta)**4 + 3.7042545181134e+66*cos(theta)**2 - 3.47165371894414e+63)*cos(37*phi)

#@torch.jit.script
def Yl59_m38(theta, phi):
    return 3.17164309407581e-66*(1.0 - cos(theta)**2)**19*(1.14690747952308e+77*cos(theta)**21 - 2.05855188632347e+77*cos(theta)**19 + 1.53048857635354e+77*cos(theta)**17 - 6.14001316767201e+76*cos(theta)**15 + 1.45203014100352e+76*cos(theta)**13 - 2.07813488070228e+75*cos(theta)**11 + 1.78033362053934e+74*cos(theta)**9 - 8.72000140672328e+72*cos(theta)**7 + 2.22233045559695e+71*cos(theta)**5 - 2.44480798195484e+69*cos(theta)**3 + 7.4085090362268e+66*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl59_m39(theta, phi):
    return 6.99135934714332e-68*(1.0 - cos(theta)**2)**19.5*(2.40850570699846e+78*cos(theta)**20 - 3.9112485840146e+78*cos(theta)**18 + 2.60183057980102e+78*cos(theta)**16 - 9.21001975150802e+77*cos(theta)**14 + 1.88763918330457e+77*cos(theta)**12 - 2.28594836877251e+76*cos(theta)**10 + 1.6023002584854e+75*cos(theta)**8 - 6.1040009847063e+73*cos(theta)**6 + 1.11116522779848e+72*cos(theta)**4 - 7.33442394586453e+69*cos(theta)**2 + 7.4085090362268e+66)*cos(39*phi)

#@torch.jit.script
def Yl59_m40(theta, phi):
    return 1.57119117009171e-69*(1.0 - cos(theta)**2)**20*(4.81701141399693e+79*cos(theta)**19 - 7.04024745122628e+79*cos(theta)**17 + 4.16292892768163e+79*cos(theta)**15 - 1.28940276521112e+79*cos(theta)**13 + 2.26516701996549e+78*cos(theta)**11 - 2.28594836877251e+77*cos(theta)**9 + 1.28184020678832e+76*cos(theta)**7 - 3.66240059082378e+74*cos(theta)**5 + 4.44466091119391e+72*cos(theta)**3 - 1.46688478917291e+70*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl59_m41(theta, phi):
    return 3.60455975337536e-71*(1.0 - cos(theta)**2)**20.5*(9.15232168659416e+80*cos(theta)**18 - 1.19684206670847e+81*cos(theta)**16 + 6.24439339152244e+80*cos(theta)**14 - 1.67622359477446e+80*cos(theta)**12 + 2.49168372196203e+79*cos(theta)**10 - 2.05735353189526e+78*cos(theta)**8 + 8.97288144751826e+76*cos(theta)**6 - 1.83120029541189e+75*cos(theta)**4 + 1.33339827335817e+73*cos(theta)**2 - 1.46688478917291e+70)*cos(41*phi)

#@torch.jit.script
def Yl59_m42(theta, phi):
    return 8.45386464102844e-73*(1.0 - cos(theta)**2)**21*(1.64741790358695e+82*cos(theta)**17 - 1.91494730673355e+82*cos(theta)**15 + 8.74215074813141e+81*cos(theta)**13 - 2.01146831372935e+81*cos(theta)**11 + 2.49168372196203e+80*cos(theta)**9 - 1.64588282551621e+79*cos(theta)**7 + 5.38372886851096e+77*cos(theta)**5 - 7.32480118164756e+75*cos(theta)**3 + 2.66679654671634e+73*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl59_m43(theta, phi):
    return 2.03016222794868e-74*(1.0 - cos(theta)**2)**21.5*(2.80061043609781e+83*cos(theta)**16 - 2.87242096010032e+83*cos(theta)**14 + 1.13647959725708e+83*cos(theta)**12 - 2.21261514510229e+82*cos(theta)**10 + 2.24251534976583e+81*cos(theta)**8 - 1.15211797786134e+80*cos(theta)**6 + 2.69186443425548e+78*cos(theta)**4 - 2.19744035449427e+76*cos(theta)**2 + 2.66679654671634e+73)*cos(43*phi)

#@torch.jit.script
def Yl59_m44(theta, phi):
    return 5.00094570655272e-76*(1.0 - cos(theta)**2)**22*(4.4809766977565e+84*cos(theta)**15 - 4.02138934414045e+84*cos(theta)**13 + 1.3637755167085e+84*cos(theta)**11 - 2.21261514510229e+83*cos(theta)**9 + 1.79401227981266e+82*cos(theta)**7 - 6.91270786716807e+80*cos(theta)**5 + 1.07674577370219e+79*cos(theta)**3 - 4.39488070898854e+76*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl59_m45(theta, phi):
    return 1.26616364741849e-77*(1.0 - cos(theta)**2)**22.5*(6.72146504663475e+85*cos(theta)**14 - 5.22780614738258e+85*cos(theta)**12 + 1.50015306837935e+85*cos(theta)**10 - 1.99135363059206e+84*cos(theta)**8 + 1.25580859586887e+83*cos(theta)**6 - 3.45635393358403e+81*cos(theta)**4 + 3.23023732110657e+79*cos(theta)**2 - 4.39488070898854e+76)*cos(45*phi)

#@torch.jit.script
def Yl59_m46(theta, phi):
    return 3.30241138659108e-79*(1.0 - cos(theta)**2)**23*(9.41005106528865e+86*cos(theta)**13 - 6.2733673768591e+86*cos(theta)**11 + 1.50015306837935e+86*cos(theta)**9 - 1.59308290447365e+85*cos(theta)**7 + 7.53485157521319e+83*cos(theta)**5 - 1.38254157343361e+82*cos(theta)**3 + 6.46047464221315e+79*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl59_m47(theta, phi):
    return 8.89624150767567e-81*(1.0 - cos(theta)**2)**23.5*(1.22330663848752e+88*cos(theta)**12 - 6.90070411454501e+87*cos(theta)**10 + 1.35013776154142e+87*cos(theta)**8 - 1.11515803313155e+86*cos(theta)**6 + 3.7674257876066e+84*cos(theta)**4 - 4.14762472030084e+82*cos(theta)**2 + 6.46047464221315e+79)*cos(47*phi)

#@torch.jit.script
def Yl59_m48(theta, phi):
    return 2.48269890330301e-82*(1.0 - cos(theta)**2)**24*(1.46796796618503e+89*cos(theta)**11 - 6.90070411454501e+88*cos(theta)**9 + 1.08011020923313e+88*cos(theta)**7 - 6.69094819878932e+86*cos(theta)**5 + 1.50697031504264e+85*cos(theta)**3 - 8.29524944060168e+82*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl59_m49(theta, phi):
    return 7.20304009217948e-84*(1.0 - cos(theta)**2)**24.5*(1.61476476280353e+90*cos(theta)**10 - 6.21063370309051e+89*cos(theta)**8 + 7.56077146463193e+88*cos(theta)**6 - 3.34547409939466e+87*cos(theta)**4 + 4.52091094512792e+85*cos(theta)**2 - 8.29524944060168e+82)*cos(49*phi)

#@torch.jit.script
def Yl59_m50(theta, phi):
    return 2.18173793550562e-85*(1.0 - cos(theta)**2)**25*(1.61476476280353e+91*cos(theta)**9 - 4.96850696247241e+90*cos(theta)**7 + 4.53646287877916e+89*cos(theta)**5 - 1.33818963975786e+88*cos(theta)**3 + 9.04182189025583e+85*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl59_m51(theta, phi):
    return 6.9340183368084e-87*(1.0 - cos(theta)**2)**25.5*(1.45328828652318e+92*cos(theta)**8 - 3.47795487373069e+91*cos(theta)**6 + 2.26823143938958e+90*cos(theta)**4 - 4.01456891927359e+88*cos(theta)**2 + 9.04182189025583e+85)*cos(51*phi)

#@torch.jit.script
def Yl59_m52(theta, phi):
    return 2.32690419685702e-88*(1.0 - cos(theta)**2)**26*(1.16263062921854e+93*cos(theta)**7 - 2.08677292423841e+92*cos(theta)**5 + 9.07292575755831e+90*cos(theta)**3 - 8.02913783854718e+88*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl59_m53(theta, phi):
    return 8.3103721316322e-90*(1.0 - cos(theta)**2)**26.5*(8.13841440452981e+93*cos(theta)**6 - 1.04338646211921e+93*cos(theta)**4 + 2.72187772726749e+91*cos(theta)**2 - 8.02913783854718e+88)*cos(53*phi)

#@torch.jit.script
def Yl59_m54(theta, phi):
    return 3.19157918962223e-91*(1.0 - cos(theta)**2)**27*(4.88304864271788e+94*cos(theta)**5 - 4.17354584847682e+93*cos(theta)**3 + 5.44375545453499e+91*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl59_m55(theta, phi):
    return 1.33680541719571e-92*(1.0 - cos(theta)**2)**27.5*(2.44152432135894e+95*cos(theta)**4 - 1.25206375454305e+94*cos(theta)**2 + 5.44375545453499e+91)*cos(55*phi)

#@torch.jit.script
def Yl59_m56(theta, phi):
    return 6.2328873960835e-94*(1.0 - cos(theta)**2)**28*(9.76609728543577e+95*cos(theta)**3 - 2.50412750908609e+94*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl59_m57(theta, phi):
    return 3.34117835278681e-95*(1.0 - cos(theta)**2)**28.5*(2.92982918563073e+96*cos(theta)**2 - 2.50412750908609e+94)*cos(57*phi)

#@torch.jit.script
def Yl59_m58(theta, phi):
    return 12.7986459962836*(1.0 - cos(theta)**2)**29*cos(58*phi)*cos(theta)

#@torch.jit.script
def Yl59_m59(theta, phi):
    return 1.17821086476446*(1.0 - cos(theta)**2)**29.5*cos(59*phi)

#@torch.jit.script
def Yl60_m_minus_60(theta, phi):
    return 1.18310989157014*(1.0 - cos(theta)**2)**30*sin(60*phi)

#@torch.jit.script
def Yl60_m_minus_59(theta, phi):
    return 12.9603195124091*(1.0 - cos(theta)**2)**29.5*sin(59*phi)*cos(theta)

#@torch.jit.script
def Yl60_m_minus_58(theta, phi):
    return 2.86737786884351e-97*(1.0 - cos(theta)**2)**29*(3.48649673090057e+98*cos(theta)**2 - 2.92982918563073e+96)*sin(58*phi)

#@torch.jit.script
def Yl60_m_minus_57(theta, phi):
    return 5.39493926594886e-96*(1.0 - cos(theta)**2)**28.5*(1.16216557696686e+98*cos(theta)**3 - 2.92982918563073e+96*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl60_m_minus_56(theta, phi):
    return 1.16710380908356e-94*(1.0 - cos(theta)**2)**28*(2.90541394241714e+97*cos(theta)**4 - 1.46491459281536e+96*cos(theta)**2 + 6.26031877271524e+93)*sin(56*phi)

#@torch.jit.script
def Yl60_m_minus_55(theta, phi):
    return 2.81075818006968e-93*(1.0 - cos(theta)**2)**27.5*(5.81082788483428e+96*cos(theta)**5 - 4.88304864271788e+95*cos(theta)**3 + 6.26031877271524e+93*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl60_m_minus_54(theta, phi):
    return 7.38325772766451e-92*(1.0 - cos(theta)**2)**27*(9.68471314139047e+95*cos(theta)**6 - 1.22076216067947e+95*cos(theta)**4 + 3.13015938635762e+93*cos(theta)**2 - 9.07292575755831e+90)*sin(54*phi)

#@torch.jit.script
def Yl60_m_minus_53(theta, phi):
    return 2.08568863326116e-90*(1.0 - cos(theta)**2)**26.5*(1.38353044877007e+95*cos(theta)**7 - 2.44152432135894e+94*cos(theta)**5 + 1.04338646211921e+93*cos(theta)**3 - 9.07292575755831e+90*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl60_m_minus_52(theta, phi):
    return 6.2709550753637e-89*(1.0 - cos(theta)**2)**26*(1.72941306096258e+94*cos(theta)**8 - 4.0692072022649e+93*cos(theta)**6 + 2.60846615529801e+92*cos(theta)**4 - 4.53646287877916e+90*cos(theta)**2 + 1.0036422298184e+88)*sin(52*phi)

#@torch.jit.script
def Yl60_m_minus_51(theta, phi):
    return 1.99096651347248e-87*(1.0 - cos(theta)**2)**25.5*(1.9215700677362e+93*cos(theta)**9 - 5.81315314609272e+92*cos(theta)**7 + 5.21693231059603e+91*cos(theta)**5 - 1.51215429292639e+90*cos(theta)**3 + 1.0036422298184e+88*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl60_m_minus_50(theta, phi):
    return 6.63323593740138e-86*(1.0 - cos(theta)**2)**25*(1.9215700677362e+92*cos(theta)**10 - 7.2664414326159e+91*cos(theta)**8 + 8.69488718432672e+90*cos(theta)**6 - 3.78038573231596e+89*cos(theta)**4 + 5.01821114909199e+87*cos(theta)**2 - 9.04182189025583e+84)*sin(50*phi)

#@torch.jit.script
def Yl60_m_minus_49(theta, phi):
    return 2.30737472014175e-84*(1.0 - cos(theta)**2)**24.5*(1.74688187976019e+91*cos(theta)**11 - 8.07382381401766e+90*cos(theta)**9 + 1.2421267406181e+90*cos(theta)**7 - 7.56077146463193e+88*cos(theta)**5 + 1.67273704969733e+87*cos(theta)**3 - 9.04182189025583e+84*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl60_m_minus_48(theta, phi):
    return 8.34491662851533e-83*(1.0 - cos(theta)**2)**24*(1.45573489980015e+90*cos(theta)**12 - 8.07382381401766e+89*cos(theta)**10 + 1.55265842577263e+89*cos(theta)**8 - 1.26012857743865e+88*cos(theta)**6 + 4.18184262424332e+86*cos(theta)**4 - 4.52091094512792e+84*cos(theta)**2 + 6.91270786716807e+81)*sin(48*phi)

#@torch.jit.script
def Yl60_m_minus_47(theta, phi):
    return 3.12683925851279e-81*(1.0 - cos(theta)**2)**23.5*(1.11979607676935e+89*cos(theta)**13 - 7.33983983092515e+88*cos(theta)**11 + 1.72517602863625e+88*cos(theta)**9 - 1.80018368205522e+87*cos(theta)**7 + 8.36368524848664e+85*cos(theta)**5 - 1.50697031504264e+84*cos(theta)**3 + 6.91270786716807e+81*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl60_m_minus_46(theta, phi):
    return 1.21021202172876e-79*(1.0 - cos(theta)**2)**23*(7.99854340549535e+87*cos(theta)**14 - 6.11653319243762e+87*cos(theta)**12 + 1.72517602863625e+87*cos(theta)**10 - 2.25022960256903e+86*cos(theta)**8 + 1.39394754141444e+85*cos(theta)**6 - 3.7674257876066e+83*cos(theta)**4 + 3.45635393358403e+81*cos(theta)**2 - 4.61462474443796e+78)*sin(46*phi)

#@torch.jit.script
def Yl60_m_minus_45(theta, phi):
    return 4.82569672553458e-78*(1.0 - cos(theta)**2)**22.5*(5.33236227033024e+86*cos(theta)**15 - 4.70502553264433e+86*cos(theta)**13 + 1.56834184421478e+86*cos(theta)**11 - 2.50025511396558e+85*cos(theta)**9 + 1.99135363059206e+84*cos(theta)**7 - 7.53485157521319e+82*cos(theta)**5 + 1.15211797786134e+81*cos(theta)**3 - 4.61462474443796e+78*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl60_m_minus_44(theta, phi):
    return 1.97794707032021e-76*(1.0 - cos(theta)**2)**22*(3.3327264189564e+85*cos(theta)**16 - 3.36073252331738e+85*cos(theta)**14 + 1.30695153684565e+85*cos(theta)**12 - 2.50025511396558e+84*cos(theta)**10 + 2.48919203824007e+83*cos(theta)**8 - 1.25580859586887e+82*cos(theta)**6 + 2.88029494465336e+80*cos(theta)**4 - 2.30731237221898e+78*cos(theta)**2 + 2.74680044311783e+75)*sin(44*phi)

#@torch.jit.script
def Yl60_m_minus_43(theta, phi):
    return 8.3167911575098e-75*(1.0 - cos(theta)**2)**21.5*(1.96042730526847e+84*cos(theta)**17 - 2.24048834887825e+84*cos(theta)**15 + 1.00534733603511e+84*cos(theta)**13 - 2.27295919451417e+83*cos(theta)**11 + 2.76576893137786e+82*cos(theta)**9 - 1.79401227981267e+81*cos(theta)**7 + 5.76058988930672e+79*cos(theta)**5 - 7.69104124072994e+77*cos(theta)**3 + 2.74680044311783e+75*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl60_m_minus_42(theta, phi):
    return 3.58105227694671e-73*(1.0 - cos(theta)**2)**21*(1.08912628070471e+83*cos(theta)**18 - 1.40030521804891e+83*cos(theta)**16 + 7.1810524002508e+82*cos(theta)**14 - 1.89413266209514e+82*cos(theta)**12 + 2.76576893137786e+81*cos(theta)**10 - 2.24251534976583e+80*cos(theta)**8 + 9.60098314884454e+78*cos(theta)**6 - 1.92276031018248e+77*cos(theta)**4 + 1.37340022155892e+75*cos(theta)**2 - 1.48155363706464e+72)*sin(42*phi)

#@torch.jit.script
def Yl60_m_minus_41(theta, phi):
    return 1.57647666728742e-71*(1.0 - cos(theta)**2)**20.5*(5.73224358265634e+81*cos(theta)**19 - 8.23708951793475e+81*cos(theta)**17 + 4.78736826683387e+81*cos(theta)**15 - 1.45702512468857e+81*cos(theta)**13 + 2.51433539216169e+80*cos(theta)**11 - 2.49168372196203e+79*cos(theta)**9 + 1.37156902126351e+78*cos(theta)**7 - 3.84552062036497e+76*cos(theta)**5 + 4.57800073852972e+74*cos(theta)**3 - 1.48155363706464e+72*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl60_m_minus_40(theta, phi):
    return 7.08538138610289e-70*(1.0 - cos(theta)**2)**20*(2.86612179132817e+80*cos(theta)**20 - 4.57616084329708e+80*cos(theta)**18 + 2.99210516677117e+80*cos(theta)**16 - 1.04073223192041e+80*cos(theta)**14 + 2.09527949346807e+79*cos(theta)**12 - 2.49168372196203e+78*cos(theta)**10 + 1.71446127657938e+77*cos(theta)**8 - 6.40920103394161e+75*cos(theta)**6 + 1.14450018463243e+74*cos(theta)**4 - 7.40776818532318e+71*cos(theta)**2 + 7.33442394586453e+68)*sin(40*phi)

#@torch.jit.script
def Yl60_m_minus_39(theta, phi):
    return 3.24692965294476e-68*(1.0 - cos(theta)**2)**19.5*(1.36481990063246e+79*cos(theta)**21 - 2.40850570699846e+79*cos(theta)**19 + 1.76006186280657e+79*cos(theta)**17 - 6.93821487946938e+78*cos(theta)**15 + 1.6117534565139e+78*cos(theta)**13 - 2.26516701996549e+77*cos(theta)**11 + 1.90495697397709e+76*cos(theta)**9 - 9.15600147705945e+74*cos(theta)**7 + 2.28900036926486e+73*cos(theta)**5 - 2.46925606177439e+71*cos(theta)**3 + 7.33442394586453e+68*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl60_m_minus_38(theta, phi):
    return 1.51531114391773e-66*(1.0 - cos(theta)**2)**19*(6.20372682105665e+77*cos(theta)**22 - 1.20425285349923e+78*cos(theta)**20 + 9.7781214600365e+77*cos(theta)**18 - 4.33638429966836e+77*cos(theta)**16 + 1.1512524689385e+77*cos(theta)**14 - 1.88763918330457e+76*cos(theta)**12 + 1.90495697397709e+75*cos(theta)**10 - 1.14450018463243e+74*cos(theta)**8 + 3.81500061544144e+72*cos(theta)**6 - 6.17314015443598e+70*cos(theta)**4 + 3.66721197293227e+68*cos(theta)**2 - 3.36750410737582e+65)*sin(38*phi)

#@torch.jit.script
def Yl60_m_minus_37(theta, phi):
    return 7.19413814360994e-65*(1.0 - cos(theta)**2)**18.5*(2.6972725308942e+76*cos(theta)**23 - 5.73453739761539e+76*cos(theta)**21 + 5.14637971580868e+76*cos(theta)**19 - 2.55081429392256e+76*cos(theta)**17 + 7.67501645959002e+75*cos(theta)**15 - 1.45203014100352e+75*cos(theta)**13 + 1.7317790672519e+74*cos(theta)**11 - 1.27166687181381e+73*cos(theta)**9 + 5.45000087920205e+71*cos(theta)**7 - 1.2346280308872e+70*cos(theta)**5 + 1.22240399097742e+68*cos(theta)**3 - 3.36750410737582e+65*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl60_m_minus_36(theta, phi):
    return 3.47112505982011e-63*(1.0 - cos(theta)**2)**18*(1.12386355453925e+75*cos(theta)**24 - 2.606607908007e+75*cos(theta)**22 + 2.57318985790434e+75*cos(theta)**20 - 1.4171190521792e+75*cos(theta)**18 + 4.79688528724376e+74*cos(theta)**16 - 1.03716438643108e+74*cos(theta)**14 + 1.44314922270992e+73*cos(theta)**12 - 1.27166687181381e+72*cos(theta)**10 + 6.81250109900257e+70*cos(theta)**8 - 2.05771338481199e+69*cos(theta)**6 + 3.05600997744356e+67*cos(theta)**4 - 1.68375205368791e+65*cos(theta)**2 + 1.44652238289339e+62)*sin(36*phi)

#@torch.jit.script
def Yl60_m_minus_35(theta, phi):
    return 1.7004970459894e-61*(1.0 - cos(theta)**2)**17.5*(4.49545421815699e+73*cos(theta)**25 - 1.13330778609e+74*cos(theta)**23 + 1.22532850376397e+74*cos(theta)**21 - 7.45852132725896e+73*cos(theta)**19 + 2.82169722779045e+73*cos(theta)**17 - 6.91442924287389e+72*cos(theta)**15 + 1.11011478669994e+72*cos(theta)**13 - 1.15606079255801e+71*cos(theta)**11 + 7.56944566555841e+69*cos(theta)**9 - 2.93959054973142e+68*cos(theta)**7 + 6.11201995488711e+66*cos(theta)**5 - 5.61250684562636e+64*cos(theta)**3 + 1.44652238289339e+62*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl60_m_minus_34(theta, phi):
    return 8.4513163486194e-60*(1.0 - cos(theta)**2)**17*(1.7290208531373e+72*cos(theta)**26 - 4.72211577537499e+72*cos(theta)**24 + 5.56967501710896e+72*cos(theta)**22 - 3.72926066362948e+72*cos(theta)**20 + 1.56760957099469e+72*cos(theta)**18 - 4.32151827679618e+71*cos(theta)**16 + 7.92939133357097e+70*cos(theta)**14 - 9.63383993798343e+69*cos(theta)**12 + 7.56944566555841e+68*cos(theta)**10 - 3.67448818716428e+67*cos(theta)**8 + 1.01866999248119e+66*cos(theta)**6 - 1.40312671140659e+64*cos(theta)**4 + 7.23261191446696e+61*cos(theta)**2 - 5.85636592264531e+58)*sin(34*phi)

#@torch.jit.script
def Yl60_m_minus_33(theta, phi):
    return 4.25765205818926e-58*(1.0 - cos(theta)**2)**16.5*(6.40378093754557e+70*cos(theta)**27 - 1.88884631015e+71*cos(theta)**25 + 2.42159783352564e+71*cos(theta)**23 - 1.77583841125213e+71*cos(theta)**21 + 8.25057668944575e+70*cos(theta)**19 - 2.54206957458599e+70*cos(theta)**17 + 5.28626088904732e+69*cos(theta)**15 - 7.4106461061411e+68*cos(theta)**13 + 6.88131424141673e+67*cos(theta)**11 - 4.08276465240475e+66*cos(theta)**9 + 1.45524284640169e+65*cos(theta)**7 - 2.80625342281318e+63*cos(theta)**5 + 2.41087063815565e+61*cos(theta)**3 - 5.85636592264531e+58*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl60_m_minus_32(theta, phi):
    return 2.17265443940271e-56*(1.0 - cos(theta)**2)**16*(2.28706462055199e+69*cos(theta)**28 - 7.26479350057691e+69*cos(theta)**26 + 1.00899909730235e+70*cos(theta)**24 - 8.07199277841879e+69*cos(theta)**22 + 4.12528834472288e+69*cos(theta)**20 - 1.41226087476999e+69*cos(theta)**18 + 3.30391305565457e+68*cos(theta)**16 - 5.29331864724364e+67*cos(theta)**14 + 5.73442853451394e+66*cos(theta)**12 - 4.08276465240475e+65*cos(theta)**10 + 1.81905355800212e+64*cos(theta)**8 - 4.67708903802197e+62*cos(theta)**6 + 6.02717659538914e+60*cos(theta)**4 - 2.92818296132266e+58*cos(theta)**2 + 2.24898844955657e+55)*sin(32*phi)

#@torch.jit.script
def Yl60_m_minus_31(theta, phi):
    return 1.12223438154577e-54*(1.0 - cos(theta)**2)**15.5*(7.88642972604135e+67*cos(theta)**29 - 2.69066425947293e+68*cos(theta)**27 + 4.03599638920939e+68*cos(theta)**25 - 3.50956207757339e+68*cos(theta)**23 + 1.96442302129661e+68*cos(theta)**21 - 7.43295197247365e+67*cos(theta)**19 + 1.9434782680321e+67*cos(theta)**17 - 3.52887909816243e+66*cos(theta)**15 + 4.41109887270303e+65*cos(theta)**13 - 3.71160422945886e+64*cos(theta)**11 + 2.02117062000235e+63*cos(theta)**9 - 6.68155576860281e+61*cos(theta)**7 + 1.20543531907783e+60*cos(theta)**5 - 9.76060987107553e+57*cos(theta)**3 + 2.24898844955657e+55*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl60_m_minus_30(theta, phi):
    return 5.8636075239113e-53*(1.0 - cos(theta)**2)**15*(2.62880990868045e+66*cos(theta)**30 - 9.60951521240332e+66*cos(theta)**28 + 1.55230630354207e+67*cos(theta)**26 - 1.46231753232224e+67*cos(theta)**24 + 8.92919555134822e+66*cos(theta)**22 - 3.71647598623683e+66*cos(theta)**20 + 1.07971014890672e+66*cos(theta)**18 - 2.20554943635152e+65*cos(theta)**16 + 3.1507849090736e+64*cos(theta)**14 - 3.09300352454905e+63*cos(theta)**12 + 2.02117062000235e+62*cos(theta)**10 - 8.35194471075352e+60*cos(theta)**8 + 2.00905886512971e+59*cos(theta)**6 - 2.44015246776888e+57*cos(theta)**4 + 1.12449422477829e+55*cos(theta)**2 - 8.23805292877866e+51)*sin(30*phi)

#@torch.jit.script
def Yl60_m_minus_29(theta, phi):
    return 3.09718391466457e-51*(1.0 - cos(theta)**2)**14.5*(8.48003196348532e+64*cos(theta)**31 - 3.31362593531149e+65*cos(theta)**29 + 5.74928260571139e+65*cos(theta)**27 - 5.84927012928898e+65*cos(theta)**25 + 3.88225893536879e+65*cos(theta)**23 - 1.76975046963658e+65*cos(theta)**21 + 5.68268499424591e+64*cos(theta)**19 - 1.29738202138325e+64*cos(theta)**17 + 2.10052327271573e+63*cos(theta)**15 - 2.37923348042235e+62*cos(theta)**13 + 1.83742783636577e+61*cos(theta)**11 - 9.27993856750391e+59*cos(theta)**9 + 2.87008409304245e+58*cos(theta)**7 - 4.88030493553776e+56*cos(theta)**5 + 3.74831408259429e+54*cos(theta)**3 - 8.23805292877866e+51*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl60_m_minus_28(theta, phi):
    return 1.65286349337081e-49*(1.0 - cos(theta)**2)**14*(2.65000998858916e+63*cos(theta)**32 - 1.10454197843716e+64*cos(theta)**30 + 2.0533152163255e+64*cos(theta)**28 - 2.24971928049576e+64*cos(theta)**26 + 1.617607889737e+64*cos(theta)**24 - 8.04432031652993e+63*cos(theta)**22 + 2.84134249712296e+63*cos(theta)**20 - 7.20767789657359e+62*cos(theta)**18 + 1.31282704544733e+62*cos(theta)**16 - 1.69945248601596e+61*cos(theta)**14 + 1.53118986363815e+60*cos(theta)**12 - 9.27993856750391e+58*cos(theta)**10 + 3.58760511630306e+57*cos(theta)**8 - 8.1338415592296e+55*cos(theta)**6 + 9.37078520648572e+53*cos(theta)**4 - 4.11902646438933e+51*cos(theta)**2 + 2.89257476431835e+48)*sin(28*phi)

#@torch.jit.script
def Yl60_m_minus_27(theta, phi):
    return 8.90707878111168e-48*(1.0 - cos(theta)**2)**13.5*(8.03033329875504e+61*cos(theta)**33 - 3.56303864011988e+62*cos(theta)**31 + 7.08039729767412e+62*cos(theta)**29 - 8.33229363146578e+62*cos(theta)**27 + 6.47043155894798e+62*cos(theta)**25 - 3.49753057240432e+62*cos(theta)**23 + 1.35302023672522e+62*cos(theta)**21 - 3.79351468240715e+61*cos(theta)**19 + 7.72251203204313e+60*cos(theta)**17 - 1.13296832401064e+60*cos(theta)**15 + 1.17783835664473e+59*cos(theta)**13 - 8.43630778863992e+57*cos(theta)**11 + 3.9862279070034e+56*cos(theta)**9 - 1.16197736560423e+55*cos(theta)**7 + 1.87415704129714e+53*cos(theta)**5 - 1.37300882146311e+51*cos(theta)**3 + 2.89257476431835e+48*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl60_m_minus_26(theta, phi):
    return 4.84433734413125e-46*(1.0 - cos(theta)**2)**13*(2.36186273492795e+60*cos(theta)**34 - 1.11344957503746e+61*cos(theta)**32 + 2.36013243255804e+61*cos(theta)**30 - 2.97581915409492e+61*cos(theta)**28 + 2.4886275226723e+61*cos(theta)**26 - 1.45730440516846e+61*cos(theta)**24 + 6.15009198511462e+60*cos(theta)**22 - 1.89675734120358e+60*cos(theta)**20 + 4.29028446224618e+59*cos(theta)**18 - 7.08105202506651e+58*cos(theta)**16 + 8.41313111889091e+57*cos(theta)**14 - 7.03025649053326e+56*cos(theta)**12 + 3.9862279070034e+55*cos(theta)**10 - 1.45247170700529e+54*cos(theta)**8 + 3.12359506882857e+52*cos(theta)**6 - 3.43252205365777e+50*cos(theta)**4 + 1.44628738215917e+48*cos(theta)**2 - 9.77881935198901e+44)*sin(26*phi)

#@torch.jit.script
def Yl60_m_minus_25(theta, phi):
    return 2.65777141519491e-44*(1.0 - cos(theta)**2)**12.5*(6.74817924265129e+58*cos(theta)**35 - 3.37408962132565e+59*cos(theta)**33 + 7.61333042760658e+59*cos(theta)**31 - 1.0261445358948e+60*cos(theta)**29 + 9.21713897286037e+59*cos(theta)**27 - 5.82921762067386e+59*cos(theta)**25 + 2.67395303700636e+59*cos(theta)**23 - 9.03217781525512e+58*cos(theta)**21 + 2.25804445381378e+58*cos(theta)**19 - 4.16532472062736e+57*cos(theta)**17 + 5.6087540792606e+56*cos(theta)**15 - 5.40788960810251e+55*cos(theta)**13 + 3.62384355182127e+54*cos(theta)**11 - 1.6138574522281e+53*cos(theta)**9 + 4.4622786697551e+51*cos(theta)**7 - 6.86504410731555e+49*cos(theta)**5 + 4.82095794053058e+47*cos(theta)**3 - 9.77881935198901e+44*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl60_m_minus_24(theta, phi):
    return 1.4702065031827e-42*(1.0 - cos(theta)**2)**12*(1.8744942340698e+57*cos(theta)**36 - 9.92379300389896e+57*cos(theta)**34 + 2.37916575862706e+58*cos(theta)**32 - 3.420481786316e+58*cos(theta)**30 + 3.29183534745013e+58*cos(theta)**28 - 2.24200677718225e+58*cos(theta)**26 + 1.11414709875265e+58*cos(theta)**24 - 4.10553537057051e+57*cos(theta)**22 + 1.12902222690689e+57*cos(theta)**20 - 2.31406928923742e+56*cos(theta)**18 + 3.50547129953788e+55*cos(theta)**16 - 3.86277829150179e+54*cos(theta)**14 + 3.01986962651773e+53*cos(theta)**12 - 1.6138574522281e+52*cos(theta)**10 + 5.57784833719388e+50*cos(theta)**8 - 1.14417401788592e+49*cos(theta)**6 + 1.20523948513264e+47*cos(theta)**4 - 4.8894096759945e+44*cos(theta)**2 + 3.19569259868922e+41)*sin(24*phi)

#@torch.jit.script
def Yl60_m_minus_23(theta, phi):
    return 8.19631884415083e-41*(1.0 - cos(theta)**2)**11.5*(5.06620063262109e+55*cos(theta)**37 - 2.83536942968542e+56*cos(theta)**35 + 7.20959320796078e+56*cos(theta)**33 - 1.10338122139226e+57*cos(theta)**31 + 1.13511563705177e+57*cos(theta)**29 - 8.30372880437872e+56*cos(theta)**27 + 4.4565883950106e+56*cos(theta)**25 - 1.78501537850892e+56*cos(theta)**23 + 5.37629631860424e+55*cos(theta)**21 - 1.2179312048618e+55*cos(theta)**19 + 2.06204194090463e+54*cos(theta)**17 - 2.57518552766786e+53*cos(theta)**15 + 2.32297663578287e+52*cos(theta)**13 - 1.46714313838918e+51*cos(theta)**11 + 6.19760926354876e+49*cos(theta)**9 - 1.63453431126561e+48*cos(theta)**7 + 2.41047897026529e+46*cos(theta)**5 - 1.6298032253315e+44*cos(theta)**3 + 3.19569259868922e+41*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl60_m_minus_22(theta, phi):
    return 4.60309235997469e-39*(1.0 - cos(theta)**2)**11*(1.33321069279502e+54*cos(theta)**38 - 7.8760261935706e+54*cos(theta)**36 + 2.1204685905767e+55*cos(theta)**34 - 3.44806631685081e+55*cos(theta)**32 + 3.78371879017257e+55*cos(theta)**30 - 2.96561743013526e+55*cos(theta)**28 + 1.71407245961946e+55*cos(theta)**26 - 7.43756407712049e+54*cos(theta)**24 + 2.44377105391102e+54*cos(theta)**22 - 6.08965602430901e+53*cos(theta)**20 + 1.14557885605813e+53*cos(theta)**18 - 1.60949095479241e+52*cos(theta)**16 + 1.65926902555919e+51*cos(theta)**14 - 1.22261928199098e+50*cos(theta)**12 + 6.19760926354876e+48*cos(theta)**10 - 2.04316788908201e+47*cos(theta)**8 + 4.01746495044215e+45*cos(theta)**6 - 4.07450806332875e+43*cos(theta)**4 + 1.59784629934461e+41*cos(theta)**2 - 1.01321895963514e+38)*sin(22*phi)

#@torch.jit.script
def Yl60_m_minus_21(theta, phi):
    return 2.60308841109392e-37*(1.0 - cos(theta)**2)**10.5*(3.41848895588468e+52*cos(theta)**39 - 2.12865572799205e+53*cos(theta)**37 + 6.058481687362e+53*cos(theta)**35 - 1.04486858086388e+54*cos(theta)**33 + 1.22055444844276e+54*cos(theta)**31 - 1.02262670004664e+54*cos(theta)**29 + 6.34841651710911e+53*cos(theta)**27 - 2.97502563084819e+53*cos(theta)**25 + 1.06250915387436e+53*cos(theta)**23 - 2.89983620205191e+52*cos(theta)**21 + 6.02936240030595e+51*cos(theta)**19 - 9.46759385172008e+50*cos(theta)**17 + 1.10617935037279e+50*cos(theta)**15 - 9.40476370762294e+48*cos(theta)**13 + 5.63419023958978e+47*cos(theta)**11 - 2.27018654342445e+46*cos(theta)**9 + 5.73923564348879e+44*cos(theta)**7 - 8.1490161266575e+42*cos(theta)**5 + 5.3261543311487e+40*cos(theta)**3 - 1.01321895963514e+38*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl60_m_minus_20(theta, phi):
    return 1.48170389937219e-35*(1.0 - cos(theta)**2)**10*(8.54622238971169e+50*cos(theta)**40 - 5.60172559997909e+51*cos(theta)**38 + 1.68291157982278e+52*cos(theta)**36 - 3.07314288489377e+52*cos(theta)**34 + 3.81423265138364e+52*cos(theta)**32 - 3.40875566682213e+52*cos(theta)**30 + 2.26729161325325e+52*cos(theta)**28 - 1.14424062724931e+52*cos(theta)**26 + 4.42712147447648e+51*cos(theta)**24 - 1.31810736456905e+51*cos(theta)**22 + 3.01468120015297e+50*cos(theta)**20 - 5.25977436206671e+49*cos(theta)**18 + 6.91362093982996e+48*cos(theta)**16 - 6.71768836258781e+47*cos(theta)**14 + 4.69515853299148e+46*cos(theta)**12 - 2.27018654342445e+45*cos(theta)**10 + 7.17404455436098e+43*cos(theta)**8 - 1.35816935444292e+42*cos(theta)**6 + 1.33153858278717e+40*cos(theta)**4 - 5.06609479817568e+37*cos(theta)**2 + 3.12721901121955e+34)*sin(20*phi)

#@torch.jit.script
def Yl60_m_minus_19(theta, phi):
    return 8.48590851998793e-34*(1.0 - cos(theta)**2)**9.5*(2.08444448529553e+49*cos(theta)**41 - 1.43633989743054e+50*cos(theta)**39 + 4.5484096751967e+50*cos(theta)**37 - 8.78040824255362e+50*cos(theta)**35 + 1.15582807617686e+51*cos(theta)**33 - 1.09959860220069e+51*cos(theta)**31 + 7.8182469422526e+50*cos(theta)**29 - 4.2379282490715e+50*cos(theta)**27 + 1.77084858979059e+50*cos(theta)**25 - 5.73090158508282e+49*cos(theta)**23 + 1.43556247626332e+49*cos(theta)**21 - 2.76830229582459e+48*cos(theta)**19 + 4.0668358469588e+47*cos(theta)**17 - 4.47845890839188e+46*cos(theta)**15 + 3.61166040999345e+45*cos(theta)**13 - 2.06380594856768e+44*cos(theta)**11 + 7.97116061595665e+42*cos(theta)**9 - 1.94024193491845e+41*cos(theta)**7 + 2.66307716557435e+39*cos(theta)**5 - 1.68869826605856e+37*cos(theta)**3 + 3.12721901121955e+34*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl60_m_minus_18(theta, phi):
    return 4.88806009407684e-32*(1.0 - cos(theta)**2)**9*(4.96296306022746e+47*cos(theta)**42 - 3.59084974357634e+48*cos(theta)**40 + 1.19694991452545e+49*cos(theta)**38 - 2.43900228959823e+49*cos(theta)**36 + 3.39949434169665e+49*cos(theta)**34 - 3.43624563187715e+49*cos(theta)**32 + 2.6060823140842e+49*cos(theta)**30 - 1.51354580323982e+49*cos(theta)**28 + 6.8109561145792e+48*cos(theta)**26 - 2.38787566045118e+48*cos(theta)**24 + 6.5252839830151e+47*cos(theta)**22 - 1.38415114791229e+47*cos(theta)**20 + 2.25935324831044e+46*cos(theta)**18 - 2.79903681774492e+45*cos(theta)**16 + 2.57975743570961e+44*cos(theta)**14 - 1.71983829047307e+43*cos(theta)**12 + 7.97116061595665e+41*cos(theta)**10 - 2.42530241864807e+40*cos(theta)**8 + 4.43846194262391e+38*cos(theta)**6 - 4.2217456651464e+36*cos(theta)**4 + 1.56360950560978e+34*cos(theta)**2 - 9.4250120892693e+30)*sin(18*phi)

#@torch.jit.script
def Yl60_m_minus_17(theta, phi):
    return 2.83085787341947e-30*(1.0 - cos(theta)**2)**8.5*(1.15417745586685e+46*cos(theta)**43 - 8.75817010628375e+46*cos(theta)**41 + 3.06910234493704e+47*cos(theta)**39 - 6.59189807999521e+47*cos(theta)**37 + 9.71284097627613e+47*cos(theta)**35 - 1.04128655511429e+48*cos(theta)**33 + 8.4067171422071e+47*cos(theta)**31 - 5.21912345944766e+47*cos(theta)**29 + 2.52257633873304e+47*cos(theta)**27 - 9.5515026418047e+46*cos(theta)**25 + 2.83707999261526e+46*cos(theta)**23 - 6.59119594243949e+45*cos(theta)**21 + 1.18913328858444e+45*cos(theta)**19 - 1.64649224573231e+44*cos(theta)**17 + 1.71983829047307e+43*cos(theta)**15 - 1.32295253113313e+42*cos(theta)**13 + 7.24650965086968e+40*cos(theta)**11 - 2.69478046516452e+39*cos(theta)**9 + 6.34065991803416e+37*cos(theta)**7 - 8.4434913302928e+35*cos(theta)**5 + 5.21203168536592e+33*cos(theta)**3 - 9.4250120892693e+30*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl60_m_minus_16(theta, phi):
    return 1.64774410460816e-28*(1.0 - cos(theta)**2)**8*(2.62313058151557e+44*cos(theta)**44 - 2.08527859673423e+45*cos(theta)**42 + 7.67275586234261e+45*cos(theta)**40 - 1.73471002105137e+46*cos(theta)**38 + 2.69801138229893e+46*cos(theta)**36 - 3.06260751504202e+46*cos(theta)**34 + 2.62709910693972e+46*cos(theta)**32 - 1.73970781981589e+46*cos(theta)**30 + 9.00920120976085e+45*cos(theta)**28 - 3.67365486223258e+45*cos(theta)**26 + 1.18211666358969e+45*cos(theta)**24 - 2.99599815565431e+44*cos(theta)**22 + 5.94566644292222e+43*cos(theta)**20 - 9.14717914295726e+42*cos(theta)**18 + 1.07489893154567e+42*cos(theta)**16 - 9.44966093666522e+40*cos(theta)**14 + 6.0387580423914e+39*cos(theta)**12 - 2.69478046516452e+38*cos(theta)**10 + 7.9258248975427e+36*cos(theta)**8 - 1.4072485550488e+35*cos(theta)**6 + 1.30300792134148e+33*cos(theta)**4 - 4.71250604463465e+30*cos(theta)**2 + 2.7818807819567e+27)*sin(16*phi)

#@torch.jit.script
def Yl60_m_minus_15(theta, phi):
    return 9.63613375229227e-27*(1.0 - cos(theta)**2)**7.5*(5.8291790700346e+42*cos(theta)**45 - 4.84948510868425e+43*cos(theta)**43 + 1.87140386886405e+44*cos(theta)**41 - 4.44797441295224e+44*cos(theta)**39 + 7.29192265486196e+44*cos(theta)**37 - 8.75030718583435e+44*cos(theta)**35 + 7.96090638466581e+44*cos(theta)**33 - 5.61196070908351e+44*cos(theta)**31 + 3.10662110681409e+44*cos(theta)**29 - 1.36061291193799e+44*cos(theta)**27 + 4.72846665435876e+43*cos(theta)**25 - 1.30260789376275e+43*cos(theta)**23 + 2.83126973472487e+42*cos(theta)**21 - 4.81430481208277e+41*cos(theta)**19 + 6.32293489144511e+40*cos(theta)**17 - 6.29977395777681e+39*cos(theta)**15 + 4.64519849414723e+38*cos(theta)**13 - 2.44980042287684e+37*cos(theta)**11 + 8.80647210838078e+35*cos(theta)**9 - 2.01035507864114e+34*cos(theta)**7 + 2.60601584268296e+32*cos(theta)**5 - 1.57083534821155e+30*cos(theta)**3 + 2.7818807819567e+27*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl60_m_minus_14(theta, phi):
    return 5.65994703365348e-25*(1.0 - cos(theta)**2)**7*(1.26721284131187e+41*cos(theta)**46 - 1.10215570651915e+42*cos(theta)**44 + 4.45572349729536e+42*cos(theta)**42 - 1.11199360323806e+43*cos(theta)**40 + 1.91892701443736e+43*cos(theta)**38 - 2.43064088495399e+43*cos(theta)**36 + 2.34144305431347e+43*cos(theta)**34 - 1.7537377215886e+43*cos(theta)**32 + 1.03554036893803e+43*cos(theta)**30 - 4.85933182834997e+42*cos(theta)**28 + 1.81864102090722e+42*cos(theta)**26 - 5.4275328906781e+41*cos(theta)**24 + 1.2869407885113e+41*cos(theta)**22 - 2.40715240604138e+40*cos(theta)**20 + 3.5127416063584e+39*cos(theta)**18 - 3.93735872361051e+38*cos(theta)**16 + 3.31799892439088e+37*cos(theta)**14 - 2.04150035239736e+36*cos(theta)**12 + 8.80647210838078e+34*cos(theta)**10 - 2.51294384830143e+33*cos(theta)**8 + 4.34335973780494e+31*cos(theta)**6 - 3.92708837052888e+29*cos(theta)**4 + 1.39094039097835e+27*cos(theta)**2 - 8.06342255639623e+23)*sin(14*phi)

#@torch.jit.script
def Yl60_m_minus_13(theta, phi):
    return 3.33792947010339e-23*(1.0 - cos(theta)**2)**6.5*(2.69619753470611e+39*cos(theta)**47 - 2.44923490337588e+40*cos(theta)**45 + 1.03621476681287e+41*cos(theta)**43 - 2.71217952009283e+41*cos(theta)**41 + 4.92032567804451e+41*cos(theta)**39 - 6.56929968906483e+41*cos(theta)**37 + 6.6898372980385e+41*cos(theta)**35 - 5.31435673208666e+41*cos(theta)**33 + 3.3404528030259e+41*cos(theta)**31 - 1.67563166494827e+41*cos(theta)**29 + 6.73570748484154e+40*cos(theta)**27 - 2.17101315627124e+40*cos(theta)**25 + 5.59539473265784e+39*cos(theta)**23 - 1.1462630504959e+39*cos(theta)**21 + 1.84881137176758e+38*cos(theta)**19 - 2.31609336682971e+37*cos(theta)**17 + 2.21199928292725e+36*cos(theta)**15 - 1.57038488645951e+35*cos(theta)**13 + 8.00588373489162e+33*cos(theta)**11 - 2.79215983144603e+32*cos(theta)**9 + 6.20479962543562e+30*cos(theta)**7 - 7.85417674105775e+28*cos(theta)**5 + 4.63646796992783e+26*cos(theta)**3 - 8.06342255639623e+23*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl60_m_minus_12(theta, phi):
    return 1.97587380944321e-21*(1.0 - cos(theta)**2)**6*(5.61707819730439e+37*cos(theta)**48 - 5.32442370299105e+38*cos(theta)**46 + 2.35503356093835e+39*cos(theta)**44 - 6.4575702859353e+39*cos(theta)**42 + 1.23008141951113e+40*cos(theta)**40 - 1.72876307606969e+40*cos(theta)**38 + 1.85828813834403e+40*cos(theta)**36 - 1.56304609767255e+40*cos(theta)**34 + 1.04389150094559e+40*cos(theta)**32 - 5.58543888316089e+39*cos(theta)**30 + 2.40560981601484e+39*cos(theta)**28 - 8.35005060104324e+38*cos(theta)**26 + 2.33141447194077e+38*cos(theta)**24 - 5.21028659316317e+37*cos(theta)**22 + 9.24405685883788e+36*cos(theta)**20 - 1.28671853712762e+36*cos(theta)**18 + 1.38249955182953e+35*cos(theta)**16 - 1.12170349032822e+34*cos(theta)**14 + 6.67156977907635e+32*cos(theta)**12 - 2.79215983144603e+31*cos(theta)**10 + 7.75599953179453e+29*cos(theta)**8 - 1.30902945684296e+28*cos(theta)**6 + 1.15911699248196e+26*cos(theta)**4 - 4.03171127819812e+23*cos(theta)**2 + 2.30120506746468e+20)*sin(12*phi)

#@torch.jit.script
def Yl60_m_minus_11(theta, phi):
    return 1.173609166318e-19*(1.0 - cos(theta)**2)**5.5*(1.14634248924579e+36*cos(theta)**49 - 1.13285610701937e+37*cos(theta)**47 + 5.23340791319633e+37*cos(theta)**45 - 1.50176053161286e+38*cos(theta)**43 + 3.00019858417348e+38*cos(theta)**41 - 4.43272583607613e+38*cos(theta)**39 + 5.02240037390277e+38*cos(theta)**37 - 4.46584599335013e+38*cos(theta)**35 + 3.16330757862301e+38*cos(theta)**33 - 1.801754478439e+38*cos(theta)**31 + 8.29520626212013e+37*cos(theta)**29 - 3.09261133371972e+37*cos(theta)**27 + 9.32565788776307e+36*cos(theta)**25 - 2.26534199702747e+36*cos(theta)**23 + 4.40193183754185e+35*cos(theta)**21 - 6.77220282698746e+34*cos(theta)**19 + 8.1323503048796e+33*cos(theta)**17 - 7.47802326885481e+32*cos(theta)**15 + 5.13197675313565e+31*cos(theta)**13 - 2.53832711949639e+30*cos(theta)**11 + 8.61777725754948e+28*cos(theta)**9 - 1.87004208120423e+27*cos(theta)**7 + 2.31823398496392e+25*cos(theta)**5 - 1.34390375939937e+23*cos(theta)**3 + 2.30120506746468e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl60_m_minus_10(theta, phi):
    return 6.99258363353129e-18*(1.0 - cos(theta)**2)**5*(2.29268497849159e+34*cos(theta)**50 - 2.36011688962369e+35*cos(theta)**48 + 1.13769737243399e+36*cos(theta)**46 - 3.41309211730196e+36*cos(theta)**44 + 7.14332996231781e+36*cos(theta)**42 - 1.10818145901903e+37*cos(theta)**40 + 1.32168430892178e+37*cos(theta)**38 - 1.24051277593059e+37*cos(theta)**36 + 9.30384581947944e+36*cos(theta)**34 - 5.63048274512186e+36*cos(theta)**32 + 2.76506875404004e+36*cos(theta)**30 - 1.10450404775704e+36*cos(theta)**28 + 3.58679149529349e+35*cos(theta)**26 - 9.43892498761444e+34*cos(theta)**24 + 2.00087810797357e+34*cos(theta)**22 - 3.38610141349373e+33*cos(theta)**20 + 4.51797239159978e+32*cos(theta)**18 - 4.67376454303425e+31*cos(theta)**16 + 3.66569768081118e+30*cos(theta)**14 - 2.11527259958033e+29*cos(theta)**12 + 8.61777725754948e+27*cos(theta)**10 - 2.33755260150528e+26*cos(theta)**8 + 3.8637233082732e+24*cos(theta)**6 - 3.35975939849843e+22*cos(theta)**4 + 1.15060253373234e+20*cos(theta)**2 - 6.48226779567515e+16)*sin(10*phi)

#@torch.jit.script
def Yl60_m_minus_9(theta, phi):
    return 4.17803214878475e-16*(1.0 - cos(theta)**2)**4.5*(4.49546074214037e+32*cos(theta)**51 - 4.81656508086468e+33*cos(theta)**49 + 2.42063270730635e+34*cos(theta)**47 - 7.5846491495599e+34*cos(theta)**45 + 1.66123952612042e+35*cos(theta)**43 - 2.7028816073635e+35*cos(theta)**41 + 3.38893412544047e+35*cos(theta)**39 - 3.35273723224484e+35*cos(theta)**37 + 2.65824166270841e+35*cos(theta)**35 - 1.70620689246117e+35*cos(theta)**33 + 8.91957662593562e+34*cos(theta)**31 - 3.80863464743808e+34*cos(theta)**29 + 1.32844129455314e+34*cos(theta)**27 - 3.77556999504578e+33*cos(theta)**25 + 8.69947003466769e+32*cos(theta)**23 - 1.61242924452082e+32*cos(theta)**21 + 2.37788020610515e+31*cos(theta)**19 - 2.74927326060839e+30*cos(theta)**17 + 2.44379845387412e+29*cos(theta)**15 - 1.62713276890794e+28*cos(theta)**13 + 7.83434296140861e+26*cos(theta)**11 - 2.5972806683392e+25*cos(theta)**9 + 5.51960472610456e+23*cos(theta)**7 - 6.71951879699686e+21*cos(theta)**5 + 3.8353417791078e+19*cos(theta)**3 - 6.48226779567515e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl60_m_minus_8(theta, phi):
    return 2.50263776961367e-14*(1.0 - cos(theta)**2)**4*(8.6451168118084e+30*cos(theta)**52 - 9.63313016172936e+31*cos(theta)**50 + 5.04298480688823e+32*cos(theta)**48 - 1.64883677164346e+33*cos(theta)**46 + 3.77554437754641e+33*cos(theta)**44 - 6.43543239848451e+33*cos(theta)**42 + 8.47233531360117e+33*cos(theta)**40 - 8.8229927164338e+33*cos(theta)**38 + 7.38400461863448e+33*cos(theta)**36 - 5.01825556606227e+33*cos(theta)**34 + 2.78736769560488e+33*cos(theta)**32 - 1.26954488247936e+33*cos(theta)**30 + 4.74443319483265e+32*cos(theta)**28 - 1.45214230578684e+32*cos(theta)**26 + 3.62477918111154e+31*cos(theta)**24 - 7.32922383873102e+30*cos(theta)**22 + 1.18894010305257e+30*cos(theta)**20 - 1.52737403367133e+29*cos(theta)**18 + 1.52737403367133e+28*cos(theta)**16 - 1.1622376920771e+27*cos(theta)**14 + 6.52861913450718e+25*cos(theta)**12 - 2.5972806683392e+24*cos(theta)**10 + 6.89950590763071e+22*cos(theta)**8 - 1.11991979949948e+21*cos(theta)**6 + 9.58835444776949e+18*cos(theta)**4 - 3.24113389783758e+16*cos(theta)**2 + 18066521169663.2)*sin(8*phi)

#@torch.jit.script
def Yl60_m_minus_7(theta, phi):
    return 1.502416642761e-12*(1.0 - cos(theta)**2)**3.5*(1.63115411543555e+29*cos(theta)**53 - 1.88884905131948e+30*cos(theta)**51 + 1.02918057283433e+31*cos(theta)**49 - 3.50816334392225e+31*cos(theta)**47 + 8.3900986167698e+31*cos(theta)**45 - 1.49661218569407e+32*cos(theta)**43 + 2.0664232472198e+32*cos(theta)**41 - 2.26230582472661e+32*cos(theta)**39 + 1.99567692395526e+32*cos(theta)**37 - 1.43378730458922e+32*cos(theta)**35 + 8.44656877456025e+31*cos(theta)**33 - 4.09530607251406e+31*cos(theta)**31 + 1.63601144649402e+31*cos(theta)**29 - 5.37830483624754e+30*cos(theta)**27 + 1.44991167244461e+30*cos(theta)**25 - 3.18661906031783e+29*cos(theta)**23 + 5.66161953834559e+28*cos(theta)**21 - 8.03881070353329e+27*cos(theta)**19 + 8.98455313924309e+26*cos(theta)**17 - 7.74825128051401e+25*cos(theta)**15 + 5.02201471885168e+24*cos(theta)**13 - 2.36116424394473e+23*cos(theta)**11 + 7.66611767514523e+21*cos(theta)**9 - 1.5998854278564e+20*cos(theta)**7 + 1.9176708895539e+18*cos(theta)**5 - 1.08037796594586e+16*cos(theta)**3 + 18066521169663.2*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl60_m_minus_6(theta, phi):
    return 9.03700800610182e-11*(1.0 - cos(theta)**2)**3*(3.02065576932509e+27*cos(theta)**54 - 3.63240202176824e+28*cos(theta)**52 + 2.05836114566867e+29*cos(theta)**50 - 7.30867363317135e+29*cos(theta)**48 + 1.82393448190648e+30*cos(theta)**46 - 3.40139133112289e+30*cos(theta)**44 + 4.92005535052333e+30*cos(theta)**42 - 5.65576456181654e+30*cos(theta)**40 + 5.25178137882964e+30*cos(theta)**38 - 3.98274251274783e+30*cos(theta)**36 + 2.48428493369419e+30*cos(theta)**34 - 1.27978314766064e+30*cos(theta)**32 + 5.4533714883134e+29*cos(theta)**30 - 1.92082315580269e+29*cos(theta)**28 + 5.57658335555621e+28*cos(theta)**26 - 1.3277579417991e+28*cos(theta)**24 + 2.57346342652072e+27*cos(theta)**22 - 4.01940535176665e+26*cos(theta)**20 + 4.99141841069061e+25*cos(theta)**18 - 4.84265705032126e+24*cos(theta)**16 + 3.58715337060834e+23*cos(theta)**14 - 1.96763686995394e+22*cos(theta)**12 + 7.66611767514523e+20*cos(theta)**10 - 1.99985678482049e+19*cos(theta)**8 + 3.1961181492565e+17*cos(theta)**6 - 2.70094491486465e+15*cos(theta)**4 + 9033260584831.59*cos(theta)**2 - 4993510549.93455)*sin(6*phi)

#@torch.jit.script
def Yl60_m_minus_5(theta, phi):
    return 5.44475045102643e-9*(1.0 - cos(theta)**2)**2.5*(5.49210139877289e+25*cos(theta)**55 - 6.85358872031742e+26*cos(theta)**53 + 4.03600224640915e+27*cos(theta)**51 - 1.49156604758599e+28*cos(theta)**49 + 3.88071166363081e+28*cos(theta)**47 - 7.55864740249532e+28*cos(theta)**45 + 1.14419891872636e+29*cos(theta)**43 - 1.37945477117477e+29*cos(theta)**41 + 1.34661060995632e+29*cos(theta)**39 - 1.07641689533725e+29*cos(theta)**37 + 7.09795695341197e+28*cos(theta)**35 - 3.8781307504868e+28*cos(theta)**33 + 1.75915209300432e+28*cos(theta)**31 - 6.62352812345757e+27*cos(theta)**29 + 2.0654012427986e+27*cos(theta)**27 - 5.31103176719639e+26*cos(theta)**25 + 1.11889714196553e+26*cos(theta)**23 - 1.91400254846031e+25*cos(theta)**21 + 2.62706232141611e+24*cos(theta)**19 - 2.84862179430662e+23*cos(theta)**17 + 2.39143558040556e+22*cos(theta)**15 - 1.51356682304149e+21*cos(theta)**13 + 6.96919788649566e+19*cos(theta)**11 - 2.22206309424499e+18*cos(theta)**9 + 4.56588307036643e+16*cos(theta)**7 - 540188982972929.0*cos(theta)**5 + 3011086861610.53*cos(theta)**3 - 4993510549.93455*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl60_m_minus_4(theta, phi):
    return 3.28494930257968e-7*(1.0 - cos(theta)**2)**2*(9.80732392638015e+23*cos(theta)**56 - 1.26918309635508e+25*cos(theta)**54 + 7.76154278155606e+25*cos(theta)**52 - 2.98313209517198e+26*cos(theta)**50 + 8.08481596589751e+26*cos(theta)**48 - 1.64318421793376e+27*cos(theta)**46 + 2.60045208801444e+27*cos(theta)**44 - 3.28441612184468e+27*cos(theta)**42 + 3.3665265248908e+27*cos(theta)**40 - 2.83267604036119e+27*cos(theta)**38 + 1.9716547092811e+27*cos(theta)**36 - 1.14062669131965e+27*cos(theta)**34 + 5.4973502906385e+26*cos(theta)**32 - 2.20784270781919e+26*cos(theta)**30 + 7.37643300999499e+25*cos(theta)**28 - 2.04270452584476e+25*cos(theta)**26 + 4.66207142485638e+24*cos(theta)**24 - 8.70001158391049e+23*cos(theta)**22 + 1.31353116070805e+23*cos(theta)**20 - 1.58256766350368e+22*cos(theta)**18 + 1.49464723775348e+21*cos(theta)**16 - 1.08111915931535e+20*cos(theta)**14 + 5.80766490541305e+18*cos(theta)**12 - 2.22206309424499e+17*cos(theta)**10 + 5.70735383795803e+15*cos(theta)**8 - 90031497162154.9*cos(theta)**6 + 752771715402.633*cos(theta)**4 - 2496755274.96727*cos(theta)**2 + 1371843.55767433)*sin(4*phi)

#@torch.jit.script
def Yl60_m_minus_3(theta, phi):
    return 1.98406586901877e-5*(1.0 - cos(theta)**2)**1.5*(1.72058314497897e+22*cos(theta)**57 - 2.30760562973651e+23*cos(theta)**55 + 1.46444203425586e+24*cos(theta)**53 - 5.84927861798428e+24*cos(theta)**51 + 1.6499624420199e+25*cos(theta)**49 - 3.49613663390163e+25*cos(theta)**47 + 5.77878241780988e+25*cos(theta)**45 - 7.63817702754577e+25*cos(theta)**43 + 8.2110403046117e+25*cos(theta)**41 - 7.26327189836202e+25*cos(theta)**39 + 5.32879651157055e+25*cos(theta)**37 - 3.25893340377042e+25*cos(theta)**35 + 1.66586372443591e+25*cos(theta)**33 - 7.12207325102964e+24*cos(theta)**31 + 2.54359758965344e+24*cos(theta)**29 - 7.56557231794357e+23*cos(theta)**27 + 1.86482856994255e+23*cos(theta)**25 - 3.78261373213499e+22*cos(theta)**23 + 6.25491028908597e+21*cos(theta)**21 - 8.32930349212463e+20*cos(theta)**19 + 8.79204257502044e+19*cos(theta)**17 - 7.20746106210235e+18*cos(theta)**15 + 4.46743454262542e+17*cos(theta)**13 - 2.02005735840454e+16*cos(theta)**11 + 634150426439781.0*cos(theta)**9 - 12861642451736.4*cos(theta)**7 + 150554343080.527*cos(theta)**5 - 832251758.322424*cos(theta)**3 + 1371843.55767433*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl60_m_minus_2(theta, phi):
    return 0.00119933458548895*(1.0 - cos(theta)**2)*(2.96652266375685e+20*cos(theta)**58 - 4.12072433881519e+21*cos(theta)**56 + 2.71192969306641e+22*cos(theta)**54 - 1.12486127268928e+23*cos(theta)**52 + 3.2999248840398e+23*cos(theta)**50 - 7.28361798729506e+23*cos(theta)**48 + 1.25625704734997e+24*cos(theta)**46 - 1.73594932444222e+24*cos(theta)**44 + 1.95500959633612e+24*cos(theta)**42 - 1.8158179745905e+24*cos(theta)**40 + 1.40231487146593e+24*cos(theta)**38 - 9.05259278825117e+23*cos(theta)**36 + 4.89959918951738e+23*cos(theta)**34 - 2.22564789094676e+23*cos(theta)**32 + 8.47865863217814e+22*cos(theta)**30 - 2.70199011355128e+22*cos(theta)**28 + 7.17241757670212e+21*cos(theta)**26 - 1.57608905505625e+21*cos(theta)**24 + 2.84314104049362e+20*cos(theta)**22 - 4.16465174606231e+19*cos(theta)**20 + 4.88446809723358e+18*cos(theta)**18 - 4.50466316381397e+17*cos(theta)**16 + 3.19102467330387e+16*cos(theta)**14 - 1.68338113200378e+15*cos(theta)**12 + 63415042643978.1*cos(theta)**10 - 1607705306467.05*cos(theta)**8 + 25092390513.4211*cos(theta)**6 - 208062939.580606*cos(theta)**4 + 685921.778837163*cos(theta)**2 - 375.436113211364)*sin(2*phi)

#@torch.jit.script
def Yl60_m_minus_1(theta, phi):
    return 0.0725374373175736*(1.0 - cos(theta)**2)**0.5*(5.02800451484212e+18*cos(theta)**59 - 7.22934094528981e+19*cos(theta)**57 + 4.93078126012074e+20*cos(theta)**55 - 2.1223797597911e+21*cos(theta)**53 + 6.47044094909765e+21*cos(theta)**51 - 1.48645265046838e+22*cos(theta)**49 + 2.67288733478718e+22*cos(theta)**47 - 3.85766516542715e+22*cos(theta)**45 + 4.54653394496772e+22*cos(theta)**43 - 4.42882432826952e+22*cos(theta)**41 + 3.59567915760496e+22*cos(theta)**39 - 2.44664669952734e+22*cos(theta)**37 + 1.39988548271925e+22*cos(theta)**35 - 6.74438754832352e+21*cos(theta)**33 + 2.73505117167037e+21*cos(theta)**31 - 9.31720728810785e+20*cos(theta)**29 + 2.65645095433412e+20*cos(theta)**27 - 6.30435622022499e+19*cos(theta)**25 + 1.23614827847549e+19*cos(theta)**23 - 1.98316749812491e+18*cos(theta)**21 + 2.57077268275452e+17*cos(theta)**19 - 2.64980186106704e+16*cos(theta)**17 + 2.12734978220258e+15*cos(theta)**15 - 129490856307983.0*cos(theta)**13 + 5765003876725.29*cos(theta)**11 - 178633922940.783*cos(theta)**9 + 3584627216.20301*cos(theta)**7 - 41612587.9161212*cos(theta)**5 + 228640.592945721*cos(theta)**3 - 375.436113211364*cos(theta))*sin(phi)

#@torch.jit.script
def Yl60_m0(theta, phi):
    return 8.16924713431039e+17*cos(theta)**60 - 1.21508969980919e+19*cos(theta)**58 + 8.58351826403673e+19*cos(theta)**56 - 3.83148351496132e+20*cos(theta)**54 + 1.21302055528975e+21*cos(theta)**52 - 2.89813559696253e+21*cos(theta)**50 + 5.42846499431055e+21*cos(theta)**48 - 8.17531176713257e+21*cos(theta)**46 + 1.00731519987883e+22*cos(theta)**44 - 1.02796135823665e+22*cos(theta)**42 + 8.76311613308672e+21*cos(theta)**40 - 6.2766121063431e+21*cos(theta)**38 + 3.79077174463849e+21*cos(theta)**36 - 1.93375400738644e+21*cos(theta)**34 + 8.33207371846229e+20*cos(theta)**32 - 3.02762532187348e+20*cos(theta)**30 + 9.2487149930826e+19*cos(theta)**28 - 2.36376894346533e+19*cos(theta)**26 + 5.02107782108649e+18*cos(theta)**24 - 8.78768217260539e+17*cos(theta)**22 + 1.25305838387151e+17*cos(theta)**20 - 1.43508796223982e+16*cos(theta)**18 + 1.29615382658024e+15*cos(theta)**16 - 90167222718625.6*cos(theta)**14 + 4683343189152.36*cos(theta)**12 - 174141211540.313*cos(theta)**10 + 4368090590.47608*cos(theta)**8 - 67610025.7232339*cos(theta)**6 + 557225.48672995*cos(theta)**4 - 1829.96875773383*cos(theta)**2 + 0.999982927723402

#@torch.jit.script
def Yl60_m1(theta, phi):
    return 0.0725374373175736*(1.0 - cos(theta)**2)**0.5*(5.02800451484212e+18*cos(theta)**59 - 7.22934094528981e+19*cos(theta)**57 + 4.93078126012074e+20*cos(theta)**55 - 2.1223797597911e+21*cos(theta)**53 + 6.47044094909765e+21*cos(theta)**51 - 1.48645265046838e+22*cos(theta)**49 + 2.67288733478718e+22*cos(theta)**47 - 3.85766516542715e+22*cos(theta)**45 + 4.54653394496772e+22*cos(theta)**43 - 4.42882432826952e+22*cos(theta)**41 + 3.59567915760496e+22*cos(theta)**39 - 2.44664669952734e+22*cos(theta)**37 + 1.39988548271925e+22*cos(theta)**35 - 6.74438754832352e+21*cos(theta)**33 + 2.73505117167037e+21*cos(theta)**31 - 9.31720728810785e+20*cos(theta)**29 + 2.65645095433412e+20*cos(theta)**27 - 6.30435622022499e+19*cos(theta)**25 + 1.23614827847549e+19*cos(theta)**23 - 1.98316749812491e+18*cos(theta)**21 + 2.57077268275452e+17*cos(theta)**19 - 2.64980186106704e+16*cos(theta)**17 + 2.12734978220258e+15*cos(theta)**15 - 129490856307983.0*cos(theta)**13 + 5765003876725.29*cos(theta)**11 - 178633922940.783*cos(theta)**9 + 3584627216.20301*cos(theta)**7 - 41612587.9161212*cos(theta)**5 + 228640.592945721*cos(theta)**3 - 375.436113211364*cos(theta))*cos(phi)

#@torch.jit.script
def Yl60_m2(theta, phi):
    return 0.00119933458548895*(1.0 - cos(theta)**2)*(2.96652266375685e+20*cos(theta)**58 - 4.12072433881519e+21*cos(theta)**56 + 2.71192969306641e+22*cos(theta)**54 - 1.12486127268928e+23*cos(theta)**52 + 3.2999248840398e+23*cos(theta)**50 - 7.28361798729506e+23*cos(theta)**48 + 1.25625704734997e+24*cos(theta)**46 - 1.73594932444222e+24*cos(theta)**44 + 1.95500959633612e+24*cos(theta)**42 - 1.8158179745905e+24*cos(theta)**40 + 1.40231487146593e+24*cos(theta)**38 - 9.05259278825117e+23*cos(theta)**36 + 4.89959918951738e+23*cos(theta)**34 - 2.22564789094676e+23*cos(theta)**32 + 8.47865863217814e+22*cos(theta)**30 - 2.70199011355128e+22*cos(theta)**28 + 7.17241757670212e+21*cos(theta)**26 - 1.57608905505625e+21*cos(theta)**24 + 2.84314104049362e+20*cos(theta)**22 - 4.16465174606231e+19*cos(theta)**20 + 4.88446809723358e+18*cos(theta)**18 - 4.50466316381397e+17*cos(theta)**16 + 3.19102467330387e+16*cos(theta)**14 - 1.68338113200378e+15*cos(theta)**12 + 63415042643978.1*cos(theta)**10 - 1607705306467.05*cos(theta)**8 + 25092390513.4211*cos(theta)**6 - 208062939.580606*cos(theta)**4 + 685921.778837163*cos(theta)**2 - 375.436113211364)*cos(2*phi)

#@torch.jit.script
def Yl60_m3(theta, phi):
    return 1.98406586901877e-5*(1.0 - cos(theta)**2)**1.5*(1.72058314497897e+22*cos(theta)**57 - 2.30760562973651e+23*cos(theta)**55 + 1.46444203425586e+24*cos(theta)**53 - 5.84927861798428e+24*cos(theta)**51 + 1.6499624420199e+25*cos(theta)**49 - 3.49613663390163e+25*cos(theta)**47 + 5.77878241780988e+25*cos(theta)**45 - 7.63817702754577e+25*cos(theta)**43 + 8.2110403046117e+25*cos(theta)**41 - 7.26327189836202e+25*cos(theta)**39 + 5.32879651157055e+25*cos(theta)**37 - 3.25893340377042e+25*cos(theta)**35 + 1.66586372443591e+25*cos(theta)**33 - 7.12207325102964e+24*cos(theta)**31 + 2.54359758965344e+24*cos(theta)**29 - 7.56557231794357e+23*cos(theta)**27 + 1.86482856994255e+23*cos(theta)**25 - 3.78261373213499e+22*cos(theta)**23 + 6.25491028908597e+21*cos(theta)**21 - 8.32930349212463e+20*cos(theta)**19 + 8.79204257502044e+19*cos(theta)**17 - 7.20746106210235e+18*cos(theta)**15 + 4.46743454262542e+17*cos(theta)**13 - 2.02005735840454e+16*cos(theta)**11 + 634150426439781.0*cos(theta)**9 - 12861642451736.4*cos(theta)**7 + 150554343080.527*cos(theta)**5 - 832251758.322424*cos(theta)**3 + 1371843.55767433*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl60_m4(theta, phi):
    return 3.28494930257968e-7*(1.0 - cos(theta)**2)**2*(9.80732392638015e+23*cos(theta)**56 - 1.26918309635508e+25*cos(theta)**54 + 7.76154278155606e+25*cos(theta)**52 - 2.98313209517198e+26*cos(theta)**50 + 8.08481596589751e+26*cos(theta)**48 - 1.64318421793376e+27*cos(theta)**46 + 2.60045208801444e+27*cos(theta)**44 - 3.28441612184468e+27*cos(theta)**42 + 3.3665265248908e+27*cos(theta)**40 - 2.83267604036119e+27*cos(theta)**38 + 1.9716547092811e+27*cos(theta)**36 - 1.14062669131965e+27*cos(theta)**34 + 5.4973502906385e+26*cos(theta)**32 - 2.20784270781919e+26*cos(theta)**30 + 7.37643300999499e+25*cos(theta)**28 - 2.04270452584476e+25*cos(theta)**26 + 4.66207142485638e+24*cos(theta)**24 - 8.70001158391049e+23*cos(theta)**22 + 1.31353116070805e+23*cos(theta)**20 - 1.58256766350368e+22*cos(theta)**18 + 1.49464723775348e+21*cos(theta)**16 - 1.08111915931535e+20*cos(theta)**14 + 5.80766490541305e+18*cos(theta)**12 - 2.22206309424499e+17*cos(theta)**10 + 5.70735383795803e+15*cos(theta)**8 - 90031497162154.9*cos(theta)**6 + 752771715402.633*cos(theta)**4 - 2496755274.96727*cos(theta)**2 + 1371843.55767433)*cos(4*phi)

#@torch.jit.script
def Yl60_m5(theta, phi):
    return 5.44475045102643e-9*(1.0 - cos(theta)**2)**2.5*(5.49210139877289e+25*cos(theta)**55 - 6.85358872031742e+26*cos(theta)**53 + 4.03600224640915e+27*cos(theta)**51 - 1.49156604758599e+28*cos(theta)**49 + 3.88071166363081e+28*cos(theta)**47 - 7.55864740249532e+28*cos(theta)**45 + 1.14419891872636e+29*cos(theta)**43 - 1.37945477117477e+29*cos(theta)**41 + 1.34661060995632e+29*cos(theta)**39 - 1.07641689533725e+29*cos(theta)**37 + 7.09795695341197e+28*cos(theta)**35 - 3.8781307504868e+28*cos(theta)**33 + 1.75915209300432e+28*cos(theta)**31 - 6.62352812345757e+27*cos(theta)**29 + 2.0654012427986e+27*cos(theta)**27 - 5.31103176719639e+26*cos(theta)**25 + 1.11889714196553e+26*cos(theta)**23 - 1.91400254846031e+25*cos(theta)**21 + 2.62706232141611e+24*cos(theta)**19 - 2.84862179430662e+23*cos(theta)**17 + 2.39143558040556e+22*cos(theta)**15 - 1.51356682304149e+21*cos(theta)**13 + 6.96919788649566e+19*cos(theta)**11 - 2.22206309424499e+18*cos(theta)**9 + 4.56588307036643e+16*cos(theta)**7 - 540188982972929.0*cos(theta)**5 + 3011086861610.53*cos(theta)**3 - 4993510549.93455*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl60_m6(theta, phi):
    return 9.03700800610182e-11*(1.0 - cos(theta)**2)**3*(3.02065576932509e+27*cos(theta)**54 - 3.63240202176824e+28*cos(theta)**52 + 2.05836114566867e+29*cos(theta)**50 - 7.30867363317135e+29*cos(theta)**48 + 1.82393448190648e+30*cos(theta)**46 - 3.40139133112289e+30*cos(theta)**44 + 4.92005535052333e+30*cos(theta)**42 - 5.65576456181654e+30*cos(theta)**40 + 5.25178137882964e+30*cos(theta)**38 - 3.98274251274783e+30*cos(theta)**36 + 2.48428493369419e+30*cos(theta)**34 - 1.27978314766064e+30*cos(theta)**32 + 5.4533714883134e+29*cos(theta)**30 - 1.92082315580269e+29*cos(theta)**28 + 5.57658335555621e+28*cos(theta)**26 - 1.3277579417991e+28*cos(theta)**24 + 2.57346342652072e+27*cos(theta)**22 - 4.01940535176665e+26*cos(theta)**20 + 4.99141841069061e+25*cos(theta)**18 - 4.84265705032126e+24*cos(theta)**16 + 3.58715337060834e+23*cos(theta)**14 - 1.96763686995394e+22*cos(theta)**12 + 7.66611767514523e+20*cos(theta)**10 - 1.99985678482049e+19*cos(theta)**8 + 3.1961181492565e+17*cos(theta)**6 - 2.70094491486465e+15*cos(theta)**4 + 9033260584831.59*cos(theta)**2 - 4993510549.93455)*cos(6*phi)

#@torch.jit.script
def Yl60_m7(theta, phi):
    return 1.502416642761e-12*(1.0 - cos(theta)**2)**3.5*(1.63115411543555e+29*cos(theta)**53 - 1.88884905131948e+30*cos(theta)**51 + 1.02918057283433e+31*cos(theta)**49 - 3.50816334392225e+31*cos(theta)**47 + 8.3900986167698e+31*cos(theta)**45 - 1.49661218569407e+32*cos(theta)**43 + 2.0664232472198e+32*cos(theta)**41 - 2.26230582472661e+32*cos(theta)**39 + 1.99567692395526e+32*cos(theta)**37 - 1.43378730458922e+32*cos(theta)**35 + 8.44656877456025e+31*cos(theta)**33 - 4.09530607251406e+31*cos(theta)**31 + 1.63601144649402e+31*cos(theta)**29 - 5.37830483624754e+30*cos(theta)**27 + 1.44991167244461e+30*cos(theta)**25 - 3.18661906031783e+29*cos(theta)**23 + 5.66161953834559e+28*cos(theta)**21 - 8.03881070353329e+27*cos(theta)**19 + 8.98455313924309e+26*cos(theta)**17 - 7.74825128051401e+25*cos(theta)**15 + 5.02201471885168e+24*cos(theta)**13 - 2.36116424394473e+23*cos(theta)**11 + 7.66611767514523e+21*cos(theta)**9 - 1.5998854278564e+20*cos(theta)**7 + 1.9176708895539e+18*cos(theta)**5 - 1.08037796594586e+16*cos(theta)**3 + 18066521169663.2*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl60_m8(theta, phi):
    return 2.50263776961367e-14*(1.0 - cos(theta)**2)**4*(8.6451168118084e+30*cos(theta)**52 - 9.63313016172936e+31*cos(theta)**50 + 5.04298480688823e+32*cos(theta)**48 - 1.64883677164346e+33*cos(theta)**46 + 3.77554437754641e+33*cos(theta)**44 - 6.43543239848451e+33*cos(theta)**42 + 8.47233531360117e+33*cos(theta)**40 - 8.8229927164338e+33*cos(theta)**38 + 7.38400461863448e+33*cos(theta)**36 - 5.01825556606227e+33*cos(theta)**34 + 2.78736769560488e+33*cos(theta)**32 - 1.26954488247936e+33*cos(theta)**30 + 4.74443319483265e+32*cos(theta)**28 - 1.45214230578684e+32*cos(theta)**26 + 3.62477918111154e+31*cos(theta)**24 - 7.32922383873102e+30*cos(theta)**22 + 1.18894010305257e+30*cos(theta)**20 - 1.52737403367133e+29*cos(theta)**18 + 1.52737403367133e+28*cos(theta)**16 - 1.1622376920771e+27*cos(theta)**14 + 6.52861913450718e+25*cos(theta)**12 - 2.5972806683392e+24*cos(theta)**10 + 6.89950590763071e+22*cos(theta)**8 - 1.11991979949948e+21*cos(theta)**6 + 9.58835444776949e+18*cos(theta)**4 - 3.24113389783758e+16*cos(theta)**2 + 18066521169663.2)*cos(8*phi)

#@torch.jit.script
def Yl60_m9(theta, phi):
    return 4.17803214878475e-16*(1.0 - cos(theta)**2)**4.5*(4.49546074214037e+32*cos(theta)**51 - 4.81656508086468e+33*cos(theta)**49 + 2.42063270730635e+34*cos(theta)**47 - 7.5846491495599e+34*cos(theta)**45 + 1.66123952612042e+35*cos(theta)**43 - 2.7028816073635e+35*cos(theta)**41 + 3.38893412544047e+35*cos(theta)**39 - 3.35273723224484e+35*cos(theta)**37 + 2.65824166270841e+35*cos(theta)**35 - 1.70620689246117e+35*cos(theta)**33 + 8.91957662593562e+34*cos(theta)**31 - 3.80863464743808e+34*cos(theta)**29 + 1.32844129455314e+34*cos(theta)**27 - 3.77556999504578e+33*cos(theta)**25 + 8.69947003466769e+32*cos(theta)**23 - 1.61242924452082e+32*cos(theta)**21 + 2.37788020610515e+31*cos(theta)**19 - 2.74927326060839e+30*cos(theta)**17 + 2.44379845387412e+29*cos(theta)**15 - 1.62713276890794e+28*cos(theta)**13 + 7.83434296140861e+26*cos(theta)**11 - 2.5972806683392e+25*cos(theta)**9 + 5.51960472610456e+23*cos(theta)**7 - 6.71951879699686e+21*cos(theta)**5 + 3.8353417791078e+19*cos(theta)**3 - 6.48226779567515e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl60_m10(theta, phi):
    return 6.99258363353129e-18*(1.0 - cos(theta)**2)**5*(2.29268497849159e+34*cos(theta)**50 - 2.36011688962369e+35*cos(theta)**48 + 1.13769737243399e+36*cos(theta)**46 - 3.41309211730196e+36*cos(theta)**44 + 7.14332996231781e+36*cos(theta)**42 - 1.10818145901903e+37*cos(theta)**40 + 1.32168430892178e+37*cos(theta)**38 - 1.24051277593059e+37*cos(theta)**36 + 9.30384581947944e+36*cos(theta)**34 - 5.63048274512186e+36*cos(theta)**32 + 2.76506875404004e+36*cos(theta)**30 - 1.10450404775704e+36*cos(theta)**28 + 3.58679149529349e+35*cos(theta)**26 - 9.43892498761444e+34*cos(theta)**24 + 2.00087810797357e+34*cos(theta)**22 - 3.38610141349373e+33*cos(theta)**20 + 4.51797239159978e+32*cos(theta)**18 - 4.67376454303425e+31*cos(theta)**16 + 3.66569768081118e+30*cos(theta)**14 - 2.11527259958033e+29*cos(theta)**12 + 8.61777725754948e+27*cos(theta)**10 - 2.33755260150528e+26*cos(theta)**8 + 3.8637233082732e+24*cos(theta)**6 - 3.35975939849843e+22*cos(theta)**4 + 1.15060253373234e+20*cos(theta)**2 - 6.48226779567515e+16)*cos(10*phi)

#@torch.jit.script
def Yl60_m11(theta, phi):
    return 1.173609166318e-19*(1.0 - cos(theta)**2)**5.5*(1.14634248924579e+36*cos(theta)**49 - 1.13285610701937e+37*cos(theta)**47 + 5.23340791319633e+37*cos(theta)**45 - 1.50176053161286e+38*cos(theta)**43 + 3.00019858417348e+38*cos(theta)**41 - 4.43272583607613e+38*cos(theta)**39 + 5.02240037390277e+38*cos(theta)**37 - 4.46584599335013e+38*cos(theta)**35 + 3.16330757862301e+38*cos(theta)**33 - 1.801754478439e+38*cos(theta)**31 + 8.29520626212013e+37*cos(theta)**29 - 3.09261133371972e+37*cos(theta)**27 + 9.32565788776307e+36*cos(theta)**25 - 2.26534199702747e+36*cos(theta)**23 + 4.40193183754185e+35*cos(theta)**21 - 6.77220282698746e+34*cos(theta)**19 + 8.1323503048796e+33*cos(theta)**17 - 7.47802326885481e+32*cos(theta)**15 + 5.13197675313565e+31*cos(theta)**13 - 2.53832711949639e+30*cos(theta)**11 + 8.61777725754948e+28*cos(theta)**9 - 1.87004208120423e+27*cos(theta)**7 + 2.31823398496392e+25*cos(theta)**5 - 1.34390375939937e+23*cos(theta)**3 + 2.30120506746468e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl60_m12(theta, phi):
    return 1.97587380944321e-21*(1.0 - cos(theta)**2)**6*(5.61707819730439e+37*cos(theta)**48 - 5.32442370299105e+38*cos(theta)**46 + 2.35503356093835e+39*cos(theta)**44 - 6.4575702859353e+39*cos(theta)**42 + 1.23008141951113e+40*cos(theta)**40 - 1.72876307606969e+40*cos(theta)**38 + 1.85828813834403e+40*cos(theta)**36 - 1.56304609767255e+40*cos(theta)**34 + 1.04389150094559e+40*cos(theta)**32 - 5.58543888316089e+39*cos(theta)**30 + 2.40560981601484e+39*cos(theta)**28 - 8.35005060104324e+38*cos(theta)**26 + 2.33141447194077e+38*cos(theta)**24 - 5.21028659316317e+37*cos(theta)**22 + 9.24405685883788e+36*cos(theta)**20 - 1.28671853712762e+36*cos(theta)**18 + 1.38249955182953e+35*cos(theta)**16 - 1.12170349032822e+34*cos(theta)**14 + 6.67156977907635e+32*cos(theta)**12 - 2.79215983144603e+31*cos(theta)**10 + 7.75599953179453e+29*cos(theta)**8 - 1.30902945684296e+28*cos(theta)**6 + 1.15911699248196e+26*cos(theta)**4 - 4.03171127819812e+23*cos(theta)**2 + 2.30120506746468e+20)*cos(12*phi)

#@torch.jit.script
def Yl60_m13(theta, phi):
    return 3.33792947010339e-23*(1.0 - cos(theta)**2)**6.5*(2.69619753470611e+39*cos(theta)**47 - 2.44923490337588e+40*cos(theta)**45 + 1.03621476681287e+41*cos(theta)**43 - 2.71217952009283e+41*cos(theta)**41 + 4.92032567804451e+41*cos(theta)**39 - 6.56929968906483e+41*cos(theta)**37 + 6.6898372980385e+41*cos(theta)**35 - 5.31435673208666e+41*cos(theta)**33 + 3.3404528030259e+41*cos(theta)**31 - 1.67563166494827e+41*cos(theta)**29 + 6.73570748484154e+40*cos(theta)**27 - 2.17101315627124e+40*cos(theta)**25 + 5.59539473265784e+39*cos(theta)**23 - 1.1462630504959e+39*cos(theta)**21 + 1.84881137176758e+38*cos(theta)**19 - 2.31609336682971e+37*cos(theta)**17 + 2.21199928292725e+36*cos(theta)**15 - 1.57038488645951e+35*cos(theta)**13 + 8.00588373489162e+33*cos(theta)**11 - 2.79215983144603e+32*cos(theta)**9 + 6.20479962543562e+30*cos(theta)**7 - 7.85417674105775e+28*cos(theta)**5 + 4.63646796992783e+26*cos(theta)**3 - 8.06342255639623e+23*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl60_m14(theta, phi):
    return 5.65994703365348e-25*(1.0 - cos(theta)**2)**7*(1.26721284131187e+41*cos(theta)**46 - 1.10215570651915e+42*cos(theta)**44 + 4.45572349729536e+42*cos(theta)**42 - 1.11199360323806e+43*cos(theta)**40 + 1.91892701443736e+43*cos(theta)**38 - 2.43064088495399e+43*cos(theta)**36 + 2.34144305431347e+43*cos(theta)**34 - 1.7537377215886e+43*cos(theta)**32 + 1.03554036893803e+43*cos(theta)**30 - 4.85933182834997e+42*cos(theta)**28 + 1.81864102090722e+42*cos(theta)**26 - 5.4275328906781e+41*cos(theta)**24 + 1.2869407885113e+41*cos(theta)**22 - 2.40715240604138e+40*cos(theta)**20 + 3.5127416063584e+39*cos(theta)**18 - 3.93735872361051e+38*cos(theta)**16 + 3.31799892439088e+37*cos(theta)**14 - 2.04150035239736e+36*cos(theta)**12 + 8.80647210838078e+34*cos(theta)**10 - 2.51294384830143e+33*cos(theta)**8 + 4.34335973780494e+31*cos(theta)**6 - 3.92708837052888e+29*cos(theta)**4 + 1.39094039097835e+27*cos(theta)**2 - 8.06342255639623e+23)*cos(14*phi)

#@torch.jit.script
def Yl60_m15(theta, phi):
    return 9.63613375229227e-27*(1.0 - cos(theta)**2)**7.5*(5.8291790700346e+42*cos(theta)**45 - 4.84948510868425e+43*cos(theta)**43 + 1.87140386886405e+44*cos(theta)**41 - 4.44797441295224e+44*cos(theta)**39 + 7.29192265486196e+44*cos(theta)**37 - 8.75030718583435e+44*cos(theta)**35 + 7.96090638466581e+44*cos(theta)**33 - 5.61196070908351e+44*cos(theta)**31 + 3.10662110681409e+44*cos(theta)**29 - 1.36061291193799e+44*cos(theta)**27 + 4.72846665435876e+43*cos(theta)**25 - 1.30260789376275e+43*cos(theta)**23 + 2.83126973472487e+42*cos(theta)**21 - 4.81430481208277e+41*cos(theta)**19 + 6.32293489144511e+40*cos(theta)**17 - 6.29977395777681e+39*cos(theta)**15 + 4.64519849414723e+38*cos(theta)**13 - 2.44980042287684e+37*cos(theta)**11 + 8.80647210838078e+35*cos(theta)**9 - 2.01035507864114e+34*cos(theta)**7 + 2.60601584268296e+32*cos(theta)**5 - 1.57083534821155e+30*cos(theta)**3 + 2.7818807819567e+27*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl60_m16(theta, phi):
    return 1.64774410460816e-28*(1.0 - cos(theta)**2)**8*(2.62313058151557e+44*cos(theta)**44 - 2.08527859673423e+45*cos(theta)**42 + 7.67275586234261e+45*cos(theta)**40 - 1.73471002105137e+46*cos(theta)**38 + 2.69801138229893e+46*cos(theta)**36 - 3.06260751504202e+46*cos(theta)**34 + 2.62709910693972e+46*cos(theta)**32 - 1.73970781981589e+46*cos(theta)**30 + 9.00920120976085e+45*cos(theta)**28 - 3.67365486223258e+45*cos(theta)**26 + 1.18211666358969e+45*cos(theta)**24 - 2.99599815565431e+44*cos(theta)**22 + 5.94566644292222e+43*cos(theta)**20 - 9.14717914295726e+42*cos(theta)**18 + 1.07489893154567e+42*cos(theta)**16 - 9.44966093666522e+40*cos(theta)**14 + 6.0387580423914e+39*cos(theta)**12 - 2.69478046516452e+38*cos(theta)**10 + 7.9258248975427e+36*cos(theta)**8 - 1.4072485550488e+35*cos(theta)**6 + 1.30300792134148e+33*cos(theta)**4 - 4.71250604463465e+30*cos(theta)**2 + 2.7818807819567e+27)*cos(16*phi)

#@torch.jit.script
def Yl60_m17(theta, phi):
    return 2.83085787341947e-30*(1.0 - cos(theta)**2)**8.5*(1.15417745586685e+46*cos(theta)**43 - 8.75817010628375e+46*cos(theta)**41 + 3.06910234493704e+47*cos(theta)**39 - 6.59189807999521e+47*cos(theta)**37 + 9.71284097627613e+47*cos(theta)**35 - 1.04128655511429e+48*cos(theta)**33 + 8.4067171422071e+47*cos(theta)**31 - 5.21912345944766e+47*cos(theta)**29 + 2.52257633873304e+47*cos(theta)**27 - 9.5515026418047e+46*cos(theta)**25 + 2.83707999261526e+46*cos(theta)**23 - 6.59119594243949e+45*cos(theta)**21 + 1.18913328858444e+45*cos(theta)**19 - 1.64649224573231e+44*cos(theta)**17 + 1.71983829047307e+43*cos(theta)**15 - 1.32295253113313e+42*cos(theta)**13 + 7.24650965086968e+40*cos(theta)**11 - 2.69478046516452e+39*cos(theta)**9 + 6.34065991803416e+37*cos(theta)**7 - 8.4434913302928e+35*cos(theta)**5 + 5.21203168536592e+33*cos(theta)**3 - 9.4250120892693e+30*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl60_m18(theta, phi):
    return 4.88806009407684e-32*(1.0 - cos(theta)**2)**9*(4.96296306022746e+47*cos(theta)**42 - 3.59084974357634e+48*cos(theta)**40 + 1.19694991452545e+49*cos(theta)**38 - 2.43900228959823e+49*cos(theta)**36 + 3.39949434169665e+49*cos(theta)**34 - 3.43624563187715e+49*cos(theta)**32 + 2.6060823140842e+49*cos(theta)**30 - 1.51354580323982e+49*cos(theta)**28 + 6.8109561145792e+48*cos(theta)**26 - 2.38787566045118e+48*cos(theta)**24 + 6.5252839830151e+47*cos(theta)**22 - 1.38415114791229e+47*cos(theta)**20 + 2.25935324831044e+46*cos(theta)**18 - 2.79903681774492e+45*cos(theta)**16 + 2.57975743570961e+44*cos(theta)**14 - 1.71983829047307e+43*cos(theta)**12 + 7.97116061595665e+41*cos(theta)**10 - 2.42530241864807e+40*cos(theta)**8 + 4.43846194262391e+38*cos(theta)**6 - 4.2217456651464e+36*cos(theta)**4 + 1.56360950560978e+34*cos(theta)**2 - 9.4250120892693e+30)*cos(18*phi)

#@torch.jit.script
def Yl60_m19(theta, phi):
    return 8.48590851998793e-34*(1.0 - cos(theta)**2)**9.5*(2.08444448529553e+49*cos(theta)**41 - 1.43633989743054e+50*cos(theta)**39 + 4.5484096751967e+50*cos(theta)**37 - 8.78040824255362e+50*cos(theta)**35 + 1.15582807617686e+51*cos(theta)**33 - 1.09959860220069e+51*cos(theta)**31 + 7.8182469422526e+50*cos(theta)**29 - 4.2379282490715e+50*cos(theta)**27 + 1.77084858979059e+50*cos(theta)**25 - 5.73090158508282e+49*cos(theta)**23 + 1.43556247626332e+49*cos(theta)**21 - 2.76830229582459e+48*cos(theta)**19 + 4.0668358469588e+47*cos(theta)**17 - 4.47845890839188e+46*cos(theta)**15 + 3.61166040999345e+45*cos(theta)**13 - 2.06380594856768e+44*cos(theta)**11 + 7.97116061595665e+42*cos(theta)**9 - 1.94024193491845e+41*cos(theta)**7 + 2.66307716557435e+39*cos(theta)**5 - 1.68869826605856e+37*cos(theta)**3 + 3.12721901121955e+34*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl60_m20(theta, phi):
    return 1.48170389937219e-35*(1.0 - cos(theta)**2)**10*(8.54622238971169e+50*cos(theta)**40 - 5.60172559997909e+51*cos(theta)**38 + 1.68291157982278e+52*cos(theta)**36 - 3.07314288489377e+52*cos(theta)**34 + 3.81423265138364e+52*cos(theta)**32 - 3.40875566682213e+52*cos(theta)**30 + 2.26729161325325e+52*cos(theta)**28 - 1.14424062724931e+52*cos(theta)**26 + 4.42712147447648e+51*cos(theta)**24 - 1.31810736456905e+51*cos(theta)**22 + 3.01468120015297e+50*cos(theta)**20 - 5.25977436206671e+49*cos(theta)**18 + 6.91362093982996e+48*cos(theta)**16 - 6.71768836258781e+47*cos(theta)**14 + 4.69515853299148e+46*cos(theta)**12 - 2.27018654342445e+45*cos(theta)**10 + 7.17404455436098e+43*cos(theta)**8 - 1.35816935444292e+42*cos(theta)**6 + 1.33153858278717e+40*cos(theta)**4 - 5.06609479817568e+37*cos(theta)**2 + 3.12721901121955e+34)*cos(20*phi)

#@torch.jit.script
def Yl60_m21(theta, phi):
    return 2.60308841109392e-37*(1.0 - cos(theta)**2)**10.5*(3.41848895588468e+52*cos(theta)**39 - 2.12865572799205e+53*cos(theta)**37 + 6.058481687362e+53*cos(theta)**35 - 1.04486858086388e+54*cos(theta)**33 + 1.22055444844276e+54*cos(theta)**31 - 1.02262670004664e+54*cos(theta)**29 + 6.34841651710911e+53*cos(theta)**27 - 2.97502563084819e+53*cos(theta)**25 + 1.06250915387436e+53*cos(theta)**23 - 2.89983620205191e+52*cos(theta)**21 + 6.02936240030595e+51*cos(theta)**19 - 9.46759385172008e+50*cos(theta)**17 + 1.10617935037279e+50*cos(theta)**15 - 9.40476370762294e+48*cos(theta)**13 + 5.63419023958978e+47*cos(theta)**11 - 2.27018654342445e+46*cos(theta)**9 + 5.73923564348879e+44*cos(theta)**7 - 8.1490161266575e+42*cos(theta)**5 + 5.3261543311487e+40*cos(theta)**3 - 1.01321895963514e+38*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl60_m22(theta, phi):
    return 4.60309235997469e-39*(1.0 - cos(theta)**2)**11*(1.33321069279502e+54*cos(theta)**38 - 7.8760261935706e+54*cos(theta)**36 + 2.1204685905767e+55*cos(theta)**34 - 3.44806631685081e+55*cos(theta)**32 + 3.78371879017257e+55*cos(theta)**30 - 2.96561743013526e+55*cos(theta)**28 + 1.71407245961946e+55*cos(theta)**26 - 7.43756407712049e+54*cos(theta)**24 + 2.44377105391102e+54*cos(theta)**22 - 6.08965602430901e+53*cos(theta)**20 + 1.14557885605813e+53*cos(theta)**18 - 1.60949095479241e+52*cos(theta)**16 + 1.65926902555919e+51*cos(theta)**14 - 1.22261928199098e+50*cos(theta)**12 + 6.19760926354876e+48*cos(theta)**10 - 2.04316788908201e+47*cos(theta)**8 + 4.01746495044215e+45*cos(theta)**6 - 4.07450806332875e+43*cos(theta)**4 + 1.59784629934461e+41*cos(theta)**2 - 1.01321895963514e+38)*cos(22*phi)

#@torch.jit.script
def Yl60_m23(theta, phi):
    return 8.19631884415083e-41*(1.0 - cos(theta)**2)**11.5*(5.06620063262109e+55*cos(theta)**37 - 2.83536942968542e+56*cos(theta)**35 + 7.20959320796078e+56*cos(theta)**33 - 1.10338122139226e+57*cos(theta)**31 + 1.13511563705177e+57*cos(theta)**29 - 8.30372880437872e+56*cos(theta)**27 + 4.4565883950106e+56*cos(theta)**25 - 1.78501537850892e+56*cos(theta)**23 + 5.37629631860424e+55*cos(theta)**21 - 1.2179312048618e+55*cos(theta)**19 + 2.06204194090463e+54*cos(theta)**17 - 2.57518552766786e+53*cos(theta)**15 + 2.32297663578287e+52*cos(theta)**13 - 1.46714313838918e+51*cos(theta)**11 + 6.19760926354876e+49*cos(theta)**9 - 1.63453431126561e+48*cos(theta)**7 + 2.41047897026529e+46*cos(theta)**5 - 1.6298032253315e+44*cos(theta)**3 + 3.19569259868922e+41*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl60_m24(theta, phi):
    return 1.4702065031827e-42*(1.0 - cos(theta)**2)**12*(1.8744942340698e+57*cos(theta)**36 - 9.92379300389896e+57*cos(theta)**34 + 2.37916575862706e+58*cos(theta)**32 - 3.420481786316e+58*cos(theta)**30 + 3.29183534745013e+58*cos(theta)**28 - 2.24200677718225e+58*cos(theta)**26 + 1.11414709875265e+58*cos(theta)**24 - 4.10553537057051e+57*cos(theta)**22 + 1.12902222690689e+57*cos(theta)**20 - 2.31406928923742e+56*cos(theta)**18 + 3.50547129953788e+55*cos(theta)**16 - 3.86277829150179e+54*cos(theta)**14 + 3.01986962651773e+53*cos(theta)**12 - 1.6138574522281e+52*cos(theta)**10 + 5.57784833719388e+50*cos(theta)**8 - 1.14417401788592e+49*cos(theta)**6 + 1.20523948513264e+47*cos(theta)**4 - 4.8894096759945e+44*cos(theta)**2 + 3.19569259868922e+41)*cos(24*phi)

#@torch.jit.script
def Yl60_m25(theta, phi):
    return 2.65777141519491e-44*(1.0 - cos(theta)**2)**12.5*(6.74817924265129e+58*cos(theta)**35 - 3.37408962132565e+59*cos(theta)**33 + 7.61333042760658e+59*cos(theta)**31 - 1.0261445358948e+60*cos(theta)**29 + 9.21713897286037e+59*cos(theta)**27 - 5.82921762067386e+59*cos(theta)**25 + 2.67395303700636e+59*cos(theta)**23 - 9.03217781525512e+58*cos(theta)**21 + 2.25804445381378e+58*cos(theta)**19 - 4.16532472062736e+57*cos(theta)**17 + 5.6087540792606e+56*cos(theta)**15 - 5.40788960810251e+55*cos(theta)**13 + 3.62384355182127e+54*cos(theta)**11 - 1.6138574522281e+53*cos(theta)**9 + 4.4622786697551e+51*cos(theta)**7 - 6.86504410731555e+49*cos(theta)**5 + 4.82095794053058e+47*cos(theta)**3 - 9.77881935198901e+44*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl60_m26(theta, phi):
    return 4.84433734413125e-46*(1.0 - cos(theta)**2)**13*(2.36186273492795e+60*cos(theta)**34 - 1.11344957503746e+61*cos(theta)**32 + 2.36013243255804e+61*cos(theta)**30 - 2.97581915409492e+61*cos(theta)**28 + 2.4886275226723e+61*cos(theta)**26 - 1.45730440516846e+61*cos(theta)**24 + 6.15009198511462e+60*cos(theta)**22 - 1.89675734120358e+60*cos(theta)**20 + 4.29028446224618e+59*cos(theta)**18 - 7.08105202506651e+58*cos(theta)**16 + 8.41313111889091e+57*cos(theta)**14 - 7.03025649053326e+56*cos(theta)**12 + 3.9862279070034e+55*cos(theta)**10 - 1.45247170700529e+54*cos(theta)**8 + 3.12359506882857e+52*cos(theta)**6 - 3.43252205365777e+50*cos(theta)**4 + 1.44628738215917e+48*cos(theta)**2 - 9.77881935198901e+44)*cos(26*phi)

#@torch.jit.script
def Yl60_m27(theta, phi):
    return 8.90707878111168e-48*(1.0 - cos(theta)**2)**13.5*(8.03033329875504e+61*cos(theta)**33 - 3.56303864011988e+62*cos(theta)**31 + 7.08039729767412e+62*cos(theta)**29 - 8.33229363146578e+62*cos(theta)**27 + 6.47043155894798e+62*cos(theta)**25 - 3.49753057240432e+62*cos(theta)**23 + 1.35302023672522e+62*cos(theta)**21 - 3.79351468240715e+61*cos(theta)**19 + 7.72251203204313e+60*cos(theta)**17 - 1.13296832401064e+60*cos(theta)**15 + 1.17783835664473e+59*cos(theta)**13 - 8.43630778863992e+57*cos(theta)**11 + 3.9862279070034e+56*cos(theta)**9 - 1.16197736560423e+55*cos(theta)**7 + 1.87415704129714e+53*cos(theta)**5 - 1.37300882146311e+51*cos(theta)**3 + 2.89257476431835e+48*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl60_m28(theta, phi):
    return 1.65286349337081e-49*(1.0 - cos(theta)**2)**14*(2.65000998858916e+63*cos(theta)**32 - 1.10454197843716e+64*cos(theta)**30 + 2.0533152163255e+64*cos(theta)**28 - 2.24971928049576e+64*cos(theta)**26 + 1.617607889737e+64*cos(theta)**24 - 8.04432031652993e+63*cos(theta)**22 + 2.84134249712296e+63*cos(theta)**20 - 7.20767789657359e+62*cos(theta)**18 + 1.31282704544733e+62*cos(theta)**16 - 1.69945248601596e+61*cos(theta)**14 + 1.53118986363815e+60*cos(theta)**12 - 9.27993856750391e+58*cos(theta)**10 + 3.58760511630306e+57*cos(theta)**8 - 8.1338415592296e+55*cos(theta)**6 + 9.37078520648572e+53*cos(theta)**4 - 4.11902646438933e+51*cos(theta)**2 + 2.89257476431835e+48)*cos(28*phi)

#@torch.jit.script
def Yl60_m29(theta, phi):
    return 3.09718391466457e-51*(1.0 - cos(theta)**2)**14.5*(8.48003196348532e+64*cos(theta)**31 - 3.31362593531149e+65*cos(theta)**29 + 5.74928260571139e+65*cos(theta)**27 - 5.84927012928898e+65*cos(theta)**25 + 3.88225893536879e+65*cos(theta)**23 - 1.76975046963658e+65*cos(theta)**21 + 5.68268499424591e+64*cos(theta)**19 - 1.29738202138325e+64*cos(theta)**17 + 2.10052327271573e+63*cos(theta)**15 - 2.37923348042235e+62*cos(theta)**13 + 1.83742783636577e+61*cos(theta)**11 - 9.27993856750391e+59*cos(theta)**9 + 2.87008409304245e+58*cos(theta)**7 - 4.88030493553776e+56*cos(theta)**5 + 3.74831408259429e+54*cos(theta)**3 - 8.23805292877866e+51*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl60_m30(theta, phi):
    return 5.8636075239113e-53*(1.0 - cos(theta)**2)**15*(2.62880990868045e+66*cos(theta)**30 - 9.60951521240332e+66*cos(theta)**28 + 1.55230630354207e+67*cos(theta)**26 - 1.46231753232224e+67*cos(theta)**24 + 8.92919555134822e+66*cos(theta)**22 - 3.71647598623683e+66*cos(theta)**20 + 1.07971014890672e+66*cos(theta)**18 - 2.20554943635152e+65*cos(theta)**16 + 3.1507849090736e+64*cos(theta)**14 - 3.09300352454905e+63*cos(theta)**12 + 2.02117062000235e+62*cos(theta)**10 - 8.35194471075352e+60*cos(theta)**8 + 2.00905886512971e+59*cos(theta)**6 - 2.44015246776888e+57*cos(theta)**4 + 1.12449422477829e+55*cos(theta)**2 - 8.23805292877866e+51)*cos(30*phi)

#@torch.jit.script
def Yl60_m31(theta, phi):
    return 1.12223438154577e-54*(1.0 - cos(theta)**2)**15.5*(7.88642972604135e+67*cos(theta)**29 - 2.69066425947293e+68*cos(theta)**27 + 4.03599638920939e+68*cos(theta)**25 - 3.50956207757339e+68*cos(theta)**23 + 1.96442302129661e+68*cos(theta)**21 - 7.43295197247365e+67*cos(theta)**19 + 1.9434782680321e+67*cos(theta)**17 - 3.52887909816243e+66*cos(theta)**15 + 4.41109887270303e+65*cos(theta)**13 - 3.71160422945886e+64*cos(theta)**11 + 2.02117062000235e+63*cos(theta)**9 - 6.68155576860281e+61*cos(theta)**7 + 1.20543531907783e+60*cos(theta)**5 - 9.76060987107553e+57*cos(theta)**3 + 2.24898844955657e+55*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl60_m32(theta, phi):
    return 2.17265443940271e-56*(1.0 - cos(theta)**2)**16*(2.28706462055199e+69*cos(theta)**28 - 7.26479350057691e+69*cos(theta)**26 + 1.00899909730235e+70*cos(theta)**24 - 8.07199277841879e+69*cos(theta)**22 + 4.12528834472288e+69*cos(theta)**20 - 1.41226087476999e+69*cos(theta)**18 + 3.30391305565457e+68*cos(theta)**16 - 5.29331864724364e+67*cos(theta)**14 + 5.73442853451394e+66*cos(theta)**12 - 4.08276465240475e+65*cos(theta)**10 + 1.81905355800212e+64*cos(theta)**8 - 4.67708903802197e+62*cos(theta)**6 + 6.02717659538914e+60*cos(theta)**4 - 2.92818296132266e+58*cos(theta)**2 + 2.24898844955657e+55)*cos(32*phi)

#@torch.jit.script
def Yl60_m33(theta, phi):
    return 4.25765205818926e-58*(1.0 - cos(theta)**2)**16.5*(6.40378093754557e+70*cos(theta)**27 - 1.88884631015e+71*cos(theta)**25 + 2.42159783352564e+71*cos(theta)**23 - 1.77583841125213e+71*cos(theta)**21 + 8.25057668944575e+70*cos(theta)**19 - 2.54206957458599e+70*cos(theta)**17 + 5.28626088904732e+69*cos(theta)**15 - 7.4106461061411e+68*cos(theta)**13 + 6.88131424141673e+67*cos(theta)**11 - 4.08276465240475e+66*cos(theta)**9 + 1.45524284640169e+65*cos(theta)**7 - 2.80625342281318e+63*cos(theta)**5 + 2.41087063815565e+61*cos(theta)**3 - 5.85636592264531e+58*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl60_m34(theta, phi):
    return 8.4513163486194e-60*(1.0 - cos(theta)**2)**17*(1.7290208531373e+72*cos(theta)**26 - 4.72211577537499e+72*cos(theta)**24 + 5.56967501710896e+72*cos(theta)**22 - 3.72926066362948e+72*cos(theta)**20 + 1.56760957099469e+72*cos(theta)**18 - 4.32151827679618e+71*cos(theta)**16 + 7.92939133357097e+70*cos(theta)**14 - 9.63383993798343e+69*cos(theta)**12 + 7.56944566555841e+68*cos(theta)**10 - 3.67448818716428e+67*cos(theta)**8 + 1.01866999248119e+66*cos(theta)**6 - 1.40312671140659e+64*cos(theta)**4 + 7.23261191446696e+61*cos(theta)**2 - 5.85636592264531e+58)*cos(34*phi)

#@torch.jit.script
def Yl60_m35(theta, phi):
    return 1.7004970459894e-61*(1.0 - cos(theta)**2)**17.5*(4.49545421815699e+73*cos(theta)**25 - 1.13330778609e+74*cos(theta)**23 + 1.22532850376397e+74*cos(theta)**21 - 7.45852132725896e+73*cos(theta)**19 + 2.82169722779045e+73*cos(theta)**17 - 6.91442924287389e+72*cos(theta)**15 + 1.11011478669994e+72*cos(theta)**13 - 1.15606079255801e+71*cos(theta)**11 + 7.56944566555841e+69*cos(theta)**9 - 2.93959054973142e+68*cos(theta)**7 + 6.11201995488711e+66*cos(theta)**5 - 5.61250684562636e+64*cos(theta)**3 + 1.44652238289339e+62*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl60_m36(theta, phi):
    return 3.47112505982011e-63*(1.0 - cos(theta)**2)**18*(1.12386355453925e+75*cos(theta)**24 - 2.606607908007e+75*cos(theta)**22 + 2.57318985790434e+75*cos(theta)**20 - 1.4171190521792e+75*cos(theta)**18 + 4.79688528724376e+74*cos(theta)**16 - 1.03716438643108e+74*cos(theta)**14 + 1.44314922270992e+73*cos(theta)**12 - 1.27166687181381e+72*cos(theta)**10 + 6.81250109900257e+70*cos(theta)**8 - 2.05771338481199e+69*cos(theta)**6 + 3.05600997744356e+67*cos(theta)**4 - 1.68375205368791e+65*cos(theta)**2 + 1.44652238289339e+62)*cos(36*phi)

#@torch.jit.script
def Yl60_m37(theta, phi):
    return 7.19413814360994e-65*(1.0 - cos(theta)**2)**18.5*(2.6972725308942e+76*cos(theta)**23 - 5.73453739761539e+76*cos(theta)**21 + 5.14637971580868e+76*cos(theta)**19 - 2.55081429392256e+76*cos(theta)**17 + 7.67501645959002e+75*cos(theta)**15 - 1.45203014100352e+75*cos(theta)**13 + 1.7317790672519e+74*cos(theta)**11 - 1.27166687181381e+73*cos(theta)**9 + 5.45000087920205e+71*cos(theta)**7 - 1.2346280308872e+70*cos(theta)**5 + 1.22240399097742e+68*cos(theta)**3 - 3.36750410737582e+65*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl60_m38(theta, phi):
    return 1.51531114391773e-66*(1.0 - cos(theta)**2)**19*(6.20372682105665e+77*cos(theta)**22 - 1.20425285349923e+78*cos(theta)**20 + 9.7781214600365e+77*cos(theta)**18 - 4.33638429966836e+77*cos(theta)**16 + 1.1512524689385e+77*cos(theta)**14 - 1.88763918330457e+76*cos(theta)**12 + 1.90495697397709e+75*cos(theta)**10 - 1.14450018463243e+74*cos(theta)**8 + 3.81500061544144e+72*cos(theta)**6 - 6.17314015443598e+70*cos(theta)**4 + 3.66721197293227e+68*cos(theta)**2 - 3.36750410737582e+65)*cos(38*phi)

#@torch.jit.script
def Yl60_m39(theta, phi):
    return 3.24692965294476e-68*(1.0 - cos(theta)**2)**19.5*(1.36481990063246e+79*cos(theta)**21 - 2.40850570699846e+79*cos(theta)**19 + 1.76006186280657e+79*cos(theta)**17 - 6.93821487946938e+78*cos(theta)**15 + 1.6117534565139e+78*cos(theta)**13 - 2.26516701996549e+77*cos(theta)**11 + 1.90495697397709e+76*cos(theta)**9 - 9.15600147705945e+74*cos(theta)**7 + 2.28900036926486e+73*cos(theta)**5 - 2.46925606177439e+71*cos(theta)**3 + 7.33442394586453e+68*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl60_m40(theta, phi):
    return 7.08538138610289e-70*(1.0 - cos(theta)**2)**20*(2.86612179132817e+80*cos(theta)**20 - 4.57616084329708e+80*cos(theta)**18 + 2.99210516677117e+80*cos(theta)**16 - 1.04073223192041e+80*cos(theta)**14 + 2.09527949346807e+79*cos(theta)**12 - 2.49168372196203e+78*cos(theta)**10 + 1.71446127657938e+77*cos(theta)**8 - 6.40920103394161e+75*cos(theta)**6 + 1.14450018463243e+74*cos(theta)**4 - 7.40776818532318e+71*cos(theta)**2 + 7.33442394586453e+68)*cos(40*phi)

#@torch.jit.script
def Yl60_m41(theta, phi):
    return 1.57647666728742e-71*(1.0 - cos(theta)**2)**20.5*(5.73224358265634e+81*cos(theta)**19 - 8.23708951793475e+81*cos(theta)**17 + 4.78736826683387e+81*cos(theta)**15 - 1.45702512468857e+81*cos(theta)**13 + 2.51433539216169e+80*cos(theta)**11 - 2.49168372196203e+79*cos(theta)**9 + 1.37156902126351e+78*cos(theta)**7 - 3.84552062036497e+76*cos(theta)**5 + 4.57800073852972e+74*cos(theta)**3 - 1.48155363706464e+72*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl60_m42(theta, phi):
    return 3.58105227694671e-73*(1.0 - cos(theta)**2)**21*(1.08912628070471e+83*cos(theta)**18 - 1.40030521804891e+83*cos(theta)**16 + 7.1810524002508e+82*cos(theta)**14 - 1.89413266209514e+82*cos(theta)**12 + 2.76576893137786e+81*cos(theta)**10 - 2.24251534976583e+80*cos(theta)**8 + 9.60098314884454e+78*cos(theta)**6 - 1.92276031018248e+77*cos(theta)**4 + 1.37340022155892e+75*cos(theta)**2 - 1.48155363706464e+72)*cos(42*phi)

#@torch.jit.script
def Yl60_m43(theta, phi):
    return 8.3167911575098e-75*(1.0 - cos(theta)**2)**21.5*(1.96042730526847e+84*cos(theta)**17 - 2.24048834887825e+84*cos(theta)**15 + 1.00534733603511e+84*cos(theta)**13 - 2.27295919451417e+83*cos(theta)**11 + 2.76576893137786e+82*cos(theta)**9 - 1.79401227981267e+81*cos(theta)**7 + 5.76058988930672e+79*cos(theta)**5 - 7.69104124072994e+77*cos(theta)**3 + 2.74680044311783e+75*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl60_m44(theta, phi):
    return 1.97794707032021e-76*(1.0 - cos(theta)**2)**22*(3.3327264189564e+85*cos(theta)**16 - 3.36073252331738e+85*cos(theta)**14 + 1.30695153684565e+85*cos(theta)**12 - 2.50025511396558e+84*cos(theta)**10 + 2.48919203824007e+83*cos(theta)**8 - 1.25580859586887e+82*cos(theta)**6 + 2.88029494465336e+80*cos(theta)**4 - 2.30731237221898e+78*cos(theta)**2 + 2.74680044311783e+75)*cos(44*phi)

#@torch.jit.script
def Yl60_m45(theta, phi):
    return 4.82569672553458e-78*(1.0 - cos(theta)**2)**22.5*(5.33236227033024e+86*cos(theta)**15 - 4.70502553264433e+86*cos(theta)**13 + 1.56834184421478e+86*cos(theta)**11 - 2.50025511396558e+85*cos(theta)**9 + 1.99135363059206e+84*cos(theta)**7 - 7.53485157521319e+82*cos(theta)**5 + 1.15211797786134e+81*cos(theta)**3 - 4.61462474443796e+78*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl60_m46(theta, phi):
    return 1.21021202172876e-79*(1.0 - cos(theta)**2)**23*(7.99854340549535e+87*cos(theta)**14 - 6.11653319243762e+87*cos(theta)**12 + 1.72517602863625e+87*cos(theta)**10 - 2.25022960256903e+86*cos(theta)**8 + 1.39394754141444e+85*cos(theta)**6 - 3.7674257876066e+83*cos(theta)**4 + 3.45635393358403e+81*cos(theta)**2 - 4.61462474443796e+78)*cos(46*phi)

#@torch.jit.script
def Yl60_m47(theta, phi):
    return 3.12683925851279e-81*(1.0 - cos(theta)**2)**23.5*(1.11979607676935e+89*cos(theta)**13 - 7.33983983092515e+88*cos(theta)**11 + 1.72517602863625e+88*cos(theta)**9 - 1.80018368205522e+87*cos(theta)**7 + 8.36368524848664e+85*cos(theta)**5 - 1.50697031504264e+84*cos(theta)**3 + 6.91270786716807e+81*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl60_m48(theta, phi):
    return 8.34491662851533e-83*(1.0 - cos(theta)**2)**24*(1.45573489980015e+90*cos(theta)**12 - 8.07382381401766e+89*cos(theta)**10 + 1.55265842577263e+89*cos(theta)**8 - 1.26012857743865e+88*cos(theta)**6 + 4.18184262424332e+86*cos(theta)**4 - 4.52091094512792e+84*cos(theta)**2 + 6.91270786716807e+81)*cos(48*phi)

#@torch.jit.script
def Yl60_m49(theta, phi):
    return 2.30737472014175e-84*(1.0 - cos(theta)**2)**24.5*(1.74688187976019e+91*cos(theta)**11 - 8.07382381401766e+90*cos(theta)**9 + 1.2421267406181e+90*cos(theta)**7 - 7.56077146463193e+88*cos(theta)**5 + 1.67273704969733e+87*cos(theta)**3 - 9.04182189025583e+84*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl60_m50(theta, phi):
    return 6.63323593740138e-86*(1.0 - cos(theta)**2)**25*(1.9215700677362e+92*cos(theta)**10 - 7.2664414326159e+91*cos(theta)**8 + 8.69488718432672e+90*cos(theta)**6 - 3.78038573231596e+89*cos(theta)**4 + 5.01821114909199e+87*cos(theta)**2 - 9.04182189025583e+84)*cos(50*phi)

#@torch.jit.script
def Yl60_m51(theta, phi):
    return 1.99096651347248e-87*(1.0 - cos(theta)**2)**25.5*(1.9215700677362e+93*cos(theta)**9 - 5.81315314609272e+92*cos(theta)**7 + 5.21693231059603e+91*cos(theta)**5 - 1.51215429292639e+90*cos(theta)**3 + 1.0036422298184e+88*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl60_m52(theta, phi):
    return 6.2709550753637e-89*(1.0 - cos(theta)**2)**26*(1.72941306096258e+94*cos(theta)**8 - 4.0692072022649e+93*cos(theta)**6 + 2.60846615529801e+92*cos(theta)**4 - 4.53646287877916e+90*cos(theta)**2 + 1.0036422298184e+88)*cos(52*phi)

#@torch.jit.script
def Yl60_m53(theta, phi):
    return 2.08568863326116e-90*(1.0 - cos(theta)**2)**26.5*(1.38353044877007e+95*cos(theta)**7 - 2.44152432135894e+94*cos(theta)**5 + 1.04338646211921e+93*cos(theta)**3 - 9.07292575755831e+90*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl60_m54(theta, phi):
    return 7.38325772766451e-92*(1.0 - cos(theta)**2)**27*(9.68471314139047e+95*cos(theta)**6 - 1.22076216067947e+95*cos(theta)**4 + 3.13015938635762e+93*cos(theta)**2 - 9.07292575755831e+90)*cos(54*phi)

#@torch.jit.script
def Yl60_m55(theta, phi):
    return 2.81075818006968e-93*(1.0 - cos(theta)**2)**27.5*(5.81082788483428e+96*cos(theta)**5 - 4.88304864271788e+95*cos(theta)**3 + 6.26031877271524e+93*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl60_m56(theta, phi):
    return 1.16710380908356e-94*(1.0 - cos(theta)**2)**28*(2.90541394241714e+97*cos(theta)**4 - 1.46491459281536e+96*cos(theta)**2 + 6.26031877271524e+93)*cos(56*phi)

#@torch.jit.script
def Yl60_m57(theta, phi):
    return 5.39493926594886e-96*(1.0 - cos(theta)**2)**28.5*(1.16216557696686e+98*cos(theta)**3 - 2.92982918563073e+96*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl60_m58(theta, phi):
    return 2.86737786884351e-97*(1.0 - cos(theta)**2)**29*(3.48649673090057e+98*cos(theta)**2 - 2.92982918563073e+96)*cos(58*phi)

#@torch.jit.script
def Yl60_m59(theta, phi):
    return 12.9603195124091*(1.0 - cos(theta)**2)**29.5*cos(59*phi)*cos(theta)

#@torch.jit.script
def Yl60_m60(theta, phi):
    return 1.18310989157014*(1.0 - cos(theta)**2)**30*cos(60*phi)

#@torch.jit.script
def Yl61_m_minus_61(theta, phi):
    return 1.18794880702723*(1.0 - cos(theta)**2)**30.5*sin(61*phi)

#@torch.jit.script
def Yl61_m_minus_60(theta, phi):
    return 13.1213234435527*(1.0 - cos(theta)**2)**30*sin(60*phi)*cos(theta)

#@torch.jit.script
def Yl61_m_minus_59(theta, phi):
    return 2.41924969941795e-99*(1.0 - cos(theta)**2)**29.5*(4.21866104438969e+100*cos(theta)**2 - 3.48649673090057e+98)*sin(59*phi)

#@torch.jit.script
def Yl61_m_minus_58(theta, phi):
    return 4.59020356730306e-98*(1.0 - cos(theta)**2)**29*(1.4062203481299e+100*cos(theta)**3 - 3.48649673090057e+98*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl61_m_minus_57(theta, phi):
    return 1.00146418526566e-96*(1.0 - cos(theta)**2)**28.5*(3.51555087032474e+99*cos(theta)**4 - 1.74324836545028e+98*cos(theta)**2 + 7.32457296407682e+95)*sin(57*phi)

#@torch.jit.script
def Yl61_m_minus_56(theta, phi):
    return 2.43254805395122e-95*(1.0 - cos(theta)**2)**28*(7.03110174064948e+98*cos(theta)**5 - 5.81082788483428e+97*cos(theta)**3 + 7.32457296407682e+95*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl61_m_minus_55(theta, phi):
    return 6.44510481250452e-94*(1.0 - cos(theta)**2)**27.5*(1.17185029010825e+98*cos(theta)**6 - 1.45270697120857e+97*cos(theta)**4 + 3.66228648203841e+95*cos(theta)**2 - 1.04338646211921e+93)*sin(55*phi)

#@torch.jit.script
def Yl61_m_minus_54(theta, phi):
    return 1.83657216977349e-92*(1.0 - cos(theta)**2)**27*(1.67407184301178e+97*cos(theta)**7 - 2.90541394241714e+96*cos(theta)**5 + 1.22076216067947e+95*cos(theta)**3 - 1.04338646211921e+93*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl61_m_minus_53(theta, phi):
    return 5.57059920296156e-91*(1.0 - cos(theta)**2)**26.5*(2.09258980376473e+96*cos(theta)**8 - 4.84235657069523e+95*cos(theta)**6 + 3.05190540169868e+94*cos(theta)**4 - 5.21693231059603e+92*cos(theta)**2 + 1.13411571969479e+90)*sin(53*phi)

#@torch.jit.script
def Yl61_m_minus_52(theta, phi):
    return 1.78433170802171e-89*(1.0 - cos(theta)**2)**26*(2.32509978196081e+95*cos(theta)**9 - 6.91765224385034e+94*cos(theta)**7 + 6.10381080339735e+93*cos(theta)**5 - 1.73897743686534e+92*cos(theta)**3 + 1.13411571969479e+90*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl61_m_minus_51(theta, phi):
    return 5.99811536901751e-88*(1.0 - cos(theta)**2)**25.5*(2.32509978196081e+94*cos(theta)**10 - 8.64706530481292e+93*cos(theta)**8 + 1.01730180056623e+93*cos(theta)**6 - 4.34744359216336e+91*cos(theta)**4 + 5.67057859847394e+89*cos(theta)**2 - 1.0036422298184e+87)*sin(51*phi)

#@torch.jit.script
def Yl61_m_minus_50(theta, phi):
    return 2.10532995018392e-86*(1.0 - cos(theta)**2)**25*(2.11372707450982e+93*cos(theta)**11 - 9.60785033868102e+92*cos(theta)**9 + 1.45328828652318e+92*cos(theta)**7 - 8.69488718432672e+90*cos(theta)**5 + 1.89019286615798e+89*cos(theta)**3 - 1.0036422298184e+87*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl61_m_minus_49(theta, phi):
    return 7.68373328093602e-85*(1.0 - cos(theta)**2)**24.5*(1.76143922875819e+92*cos(theta)**12 - 9.60785033868102e+91*cos(theta)**10 + 1.81661035815397e+91*cos(theta)**8 - 1.44914786405445e+90*cos(theta)**6 + 4.72548216539495e+88*cos(theta)**4 - 5.01821114909199e+86*cos(theta)**2 + 7.53485157521319e+83)*sin(49*phi)

#@torch.jit.script
def Yl61_m_minus_48(theta, phi):
    return 2.9056299265317e-83*(1.0 - cos(theta)**2)**24*(1.35495325289091e+91*cos(theta)**13 - 8.73440939880093e+90*cos(theta)**11 + 2.01845595350442e+90*cos(theta)**9 - 2.0702112343635e+89*cos(theta)**7 + 9.45096433078991e+87*cos(theta)**5 - 1.67273704969733e+86*cos(theta)**3 + 7.53485157521319e+83*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl61_m_minus_47(theta, phi):
    return 1.1350567264218e-81*(1.0 - cos(theta)**2)**23.5*(9.67823752064938e+89*cos(theta)**14 - 7.27867449900077e+89*cos(theta)**12 + 2.01845595350442e+89*cos(theta)**10 - 2.58776404295438e+88*cos(theta)**8 + 1.57516072179832e+87*cos(theta)**6 - 4.18184262424332e+85*cos(theta)**4 + 3.7674257876066e+83*cos(theta)**2 - 4.93764847654862e+80)*sin(47*phi)

#@torch.jit.script
def Yl61_m_minus_46(theta, phi):
    return 4.56851519747556e-80*(1.0 - cos(theta)**2)**23*(6.45215834709959e+88*cos(theta)**15 - 5.59898038384675e+88*cos(theta)**13 + 1.83495995773129e+88*cos(theta)**11 - 2.87529338106042e+87*cos(theta)**9 + 2.25022960256903e+86*cos(theta)**7 - 8.36368524848664e+84*cos(theta)**5 + 1.25580859586887e+83*cos(theta)**3 - 4.93764847654862e+80*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl61_m_minus_45(theta, phi):
    return 1.89028354644417e-78*(1.0 - cos(theta)**2)**22.5*(4.03259896693724e+87*cos(theta)**16 - 3.99927170274768e+87*cos(theta)**14 + 1.52913329810941e+87*cos(theta)**12 - 2.87529338106042e+86*cos(theta)**10 + 2.81278700321128e+85*cos(theta)**8 - 1.39394754141444e+84*cos(theta)**6 + 3.13952148967216e+82*cos(theta)**4 - 2.46882423827431e+80*cos(theta)**2 + 2.88414046527373e+77)*sin(45*phi)

#@torch.jit.script
def Yl61_m_minus_44(theta, phi):
    return 8.02424808844761e-77*(1.0 - cos(theta)**2)**22*(2.37211703937485e+86*cos(theta)**17 - 2.66618113516512e+86*cos(theta)**15 + 1.17625638316108e+86*cos(theta)**13 - 2.61390307369129e+85*cos(theta)**11 + 3.12531889245698e+84*cos(theta)**9 - 1.99135363059206e+83*cos(theta)**7 + 6.27904297934433e+81*cos(theta)**5 - 8.22941412758103e+79*cos(theta)**3 + 2.88414046527373e+77*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl61_m_minus_43(theta, phi):
    return 3.48847206463754e-75*(1.0 - cos(theta)**2)**21.5*(1.31784279965269e+85*cos(theta)**18 - 1.6663632094782e+85*cos(theta)**16 + 8.40183130829344e+84*cos(theta)**14 - 2.17825256140941e+84*cos(theta)**12 + 3.12531889245698e+83*cos(theta)**10 - 2.48919203824007e+82*cos(theta)**8 + 1.04650716322405e+81*cos(theta)**6 - 2.05735353189526e+79*cos(theta)**4 + 1.44207023263686e+77*cos(theta)**2 - 1.52600024617657e+74)*sin(43*phi)

#@torch.jit.script
def Yl61_m_minus_42(theta, phi):
    return 1.55070333059599e-73*(1.0 - cos(theta)**2)**21*(6.93601473501418e+83*cos(theta)**19 - 9.80213652634235e+83*cos(theta)**17 + 5.60122087219563e+83*cos(theta)**15 - 1.67557889339185e+83*cos(theta)**13 + 2.84119899314271e+82*cos(theta)**11 - 2.76576893137786e+81*cos(theta)**9 + 1.49501023317722e+80*cos(theta)**7 - 4.11470706379052e+78*cos(theta)**5 + 4.80690077545621e+76*cos(theta)**3 - 1.52600024617657e+74*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl61_m_minus_41(theta, phi):
    return 7.03821176735559e-72*(1.0 - cos(theta)**2)**20.5*(3.46800736750709e+82*cos(theta)**20 - 5.44563140352353e+82*cos(theta)**18 + 3.50076304512227e+82*cos(theta)**16 - 1.19684206670847e+82*cos(theta)**14 + 2.36766582761892e+81*cos(theta)**12 - 2.76576893137786e+80*cos(theta)**10 + 1.86876279147153e+79*cos(theta)**8 - 6.85784510631753e+77*cos(theta)**6 + 1.20172519386405e+76*cos(theta)**4 - 7.63000123088287e+73*cos(theta)**2 + 7.40776818532318e+70)*sin(41*phi)

#@torch.jit.script
def Yl61_m_minus_40(theta, phi):
    return 3.25740728337047e-70*(1.0 - cos(theta)**2)**20*(1.65143207976528e+81*cos(theta)**21 - 2.86612179132817e+81*cos(theta)**19 + 2.05927237948369e+81*cos(theta)**17 - 7.97894711138978e+80*cos(theta)**15 + 1.82128140586071e+80*cos(theta)**13 - 2.51433539216169e+79*cos(theta)**11 + 2.07640310163503e+78*cos(theta)**9 - 9.79692158045361e+76*cos(theta)**7 + 2.40345038772811e+75*cos(theta)**5 - 2.54333374362762e+73*cos(theta)**3 + 7.40776818532318e+70*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl61_m_minus_39(theta, phi):
    return 1.53547973969296e-68*(1.0 - cos(theta)**2)**19.5*(7.50650945347855e+79*cos(theta)**22 - 1.43306089566409e+80*cos(theta)**20 + 1.14404021082427e+80*cos(theta)**18 - 4.98684194461861e+79*cos(theta)**16 + 1.30091528990051e+79*cos(theta)**14 - 2.09527949346807e+78*cos(theta)**12 + 2.07640310163503e+77*cos(theta)**10 - 1.2246151975567e+76*cos(theta)**8 + 4.00575064621351e+74*cos(theta)**6 - 6.35833435906906e+72*cos(theta)**4 + 3.70388409266159e+70*cos(theta)**2 - 3.33382906630206e+67)*sin(39*phi)

#@torch.jit.script
def Yl61_m_minus_38(theta, phi):
    return 7.36390213902749e-67*(1.0 - cos(theta)**2)**19*(3.26369976238198e+78*cos(theta)**23 - 6.82409950316231e+78*cos(theta)**21 + 6.02126426749616e+78*cos(theta)**19 - 2.93343643801095e+78*cos(theta)**17 + 8.67276859933672e+77*cos(theta)**15 - 1.6117534565139e+77*cos(theta)**13 + 1.88763918330457e+76*cos(theta)**11 - 1.36068355284078e+75*cos(theta)**9 + 5.72250092316216e+73*cos(theta)**7 - 1.27166687181381e+72*cos(theta)**5 + 1.2346280308872e+70*cos(theta)**3 - 3.33382906630206e+67*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl61_m_minus_37(theta, phi):
    return 3.58947742712642e-65*(1.0 - cos(theta)**2)**18.5*(1.35987490099249e+77*cos(theta)**24 - 3.10186341052832e+77*cos(theta)**22 + 3.01063213374808e+77*cos(theta)**20 - 1.62968691000608e+77*cos(theta)**18 + 5.42048037458545e+76*cos(theta)**16 - 1.1512524689385e+76*cos(theta)**14 + 1.57303265275381e+75*cos(theta)**12 - 1.36068355284078e+74*cos(theta)**10 + 7.15312615395269e+72*cos(theta)**8 - 2.11944478635635e+71*cos(theta)**6 + 3.08657007721799e+69*cos(theta)**4 - 1.66691453315103e+67*cos(theta)**2 + 1.40312671140659e+64)*sin(37*phi)

#@torch.jit.script
def Yl61_m_minus_36(theta, phi):
    return 1.77670068074599e-63*(1.0 - cos(theta)**2)**18*(5.43949960396996e+75*cos(theta)**25 - 1.3486362654471e+76*cos(theta)**23 + 1.43363434940385e+76*cos(theta)**21 - 8.5772995263478e+75*cos(theta)**19 + 3.18851786740321e+75*cos(theta)**17 - 7.67501645959002e+74*cos(theta)**15 + 1.21002511750293e+74*cos(theta)**13 - 1.23698504803707e+73*cos(theta)**11 + 7.94791794883633e+71*cos(theta)**9 - 3.02777826622336e+70*cos(theta)**7 + 6.17314015443598e+68*cos(theta)**5 - 5.5563817771701e+66*cos(theta)**3 + 1.40312671140659e+64*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl61_m_minus_35(theta, phi):
    return 8.92250520269132e-62*(1.0 - cos(theta)**2)**17.5*(2.09211523229614e+74*cos(theta)**26 - 5.61931777269624e+74*cos(theta)**24 + 6.51651977001749e+74*cos(theta)**22 - 4.2886497631739e+74*cos(theta)**20 + 1.771398815224e+74*cos(theta)**18 - 4.79688528724376e+73*cos(theta)**16 + 8.64303655359236e+72*cos(theta)**14 - 1.03082087336423e+72*cos(theta)**12 + 7.94791794883633e+70*cos(theta)**10 - 3.7847228327792e+69*cos(theta)**8 + 1.028856692406e+68*cos(theta)**6 - 1.38909544429253e+66*cos(theta)**4 + 7.01563355703296e+63*cos(theta)**2 - 5.56354762651305e+60)*sin(35*phi)

#@torch.jit.script
def Yl61_m_minus_34(theta, phi):
    return 4.5425980324766e-60*(1.0 - cos(theta)**2)**17*(7.74857493443014e+72*cos(theta)**27 - 2.2477271090785e+73*cos(theta)**25 + 2.83326946522499e+73*cos(theta)**23 - 2.04221417293995e+73*cos(theta)**21 + 9.3231516590737e+72*cos(theta)**19 - 2.82169722779045e+72*cos(theta)**17 + 5.76202436906157e+71*cos(theta)**15 - 7.92939133357097e+70*cos(theta)**13 + 7.22537995348757e+69*cos(theta)**11 - 4.20524759197689e+68*cos(theta)**9 + 1.46979527486571e+67*cos(theta)**7 - 2.77819088858505e+65*cos(theta)**5 + 2.33854451901099e+63*cos(theta)**3 - 5.56354762651305e+60*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl61_m_minus_33(theta, phi):
    return 2.3428534677439e-58*(1.0 - cos(theta)**2)**16.5*(2.76734819086791e+71*cos(theta)**28 - 8.64510426568652e+71*cos(theta)**26 + 1.18052894384375e+72*cos(theta)**24 - 9.28279169518161e+71*cos(theta)**22 + 4.66157582953685e+71*cos(theta)**20 - 1.56760957099469e+71*cos(theta)**18 + 3.60126523066348e+70*cos(theta)**16 - 5.6638509525507e+69*cos(theta)**14 + 6.02114996123964e+68*cos(theta)**12 - 4.20524759197689e+67*cos(theta)**10 + 1.83724409358214e+66*cos(theta)**8 - 4.63031814764175e+64*cos(theta)**6 + 5.84636129752746e+62*cos(theta)**4 - 2.78177381325652e+60*cos(theta)**2 + 2.09155925808761e+57)*sin(33*phi)

#@torch.jit.script
def Yl61_m_minus_32(theta, phi):
    return 1.22322979951509e-56*(1.0 - cos(theta)**2)**16*(9.54257996851003e+69*cos(theta)**29 - 3.20189046877279e+70*cos(theta)**27 + 4.72211577537499e+70*cos(theta)**25 - 4.03599638920939e+70*cos(theta)**23 + 2.21979801406517e+70*cos(theta)**21 - 8.25057668944575e+69*cos(theta)**19 + 2.11839131215499e+69*cos(theta)**17 - 3.7759006350338e+68*cos(theta)**15 + 4.63165381633819e+67*cos(theta)**13 - 3.82295235634263e+66*cos(theta)**11 + 2.04138232620238e+65*cos(theta)**9 - 6.61474021091679e+63*cos(theta)**7 + 1.16927225950549e+62*cos(theta)**5 - 9.27257937752175e+59*cos(theta)**3 + 2.09155925808761e+57*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl61_m_minus_31(theta, phi):
    return 6.46115491793583e-55*(1.0 - cos(theta)**2)**15.5*(3.18085998950334e+68*cos(theta)**30 - 1.143532310276e+69*cos(theta)**28 + 1.81619837514423e+69*cos(theta)**26 - 1.68166516217058e+69*cos(theta)**24 + 1.00899909730235e+69*cos(theta)**22 - 4.12528834472288e+68*cos(theta)**20 + 1.17688406230833e+68*cos(theta)**18 - 2.35993789689612e+67*cos(theta)**16 + 3.30832415452728e+66*cos(theta)**14 - 3.18579363028552e+65*cos(theta)**12 + 2.04138232620237e+64*cos(theta)**10 - 8.26842526364598e+62*cos(theta)**8 + 1.94878709917582e+61*cos(theta)**6 - 2.31814484438044e+59*cos(theta)**4 + 1.04577962904381e+57*cos(theta)**2 - 7.49662816518858e+53)*sin(31*phi)

#@torch.jit.script
def Yl61_m_minus_30(theta, phi):
    return 3.45052290581314e-53*(1.0 - cos(theta)**2)**15*(1.02608386758172e+67*cos(theta)**31 - 3.94321486302067e+67*cos(theta)**29 + 6.72666064868232e+67*cos(theta)**27 - 6.72666064868232e+67*cos(theta)**25 + 4.38695259696673e+67*cos(theta)**23 - 1.96442302129661e+67*cos(theta)**21 + 6.19412664372804e+66*cos(theta)**19 - 1.38819876288007e+66*cos(theta)**17 + 2.20554943635152e+65*cos(theta)**15 - 2.45061048483502e+64*cos(theta)**13 + 1.85580211472943e+63*cos(theta)**11 - 9.18713918182887e+61*cos(theta)**9 + 2.78398157025117e+60*cos(theta)**7 - 4.63628968876087e+58*cos(theta)**5 + 3.48593209681269e+56*cos(theta)**3 - 7.49662816518858e+53*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl61_m_minus_29(theta, phi):
    return 1.86200395912983e-51*(1.0 - cos(theta)**2)**14.5*(3.20651208619289e+65*cos(theta)**32 - 1.31440495434022e+66*cos(theta)**30 + 2.40237880310083e+66*cos(theta)**28 - 2.58717717257012e+66*cos(theta)**26 + 1.82789691540281e+66*cos(theta)**24 - 8.92919555134822e+65*cos(theta)**22 + 3.09706332186402e+65*cos(theta)**20 - 7.71221534933374e+64*cos(theta)**18 + 1.3784683977197e+64*cos(theta)**16 - 1.75043606059644e+63*cos(theta)**14 + 1.54650176227453e+62*cos(theta)**12 - 9.18713918182887e+60*cos(theta)**10 + 3.47997696281397e+59*cos(theta)**8 - 7.72714948126812e+57*cos(theta)**6 + 8.71483024203172e+55*cos(theta)**4 - 3.74831408259429e+53*cos(theta)**2 + 2.57439154024333e+50)*sin(29*phi)

#@torch.jit.script
def Yl61_m_minus_28(theta, phi):
    return 1.01474945031427e-49*(1.0 - cos(theta)**2)**14*(9.71670329149359e+63*cos(theta)**33 - 4.24001598174266e+64*cos(theta)**31 + 8.28406483827872e+64*cos(theta)**29 - 9.58213767618565e+64*cos(theta)**27 + 7.31158766161122e+64*cos(theta)**25 - 3.88225893536879e+64*cos(theta)**23 + 1.47479205803049e+64*cos(theta)**21 - 4.05906071017565e+63*cos(theta)**19 + 8.10863763364528e+62*cos(theta)**17 - 1.16695737373096e+62*cos(theta)**15 + 1.18961674021117e+61*cos(theta)**13 - 8.35194471075352e+59*cos(theta)**11 + 3.8666410697933e+58*cos(theta)**9 - 1.10387849732402e+57*cos(theta)**7 + 1.74296604840634e+55*cos(theta)**5 - 1.24943802753143e+53*cos(theta)**3 + 2.57439154024333e+50*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl61_m_minus_27(theta, phi):
    return 5.58204440000173e-48*(1.0 - cos(theta)**2)**13.5*(2.85785390926282e+62*cos(theta)**34 - 1.32500499429458e+63*cos(theta)**32 + 2.76135494609291e+63*cos(theta)**30 - 3.42219202720916e+63*cos(theta)**28 + 2.8121491006197e+63*cos(theta)**26 - 1.617607889737e+63*cos(theta)**24 + 6.70360026377494e+62*cos(theta)**22 - 2.02953035508783e+62*cos(theta)**20 + 4.50479868535849e+61*cos(theta)**18 - 7.29348358581851e+60*cos(theta)**16 + 8.49726243007982e+59*cos(theta)**14 - 6.95995392562793e+58*cos(theta)**12 + 3.8666410697933e+57*cos(theta)**10 - 1.37984812165502e+56*cos(theta)**8 + 2.90494341401057e+54*cos(theta)**6 - 3.12359506882857e+52*cos(theta)**4 + 1.28719577012166e+50*cos(theta)**2 - 8.50757283623044e+46)*sin(27*phi)

#@torch.jit.script
def Yl61_m_minus_26(theta, phi):
    return 3.09790891772917e-46*(1.0 - cos(theta)**2)**13*(8.16529688360806e+60*cos(theta)**35 - 4.01516664937752e+61*cos(theta)**33 + 8.9075966002997e+61*cos(theta)**31 - 1.18006621627902e+62*cos(theta)**29 + 1.04153670393322e+62*cos(theta)**27 - 6.47043155894798e+61*cos(theta)**25 + 2.91460881033693e+61*cos(theta)**23 - 9.66443026232298e+60*cos(theta)**21 + 2.37094667650447e+60*cos(theta)**19 - 4.29028446224618e+59*cos(theta)**17 + 5.66484162005321e+58*cos(theta)**15 - 5.35381071202149e+57*cos(theta)**13 + 3.51512824526663e+56*cos(theta)**11 - 1.53316457961669e+55*cos(theta)**9 + 4.14991916287225e+53*cos(theta)**7 - 6.24719013765715e+51*cos(theta)**5 + 4.29065256707222e+49*cos(theta)**3 - 8.50757283623044e+46*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl61_m_minus_25(theta, phi):
    return 1.73372224485625e-44*(1.0 - cos(theta)**2)**12.5*(2.26813802322446e+59*cos(theta)**36 - 1.18093136746398e+60*cos(theta)**34 + 2.78362393759366e+60*cos(theta)**32 - 3.9335540542634e+60*cos(theta)**30 + 3.71977394261865e+60*cos(theta)**28 - 2.4886275226723e+60*cos(theta)**26 + 1.21442033764039e+60*cos(theta)**24 - 4.39292284651044e+59*cos(theta)**22 + 1.18547333825223e+59*cos(theta)**20 - 2.38349136791455e+58*cos(theta)**18 + 3.54052601253326e+57*cos(theta)**16 - 3.82415050858678e+56*cos(theta)**14 + 2.92927353772219e+55*cos(theta)**12 - 1.53316457961669e+54*cos(theta)**10 + 5.18739895359031e+52*cos(theta)**8 - 1.04119835627619e+51*cos(theta)**6 + 1.07266314176805e+49*cos(theta)**4 - 4.25378641811522e+46*cos(theta)**2 + 2.71633870888584e+43)*sin(25*phi)

#@torch.jit.script
def Yl61_m_minus_24(theta, phi):
    return 9.77979179767568e-43*(1.0 - cos(theta)**2)**12*(6.13010276547152e+57*cos(theta)**37 - 3.37408962132565e+58*cos(theta)**35 + 8.43522405331411e+58*cos(theta)**33 - 1.2688884046011e+59*cos(theta)**31 + 1.2826806698685e+59*cos(theta)**29 - 9.21713897286038e+58*cos(theta)**27 + 4.85768135056155e+58*cos(theta)**25 - 1.90996645500454e+58*cos(theta)**23 + 5.64511113453445e+57*cos(theta)**21 - 1.25446914100766e+57*cos(theta)**19 + 2.08266236031368e+56*cos(theta)**17 - 2.54943367239118e+55*cos(theta)**15 + 2.25328733670938e+54*cos(theta)**13 - 1.39378598146972e+53*cos(theta)**11 + 5.76377661510034e+51*cos(theta)**9 - 1.4874262232517e+50*cos(theta)**7 + 2.14532628353611e+48*cos(theta)**5 - 1.41792880603841e+46*cos(theta)**3 + 2.71633870888584e+43*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl61_m_minus_23(theta, phi):
    return 5.55815777184317e-41*(1.0 - cos(theta)**2)**11.5*(1.61318493828198e+56*cos(theta)**38 - 9.37247117034901e+56*cos(theta)**36 + 2.48094825097474e+57*cos(theta)**34 - 3.96527626437843e+57*cos(theta)**32 + 4.275602232895e+57*cos(theta)**30 - 3.29183534745013e+57*cos(theta)**28 + 1.86833898098521e+57*cos(theta)**26 - 7.95819356251892e+56*cos(theta)**24 + 2.56595960660657e+56*cos(theta)**22 - 6.27234570503828e+55*cos(theta)**20 + 1.15703464461871e+55*cos(theta)**18 - 1.59339604524449e+54*cos(theta)**16 + 1.60949095479241e+53*cos(theta)**14 - 1.16148831789143e+52*cos(theta)**12 + 5.76377661510034e+50*cos(theta)**10 - 1.85928277906463e+49*cos(theta)**8 + 3.57554380589351e+47*cos(theta)**6 - 3.54482201509601e+45*cos(theta)**4 + 1.35816935444292e+43*cos(theta)**2 - 8.40971736497163e+39)*sin(23*phi)

#@torch.jit.script
def Yl61_m_minus_22(theta, phi):
    return 3.18128675173288e-39*(1.0 - cos(theta)**2)**11*(4.13637163662046e+54*cos(theta)**39 - 2.53310031631054e+55*cos(theta)**37 + 7.08842357421354e+55*cos(theta)**35 - 1.20159886799346e+56*cos(theta)**33 + 1.37922652674032e+56*cos(theta)**31 - 1.13511563705177e+56*cos(theta)**29 + 6.91977400364893e+55*cos(theta)**27 - 3.18327742500757e+55*cos(theta)**25 + 1.11563461156807e+55*cos(theta)**23 - 2.98683128811347e+54*cos(theta)**21 + 6.08965602430901e+53*cos(theta)**19 - 9.37291791320288e+52*cos(theta)**17 + 1.07299396986161e+52*cos(theta)**15 - 8.93452552224179e+50*cos(theta)**13 + 5.23979692281849e+49*cos(theta)**11 - 2.06586975451625e+48*cos(theta)**9 + 5.10791972270502e+46*cos(theta)**7 - 7.08964403019203e+44*cos(theta)**5 + 4.52723118147639e+42*cos(theta)**3 - 8.40971736497163e+39*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl61_m_minus_21(theta, phi):
    return 1.83303964815859e-37*(1.0 - cos(theta)**2)**10.5*(1.03409290915511e+53*cos(theta)**40 - 6.66605346397512e+53*cos(theta)**38 + 1.96900654839265e+54*cos(theta)**36 - 3.53411431762783e+54*cos(theta)**34 + 4.31008289606351e+54*cos(theta)**32 - 3.78371879017257e+54*cos(theta)**30 + 2.47134785844605e+54*cos(theta)**28 - 1.22433747115676e+54*cos(theta)**26 + 4.6484775482003e+53*cos(theta)**24 - 1.35765058550612e+53*cos(theta)**22 + 3.0448280121545e+52*cos(theta)**20 - 5.20717661844605e+51*cos(theta)**18 + 6.70621231163506e+50*cos(theta)**16 - 6.38180394445842e+49*cos(theta)**14 + 4.36649743568208e+48*cos(theta)**12 - 2.06586975451625e+47*cos(theta)**10 + 6.38489965338127e+45*cos(theta)**8 - 1.18160733836534e+44*cos(theta)**6 + 1.1318077953691e+42*cos(theta)**4 - 4.20485868248581e+39*cos(theta)**2 + 2.53304739908784e+36)*sin(21*phi)

#@torch.jit.script
def Yl61_m_minus_20(theta, phi):
    return 1.06284690762533e-35*(1.0 - cos(theta)**2)**10*(2.5221778272076e+51*cos(theta)**41 - 1.70924447794234e+52*cos(theta)**39 + 5.32163931998014e+52*cos(theta)**37 - 1.00974694789367e+53*cos(theta)**35 + 1.30608572607985e+53*cos(theta)**33 - 1.22055444844276e+53*cos(theta)**31 + 8.52188916705533e+52*cos(theta)**29 - 4.53458322650651e+52*cos(theta)**27 + 1.85939101928012e+52*cos(theta)**25 - 5.90282863263531e+51*cos(theta)**23 + 1.44991810102595e+51*cos(theta)**21 - 2.74061927286634e+50*cos(theta)**19 + 3.94483077155003e+49*cos(theta)**17 - 4.25453596297228e+48*cos(theta)**15 + 3.35884418129391e+47*cos(theta)**13 - 1.87806341319659e+46*cos(theta)**11 + 7.09433294820142e+44*cos(theta)**9 - 1.68801048337905e+43*cos(theta)**7 + 2.2636155907382e+41*cos(theta)**5 - 1.4016195608286e+39*cos(theta)**3 + 2.53304739908784e+36*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl61_m_minus_19(theta, phi):
    return 6.19923168938198e-34*(1.0 - cos(theta)**2)**9.5*(6.00518530287523e+49*cos(theta)**42 - 4.27311119485584e+50*cos(theta)**40 + 1.40043139999477e+51*cos(theta)**38 - 2.80485263303796e+51*cos(theta)**36 + 3.84142860611721e+51*cos(theta)**34 - 3.81423265138364e+51*cos(theta)**32 + 2.84062972235178e+51*cos(theta)**30 - 1.61949400946661e+51*cos(theta)**28 + 7.15150392030816e+50*cos(theta)**26 - 2.45951193026471e+50*cos(theta)**24 + 6.59053682284525e+49*cos(theta)**22 - 1.37030963643317e+49*cos(theta)**20 + 2.19157265086113e+48*cos(theta)**18 - 2.65908497685768e+47*cos(theta)**16 + 2.39917441520993e+46*cos(theta)**14 - 1.56505284433049e+45*cos(theta)**12 + 7.09433294820142e+43*cos(theta)**10 - 2.11001310422382e+42*cos(theta)**8 + 3.77269265123033e+40*cos(theta)**6 - 3.50404890207151e+38*cos(theta)**4 + 1.26652369954392e+36*cos(theta)**2 - 7.44575955052275e+32)*sin(19*phi)

#@torch.jit.script
def Yl61_m_minus_18(theta, phi):
    return 3.63594319225306e-32*(1.0 - cos(theta)**2)**9*(1.39655472159889e+48*cos(theta)**43 - 1.04222224264777e+49*cos(theta)**41 + 3.59084974357634e+49*cos(theta)**39 - 7.5806827919945e+49*cos(theta)**37 + 1.0975510303192e+50*cos(theta)**35 - 1.15582807617686e+50*cos(theta)**33 + 9.16332168500574e+49*cos(theta)**31 - 5.584462101609e+49*cos(theta)**29 + 2.64870515566969e+49*cos(theta)**27 - 9.83804772105885e+48*cos(theta)**25 + 2.86545079254141e+48*cos(theta)**23 - 6.5252839830151e+47*cos(theta)**21 + 1.15345928992691e+47*cos(theta)**19 - 1.56416763344569e+46*cos(theta)**17 + 1.59944961013996e+45*cos(theta)**15 - 1.20388680333115e+44*cos(theta)**13 + 6.44939358927401e+42*cos(theta)**11 - 2.34445900469313e+41*cos(theta)**9 + 5.38956093032904e+39*cos(theta)**7 - 7.00809780414302e+37*cos(theta)**5 + 4.2217456651464e+35*cos(theta)**3 - 7.44575955052275e+32*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl61_m_minus_17(theta, phi):
    return 2.14366527589978e-30*(1.0 - cos(theta)**2)**8.5*(3.17398800363384e+46*cos(theta)**44 - 2.48148153011373e+47*cos(theta)**42 + 8.97712435894085e+47*cos(theta)**40 - 1.99491652420908e+48*cos(theta)**38 + 3.04875286199779e+48*cos(theta)**36 - 3.39949434169665e+48*cos(theta)**34 + 2.86353802656429e+48*cos(theta)**32 - 1.861487367203e+48*cos(theta)**30 + 9.45966127024889e+47*cos(theta)**28 - 3.78386450809956e+47*cos(theta)**26 + 1.19393783022559e+47*cos(theta)**24 - 2.96603817409777e+46*cos(theta)**22 + 5.76729644963455e+45*cos(theta)**20 - 8.6898201858094e+44*cos(theta)**18 + 9.99656006337472e+43*cos(theta)**16 - 8.59919145236535e+42*cos(theta)**14 + 5.37449465772834e+41*cos(theta)**12 - 2.34445900469313e+40*cos(theta)**10 + 6.7369511629113e+38*cos(theta)**8 - 1.1680163006905e+37*cos(theta)**6 + 1.0554364162866e+35*cos(theta)**4 - 3.72287977526137e+32*cos(theta)**2 + 2.14204820210666e+29)*sin(17*phi)

#@torch.jit.script
def Yl61_m_minus_16(theta, phi):
    return 1.27001991563108e-28*(1.0 - cos(theta)**2)**8*(7.05330667474187e+44*cos(theta)**45 - 5.77088727933426e+45*cos(theta)**43 + 2.18954252657094e+46*cos(theta)**41 - 5.11517057489507e+46*cos(theta)**39 + 8.23987259999402e+46*cos(theta)**37 - 9.71284097627613e+46*cos(theta)**35 + 8.67738795928573e+46*cos(theta)**33 - 6.00479795871935e+46*cos(theta)**31 + 3.26195216215479e+46*cos(theta)**29 - 1.40143129929613e+46*cos(theta)**27 + 4.77575132090235e+45*cos(theta)**25 - 1.28958181482512e+45*cos(theta)**23 + 2.74633164268312e+44*cos(theta)**21 - 4.57358957147863e+43*cos(theta)**19 + 5.88032944904395e+42*cos(theta)**17 - 5.7327943015769e+41*cos(theta)**15 + 4.13422665979103e+40*cos(theta)**13 - 2.13132636790285e+39*cos(theta)**11 + 7.48550129212366e+37*cos(theta)**9 - 1.66859471527215e+36*cos(theta)**7 + 2.1108728325732e+34*cos(theta)**5 - 1.24095992508712e+32*cos(theta)**3 + 2.14204820210666e+29*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl61_m_minus_15(theta, phi):
    return 7.55848594360317e-27*(1.0 - cos(theta)**2)**7.5*(1.53332753798736e+43*cos(theta)**46 - 1.31156529075779e+44*cos(theta)**44 + 5.21319649183557e+44*cos(theta)**42 - 1.27879264372377e+45*cos(theta)**40 + 2.16838752631421e+45*cos(theta)**38 - 2.69801138229893e+45*cos(theta)**36 + 2.55217292920169e+45*cos(theta)**34 - 1.8764993620998e+45*cos(theta)**32 + 1.08731738738493e+45*cos(theta)**30 - 5.00511178320047e+44*cos(theta)**28 + 1.83682743111629e+44*cos(theta)**26 - 5.37325756177132e+43*cos(theta)**24 + 1.24833256485596e+43*cos(theta)**22 - 2.28679478573932e+42*cos(theta)**20 + 3.26684969391331e+41*cos(theta)**18 - 3.58299643848556e+40*cos(theta)**16 + 2.95301904270788e+39*cos(theta)**14 - 1.77610530658571e+38*cos(theta)**12 + 7.48550129212366e+36*cos(theta)**10 - 2.08574339409018e+35*cos(theta)**8 + 3.518121387622e+33*cos(theta)**6 - 3.10239981271781e+31*cos(theta)**4 + 1.07102410105333e+29*cos(theta)**2 - 6.04756691729717e+25)*sin(15*phi)

#@torch.jit.script
def Yl61_m_minus_14(theta, phi):
    return 4.51742067181548e-25*(1.0 - cos(theta)**2)**7*(3.26239901699439e+41*cos(theta)**47 - 2.9145895350173e+42*cos(theta)**45 + 1.21237127717106e+43*cos(theta)**43 - 3.11900644810675e+43*cos(theta)**41 + 5.55996801619029e+43*cos(theta)**39 - 7.29192265486196e+43*cos(theta)**37 + 7.29192265486196e+43*cos(theta)**35 - 5.68636170333272e+43*cos(theta)**33 + 3.50747544317719e+43*cos(theta)**31 - 1.72590061489671e+43*cos(theta)**29 + 6.80306455968996e+42*cos(theta)**27 - 2.14930302470853e+42*cos(theta)**25 + 5.4275328906781e+41*cos(theta)**23 - 1.0889498979711e+41*cos(theta)**21 + 1.71939457574385e+40*cos(theta)**19 - 2.10764496381504e+39*cos(theta)**17 + 1.96867936180525e+38*cos(theta)**15 - 1.36623485121977e+37*cos(theta)**13 + 6.80500117465788e+35*cos(theta)**11 - 2.31749266010021e+34*cos(theta)**9 + 5.02588769660285e+32*cos(theta)**7 - 6.20479962543562e+30*cos(theta)**5 + 3.57008033684443e+28*cos(theta)**3 - 6.04756691729717e+25*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl61_m_minus_13(theta, phi):
    return 2.71045240308929e-23*(1.0 - cos(theta)**2)**6.5*(6.79666461873831e+39*cos(theta)**48 - 6.33606420655935e+40*cos(theta)**46 + 2.75538926629787e+41*cos(theta)**44 - 7.4262058288256e+41*cos(theta)**42 + 1.38999200404757e+42*cos(theta)**40 - 1.91892701443736e+42*cos(theta)**38 + 2.02553407079499e+42*cos(theta)**36 - 1.67245932450962e+42*cos(theta)**34 + 1.09608607599287e+42*cos(theta)**32 - 5.75300204965571e+41*cos(theta)**30 + 2.42966591417499e+41*cos(theta)**28 - 8.26655009503281e+40*cos(theta)**26 + 2.26147203778254e+40*cos(theta)**24 - 4.94977226350501e+39*cos(theta)**22 + 8.59697287871923e+38*cos(theta)**20 - 1.17091386878613e+38*cos(theta)**18 + 1.23042460112828e+37*cos(theta)**16 - 9.75882036585553e+35*cos(theta)**14 + 5.6708343122149e+34*cos(theta)**12 - 2.31749266010021e+33*cos(theta)**10 + 6.28235962075357e+31*cos(theta)**8 - 1.03413327090594e+30*cos(theta)**6 + 8.92520084211108e+27*cos(theta)**4 - 3.02378345864859e+25*cos(theta)**2 + 1.67987969924922e+22)*sin(13*phi)

#@torch.jit.script
def Yl61_m_minus_12(theta, phi):
    return 1.6321335234548e-21*(1.0 - cos(theta)**2)**6*(1.38707441198741e+38*cos(theta)**49 - 1.34809876735305e+39*cos(theta)**47 + 6.12308725843971e+39*cos(theta)**45 - 1.72702461135479e+40*cos(theta)**43 + 3.39022440011603e+40*cos(theta)**41 - 4.92032567804451e+40*cos(theta)**39 + 5.47441640755402e+40*cos(theta)**37 - 4.77845521288464e+40*cos(theta)**35 + 3.32147295755416e+40*cos(theta)**33 - 1.85580711279217e+40*cos(theta)**31 + 8.37815832474133e+39*cos(theta)**29 - 3.06168522038252e+39*cos(theta)**27 + 9.04588815113017e+38*cos(theta)**25 - 2.15207489717609e+38*cos(theta)**23 + 4.09379660891392e+37*cos(theta)**21 - 6.16270457255859e+36*cos(theta)**19 + 7.23779177134285e+35*cos(theta)**17 - 6.50588024390368e+34*cos(theta)**15 + 4.3621802401653e+33*cos(theta)**13 - 2.106811509182e+32*cos(theta)**11 + 6.98039957861508e+30*cos(theta)**9 - 1.47733324415134e+29*cos(theta)**7 + 1.78504016842222e+27*cos(theta)**5 - 1.00792781954953e+25*cos(theta)**3 + 1.67987969924922e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl61_m_minus_11(theta, phi):
    return 9.8605721994746e-20*(1.0 - cos(theta)**2)**5.5*(2.77414882397482e+36*cos(theta)**50 - 2.80853909865219e+37*cos(theta)**48 + 1.33110592574776e+38*cos(theta)**46 - 3.92505593489725e+38*cos(theta)**44 + 8.07196285741913e+38*cos(theta)**42 - 1.23008141951113e+39*cos(theta)**40 + 1.44063589672474e+39*cos(theta)**38 - 1.32734867024573e+39*cos(theta)**36 + 9.76903811045341e+38*cos(theta)**34 - 5.79939722747552e+38*cos(theta)**32 + 2.79271944158044e+38*cos(theta)**30 - 1.09345900727947e+38*cos(theta)**28 + 3.47918775043468e+37*cos(theta)**26 - 8.96697873823372e+36*cos(theta)**24 + 1.86081664041542e+36*cos(theta)**22 - 3.08135228627929e+35*cos(theta)**20 + 4.0209954285238e+34*cos(theta)**18 - 4.0661751524398e+33*cos(theta)**16 + 3.1158430286895e+32*cos(theta)**14 - 1.75567625765167e+31*cos(theta)**12 + 6.98039957861508e+29*cos(theta)**10 - 1.84666655518917e+28*cos(theta)**8 + 2.97506694737036e+26*cos(theta)**6 - 2.51981954887382e+24*cos(theta)**4 + 8.39939849624608e+21*cos(theta)**2 - 4.60241013492936e+18)*sin(11*phi)

#@torch.jit.script
def Yl61_m_minus_10(theta, phi):
    return 5.97521385742017e-18*(1.0 - cos(theta)**2)**5*(5.43950749798985e+34*cos(theta)**51 - 5.73171244622897e+35*cos(theta)**49 + 2.83214026754843e+36*cos(theta)**47 - 8.72234652199389e+36*cos(theta)**45 + 1.87720066451608e+37*cos(theta)**43 - 3.00019858417348e+37*cos(theta)**41 + 3.69393819673011e+37*cos(theta)**39 - 3.58742883850198e+37*cos(theta)**37 + 2.79115374584383e+37*cos(theta)**35 - 1.75739309923501e+37*cos(theta)**33 + 9.00877239219498e+36*cos(theta)**31 - 3.77054830096369e+36*cos(theta)**29 + 1.28858805571655e+36*cos(theta)**27 - 3.58679149529349e+35*cos(theta)**25 + 8.09050713224095e+34*cos(theta)**23 - 1.46731061251395e+34*cos(theta)**21 + 2.11631338343358e+33*cos(theta)**19 - 2.3918677367293e+32*cos(theta)**17 + 2.077228685793e+31*cos(theta)**15 - 1.35052019819359e+30*cos(theta)**13 + 6.34581779874098e+28*cos(theta)**11 - 2.05185172798797e+27*cos(theta)**9 + 4.25009563910051e+25*cos(theta)**7 - 5.03963909774765e+23*cos(theta)**5 + 2.79979949874869e+21*cos(theta)**3 - 4.60241013492936e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl61_m_minus_9(theta, phi):
    return 3.63064929358258e-16*(1.0 - cos(theta)**2)**4.5*(1.04605913422882e+33*cos(theta)**52 - 1.14634248924579e+34*cos(theta)**50 + 5.90029222405923e+34*cos(theta)**48 - 1.89616228738998e+35*cos(theta)**46 + 4.26636514662745e+35*cos(theta)**44 - 7.14332996231781e+35*cos(theta)**42 + 9.23484549182528e+35*cos(theta)**40 - 9.44060220658416e+35*cos(theta)**38 + 7.7532048495662e+35*cos(theta)**36 - 5.16880323304413e+35*cos(theta)**34 + 2.81524137256093e+35*cos(theta)**32 - 1.25684943365456e+35*cos(theta)**30 + 4.60210019898767e+34*cos(theta)**28 - 1.37953519049749e+34*cos(theta)**26 + 3.37104463843373e+33*cos(theta)**24 - 6.66959369324523e+32*cos(theta)**22 + 1.05815669171679e+32*cos(theta)**20 - 1.32881540929405e+31*cos(theta)**18 + 1.29826792862063e+30*cos(theta)**16 - 9.64657284423995e+28*cos(theta)**14 + 5.28818149895081e+27*cos(theta)**12 - 2.05185172798797e+26*cos(theta)**10 + 5.31261954887564e+24*cos(theta)**8 - 8.39939849624608e+22*cos(theta)**6 + 6.99949874687173e+20*cos(theta)**4 - 2.30120506746468e+18*cos(theta)**2 + 1.24658996070676e+15)*sin(9*phi)

#@torch.jit.script
def Yl61_m_minus_8(theta, phi):
    return 2.21142010995196e-14*(1.0 - cos(theta)**2)**4*(1.97369647967701e+31*cos(theta)**53 - 2.24773037107018e+32*cos(theta)**51 + 1.20414127021617e+33*cos(theta)**49 - 4.03438784551059e+33*cos(theta)**47 + 9.48081143694988e+33*cos(theta)**45 - 1.66123952612042e+34*cos(theta)**43 + 2.25240133946958e+34*cos(theta)**41 - 2.42066723245748e+34*cos(theta)**39 + 2.09546077015303e+34*cos(theta)**37 - 1.4768009237269e+34*cos(theta)**35 + 8.53103446230585e+33*cos(theta)**33 - 4.05435301178892e+33*cos(theta)**31 + 1.5869311030992e+33*cos(theta)**29 - 5.10938959443517e+32*cos(theta)**27 + 1.34841785537349e+32*cos(theta)**25 - 2.89982334488923e+31*cos(theta)**23 + 5.03884138912757e+30*cos(theta)**21 - 6.99376531207396e+29*cos(theta)**19 + 7.63687016835663e+28*cos(theta)**17 - 6.43104856282663e+27*cos(theta)**15 + 4.06783192226986e+26*cos(theta)**13 - 1.86531975271634e+25*cos(theta)**11 + 5.90291060986183e+23*cos(theta)**9 - 1.1999140708923e+22*cos(theta)**7 + 1.39989974937435e+20*cos(theta)**5 - 7.6706835582156e+17*cos(theta)**3 + 1.24658996070676e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl61_m_minus_7(theta, phi):
    return 1.3498722825312e-12*(1.0 - cos(theta)**2)**3.5*(3.65499348088336e+29*cos(theta)**54 - 4.3225584059042e+30*cos(theta)**52 + 2.40828254043234e+31*cos(theta)**50 - 8.40497467814706e+31*cos(theta)**48 + 2.06104596455432e+32*cos(theta)**46 - 3.77554437754641e+32*cos(theta)**44 + 5.36286033207043e+32*cos(theta)**42 - 6.05166808114369e+32*cos(theta)**40 + 5.51437044777112e+32*cos(theta)**38 - 4.10222478813026e+32*cos(theta)**36 + 2.50912778303113e+32*cos(theta)**34 - 1.26698531618404e+32*cos(theta)**32 + 5.28977034366399e+31*cos(theta)**30 - 1.82478199801256e+31*cos(theta)**28 + 5.18622252066727e+30*cos(theta)**26 - 1.20825972703718e+30*cos(theta)**24 + 2.29038244960344e+29*cos(theta)**22 - 3.49688265603698e+28*cos(theta)**20 + 4.24270564908701e+27*cos(theta)**18 - 4.01940535176665e+26*cos(theta)**16 + 2.90559423019276e+25*cos(theta)**14 - 1.55443312726361e+24*cos(theta)**12 + 5.90291060986183e+22*cos(theta)**10 - 1.49989258861537e+21*cos(theta)**8 + 2.33316624895724e+19*cos(theta)**6 - 1.9176708895539e+17*cos(theta)**4 + 623294980353380.0*cos(theta)**2 - 334565206845.615)*sin(7*phi)

#@torch.jit.script
def Yl61_m_minus_6(theta, phi):
    return 8.25521675669756e-11*(1.0 - cos(theta)**2)**3*(6.64544269251519e+27*cos(theta)**55 - 8.15577057717774e+28*cos(theta)**53 + 4.72212262829871e+29*cos(theta)**51 - 1.71530095472389e+30*cos(theta)**49 + 4.38520417990281e+30*cos(theta)**47 - 8.3900986167698e+30*cos(theta)**45 + 1.24717682141173e+31*cos(theta)**43 - 1.476016605157e+31*cos(theta)**41 + 1.41394114045413e+31*cos(theta)**39 - 1.10870940219737e+31*cos(theta)**37 + 7.16893652294609e+30*cos(theta)**35 - 3.83934944298193e+30*cos(theta)**33 + 1.70637753021419e+30*cos(theta)**31 - 6.29235171728469e+29*cos(theta)**29 + 1.92082315580269e+29*cos(theta)**27 - 4.83303890814871e+28*cos(theta)**25 + 9.95818456349323e+27*cos(theta)**23 - 1.66518221716047e+27*cos(theta)**21 + 2.23300297320369e+26*cos(theta)**19 - 2.3643560892745e+25*cos(theta)**17 + 1.9370628201285e+24*cos(theta)**15 - 1.19571779020278e+23*cos(theta)**13 + 5.36628237260166e+21*cos(theta)**11 - 1.66654732068375e+20*cos(theta)**9 + 3.33309464136749e+18*cos(theta)**7 - 3.8353417791078e+16*cos(theta)**5 + 207764993451127.0*cos(theta)**3 - 334565206845.615*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl61_m_minus_5(theta, phi):
    return 5.05661508405203e-9*(1.0 - cos(theta)**2)**2.5*(1.186686195092e+26*cos(theta)**56 - 1.51032788466254e+27*cos(theta)**54 + 9.08100505442059e+27*cos(theta)**52 - 3.43060190944778e+28*cos(theta)**50 + 9.13584204146419e+28*cos(theta)**48 - 1.82393448190648e+29*cos(theta)**46 + 2.83449277593574e+29*cos(theta)**44 - 3.51432525037381e+29*cos(theta)**42 + 3.53485285113534e+29*cos(theta)**40 - 2.91765632157202e+29*cos(theta)**38 + 1.99137125637391e+29*cos(theta)**36 - 1.12922042440645e+29*cos(theta)**34 + 5.33242978191935e+28*cos(theta)**32 - 2.09745057242823e+28*cos(theta)**30 + 6.86008269929534e+27*cos(theta)**28 - 1.85886111851874e+27*cos(theta)**26 + 4.14924356812218e+26*cos(theta)**24 - 7.56901007800212e+25*cos(theta)**22 + 1.11650148660185e+25*cos(theta)**20 - 1.31353116070805e+24*cos(theta)**18 + 1.21066426258031e+23*cos(theta)**16 - 8.54084135859129e+21*cos(theta)**14 + 4.47190197716805e+20*cos(theta)**12 - 1.66654732068375e+19*cos(theta)**10 + 4.16636830170936e+17*cos(theta)**8 - 6.392236298513e+15*cos(theta)**6 + 51941248362781.7*cos(theta)**4 - 167282603422.807*cos(theta)**2 + 89169831.2488312)*sin(5*phi)

#@torch.jit.script
def Yl61_m_minus_4(theta, phi):
    return 3.10148218887814e-7*(1.0 - cos(theta)**2)**2*(2.08190560542456e+24*cos(theta)**57 - 2.74605069938644e+25*cos(theta)**55 + 1.71339718007936e+26*cos(theta)**53 - 6.72667041068192e+26*cos(theta)**51 + 1.86445755948249e+27*cos(theta)**49 - 3.88071166363081e+27*cos(theta)**47 + 6.29887283541277e+27*cos(theta)**45 - 8.17284941947397e+27*cos(theta)**43 + 8.62159231984228e+27*cos(theta)**41 - 7.48117005531288e+27*cos(theta)**39 + 5.38208447668626e+27*cos(theta)**37 - 3.22634406973272e+27*cos(theta)**35 + 1.61588781270283e+27*cos(theta)**33 - 6.76596958847816e+26*cos(theta)**31 + 2.3655457583777e+26*cos(theta)**29 - 6.88467080932865e+25*cos(theta)**27 + 1.65969742724887e+25*cos(theta)**25 - 3.29087394695745e+24*cos(theta)**23 + 5.31667374572308e+23*cos(theta)**21 - 6.91332189846344e+22*cos(theta)**19 + 7.12155448576656e+21*cos(theta)**17 - 5.69389423906086e+20*cos(theta)**15 + 3.43992459782158e+19*cos(theta)**13 - 1.5150430188034e+18*cos(theta)**11 + 4.6292981130104e+16*cos(theta)**9 - 913176614073285.0*cos(theta)**7 + 10388249672556.3*cos(theta)**5 - 55760867807.6024*cos(theta)**3 + 89169831.2488312*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl61_m_minus_3(theta, phi):
    return 1.90432016649223e-5*(1.0 - cos(theta)**2)**1.5*(3.58949242314579e+22*cos(theta)**58 - 4.90366196319008e+23*cos(theta)**56 + 3.1729577408877e+24*cos(theta)**54 - 1.29359046359268e+25*cos(theta)**52 + 3.72891511896498e+25*cos(theta)**50 - 8.08481596589751e+25*cos(theta)**48 + 1.36932018161147e+26*cos(theta)**46 - 1.85746577715317e+26*cos(theta)**44 + 2.05276007615292e+26*cos(theta)**42 - 1.87029251382822e+26*cos(theta)**40 + 1.41633802018059e+26*cos(theta)**38 - 8.96206686036865e+25*cos(theta)**36 + 4.75261121383186e+25*cos(theta)**34 - 2.11436549639942e+25*cos(theta)**32 + 7.88515252792567e+24*cos(theta)**30 - 2.45881100333166e+24*cos(theta)**28 + 6.38345164326489e+23*cos(theta)**26 - 1.37119747789894e+23*cos(theta)**24 + 2.41666988441958e+22*cos(theta)**22 - 3.45666094923172e+21*cos(theta)**20 + 3.9564191587592e+20*cos(theta)**18 - 3.55868389941304e+19*cos(theta)**16 + 2.45708899844398e+18*cos(theta)**14 - 1.26253584900284e+17*cos(theta)**12 + 4.6292981130104e+15*cos(theta)**10 - 114147076759161.0*cos(theta)**8 + 1731374945426.06*cos(theta)**6 - 13940216951.9006*cos(theta)**4 + 44584915.6244156*cos(theta)**2 - 23652.475132316)*sin(3*phi)

#@torch.jit.script
def Yl61_m_minus_2(theta, phi):
    return 0.00117018885995458*(1.0 - cos(theta)**2)*(6.08388546295897e+20*cos(theta)**59 - 8.60291572489487e+21*cos(theta)**57 + 5.76901407434127e+22*cos(theta)**55 - 2.44073672375977e+23*cos(theta)**53 + 7.31159827248035e+23*cos(theta)**51 - 1.6499624420199e+24*cos(theta)**49 + 2.91344719491802e+24*cos(theta)**47 - 4.12770172700705e+24*cos(theta)**45 + 4.7738606422161e+24*cos(theta)**43 - 4.56168905811761e+24*cos(theta)**41 + 3.63163594918101e+24*cos(theta)**39 - 2.42218023253207e+24*cos(theta)**37 + 1.35788891823767e+24*cos(theta)**35 - 6.40716817090735e+23*cos(theta)**33 + 2.54359758965344e+23*cos(theta)**31 - 8.47865863217814e+22*cos(theta)**29 + 2.36424134935737e+22*cos(theta)**27 - 5.48478991159574e+21*cos(theta)**25 + 1.05072603670417e+21*cos(theta)**23 - 1.64602902344368e+20*cos(theta)**21 + 2.08232587303116e+19*cos(theta)**19 - 2.09334347024296e+18*cos(theta)**17 + 1.63805933229599e+17*cos(theta)**15 - 9.71181422309875e+15*cos(theta)**13 + 420845283000946.0*cos(theta)**11 - 12683008528795.6*cos(theta)**9 + 247339277918.008*cos(theta)**7 - 2788043390.38012*cos(theta)**5 + 14861638.5414719*cos(theta)**3 - 23652.475132316*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl61_m_minus_1(theta, phi):
    return 0.0719452058089738*(1.0 - cos(theta)**2)**0.5*(1.01398091049316e+19*cos(theta)**60 - 1.48326133187843e+20*cos(theta)**58 + 1.0301810847038e+21*cos(theta)**56 - 4.51988282177735e+21*cos(theta)**54 + 1.4060765908616e+22*cos(theta)**52 - 3.2999248840398e+22*cos(theta)**50 + 6.06968165607921e+22*cos(theta)**48 - 8.97326462392838e+22*cos(theta)**46 + 1.08496832777639e+23*cos(theta)**44 - 1.08611644240895e+23*cos(theta)**42 + 9.07908987295252e+22*cos(theta)**40 - 6.37415850666334e+22*cos(theta)**38 + 3.77191366177132e+22*cos(theta)**36 - 1.88446122673746e+22*cos(theta)**34 + 7.94874246766701e+21*cos(theta)**32 - 2.82621954405938e+21*cos(theta)**30 + 8.44371910484774e+20*cos(theta)**28 - 2.10953458138298e+20*cos(theta)**26 + 4.37802515293402e+19*cos(theta)**24 - 7.48195010656217e+18*cos(theta)**22 + 1.04116293651558e+18*cos(theta)**20 - 1.16296859457942e+17*cos(theta)**18 + 1.02378708268499e+16*cos(theta)**16 - 693701015935625.0*cos(theta)**14 + 35070440250078.8*cos(theta)**12 - 1268300852879.56*cos(theta)**10 + 30917409739.751*cos(theta)**8 - 464673898.396687*cos(theta)**6 + 3715409.63536797*cos(theta)**4 - 11826.237566158*cos(theta)**2 + 6.25726855352274)*sin(phi)

#@torch.jit.script
def Yl61_m0(theta, phi):
    return 1.63379453984008e+18*cos(theta)**61 - 2.47094546108045e+19*cos(theta)**59 + 1.77638137979355e+20*cos(theta)**57 - 8.07722131666811e+20*cos(theta)**55 + 2.60753775114177e+21*cos(theta)**53 - 6.35962304614754e+21*cos(theta)**51 + 1.2174954029787e+22*cos(theta)**49 - 1.87650667615065e+22*cos(theta)**47 + 2.36974733284913e+22*cos(theta)**45 - 2.48259244393718e+22*cos(theta)**43 + 2.1764863853158e+22*cos(theta)**41 - 1.60640759312237e+22*cos(theta)**39 + 1.00197645328592e+22*cos(theta)**37 - 5.29196128380988e+21*cos(theta)**35 + 2.36745636380968e+21*cos(theta)**33 - 8.96069505441944e+20*cos(theta)**31 + 2.86176043976995e+20*cos(theta)**29 - 7.67927784895306e+19*cos(theta)**27 + 1.72121744890327e+19*cos(theta)**25 - 3.19730795461908e+18*cos(theta)**23 + 4.87300549710017e+17*cos(theta)**21 - 6.01605616925947e+16*cos(theta)**19 + 5.91913466595724e+15*cos(theta)**17 - 454546761473848.0*cos(theta)**15 + 26515227752641.1*cos(theta)**13 - 1133253569701.92*cos(theta)**11 + 33764326291.2274*cos(theta)**9 - 652450749.588935*cos(theta)**7 + 7303553.16704031*cos(theta)**5 - 38745.6401434499*cos(theta)**3 + 61.5010161007142*cos(theta)

#@torch.jit.script
def Yl61_m1(theta, phi):
    return 0.0719452058089738*(1.0 - cos(theta)**2)**0.5*(1.01398091049316e+19*cos(theta)**60 - 1.48326133187843e+20*cos(theta)**58 + 1.0301810847038e+21*cos(theta)**56 - 4.51988282177735e+21*cos(theta)**54 + 1.4060765908616e+22*cos(theta)**52 - 3.2999248840398e+22*cos(theta)**50 + 6.06968165607921e+22*cos(theta)**48 - 8.97326462392838e+22*cos(theta)**46 + 1.08496832777639e+23*cos(theta)**44 - 1.08611644240895e+23*cos(theta)**42 + 9.07908987295252e+22*cos(theta)**40 - 6.37415850666334e+22*cos(theta)**38 + 3.77191366177132e+22*cos(theta)**36 - 1.88446122673746e+22*cos(theta)**34 + 7.94874246766701e+21*cos(theta)**32 - 2.82621954405938e+21*cos(theta)**30 + 8.44371910484774e+20*cos(theta)**28 - 2.10953458138298e+20*cos(theta)**26 + 4.37802515293402e+19*cos(theta)**24 - 7.48195010656217e+18*cos(theta)**22 + 1.04116293651558e+18*cos(theta)**20 - 1.16296859457942e+17*cos(theta)**18 + 1.02378708268499e+16*cos(theta)**16 - 693701015935625.0*cos(theta)**14 + 35070440250078.8*cos(theta)**12 - 1268300852879.56*cos(theta)**10 + 30917409739.751*cos(theta)**8 - 464673898.396687*cos(theta)**6 + 3715409.63536797*cos(theta)**4 - 11826.237566158*cos(theta)**2 + 6.25726855352274)*cos(phi)

#@torch.jit.script
def Yl61_m2(theta, phi):
    return 0.00117018885995458*(1.0 - cos(theta)**2)*(6.08388546295897e+20*cos(theta)**59 - 8.60291572489487e+21*cos(theta)**57 + 5.76901407434127e+22*cos(theta)**55 - 2.44073672375977e+23*cos(theta)**53 + 7.31159827248035e+23*cos(theta)**51 - 1.6499624420199e+24*cos(theta)**49 + 2.91344719491802e+24*cos(theta)**47 - 4.12770172700705e+24*cos(theta)**45 + 4.7738606422161e+24*cos(theta)**43 - 4.56168905811761e+24*cos(theta)**41 + 3.63163594918101e+24*cos(theta)**39 - 2.42218023253207e+24*cos(theta)**37 + 1.35788891823767e+24*cos(theta)**35 - 6.40716817090735e+23*cos(theta)**33 + 2.54359758965344e+23*cos(theta)**31 - 8.47865863217814e+22*cos(theta)**29 + 2.36424134935737e+22*cos(theta)**27 - 5.48478991159574e+21*cos(theta)**25 + 1.05072603670417e+21*cos(theta)**23 - 1.64602902344368e+20*cos(theta)**21 + 2.08232587303116e+19*cos(theta)**19 - 2.09334347024296e+18*cos(theta)**17 + 1.63805933229599e+17*cos(theta)**15 - 9.71181422309875e+15*cos(theta)**13 + 420845283000946.0*cos(theta)**11 - 12683008528795.6*cos(theta)**9 + 247339277918.008*cos(theta)**7 - 2788043390.38012*cos(theta)**5 + 14861638.5414719*cos(theta)**3 - 23652.475132316*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl61_m3(theta, phi):
    return 1.90432016649223e-5*(1.0 - cos(theta)**2)**1.5*(3.58949242314579e+22*cos(theta)**58 - 4.90366196319008e+23*cos(theta)**56 + 3.1729577408877e+24*cos(theta)**54 - 1.29359046359268e+25*cos(theta)**52 + 3.72891511896498e+25*cos(theta)**50 - 8.08481596589751e+25*cos(theta)**48 + 1.36932018161147e+26*cos(theta)**46 - 1.85746577715317e+26*cos(theta)**44 + 2.05276007615292e+26*cos(theta)**42 - 1.87029251382822e+26*cos(theta)**40 + 1.41633802018059e+26*cos(theta)**38 - 8.96206686036865e+25*cos(theta)**36 + 4.75261121383186e+25*cos(theta)**34 - 2.11436549639942e+25*cos(theta)**32 + 7.88515252792567e+24*cos(theta)**30 - 2.45881100333166e+24*cos(theta)**28 + 6.38345164326489e+23*cos(theta)**26 - 1.37119747789894e+23*cos(theta)**24 + 2.41666988441958e+22*cos(theta)**22 - 3.45666094923172e+21*cos(theta)**20 + 3.9564191587592e+20*cos(theta)**18 - 3.55868389941304e+19*cos(theta)**16 + 2.45708899844398e+18*cos(theta)**14 - 1.26253584900284e+17*cos(theta)**12 + 4.6292981130104e+15*cos(theta)**10 - 114147076759161.0*cos(theta)**8 + 1731374945426.06*cos(theta)**6 - 13940216951.9006*cos(theta)**4 + 44584915.6244156*cos(theta)**2 - 23652.475132316)*cos(3*phi)

#@torch.jit.script
def Yl61_m4(theta, phi):
    return 3.10148218887814e-7*(1.0 - cos(theta)**2)**2*(2.08190560542456e+24*cos(theta)**57 - 2.74605069938644e+25*cos(theta)**55 + 1.71339718007936e+26*cos(theta)**53 - 6.72667041068192e+26*cos(theta)**51 + 1.86445755948249e+27*cos(theta)**49 - 3.88071166363081e+27*cos(theta)**47 + 6.29887283541277e+27*cos(theta)**45 - 8.17284941947397e+27*cos(theta)**43 + 8.62159231984228e+27*cos(theta)**41 - 7.48117005531288e+27*cos(theta)**39 + 5.38208447668626e+27*cos(theta)**37 - 3.22634406973272e+27*cos(theta)**35 + 1.61588781270283e+27*cos(theta)**33 - 6.76596958847816e+26*cos(theta)**31 + 2.3655457583777e+26*cos(theta)**29 - 6.88467080932865e+25*cos(theta)**27 + 1.65969742724887e+25*cos(theta)**25 - 3.29087394695745e+24*cos(theta)**23 + 5.31667374572308e+23*cos(theta)**21 - 6.91332189846344e+22*cos(theta)**19 + 7.12155448576656e+21*cos(theta)**17 - 5.69389423906086e+20*cos(theta)**15 + 3.43992459782158e+19*cos(theta)**13 - 1.5150430188034e+18*cos(theta)**11 + 4.6292981130104e+16*cos(theta)**9 - 913176614073285.0*cos(theta)**7 + 10388249672556.3*cos(theta)**5 - 55760867807.6024*cos(theta)**3 + 89169831.2488312*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl61_m5(theta, phi):
    return 5.05661508405203e-9*(1.0 - cos(theta)**2)**2.5*(1.186686195092e+26*cos(theta)**56 - 1.51032788466254e+27*cos(theta)**54 + 9.08100505442059e+27*cos(theta)**52 - 3.43060190944778e+28*cos(theta)**50 + 9.13584204146419e+28*cos(theta)**48 - 1.82393448190648e+29*cos(theta)**46 + 2.83449277593574e+29*cos(theta)**44 - 3.51432525037381e+29*cos(theta)**42 + 3.53485285113534e+29*cos(theta)**40 - 2.91765632157202e+29*cos(theta)**38 + 1.99137125637391e+29*cos(theta)**36 - 1.12922042440645e+29*cos(theta)**34 + 5.33242978191935e+28*cos(theta)**32 - 2.09745057242823e+28*cos(theta)**30 + 6.86008269929534e+27*cos(theta)**28 - 1.85886111851874e+27*cos(theta)**26 + 4.14924356812218e+26*cos(theta)**24 - 7.56901007800212e+25*cos(theta)**22 + 1.11650148660185e+25*cos(theta)**20 - 1.31353116070805e+24*cos(theta)**18 + 1.21066426258031e+23*cos(theta)**16 - 8.54084135859129e+21*cos(theta)**14 + 4.47190197716805e+20*cos(theta)**12 - 1.66654732068375e+19*cos(theta)**10 + 4.16636830170936e+17*cos(theta)**8 - 6.392236298513e+15*cos(theta)**6 + 51941248362781.7*cos(theta)**4 - 167282603422.807*cos(theta)**2 + 89169831.2488312)*cos(5*phi)

#@torch.jit.script
def Yl61_m6(theta, phi):
    return 8.25521675669756e-11*(1.0 - cos(theta)**2)**3*(6.64544269251519e+27*cos(theta)**55 - 8.15577057717774e+28*cos(theta)**53 + 4.72212262829871e+29*cos(theta)**51 - 1.71530095472389e+30*cos(theta)**49 + 4.38520417990281e+30*cos(theta)**47 - 8.3900986167698e+30*cos(theta)**45 + 1.24717682141173e+31*cos(theta)**43 - 1.476016605157e+31*cos(theta)**41 + 1.41394114045413e+31*cos(theta)**39 - 1.10870940219737e+31*cos(theta)**37 + 7.16893652294609e+30*cos(theta)**35 - 3.83934944298193e+30*cos(theta)**33 + 1.70637753021419e+30*cos(theta)**31 - 6.29235171728469e+29*cos(theta)**29 + 1.92082315580269e+29*cos(theta)**27 - 4.83303890814871e+28*cos(theta)**25 + 9.95818456349323e+27*cos(theta)**23 - 1.66518221716047e+27*cos(theta)**21 + 2.23300297320369e+26*cos(theta)**19 - 2.3643560892745e+25*cos(theta)**17 + 1.9370628201285e+24*cos(theta)**15 - 1.19571779020278e+23*cos(theta)**13 + 5.36628237260166e+21*cos(theta)**11 - 1.66654732068375e+20*cos(theta)**9 + 3.33309464136749e+18*cos(theta)**7 - 3.8353417791078e+16*cos(theta)**5 + 207764993451127.0*cos(theta)**3 - 334565206845.615*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl61_m7(theta, phi):
    return 1.3498722825312e-12*(1.0 - cos(theta)**2)**3.5*(3.65499348088336e+29*cos(theta)**54 - 4.3225584059042e+30*cos(theta)**52 + 2.40828254043234e+31*cos(theta)**50 - 8.40497467814706e+31*cos(theta)**48 + 2.06104596455432e+32*cos(theta)**46 - 3.77554437754641e+32*cos(theta)**44 + 5.36286033207043e+32*cos(theta)**42 - 6.05166808114369e+32*cos(theta)**40 + 5.51437044777112e+32*cos(theta)**38 - 4.10222478813026e+32*cos(theta)**36 + 2.50912778303113e+32*cos(theta)**34 - 1.26698531618404e+32*cos(theta)**32 + 5.28977034366399e+31*cos(theta)**30 - 1.82478199801256e+31*cos(theta)**28 + 5.18622252066727e+30*cos(theta)**26 - 1.20825972703718e+30*cos(theta)**24 + 2.29038244960344e+29*cos(theta)**22 - 3.49688265603698e+28*cos(theta)**20 + 4.24270564908701e+27*cos(theta)**18 - 4.01940535176665e+26*cos(theta)**16 + 2.90559423019276e+25*cos(theta)**14 - 1.55443312726361e+24*cos(theta)**12 + 5.90291060986183e+22*cos(theta)**10 - 1.49989258861537e+21*cos(theta)**8 + 2.33316624895724e+19*cos(theta)**6 - 1.9176708895539e+17*cos(theta)**4 + 623294980353380.0*cos(theta)**2 - 334565206845.615)*cos(7*phi)

#@torch.jit.script
def Yl61_m8(theta, phi):
    return 2.21142010995196e-14*(1.0 - cos(theta)**2)**4*(1.97369647967701e+31*cos(theta)**53 - 2.24773037107018e+32*cos(theta)**51 + 1.20414127021617e+33*cos(theta)**49 - 4.03438784551059e+33*cos(theta)**47 + 9.48081143694988e+33*cos(theta)**45 - 1.66123952612042e+34*cos(theta)**43 + 2.25240133946958e+34*cos(theta)**41 - 2.42066723245748e+34*cos(theta)**39 + 2.09546077015303e+34*cos(theta)**37 - 1.4768009237269e+34*cos(theta)**35 + 8.53103446230585e+33*cos(theta)**33 - 4.05435301178892e+33*cos(theta)**31 + 1.5869311030992e+33*cos(theta)**29 - 5.10938959443517e+32*cos(theta)**27 + 1.34841785537349e+32*cos(theta)**25 - 2.89982334488923e+31*cos(theta)**23 + 5.03884138912757e+30*cos(theta)**21 - 6.99376531207396e+29*cos(theta)**19 + 7.63687016835663e+28*cos(theta)**17 - 6.43104856282663e+27*cos(theta)**15 + 4.06783192226986e+26*cos(theta)**13 - 1.86531975271634e+25*cos(theta)**11 + 5.90291060986183e+23*cos(theta)**9 - 1.1999140708923e+22*cos(theta)**7 + 1.39989974937435e+20*cos(theta)**5 - 7.6706835582156e+17*cos(theta)**3 + 1.24658996070676e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl61_m9(theta, phi):
    return 3.63064929358258e-16*(1.0 - cos(theta)**2)**4.5*(1.04605913422882e+33*cos(theta)**52 - 1.14634248924579e+34*cos(theta)**50 + 5.90029222405923e+34*cos(theta)**48 - 1.89616228738998e+35*cos(theta)**46 + 4.26636514662745e+35*cos(theta)**44 - 7.14332996231781e+35*cos(theta)**42 + 9.23484549182528e+35*cos(theta)**40 - 9.44060220658416e+35*cos(theta)**38 + 7.7532048495662e+35*cos(theta)**36 - 5.16880323304413e+35*cos(theta)**34 + 2.81524137256093e+35*cos(theta)**32 - 1.25684943365456e+35*cos(theta)**30 + 4.60210019898767e+34*cos(theta)**28 - 1.37953519049749e+34*cos(theta)**26 + 3.37104463843373e+33*cos(theta)**24 - 6.66959369324523e+32*cos(theta)**22 + 1.05815669171679e+32*cos(theta)**20 - 1.32881540929405e+31*cos(theta)**18 + 1.29826792862063e+30*cos(theta)**16 - 9.64657284423995e+28*cos(theta)**14 + 5.28818149895081e+27*cos(theta)**12 - 2.05185172798797e+26*cos(theta)**10 + 5.31261954887564e+24*cos(theta)**8 - 8.39939849624608e+22*cos(theta)**6 + 6.99949874687173e+20*cos(theta)**4 - 2.30120506746468e+18*cos(theta)**2 + 1.24658996070676e+15)*cos(9*phi)

#@torch.jit.script
def Yl61_m10(theta, phi):
    return 5.97521385742017e-18*(1.0 - cos(theta)**2)**5*(5.43950749798985e+34*cos(theta)**51 - 5.73171244622897e+35*cos(theta)**49 + 2.83214026754843e+36*cos(theta)**47 - 8.72234652199389e+36*cos(theta)**45 + 1.87720066451608e+37*cos(theta)**43 - 3.00019858417348e+37*cos(theta)**41 + 3.69393819673011e+37*cos(theta)**39 - 3.58742883850198e+37*cos(theta)**37 + 2.79115374584383e+37*cos(theta)**35 - 1.75739309923501e+37*cos(theta)**33 + 9.00877239219498e+36*cos(theta)**31 - 3.77054830096369e+36*cos(theta)**29 + 1.28858805571655e+36*cos(theta)**27 - 3.58679149529349e+35*cos(theta)**25 + 8.09050713224095e+34*cos(theta)**23 - 1.46731061251395e+34*cos(theta)**21 + 2.11631338343358e+33*cos(theta)**19 - 2.3918677367293e+32*cos(theta)**17 + 2.077228685793e+31*cos(theta)**15 - 1.35052019819359e+30*cos(theta)**13 + 6.34581779874098e+28*cos(theta)**11 - 2.05185172798797e+27*cos(theta)**9 + 4.25009563910051e+25*cos(theta)**7 - 5.03963909774765e+23*cos(theta)**5 + 2.79979949874869e+21*cos(theta)**3 - 4.60241013492936e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl61_m11(theta, phi):
    return 9.8605721994746e-20*(1.0 - cos(theta)**2)**5.5*(2.77414882397482e+36*cos(theta)**50 - 2.80853909865219e+37*cos(theta)**48 + 1.33110592574776e+38*cos(theta)**46 - 3.92505593489725e+38*cos(theta)**44 + 8.07196285741913e+38*cos(theta)**42 - 1.23008141951113e+39*cos(theta)**40 + 1.44063589672474e+39*cos(theta)**38 - 1.32734867024573e+39*cos(theta)**36 + 9.76903811045341e+38*cos(theta)**34 - 5.79939722747552e+38*cos(theta)**32 + 2.79271944158044e+38*cos(theta)**30 - 1.09345900727947e+38*cos(theta)**28 + 3.47918775043468e+37*cos(theta)**26 - 8.96697873823372e+36*cos(theta)**24 + 1.86081664041542e+36*cos(theta)**22 - 3.08135228627929e+35*cos(theta)**20 + 4.0209954285238e+34*cos(theta)**18 - 4.0661751524398e+33*cos(theta)**16 + 3.1158430286895e+32*cos(theta)**14 - 1.75567625765167e+31*cos(theta)**12 + 6.98039957861508e+29*cos(theta)**10 - 1.84666655518917e+28*cos(theta)**8 + 2.97506694737036e+26*cos(theta)**6 - 2.51981954887382e+24*cos(theta)**4 + 8.39939849624608e+21*cos(theta)**2 - 4.60241013492936e+18)*cos(11*phi)

#@torch.jit.script
def Yl61_m12(theta, phi):
    return 1.6321335234548e-21*(1.0 - cos(theta)**2)**6*(1.38707441198741e+38*cos(theta)**49 - 1.34809876735305e+39*cos(theta)**47 + 6.12308725843971e+39*cos(theta)**45 - 1.72702461135479e+40*cos(theta)**43 + 3.39022440011603e+40*cos(theta)**41 - 4.92032567804451e+40*cos(theta)**39 + 5.47441640755402e+40*cos(theta)**37 - 4.77845521288464e+40*cos(theta)**35 + 3.32147295755416e+40*cos(theta)**33 - 1.85580711279217e+40*cos(theta)**31 + 8.37815832474133e+39*cos(theta)**29 - 3.06168522038252e+39*cos(theta)**27 + 9.04588815113017e+38*cos(theta)**25 - 2.15207489717609e+38*cos(theta)**23 + 4.09379660891392e+37*cos(theta)**21 - 6.16270457255859e+36*cos(theta)**19 + 7.23779177134285e+35*cos(theta)**17 - 6.50588024390368e+34*cos(theta)**15 + 4.3621802401653e+33*cos(theta)**13 - 2.106811509182e+32*cos(theta)**11 + 6.98039957861508e+30*cos(theta)**9 - 1.47733324415134e+29*cos(theta)**7 + 1.78504016842222e+27*cos(theta)**5 - 1.00792781954953e+25*cos(theta)**3 + 1.67987969924922e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl61_m13(theta, phi):
    return 2.71045240308929e-23*(1.0 - cos(theta)**2)**6.5*(6.79666461873831e+39*cos(theta)**48 - 6.33606420655935e+40*cos(theta)**46 + 2.75538926629787e+41*cos(theta)**44 - 7.4262058288256e+41*cos(theta)**42 + 1.38999200404757e+42*cos(theta)**40 - 1.91892701443736e+42*cos(theta)**38 + 2.02553407079499e+42*cos(theta)**36 - 1.67245932450962e+42*cos(theta)**34 + 1.09608607599287e+42*cos(theta)**32 - 5.75300204965571e+41*cos(theta)**30 + 2.42966591417499e+41*cos(theta)**28 - 8.26655009503281e+40*cos(theta)**26 + 2.26147203778254e+40*cos(theta)**24 - 4.94977226350501e+39*cos(theta)**22 + 8.59697287871923e+38*cos(theta)**20 - 1.17091386878613e+38*cos(theta)**18 + 1.23042460112828e+37*cos(theta)**16 - 9.75882036585553e+35*cos(theta)**14 + 5.6708343122149e+34*cos(theta)**12 - 2.31749266010021e+33*cos(theta)**10 + 6.28235962075357e+31*cos(theta)**8 - 1.03413327090594e+30*cos(theta)**6 + 8.92520084211108e+27*cos(theta)**4 - 3.02378345864859e+25*cos(theta)**2 + 1.67987969924922e+22)*cos(13*phi)

#@torch.jit.script
def Yl61_m14(theta, phi):
    return 4.51742067181548e-25*(1.0 - cos(theta)**2)**7*(3.26239901699439e+41*cos(theta)**47 - 2.9145895350173e+42*cos(theta)**45 + 1.21237127717106e+43*cos(theta)**43 - 3.11900644810675e+43*cos(theta)**41 + 5.55996801619029e+43*cos(theta)**39 - 7.29192265486196e+43*cos(theta)**37 + 7.29192265486196e+43*cos(theta)**35 - 5.68636170333272e+43*cos(theta)**33 + 3.50747544317719e+43*cos(theta)**31 - 1.72590061489671e+43*cos(theta)**29 + 6.80306455968996e+42*cos(theta)**27 - 2.14930302470853e+42*cos(theta)**25 + 5.4275328906781e+41*cos(theta)**23 - 1.0889498979711e+41*cos(theta)**21 + 1.71939457574385e+40*cos(theta)**19 - 2.10764496381504e+39*cos(theta)**17 + 1.96867936180525e+38*cos(theta)**15 - 1.36623485121977e+37*cos(theta)**13 + 6.80500117465788e+35*cos(theta)**11 - 2.31749266010021e+34*cos(theta)**9 + 5.02588769660285e+32*cos(theta)**7 - 6.20479962543562e+30*cos(theta)**5 + 3.57008033684443e+28*cos(theta)**3 - 6.04756691729717e+25*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl61_m15(theta, phi):
    return 7.55848594360317e-27*(1.0 - cos(theta)**2)**7.5*(1.53332753798736e+43*cos(theta)**46 - 1.31156529075779e+44*cos(theta)**44 + 5.21319649183557e+44*cos(theta)**42 - 1.27879264372377e+45*cos(theta)**40 + 2.16838752631421e+45*cos(theta)**38 - 2.69801138229893e+45*cos(theta)**36 + 2.55217292920169e+45*cos(theta)**34 - 1.8764993620998e+45*cos(theta)**32 + 1.08731738738493e+45*cos(theta)**30 - 5.00511178320047e+44*cos(theta)**28 + 1.83682743111629e+44*cos(theta)**26 - 5.37325756177132e+43*cos(theta)**24 + 1.24833256485596e+43*cos(theta)**22 - 2.28679478573932e+42*cos(theta)**20 + 3.26684969391331e+41*cos(theta)**18 - 3.58299643848556e+40*cos(theta)**16 + 2.95301904270788e+39*cos(theta)**14 - 1.77610530658571e+38*cos(theta)**12 + 7.48550129212366e+36*cos(theta)**10 - 2.08574339409018e+35*cos(theta)**8 + 3.518121387622e+33*cos(theta)**6 - 3.10239981271781e+31*cos(theta)**4 + 1.07102410105333e+29*cos(theta)**2 - 6.04756691729717e+25)*cos(15*phi)

#@torch.jit.script
def Yl61_m16(theta, phi):
    return 1.27001991563108e-28*(1.0 - cos(theta)**2)**8*(7.05330667474187e+44*cos(theta)**45 - 5.77088727933426e+45*cos(theta)**43 + 2.18954252657094e+46*cos(theta)**41 - 5.11517057489507e+46*cos(theta)**39 + 8.23987259999402e+46*cos(theta)**37 - 9.71284097627613e+46*cos(theta)**35 + 8.67738795928573e+46*cos(theta)**33 - 6.00479795871935e+46*cos(theta)**31 + 3.26195216215479e+46*cos(theta)**29 - 1.40143129929613e+46*cos(theta)**27 + 4.77575132090235e+45*cos(theta)**25 - 1.28958181482512e+45*cos(theta)**23 + 2.74633164268312e+44*cos(theta)**21 - 4.57358957147863e+43*cos(theta)**19 + 5.88032944904395e+42*cos(theta)**17 - 5.7327943015769e+41*cos(theta)**15 + 4.13422665979103e+40*cos(theta)**13 - 2.13132636790285e+39*cos(theta)**11 + 7.48550129212366e+37*cos(theta)**9 - 1.66859471527215e+36*cos(theta)**7 + 2.1108728325732e+34*cos(theta)**5 - 1.24095992508712e+32*cos(theta)**3 + 2.14204820210666e+29*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl61_m17(theta, phi):
    return 2.14366527589978e-30*(1.0 - cos(theta)**2)**8.5*(3.17398800363384e+46*cos(theta)**44 - 2.48148153011373e+47*cos(theta)**42 + 8.97712435894085e+47*cos(theta)**40 - 1.99491652420908e+48*cos(theta)**38 + 3.04875286199779e+48*cos(theta)**36 - 3.39949434169665e+48*cos(theta)**34 + 2.86353802656429e+48*cos(theta)**32 - 1.861487367203e+48*cos(theta)**30 + 9.45966127024889e+47*cos(theta)**28 - 3.78386450809956e+47*cos(theta)**26 + 1.19393783022559e+47*cos(theta)**24 - 2.96603817409777e+46*cos(theta)**22 + 5.76729644963455e+45*cos(theta)**20 - 8.6898201858094e+44*cos(theta)**18 + 9.99656006337472e+43*cos(theta)**16 - 8.59919145236535e+42*cos(theta)**14 + 5.37449465772834e+41*cos(theta)**12 - 2.34445900469313e+40*cos(theta)**10 + 6.7369511629113e+38*cos(theta)**8 - 1.1680163006905e+37*cos(theta)**6 + 1.0554364162866e+35*cos(theta)**4 - 3.72287977526137e+32*cos(theta)**2 + 2.14204820210666e+29)*cos(17*phi)

#@torch.jit.script
def Yl61_m18(theta, phi):
    return 3.63594319225306e-32*(1.0 - cos(theta)**2)**9*(1.39655472159889e+48*cos(theta)**43 - 1.04222224264777e+49*cos(theta)**41 + 3.59084974357634e+49*cos(theta)**39 - 7.5806827919945e+49*cos(theta)**37 + 1.0975510303192e+50*cos(theta)**35 - 1.15582807617686e+50*cos(theta)**33 + 9.16332168500574e+49*cos(theta)**31 - 5.584462101609e+49*cos(theta)**29 + 2.64870515566969e+49*cos(theta)**27 - 9.83804772105885e+48*cos(theta)**25 + 2.86545079254141e+48*cos(theta)**23 - 6.5252839830151e+47*cos(theta)**21 + 1.15345928992691e+47*cos(theta)**19 - 1.56416763344569e+46*cos(theta)**17 + 1.59944961013996e+45*cos(theta)**15 - 1.20388680333115e+44*cos(theta)**13 + 6.44939358927401e+42*cos(theta)**11 - 2.34445900469313e+41*cos(theta)**9 + 5.38956093032904e+39*cos(theta)**7 - 7.00809780414302e+37*cos(theta)**5 + 4.2217456651464e+35*cos(theta)**3 - 7.44575955052275e+32*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl61_m19(theta, phi):
    return 6.19923168938198e-34*(1.0 - cos(theta)**2)**9.5*(6.00518530287523e+49*cos(theta)**42 - 4.27311119485584e+50*cos(theta)**40 + 1.40043139999477e+51*cos(theta)**38 - 2.80485263303796e+51*cos(theta)**36 + 3.84142860611721e+51*cos(theta)**34 - 3.81423265138364e+51*cos(theta)**32 + 2.84062972235178e+51*cos(theta)**30 - 1.61949400946661e+51*cos(theta)**28 + 7.15150392030816e+50*cos(theta)**26 - 2.45951193026471e+50*cos(theta)**24 + 6.59053682284525e+49*cos(theta)**22 - 1.37030963643317e+49*cos(theta)**20 + 2.19157265086113e+48*cos(theta)**18 - 2.65908497685768e+47*cos(theta)**16 + 2.39917441520993e+46*cos(theta)**14 - 1.56505284433049e+45*cos(theta)**12 + 7.09433294820142e+43*cos(theta)**10 - 2.11001310422382e+42*cos(theta)**8 + 3.77269265123033e+40*cos(theta)**6 - 3.50404890207151e+38*cos(theta)**4 + 1.26652369954392e+36*cos(theta)**2 - 7.44575955052275e+32)*cos(19*phi)

#@torch.jit.script
def Yl61_m20(theta, phi):
    return 1.06284690762533e-35*(1.0 - cos(theta)**2)**10*(2.5221778272076e+51*cos(theta)**41 - 1.70924447794234e+52*cos(theta)**39 + 5.32163931998014e+52*cos(theta)**37 - 1.00974694789367e+53*cos(theta)**35 + 1.30608572607985e+53*cos(theta)**33 - 1.22055444844276e+53*cos(theta)**31 + 8.52188916705533e+52*cos(theta)**29 - 4.53458322650651e+52*cos(theta)**27 + 1.85939101928012e+52*cos(theta)**25 - 5.90282863263531e+51*cos(theta)**23 + 1.44991810102595e+51*cos(theta)**21 - 2.74061927286634e+50*cos(theta)**19 + 3.94483077155003e+49*cos(theta)**17 - 4.25453596297228e+48*cos(theta)**15 + 3.35884418129391e+47*cos(theta)**13 - 1.87806341319659e+46*cos(theta)**11 + 7.09433294820142e+44*cos(theta)**9 - 1.68801048337905e+43*cos(theta)**7 + 2.2636155907382e+41*cos(theta)**5 - 1.4016195608286e+39*cos(theta)**3 + 2.53304739908784e+36*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl61_m21(theta, phi):
    return 1.83303964815859e-37*(1.0 - cos(theta)**2)**10.5*(1.03409290915511e+53*cos(theta)**40 - 6.66605346397512e+53*cos(theta)**38 + 1.96900654839265e+54*cos(theta)**36 - 3.53411431762783e+54*cos(theta)**34 + 4.31008289606351e+54*cos(theta)**32 - 3.78371879017257e+54*cos(theta)**30 + 2.47134785844605e+54*cos(theta)**28 - 1.22433747115676e+54*cos(theta)**26 + 4.6484775482003e+53*cos(theta)**24 - 1.35765058550612e+53*cos(theta)**22 + 3.0448280121545e+52*cos(theta)**20 - 5.20717661844605e+51*cos(theta)**18 + 6.70621231163506e+50*cos(theta)**16 - 6.38180394445842e+49*cos(theta)**14 + 4.36649743568208e+48*cos(theta)**12 - 2.06586975451625e+47*cos(theta)**10 + 6.38489965338127e+45*cos(theta)**8 - 1.18160733836534e+44*cos(theta)**6 + 1.1318077953691e+42*cos(theta)**4 - 4.20485868248581e+39*cos(theta)**2 + 2.53304739908784e+36)*cos(21*phi)

#@torch.jit.script
def Yl61_m22(theta, phi):
    return 3.18128675173288e-39*(1.0 - cos(theta)**2)**11*(4.13637163662046e+54*cos(theta)**39 - 2.53310031631054e+55*cos(theta)**37 + 7.08842357421354e+55*cos(theta)**35 - 1.20159886799346e+56*cos(theta)**33 + 1.37922652674032e+56*cos(theta)**31 - 1.13511563705177e+56*cos(theta)**29 + 6.91977400364893e+55*cos(theta)**27 - 3.18327742500757e+55*cos(theta)**25 + 1.11563461156807e+55*cos(theta)**23 - 2.98683128811347e+54*cos(theta)**21 + 6.08965602430901e+53*cos(theta)**19 - 9.37291791320288e+52*cos(theta)**17 + 1.07299396986161e+52*cos(theta)**15 - 8.93452552224179e+50*cos(theta)**13 + 5.23979692281849e+49*cos(theta)**11 - 2.06586975451625e+48*cos(theta)**9 + 5.10791972270502e+46*cos(theta)**7 - 7.08964403019203e+44*cos(theta)**5 + 4.52723118147639e+42*cos(theta)**3 - 8.40971736497163e+39*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl61_m23(theta, phi):
    return 5.55815777184317e-41*(1.0 - cos(theta)**2)**11.5*(1.61318493828198e+56*cos(theta)**38 - 9.37247117034901e+56*cos(theta)**36 + 2.48094825097474e+57*cos(theta)**34 - 3.96527626437843e+57*cos(theta)**32 + 4.275602232895e+57*cos(theta)**30 - 3.29183534745013e+57*cos(theta)**28 + 1.86833898098521e+57*cos(theta)**26 - 7.95819356251892e+56*cos(theta)**24 + 2.56595960660657e+56*cos(theta)**22 - 6.27234570503828e+55*cos(theta)**20 + 1.15703464461871e+55*cos(theta)**18 - 1.59339604524449e+54*cos(theta)**16 + 1.60949095479241e+53*cos(theta)**14 - 1.16148831789143e+52*cos(theta)**12 + 5.76377661510034e+50*cos(theta)**10 - 1.85928277906463e+49*cos(theta)**8 + 3.57554380589351e+47*cos(theta)**6 - 3.54482201509601e+45*cos(theta)**4 + 1.35816935444292e+43*cos(theta)**2 - 8.40971736497163e+39)*cos(23*phi)

#@torch.jit.script
def Yl61_m24(theta, phi):
    return 9.77979179767568e-43*(1.0 - cos(theta)**2)**12*(6.13010276547152e+57*cos(theta)**37 - 3.37408962132565e+58*cos(theta)**35 + 8.43522405331411e+58*cos(theta)**33 - 1.2688884046011e+59*cos(theta)**31 + 1.2826806698685e+59*cos(theta)**29 - 9.21713897286038e+58*cos(theta)**27 + 4.85768135056155e+58*cos(theta)**25 - 1.90996645500454e+58*cos(theta)**23 + 5.64511113453445e+57*cos(theta)**21 - 1.25446914100766e+57*cos(theta)**19 + 2.08266236031368e+56*cos(theta)**17 - 2.54943367239118e+55*cos(theta)**15 + 2.25328733670938e+54*cos(theta)**13 - 1.39378598146972e+53*cos(theta)**11 + 5.76377661510034e+51*cos(theta)**9 - 1.4874262232517e+50*cos(theta)**7 + 2.14532628353611e+48*cos(theta)**5 - 1.41792880603841e+46*cos(theta)**3 + 2.71633870888584e+43*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl61_m25(theta, phi):
    return 1.73372224485625e-44*(1.0 - cos(theta)**2)**12.5*(2.26813802322446e+59*cos(theta)**36 - 1.18093136746398e+60*cos(theta)**34 + 2.78362393759366e+60*cos(theta)**32 - 3.9335540542634e+60*cos(theta)**30 + 3.71977394261865e+60*cos(theta)**28 - 2.4886275226723e+60*cos(theta)**26 + 1.21442033764039e+60*cos(theta)**24 - 4.39292284651044e+59*cos(theta)**22 + 1.18547333825223e+59*cos(theta)**20 - 2.38349136791455e+58*cos(theta)**18 + 3.54052601253326e+57*cos(theta)**16 - 3.82415050858678e+56*cos(theta)**14 + 2.92927353772219e+55*cos(theta)**12 - 1.53316457961669e+54*cos(theta)**10 + 5.18739895359031e+52*cos(theta)**8 - 1.04119835627619e+51*cos(theta)**6 + 1.07266314176805e+49*cos(theta)**4 - 4.25378641811522e+46*cos(theta)**2 + 2.71633870888584e+43)*cos(25*phi)

#@torch.jit.script
def Yl61_m26(theta, phi):
    return 3.09790891772917e-46*(1.0 - cos(theta)**2)**13*(8.16529688360806e+60*cos(theta)**35 - 4.01516664937752e+61*cos(theta)**33 + 8.9075966002997e+61*cos(theta)**31 - 1.18006621627902e+62*cos(theta)**29 + 1.04153670393322e+62*cos(theta)**27 - 6.47043155894798e+61*cos(theta)**25 + 2.91460881033693e+61*cos(theta)**23 - 9.66443026232298e+60*cos(theta)**21 + 2.37094667650447e+60*cos(theta)**19 - 4.29028446224618e+59*cos(theta)**17 + 5.66484162005321e+58*cos(theta)**15 - 5.35381071202149e+57*cos(theta)**13 + 3.51512824526663e+56*cos(theta)**11 - 1.53316457961669e+55*cos(theta)**9 + 4.14991916287225e+53*cos(theta)**7 - 6.24719013765715e+51*cos(theta)**5 + 4.29065256707222e+49*cos(theta)**3 - 8.50757283623044e+46*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl61_m27(theta, phi):
    return 5.58204440000173e-48*(1.0 - cos(theta)**2)**13.5*(2.85785390926282e+62*cos(theta)**34 - 1.32500499429458e+63*cos(theta)**32 + 2.76135494609291e+63*cos(theta)**30 - 3.42219202720916e+63*cos(theta)**28 + 2.8121491006197e+63*cos(theta)**26 - 1.617607889737e+63*cos(theta)**24 + 6.70360026377494e+62*cos(theta)**22 - 2.02953035508783e+62*cos(theta)**20 + 4.50479868535849e+61*cos(theta)**18 - 7.29348358581851e+60*cos(theta)**16 + 8.49726243007982e+59*cos(theta)**14 - 6.95995392562793e+58*cos(theta)**12 + 3.8666410697933e+57*cos(theta)**10 - 1.37984812165502e+56*cos(theta)**8 + 2.90494341401057e+54*cos(theta)**6 - 3.12359506882857e+52*cos(theta)**4 + 1.28719577012166e+50*cos(theta)**2 - 8.50757283623044e+46)*cos(27*phi)

#@torch.jit.script
def Yl61_m28(theta, phi):
    return 1.01474945031427e-49*(1.0 - cos(theta)**2)**14*(9.71670329149359e+63*cos(theta)**33 - 4.24001598174266e+64*cos(theta)**31 + 8.28406483827872e+64*cos(theta)**29 - 9.58213767618565e+64*cos(theta)**27 + 7.31158766161122e+64*cos(theta)**25 - 3.88225893536879e+64*cos(theta)**23 + 1.47479205803049e+64*cos(theta)**21 - 4.05906071017565e+63*cos(theta)**19 + 8.10863763364528e+62*cos(theta)**17 - 1.16695737373096e+62*cos(theta)**15 + 1.18961674021117e+61*cos(theta)**13 - 8.35194471075352e+59*cos(theta)**11 + 3.8666410697933e+58*cos(theta)**9 - 1.10387849732402e+57*cos(theta)**7 + 1.74296604840634e+55*cos(theta)**5 - 1.24943802753143e+53*cos(theta)**3 + 2.57439154024333e+50*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl61_m29(theta, phi):
    return 1.86200395912983e-51*(1.0 - cos(theta)**2)**14.5*(3.20651208619289e+65*cos(theta)**32 - 1.31440495434022e+66*cos(theta)**30 + 2.40237880310083e+66*cos(theta)**28 - 2.58717717257012e+66*cos(theta)**26 + 1.82789691540281e+66*cos(theta)**24 - 8.92919555134822e+65*cos(theta)**22 + 3.09706332186402e+65*cos(theta)**20 - 7.71221534933374e+64*cos(theta)**18 + 1.3784683977197e+64*cos(theta)**16 - 1.75043606059644e+63*cos(theta)**14 + 1.54650176227453e+62*cos(theta)**12 - 9.18713918182887e+60*cos(theta)**10 + 3.47997696281397e+59*cos(theta)**8 - 7.72714948126812e+57*cos(theta)**6 + 8.71483024203172e+55*cos(theta)**4 - 3.74831408259429e+53*cos(theta)**2 + 2.57439154024333e+50)*cos(29*phi)

#@torch.jit.script
def Yl61_m30(theta, phi):
    return 3.45052290581314e-53*(1.0 - cos(theta)**2)**15*(1.02608386758172e+67*cos(theta)**31 - 3.94321486302067e+67*cos(theta)**29 + 6.72666064868232e+67*cos(theta)**27 - 6.72666064868232e+67*cos(theta)**25 + 4.38695259696673e+67*cos(theta)**23 - 1.96442302129661e+67*cos(theta)**21 + 6.19412664372804e+66*cos(theta)**19 - 1.38819876288007e+66*cos(theta)**17 + 2.20554943635152e+65*cos(theta)**15 - 2.45061048483502e+64*cos(theta)**13 + 1.85580211472943e+63*cos(theta)**11 - 9.18713918182887e+61*cos(theta)**9 + 2.78398157025117e+60*cos(theta)**7 - 4.63628968876087e+58*cos(theta)**5 + 3.48593209681269e+56*cos(theta)**3 - 7.49662816518858e+53*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl61_m31(theta, phi):
    return 6.46115491793583e-55*(1.0 - cos(theta)**2)**15.5*(3.18085998950334e+68*cos(theta)**30 - 1.143532310276e+69*cos(theta)**28 + 1.81619837514423e+69*cos(theta)**26 - 1.68166516217058e+69*cos(theta)**24 + 1.00899909730235e+69*cos(theta)**22 - 4.12528834472288e+68*cos(theta)**20 + 1.17688406230833e+68*cos(theta)**18 - 2.35993789689612e+67*cos(theta)**16 + 3.30832415452728e+66*cos(theta)**14 - 3.18579363028552e+65*cos(theta)**12 + 2.04138232620237e+64*cos(theta)**10 - 8.26842526364598e+62*cos(theta)**8 + 1.94878709917582e+61*cos(theta)**6 - 2.31814484438044e+59*cos(theta)**4 + 1.04577962904381e+57*cos(theta)**2 - 7.49662816518858e+53)*cos(31*phi)

#@torch.jit.script
def Yl61_m32(theta, phi):
    return 1.22322979951509e-56*(1.0 - cos(theta)**2)**16*(9.54257996851003e+69*cos(theta)**29 - 3.20189046877279e+70*cos(theta)**27 + 4.72211577537499e+70*cos(theta)**25 - 4.03599638920939e+70*cos(theta)**23 + 2.21979801406517e+70*cos(theta)**21 - 8.25057668944575e+69*cos(theta)**19 + 2.11839131215499e+69*cos(theta)**17 - 3.7759006350338e+68*cos(theta)**15 + 4.63165381633819e+67*cos(theta)**13 - 3.82295235634263e+66*cos(theta)**11 + 2.04138232620238e+65*cos(theta)**9 - 6.61474021091679e+63*cos(theta)**7 + 1.16927225950549e+62*cos(theta)**5 - 9.27257937752175e+59*cos(theta)**3 + 2.09155925808761e+57*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl61_m33(theta, phi):
    return 2.3428534677439e-58*(1.0 - cos(theta)**2)**16.5*(2.76734819086791e+71*cos(theta)**28 - 8.64510426568652e+71*cos(theta)**26 + 1.18052894384375e+72*cos(theta)**24 - 9.28279169518161e+71*cos(theta)**22 + 4.66157582953685e+71*cos(theta)**20 - 1.56760957099469e+71*cos(theta)**18 + 3.60126523066348e+70*cos(theta)**16 - 5.6638509525507e+69*cos(theta)**14 + 6.02114996123964e+68*cos(theta)**12 - 4.20524759197689e+67*cos(theta)**10 + 1.83724409358214e+66*cos(theta)**8 - 4.63031814764175e+64*cos(theta)**6 + 5.84636129752746e+62*cos(theta)**4 - 2.78177381325652e+60*cos(theta)**2 + 2.09155925808761e+57)*cos(33*phi)

#@torch.jit.script
def Yl61_m34(theta, phi):
    return 4.5425980324766e-60*(1.0 - cos(theta)**2)**17*(7.74857493443014e+72*cos(theta)**27 - 2.2477271090785e+73*cos(theta)**25 + 2.83326946522499e+73*cos(theta)**23 - 2.04221417293995e+73*cos(theta)**21 + 9.3231516590737e+72*cos(theta)**19 - 2.82169722779045e+72*cos(theta)**17 + 5.76202436906157e+71*cos(theta)**15 - 7.92939133357097e+70*cos(theta)**13 + 7.22537995348757e+69*cos(theta)**11 - 4.20524759197689e+68*cos(theta)**9 + 1.46979527486571e+67*cos(theta)**7 - 2.77819088858505e+65*cos(theta)**5 + 2.33854451901099e+63*cos(theta)**3 - 5.56354762651305e+60*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl61_m35(theta, phi):
    return 8.92250520269132e-62*(1.0 - cos(theta)**2)**17.5*(2.09211523229614e+74*cos(theta)**26 - 5.61931777269624e+74*cos(theta)**24 + 6.51651977001749e+74*cos(theta)**22 - 4.2886497631739e+74*cos(theta)**20 + 1.771398815224e+74*cos(theta)**18 - 4.79688528724376e+73*cos(theta)**16 + 8.64303655359236e+72*cos(theta)**14 - 1.03082087336423e+72*cos(theta)**12 + 7.94791794883633e+70*cos(theta)**10 - 3.7847228327792e+69*cos(theta)**8 + 1.028856692406e+68*cos(theta)**6 - 1.38909544429253e+66*cos(theta)**4 + 7.01563355703296e+63*cos(theta)**2 - 5.56354762651305e+60)*cos(35*phi)

#@torch.jit.script
def Yl61_m36(theta, phi):
    return 1.77670068074599e-63*(1.0 - cos(theta)**2)**18*(5.43949960396996e+75*cos(theta)**25 - 1.3486362654471e+76*cos(theta)**23 + 1.43363434940385e+76*cos(theta)**21 - 8.5772995263478e+75*cos(theta)**19 + 3.18851786740321e+75*cos(theta)**17 - 7.67501645959002e+74*cos(theta)**15 + 1.21002511750293e+74*cos(theta)**13 - 1.23698504803707e+73*cos(theta)**11 + 7.94791794883633e+71*cos(theta)**9 - 3.02777826622336e+70*cos(theta)**7 + 6.17314015443598e+68*cos(theta)**5 - 5.5563817771701e+66*cos(theta)**3 + 1.40312671140659e+64*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl61_m37(theta, phi):
    return 3.58947742712642e-65*(1.0 - cos(theta)**2)**18.5*(1.35987490099249e+77*cos(theta)**24 - 3.10186341052832e+77*cos(theta)**22 + 3.01063213374808e+77*cos(theta)**20 - 1.62968691000608e+77*cos(theta)**18 + 5.42048037458545e+76*cos(theta)**16 - 1.1512524689385e+76*cos(theta)**14 + 1.57303265275381e+75*cos(theta)**12 - 1.36068355284078e+74*cos(theta)**10 + 7.15312615395269e+72*cos(theta)**8 - 2.11944478635635e+71*cos(theta)**6 + 3.08657007721799e+69*cos(theta)**4 - 1.66691453315103e+67*cos(theta)**2 + 1.40312671140659e+64)*cos(37*phi)

#@torch.jit.script
def Yl61_m38(theta, phi):
    return 7.36390213902749e-67*(1.0 - cos(theta)**2)**19*(3.26369976238198e+78*cos(theta)**23 - 6.82409950316231e+78*cos(theta)**21 + 6.02126426749616e+78*cos(theta)**19 - 2.93343643801095e+78*cos(theta)**17 + 8.67276859933672e+77*cos(theta)**15 - 1.6117534565139e+77*cos(theta)**13 + 1.88763918330457e+76*cos(theta)**11 - 1.36068355284078e+75*cos(theta)**9 + 5.72250092316216e+73*cos(theta)**7 - 1.27166687181381e+72*cos(theta)**5 + 1.2346280308872e+70*cos(theta)**3 - 3.33382906630206e+67*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl61_m39(theta, phi):
    return 1.53547973969296e-68*(1.0 - cos(theta)**2)**19.5*(7.50650945347855e+79*cos(theta)**22 - 1.43306089566409e+80*cos(theta)**20 + 1.14404021082427e+80*cos(theta)**18 - 4.98684194461861e+79*cos(theta)**16 + 1.30091528990051e+79*cos(theta)**14 - 2.09527949346807e+78*cos(theta)**12 + 2.07640310163503e+77*cos(theta)**10 - 1.2246151975567e+76*cos(theta)**8 + 4.00575064621351e+74*cos(theta)**6 - 6.35833435906906e+72*cos(theta)**4 + 3.70388409266159e+70*cos(theta)**2 - 3.33382906630206e+67)*cos(39*phi)

#@torch.jit.script
def Yl61_m40(theta, phi):
    return 3.25740728337047e-70*(1.0 - cos(theta)**2)**20*(1.65143207976528e+81*cos(theta)**21 - 2.86612179132817e+81*cos(theta)**19 + 2.05927237948369e+81*cos(theta)**17 - 7.97894711138978e+80*cos(theta)**15 + 1.82128140586071e+80*cos(theta)**13 - 2.51433539216169e+79*cos(theta)**11 + 2.07640310163503e+78*cos(theta)**9 - 9.79692158045361e+76*cos(theta)**7 + 2.40345038772811e+75*cos(theta)**5 - 2.54333374362762e+73*cos(theta)**3 + 7.40776818532318e+70*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl61_m41(theta, phi):
    return 7.03821176735559e-72*(1.0 - cos(theta)**2)**20.5*(3.46800736750709e+82*cos(theta)**20 - 5.44563140352353e+82*cos(theta)**18 + 3.50076304512227e+82*cos(theta)**16 - 1.19684206670847e+82*cos(theta)**14 + 2.36766582761892e+81*cos(theta)**12 - 2.76576893137786e+80*cos(theta)**10 + 1.86876279147153e+79*cos(theta)**8 - 6.85784510631753e+77*cos(theta)**6 + 1.20172519386405e+76*cos(theta)**4 - 7.63000123088287e+73*cos(theta)**2 + 7.40776818532318e+70)*cos(41*phi)

#@torch.jit.script
def Yl61_m42(theta, phi):
    return 1.55070333059599e-73*(1.0 - cos(theta)**2)**21*(6.93601473501418e+83*cos(theta)**19 - 9.80213652634235e+83*cos(theta)**17 + 5.60122087219563e+83*cos(theta)**15 - 1.67557889339185e+83*cos(theta)**13 + 2.84119899314271e+82*cos(theta)**11 - 2.76576893137786e+81*cos(theta)**9 + 1.49501023317722e+80*cos(theta)**7 - 4.11470706379052e+78*cos(theta)**5 + 4.80690077545621e+76*cos(theta)**3 - 1.52600024617657e+74*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl61_m43(theta, phi):
    return 3.48847206463754e-75*(1.0 - cos(theta)**2)**21.5*(1.31784279965269e+85*cos(theta)**18 - 1.6663632094782e+85*cos(theta)**16 + 8.40183130829344e+84*cos(theta)**14 - 2.17825256140941e+84*cos(theta)**12 + 3.12531889245698e+83*cos(theta)**10 - 2.48919203824007e+82*cos(theta)**8 + 1.04650716322405e+81*cos(theta)**6 - 2.05735353189526e+79*cos(theta)**4 + 1.44207023263686e+77*cos(theta)**2 - 1.52600024617657e+74)*cos(43*phi)

#@torch.jit.script
def Yl61_m44(theta, phi):
    return 8.02424808844761e-77*(1.0 - cos(theta)**2)**22*(2.37211703937485e+86*cos(theta)**17 - 2.66618113516512e+86*cos(theta)**15 + 1.17625638316108e+86*cos(theta)**13 - 2.61390307369129e+85*cos(theta)**11 + 3.12531889245698e+84*cos(theta)**9 - 1.99135363059206e+83*cos(theta)**7 + 6.27904297934433e+81*cos(theta)**5 - 8.22941412758103e+79*cos(theta)**3 + 2.88414046527373e+77*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl61_m45(theta, phi):
    return 1.89028354644417e-78*(1.0 - cos(theta)**2)**22.5*(4.03259896693724e+87*cos(theta)**16 - 3.99927170274768e+87*cos(theta)**14 + 1.52913329810941e+87*cos(theta)**12 - 2.87529338106042e+86*cos(theta)**10 + 2.81278700321128e+85*cos(theta)**8 - 1.39394754141444e+84*cos(theta)**6 + 3.13952148967216e+82*cos(theta)**4 - 2.46882423827431e+80*cos(theta)**2 + 2.88414046527373e+77)*cos(45*phi)

#@torch.jit.script
def Yl61_m46(theta, phi):
    return 4.56851519747556e-80*(1.0 - cos(theta)**2)**23*(6.45215834709959e+88*cos(theta)**15 - 5.59898038384675e+88*cos(theta)**13 + 1.83495995773129e+88*cos(theta)**11 - 2.87529338106042e+87*cos(theta)**9 + 2.25022960256903e+86*cos(theta)**7 - 8.36368524848664e+84*cos(theta)**5 + 1.25580859586887e+83*cos(theta)**3 - 4.93764847654862e+80*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl61_m47(theta, phi):
    return 1.1350567264218e-81*(1.0 - cos(theta)**2)**23.5*(9.67823752064938e+89*cos(theta)**14 - 7.27867449900077e+89*cos(theta)**12 + 2.01845595350442e+89*cos(theta)**10 - 2.58776404295438e+88*cos(theta)**8 + 1.57516072179832e+87*cos(theta)**6 - 4.18184262424332e+85*cos(theta)**4 + 3.7674257876066e+83*cos(theta)**2 - 4.93764847654862e+80)*cos(47*phi)

#@torch.jit.script
def Yl61_m48(theta, phi):
    return 2.9056299265317e-83*(1.0 - cos(theta)**2)**24*(1.35495325289091e+91*cos(theta)**13 - 8.73440939880093e+90*cos(theta)**11 + 2.01845595350442e+90*cos(theta)**9 - 2.0702112343635e+89*cos(theta)**7 + 9.45096433078991e+87*cos(theta)**5 - 1.67273704969733e+86*cos(theta)**3 + 7.53485157521319e+83*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl61_m49(theta, phi):
    return 7.68373328093602e-85*(1.0 - cos(theta)**2)**24.5*(1.76143922875819e+92*cos(theta)**12 - 9.60785033868102e+91*cos(theta)**10 + 1.81661035815397e+91*cos(theta)**8 - 1.44914786405445e+90*cos(theta)**6 + 4.72548216539495e+88*cos(theta)**4 - 5.01821114909199e+86*cos(theta)**2 + 7.53485157521319e+83)*cos(49*phi)

#@torch.jit.script
def Yl61_m50(theta, phi):
    return 2.10532995018392e-86*(1.0 - cos(theta)**2)**25*(2.11372707450982e+93*cos(theta)**11 - 9.60785033868102e+92*cos(theta)**9 + 1.45328828652318e+92*cos(theta)**7 - 8.69488718432672e+90*cos(theta)**5 + 1.89019286615798e+89*cos(theta)**3 - 1.0036422298184e+87*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl61_m51(theta, phi):
    return 5.99811536901751e-88*(1.0 - cos(theta)**2)**25.5*(2.32509978196081e+94*cos(theta)**10 - 8.64706530481292e+93*cos(theta)**8 + 1.01730180056623e+93*cos(theta)**6 - 4.34744359216336e+91*cos(theta)**4 + 5.67057859847394e+89*cos(theta)**2 - 1.0036422298184e+87)*cos(51*phi)

#@torch.jit.script
def Yl61_m52(theta, phi):
    return 1.78433170802171e-89*(1.0 - cos(theta)**2)**26*(2.32509978196081e+95*cos(theta)**9 - 6.91765224385034e+94*cos(theta)**7 + 6.10381080339735e+93*cos(theta)**5 - 1.73897743686534e+92*cos(theta)**3 + 1.13411571969479e+90*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl61_m53(theta, phi):
    return 5.57059920296156e-91*(1.0 - cos(theta)**2)**26.5*(2.09258980376473e+96*cos(theta)**8 - 4.84235657069523e+95*cos(theta)**6 + 3.05190540169868e+94*cos(theta)**4 - 5.21693231059603e+92*cos(theta)**2 + 1.13411571969479e+90)*cos(53*phi)

#@torch.jit.script
def Yl61_m54(theta, phi):
    return 1.83657216977349e-92*(1.0 - cos(theta)**2)**27*(1.67407184301178e+97*cos(theta)**7 - 2.90541394241714e+96*cos(theta)**5 + 1.22076216067947e+95*cos(theta)**3 - 1.04338646211921e+93*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl61_m55(theta, phi):
    return 6.44510481250452e-94*(1.0 - cos(theta)**2)**27.5*(1.17185029010825e+98*cos(theta)**6 - 1.45270697120857e+97*cos(theta)**4 + 3.66228648203841e+95*cos(theta)**2 - 1.04338646211921e+93)*cos(55*phi)

#@torch.jit.script
def Yl61_m56(theta, phi):
    return 2.43254805395122e-95*(1.0 - cos(theta)**2)**28*(7.03110174064948e+98*cos(theta)**5 - 5.81082788483428e+97*cos(theta)**3 + 7.32457296407682e+95*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl61_m57(theta, phi):
    return 1.00146418526566e-96*(1.0 - cos(theta)**2)**28.5*(3.51555087032474e+99*cos(theta)**4 - 1.74324836545028e+98*cos(theta)**2 + 7.32457296407682e+95)*cos(57*phi)

#@torch.jit.script
def Yl61_m58(theta, phi):
    return 4.59020356730306e-98*(1.0 - cos(theta)**2)**29*(1.4062203481299e+100*cos(theta)**3 - 3.48649673090057e+98*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl61_m59(theta, phi):
    return 2.41924969941795e-99*(1.0 - cos(theta)**2)**29.5*(4.21866104438969e+100*cos(theta)**2 - 3.48649673090057e+98)*cos(59*phi)

#@torch.jit.script
def Yl61_m60(theta, phi):
    return 13.1213234435527*(1.0 - cos(theta)**2)**30*cos(60*phi)*cos(theta)

#@torch.jit.script
def Yl61_m61(theta, phi):
    return 1.18794880702723*(1.0 - cos(theta)**2)**30.5*cos(61*phi)

#@torch.jit.script
def Yl62_m_minus_62(theta, phi):
    return 1.19272930443867*(1.0 - cos(theta)**2)**31*sin(62*phi)

#@torch.jit.script
def Yl62_m_minus_61(theta, phi):
    return 13.2816714315134*(1.0 - cos(theta)**2)**30.5*sin(61*phi)*cos(theta)

#@torch.jit.script
def Yl62_m_minus_60(theta, phi):
    return 2.00729196448552e-101*(1.0 - cos(theta)**2)**30*(5.18895308459932e+102*cos(theta)**2 - 4.21866104438969e+100)*sin(60*phi)

#@torch.jit.script
def Yl62_m_minus_59(theta, phi):
    return 3.84017564342032e-100*(1.0 - cos(theta)**2)**29.5*(1.72965102819977e+102*cos(theta)**3 - 4.21866104438969e+100*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl62_m_minus_58(theta, phi):
    return 8.4483864155247e-99*(1.0 - cos(theta)**2)**29*(4.32412757049943e+101*cos(theta)**4 - 2.10933052219484e+100*cos(theta)**2 + 8.71624182725142e+97)*sin(58*phi)

#@torch.jit.script
def Yl62_m_minus_57(theta, phi):
    return 2.06942358678965e-97*(1.0 - cos(theta)**2)**28.5*(8.64825514099886e+100*cos(theta)**5 - 7.03110174064948e+99*cos(theta)**3 + 8.71624182725142e+97*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl62_m_minus_56(theta, phi):
    return 5.52966091440948e-96*(1.0 - cos(theta)**2)**28*(1.44137585683314e+100*cos(theta)**6 - 1.75777543516237e+99*cos(theta)**4 + 4.35812091362571e+97*cos(theta)**2 - 1.22076216067947e+95)*sin(56*phi)

#@torch.jit.script
def Yl62_m_minus_55(theta, phi):
    return 1.5892364757397e-94*(1.0 - cos(theta)**2)**27.5*(2.05910836690449e+99*cos(theta)**7 - 3.51555087032474e+98*cos(theta)**5 + 1.45270697120857e+97*cos(theta)**3 - 1.22076216067947e+95*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl62_m_minus_54(theta, phi):
    return 4.86212868090609e-93*(1.0 - cos(theta)**2)**27*(2.57388545863061e+98*cos(theta)**8 - 5.85925145054123e+97*cos(theta)**6 + 3.63176742802143e+96*cos(theta)**4 - 6.10381080339735e+94*cos(theta)**2 + 1.30423307764901e+92)*sin(54*phi)

#@torch.jit.script
def Yl62_m_minus_53(theta, phi):
    return 1.57100185561049e-91*(1.0 - cos(theta)**2)**26.5*(2.85987273181179e+97*cos(theta)**9 - 8.37035921505891e+96*cos(theta)**7 + 7.26353485604285e+95*cos(theta)**5 - 2.03460360113245e+94*cos(theta)**3 + 1.30423307764901e+92*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl62_m_minus_52(theta, phi):
    return 5.32752649442622e-90*(1.0 - cos(theta)**2)**26*(2.85987273181179e+96*cos(theta)**10 - 1.04629490188236e+96*cos(theta)**8 + 1.21058914267381e+95*cos(theta)**6 - 5.08650900283113e+93*cos(theta)**4 + 6.52116538824504e+91*cos(theta)**2 - 1.13411571969479e+89)*sin(52*phi)

#@torch.jit.script
def Yl62_m_minus_51(theta, phi):
    return 1.88657635255539e-88*(1.0 - cos(theta)**2)**25.5*(2.59988430164708e+95*cos(theta)**11 - 1.1625498909804e+95*cos(theta)**9 + 1.72941306096258e+94*cos(theta)**7 - 1.01730180056623e+93*cos(theta)**5 + 2.17372179608168e+91*cos(theta)**3 - 1.13411571969479e+89*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl62_m_minus_50(theta, phi):
    return 6.94711089081838e-87*(1.0 - cos(theta)**2)**25*(2.16657025137257e+94*cos(theta)**12 - 1.1625498909804e+94*cos(theta)**10 + 2.16176632620323e+93*cos(theta)**8 - 1.69550300094371e+92*cos(theta)**6 + 5.4343044902042e+90*cos(theta)**4 - 5.67057859847394e+88*cos(theta)**2 + 8.36368524848664e+85)*sin(50*phi)

#@torch.jit.script
def Yl62_m_minus_49(theta, phi):
    return 2.6508485661369e-85*(1.0 - cos(theta)**2)**24.5*(1.66659250105582e+93*cos(theta)**13 - 1.05686353725491e+93*cos(theta)**11 + 2.40196258467026e+92*cos(theta)**9 - 2.4221471442053e+91*cos(theta)**7 + 1.08686089804084e+90*cos(theta)**5 - 1.89019286615798e+88*cos(theta)**3 + 8.36368524848664e+85*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl62_m_minus_48(theta, phi):
    return 1.04498588887109e-83*(1.0 - cos(theta)**2)**24*(1.19042321503987e+92*cos(theta)**14 - 8.80719614379094e+91*cos(theta)**12 + 2.40196258467026e+91*cos(theta)**10 - 3.02768393025662e+90*cos(theta)**8 + 1.81143483006807e+89*cos(theta)**6 - 4.72548216539495e+87*cos(theta)**4 + 4.18184262424332e+85*cos(theta)**2 - 5.382036839438e+82)*sin(48*phi)

#@torch.jit.script
def Yl62_m_minus_47(theta, phi):
    return 4.24475274674568e-82*(1.0 - cos(theta)**2)**23.5*(7.93615476693249e+90*cos(theta)**15 - 6.77476626445457e+90*cos(theta)**13 + 2.18360234970023e+90*cos(theta)**11 - 3.36409325584069e+89*cos(theta)**9 + 2.58776404295438e+88*cos(theta)**7 - 9.45096433078991e+86*cos(theta)**5 + 1.39394754141444e+85*cos(theta)**3 - 5.382036839438e+82*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl62_m_minus_46(theta, phi):
    return 1.77266078922259e-80*(1.0 - cos(theta)**2)**23*(4.96009672933281e+89*cos(theta)**16 - 4.83911876032469e+89*cos(theta)**14 + 1.81966862475019e+89*cos(theta)**12 - 3.36409325584069e+88*cos(theta)**10 + 3.23470505369297e+87*cos(theta)**8 - 1.57516072179832e+86*cos(theta)**6 + 3.4848688535361e+84*cos(theta)**4 - 2.691018419719e+82*cos(theta)**2 + 3.08603029784289e+79)*sin(46*phi)

#@torch.jit.script
def Yl62_m_minus_45(theta, phi):
    return 7.59559809259046e-79*(1.0 - cos(theta)**2)**22.5*(2.91770395843106e+88*cos(theta)**17 - 3.22607917354979e+88*cos(theta)**15 + 1.39974509596169e+88*cos(theta)**13 - 3.05826659621881e+87*cos(theta)**11 + 3.59411672632553e+86*cos(theta)**9 - 2.25022960256903e+85*cos(theta)**7 + 6.9697377070722e+83*cos(theta)**5 - 8.97006139906332e+81*cos(theta)**3 + 3.08603029784289e+79*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl62_m_minus_44(theta, phi):
    return 3.3334206245222e-77*(1.0 - cos(theta)**2)**22*(1.62094664357281e+87*cos(theta)**18 - 2.01629948346862e+87*cos(theta)**16 + 9.99817925686919e+86*cos(theta)**14 - 2.54855549684901e+86*cos(theta)**12 + 3.59411672632553e+85*cos(theta)**10 - 2.81278700321128e+84*cos(theta)**8 + 1.1616229511787e+83*cos(theta)**6 - 2.24251534976583e+81*cos(theta)**4 + 1.54301514892144e+79*cos(theta)**2 - 1.6023002584854e+76)*sin(44*phi)

#@torch.jit.script
def Yl62_m_minus_43(theta, phi):
    return 1.49595955235494e-75*(1.0 - cos(theta)**2)**21.5*(8.53129812406744e+85*cos(theta)**19 - 1.18605851968742e+86*cos(theta)**17 + 6.6654528379128e+85*cos(theta)**15 - 1.96042730526847e+85*cos(theta)**13 + 3.26737884211412e+84*cos(theta)**11 - 3.12531889245698e+83*cos(theta)**9 + 1.65946135882672e+82*cos(theta)**7 - 4.48503069953166e+80*cos(theta)**5 + 5.14338382973815e+78*cos(theta)**3 - 1.6023002584854e+76*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl62_m_minus_42(theta, phi):
    return 6.85534788525874e-74*(1.0 - cos(theta)**2)**21*(4.26564906203372e+84*cos(theta)**20 - 6.58921399826347e+84*cos(theta)**18 + 4.1659080236955e+84*cos(theta)**16 - 1.40030521804891e+84*cos(theta)**14 + 2.72281570176176e+83*cos(theta)**12 - 3.12531889245698e+82*cos(theta)**10 + 2.07432669853339e+81*cos(theta)**8 - 7.4750511658861e+79*cos(theta)**6 + 1.28584595743454e+78*cos(theta)**4 - 8.01150129242702e+75*cos(theta)**2 + 7.63000123088287e+72)*sin(42*phi)

#@torch.jit.script
def Yl62_m_minus_41(theta, phi):
    return 3.2037293185814e-72*(1.0 - cos(theta)**2)**20.5*(2.03126145811129e+83*cos(theta)**21 - 3.46800736750709e+83*cos(theta)**19 + 2.45053413158559e+83*cos(theta)**17 - 9.33536812032604e+82*cos(theta)**15 + 2.09447361673982e+82*cos(theta)**13 - 2.84119899314271e+81*cos(theta)**11 + 2.30480744281488e+80*cos(theta)**9 - 1.06786445226944e+79*cos(theta)**7 + 2.57169191486907e+77*cos(theta)**5 - 2.67050043080901e+75*cos(theta)**3 + 7.63000123088287e+72*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl62_m_minus_40(theta, phi):
    return 1.52505591979142e-70*(1.0 - cos(theta)**2)**20*(9.23300662777861e+81*cos(theta)**22 - 1.73400368375354e+82*cos(theta)**20 + 1.36140785088088e+82*cos(theta)**18 - 5.83460507520378e+81*cos(theta)**16 + 1.49605258338558e+81*cos(theta)**14 - 2.36766582761892e+80*cos(theta)**12 + 2.30480744281488e+79*cos(theta)**10 - 1.3348305653368e+78*cos(theta)**8 + 4.28615319144845e+76*cos(theta)**6 - 6.67625107702251e+74*cos(theta)**4 + 3.81500061544144e+72*cos(theta)**2 - 3.36716735696508e+69)*sin(40*phi)

#@torch.jit.script
def Yl62_m_minus_39(theta, phi):
    return 7.38668828381131e-69*(1.0 - cos(theta)**2)**19.5*(4.01435070772983e+80*cos(theta)**23 - 8.2571603988264e+80*cos(theta)**21 + 7.16530447832043e+80*cos(theta)**19 - 3.43212063247281e+80*cos(theta)**17 + 9.97368388923723e+79*cos(theta)**15 - 1.82128140586071e+79*cos(theta)**13 + 2.09527949346807e+78*cos(theta)**11 - 1.48314507259645e+77*cos(theta)**9 + 6.12307598778351e+75*cos(theta)**7 - 1.3352502154045e+74*cos(theta)**5 + 1.27166687181381e+72*cos(theta)**3 - 3.36716735696508e+69*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl62_m_minus_38(theta, phi):
    return 3.63677204477434e-67*(1.0 - cos(theta)**2)**19*(1.67264612822076e+79*cos(theta)**24 - 3.75325472673927e+79*cos(theta)**22 + 3.58265223916021e+79*cos(theta)**20 - 1.90673368470712e+79*cos(theta)**18 + 6.23355243077327e+78*cos(theta)**16 - 1.30091528990051e+78*cos(theta)**14 + 1.74606624455673e+77*cos(theta)**12 - 1.48314507259645e+76*cos(theta)**10 + 7.65384498472938e+74*cos(theta)**8 - 2.22541702567417e+73*cos(theta)**6 + 3.17916717953453e+71*cos(theta)**4 - 1.68358367848254e+69*cos(theta)**2 + 1.38909544429253e+66)*sin(38*phi)

#@torch.jit.script
def Yl62_m_minus_37(theta, phi):
    return 1.81838602238717e-65*(1.0 - cos(theta)**2)**18.5*(6.69058451288305e+77*cos(theta)**25 - 1.63184988119099e+78*cos(theta)**23 + 1.70602487579058e+78*cos(theta)**21 - 1.00354404458269e+78*cos(theta)**19 + 3.66679554751369e+77*cos(theta)**17 - 8.67276859933672e+76*cos(theta)**15 + 1.34312788042825e+76*cos(theta)**13 - 1.34831370236041e+75*cos(theta)**11 + 8.50427220525487e+73*cos(theta)**9 - 3.17916717953453e+72*cos(theta)**7 + 6.35833435906906e+70*cos(theta)**5 - 5.6119455949418e+68*cos(theta)**3 + 1.38909544429253e+66*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl62_m_minus_36(theta, phi):
    return 9.22550939937039e-64*(1.0 - cos(theta)**2)**18*(2.57330173572425e+76*cos(theta)**26 - 6.79937450496245e+76*cos(theta)**24 + 7.75465852632081e+76*cos(theta)**22 - 5.01772022291347e+76*cos(theta)**20 + 2.0371086375076e+76*cos(theta)**18 - 5.42048037458545e+75*cos(theta)**16 + 9.59377057448752e+74*cos(theta)**14 - 1.12359475196701e+74*cos(theta)**12 + 8.50427220525487e+72*cos(theta)**10 - 3.97395897441816e+71*cos(theta)**8 + 1.05972239317818e+70*cos(theta)**6 - 1.40298639873545e+68*cos(theta)**4 + 6.94547722146263e+65*cos(theta)**2 - 5.39664119771766e+62)*sin(36*phi)

#@torch.jit.script
def Yl62_m_minus_35(theta, phi):
    return 4.74553603559859e-62*(1.0 - cos(theta)**2)**17.5*(9.53074716934908e+74*cos(theta)**27 - 2.71974980198498e+75*cos(theta)**25 + 3.37159066361774e+75*cos(theta)**23 - 2.38939058233975e+75*cos(theta)**21 + 1.07216244079348e+75*cos(theta)**19 - 3.18851786740321e+74*cos(theta)**17 + 6.39584704965835e+73*cos(theta)**15 - 8.64303655359236e+72*cos(theta)**13 + 7.7311565502317e+71*cos(theta)**11 - 4.41550997157574e+70*cos(theta)**9 + 1.51388913311168e+69*cos(theta)**7 - 2.8059727974709e+67*cos(theta)**5 + 2.31515907382088e+65*cos(theta)**3 - 5.39664119771766e+62*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl62_m_minus_34(theta, phi):
    return 2.47314829543615e-60*(1.0 - cos(theta)**2)**17*(3.40383827476753e+73*cos(theta)**28 - 1.04605761614807e+74*cos(theta)**26 + 1.40482944317406e+74*cos(theta)**24 - 1.08608662833625e+74*cos(theta)**22 + 5.36081220396738e+73*cos(theta)**20 - 1.771398815224e+73*cos(theta)**18 + 3.99740440603647e+72*cos(theta)**16 - 6.17359753828026e+71*cos(theta)**14 + 6.44263045852642e+70*cos(theta)**12 - 4.41550997157574e+69*cos(theta)**10 + 1.8923614163896e+68*cos(theta)**8 - 4.67662132911817e+66*cos(theta)**6 + 5.78789768455219e+64*cos(theta)**4 - 2.69832059885883e+62*cos(theta)**2 + 1.98698129518323e+59)*sin(34*phi)

#@torch.jit.script
def Yl62_m_minus_33(theta, phi):
    return 1.30492266343845e-58*(1.0 - cos(theta)**2)**16.5*(1.17373733612673e+72*cos(theta)**29 - 3.87428746721507e+72*cos(theta)**27 + 5.61931777269624e+72*cos(theta)**25 - 4.72211577537499e+72*cos(theta)**23 + 2.55276771617494e+72*cos(theta)**21 - 9.3231516590737e+71*cos(theta)**19 + 2.35141435649204e+71*cos(theta)**17 - 4.11573169218684e+70*cos(theta)**15 + 4.95586958348186e+69*cos(theta)**13 - 4.01409997415976e+68*cos(theta)**11 + 2.10262379598845e+67*cos(theta)**9 - 6.68088761302595e+65*cos(theta)**7 + 1.15757953691044e+64*cos(theta)**5 - 8.9944019961961e+61*cos(theta)**3 + 1.98698129518323e+59*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl62_m_minus_32(theta, phi):
    return 6.96638069519073e-57*(1.0 - cos(theta)**2)**16*(3.91245778708911e+70*cos(theta)**30 - 1.38367409543395e+71*cos(theta)**28 + 2.16127606642163e+71*cos(theta)**26 - 1.96754823973958e+71*cos(theta)**24 + 1.1603489618977e+71*cos(theta)**22 - 4.66157582953685e+70*cos(theta)**20 + 1.30634130916224e+70*cos(theta)**18 - 2.57233230761677e+69*cos(theta)**16 + 3.53990684534418e+68*cos(theta)**14 - 3.3450833117998e+67*cos(theta)**12 + 2.10262379598845e+66*cos(theta)**10 - 8.35110951628244e+64*cos(theta)**8 + 1.92929922818406e+63*cos(theta)**6 - 2.24860049904902e+61*cos(theta)**4 + 9.93490647591616e+58*cos(theta)**2 - 6.97186419362538e+55)*sin(32*phi)

#@torch.jit.script
def Yl62_m_minus_31(theta, phi):
    return 3.76055528362249e-55*(1.0 - cos(theta)**2)**15.5*(1.26208315712552e+69*cos(theta)**31 - 4.77128998425501e+69*cos(theta)**29 + 8.00472617193197e+69*cos(theta)**27 - 7.87019295895832e+69*cos(theta)**25 + 5.04499548651174e+69*cos(theta)**23 - 2.21979801406517e+69*cos(theta)**21 + 6.87548057453813e+68*cos(theta)**19 - 1.51313665153928e+68*cos(theta)**17 + 2.35993789689612e+67*cos(theta)**15 - 2.57314100907677e+66*cos(theta)**13 + 1.91147617817131e+65*cos(theta)**11 - 9.27901057364716e+63*cos(theta)**9 + 2.75614175454866e+62*cos(theta)**7 - 4.49720099809805e+60*cos(theta)**5 + 3.31163549197205e+58*cos(theta)**3 - 6.97186419362538e+55*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl62_m_minus_30(theta, phi):
    return 2.05148544958415e-53*(1.0 - cos(theta)**2)**15*(3.94400986601725e+67*cos(theta)**32 - 1.59042999475167e+68*cos(theta)**30 + 2.85883077568999e+68*cos(theta)**28 - 3.02699729190705e+68*cos(theta)**26 + 2.10208145271323e+68*cos(theta)**24 - 1.00899909730235e+68*cos(theta)**22 + 3.43774028726906e+67*cos(theta)**20 - 8.40631473077377e+66*cos(theta)**18 + 1.47496118556008e+66*cos(theta)**16 - 1.83795786362626e+65*cos(theta)**14 + 1.59289681514276e+64*cos(theta)**12 - 9.27901057364716e+62*cos(theta)**10 + 3.44517719318583e+61*cos(theta)**8 - 7.49533499683008e+59*cos(theta)**6 + 8.27908872993013e+57*cos(theta)**4 - 3.48593209681269e+55*cos(theta)**2 + 2.34269630162143e+52)*sin(30*phi)

#@torch.jit.script
def Yl62_m_minus_29(theta, phi):
    return 1.13036662111729e-51*(1.0 - cos(theta)**2)**14.5*(1.19515450485371e+66*cos(theta)**33 - 5.13041933790862e+66*cos(theta)**31 + 9.85803715755168e+66*cos(theta)**29 - 1.12111010811372e+67*cos(theta)**27 + 8.40832581085291e+66*cos(theta)**25 - 4.38695259696673e+66*cos(theta)**23 + 1.63701918441384e+66*cos(theta)**21 - 4.42437617409146e+65*cos(theta)**19 + 8.67624226800045e+64*cos(theta)**17 - 1.22530524241751e+64*cos(theta)**15 + 1.22530524241751e+63*cos(theta)**13 - 8.43546415786105e+61*cos(theta)**11 + 3.82797465909536e+60*cos(theta)**9 - 1.0707621424043e+59*cos(theta)**7 + 1.65581774598603e+57*cos(theta)**5 - 1.16197736560423e+55*cos(theta)**3 + 2.34269630162143e+52*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl62_m_minus_28(theta, phi):
    return 6.28752144492021e-50*(1.0 - cos(theta)**2)**14*(3.51516030839327e+64*cos(theta)**34 - 1.60325604309644e+65*cos(theta)**32 + 3.28601238585056e+65*cos(theta)**30 - 4.00396467183472e+65*cos(theta)**28 + 3.23397146571266e+65*cos(theta)**26 - 1.82789691540281e+65*cos(theta)**24 + 7.44099629279018e+64*cos(theta)**22 - 2.21218808704573e+64*cos(theta)**20 + 4.82013459333359e+63*cos(theta)**18 - 7.65815776510943e+62*cos(theta)**16 + 8.75218030298221e+61*cos(theta)**14 - 7.02955346488421e+60*cos(theta)**12 + 3.82797465909536e+59*cos(theta)**10 - 1.33845267800537e+58*cos(theta)**8 + 2.75969624331004e+56*cos(theta)**6 - 2.90494341401057e+54*cos(theta)**4 + 1.17134815081071e+52*cos(theta)**2 - 7.57173982424509e+48)*sin(28*phi)

#@torch.jit.script
def Yl62_m_minus_27(theta, phi):
    return 3.52886265883279e-48*(1.0 - cos(theta)**2)**13.5*(1.00433151668379e+63*cos(theta)**35 - 4.8583516457468e+63*cos(theta)**33 + 1.06000399543566e+64*cos(theta)**31 - 1.38067747304645e+64*cos(theta)**29 + 1.19776720952321e+64*cos(theta)**27 - 7.31158766161122e+63*cos(theta)**25 + 3.23521577947399e+63*cos(theta)**23 - 1.0534228985932e+63*cos(theta)**21 + 2.53691294385978e+62*cos(theta)**19 - 4.50479868535849e+61*cos(theta)**17 + 5.83478686865481e+60*cos(theta)**15 - 5.4073488191417e+59*cos(theta)**13 + 3.47997696281397e+58*cos(theta)**11 - 1.48716964222819e+57*cos(theta)**9 + 3.94242320472863e+55*cos(theta)**7 - 5.80988682802115e+53*cos(theta)**5 + 3.90449383603572e+51*cos(theta)**3 - 7.57173982424509e+48*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl62_m_minus_26(theta, phi):
    return 1.99747342446286e-46*(1.0 - cos(theta)**2)**13*(2.78980976856609e+61*cos(theta)**36 - 1.42892695463141e+62*cos(theta)**34 + 3.31251248573645e+62*cos(theta)**32 - 4.60225824348818e+62*cos(theta)**30 + 4.27774003401145e+62*cos(theta)**28 - 2.8121491006197e+62*cos(theta)**26 + 1.34800657478083e+62*cos(theta)**24 - 4.78828590269638e+61*cos(theta)**22 + 1.26845647192989e+61*cos(theta)**20 - 2.50266593631027e+60*cos(theta)**18 + 3.64674179290925e+59*cos(theta)**16 - 3.86239201367264e+58*cos(theta)**14 + 2.89998080234497e+57*cos(theta)**12 - 1.48716964222819e+56*cos(theta)**10 + 4.92802900591079e+54*cos(theta)**8 - 9.68314471336858e+52*cos(theta)**6 + 9.76123459008929e+50*cos(theta)**4 - 3.78586991212254e+48*cos(theta)**2 + 2.36321467673068e+45)*sin(26*phi)

#@torch.jit.script
def Yl62_m_minus_25(theta, phi):
    return 1.1397857107875e-44*(1.0 - cos(theta)**2)**12.5*(7.54002640152997e+59*cos(theta)**37 - 4.08264844180403e+60*cos(theta)**35 + 1.00379166234438e+61*cos(theta)**33 - 1.48459943338328e+61*cos(theta)**31 + 1.47508277034878e+61*cos(theta)**29 - 1.04153670393322e+61*cos(theta)**27 + 5.39202629912332e+60*cos(theta)**25 - 2.08186343595495e+60*cos(theta)**23 + 6.04026891395186e+59*cos(theta)**21 - 1.31719259805804e+59*cos(theta)**19 + 2.14514223112309e+58*cos(theta)**17 - 2.5749280091151e+57*cos(theta)**15 + 2.23075446334229e+56*cos(theta)**13 - 1.35197240202563e+55*cos(theta)**11 + 5.47558778434533e+53*cos(theta)**9 - 1.38330638762408e+52*cos(theta)**7 + 1.95224691801786e+50*cos(theta)**5 - 1.26195663737418e+48*cos(theta)**3 + 2.36321467673068e+45*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl62_m_minus_24(theta, phi):
    return 6.55352005284167e-43*(1.0 - cos(theta)**2)**12*(1.98421747408683e+58*cos(theta)**38 - 1.13406901161223e+59*cos(theta)**36 + 2.95232841865994e+59*cos(theta)**34 - 4.63937322932276e+59*cos(theta)**32 + 4.91694256782925e+59*cos(theta)**30 - 3.71977394261865e+59*cos(theta)**28 + 2.07385626889358e+59*cos(theta)**26 - 8.67443098314562e+58*cos(theta)**24 + 2.74557677906903e+58*cos(theta)**22 - 6.58596299029019e+57*cos(theta)**20 + 1.19174568395727e+57*cos(theta)**18 - 1.60933000569693e+56*cos(theta)**16 + 1.59339604524449e+55*cos(theta)**14 - 1.12664366835469e+54*cos(theta)**12 + 5.47558778434533e+52*cos(theta)**10 - 1.7291329845301e+51*cos(theta)**8 + 3.2537448633631e+49*cos(theta)**6 - 3.15489159343545e+47*cos(theta)**4 + 1.18160733836534e+45*cos(theta)**2 - 7.14825976022588e+41)*sin(24*phi)

#@torch.jit.script
def Yl62_m_minus_23(theta, phi):
    return 3.79538783958076e-41*(1.0 - cos(theta)**2)**11.5*(5.08773711304316e+56*cos(theta)**39 - 3.06505138273576e+57*cos(theta)**37 + 8.43522405331411e+57*cos(theta)**35 - 1.40587067555235e+58*cos(theta)**33 + 1.58611050575137e+58*cos(theta)**31 - 1.2826806698685e+58*cos(theta)**29 + 7.68094914405031e+57*cos(theta)**27 - 3.46977239325825e+57*cos(theta)**25 + 1.19372903437784e+57*cos(theta)**23 - 3.13617285251914e+56*cos(theta)**21 + 6.27234570503828e+55*cos(theta)**19 - 9.46664709233491e+54*cos(theta)**17 + 1.06226403016299e+54*cos(theta)**15 - 8.66648975657454e+52*cos(theta)**13 + 4.97780707667757e+51*cos(theta)**11 - 1.92125887170011e+50*cos(theta)**9 + 4.64820694766157e+48*cos(theta)**7 - 6.30978318687091e+46*cos(theta)**5 + 3.93869112788446e+44*cos(theta)**3 - 7.14825976022588e+41*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl62_m_minus_22(theta, phi):
    return 2.21307239148762e-39*(1.0 - cos(theta)**2)**11*(1.27193427826079e+55*cos(theta)**40 - 8.06592469140989e+55*cos(theta)**38 + 2.34311779258725e+56*cos(theta)**36 - 4.13491375162457e+56*cos(theta)**34 + 4.95659533047304e+56*cos(theta)**32 - 4.275602232895e+56*cos(theta)**30 + 2.74319612287511e+56*cos(theta)**28 - 1.33452784356087e+56*cos(theta)**26 + 4.97387097657433e+55*cos(theta)**24 - 1.42553311478143e+55*cos(theta)**22 + 3.13617285251914e+54*cos(theta)**20 - 5.25924838463051e+53*cos(theta)**18 + 6.63915018851871e+52*cos(theta)**16 - 6.19034982612467e+51*cos(theta)**14 + 4.14817256389797e+50*cos(theta)**12 - 1.92125887170011e+49*cos(theta)**10 + 5.81025868457696e+47*cos(theta)**8 - 1.05163053114515e+46*cos(theta)**6 + 9.84672781971115e+43*cos(theta)**4 - 3.57412988011294e+41*cos(theta)**2 + 2.10242934124291e+38)*sin(22*phi)

#@torch.jit.script
def Yl62_m_minus_21(theta, phi):
    return 1.29875487787028e-37*(1.0 - cos(theta)**2)**10.5*(3.10227872746534e+53*cos(theta)**41 - 2.06818581831023e+54*cos(theta)**39 + 6.33275079077636e+54*cos(theta)**37 - 1.18140392903559e+55*cos(theta)**35 + 1.50199858499183e+55*cos(theta)**33 - 1.37922652674032e+55*cos(theta)**31 + 9.45929697543142e+54*cos(theta)**29 - 4.94269571689209e+54*cos(theta)**27 + 1.98954839062973e+54*cos(theta)**25 - 6.19797006426707e+53*cos(theta)**23 + 1.49341564405673e+53*cos(theta)**21 - 2.768025465595e+52*cos(theta)**19 + 3.90538246383453e+51*cos(theta)**17 - 4.12689988408311e+50*cos(theta)**15 + 3.19090197222921e+49*cos(theta)**13 - 1.74659897427283e+48*cos(theta)**11 + 6.45584298286329e+46*cos(theta)**9 - 1.50232933020736e+45*cos(theta)**7 + 1.96934556394223e+43*cos(theta)**5 - 1.19137662670431e+41*cos(theta)**3 + 2.10242934124291e+38*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl62_m_minus_20(theta, phi):
    return 7.66815500333191e-36*(1.0 - cos(theta)**2)**10*(7.38637792253653e+51*cos(theta)**42 - 5.17046454577557e+52*cos(theta)**40 + 1.66651336599378e+53*cos(theta)**38 - 3.28167758065442e+53*cos(theta)**36 + 4.41764289703479e+53*cos(theta)**34 - 4.31008289606351e+53*cos(theta)**32 + 3.15309899181047e+53*cos(theta)**30 - 1.7652484703186e+53*cos(theta)**28 + 7.65210919472973e+52*cos(theta)**26 - 2.58248752677795e+52*cos(theta)**24 + 6.7882529275306e+51*cos(theta)**22 - 1.3840127327975e+51*cos(theta)**20 + 2.16965692435252e+50*cos(theta)**18 - 2.57931242755195e+49*cos(theta)**16 + 2.27921569444944e+48*cos(theta)**14 - 1.45549914522736e+47*cos(theta)**12 + 6.45584298286329e+45*cos(theta)**10 - 1.8779116627592e+44*cos(theta)**8 + 3.28224260657038e+42*cos(theta)**6 - 2.97844156676078e+40*cos(theta)**4 + 1.05121467062145e+38*cos(theta)**2 - 6.03106523592343e+34)*sin(20*phi)

#@torch.jit.script
def Yl62_m_minus_19(theta, phi):
    return 4.55336051365327e-34*(1.0 - cos(theta)**2)**9.5*(1.71776230756663e+50*cos(theta)**43 - 1.2610889136038e+51*cos(theta)**41 + 4.27311119485584e+51*cos(theta)**39 - 8.86939886663356e+51*cos(theta)**37 + 1.26218368486708e+52*cos(theta)**35 - 1.30608572607985e+52*cos(theta)**33 + 1.01712870703564e+52*cos(theta)**31 - 6.08706369075381e+51*cos(theta)**29 + 2.83411451656657e+51*cos(theta)**27 - 1.03299501071118e+51*cos(theta)**25 + 2.95141431631765e+50*cos(theta)**23 - 6.59053682284525e+49*cos(theta)**21 + 1.14192469702764e+49*cos(theta)**19 - 1.51724260444232e+48*cos(theta)**17 + 1.51947712963296e+47*cos(theta)**15 - 1.11961472709797e+46*cos(theta)**13 + 5.86894816623935e+44*cos(theta)**11 - 2.08656851417689e+43*cos(theta)**9 + 4.68891800938626e+41*cos(theta)**7 - 5.95688313352157e+39*cos(theta)**5 + 3.50404890207151e+37*cos(theta)**3 - 6.03106523592343e+34*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl62_m_minus_18(theta, phi):
    return 2.71832190462141e-32*(1.0 - cos(theta)**2)**9*(3.90400524446963e+48*cos(theta)**44 - 3.00259265143761e+49*cos(theta)**42 + 1.06827779871396e+50*cos(theta)**40 - 2.33405233332462e+50*cos(theta)**38 + 3.50606579129745e+50*cos(theta)**36 - 3.84142860611721e+50*cos(theta)**34 + 3.17852720948636e+50*cos(theta)**32 - 2.02902123025127e+50*cos(theta)**30 + 1.01218375591663e+50*cos(theta)**28 - 3.97305773350453e+49*cos(theta)**26 + 1.22975596513236e+49*cos(theta)**24 - 2.99569855583875e+48*cos(theta)**22 + 5.70962348513821e+47*cos(theta)**20 - 8.42912558023512e+46*cos(theta)**18 + 9.49673206020599e+45*cos(theta)**16 - 7.99724805069978e+44*cos(theta)**14 + 4.89079013853279e+43*cos(theta)**12 - 2.08656851417689e+42*cos(theta)**10 + 5.86114751173283e+40*cos(theta)**8 - 9.92813855586928e+38*cos(theta)**6 + 8.76012225517878e+36*cos(theta)**4 - 3.01553261796171e+34*cos(theta)**2 + 1.69221807966426e+31)*sin(18*phi)

#@torch.jit.script
def Yl62_m_minus_17(theta, phi):
    return 1.63099314277285e-30*(1.0 - cos(theta)**2)**8.5*(8.6755672099325e+46*cos(theta)**45 - 6.98277360799445e+47*cos(theta)**43 + 2.60555560661942e+48*cos(theta)**41 - 5.98474957262723e+48*cos(theta)**39 + 9.47585348999312e+48*cos(theta)**37 - 1.0975510303192e+49*cos(theta)**35 + 9.63190063480717e+48*cos(theta)**33 - 6.5452297750041e+48*cos(theta)**31 + 3.49028881350562e+48*cos(theta)**29 - 1.47150286426094e+48*cos(theta)**27 + 4.91902386052942e+47*cos(theta)**25 - 1.30247763297337e+47*cos(theta)**23 + 2.71886832625629e+46*cos(theta)**21 - 4.43638188433427e+45*cos(theta)**19 + 5.58631297659176e+44*cos(theta)**17 - 5.33149870046652e+43*cos(theta)**15 + 3.76214626040984e+42*cos(theta)**13 - 1.89688046743353e+41*cos(theta)**11 + 6.51238612414759e+39*cos(theta)**9 - 1.41830550798133e+38*cos(theta)**7 + 1.75202445103576e+36*cos(theta)**5 - 1.00517753932057e+34*cos(theta)**3 + 1.69221807966426e+31*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl62_m_minus_16(theta, phi):
    return 9.832061730817e-29*(1.0 - cos(theta)**2)**8*(1.88599287172446e+45*cos(theta)**46 - 1.58699400181692e+46*cos(theta)**44 + 6.20370382528433e+46*cos(theta)**42 - 1.49618739315681e+47*cos(theta)**40 + 2.49364565526135e+47*cos(theta)**38 - 3.04875286199779e+47*cos(theta)**36 + 2.83291195141387e+47*cos(theta)**34 - 2.04538430468878e+47*cos(theta)**32 + 1.16342960450187e+47*cos(theta)**30 - 5.25536737236049e+46*cos(theta)**28 + 1.89193225404978e+46*cos(theta)**26 - 5.42699013738904e+45*cos(theta)**24 + 1.2358492392074e+45*cos(theta)**22 - 2.21819094216714e+44*cos(theta)**20 + 3.10350720921764e+43*cos(theta)**18 - 3.33218668779157e+42*cos(theta)**16 + 2.68724732886417e+41*cos(theta)**14 - 1.58073372286128e+40*cos(theta)**12 + 6.51238612414759e+38*cos(theta)**10 - 1.77288188497666e+37*cos(theta)**8 + 2.92004075172626e+35*cos(theta)**6 - 2.51294384830143e+33*cos(theta)**4 + 8.4610903983213e+30*cos(theta)**2 - 4.65662652631882e+27)*sin(16*phi)

#@torch.jit.script
def Yl62_m_minus_15(theta, phi):
    return 5.95306777437426e-27*(1.0 - cos(theta)**2)**7.5*(4.0127507909031e+43*cos(theta)**47 - 3.52665333737093e+44*cos(theta)**45 + 1.44272181983356e+45*cos(theta)**43 - 3.6492375442849e+45*cos(theta)**41 + 6.39396321861884e+45*cos(theta)**39 - 8.23987259999402e+45*cos(theta)**37 + 8.09403414689678e+45*cos(theta)**35 - 6.19813425663267e+45*cos(theta)**33 + 3.7529987241996e+45*cos(theta)**31 - 1.81219564564155e+45*cos(theta)**29 + 7.00715649648066e+44*cos(theta)**27 - 2.17079605495561e+44*cos(theta)**25 + 5.37325756177132e+43*cos(theta)**23 - 1.05628140103197e+43*cos(theta)**21 + 1.63342484695665e+42*cos(theta)**19 - 1.96010981634798e+41*cos(theta)**17 + 1.79149821924278e+40*cos(theta)**15 - 1.2159490175856e+39*cos(theta)**13 + 5.92035102195235e+37*cos(theta)**11 - 1.96986876108517e+36*cos(theta)**9 + 4.17148678818037e+34*cos(theta)**7 - 5.02588769660285e+32*cos(theta)**5 + 2.8203634661071e+30*cos(theta)**3 - 4.65662652631882e+27*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl62_m_minus_14(theta, phi):
    return 3.61915187390057e-25*(1.0 - cos(theta)**2)**7*(8.35989748104812e+41*cos(theta)**48 - 7.66663768993682e+42*cos(theta)**46 + 3.27891322689446e+43*cos(theta)**44 - 8.68866081972595e+43*cos(theta)**42 + 1.59849080465471e+44*cos(theta)**40 - 2.16838752631421e+44*cos(theta)**38 + 2.24834281858244e+44*cos(theta)**36 - 1.82298066371549e+44*cos(theta)**34 + 1.17281210131237e+44*cos(theta)**32 - 6.0406521521385e+43*cos(theta)**30 + 2.50255589160024e+43*cos(theta)**28 - 8.34921559598313e+42*cos(theta)**26 + 2.23885731740472e+42*cos(theta)**24 - 4.80127909559986e+41*cos(theta)**22 + 8.16712423478327e+40*cos(theta)**20 - 1.0889498979711e+40*cos(theta)**18 + 1.11968638702674e+39*cos(theta)**16 - 8.68535012561142e+37*cos(theta)**14 + 4.93362585162696e+36*cos(theta)**12 - 1.96986876108517e+35*cos(theta)**10 + 5.21435848522546e+33*cos(theta)**8 - 8.37647949433809e+31*cos(theta)**6 + 7.05090866526775e+29*cos(theta)**4 - 2.32831326315941e+27*cos(theta)**2 + 1.25990977443691e+24)*sin(14*phi)

#@torch.jit.script
def Yl62_m_minus_13(theta, phi):
    return 2.20857241915218e-23*(1.0 - cos(theta)**2)**6.5*(1.70610152674451e+40*cos(theta)**49 - 1.63119950849719e+41*cos(theta)**47 + 7.28647383754325e+41*cos(theta)**45 - 2.0206187952851e+42*cos(theta)**43 + 3.89875806013344e+42*cos(theta)**41 - 5.55996801619029e+42*cos(theta)**39 + 6.07660221238497e+42*cos(theta)**37 - 5.20851618204426e+42*cos(theta)**35 + 3.55397606458295e+42*cos(theta)**33 - 1.94859746843177e+42*cos(theta)**31 + 8.62950307448357e+41*cos(theta)**29 - 3.09230207258635e+41*cos(theta)**27 + 8.95542926961887e+40*cos(theta)**25 - 2.08751265026081e+40*cos(theta)**23 + 3.88910677846822e+39*cos(theta)**21 - 5.73131525247949e+38*cos(theta)**19 + 6.58639051192199e+37*cos(theta)**17 - 5.79023341707428e+36*cos(theta)**15 + 3.79509680894382e+35*cos(theta)**13 - 1.7907897828047e+34*cos(theta)**11 + 5.79373165025051e+32*cos(theta)**9 - 1.19663992776258e+31*cos(theta)**7 + 1.41018173305355e+29*cos(theta)**5 - 7.76104421053137e+26*cos(theta)**3 + 1.25990977443691e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl62_m_minus_12(theta, phi):
    return 1.35246887172678e-21*(1.0 - cos(theta)**2)**6*(3.41220305348903e+38*cos(theta)**50 - 3.39833230936916e+39*cos(theta)**48 + 1.58401605163984e+40*cos(theta)**46 - 4.59231544382978e+40*cos(theta)**44 + 9.282757286032e+40*cos(theta)**42 - 1.38999200404757e+41*cos(theta)**40 + 1.59910584536447e+41*cos(theta)**38 - 1.44681005056785e+41*cos(theta)**36 + 1.04528707781852e+41*cos(theta)**34 - 6.08936708884929e+40*cos(theta)**32 + 2.87650102482786e+40*cos(theta)**30 - 1.10439359735227e+40*cos(theta)**28 + 3.44439587293034e+39*cos(theta)**26 - 8.69796937608671e+38*cos(theta)**24 + 1.76777580839465e+38*cos(theta)**22 - 2.86565762623974e+37*cos(theta)**20 + 3.65910583995666e+36*cos(theta)**18 - 3.61889588567142e+35*cos(theta)**16 + 2.71078343495987e+34*cos(theta)**14 - 1.49232481900392e+33*cos(theta)**12 + 5.79373165025051e+31*cos(theta)**10 - 1.49579990970323e+30*cos(theta)**8 + 2.35030288842258e+28*cos(theta)**6 - 1.94026105263284e+26*cos(theta)**4 + 6.29954887218456e+23*cos(theta)**2 - 3.35975939849843e+20)*sin(12*phi)

#@torch.jit.script
def Yl62_m_minus_11(theta, phi):
    return 8.30860717141439e-20*(1.0 - cos(theta)**2)**5.5*(6.69059422252751e+36*cos(theta)**51 - 6.93537205993705e+37*cos(theta)**49 + 3.37024691838263e+38*cos(theta)**47 - 1.02051454307328e+39*cos(theta)**45 + 2.15878076419349e+39*cos(theta)**43 - 3.39022440011603e+39*cos(theta)**41 + 4.10027139837042e+39*cos(theta)**39 - 3.91029743396716e+39*cos(theta)**37 + 2.9865345080529e+39*cos(theta)**35 - 1.84526275419676e+39*cos(theta)**33 + 9.27903556396083e+38*cos(theta)**31 - 3.80825378397333e+38*cos(theta)**29 + 1.27570217515938e+38*cos(theta)**27 - 3.47918775043468e+37*cos(theta)**25 + 7.6859817756289e+36*cos(theta)**23 - 1.36459886963797e+36*cos(theta)**21 + 1.92584517892456e+35*cos(theta)**19 - 2.12876228568907e+34*cos(theta)**17 + 1.80718895663991e+33*cos(theta)**15 - 1.14794216846455e+32*cos(theta)**13 + 5.26702877295501e+30*cos(theta)**11 - 1.66199989967026e+29*cos(theta)**9 + 3.35757555488941e+27*cos(theta)**7 - 3.88052210526569e+25*cos(theta)**5 + 2.09984962406152e+23*cos(theta)**3 - 3.35975939849843e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl62_m_minus_10(theta, phi):
    return 5.11907306137765e-18*(1.0 - cos(theta)**2)**5*(1.28665273510144e+35*cos(theta)**52 - 1.38707441198741e+36*cos(theta)**50 + 7.02134774663049e+36*cos(theta)**48 - 2.21850987624627e+37*cos(theta)**46 + 4.90631991862156e+37*cos(theta)**44 - 8.07196285741913e+37*cos(theta)**42 + 1.02506784959261e+38*cos(theta)**40 - 1.02902564051767e+38*cos(theta)**38 + 8.29592918903583e+37*cos(theta)**36 - 5.42724339469634e+37*cos(theta)**34 + 2.89969861373776e+37*cos(theta)**32 - 1.26941792799111e+37*cos(theta)**30 + 4.5560791969978e+36*cos(theta)**28 - 1.33814913478257e+36*cos(theta)**26 + 3.20249240651204e+35*cos(theta)**24 - 6.20272213471806e+34*cos(theta)**22 + 9.62922589462279e+33*cos(theta)**20 - 1.18264571427171e+33*cos(theta)**18 + 1.12949309789995e+32*cos(theta)**16 - 8.19958691760396e+30*cos(theta)**14 + 4.38919064412918e+29*cos(theta)**12 - 1.66199989967026e+28*cos(theta)**10 + 4.19696944361176e+26*cos(theta)**8 - 6.46753684210948e+24*cos(theta)**6 + 5.2496240601538e+22*cos(theta)**4 - 1.67987969924922e+20*cos(theta)**2 + 8.85078872101799e+16)*sin(10*phi)

#@torch.jit.script
def Yl62_m_minus_9(theta, phi):
    return 3.16224497427806e-16*(1.0 - cos(theta)**2)**4.5*(2.42764667000272e+33*cos(theta)**53 - 2.71975374899492e+34*cos(theta)**51 + 1.43292811155724e+35*cos(theta)**49 - 4.72023377924739e+35*cos(theta)**47 + 1.09029331524924e+36*cos(theta)**45 - 1.87720066451608e+36*cos(theta)**43 + 2.50016548681123e+36*cos(theta)**41 - 2.63852728337865e+36*cos(theta)**39 + 2.24214302406374e+36*cos(theta)**37 - 1.55064096991324e+36*cos(theta)**35 + 8.78696549617503e+35*cos(theta)**33 - 4.09489654190681e+35*cos(theta)**31 + 1.57106179206821e+35*cos(theta)**29 - 4.95610790660211e+34*cos(theta)**27 + 1.28099696260482e+34*cos(theta)**25 - 2.69683571074698e+33*cos(theta)**23 + 4.58534566410609e+32*cos(theta)**21 - 6.22445112774583e+31*cos(theta)**19 + 6.64407704647026e+30*cos(theta)**17 - 5.46639127840264e+29*cos(theta)**15 + 3.37630049548398e+28*cos(theta)**13 - 1.51090899970023e+27*cos(theta)**11 + 4.66329938179084e+25*cos(theta)**9 - 9.23933834587068e+23*cos(theta)**7 + 1.04992481203076e+22*cos(theta)**5 - 5.59959899749738e+19*cos(theta)**3 + 8.85078872101799e+16*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl62_m_minus_8(theta, phi):
    return 1.95804002577444e-14*(1.0 - cos(theta)**2)**4*(4.49564198148653e+31*cos(theta)**54 - 5.23029567114408e+32*cos(theta)**52 + 2.86585622311448e+33*cos(theta)**50 - 9.83382037343205e+33*cos(theta)**48 + 2.37020285923747e+34*cos(theta)**46 - 4.26636514662745e+34*cos(theta)**44 + 5.95277496859818e+34*cos(theta)**42 - 6.59631820844663e+34*cos(theta)**40 + 5.9003763791151e+34*cos(theta)**38 - 4.30733602753678e+34*cos(theta)**36 + 2.58440161652207e+34*cos(theta)**34 - 1.27965516934588e+34*cos(theta)**32 + 5.23687264022735e+33*cos(theta)**30 - 1.77003853807218e+33*cos(theta)**28 + 4.92691139463391e+32*cos(theta)**26 - 1.12368154614458e+32*cos(theta)**24 + 2.08424802913913e+31*cos(theta)**22 - 3.11222556387291e+30*cos(theta)**20 + 3.6911539147057e+29*cos(theta)**18 - 3.41649454900165e+28*cos(theta)**16 + 2.41164321105999e+27*cos(theta)**14 - 1.25909083308353e+26*cos(theta)**12 + 4.66329938179084e+24*cos(theta)**10 - 1.15491729323384e+23*cos(theta)**8 + 1.74987468671793e+21*cos(theta)**6 - 1.39989974937435e+19*cos(theta)**4 + 4.425394360509e+16*cos(theta)**2 - 23084999272347.4)*sin(8*phi)

#@torch.jit.script
def Yl62_m_minus_7(theta, phi):
    return 1.21493188528242e-12*(1.0 - cos(theta)**2)**3.5*(8.17389451179369e+29*cos(theta)**55 - 9.86848239838506e+30*cos(theta)**53 + 5.61932592767546e+31*cos(theta)**51 - 2.00690211702695e+32*cos(theta)**49 + 5.04298480688823e+32*cos(theta)**47 - 9.48081143694988e+32*cos(theta)**45 + 1.38436627176702e+33*cos(theta)**43 - 1.60885809962113e+33*cos(theta)**41 + 1.51291702028592e+33*cos(theta)**39 - 1.16414487230724e+33*cos(theta)**37 + 7.38400461863448e+32*cos(theta)**35 - 3.87774293741175e+32*cos(theta)**33 + 1.68931375491205e+32*cos(theta)**31 - 6.10358116576615e+31*cos(theta)**29 + 1.82478199801256e+31*cos(theta)**27 - 4.4947261845783e+30*cos(theta)**25 + 9.06194795277884e+29*cos(theta)**23 - 1.48201217327282e+29*cos(theta)**21 + 1.94271258668721e+28*cos(theta)**19 - 2.00970267588332e+27*cos(theta)**17 + 1.60776214070666e+26*cos(theta)**15 - 9.68531410064252e+24*cos(theta)**13 + 4.23936307435531e+23*cos(theta)**11 - 1.28324143692648e+22*cos(theta)**9 + 2.49982098102562e+20*cos(theta)**7 - 2.79979949874869e+18*cos(theta)**5 + 1.475131453503e+16*cos(theta)**3 - 23084999272347.4*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl62_m_minus_6(theta, phi):
    return 7.55214794176097e-11*(1.0 - cos(theta)**2)**3*(1.45962401996316e+28*cos(theta)**56 - 1.82749674044168e+29*cos(theta)**54 + 1.08063960147605e+30*cos(theta)**52 - 4.0138042340539e+30*cos(theta)**50 + 1.05062183476838e+31*cos(theta)**48 - 2.06104596455432e+31*cos(theta)**46 + 3.14628698128868e+31*cos(theta)**44 - 3.83061452290745e+31*cos(theta)**42 + 3.78229255071481e+31*cos(theta)**40 - 3.06353913765062e+31*cos(theta)**38 + 2.05111239406513e+31*cos(theta)**36 - 1.14051262865051e+31*cos(theta)**34 + 5.27910548410016e+30*cos(theta)**32 - 2.03452705525538e+30*cos(theta)**30 + 6.51707856433057e+29*cos(theta)**28 - 1.72874084022242e+29*cos(theta)**26 + 3.77581164699118e+28*cos(theta)**24 - 6.73641896942189e+27*cos(theta)**22 + 9.71356293343606e+26*cos(theta)**20 - 1.11650148660185e+26*cos(theta)**18 + 1.00485133794166e+25*cos(theta)**16 - 6.91808150045894e+23*cos(theta)**14 + 3.53280256196276e+22*cos(theta)**12 - 1.28324143692648e+21*cos(theta)**10 + 3.12477622628202e+19*cos(theta)**8 - 4.66633249791449e+17*cos(theta)**6 + 3.6878286337575e+15*cos(theta)**4 - 11542499636173.7*cos(theta)**2 + 5974378693.67169)*sin(6*phi)

#@torch.jit.script
def Yl62_m_minus_5(theta, phi):
    return 4.70178074519359e-9*(1.0 - cos(theta)**2)**2.5*(2.56074389467221e+26*cos(theta)**57 - 3.3227213462576e+27*cos(theta)**55 + 2.03894264429443e+28*cos(theta)**53 - 7.87020438049784e+28*cos(theta)**51 + 2.14412619340486e+29*cos(theta)**49 - 4.38520417990281e+29*cos(theta)**47 + 6.99174884730817e+29*cos(theta)**45 - 8.90840586722663e+29*cos(theta)**43 + 9.22510378223124e+29*cos(theta)**41 - 7.85522855807852e+29*cos(theta)**39 + 5.54354701098684e+29*cos(theta)**37 - 3.25860751043004e+29*cos(theta)**35 + 1.5997289345758e+29*cos(theta)**33 - 6.56299050082381e+28*cos(theta)**31 + 2.24726847045882e+28*cos(theta)**29 - 6.40274385267565e+27*cos(theta)**27 + 1.51032465879647e+27*cos(theta)**25 - 2.92887781279213e+26*cos(theta)**23 + 4.62550615877908e+25*cos(theta)**21 - 5.87632361369393e+24*cos(theta)**19 + 5.91089022318624e+23*cos(theta)**17 - 4.6120543336393e+22*cos(theta)**15 + 2.71754043227905e+21*cos(theta)**13 - 1.16658312447862e+20*cos(theta)**11 + 3.4719735847578e+18*cos(theta)**9 - 6.66618928273498e+16*cos(theta)**7 + 737565726751500.0*cos(theta)**5 - 3847499878724.57*cos(theta)**3 + 5974378693.67169*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl62_m_minus_4(theta, phi):
    return 2.93098618378598e-7*(1.0 - cos(theta)**2)**2*(4.41507568046932e+24*cos(theta)**58 - 5.93343097545999e+25*cos(theta)**56 + 3.77581971165636e+26*cos(theta)**54 - 1.51350084240343e+27*cos(theta)**52 + 4.28825238680972e+27*cos(theta)**50 - 9.13584204146419e+27*cos(theta)**48 + 1.51994540158873e+28*cos(theta)**46 - 2.02463769709696e+28*cos(theta)**44 + 2.19645328148363e+28*cos(theta)**42 - 1.96380713951963e+28*cos(theta)**40 + 1.45882816078601e+28*cos(theta)**38 - 9.05168752897234e+27*cos(theta)**36 + 4.70508510169354e+27*cos(theta)**34 - 2.05093453150744e+27*cos(theta)**32 + 7.49089490152939e+26*cos(theta)**30 - 2.28669423309845e+26*cos(theta)**28 + 5.80894099537105e+25*cos(theta)**26 - 1.22036575533005e+25*cos(theta)**24 + 2.10250279944503e+24*cos(theta)**22 - 2.93816180684696e+23*cos(theta)**20 + 3.28382790177014e+22*cos(theta)**18 - 2.88253395852456e+21*cos(theta)**16 + 1.94110030877075e+20*cos(theta)**14 - 9.72152603732185e+18*cos(theta)**12 + 3.4719735847578e+17*cos(theta)**10 - 8.33273660341873e+15*cos(theta)**8 + 122927621125250.0*cos(theta)**6 - 961874969681.142*cos(theta)**4 + 2987189346.83584*cos(theta)**2 - 1537410.88360054)*sin(4*phi)

#@torch.jit.script
def Yl62_m_minus_3(theta, phi):
    return 1.82899174293285e-5*(1.0 - cos(theta)**2)**1.5*(7.48317911943953e+22*cos(theta)**59 - 1.04095280271228e+24*cos(theta)**57 + 6.86512674846611e+24*cos(theta)**55 - 2.85566196679893e+25*cos(theta)**53 + 8.4083380133524e+25*cos(theta)**51 - 1.86445755948249e+26*cos(theta)**49 + 3.23392638635901e+26*cos(theta)**47 - 4.49919488243769e+26*cos(theta)**45 + 5.10803088717123e+26*cos(theta)**43 - 4.78977351102349e+26*cos(theta)**41 + 3.74058502765644e+26*cos(theta)**39 - 2.44640203485739e+26*cos(theta)**37 + 1.3443100290553e+26*cos(theta)**35 - 6.21495312578013e+25*cos(theta)**33 + 2.41641771017077e+25*cos(theta)**31 - 7.88515252792567e+24*cos(theta)**29 + 2.1514596279152e+24*cos(theta)**27 - 4.88146302132021e+23*cos(theta)**25 + 9.14131651932624e+22*cos(theta)**23 - 1.39912466992713e+22*cos(theta)**21 + 1.72833047461586e+21*cos(theta)**19 - 1.6956082108968e+20*cos(theta)**17 + 1.29406687251383e+19*cos(theta)**15 - 7.47809695178604e+17*cos(theta)**13 + 3.15633962250709e+16*cos(theta)**11 - 925859622602081.0*cos(theta)**9 + 17561088732178.6*cos(theta)**7 - 192374993936.228*cos(theta)**5 + 995729782.278615*cos(theta)**3 - 1537410.88360054*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl62_m_minus_2(theta, phi):
    return 0.00114220497737029*(1.0 - cos(theta)**2)*(1.24719651990659e+21*cos(theta)**60 - 1.7947462115729e+22*cos(theta)**58 + 1.22591549079752e+23*cos(theta)**56 - 5.28826290147949e+23*cos(theta)**54 + 1.61698807949085e+24*cos(theta)**52 - 3.72891511896498e+24*cos(theta)**50 + 6.73734663824793e+24*cos(theta)**48 - 9.78085844008193e+24*cos(theta)**46 + 1.16091611072073e+25*cos(theta)**44 - 1.1404222645294e+25*cos(theta)**42 + 9.3514625691411e+24*cos(theta)**40 - 6.43790009172997e+24*cos(theta)**38 + 3.73419452515361e+24*cos(theta)**36 - 1.82792738993533e+24*cos(theta)**34 + 7.55130534428366e+23*cos(theta)**32 - 2.62838417597522e+23*cos(theta)**30 + 7.68378438541144e+22*cos(theta)**28 - 1.87748577743085e+22*cos(theta)**26 + 3.8088818830526e+21*cos(theta)**24 - 6.35965759057784e+20*cos(theta)**22 + 8.6416523730793e+19*cos(theta)**20 - 9.42004561609333e+18*cos(theta)**18 + 8.08791795321145e+17*cos(theta)**16 - 5.34149782270431e+16*cos(theta)**14 + 2.63028301875591e+15*cos(theta)**12 - 92585962260208.1*cos(theta)**10 + 2195136091522.32*cos(theta)**8 - 32062498989.3714*cos(theta)**6 + 248932445.569654*cos(theta)**4 - 768705.441800269*cos(theta)**2 + 394.207918871933)*sin(2*phi)

#@torch.jit.script
def Yl62_m_minus_1(theta, phi):
    return 0.071367248434602*(1.0 - cos(theta)**2)**0.5*(2.04458445886326e+19*cos(theta)**61 - 3.04194273147948e+20*cos(theta)**59 + 2.15072893122372e+21*cos(theta)**57 - 9.61502345723545e+21*cos(theta)**55 + 3.05092090469971e+22*cos(theta)**53 - 7.31159827248034e+22*cos(theta)**51 + 1.37496870168325e+23*cos(theta)**49 - 2.08103371065573e+23*cos(theta)**47 + 2.57981357937941e+23*cos(theta)**45 - 2.65214480123117e+23*cos(theta)**43 + 2.2808445290588e+23*cos(theta)**41 - 1.6507436132641e+23*cos(theta)**39 + 1.00924176355503e+23*cos(theta)**37 - 5.22264968552952e+22*cos(theta)**35 + 2.28827434675262e+22*cos(theta)**33 - 8.47865863217814e+21*cos(theta)**31 + 2.64958082255567e+21*cos(theta)**29 - 6.95365102752167e+20*cos(theta)**27 + 1.52355275322104e+20*cos(theta)**25 - 2.76506851764254e+19*cos(theta)**23 + 4.11507255860919e+18*cos(theta)**21 - 4.95791874531228e+17*cos(theta)**19 + 4.75759879600673e+16*cos(theta)**17 - 3.56099854846954e+15*cos(theta)**15 + 202329462981224.0*cos(theta)**13 - 8416905660018.92*cos(theta)**11 + 243904010169.147*cos(theta)**9 - 4580356998.48163*cos(theta)**7 + 49786489.1139307*cos(theta)**5 - 256235.147266756*cos(theta)**3 + 394.207918871933*cos(theta))*sin(phi)

#@torch.jit.script
def Yl62_m0(theta, phi):
    return 3.26748282180394e+18*cos(theta)**62 - 5.02342277726118e+19*cos(theta)**60 + 3.67415632882326e+20*cos(theta)**58 - 1.70122700603497e+21*cos(theta)**56 + 5.59805467797832e+21*cos(theta)**54 - 1.39318543377165e+22*cos(theta)**52 + 2.72472549436756e+22*cos(theta)**50 - 4.29573839202093e+22*cos(theta)**48 + 5.55687259885276e+22*cos(theta)**46 - 5.97233970904736e+22*cos(theta)**44 + 5.38079368072267e+22*cos(theta)**42 - 4.08902326487398e+22*cos(theta)**40 + 2.631549625909e+22*cos(theta)**38 - 1.43743542114532e+22*cos(theta)**36 + 6.66851484036488e+21*cos(theta)**34 - 2.62528900031207e+21*cos(theta)**32 + 8.75096333437356e+20*cos(theta)**30 - 2.46067811923238e+20*cos(theta)**28 + 5.80609443863821e+19*cos(theta)**26 - 1.14154911830455e+19*cos(theta)**24 + 1.8533385685415e+18*cos(theta)**22 - 2.45623183782609e+17*cos(theta)**20 + 2.61887794156541e+16*cos(theta)**18 - 2.20521918029449e+15*cos(theta)**16 + 143196050668473.0*cos(theta)**14 - 6949781659109.9*cos(theta)**12 + 241667855374.738*cos(theta)**10 - 5672954351.51968*cos(theta)**8 + 82216729.7321692*cos(theta)**6 - 634714.846105269*cos(theta)**4 + 1952.96875724698*cos(theta)**2 - 0.999984002686627

#@torch.jit.script
def Yl62_m1(theta, phi):
    return 0.071367248434602*(1.0 - cos(theta)**2)**0.5*(2.04458445886326e+19*cos(theta)**61 - 3.04194273147948e+20*cos(theta)**59 + 2.15072893122372e+21*cos(theta)**57 - 9.61502345723545e+21*cos(theta)**55 + 3.05092090469971e+22*cos(theta)**53 - 7.31159827248034e+22*cos(theta)**51 + 1.37496870168325e+23*cos(theta)**49 - 2.08103371065573e+23*cos(theta)**47 + 2.57981357937941e+23*cos(theta)**45 - 2.65214480123117e+23*cos(theta)**43 + 2.2808445290588e+23*cos(theta)**41 - 1.6507436132641e+23*cos(theta)**39 + 1.00924176355503e+23*cos(theta)**37 - 5.22264968552952e+22*cos(theta)**35 + 2.28827434675262e+22*cos(theta)**33 - 8.47865863217814e+21*cos(theta)**31 + 2.64958082255567e+21*cos(theta)**29 - 6.95365102752167e+20*cos(theta)**27 + 1.52355275322104e+20*cos(theta)**25 - 2.76506851764254e+19*cos(theta)**23 + 4.11507255860919e+18*cos(theta)**21 - 4.95791874531228e+17*cos(theta)**19 + 4.75759879600673e+16*cos(theta)**17 - 3.56099854846954e+15*cos(theta)**15 + 202329462981224.0*cos(theta)**13 - 8416905660018.92*cos(theta)**11 + 243904010169.147*cos(theta)**9 - 4580356998.48163*cos(theta)**7 + 49786489.1139307*cos(theta)**5 - 256235.147266756*cos(theta)**3 + 394.207918871933*cos(theta))*cos(phi)

#@torch.jit.script
def Yl62_m2(theta, phi):
    return 0.00114220497737029*(1.0 - cos(theta)**2)*(1.24719651990659e+21*cos(theta)**60 - 1.7947462115729e+22*cos(theta)**58 + 1.22591549079752e+23*cos(theta)**56 - 5.28826290147949e+23*cos(theta)**54 + 1.61698807949085e+24*cos(theta)**52 - 3.72891511896498e+24*cos(theta)**50 + 6.73734663824793e+24*cos(theta)**48 - 9.78085844008193e+24*cos(theta)**46 + 1.16091611072073e+25*cos(theta)**44 - 1.1404222645294e+25*cos(theta)**42 + 9.3514625691411e+24*cos(theta)**40 - 6.43790009172997e+24*cos(theta)**38 + 3.73419452515361e+24*cos(theta)**36 - 1.82792738993533e+24*cos(theta)**34 + 7.55130534428366e+23*cos(theta)**32 - 2.62838417597522e+23*cos(theta)**30 + 7.68378438541144e+22*cos(theta)**28 - 1.87748577743085e+22*cos(theta)**26 + 3.8088818830526e+21*cos(theta)**24 - 6.35965759057784e+20*cos(theta)**22 + 8.6416523730793e+19*cos(theta)**20 - 9.42004561609333e+18*cos(theta)**18 + 8.08791795321145e+17*cos(theta)**16 - 5.34149782270431e+16*cos(theta)**14 + 2.63028301875591e+15*cos(theta)**12 - 92585962260208.1*cos(theta)**10 + 2195136091522.32*cos(theta)**8 - 32062498989.3714*cos(theta)**6 + 248932445.569654*cos(theta)**4 - 768705.441800269*cos(theta)**2 + 394.207918871933)*cos(2*phi)

#@torch.jit.script
def Yl62_m3(theta, phi):
    return 1.82899174293285e-5*(1.0 - cos(theta)**2)**1.5*(7.48317911943953e+22*cos(theta)**59 - 1.04095280271228e+24*cos(theta)**57 + 6.86512674846611e+24*cos(theta)**55 - 2.85566196679893e+25*cos(theta)**53 + 8.4083380133524e+25*cos(theta)**51 - 1.86445755948249e+26*cos(theta)**49 + 3.23392638635901e+26*cos(theta)**47 - 4.49919488243769e+26*cos(theta)**45 + 5.10803088717123e+26*cos(theta)**43 - 4.78977351102349e+26*cos(theta)**41 + 3.74058502765644e+26*cos(theta)**39 - 2.44640203485739e+26*cos(theta)**37 + 1.3443100290553e+26*cos(theta)**35 - 6.21495312578013e+25*cos(theta)**33 + 2.41641771017077e+25*cos(theta)**31 - 7.88515252792567e+24*cos(theta)**29 + 2.1514596279152e+24*cos(theta)**27 - 4.88146302132021e+23*cos(theta)**25 + 9.14131651932624e+22*cos(theta)**23 - 1.39912466992713e+22*cos(theta)**21 + 1.72833047461586e+21*cos(theta)**19 - 1.6956082108968e+20*cos(theta)**17 + 1.29406687251383e+19*cos(theta)**15 - 7.47809695178604e+17*cos(theta)**13 + 3.15633962250709e+16*cos(theta)**11 - 925859622602081.0*cos(theta)**9 + 17561088732178.6*cos(theta)**7 - 192374993936.228*cos(theta)**5 + 995729782.278615*cos(theta)**3 - 1537410.88360054*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl62_m4(theta, phi):
    return 2.93098618378598e-7*(1.0 - cos(theta)**2)**2*(4.41507568046932e+24*cos(theta)**58 - 5.93343097545999e+25*cos(theta)**56 + 3.77581971165636e+26*cos(theta)**54 - 1.51350084240343e+27*cos(theta)**52 + 4.28825238680972e+27*cos(theta)**50 - 9.13584204146419e+27*cos(theta)**48 + 1.51994540158873e+28*cos(theta)**46 - 2.02463769709696e+28*cos(theta)**44 + 2.19645328148363e+28*cos(theta)**42 - 1.96380713951963e+28*cos(theta)**40 + 1.45882816078601e+28*cos(theta)**38 - 9.05168752897234e+27*cos(theta)**36 + 4.70508510169354e+27*cos(theta)**34 - 2.05093453150744e+27*cos(theta)**32 + 7.49089490152939e+26*cos(theta)**30 - 2.28669423309845e+26*cos(theta)**28 + 5.80894099537105e+25*cos(theta)**26 - 1.22036575533005e+25*cos(theta)**24 + 2.10250279944503e+24*cos(theta)**22 - 2.93816180684696e+23*cos(theta)**20 + 3.28382790177014e+22*cos(theta)**18 - 2.88253395852456e+21*cos(theta)**16 + 1.94110030877075e+20*cos(theta)**14 - 9.72152603732185e+18*cos(theta)**12 + 3.4719735847578e+17*cos(theta)**10 - 8.33273660341873e+15*cos(theta)**8 + 122927621125250.0*cos(theta)**6 - 961874969681.142*cos(theta)**4 + 2987189346.83584*cos(theta)**2 - 1537410.88360054)*cos(4*phi)

#@torch.jit.script
def Yl62_m5(theta, phi):
    return 4.70178074519359e-9*(1.0 - cos(theta)**2)**2.5*(2.56074389467221e+26*cos(theta)**57 - 3.3227213462576e+27*cos(theta)**55 + 2.03894264429443e+28*cos(theta)**53 - 7.87020438049784e+28*cos(theta)**51 + 2.14412619340486e+29*cos(theta)**49 - 4.38520417990281e+29*cos(theta)**47 + 6.99174884730817e+29*cos(theta)**45 - 8.90840586722663e+29*cos(theta)**43 + 9.22510378223124e+29*cos(theta)**41 - 7.85522855807852e+29*cos(theta)**39 + 5.54354701098684e+29*cos(theta)**37 - 3.25860751043004e+29*cos(theta)**35 + 1.5997289345758e+29*cos(theta)**33 - 6.56299050082381e+28*cos(theta)**31 + 2.24726847045882e+28*cos(theta)**29 - 6.40274385267565e+27*cos(theta)**27 + 1.51032465879647e+27*cos(theta)**25 - 2.92887781279213e+26*cos(theta)**23 + 4.62550615877908e+25*cos(theta)**21 - 5.87632361369393e+24*cos(theta)**19 + 5.91089022318624e+23*cos(theta)**17 - 4.6120543336393e+22*cos(theta)**15 + 2.71754043227905e+21*cos(theta)**13 - 1.16658312447862e+20*cos(theta)**11 + 3.4719735847578e+18*cos(theta)**9 - 6.66618928273498e+16*cos(theta)**7 + 737565726751500.0*cos(theta)**5 - 3847499878724.57*cos(theta)**3 + 5974378693.67169*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl62_m6(theta, phi):
    return 7.55214794176097e-11*(1.0 - cos(theta)**2)**3*(1.45962401996316e+28*cos(theta)**56 - 1.82749674044168e+29*cos(theta)**54 + 1.08063960147605e+30*cos(theta)**52 - 4.0138042340539e+30*cos(theta)**50 + 1.05062183476838e+31*cos(theta)**48 - 2.06104596455432e+31*cos(theta)**46 + 3.14628698128868e+31*cos(theta)**44 - 3.83061452290745e+31*cos(theta)**42 + 3.78229255071481e+31*cos(theta)**40 - 3.06353913765062e+31*cos(theta)**38 + 2.05111239406513e+31*cos(theta)**36 - 1.14051262865051e+31*cos(theta)**34 + 5.27910548410016e+30*cos(theta)**32 - 2.03452705525538e+30*cos(theta)**30 + 6.51707856433057e+29*cos(theta)**28 - 1.72874084022242e+29*cos(theta)**26 + 3.77581164699118e+28*cos(theta)**24 - 6.73641896942189e+27*cos(theta)**22 + 9.71356293343606e+26*cos(theta)**20 - 1.11650148660185e+26*cos(theta)**18 + 1.00485133794166e+25*cos(theta)**16 - 6.91808150045894e+23*cos(theta)**14 + 3.53280256196276e+22*cos(theta)**12 - 1.28324143692648e+21*cos(theta)**10 + 3.12477622628202e+19*cos(theta)**8 - 4.66633249791449e+17*cos(theta)**6 + 3.6878286337575e+15*cos(theta)**4 - 11542499636173.7*cos(theta)**2 + 5974378693.67169)*cos(6*phi)

#@torch.jit.script
def Yl62_m7(theta, phi):
    return 1.21493188528242e-12*(1.0 - cos(theta)**2)**3.5*(8.17389451179369e+29*cos(theta)**55 - 9.86848239838506e+30*cos(theta)**53 + 5.61932592767546e+31*cos(theta)**51 - 2.00690211702695e+32*cos(theta)**49 + 5.04298480688823e+32*cos(theta)**47 - 9.48081143694988e+32*cos(theta)**45 + 1.38436627176702e+33*cos(theta)**43 - 1.60885809962113e+33*cos(theta)**41 + 1.51291702028592e+33*cos(theta)**39 - 1.16414487230724e+33*cos(theta)**37 + 7.38400461863448e+32*cos(theta)**35 - 3.87774293741175e+32*cos(theta)**33 + 1.68931375491205e+32*cos(theta)**31 - 6.10358116576615e+31*cos(theta)**29 + 1.82478199801256e+31*cos(theta)**27 - 4.4947261845783e+30*cos(theta)**25 + 9.06194795277884e+29*cos(theta)**23 - 1.48201217327282e+29*cos(theta)**21 + 1.94271258668721e+28*cos(theta)**19 - 2.00970267588332e+27*cos(theta)**17 + 1.60776214070666e+26*cos(theta)**15 - 9.68531410064252e+24*cos(theta)**13 + 4.23936307435531e+23*cos(theta)**11 - 1.28324143692648e+22*cos(theta)**9 + 2.49982098102562e+20*cos(theta)**7 - 2.79979949874869e+18*cos(theta)**5 + 1.475131453503e+16*cos(theta)**3 - 23084999272347.4*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl62_m8(theta, phi):
    return 1.95804002577444e-14*(1.0 - cos(theta)**2)**4*(4.49564198148653e+31*cos(theta)**54 - 5.23029567114408e+32*cos(theta)**52 + 2.86585622311448e+33*cos(theta)**50 - 9.83382037343205e+33*cos(theta)**48 + 2.37020285923747e+34*cos(theta)**46 - 4.26636514662745e+34*cos(theta)**44 + 5.95277496859818e+34*cos(theta)**42 - 6.59631820844663e+34*cos(theta)**40 + 5.9003763791151e+34*cos(theta)**38 - 4.30733602753678e+34*cos(theta)**36 + 2.58440161652207e+34*cos(theta)**34 - 1.27965516934588e+34*cos(theta)**32 + 5.23687264022735e+33*cos(theta)**30 - 1.77003853807218e+33*cos(theta)**28 + 4.92691139463391e+32*cos(theta)**26 - 1.12368154614458e+32*cos(theta)**24 + 2.08424802913913e+31*cos(theta)**22 - 3.11222556387291e+30*cos(theta)**20 + 3.6911539147057e+29*cos(theta)**18 - 3.41649454900165e+28*cos(theta)**16 + 2.41164321105999e+27*cos(theta)**14 - 1.25909083308353e+26*cos(theta)**12 + 4.66329938179084e+24*cos(theta)**10 - 1.15491729323384e+23*cos(theta)**8 + 1.74987468671793e+21*cos(theta)**6 - 1.39989974937435e+19*cos(theta)**4 + 4.425394360509e+16*cos(theta)**2 - 23084999272347.4)*cos(8*phi)

#@torch.jit.script
def Yl62_m9(theta, phi):
    return 3.16224497427806e-16*(1.0 - cos(theta)**2)**4.5*(2.42764667000272e+33*cos(theta)**53 - 2.71975374899492e+34*cos(theta)**51 + 1.43292811155724e+35*cos(theta)**49 - 4.72023377924739e+35*cos(theta)**47 + 1.09029331524924e+36*cos(theta)**45 - 1.87720066451608e+36*cos(theta)**43 + 2.50016548681123e+36*cos(theta)**41 - 2.63852728337865e+36*cos(theta)**39 + 2.24214302406374e+36*cos(theta)**37 - 1.55064096991324e+36*cos(theta)**35 + 8.78696549617503e+35*cos(theta)**33 - 4.09489654190681e+35*cos(theta)**31 + 1.57106179206821e+35*cos(theta)**29 - 4.95610790660211e+34*cos(theta)**27 + 1.28099696260482e+34*cos(theta)**25 - 2.69683571074698e+33*cos(theta)**23 + 4.58534566410609e+32*cos(theta)**21 - 6.22445112774583e+31*cos(theta)**19 + 6.64407704647026e+30*cos(theta)**17 - 5.46639127840264e+29*cos(theta)**15 + 3.37630049548398e+28*cos(theta)**13 - 1.51090899970023e+27*cos(theta)**11 + 4.66329938179084e+25*cos(theta)**9 - 9.23933834587068e+23*cos(theta)**7 + 1.04992481203076e+22*cos(theta)**5 - 5.59959899749738e+19*cos(theta)**3 + 8.85078872101799e+16*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl62_m10(theta, phi):
    return 5.11907306137765e-18*(1.0 - cos(theta)**2)**5*(1.28665273510144e+35*cos(theta)**52 - 1.38707441198741e+36*cos(theta)**50 + 7.02134774663049e+36*cos(theta)**48 - 2.21850987624627e+37*cos(theta)**46 + 4.90631991862156e+37*cos(theta)**44 - 8.07196285741913e+37*cos(theta)**42 + 1.02506784959261e+38*cos(theta)**40 - 1.02902564051767e+38*cos(theta)**38 + 8.29592918903583e+37*cos(theta)**36 - 5.42724339469634e+37*cos(theta)**34 + 2.89969861373776e+37*cos(theta)**32 - 1.26941792799111e+37*cos(theta)**30 + 4.5560791969978e+36*cos(theta)**28 - 1.33814913478257e+36*cos(theta)**26 + 3.20249240651204e+35*cos(theta)**24 - 6.20272213471806e+34*cos(theta)**22 + 9.62922589462279e+33*cos(theta)**20 - 1.18264571427171e+33*cos(theta)**18 + 1.12949309789995e+32*cos(theta)**16 - 8.19958691760396e+30*cos(theta)**14 + 4.38919064412918e+29*cos(theta)**12 - 1.66199989967026e+28*cos(theta)**10 + 4.19696944361176e+26*cos(theta)**8 - 6.46753684210948e+24*cos(theta)**6 + 5.2496240601538e+22*cos(theta)**4 - 1.67987969924922e+20*cos(theta)**2 + 8.85078872101799e+16)*cos(10*phi)

#@torch.jit.script
def Yl62_m11(theta, phi):
    return 8.30860717141439e-20*(1.0 - cos(theta)**2)**5.5*(6.69059422252751e+36*cos(theta)**51 - 6.93537205993705e+37*cos(theta)**49 + 3.37024691838263e+38*cos(theta)**47 - 1.02051454307328e+39*cos(theta)**45 + 2.15878076419349e+39*cos(theta)**43 - 3.39022440011603e+39*cos(theta)**41 + 4.10027139837042e+39*cos(theta)**39 - 3.91029743396716e+39*cos(theta)**37 + 2.9865345080529e+39*cos(theta)**35 - 1.84526275419676e+39*cos(theta)**33 + 9.27903556396083e+38*cos(theta)**31 - 3.80825378397333e+38*cos(theta)**29 + 1.27570217515938e+38*cos(theta)**27 - 3.47918775043468e+37*cos(theta)**25 + 7.6859817756289e+36*cos(theta)**23 - 1.36459886963797e+36*cos(theta)**21 + 1.92584517892456e+35*cos(theta)**19 - 2.12876228568907e+34*cos(theta)**17 + 1.80718895663991e+33*cos(theta)**15 - 1.14794216846455e+32*cos(theta)**13 + 5.26702877295501e+30*cos(theta)**11 - 1.66199989967026e+29*cos(theta)**9 + 3.35757555488941e+27*cos(theta)**7 - 3.88052210526569e+25*cos(theta)**5 + 2.09984962406152e+23*cos(theta)**3 - 3.35975939849843e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl62_m12(theta, phi):
    return 1.35246887172678e-21*(1.0 - cos(theta)**2)**6*(3.41220305348903e+38*cos(theta)**50 - 3.39833230936916e+39*cos(theta)**48 + 1.58401605163984e+40*cos(theta)**46 - 4.59231544382978e+40*cos(theta)**44 + 9.282757286032e+40*cos(theta)**42 - 1.38999200404757e+41*cos(theta)**40 + 1.59910584536447e+41*cos(theta)**38 - 1.44681005056785e+41*cos(theta)**36 + 1.04528707781852e+41*cos(theta)**34 - 6.08936708884929e+40*cos(theta)**32 + 2.87650102482786e+40*cos(theta)**30 - 1.10439359735227e+40*cos(theta)**28 + 3.44439587293034e+39*cos(theta)**26 - 8.69796937608671e+38*cos(theta)**24 + 1.76777580839465e+38*cos(theta)**22 - 2.86565762623974e+37*cos(theta)**20 + 3.65910583995666e+36*cos(theta)**18 - 3.61889588567142e+35*cos(theta)**16 + 2.71078343495987e+34*cos(theta)**14 - 1.49232481900392e+33*cos(theta)**12 + 5.79373165025051e+31*cos(theta)**10 - 1.49579990970323e+30*cos(theta)**8 + 2.35030288842258e+28*cos(theta)**6 - 1.94026105263284e+26*cos(theta)**4 + 6.29954887218456e+23*cos(theta)**2 - 3.35975939849843e+20)*cos(12*phi)

#@torch.jit.script
def Yl62_m13(theta, phi):
    return 2.20857241915218e-23*(1.0 - cos(theta)**2)**6.5*(1.70610152674451e+40*cos(theta)**49 - 1.63119950849719e+41*cos(theta)**47 + 7.28647383754325e+41*cos(theta)**45 - 2.0206187952851e+42*cos(theta)**43 + 3.89875806013344e+42*cos(theta)**41 - 5.55996801619029e+42*cos(theta)**39 + 6.07660221238497e+42*cos(theta)**37 - 5.20851618204426e+42*cos(theta)**35 + 3.55397606458295e+42*cos(theta)**33 - 1.94859746843177e+42*cos(theta)**31 + 8.62950307448357e+41*cos(theta)**29 - 3.09230207258635e+41*cos(theta)**27 + 8.95542926961887e+40*cos(theta)**25 - 2.08751265026081e+40*cos(theta)**23 + 3.88910677846822e+39*cos(theta)**21 - 5.73131525247949e+38*cos(theta)**19 + 6.58639051192199e+37*cos(theta)**17 - 5.79023341707428e+36*cos(theta)**15 + 3.79509680894382e+35*cos(theta)**13 - 1.7907897828047e+34*cos(theta)**11 + 5.79373165025051e+32*cos(theta)**9 - 1.19663992776258e+31*cos(theta)**7 + 1.41018173305355e+29*cos(theta)**5 - 7.76104421053137e+26*cos(theta)**3 + 1.25990977443691e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl62_m14(theta, phi):
    return 3.61915187390057e-25*(1.0 - cos(theta)**2)**7*(8.35989748104812e+41*cos(theta)**48 - 7.66663768993682e+42*cos(theta)**46 + 3.27891322689446e+43*cos(theta)**44 - 8.68866081972595e+43*cos(theta)**42 + 1.59849080465471e+44*cos(theta)**40 - 2.16838752631421e+44*cos(theta)**38 + 2.24834281858244e+44*cos(theta)**36 - 1.82298066371549e+44*cos(theta)**34 + 1.17281210131237e+44*cos(theta)**32 - 6.0406521521385e+43*cos(theta)**30 + 2.50255589160024e+43*cos(theta)**28 - 8.34921559598313e+42*cos(theta)**26 + 2.23885731740472e+42*cos(theta)**24 - 4.80127909559986e+41*cos(theta)**22 + 8.16712423478327e+40*cos(theta)**20 - 1.0889498979711e+40*cos(theta)**18 + 1.11968638702674e+39*cos(theta)**16 - 8.68535012561142e+37*cos(theta)**14 + 4.93362585162696e+36*cos(theta)**12 - 1.96986876108517e+35*cos(theta)**10 + 5.21435848522546e+33*cos(theta)**8 - 8.37647949433809e+31*cos(theta)**6 + 7.05090866526775e+29*cos(theta)**4 - 2.32831326315941e+27*cos(theta)**2 + 1.25990977443691e+24)*cos(14*phi)

#@torch.jit.script
def Yl62_m15(theta, phi):
    return 5.95306777437426e-27*(1.0 - cos(theta)**2)**7.5*(4.0127507909031e+43*cos(theta)**47 - 3.52665333737093e+44*cos(theta)**45 + 1.44272181983356e+45*cos(theta)**43 - 3.6492375442849e+45*cos(theta)**41 + 6.39396321861884e+45*cos(theta)**39 - 8.23987259999402e+45*cos(theta)**37 + 8.09403414689678e+45*cos(theta)**35 - 6.19813425663267e+45*cos(theta)**33 + 3.7529987241996e+45*cos(theta)**31 - 1.81219564564155e+45*cos(theta)**29 + 7.00715649648066e+44*cos(theta)**27 - 2.17079605495561e+44*cos(theta)**25 + 5.37325756177132e+43*cos(theta)**23 - 1.05628140103197e+43*cos(theta)**21 + 1.63342484695665e+42*cos(theta)**19 - 1.96010981634798e+41*cos(theta)**17 + 1.79149821924278e+40*cos(theta)**15 - 1.2159490175856e+39*cos(theta)**13 + 5.92035102195235e+37*cos(theta)**11 - 1.96986876108517e+36*cos(theta)**9 + 4.17148678818037e+34*cos(theta)**7 - 5.02588769660285e+32*cos(theta)**5 + 2.8203634661071e+30*cos(theta)**3 - 4.65662652631882e+27*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl62_m16(theta, phi):
    return 9.832061730817e-29*(1.0 - cos(theta)**2)**8*(1.88599287172446e+45*cos(theta)**46 - 1.58699400181692e+46*cos(theta)**44 + 6.20370382528433e+46*cos(theta)**42 - 1.49618739315681e+47*cos(theta)**40 + 2.49364565526135e+47*cos(theta)**38 - 3.04875286199779e+47*cos(theta)**36 + 2.83291195141387e+47*cos(theta)**34 - 2.04538430468878e+47*cos(theta)**32 + 1.16342960450187e+47*cos(theta)**30 - 5.25536737236049e+46*cos(theta)**28 + 1.89193225404978e+46*cos(theta)**26 - 5.42699013738904e+45*cos(theta)**24 + 1.2358492392074e+45*cos(theta)**22 - 2.21819094216714e+44*cos(theta)**20 + 3.10350720921764e+43*cos(theta)**18 - 3.33218668779157e+42*cos(theta)**16 + 2.68724732886417e+41*cos(theta)**14 - 1.58073372286128e+40*cos(theta)**12 + 6.51238612414759e+38*cos(theta)**10 - 1.77288188497666e+37*cos(theta)**8 + 2.92004075172626e+35*cos(theta)**6 - 2.51294384830143e+33*cos(theta)**4 + 8.4610903983213e+30*cos(theta)**2 - 4.65662652631882e+27)*cos(16*phi)

#@torch.jit.script
def Yl62_m17(theta, phi):
    return 1.63099314277285e-30*(1.0 - cos(theta)**2)**8.5*(8.6755672099325e+46*cos(theta)**45 - 6.98277360799445e+47*cos(theta)**43 + 2.60555560661942e+48*cos(theta)**41 - 5.98474957262723e+48*cos(theta)**39 + 9.47585348999312e+48*cos(theta)**37 - 1.0975510303192e+49*cos(theta)**35 + 9.63190063480717e+48*cos(theta)**33 - 6.5452297750041e+48*cos(theta)**31 + 3.49028881350562e+48*cos(theta)**29 - 1.47150286426094e+48*cos(theta)**27 + 4.91902386052942e+47*cos(theta)**25 - 1.30247763297337e+47*cos(theta)**23 + 2.71886832625629e+46*cos(theta)**21 - 4.43638188433427e+45*cos(theta)**19 + 5.58631297659176e+44*cos(theta)**17 - 5.33149870046652e+43*cos(theta)**15 + 3.76214626040984e+42*cos(theta)**13 - 1.89688046743353e+41*cos(theta)**11 + 6.51238612414759e+39*cos(theta)**9 - 1.41830550798133e+38*cos(theta)**7 + 1.75202445103576e+36*cos(theta)**5 - 1.00517753932057e+34*cos(theta)**3 + 1.69221807966426e+31*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl62_m18(theta, phi):
    return 2.71832190462141e-32*(1.0 - cos(theta)**2)**9*(3.90400524446963e+48*cos(theta)**44 - 3.00259265143761e+49*cos(theta)**42 + 1.06827779871396e+50*cos(theta)**40 - 2.33405233332462e+50*cos(theta)**38 + 3.50606579129745e+50*cos(theta)**36 - 3.84142860611721e+50*cos(theta)**34 + 3.17852720948636e+50*cos(theta)**32 - 2.02902123025127e+50*cos(theta)**30 + 1.01218375591663e+50*cos(theta)**28 - 3.97305773350453e+49*cos(theta)**26 + 1.22975596513236e+49*cos(theta)**24 - 2.99569855583875e+48*cos(theta)**22 + 5.70962348513821e+47*cos(theta)**20 - 8.42912558023512e+46*cos(theta)**18 + 9.49673206020599e+45*cos(theta)**16 - 7.99724805069978e+44*cos(theta)**14 + 4.89079013853279e+43*cos(theta)**12 - 2.08656851417689e+42*cos(theta)**10 + 5.86114751173283e+40*cos(theta)**8 - 9.92813855586928e+38*cos(theta)**6 + 8.76012225517878e+36*cos(theta)**4 - 3.01553261796171e+34*cos(theta)**2 + 1.69221807966426e+31)*cos(18*phi)

#@torch.jit.script
def Yl62_m19(theta, phi):
    return 4.55336051365327e-34*(1.0 - cos(theta)**2)**9.5*(1.71776230756663e+50*cos(theta)**43 - 1.2610889136038e+51*cos(theta)**41 + 4.27311119485584e+51*cos(theta)**39 - 8.86939886663356e+51*cos(theta)**37 + 1.26218368486708e+52*cos(theta)**35 - 1.30608572607985e+52*cos(theta)**33 + 1.01712870703564e+52*cos(theta)**31 - 6.08706369075381e+51*cos(theta)**29 + 2.83411451656657e+51*cos(theta)**27 - 1.03299501071118e+51*cos(theta)**25 + 2.95141431631765e+50*cos(theta)**23 - 6.59053682284525e+49*cos(theta)**21 + 1.14192469702764e+49*cos(theta)**19 - 1.51724260444232e+48*cos(theta)**17 + 1.51947712963296e+47*cos(theta)**15 - 1.11961472709797e+46*cos(theta)**13 + 5.86894816623935e+44*cos(theta)**11 - 2.08656851417689e+43*cos(theta)**9 + 4.68891800938626e+41*cos(theta)**7 - 5.95688313352157e+39*cos(theta)**5 + 3.50404890207151e+37*cos(theta)**3 - 6.03106523592343e+34*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl62_m20(theta, phi):
    return 7.66815500333191e-36*(1.0 - cos(theta)**2)**10*(7.38637792253653e+51*cos(theta)**42 - 5.17046454577557e+52*cos(theta)**40 + 1.66651336599378e+53*cos(theta)**38 - 3.28167758065442e+53*cos(theta)**36 + 4.41764289703479e+53*cos(theta)**34 - 4.31008289606351e+53*cos(theta)**32 + 3.15309899181047e+53*cos(theta)**30 - 1.7652484703186e+53*cos(theta)**28 + 7.65210919472973e+52*cos(theta)**26 - 2.58248752677795e+52*cos(theta)**24 + 6.7882529275306e+51*cos(theta)**22 - 1.3840127327975e+51*cos(theta)**20 + 2.16965692435252e+50*cos(theta)**18 - 2.57931242755195e+49*cos(theta)**16 + 2.27921569444944e+48*cos(theta)**14 - 1.45549914522736e+47*cos(theta)**12 + 6.45584298286329e+45*cos(theta)**10 - 1.8779116627592e+44*cos(theta)**8 + 3.28224260657038e+42*cos(theta)**6 - 2.97844156676078e+40*cos(theta)**4 + 1.05121467062145e+38*cos(theta)**2 - 6.03106523592343e+34)*cos(20*phi)

#@torch.jit.script
def Yl62_m21(theta, phi):
    return 1.29875487787028e-37*(1.0 - cos(theta)**2)**10.5*(3.10227872746534e+53*cos(theta)**41 - 2.06818581831023e+54*cos(theta)**39 + 6.33275079077636e+54*cos(theta)**37 - 1.18140392903559e+55*cos(theta)**35 + 1.50199858499183e+55*cos(theta)**33 - 1.37922652674032e+55*cos(theta)**31 + 9.45929697543142e+54*cos(theta)**29 - 4.94269571689209e+54*cos(theta)**27 + 1.98954839062973e+54*cos(theta)**25 - 6.19797006426707e+53*cos(theta)**23 + 1.49341564405673e+53*cos(theta)**21 - 2.768025465595e+52*cos(theta)**19 + 3.90538246383453e+51*cos(theta)**17 - 4.12689988408311e+50*cos(theta)**15 + 3.19090197222921e+49*cos(theta)**13 - 1.74659897427283e+48*cos(theta)**11 + 6.45584298286329e+46*cos(theta)**9 - 1.50232933020736e+45*cos(theta)**7 + 1.96934556394223e+43*cos(theta)**5 - 1.19137662670431e+41*cos(theta)**3 + 2.10242934124291e+38*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl62_m22(theta, phi):
    return 2.21307239148762e-39*(1.0 - cos(theta)**2)**11*(1.27193427826079e+55*cos(theta)**40 - 8.06592469140989e+55*cos(theta)**38 + 2.34311779258725e+56*cos(theta)**36 - 4.13491375162457e+56*cos(theta)**34 + 4.95659533047304e+56*cos(theta)**32 - 4.275602232895e+56*cos(theta)**30 + 2.74319612287511e+56*cos(theta)**28 - 1.33452784356087e+56*cos(theta)**26 + 4.97387097657433e+55*cos(theta)**24 - 1.42553311478143e+55*cos(theta)**22 + 3.13617285251914e+54*cos(theta)**20 - 5.25924838463051e+53*cos(theta)**18 + 6.63915018851871e+52*cos(theta)**16 - 6.19034982612467e+51*cos(theta)**14 + 4.14817256389797e+50*cos(theta)**12 - 1.92125887170011e+49*cos(theta)**10 + 5.81025868457696e+47*cos(theta)**8 - 1.05163053114515e+46*cos(theta)**6 + 9.84672781971115e+43*cos(theta)**4 - 3.57412988011294e+41*cos(theta)**2 + 2.10242934124291e+38)*cos(22*phi)

#@torch.jit.script
def Yl62_m23(theta, phi):
    return 3.79538783958076e-41*(1.0 - cos(theta)**2)**11.5*(5.08773711304316e+56*cos(theta)**39 - 3.06505138273576e+57*cos(theta)**37 + 8.43522405331411e+57*cos(theta)**35 - 1.40587067555235e+58*cos(theta)**33 + 1.58611050575137e+58*cos(theta)**31 - 1.2826806698685e+58*cos(theta)**29 + 7.68094914405031e+57*cos(theta)**27 - 3.46977239325825e+57*cos(theta)**25 + 1.19372903437784e+57*cos(theta)**23 - 3.13617285251914e+56*cos(theta)**21 + 6.27234570503828e+55*cos(theta)**19 - 9.46664709233491e+54*cos(theta)**17 + 1.06226403016299e+54*cos(theta)**15 - 8.66648975657454e+52*cos(theta)**13 + 4.97780707667757e+51*cos(theta)**11 - 1.92125887170011e+50*cos(theta)**9 + 4.64820694766157e+48*cos(theta)**7 - 6.30978318687091e+46*cos(theta)**5 + 3.93869112788446e+44*cos(theta)**3 - 7.14825976022588e+41*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl62_m24(theta, phi):
    return 6.55352005284167e-43*(1.0 - cos(theta)**2)**12*(1.98421747408683e+58*cos(theta)**38 - 1.13406901161223e+59*cos(theta)**36 + 2.95232841865994e+59*cos(theta)**34 - 4.63937322932276e+59*cos(theta)**32 + 4.91694256782925e+59*cos(theta)**30 - 3.71977394261865e+59*cos(theta)**28 + 2.07385626889358e+59*cos(theta)**26 - 8.67443098314562e+58*cos(theta)**24 + 2.74557677906903e+58*cos(theta)**22 - 6.58596299029019e+57*cos(theta)**20 + 1.19174568395727e+57*cos(theta)**18 - 1.60933000569693e+56*cos(theta)**16 + 1.59339604524449e+55*cos(theta)**14 - 1.12664366835469e+54*cos(theta)**12 + 5.47558778434533e+52*cos(theta)**10 - 1.7291329845301e+51*cos(theta)**8 + 3.2537448633631e+49*cos(theta)**6 - 3.15489159343545e+47*cos(theta)**4 + 1.18160733836534e+45*cos(theta)**2 - 7.14825976022588e+41)*cos(24*phi)

#@torch.jit.script
def Yl62_m25(theta, phi):
    return 1.1397857107875e-44*(1.0 - cos(theta)**2)**12.5*(7.54002640152997e+59*cos(theta)**37 - 4.08264844180403e+60*cos(theta)**35 + 1.00379166234438e+61*cos(theta)**33 - 1.48459943338328e+61*cos(theta)**31 + 1.47508277034878e+61*cos(theta)**29 - 1.04153670393322e+61*cos(theta)**27 + 5.39202629912332e+60*cos(theta)**25 - 2.08186343595495e+60*cos(theta)**23 + 6.04026891395186e+59*cos(theta)**21 - 1.31719259805804e+59*cos(theta)**19 + 2.14514223112309e+58*cos(theta)**17 - 2.5749280091151e+57*cos(theta)**15 + 2.23075446334229e+56*cos(theta)**13 - 1.35197240202563e+55*cos(theta)**11 + 5.47558778434533e+53*cos(theta)**9 - 1.38330638762408e+52*cos(theta)**7 + 1.95224691801786e+50*cos(theta)**5 - 1.26195663737418e+48*cos(theta)**3 + 2.36321467673068e+45*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl62_m26(theta, phi):
    return 1.99747342446286e-46*(1.0 - cos(theta)**2)**13*(2.78980976856609e+61*cos(theta)**36 - 1.42892695463141e+62*cos(theta)**34 + 3.31251248573645e+62*cos(theta)**32 - 4.60225824348818e+62*cos(theta)**30 + 4.27774003401145e+62*cos(theta)**28 - 2.8121491006197e+62*cos(theta)**26 + 1.34800657478083e+62*cos(theta)**24 - 4.78828590269638e+61*cos(theta)**22 + 1.26845647192989e+61*cos(theta)**20 - 2.50266593631027e+60*cos(theta)**18 + 3.64674179290925e+59*cos(theta)**16 - 3.86239201367264e+58*cos(theta)**14 + 2.89998080234497e+57*cos(theta)**12 - 1.48716964222819e+56*cos(theta)**10 + 4.92802900591079e+54*cos(theta)**8 - 9.68314471336858e+52*cos(theta)**6 + 9.76123459008929e+50*cos(theta)**4 - 3.78586991212254e+48*cos(theta)**2 + 2.36321467673068e+45)*cos(26*phi)

#@torch.jit.script
def Yl62_m27(theta, phi):
    return 3.52886265883279e-48*(1.0 - cos(theta)**2)**13.5*(1.00433151668379e+63*cos(theta)**35 - 4.8583516457468e+63*cos(theta)**33 + 1.06000399543566e+64*cos(theta)**31 - 1.38067747304645e+64*cos(theta)**29 + 1.19776720952321e+64*cos(theta)**27 - 7.31158766161122e+63*cos(theta)**25 + 3.23521577947399e+63*cos(theta)**23 - 1.0534228985932e+63*cos(theta)**21 + 2.53691294385978e+62*cos(theta)**19 - 4.50479868535849e+61*cos(theta)**17 + 5.83478686865481e+60*cos(theta)**15 - 5.4073488191417e+59*cos(theta)**13 + 3.47997696281397e+58*cos(theta)**11 - 1.48716964222819e+57*cos(theta)**9 + 3.94242320472863e+55*cos(theta)**7 - 5.80988682802115e+53*cos(theta)**5 + 3.90449383603572e+51*cos(theta)**3 - 7.57173982424509e+48*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl62_m28(theta, phi):
    return 6.28752144492021e-50*(1.0 - cos(theta)**2)**14*(3.51516030839327e+64*cos(theta)**34 - 1.60325604309644e+65*cos(theta)**32 + 3.28601238585056e+65*cos(theta)**30 - 4.00396467183472e+65*cos(theta)**28 + 3.23397146571266e+65*cos(theta)**26 - 1.82789691540281e+65*cos(theta)**24 + 7.44099629279018e+64*cos(theta)**22 - 2.21218808704573e+64*cos(theta)**20 + 4.82013459333359e+63*cos(theta)**18 - 7.65815776510943e+62*cos(theta)**16 + 8.75218030298221e+61*cos(theta)**14 - 7.02955346488421e+60*cos(theta)**12 + 3.82797465909536e+59*cos(theta)**10 - 1.33845267800537e+58*cos(theta)**8 + 2.75969624331004e+56*cos(theta)**6 - 2.90494341401057e+54*cos(theta)**4 + 1.17134815081071e+52*cos(theta)**2 - 7.57173982424509e+48)*cos(28*phi)

#@torch.jit.script
def Yl62_m29(theta, phi):
    return 1.13036662111729e-51*(1.0 - cos(theta)**2)**14.5*(1.19515450485371e+66*cos(theta)**33 - 5.13041933790862e+66*cos(theta)**31 + 9.85803715755168e+66*cos(theta)**29 - 1.12111010811372e+67*cos(theta)**27 + 8.40832581085291e+66*cos(theta)**25 - 4.38695259696673e+66*cos(theta)**23 + 1.63701918441384e+66*cos(theta)**21 - 4.42437617409146e+65*cos(theta)**19 + 8.67624226800045e+64*cos(theta)**17 - 1.22530524241751e+64*cos(theta)**15 + 1.22530524241751e+63*cos(theta)**13 - 8.43546415786105e+61*cos(theta)**11 + 3.82797465909536e+60*cos(theta)**9 - 1.0707621424043e+59*cos(theta)**7 + 1.65581774598603e+57*cos(theta)**5 - 1.16197736560423e+55*cos(theta)**3 + 2.34269630162143e+52*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl62_m30(theta, phi):
    return 2.05148544958415e-53*(1.0 - cos(theta)**2)**15*(3.94400986601725e+67*cos(theta)**32 - 1.59042999475167e+68*cos(theta)**30 + 2.85883077568999e+68*cos(theta)**28 - 3.02699729190705e+68*cos(theta)**26 + 2.10208145271323e+68*cos(theta)**24 - 1.00899909730235e+68*cos(theta)**22 + 3.43774028726906e+67*cos(theta)**20 - 8.40631473077377e+66*cos(theta)**18 + 1.47496118556008e+66*cos(theta)**16 - 1.83795786362626e+65*cos(theta)**14 + 1.59289681514276e+64*cos(theta)**12 - 9.27901057364716e+62*cos(theta)**10 + 3.44517719318583e+61*cos(theta)**8 - 7.49533499683008e+59*cos(theta)**6 + 8.27908872993013e+57*cos(theta)**4 - 3.48593209681269e+55*cos(theta)**2 + 2.34269630162143e+52)*cos(30*phi)

#@torch.jit.script
def Yl62_m31(theta, phi):
    return 3.76055528362249e-55*(1.0 - cos(theta)**2)**15.5*(1.26208315712552e+69*cos(theta)**31 - 4.77128998425501e+69*cos(theta)**29 + 8.00472617193197e+69*cos(theta)**27 - 7.87019295895832e+69*cos(theta)**25 + 5.04499548651174e+69*cos(theta)**23 - 2.21979801406517e+69*cos(theta)**21 + 6.87548057453813e+68*cos(theta)**19 - 1.51313665153928e+68*cos(theta)**17 + 2.35993789689612e+67*cos(theta)**15 - 2.57314100907677e+66*cos(theta)**13 + 1.91147617817131e+65*cos(theta)**11 - 9.27901057364716e+63*cos(theta)**9 + 2.75614175454866e+62*cos(theta)**7 - 4.49720099809805e+60*cos(theta)**5 + 3.31163549197205e+58*cos(theta)**3 - 6.97186419362538e+55*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl62_m32(theta, phi):
    return 6.96638069519073e-57*(1.0 - cos(theta)**2)**16*(3.91245778708911e+70*cos(theta)**30 - 1.38367409543395e+71*cos(theta)**28 + 2.16127606642163e+71*cos(theta)**26 - 1.96754823973958e+71*cos(theta)**24 + 1.1603489618977e+71*cos(theta)**22 - 4.66157582953685e+70*cos(theta)**20 + 1.30634130916224e+70*cos(theta)**18 - 2.57233230761677e+69*cos(theta)**16 + 3.53990684534418e+68*cos(theta)**14 - 3.3450833117998e+67*cos(theta)**12 + 2.10262379598845e+66*cos(theta)**10 - 8.35110951628244e+64*cos(theta)**8 + 1.92929922818406e+63*cos(theta)**6 - 2.24860049904902e+61*cos(theta)**4 + 9.93490647591616e+58*cos(theta)**2 - 6.97186419362538e+55)*cos(32*phi)

#@torch.jit.script
def Yl62_m33(theta, phi):
    return 1.30492266343845e-58*(1.0 - cos(theta)**2)**16.5*(1.17373733612673e+72*cos(theta)**29 - 3.87428746721507e+72*cos(theta)**27 + 5.61931777269624e+72*cos(theta)**25 - 4.72211577537499e+72*cos(theta)**23 + 2.55276771617494e+72*cos(theta)**21 - 9.3231516590737e+71*cos(theta)**19 + 2.35141435649204e+71*cos(theta)**17 - 4.11573169218684e+70*cos(theta)**15 + 4.95586958348186e+69*cos(theta)**13 - 4.01409997415976e+68*cos(theta)**11 + 2.10262379598845e+67*cos(theta)**9 - 6.68088761302595e+65*cos(theta)**7 + 1.15757953691044e+64*cos(theta)**5 - 8.9944019961961e+61*cos(theta)**3 + 1.98698129518323e+59*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl62_m34(theta, phi):
    return 2.47314829543615e-60*(1.0 - cos(theta)**2)**17*(3.40383827476753e+73*cos(theta)**28 - 1.04605761614807e+74*cos(theta)**26 + 1.40482944317406e+74*cos(theta)**24 - 1.08608662833625e+74*cos(theta)**22 + 5.36081220396738e+73*cos(theta)**20 - 1.771398815224e+73*cos(theta)**18 + 3.99740440603647e+72*cos(theta)**16 - 6.17359753828026e+71*cos(theta)**14 + 6.44263045852642e+70*cos(theta)**12 - 4.41550997157574e+69*cos(theta)**10 + 1.8923614163896e+68*cos(theta)**8 - 4.67662132911817e+66*cos(theta)**6 + 5.78789768455219e+64*cos(theta)**4 - 2.69832059885883e+62*cos(theta)**2 + 1.98698129518323e+59)*cos(34*phi)

#@torch.jit.script
def Yl62_m35(theta, phi):
    return 4.74553603559859e-62*(1.0 - cos(theta)**2)**17.5*(9.53074716934908e+74*cos(theta)**27 - 2.71974980198498e+75*cos(theta)**25 + 3.37159066361774e+75*cos(theta)**23 - 2.38939058233975e+75*cos(theta)**21 + 1.07216244079348e+75*cos(theta)**19 - 3.18851786740321e+74*cos(theta)**17 + 6.39584704965835e+73*cos(theta)**15 - 8.64303655359236e+72*cos(theta)**13 + 7.7311565502317e+71*cos(theta)**11 - 4.41550997157574e+70*cos(theta)**9 + 1.51388913311168e+69*cos(theta)**7 - 2.8059727974709e+67*cos(theta)**5 + 2.31515907382088e+65*cos(theta)**3 - 5.39664119771766e+62*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl62_m36(theta, phi):
    return 9.22550939937039e-64*(1.0 - cos(theta)**2)**18*(2.57330173572425e+76*cos(theta)**26 - 6.79937450496245e+76*cos(theta)**24 + 7.75465852632081e+76*cos(theta)**22 - 5.01772022291347e+76*cos(theta)**20 + 2.0371086375076e+76*cos(theta)**18 - 5.42048037458545e+75*cos(theta)**16 + 9.59377057448752e+74*cos(theta)**14 - 1.12359475196701e+74*cos(theta)**12 + 8.50427220525487e+72*cos(theta)**10 - 3.97395897441816e+71*cos(theta)**8 + 1.05972239317818e+70*cos(theta)**6 - 1.40298639873545e+68*cos(theta)**4 + 6.94547722146263e+65*cos(theta)**2 - 5.39664119771766e+62)*cos(36*phi)

#@torch.jit.script
def Yl62_m37(theta, phi):
    return 1.81838602238717e-65*(1.0 - cos(theta)**2)**18.5*(6.69058451288305e+77*cos(theta)**25 - 1.63184988119099e+78*cos(theta)**23 + 1.70602487579058e+78*cos(theta)**21 - 1.00354404458269e+78*cos(theta)**19 + 3.66679554751369e+77*cos(theta)**17 - 8.67276859933672e+76*cos(theta)**15 + 1.34312788042825e+76*cos(theta)**13 - 1.34831370236041e+75*cos(theta)**11 + 8.50427220525487e+73*cos(theta)**9 - 3.17916717953453e+72*cos(theta)**7 + 6.35833435906906e+70*cos(theta)**5 - 5.6119455949418e+68*cos(theta)**3 + 1.38909544429253e+66*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl62_m38(theta, phi):
    return 3.63677204477434e-67*(1.0 - cos(theta)**2)**19*(1.67264612822076e+79*cos(theta)**24 - 3.75325472673927e+79*cos(theta)**22 + 3.58265223916021e+79*cos(theta)**20 - 1.90673368470712e+79*cos(theta)**18 + 6.23355243077327e+78*cos(theta)**16 - 1.30091528990051e+78*cos(theta)**14 + 1.74606624455673e+77*cos(theta)**12 - 1.48314507259645e+76*cos(theta)**10 + 7.65384498472938e+74*cos(theta)**8 - 2.22541702567417e+73*cos(theta)**6 + 3.17916717953453e+71*cos(theta)**4 - 1.68358367848254e+69*cos(theta)**2 + 1.38909544429253e+66)*cos(38*phi)

#@torch.jit.script
def Yl62_m39(theta, phi):
    return 7.38668828381131e-69*(1.0 - cos(theta)**2)**19.5*(4.01435070772983e+80*cos(theta)**23 - 8.2571603988264e+80*cos(theta)**21 + 7.16530447832043e+80*cos(theta)**19 - 3.43212063247281e+80*cos(theta)**17 + 9.97368388923723e+79*cos(theta)**15 - 1.82128140586071e+79*cos(theta)**13 + 2.09527949346807e+78*cos(theta)**11 - 1.48314507259645e+77*cos(theta)**9 + 6.12307598778351e+75*cos(theta)**7 - 1.3352502154045e+74*cos(theta)**5 + 1.27166687181381e+72*cos(theta)**3 - 3.36716735696508e+69*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl62_m40(theta, phi):
    return 1.52505591979142e-70*(1.0 - cos(theta)**2)**20*(9.23300662777861e+81*cos(theta)**22 - 1.73400368375354e+82*cos(theta)**20 + 1.36140785088088e+82*cos(theta)**18 - 5.83460507520378e+81*cos(theta)**16 + 1.49605258338558e+81*cos(theta)**14 - 2.36766582761892e+80*cos(theta)**12 + 2.30480744281488e+79*cos(theta)**10 - 1.3348305653368e+78*cos(theta)**8 + 4.28615319144845e+76*cos(theta)**6 - 6.67625107702251e+74*cos(theta)**4 + 3.81500061544144e+72*cos(theta)**2 - 3.36716735696508e+69)*cos(40*phi)

#@torch.jit.script
def Yl62_m41(theta, phi):
    return 3.2037293185814e-72*(1.0 - cos(theta)**2)**20.5*(2.03126145811129e+83*cos(theta)**21 - 3.46800736750709e+83*cos(theta)**19 + 2.45053413158559e+83*cos(theta)**17 - 9.33536812032604e+82*cos(theta)**15 + 2.09447361673982e+82*cos(theta)**13 - 2.84119899314271e+81*cos(theta)**11 + 2.30480744281488e+80*cos(theta)**9 - 1.06786445226944e+79*cos(theta)**7 + 2.57169191486907e+77*cos(theta)**5 - 2.67050043080901e+75*cos(theta)**3 + 7.63000123088287e+72*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl62_m42(theta, phi):
    return 6.85534788525874e-74*(1.0 - cos(theta)**2)**21*(4.26564906203372e+84*cos(theta)**20 - 6.58921399826347e+84*cos(theta)**18 + 4.1659080236955e+84*cos(theta)**16 - 1.40030521804891e+84*cos(theta)**14 + 2.72281570176176e+83*cos(theta)**12 - 3.12531889245698e+82*cos(theta)**10 + 2.07432669853339e+81*cos(theta)**8 - 7.4750511658861e+79*cos(theta)**6 + 1.28584595743454e+78*cos(theta)**4 - 8.01150129242702e+75*cos(theta)**2 + 7.63000123088287e+72)*cos(42*phi)

#@torch.jit.script
def Yl62_m43(theta, phi):
    return 1.49595955235494e-75*(1.0 - cos(theta)**2)**21.5*(8.53129812406744e+85*cos(theta)**19 - 1.18605851968742e+86*cos(theta)**17 + 6.6654528379128e+85*cos(theta)**15 - 1.96042730526847e+85*cos(theta)**13 + 3.26737884211412e+84*cos(theta)**11 - 3.12531889245698e+83*cos(theta)**9 + 1.65946135882672e+82*cos(theta)**7 - 4.48503069953166e+80*cos(theta)**5 + 5.14338382973815e+78*cos(theta)**3 - 1.6023002584854e+76*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl62_m44(theta, phi):
    return 3.3334206245222e-77*(1.0 - cos(theta)**2)**22*(1.62094664357281e+87*cos(theta)**18 - 2.01629948346862e+87*cos(theta)**16 + 9.99817925686919e+86*cos(theta)**14 - 2.54855549684901e+86*cos(theta)**12 + 3.59411672632553e+85*cos(theta)**10 - 2.81278700321128e+84*cos(theta)**8 + 1.1616229511787e+83*cos(theta)**6 - 2.24251534976583e+81*cos(theta)**4 + 1.54301514892144e+79*cos(theta)**2 - 1.6023002584854e+76)*cos(44*phi)

#@torch.jit.script
def Yl62_m45(theta, phi):
    return 7.59559809259046e-79*(1.0 - cos(theta)**2)**22.5*(2.91770395843106e+88*cos(theta)**17 - 3.22607917354979e+88*cos(theta)**15 + 1.39974509596169e+88*cos(theta)**13 - 3.05826659621881e+87*cos(theta)**11 + 3.59411672632553e+86*cos(theta)**9 - 2.25022960256903e+85*cos(theta)**7 + 6.9697377070722e+83*cos(theta)**5 - 8.97006139906332e+81*cos(theta)**3 + 3.08603029784289e+79*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl62_m46(theta, phi):
    return 1.77266078922259e-80*(1.0 - cos(theta)**2)**23*(4.96009672933281e+89*cos(theta)**16 - 4.83911876032469e+89*cos(theta)**14 + 1.81966862475019e+89*cos(theta)**12 - 3.36409325584069e+88*cos(theta)**10 + 3.23470505369297e+87*cos(theta)**8 - 1.57516072179832e+86*cos(theta)**6 + 3.4848688535361e+84*cos(theta)**4 - 2.691018419719e+82*cos(theta)**2 + 3.08603029784289e+79)*cos(46*phi)

#@torch.jit.script
def Yl62_m47(theta, phi):
    return 4.24475274674568e-82*(1.0 - cos(theta)**2)**23.5*(7.93615476693249e+90*cos(theta)**15 - 6.77476626445457e+90*cos(theta)**13 + 2.18360234970023e+90*cos(theta)**11 - 3.36409325584069e+89*cos(theta)**9 + 2.58776404295438e+88*cos(theta)**7 - 9.45096433078991e+86*cos(theta)**5 + 1.39394754141444e+85*cos(theta)**3 - 5.382036839438e+82*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl62_m48(theta, phi):
    return 1.04498588887109e-83*(1.0 - cos(theta)**2)**24*(1.19042321503987e+92*cos(theta)**14 - 8.80719614379094e+91*cos(theta)**12 + 2.40196258467026e+91*cos(theta)**10 - 3.02768393025662e+90*cos(theta)**8 + 1.81143483006807e+89*cos(theta)**6 - 4.72548216539495e+87*cos(theta)**4 + 4.18184262424332e+85*cos(theta)**2 - 5.382036839438e+82)*cos(48*phi)

#@torch.jit.script
def Yl62_m49(theta, phi):
    return 2.6508485661369e-85*(1.0 - cos(theta)**2)**24.5*(1.66659250105582e+93*cos(theta)**13 - 1.05686353725491e+93*cos(theta)**11 + 2.40196258467026e+92*cos(theta)**9 - 2.4221471442053e+91*cos(theta)**7 + 1.08686089804084e+90*cos(theta)**5 - 1.89019286615798e+88*cos(theta)**3 + 8.36368524848664e+85*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl62_m50(theta, phi):
    return 6.94711089081838e-87*(1.0 - cos(theta)**2)**25*(2.16657025137257e+94*cos(theta)**12 - 1.1625498909804e+94*cos(theta)**10 + 2.16176632620323e+93*cos(theta)**8 - 1.69550300094371e+92*cos(theta)**6 + 5.4343044902042e+90*cos(theta)**4 - 5.67057859847394e+88*cos(theta)**2 + 8.36368524848664e+85)*cos(50*phi)

#@torch.jit.script
def Yl62_m51(theta, phi):
    return 1.88657635255539e-88*(1.0 - cos(theta)**2)**25.5*(2.59988430164708e+95*cos(theta)**11 - 1.1625498909804e+95*cos(theta)**9 + 1.72941306096258e+94*cos(theta)**7 - 1.01730180056623e+93*cos(theta)**5 + 2.17372179608168e+91*cos(theta)**3 - 1.13411571969479e+89*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl62_m52(theta, phi):
    return 5.32752649442622e-90*(1.0 - cos(theta)**2)**26*(2.85987273181179e+96*cos(theta)**10 - 1.04629490188236e+96*cos(theta)**8 + 1.21058914267381e+95*cos(theta)**6 - 5.08650900283113e+93*cos(theta)**4 + 6.52116538824504e+91*cos(theta)**2 - 1.13411571969479e+89)*cos(52*phi)

#@torch.jit.script
def Yl62_m53(theta, phi):
    return 1.57100185561049e-91*(1.0 - cos(theta)**2)**26.5*(2.85987273181179e+97*cos(theta)**9 - 8.37035921505891e+96*cos(theta)**7 + 7.26353485604285e+95*cos(theta)**5 - 2.03460360113245e+94*cos(theta)**3 + 1.30423307764901e+92*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl62_m54(theta, phi):
    return 4.86212868090609e-93*(1.0 - cos(theta)**2)**27*(2.57388545863061e+98*cos(theta)**8 - 5.85925145054123e+97*cos(theta)**6 + 3.63176742802143e+96*cos(theta)**4 - 6.10381080339735e+94*cos(theta)**2 + 1.30423307764901e+92)*cos(54*phi)

#@torch.jit.script
def Yl62_m55(theta, phi):
    return 1.5892364757397e-94*(1.0 - cos(theta)**2)**27.5*(2.05910836690449e+99*cos(theta)**7 - 3.51555087032474e+98*cos(theta)**5 + 1.45270697120857e+97*cos(theta)**3 - 1.22076216067947e+95*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl62_m56(theta, phi):
    return 5.52966091440948e-96*(1.0 - cos(theta)**2)**28*(1.44137585683314e+100*cos(theta)**6 - 1.75777543516237e+99*cos(theta)**4 + 4.35812091362571e+97*cos(theta)**2 - 1.22076216067947e+95)*cos(56*phi)

#@torch.jit.script
def Yl62_m57(theta, phi):
    return 2.06942358678965e-97*(1.0 - cos(theta)**2)**28.5*(8.64825514099886e+100*cos(theta)**5 - 7.03110174064948e+99*cos(theta)**3 + 8.71624182725142e+97*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl62_m58(theta, phi):
    return 8.4483864155247e-99*(1.0 - cos(theta)**2)**29*(4.32412757049943e+101*cos(theta)**4 - 2.10933052219484e+100*cos(theta)**2 + 8.71624182725142e+97)*cos(58*phi)

#@torch.jit.script
def Yl62_m59(theta, phi):
    return 3.84017564342032e-100*(1.0 - cos(theta)**2)**29.5*(1.72965102819977e+102*cos(theta)**3 - 4.21866104438969e+100*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl62_m60(theta, phi):
    return 2.00729196448552e-101*(1.0 - cos(theta)**2)**30*(5.18895308459932e+102*cos(theta)**2 - 4.21866104438969e+100)*cos(60*phi)

#@torch.jit.script
def Yl62_m61(theta, phi):
    return 13.2816714315134*(1.0 - cos(theta)**2)**30.5*cos(61*phi)*cos(theta)

#@torch.jit.script
def Yl62_m62(theta, phi):
    return 1.19272930443867*(1.0 - cos(theta)**2)**31*cos(62*phi)

#@torch.jit.script
def Yl63_m_minus_63(theta, phi):
    return 1.19745300333825*(1.0 - cos(theta)**2)**31.5*sin(63*phi)

#@torch.jit.script
def Yl63_m_minus_62(theta, phi):
    return 13.4413766257656*(1.0 - cos(theta)**2)**31*sin(62*phi)*cos(theta)

#@torch.jit.script
def Yl63_m_minus_61(theta, phi):
    return 1.63830215199759e-103*(1.0 - cos(theta)**2)**30.5*(6.48619135574915e+104*cos(theta)**2 - 5.18895308459932e+102)*sin(61*phi)

#@torch.jit.script
def Yl63_m_minus_60(theta, phi):
    return 3.1598427589696e-102*(1.0 - cos(theta)**2)**30*(2.16206378524972e+104*cos(theta)**3 - 5.18895308459932e+102*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl63_m_minus_59(theta, phi):
    return 7.00887029457315e-101*(1.0 - cos(theta)**2)**29.5*(5.40515946312429e+103*cos(theta)**4 - 2.59447654229966e+102*cos(theta)**2 + 1.05466526109742e+100)*sin(59*phi)

#@torch.jit.script
def Yl63_m_minus_58(theta, phi):
    return 1.73106326608104e-99*(1.0 - cos(theta)**2)**29*(1.08103189262486e+103*cos(theta)**5 - 8.64825514099886e+101*cos(theta)**3 + 1.05466526109742e+100*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl63_m_minus_57(theta, phi):
    return 4.66424388581167e-98*(1.0 - cos(theta)**2)**28.5*(1.80171982104143e+102*cos(theta)**6 - 2.16206378524972e+101*cos(theta)**4 + 5.27332630548711e+99*cos(theta)**2 - 1.45270697120857e+97)*sin(57*phi)

#@torch.jit.script
def Yl63_m_minus_56(theta, phi):
    return 1.35182630770815e-96*(1.0 - cos(theta)**2)**28*(2.57388545863061e+101*cos(theta)**7 - 4.32412757049943e+100*cos(theta)**5 + 1.75777543516237e+99*cos(theta)**3 - 1.45270697120857e+97*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl63_m_minus_55(theta, phi):
    return 4.17099210816046e-95*(1.0 - cos(theta)**2)**27.5*(3.21735682328827e+100*cos(theta)**8 - 7.20687928416572e+99*cos(theta)**6 + 4.39443858790593e+98*cos(theta)**4 - 7.26353485604285e+96*cos(theta)**2 + 1.52595270084934e+94)*sin(55*phi)

#@torch.jit.script
def Yl63_m_minus_54(theta, phi):
    return 1.35925715104427e-93*(1.0 - cos(theta)**2)**27*(3.57484091476474e+99*cos(theta)**9 - 1.02955418345225e+99*cos(theta)**7 + 8.78887717581185e+97*cos(theta)**5 - 2.42117828534762e+96*cos(theta)**3 + 1.52595270084934e+94*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl63_m_minus_53(theta, phi):
    return 4.64937480003281e-92*(1.0 - cos(theta)**2)**26.5*(3.57484091476474e+98*cos(theta)**10 - 1.28694272931531e+98*cos(theta)**8 + 1.46481286263531e+97*cos(theta)**6 - 6.05294571336904e+95*cos(theta)**4 + 7.62976350424669e+93*cos(theta)**2 - 1.30423307764901e+91)*sin(53*phi)

#@torch.jit.script
def Yl63_m_minus_52(theta, phi):
    return 1.66080978368343e-90*(1.0 - cos(theta)**2)**26*(3.24985537705886e+97*cos(theta)**11 - 1.4299363659059e+97*cos(theta)**9 + 2.09258980376473e+96*cos(theta)**7 - 1.21058914267381e+95*cos(theta)**5 + 2.54325450141556e+93*cos(theta)**3 - 1.30423307764901e+91*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl63_m_minus_51(theta, phi):
    return 6.16963451904442e-89*(1.0 - cos(theta)**2)**25.5*(2.70821281421571e+96*cos(theta)**12 - 1.4299363659059e+96*cos(theta)**10 + 2.61573725470591e+95*cos(theta)**8 - 2.01764857112301e+94*cos(theta)**6 + 6.35813625353891e+92*cos(theta)**4 - 6.52116538824504e+90*cos(theta)**2 + 9.45096433078991e+87)*sin(51*phi)

#@torch.jit.script
def Yl63_m_minus_50(theta, phi):
    return 2.37510896857602e-87*(1.0 - cos(theta)**2)**25*(2.08324062631978e+95*cos(theta)**13 - 1.29994215082354e+95*cos(theta)**11 + 2.90637472745101e+94*cos(theta)**9 - 2.88235510160431e+93*cos(theta)**7 + 1.27162725070778e+92*cos(theta)**5 - 2.17372179608168e+90*cos(theta)**3 + 9.45096433078991e+87*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl63_m_minus_49(theta, phi):
    return 9.44684477121826e-86*(1.0 - cos(theta)**2)**24.5*(1.48802901879984e+94*cos(theta)**14 - 1.08328512568629e+94*cos(theta)**12 + 2.90637472745101e+93*cos(theta)**10 - 3.60294387700538e+92*cos(theta)**8 + 2.11937875117964e+91*cos(theta)**6 - 5.4343044902042e+89*cos(theta)**4 + 4.72548216539495e+87*cos(theta)**2 - 5.97406089177617e+84)*sin(49*phi)

#@torch.jit.script
def Yl63_m_minus_48(theta, phi):
    return 3.87205413057346e-84*(1.0 - cos(theta)**2)**24*(9.92019345866561e+92*cos(theta)**15 - 8.33296250527912e+92*cos(theta)**13 + 2.64215884313728e+92*cos(theta)**11 - 4.00327097445043e+91*cos(theta)**9 + 3.02768393025662e+90*cos(theta)**7 - 1.08686089804084e+89*cos(theta)**5 + 1.57516072179832e+87*cos(theta)**3 - 5.97406089177617e+84*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl63_m_minus_47(theta, phi):
    return 1.63178486528101e-82*(1.0 - cos(theta)**2)**23.5*(6.20012091166601e+91*cos(theta)**16 - 5.95211607519937e+91*cos(theta)**14 + 2.20179903594773e+91*cos(theta)**12 - 4.00327097445043e+90*cos(theta)**10 + 3.78460491282078e+89*cos(theta)**8 - 1.81143483006807e+88*cos(theta)**6 + 3.9379018044958e+86*cos(theta)**4 - 2.98703044588809e+84*cos(theta)**2 + 3.36377302464875e+81)*sin(47*phi)

#@torch.jit.script
def Yl63_m_minus_46(theta, phi):
    return 7.05640833077812e-81*(1.0 - cos(theta)**2)**23*(3.64712994803883e+90*cos(theta)**17 - 3.96807738346625e+90*cos(theta)**15 + 1.69369156611364e+90*cos(theta)**13 - 3.63933724950039e+89*cos(theta)**11 + 4.20511656980087e+88*cos(theta)**9 - 2.58776404295438e+87*cos(theta)**7 + 7.87580360899159e+85*cos(theta)**5 - 9.95676815296029e+83*cos(theta)**3 + 3.36377302464875e+81*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl63_m_minus_45(theta, phi):
    return 3.12559861334088e-79*(1.0 - cos(theta)**2)**22.5*(2.02618330446602e+89*cos(theta)**18 - 2.4800483646664e+89*cos(theta)**16 + 1.20977969008117e+89*cos(theta)**14 - 3.03278104125032e+88*cos(theta)**12 + 4.20511656980087e+87*cos(theta)**10 - 3.23470505369297e+86*cos(theta)**8 + 1.31263393483193e+85*cos(theta)**6 - 2.48919203824007e+83*cos(theta)**4 + 1.68188651232437e+81*cos(theta)**2 - 1.71446127657938e+78)*sin(45*phi)

#@torch.jit.script
def Yl63_m_minus_44(theta, phi):
    return 1.41586512251013e-77*(1.0 - cos(theta)**2)**22*(1.06641226550843e+88*cos(theta)**19 - 1.45885197921553e+88*cos(theta)**17 + 8.06519793387448e+87*cos(theta)**15 - 2.33290849326948e+87*cos(theta)**13 + 3.82283324527352e+86*cos(theta)**11 - 3.59411672632553e+85*cos(theta)**9 + 1.87519133547419e+84*cos(theta)**7 - 4.97838407648015e+82*cos(theta)**5 + 5.60628837441458e+80*cos(theta)**3 - 1.71446127657938e+78*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl63_m_minus_43(theta, phi):
    return 6.54981103284738e-76*(1.0 - cos(theta)**2)**21.5*(5.33206132754215e+86*cos(theta)**20 - 8.10473321786406e+86*cos(theta)**18 + 5.04074870867155e+86*cos(theta)**16 - 1.6663632094782e+86*cos(theta)**14 + 3.18569437106126e+85*cos(theta)**12 - 3.59411672632553e+84*cos(theta)**10 + 2.34398916934274e+83*cos(theta)**8 - 8.29730679413358e+81*cos(theta)**6 + 1.40157209360364e+80*cos(theta)**4 - 8.57230638289691e+77*cos(theta)**2 + 8.01150129242702e+74)*sin(43*phi)

#@torch.jit.script
def Yl63_m_minus_42(theta, phi):
    return 3.09023388571054e-74*(1.0 - cos(theta)**2)**21*(2.53907682263912e+85*cos(theta)**21 - 4.26564906203372e+85*cos(theta)**19 + 2.96514629921856e+85*cos(theta)**17 - 1.1109088063188e+85*cos(theta)**15 + 2.45053413158559e+84*cos(theta)**13 - 3.26737884211412e+83*cos(theta)**11 + 2.60443241038082e+82*cos(theta)**9 - 1.18532954201908e+81*cos(theta)**7 + 2.80314418720729e+79*cos(theta)**5 - 2.85743546096564e+77*cos(theta)**3 + 8.01150129242702e+74*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl63_m_minus_41(theta, phi):
    return 1.48524240553485e-72*(1.0 - cos(theta)**2)**20.5*(1.15412582847233e+84*cos(theta)**22 - 2.13282453101686e+84*cos(theta)**20 + 1.64730349956587e+84*cos(theta)**18 - 6.9431800394925e+83*cos(theta)**16 + 1.75038152256113e+83*cos(theta)**14 - 2.72281570176176e+82*cos(theta)**12 + 2.60443241038082e+81*cos(theta)**10 - 1.48166192752385e+80*cos(theta)**8 + 4.67190697867882e+78*cos(theta)**6 - 7.14358865241409e+76*cos(theta)**4 + 4.00575064621351e+74*cos(theta)**2 - 3.46818237767403e+71)*sin(41*phi)

#@torch.jit.script
def Yl63_m_minus_40(theta, phi):
    return 7.26403499967604e-71*(1.0 - cos(theta)**2)**20*(5.01793838466229e+82*cos(theta)**23 - 1.01563072905565e+83*cos(theta)**21 + 8.67001841876772e+82*cos(theta)**19 - 4.08422355264264e+82*cos(theta)**17 + 1.16692101504076e+82*cos(theta)**15 - 2.09447361673982e+81*cos(theta)**13 + 2.36766582761892e+80*cos(theta)**11 - 1.64629103058206e+79*cos(theta)**9 + 6.67415282668402e+77*cos(theta)**7 - 1.42871773048282e+76*cos(theta)**5 + 1.3352502154045e+74*cos(theta)**3 - 3.46818237767403e+71*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl63_m_minus_39(theta, phi):
    return 3.61162093063425e-69*(1.0 - cos(theta)**2)**19.5*(2.09080766027595e+81*cos(theta)**24 - 4.61650331388931e+81*cos(theta)**22 + 4.33500920938386e+81*cos(theta)**20 - 2.26901308480147e+81*cos(theta)**18 + 7.29325634400472e+80*cos(theta)**16 - 1.49605258338558e+80*cos(theta)**14 + 1.9730548563491e+79*cos(theta)**12 - 1.64629103058206e+78*cos(theta)**10 + 8.34269103335503e+76*cos(theta)**8 - 2.38119621747136e+75*cos(theta)**6 + 3.33812553851126e+73*cos(theta)**4 - 1.73409118883702e+71*cos(theta)**2 + 1.40298639873545e+68)*sin(39*phi)

#@torch.jit.script
def Yl63_m_minus_38(theta, phi):
    return 1.82377917122162e-67*(1.0 - cos(theta)**2)**19*(8.36323064110381e+79*cos(theta)**25 - 2.00717535386492e+80*cos(theta)**23 + 2.0642900997066e+80*cos(theta)**21 - 1.1942174130534e+80*cos(theta)**19 + 4.29015079059101e+79*cos(theta)**17 - 9.97368388923723e+78*cos(theta)**15 + 1.51773450488393e+78*cos(theta)**13 - 1.49662820962005e+77*cos(theta)**11 + 9.26965670372781e+75*cos(theta)**9 - 3.40170888210195e+74*cos(theta)**7 + 6.67625107702251e+72*cos(theta)**5 - 5.78030396279006e+70*cos(theta)**3 + 1.40298639873545e+68*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl63_m_minus_37(theta, phi):
    return 9.34586734449653e-66*(1.0 - cos(theta)**2)**18.5*(3.21662716965531e+78*cos(theta)**26 - 8.36323064110381e+78*cos(theta)**24 + 9.38313681684818e+78*cos(theta)**22 - 5.97108706526702e+78*cos(theta)**20 + 2.3834171058839e+78*cos(theta)**18 - 6.23355243077327e+77*cos(theta)**16 + 1.08409607491709e+77*cos(theta)**14 - 1.24719017468338e+76*cos(theta)**12 + 9.26965670372781e+74*cos(theta)**10 - 4.25213610262743e+73*cos(theta)**8 + 1.11270851283709e+72*cos(theta)**6 - 1.44507599069751e+70*cos(theta)**4 + 7.01493199367725e+67*cos(theta)**2 - 5.34267478574048e+64)*sin(37*phi)

#@torch.jit.script
def Yl63_m_minus_36(theta, phi):
    return 4.85625512444004e-64*(1.0 - cos(theta)**2)**18*(1.19134339616863e+77*cos(theta)**27 - 3.34529225644153e+77*cos(theta)**25 + 4.07962470297747e+77*cos(theta)**23 - 2.8433747929843e+77*cos(theta)**21 + 1.25443005572837e+77*cos(theta)**19 - 3.66679554751369e+76*cos(theta)**17 + 7.22730716611393e+75*cos(theta)**15 - 9.59377057448752e+74*cos(theta)**13 + 8.42696063975255e+73*cos(theta)**11 - 4.72459566958604e+72*cos(theta)**9 + 1.58958358976727e+71*cos(theta)**7 - 2.89015198139503e+69*cos(theta)**5 + 2.33831066455908e+67*cos(theta)**3 - 5.34267478574048e+64*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl63_m_minus_35(theta, phi):
    return 2.55680794638311e-62*(1.0 - cos(theta)**2)**17.5*(4.25479784345941e+75*cos(theta)**28 - 1.28665086786213e+76*cos(theta)**26 + 1.69984362624061e+76*cos(theta)**24 - 1.29244308772014e+76*cos(theta)**22 + 6.27215027864183e+75*cos(theta)**20 - 2.0371086375076e+75*cos(theta)**18 + 4.51706697882121e+74*cos(theta)**16 - 6.85269326749109e+73*cos(theta)**14 + 7.02246719979379e+72*cos(theta)**12 - 4.72459566958604e+71*cos(theta)**10 + 1.98697948720908e+70*cos(theta)**8 - 4.81691996899171e+68*cos(theta)**6 + 5.84577666139771e+66*cos(theta)**4 - 2.67133739287024e+64*cos(theta)**2 + 1.92737185632774e+61)*sin(35*phi)

#@torch.jit.script
def Yl63_m_minus_34(theta, phi):
    return 1.36304484364465e-60*(1.0 - cos(theta)**2)**17*(1.46717167015842e+74*cos(theta)**29 - 4.76537358467454e+74*cos(theta)**27 + 6.79937450496245e+74*cos(theta)**25 - 5.61931777269624e+74*cos(theta)**23 + 2.98673822792468e+74*cos(theta)**21 - 1.07216244079348e+74*cos(theta)**19 + 2.657098222836e+73*cos(theta)**17 - 4.56846217832739e+72*cos(theta)**15 + 5.40189784599523e+71*cos(theta)**13 - 4.29508697235094e+70*cos(theta)**11 + 2.20775498578787e+69*cos(theta)**9 - 6.88131424141673e+67*cos(theta)**7 + 1.16915533227954e+66*cos(theta)**5 - 8.90445797623414e+63*cos(theta)**3 + 1.92737185632774e+61*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl63_m_minus_33(theta, phi):
    return 7.35286578501069e-59*(1.0 - cos(theta)**2)**16.5*(4.89057223386139e+72*cos(theta)**30 - 1.70191913738376e+73*cos(theta)**28 + 2.61514404037017e+73*cos(theta)**26 - 2.3413824052901e+73*cos(theta)**24 + 1.35760828542031e+73*cos(theta)**22 - 5.36081220396738e+72*cos(theta)**20 + 1.47616567935334e+72*cos(theta)**18 - 2.85528886145462e+71*cos(theta)**16 + 3.85849846142516e+70*cos(theta)**14 - 3.57923914362579e+69*cos(theta)**12 + 2.20775498578787e+68*cos(theta)**10 - 8.60164280177092e+66*cos(theta)**8 + 1.9485922204659e+65*cos(theta)**6 - 2.22611449405853e+63*cos(theta)**4 + 9.63685928163868e+60*cos(theta)**2 - 6.62327098394411e+57)*sin(33*phi)

#@torch.jit.script
def Yl63_m_minus_32(theta, phi):
    return 4.01118878278105e-57*(1.0 - cos(theta)**2)**16*(1.5776039464069e+71*cos(theta)**31 - 5.86868668063367e+71*cos(theta)**29 + 9.68571866803768e+71*cos(theta)**27 - 9.3655296211604e+71*cos(theta)**25 + 5.90264471921874e+71*cos(theta)**23 - 2.55276771617494e+71*cos(theta)**21 + 7.76929304922808e+70*cos(theta)**19 - 1.6795816832086e+70*cos(theta)**17 + 2.57233230761677e+69*cos(theta)**15 - 2.75326087971214e+68*cos(theta)**13 + 2.00704998707988e+67*cos(theta)**11 - 9.55738089085657e+65*cos(theta)**9 + 2.78370317209415e+64*cos(theta)**7 - 4.45222898811707e+62*cos(theta)**5 + 3.21228642721289e+60*cos(theta)**3 - 6.62327098394411e+57*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl63_m_minus_31(theta, phi):
    return 2.21161686942766e-55*(1.0 - cos(theta)**2)**15.5*(4.93001233252156e+69*cos(theta)**32 - 1.95622889354456e+70*cos(theta)**30 + 3.45918523858488e+70*cos(theta)**28 - 3.60212677736938e+70*cos(theta)**26 + 2.45943529967447e+70*cos(theta)**24 - 1.1603489618977e+70*cos(theta)**22 + 3.88464652461404e+69*cos(theta)**20 - 9.33100935115889e+68*cos(theta)**18 + 1.60770769226048e+68*cos(theta)**16 - 1.9666149140801e+67*cos(theta)**14 + 1.6725416558999e+66*cos(theta)**12 - 9.55738089085657e+64*cos(theta)**10 + 3.47962896511768e+63*cos(theta)**8 - 7.42038164686178e+61*cos(theta)**6 + 8.03071606803223e+59*cos(theta)**4 - 3.31163549197205e+57*cos(theta)**2 + 2.17870756050793e+54)*sin(31*phi)

#@torch.jit.script
def Yl63_m_minus_30(theta, phi):
    return 1.23177331305232e-53*(1.0 - cos(theta)**2)**15*(1.49394313106714e+68*cos(theta)**33 - 6.3104157856276e+68*cos(theta)**31 + 1.19282249606375e+69*cos(theta)**29 - 1.33412102865533e+69*cos(theta)**27 + 9.8377411986979e+68*cos(theta)**25 - 5.04499548651174e+68*cos(theta)**23 + 1.84983167838764e+68*cos(theta)**21 - 4.91105755324152e+67*cos(theta)**19 + 9.45710407212049e+66*cos(theta)**17 - 1.31107660938674e+66*cos(theta)**15 + 1.28657050453838e+65*cos(theta)**13 - 8.68852808259689e+63*cos(theta)**11 + 3.86625440568632e+62*cos(theta)**9 - 1.06005452098025e+61*cos(theta)**7 + 1.60614321360645e+59*cos(theta)**5 - 1.10387849732402e+57*cos(theta)**3 + 2.17870756050793e+54*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl63_m_minus_29(theta, phi):
    return 6.92646626671411e-52*(1.0 - cos(theta)**2)**14.5*(4.39395038549159e+66*cos(theta)**34 - 1.97200493300862e+67*cos(theta)**32 + 3.97607498687918e+67*cos(theta)**30 - 4.76471795948331e+67*cos(theta)**28 + 3.78374661488381e+67*cos(theta)**26 - 2.10208145271323e+67*cos(theta)**24 + 8.40832581085291e+66*cos(theta)**22 - 2.45552877662076e+66*cos(theta)**20 + 5.25394670673361e+65*cos(theta)**18 - 8.19422880866709e+64*cos(theta)**16 + 9.18978931813132e+63*cos(theta)**14 - 7.24044006883074e+62*cos(theta)**12 + 3.86625440568632e+61*cos(theta)**10 - 1.32506815122532e+60*cos(theta)**8 + 2.67690535601074e+58*cos(theta)**6 - 2.75969624331004e+56*cos(theta)**4 + 1.08935378025396e+54*cos(theta)**2 - 6.89028324006303e+50)*sin(29*phi)

#@torch.jit.script
def Yl63_m_minus_28(theta, phi):
    return 3.93042631936345e-50*(1.0 - cos(theta)**2)**14*(1.25541439585474e+65*cos(theta)**35 - 5.97577252426856e+65*cos(theta)**33 + 1.28260483447715e+66*cos(theta)**31 - 1.64300619292528e+66*cos(theta)**29 + 1.40138763514215e+66*cos(theta)**27 - 8.4083258108529e+65*cos(theta)**25 + 3.65579383080561e+65*cos(theta)**23 - 1.16929941743846e+65*cos(theta)**21 + 2.76523510880716e+64*cos(theta)**19 - 4.82013459333359e+63*cos(theta)**17 + 6.12652621208755e+62*cos(theta)**15 - 5.56956928371595e+61*cos(theta)**13 + 3.51477673244211e+60*cos(theta)**11 - 1.47229794580591e+59*cos(theta)**9 + 3.82415050858678e+57*cos(theta)**7 - 5.51939248662009e+55*cos(theta)**5 + 3.63117926751322e+53*cos(theta)**3 - 6.89028324006303e+50*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl63_m_minus_27(theta, phi):
    return 2.24963264659303e-48*(1.0 - cos(theta)**2)**13.5*(3.48726221070761e+63*cos(theta)**36 - 1.75758015419664e+64*cos(theta)**34 + 4.00814010774111e+64*cos(theta)**32 - 5.47668730975093e+64*cos(theta)**30 + 5.0049558397934e+64*cos(theta)**28 - 3.23397146571266e+64*cos(theta)**26 + 1.52324742950234e+64*cos(theta)**24 - 5.31499735199299e+63*cos(theta)**22 + 1.38261755440358e+63*cos(theta)**20 - 2.67785255185199e+62*cos(theta)**18 + 3.82907888255472e+61*cos(theta)**16 - 3.97826377408282e+60*cos(theta)**14 + 2.92898061036842e+59*cos(theta)**12 - 1.47229794580591e+58*cos(theta)**10 + 4.78018813573347e+56*cos(theta)**8 - 9.19898747770015e+54*cos(theta)**6 + 9.07794816878304e+52*cos(theta)**4 - 3.44514162003151e+50*cos(theta)**2 + 2.1032610622903e+47)*sin(27*phi)

#@torch.jit.script
def Yl63_m_minus_26(theta, phi):
    return 1.29817643864673e-46*(1.0 - cos(theta)**2)**13*(9.42503300191246e+61*cos(theta)**37 - 5.02165758341896e+62*cos(theta)**35 + 1.2145879114367e+63*cos(theta)**33 - 1.76667332572611e+63*cos(theta)**31 + 1.72584684130807e+63*cos(theta)**29 - 1.19776720952321e+63*cos(theta)**27 + 6.09298971800935e+62*cos(theta)**25 - 2.31086841390999e+62*cos(theta)**23 + 6.58389311620753e+61*cos(theta)**21 - 1.4093960799221e+61*cos(theta)**19 + 2.25239934267925e+60*cos(theta)**17 - 2.65217584938855e+59*cos(theta)**15 + 2.25306200797571e+58*cos(theta)**13 - 1.33845267800537e+57*cos(theta)**11 + 5.31132015081497e+55*cos(theta)**9 - 1.31414106824288e+54*cos(theta)**7 + 1.81558963375661e+52*cos(theta)**5 - 1.1483805400105e+50*cos(theta)**3 + 2.1032610622903e+47*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl63_m_minus_25(theta, phi):
    return 7.54954058650599e-45*(1.0 - cos(theta)**2)**12.5*(2.48027184260854e+60*cos(theta)**38 - 1.39490488428304e+61*cos(theta)**36 + 3.57231738657853e+61*cos(theta)**34 - 5.52085414289409e+61*cos(theta)**32 + 5.75282280436023e+61*cos(theta)**30 - 4.27774003401145e+61*cos(theta)**28 + 2.34345758384975e+61*cos(theta)**26 - 9.62861839129164e+60*cos(theta)**24 + 2.99267868918524e+60*cos(theta)**22 - 7.0469803996105e+59*cos(theta)**20 + 1.25133296815514e+59*cos(theta)**18 - 1.65760990586784e+58*cos(theta)**16 + 1.60933000569693e+57*cos(theta)**14 - 1.11537723167114e+56*cos(theta)**12 + 5.31132015081497e+54*cos(theta)**10 - 1.6426763353036e+53*cos(theta)**8 + 3.02598272292768e+51*cos(theta)**6 - 2.87095135002626e+49*cos(theta)**4 + 1.05163053114515e+47*cos(theta)**2 - 6.21898599139652e+43)*sin(25*phi)

#@torch.jit.script
def Yl63_m_minus_24(theta, phi):
    return 4.42276805232852e-43*(1.0 - cos(theta)**2)**12*(6.35967139130395e+58*cos(theta)**39 - 3.77001320076498e+59*cos(theta)**37 + 1.02066211045101e+60*cos(theta)**35 - 1.6729861039073e+60*cos(theta)**33 + 1.8557492917291e+60*cos(theta)**31 - 1.47508277034878e+60*cos(theta)**29 + 8.67947253277685e+59*cos(theta)**27 - 3.85144735651666e+59*cos(theta)**25 + 1.30116464747184e+59*cos(theta)**23 - 3.35570495219548e+58*cos(theta)**21 + 6.58596299029019e+57*cos(theta)**19 - 9.75064650510496e+56*cos(theta)**17 + 1.07288667046462e+56*cos(theta)**15 - 8.57982485900879e+54*cos(theta)**13 + 4.82847286437724e+53*cos(theta)**11 - 1.82519592811511e+52*cos(theta)**9 + 4.32283246132526e+50*cos(theta)**7 - 5.74190270005252e+48*cos(theta)**5 + 3.50543510381717e+46*cos(theta)**3 - 6.21898599139652e+43*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl63_m_minus_23(theta, phi):
    return 2.60905831309973e-41*(1.0 - cos(theta)**2)**11.5*(1.58991784782599e+57*cos(theta)**40 - 9.92108737043417e+57*cos(theta)**38 + 2.83517252903058e+58*cos(theta)**36 - 4.92054736443323e+58*cos(theta)**34 + 5.79921653665345e+58*cos(theta)**32 - 4.91694256782925e+58*cos(theta)**30 + 3.09981161884888e+58*cos(theta)**28 - 1.48132590635256e+58*cos(theta)**26 + 5.42151936446602e+57*cos(theta)**24 - 1.52532043281613e+57*cos(theta)**22 + 3.2929814951451e+56*cos(theta)**20 - 5.41702583616942e+55*cos(theta)**18 + 6.7055416904039e+54*cos(theta)**16 - 6.12844632786342e+53*cos(theta)**14 + 4.02372738698104e+52*cos(theta)**12 - 1.82519592811511e+51*cos(theta)**10 + 5.40354057665657e+49*cos(theta)**8 - 9.56983783342087e+47*cos(theta)**6 + 8.76358775954292e+45*cos(theta)**4 - 3.10949299569826e+43*cos(theta)**2 + 1.78706494005647e+40)*sin(23*phi)

#@torch.jit.script
def Yl63_m_minus_22(theta, phi):
    return 1.54926225350494e-39*(1.0 - cos(theta)**2)**11*(3.87784840933168e+55*cos(theta)**41 - 2.54386855652158e+56*cos(theta)**39 + 7.6626284568394e+56*cos(theta)**37 - 1.40587067555235e+57*cos(theta)**35 + 1.75733834444044e+57*cos(theta)**33 - 1.58611050575137e+57*cos(theta)**31 + 1.06890055822375e+57*cos(theta)**29 - 5.48639224575022e+56*cos(theta)**27 + 2.16860774578641e+56*cos(theta)**25 - 6.63182796876577e+55*cos(theta)**23 + 1.56808642625957e+55*cos(theta)**21 - 2.85106622956285e+54*cos(theta)**19 + 3.94443628847288e+53*cos(theta)**17 - 4.08563088524228e+52*cos(theta)**15 + 3.09517491306233e+51*cos(theta)**13 - 1.65926902555919e+50*cos(theta)**11 + 6.00393397406286e+48*cos(theta)**9 - 1.3671196904887e+47*cos(theta)**7 + 1.75271755190858e+45*cos(theta)**5 - 1.03649766523275e+43*cos(theta)**3 + 1.78706494005647e+40*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl63_m_minus_21(theta, phi):
    return 9.25676093597681e-38*(1.0 - cos(theta)**2)**10.5*(9.23297240317066e+53*cos(theta)**42 - 6.35967139130395e+54*cos(theta)**40 + 2.01648117285247e+55*cos(theta)**38 - 3.90519632097876e+55*cos(theta)**36 + 5.16864218953071e+55*cos(theta)**34 - 4.95659533047304e+55*cos(theta)**32 + 3.56300186074583e+55*cos(theta)**30 - 1.95942580205365e+55*cos(theta)**28 + 8.34079902225541e+54*cos(theta)**26 - 2.7632616536524e+54*cos(theta)**24 + 7.12766557390713e+53*cos(theta)**22 - 1.42553311478143e+53*cos(theta)**20 + 2.19135349359604e+52*cos(theta)**18 - 2.55351930327643e+51*cos(theta)**16 + 2.21083922361595e+50*cos(theta)**14 - 1.38272418796599e+49*cos(theta)**12 + 6.00393397406286e+47*cos(theta)**10 - 1.70889961311087e+46*cos(theta)**8 + 2.92119591984764e+44*cos(theta)**6 - 2.59124416308188e+42*cos(theta)**4 + 8.93532470028235e+39*cos(theta)**2 - 5.00578414581644e+36)*sin(21*phi)

#@torch.jit.script
def Yl63_m_minus_20(theta, phi):
    return 5.56330562138451e-36*(1.0 - cos(theta)**2)**10*(2.14720288445829e+52*cos(theta)**43 - 1.55113936373267e+53*cos(theta)**41 + 5.17046454577557e+53*cos(theta)**39 - 1.05545846512939e+54*cos(theta)**37 + 1.47675491129449e+54*cos(theta)**35 - 1.50199858499183e+54*cos(theta)**33 + 1.14935543895027e+54*cos(theta)**31 - 6.75664069673673e+53*cos(theta)**29 + 3.08918482305756e+53*cos(theta)**27 - 1.10530466146096e+53*cos(theta)**25 + 3.09898503213354e+52*cos(theta)**23 - 6.7882529275306e+51*cos(theta)**21 + 1.15334394399792e+51*cos(theta)**19 - 1.5020701783979e+50*cos(theta)**17 + 1.47389281574397e+49*cos(theta)**15 - 1.06363399074307e+48*cos(theta)**13 + 5.4581217946026e+46*cos(theta)**11 - 1.89877734790097e+45*cos(theta)**9 + 4.17313702835377e+43*cos(theta)**7 - 5.18248832616376e+41*cos(theta)**5 + 2.97844156676078e+39*cos(theta)**3 - 5.00578414581644e+36*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl63_m_minus_19(theta, phi):
    return 3.36200459820719e-34*(1.0 - cos(theta)**2)**9.5*(4.88000655558703e+50*cos(theta)**44 - 3.69318896126827e+51*cos(theta)**42 + 1.29261613644389e+52*cos(theta)**40 - 2.7775222766563e+52*cos(theta)**38 + 4.10209697581802e+52*cos(theta)**36 - 4.41764289703479e+52*cos(theta)**34 + 3.59173574671959e+52*cos(theta)**32 - 2.25221356557891e+52*cos(theta)**30 + 1.10328029394913e+52*cos(theta)**28 - 4.25117177484985e+51*cos(theta)**26 + 1.29124376338897e+51*cos(theta)**24 - 3.08556951251391e+50*cos(theta)**22 + 5.76671971998959e+49*cos(theta)**20 - 8.34483432443277e+48*cos(theta)**18 + 9.21183009839981e+47*cos(theta)**16 - 7.59738564816479e+46*cos(theta)**14 + 4.5484348288355e+45*cos(theta)**12 - 1.89877734790097e+44*cos(theta)**10 + 5.21642128544222e+42*cos(theta)**8 - 8.63748054360627e+40*cos(theta)**6 + 7.44610391690196e+38*cos(theta)**4 - 2.50289207290822e+36*cos(theta)**2 + 1.37069664452805e+33)*sin(19*phi)

#@torch.jit.script
def Yl63_m_minus_18(theta, phi):
    return 2.04226213911857e-32*(1.0 - cos(theta)**2)**9*(1.08444590124156e+49*cos(theta)**45 - 8.58881153783317e+49*cos(theta)**43 + 3.15272228400949e+50*cos(theta)**41 - 7.12185199142641e+50*cos(theta)**39 + 1.10867485832919e+51*cos(theta)**37 - 1.26218368486708e+51*cos(theta)**35 + 1.08840477173321e+51*cos(theta)**33 - 7.26520505025455e+50*cos(theta)**31 + 3.80441480672113e+50*cos(theta)**29 - 1.5745080647592e+50*cos(theta)**27 + 5.16497505355589e+49*cos(theta)**25 - 1.34155196196257e+49*cos(theta)**23 + 2.74605700951885e+48*cos(theta)**21 - 4.39201806549093e+47*cos(theta)**19 + 5.418723587294e+46*cos(theta)**17 - 5.06492376544319e+45*cos(theta)**15 + 3.49879602218115e+44*cos(theta)**13 - 1.72616122536452e+43*cos(theta)**11 + 5.79602365049135e+41*cos(theta)**9 - 1.23392579194375e+40*cos(theta)**7 + 1.48922078338039e+38*cos(theta)**5 - 8.34297357636074e+35*cos(theta)**3 + 1.37069664452805e+33*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl63_m_minus_17(theta, phi):
    return 1.24661661655909e-30*(1.0 - cos(theta)**2)**8.5*(2.35749108965557e+47*cos(theta)**46 - 1.95200262223481e+48*cos(theta)**44 + 7.50648162859404e+48*cos(theta)**42 - 1.7804629978566e+49*cos(theta)**40 + 2.91756541665578e+49*cos(theta)**38 - 3.50606579129745e+49*cos(theta)**36 + 3.20119050509768e+49*cos(theta)**34 - 2.27037657820455e+49*cos(theta)**32 + 1.26813826890704e+49*cos(theta)**30 - 5.62324308842573e+48*cos(theta)**28 + 1.98652886675227e+48*cos(theta)**26 - 5.58979984151071e+47*cos(theta)**24 + 1.24820773159948e+47*cos(theta)**22 - 2.19600903274546e+46*cos(theta)**20 + 3.01040199294111e+45*cos(theta)**18 - 3.165577353402e+44*cos(theta)**16 + 2.49914001584368e+43*cos(theta)**14 - 1.43846768780376e+42*cos(theta)**12 + 5.79602365049135e+40*cos(theta)**10 - 1.54240723992969e+39*cos(theta)**8 + 2.48203463896732e+37*cos(theta)**6 - 2.08574339409018e+35*cos(theta)**4 + 6.85348322264026e+32*cos(theta)**2 - 3.67873495579187e+29)*sin(17*phi)

#@torch.jit.script
def Yl63_m_minus_16(theta, phi):
    return 7.64410834397408e-29*(1.0 - cos(theta)**2)**8*(5.01593848862887e+45*cos(theta)**47 - 4.33778360496625e+46*cos(theta)**45 + 1.74569340199861e+47*cos(theta)**43 - 4.34259267769903e+47*cos(theta)**41 + 7.48093696578404e+47*cos(theta)**39 - 9.47585348999312e+47*cos(theta)**37 + 9.14625858599336e+47*cos(theta)**35 - 6.87992902486226e+47*cos(theta)**33 + 4.09076860937756e+47*cos(theta)**31 - 1.93904934083646e+47*cos(theta)**29 + 7.35751432130469e+46*cos(theta)**27 - 2.23591993660428e+46*cos(theta)**25 + 5.42699013738904e+45*cos(theta)**23 - 1.04571858702165e+45*cos(theta)**21 + 1.58442210154795e+44*cos(theta)**19 - 1.86210432553059e+43*cos(theta)**17 + 1.66609334389579e+42*cos(theta)**15 - 1.10651360600289e+41*cos(theta)**13 + 5.26911240953759e+39*cos(theta)**11 - 1.7137858221441e+38*cos(theta)**9 + 3.54576376995331e+36*cos(theta)**7 - 4.17148678818037e+34*cos(theta)**5 + 2.28449440754675e+32*cos(theta)**3 - 3.67873495579187e+29*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl63_m_minus_15(theta, phi):
    return 4.70718208574704e-27*(1.0 - cos(theta)**2)**7.5*(1.04498718513102e+44*cos(theta)**48 - 9.42996435862228e+44*cos(theta)**46 + 3.9674850045423e+45*cos(theta)**44 - 1.03395063754739e+46*cos(theta)**42 + 1.87023424144601e+46*cos(theta)**40 - 2.49364565526135e+46*cos(theta)**38 + 2.54062738499815e+46*cos(theta)**36 - 2.02350853672419e+46*cos(theta)**34 + 1.27836519043049e+46*cos(theta)**32 - 6.46349780278819e+45*cos(theta)**30 + 2.62768368618025e+45*cos(theta)**28 - 8.59969206386263e+44*cos(theta)**26 + 2.26124589057877e+44*cos(theta)**24 - 4.75326630464386e+43*cos(theta)**22 + 7.92211050773977e+42*cos(theta)**20 - 1.03450240307255e+42*cos(theta)**18 + 1.04130833993487e+41*cos(theta)**16 - 7.90366861430639e+39*cos(theta)**14 + 4.39092700794799e+38*cos(theta)**12 - 1.7137858221441e+37*cos(theta)**10 + 4.43220471244164e+35*cos(theta)**8 - 6.95247798030062e+33*cos(theta)**6 + 5.71123601886688e+31*cos(theta)**4 - 1.83936747789594e+29*cos(theta)**2 + 9.70130526316422e+25)*sin(15*phi)

#@torch.jit.script
def Yl63_m_minus_14(theta, phi):
    return 2.91008945749061e-25*(1.0 - cos(theta)**2)**7*(2.13262690843064e+42*cos(theta)**49 - 2.00637539545155e+43*cos(theta)**47 + 8.81663334342734e+43*cos(theta)**45 - 2.40453636638927e+44*cos(theta)**43 + 4.56154693035612e+44*cos(theta)**41 - 6.39396321861884e+44*cos(theta)**39 + 6.86656049999501e+44*cos(theta)**37 - 5.78145296206913e+44*cos(theta)**35 + 3.87383391039542e+44*cos(theta)**33 - 2.084999291222e+44*cos(theta)**31 + 9.06097822820775e+43*cos(theta)**29 - 3.18507113476394e+43*cos(theta)**27 + 9.04498356231506e+42*cos(theta)**25 - 2.0666375237582e+42*cos(theta)**23 + 3.77243357511418e+41*cos(theta)**21 - 5.44474948985551e+40*cos(theta)**19 + 6.12534317608745e+39*cos(theta)**17 - 5.26911240953759e+38*cos(theta)**15 + 3.37763615996e+37*cos(theta)**13 - 1.55798711104009e+36*cos(theta)**11 + 4.92467190271294e+34*cos(theta)**9 - 9.93211140042945e+32*cos(theta)**7 + 1.14224720377338e+31*cos(theta)**5 - 6.13122492631979e+28*cos(theta)**3 + 9.70130526316422e+25*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl63_m_minus_13(theta, phi):
    return 1.80566302240486e-23*(1.0 - cos(theta)**2)**6.5*(4.26525381686129e+40*cos(theta)**50 - 4.17994874052406e+41*cos(theta)**48 + 1.9166594224842e+42*cos(theta)**46 - 5.46485537815744e+42*cos(theta)**44 + 1.08608260246574e+43*cos(theta)**42 - 1.59849080465471e+43*cos(theta)**40 + 1.80698960526185e+43*cos(theta)**38 - 1.60595915613031e+43*cos(theta)**36 + 1.13936291482218e+43*cos(theta)**34 - 6.51562278506874e+42*cos(theta)**32 + 3.02032607606925e+42*cos(theta)**30 - 1.13752540527283e+42*cos(theta)**28 + 3.47883983165964e+41*cos(theta)**26 - 8.61098968232584e+40*cos(theta)**24 + 1.71474253414281e+40*cos(theta)**22 - 2.72237474492776e+39*cos(theta)**20 + 3.4029684311597e+38*cos(theta)**18 - 3.293195255961e+37*cos(theta)**16 + 2.41259725711428e+36*cos(theta)**14 - 1.29832259253341e+35*cos(theta)**12 + 4.92467190271294e+33*cos(theta)**10 - 1.24151392505368e+32*cos(theta)**8 + 1.90374533962229e+30*cos(theta)**6 - 1.53280623157995e+28*cos(theta)**4 + 4.85065263158211e+25*cos(theta)**2 - 2.51981954887382e+22)*sin(13*phi)

#@torch.jit.script
def Yl63_m_minus_12(theta, phi):
    return 1.12416119182533e-21*(1.0 - cos(theta)**2)**6*(8.36324277815939e+38*cos(theta)**51 - 8.53050763372257e+39*cos(theta)**49 + 4.07799877124299e+40*cos(theta)**47 - 1.21441230625721e+41*cos(theta)**45 + 2.52577349410638e+41*cos(theta)**43 - 3.89875806013344e+41*cos(theta)**41 + 4.63330668015858e+41*cos(theta)**39 - 4.34043015170355e+41*cos(theta)**37 + 3.25532261377766e+41*cos(theta)**35 - 1.97443114699053e+41*cos(theta)**33 + 9.74298734215887e+40*cos(theta)**31 - 3.92250139749253e+40*cos(theta)**29 + 1.28845919691098e+40*cos(theta)**27 - 3.44439587293034e+39*cos(theta)**25 + 7.45540232236003e+38*cos(theta)**23 - 1.29636892615607e+38*cos(theta)**21 + 1.79103601639984e+37*cos(theta)**19 - 1.93717367997706e+36*cos(theta)**17 + 1.60839817140952e+35*cos(theta)**15 - 9.98709686564162e+33*cos(theta)**13 + 4.47697445701176e+32*cos(theta)**11 - 1.37945991672631e+31*cos(theta)**9 + 2.71963619946042e+29*cos(theta)**7 - 3.06561246315989e+27*cos(theta)**5 + 1.61688421052737e+25*cos(theta)**3 - 2.51981954887382e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl63_m_minus_11(theta, phi):
    return 7.02038439282633e-20*(1.0 - cos(theta)**2)**5.5*(1.60831591887681e+37*cos(theta)**52 - 1.70610152674451e+38*cos(theta)**50 + 8.49583077342289e+38*cos(theta)**48 - 2.64002675273306e+39*cos(theta)**46 + 5.74039430478723e+39*cos(theta)**44 - 9.282757286032e+39*cos(theta)**42 + 1.15832667003964e+40*cos(theta)**40 - 1.14221846097462e+40*cos(theta)**38 + 9.04256281604906e+39*cos(theta)**36 - 5.80715043232508e+39*cos(theta)**34 + 3.04468354442465e+39*cos(theta)**32 - 1.30750046583084e+39*cos(theta)**30 + 4.60163998896778e+38*cos(theta)**28 - 1.32476764343474e+38*cos(theta)**26 + 3.10641763431668e+37*cos(theta)**24 - 5.89258602798216e+36*cos(theta)**22 + 8.9551800819992e+35*cos(theta)**20 - 1.07620759998725e+35*cos(theta)**18 + 1.00524885713095e+34*cos(theta)**16 - 7.13364061831544e+32*cos(theta)**14 + 3.7308120475098e+31*cos(theta)**12 - 1.37945991672631e+30*cos(theta)**10 + 3.39954524932552e+28*cos(theta)**8 - 5.10935410526649e+26*cos(theta)**6 + 4.04221052631842e+24*cos(theta)**4 - 1.25990977443691e+22*cos(theta)**2 + 6.46107576634314e+18)*sin(11*phi)

#@torch.jit.script
def Yl63_m_minus_10(theta, phi):
    return 4.396577031332e-18*(1.0 - cos(theta)**2)**5*(3.03455833750341e+35*cos(theta)**53 - 3.34529711126375e+36*cos(theta)**51 + 1.73384301498426e+37*cos(theta)**49 - 5.61707819730439e+37*cos(theta)**47 + 1.27564317884161e+38*cos(theta)**45 - 2.15878076419349e+38*cos(theta)**43 + 2.82518700009669e+38*cos(theta)**41 - 2.9287652845503e+38*cos(theta)**39 + 2.44393589622948e+38*cos(theta)**37 - 1.65918583780717e+38*cos(theta)**35 + 9.22631377098378e+37*cos(theta)**33 - 4.21774343816401e+37*cos(theta)**31 + 1.58677240998889e+37*cos(theta)**29 - 4.90654682753609e+36*cos(theta)**27 + 1.24256705372667e+36*cos(theta)**25 - 2.56199392520963e+35*cos(theta)**23 + 4.26437146761867e+34*cos(theta)**21 - 5.6642505262487e+33*cos(theta)**19 + 5.91322857135854e+32*cos(theta)**17 - 4.7557604122103e+31*cos(theta)**15 + 2.86985542116138e+30*cos(theta)**13 - 1.25405446975119e+29*cos(theta)**11 + 3.77727249925058e+27*cos(theta)**9 - 7.29907729323784e+25*cos(theta)**7 + 8.08442105263685e+23*cos(theta)**5 - 4.19969924812304e+21*cos(theta)**3 + 6.46107576634314e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl63_m_minus_9(theta, phi):
    return 2.76040621600124e-16*(1.0 - cos(theta)**2)**4.5*(5.61955247685816e+33*cos(theta)**54 - 6.43326367550722e+34*cos(theta)**52 + 3.46768602996853e+35*cos(theta)**50 - 1.17022462443841e+36*cos(theta)**48 + 2.77313734530784e+36*cos(theta)**46 - 4.90631991862156e+36*cos(theta)**44 + 6.72663571451594e+36*cos(theta)**42 - 7.32191321137576e+36*cos(theta)**40 + 6.43141025323546e+36*cos(theta)**38 - 4.60884954946435e+36*cos(theta)**36 + 2.71362169734817e+36*cos(theta)**34 - 1.31804482442625e+36*cos(theta)**32 + 5.28924136662963e+35*cos(theta)**30 - 1.75233815269146e+35*cos(theta)**28 + 4.77910405279489e+34*cos(theta)**26 - 1.06749746883735e+34*cos(theta)**24 + 1.93835066709939e+33*cos(theta)**22 - 2.83212526312435e+32*cos(theta)**20 + 3.28512698408808e+31*cos(theta)**18 - 2.97235025763143e+30*cos(theta)**16 + 2.04989672940099e+29*cos(theta)**14 - 1.04504539145933e+28*cos(theta)**12 + 3.77727249925058e+26*cos(theta)**10 - 9.1238466165473e+24*cos(theta)**8 + 1.34740350877281e+23*cos(theta)**6 - 1.04992481203076e+21*cos(theta)**4 + 3.23053788317157e+18*cos(theta)**2 - 1.63903494833667e+15)*sin(9*phi)

#@torch.jit.script
def Yl63_m_minus_8(theta, phi):
    return 1.73708307833159e-14*(1.0 - cos(theta)**2)**4*(1.02173681397421e+32*cos(theta)**55 - 1.21382333500136e+33*cos(theta)**53 + 6.79938437248731e+33*cos(theta)**51 - 2.38821351926207e+34*cos(theta)**49 + 5.90029222405923e+34*cos(theta)**47 - 1.09029331524924e+35*cos(theta)**45 + 1.56433388709673e+35*cos(theta)**43 - 1.78583249057945e+35*cos(theta)**41 + 1.64907955211166e+35*cos(theta)**39 - 1.24563501336874e+35*cos(theta)**37 + 7.7532048495662e+34*cos(theta)**35 - 3.9940752255341e+34*cos(theta)**33 + 1.70620689246117e+34*cos(theta)**31 - 6.04254535410849e+33*cos(theta)**29 + 1.77003853807218e+33*cos(theta)**27 - 4.26998987534939e+32*cos(theta)**25 + 8.42761159608432e+31*cos(theta)**23 - 1.34863107767826e+31*cos(theta)**21 + 1.72901420215162e+30*cos(theta)**19 - 1.74844132801849e+29*cos(theta)**17 + 1.36659781960066e+28*cos(theta)**15 - 8.03881070353329e+26*cos(theta)**13 + 3.4338840902278e+25*cos(theta)**11 - 1.01376073517192e+24*cos(theta)**9 + 1.92486215538973e+22*cos(theta)**7 - 2.09984962406152e+20*cos(theta)**5 + 1.07684596105719e+18*cos(theta)**3 - 1.63903494833667e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl63_m_minus_7(theta, phi):
    return 1.09532696037299e-12*(1.0 - cos(theta)**2)**3.5*(1.82453002495395e+30*cos(theta)**56 - 2.24782099074326e+31*cos(theta)**54 + 1.30757391778602e+32*cos(theta)**52 - 4.77642703852414e+32*cos(theta)**50 + 1.22922754667901e+33*cos(theta)**48 - 2.37020285923747e+33*cos(theta)**46 + 3.5553042888562e+33*cos(theta)**44 - 4.25198212042727e+33*cos(theta)**42 + 4.12269888027914e+33*cos(theta)**40 - 3.27798687728617e+33*cos(theta)**38 + 2.15366801376839e+33*cos(theta)**36 - 1.17472800751003e+33*cos(theta)**34 + 5.33189653894116e+32*cos(theta)**32 - 2.01418178470283e+32*cos(theta)**30 + 6.32156620740065e+31*cos(theta)**28 - 1.6423037982113e+31*cos(theta)**26 + 3.5115048317018e+30*cos(theta)**24 - 6.13014126217392e+29*cos(theta)**22 + 8.64507101075809e+28*cos(theta)**20 - 9.71356293343606e+27*cos(theta)**18 + 8.54123637250412e+26*cos(theta)**16 - 5.74200764538092e+25*cos(theta)**14 + 2.86157007518983e+24*cos(theta)**12 - 1.01376073517192e+23*cos(theta)**10 + 2.40607769423716e+21*cos(theta)**8 - 3.49974937343587e+19*cos(theta)**6 + 2.69211490264297e+17*cos(theta)**4 - 819517474168333.0*cos(theta)**2 + 412232129863.346)*sin(7*phi)

#@torch.jit.script
def Yl63_m_minus_6(theta, phi):
    return 6.91879121594119e-11*(1.0 - cos(theta)**2)**3*(3.20092986834026e+28*cos(theta)**57 - 4.08694725589684e+29*cos(theta)**55 + 2.46712059959626e+30*cos(theta)**53 - 9.36554321279243e+30*cos(theta)**51 + 2.50862764628369e+31*cos(theta)**49 - 5.04298480688823e+31*cos(theta)**47 + 7.90067619745823e+31*cos(theta)**45 - 9.88833051262155e+31*cos(theta)**43 + 1.00553631226321e+32*cos(theta)**41 - 8.40509455714402e+31*cos(theta)**39 + 5.82072436153619e+31*cos(theta)**37 - 3.35636573574294e+31*cos(theta)**35 + 1.61572622392156e+31*cos(theta)**33 - 6.49736059581558e+30*cos(theta)**31 + 2.17985041634505e+30*cos(theta)**29 - 6.08260666004186e+29*cos(theta)**27 + 1.40460193268072e+29*cos(theta)**25 - 2.66527880964084e+28*cos(theta)**23 + 4.11670048131338e+27*cos(theta)**21 - 5.11240154391372e+26*cos(theta)**19 + 5.02425668970831e+25*cos(theta)**17 - 3.82800509692061e+24*cos(theta)**15 + 2.20120775014603e+23*cos(theta)**13 - 9.21600668338111e+21*cos(theta)**11 + 2.67341966026351e+20*cos(theta)**9 - 4.99964196205124e+18*cos(theta)**7 + 5.38422980528595e+16*cos(theta)**5 - 273172491389444.0*cos(theta)**3 + 412232129863.346*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl63_m_minus_5(theta, phi):
    return 4.37692159974244e-9*(1.0 - cos(theta)**2)**2.5*(5.51884460058665e+26*cos(theta)**58 - 7.29812009981579e+27*cos(theta)**56 + 4.56874185110419e+28*cos(theta)**54 - 1.80106600246008e+29*cos(theta)**52 + 5.01725529256738e+29*cos(theta)**50 - 1.05062183476838e+30*cos(theta)**48 + 1.71753830379527e+30*cos(theta)**46 - 2.24734784377763e+30*cos(theta)**44 + 2.39413407681716e+30*cos(theta)**42 - 2.10127363928601e+30*cos(theta)**40 + 1.53176956882531e+30*cos(theta)**38 - 9.32323815484151e+29*cos(theta)**36 + 4.75213595271048e+29*cos(theta)**34 - 2.03042518619237e+29*cos(theta)**32 + 7.26616805448351e+28*cos(theta)**30 - 2.17235952144352e+28*cos(theta)**28 + 5.40231512569508e+27*cos(theta)**26 - 1.11053283735035e+27*cos(theta)**24 + 1.87122749150608e+26*cos(theta)**22 - 2.55620077195686e+25*cos(theta)**20 + 2.79125371650461e+24*cos(theta)**18 - 2.39250318557538e+23*cos(theta)**16 + 1.57229125010431e+22*cos(theta)**14 - 7.68000556948426e+20*cos(theta)**12 + 2.67341966026351e+19*cos(theta)**10 - 6.24955245256404e+17*cos(theta)**8 + 8.97371634214324e+15*cos(theta)**6 - 68293122847361.1*cos(theta)**4 + 206116064931.673*cos(theta)**2 - 103006529.201236)*sin(5*phi)

#@torch.jit.script
def Yl63_m_minus_4(theta, phi):
    return 2.77235748188164e-7*(1.0 - cos(theta)**2)**2*(9.35397389929941e+24*cos(theta)**59 - 1.2803719473361e+26*cos(theta)**57 + 8.30680336564399e+26*cos(theta)**55 - 3.39823774049072e+27*cos(theta)**53 + 9.8377554756223e+27*cos(theta)**51 - 2.14412619340486e+28*cos(theta)**49 + 3.65433681658568e+28*cos(theta)**47 - 4.99410631950584e+28*cos(theta)**45 + 5.56775366701664e+28*cos(theta)**43 - 5.12505765679513e+28*cos(theta)**41 + 3.92761427903926e+28*cos(theta)**39 - 2.51979409590311e+28*cos(theta)**37 + 1.35775312934585e+28*cos(theta)**35 - 6.15280359452233e+27*cos(theta)**33 + 2.34392517886565e+27*cos(theta)**31 - 7.49089490152939e+26*cos(theta)**29 + 2.00085745396114e+26*cos(theta)**27 - 4.44213134940139e+25*cos(theta)**25 + 8.13577170220035e+24*cos(theta)**23 - 1.2172384628366e+24*cos(theta)**21 + 1.46908090342348e+23*cos(theta)**19 - 1.40735481504434e+22*cos(theta)**17 + 1.0481941667362e+21*cos(theta)**15 - 5.90769659191097e+19*cos(theta)**13 + 2.43038150933046e+18*cos(theta)**11 - 6.94394716951561e+16*cos(theta)**9 + 1.28195947744903e+15*cos(theta)**7 - 13658624569472.2*cos(theta)**5 + 68705354977.2244*cos(theta)**3 - 103006529.201236*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl63_m_minus_3(theta, phi):
    return 1.75777084255962e-5*(1.0 - cos(theta)**2)**1.5*(1.55899564988324e+23*cos(theta)**60 - 2.20753784023466e+24*cos(theta)**58 + 1.483357743865e+25*cos(theta)**56 - 6.2930328527606e+25*cos(theta)**54 + 1.89187605300429e+26*cos(theta)**52 - 4.28825238680972e+26*cos(theta)**50 + 7.61320170122016e+26*cos(theta)**48 - 1.08567528684909e+27*cos(theta)**46 + 1.2653985606856e+27*cos(theta)**44 - 1.22025182304646e+27*cos(theta)**42 + 9.81903569759815e+26*cos(theta)**40 - 6.63103709448187e+26*cos(theta)**38 + 3.77153647040514e+26*cos(theta)**36 - 1.80964811603598e+26*cos(theta)**34 + 7.32476618395515e+25*cos(theta)**32 - 2.49696496717646e+25*cos(theta)**30 + 7.14591947843264e+24*cos(theta)**28 - 1.70851205746207e+24*cos(theta)**26 + 3.38990487591681e+23*cos(theta)**24 - 5.53290210380272e+22*cos(theta)**22 + 7.34540451711741e+21*cos(theta)**20 - 7.81863786135747e+20*cos(theta)**18 + 6.55121354210127e+19*cos(theta)**16 - 4.21978327993641e+18*cos(theta)**14 + 2.02531792444205e+17*cos(theta)**12 - 6.94394716951561e+15*cos(theta)**10 + 160244934681129.0*cos(theta)**8 - 2276437428245.37*cos(theta)**6 + 17176338744.3061*cos(theta)**4 - 51503264.600618*cos(theta)**2 + 25623.5147266756)*sin(3*phi)

#@torch.jit.script
def Yl63_m_minus_2(theta, phi):
    return 0.00111531910485384*(1.0 - cos(theta)**2)*(2.55573057357907e+21*cos(theta)**61 - 3.74158955971977e+22*cos(theta)**59 + 2.6023820067807e+23*cos(theta)**57 - 1.14418779141102e+24*cos(theta)**55 + 3.56957745849866e+24*cos(theta)**53 - 8.4083380133524e+24*cos(theta)**51 + 1.55371463290207e+25*cos(theta)**49 - 2.30994741882786e+25*cos(theta)**47 + 2.81199680152356e+25*cos(theta)**45 - 2.83779493731735e+25*cos(theta)**43 + 2.39488675551175e+25*cos(theta)**41 - 1.70026592166202e+25*cos(theta)**39 + 1.01933418119058e+25*cos(theta)**37 - 5.17042318867422e+24*cos(theta)**35 + 2.21962611635005e+24*cos(theta)**33 - 8.05472570056924e+23*cos(theta)**31 + 2.46411016497677e+23*cos(theta)**29 - 6.32782243504472e+22*cos(theta)**27 + 1.35596195036673e+22*cos(theta)**25 - 2.40560961034901e+21*cos(theta)**23 + 3.49781167481781e+20*cos(theta)**21 - 4.11507255860919e+19*cos(theta)**19 + 3.85365502476545e+18*cos(theta)**17 - 2.81318885329094e+17*cos(theta)**15 + 1.55793686495542e+16*cos(theta)**13 - 631267924501419.0*cos(theta)**11 + 17804992742347.7*cos(theta)**9 - 325205346892.196*cos(theta)**7 + 3435267748.86122*cos(theta)**5 - 17167754.8668727*cos(theta)**3 + 25623.5147266756*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl63_m_minus_1(theta, phi):
    return 0.0708030008105409*(1.0 - cos(theta)**2)**0.5*(4.12214608641786e+19*cos(theta)**62 - 6.23598259953294e+20*cos(theta)**60 + 4.48686552893224e+21*cos(theta)**58 - 2.04319248466253e+22*cos(theta)**56 + 6.61032862684937e+22*cos(theta)**54 - 1.61698807949085e+23*cos(theta)**52 + 3.10742926580415e+23*cos(theta)**50 - 4.81239045589138e+23*cos(theta)**48 + 6.11303652505121e+23*cos(theta)**46 - 6.44953394844852e+23*cos(theta)**44 + 5.70211132264701e+23*cos(theta)**42 - 4.25066480415505e+23*cos(theta)**40 + 2.68245837155415e+23*cos(theta)**38 - 1.43622866352062e+23*cos(theta)**36 + 6.5283121069119e+22*cos(theta)**34 - 2.51710178142789e+22*cos(theta)**32 + 8.21370054992258e+21*cos(theta)**30 - 2.25993658394454e+21*cos(theta)**28 + 5.21523827064125e+20*cos(theta)**26 - 1.00233733764542e+20*cos(theta)**24 + 1.58991439764446e+19*cos(theta)**22 - 2.0575362793046e+18*cos(theta)**20 + 2.14091945820303e+17*cos(theta)**18 - 1.75824303330684e+16*cos(theta)**16 + 1.11281204639673e+15*cos(theta)**14 - 52605660375118.2*cos(theta)**12 + 1780499274234.77*cos(theta)**10 - 40650668361.5244*cos(theta)**8 + 572544624.810203*cos(theta)**6 - 4291938.71671817*cos(theta)**4 + 12811.7573633378*cos(theta)**2 - 6.35819223986988)*sin(phi)

#@torch.jit.script
def Yl63_m0(theta, phi):
    return 6.53475982764185e+18*cos(theta)**63 - 1.02099087547076e+20*cos(theta)**61 + 7.59517602484348e+20*cos(theta)**59 - 3.57998517314248e+21*cos(theta)**57 + 1.20034796981836e+22*cos(theta)**55 - 3.0470371541543e+22*cos(theta)**53 + 6.08524231655743e+22*cos(theta)**51 - 9.80870284906539e+22*cos(theta)**49 + 1.29899037730866e+23*cos(theta)**47 - 1.43140529854298e+23*cos(theta)**45 + 1.32438434164257e+23*cos(theta)**43 - 1.03542775801146e+23*cos(theta)**41 + 6.869342731144e+22*cos(theta)**39 - 3.87675777896246e+22*cos(theta)**37 + 1.8628576340469e+22*cos(theta)**35 - 7.61787142445294e+21*cos(theta)**33 + 2.64620796849418e+21*cos(theta)**31 - 7.78296461321817e+20*cos(theta)**29 + 1.92911088703698e+20*cos(theta)**27 - 4.00424554316961e+19*cos(theta)**25 + 6.9038716261545e+18*cos(theta)**23 - 9.78531944771478e+17*cos(theta)**21 + 1.12536532531221e+17*cos(theta)**19 - 1.03294401840252e+16*cos(theta)**17 + 740930308558767.0*cos(theta)**15 - 40414380466841.8*cos(theta)**13 + 1616575218673.67*cos(theta)**11 - 45109912241.0208*cos(theta)**9 + 816879698.529552*cos(theta)**7 - 8572950.3593806*cos(theta)**5 + 42651.4943252766*cos(theta)**3 - 63.5009841071116*cos(theta)

#@torch.jit.script
def Yl63_m1(theta, phi):
    return 0.0708030008105409*(1.0 - cos(theta)**2)**0.5*(4.12214608641786e+19*cos(theta)**62 - 6.23598259953294e+20*cos(theta)**60 + 4.48686552893224e+21*cos(theta)**58 - 2.04319248466253e+22*cos(theta)**56 + 6.61032862684937e+22*cos(theta)**54 - 1.61698807949085e+23*cos(theta)**52 + 3.10742926580415e+23*cos(theta)**50 - 4.81239045589138e+23*cos(theta)**48 + 6.11303652505121e+23*cos(theta)**46 - 6.44953394844852e+23*cos(theta)**44 + 5.70211132264701e+23*cos(theta)**42 - 4.25066480415505e+23*cos(theta)**40 + 2.68245837155415e+23*cos(theta)**38 - 1.43622866352062e+23*cos(theta)**36 + 6.5283121069119e+22*cos(theta)**34 - 2.51710178142789e+22*cos(theta)**32 + 8.21370054992258e+21*cos(theta)**30 - 2.25993658394454e+21*cos(theta)**28 + 5.21523827064125e+20*cos(theta)**26 - 1.00233733764542e+20*cos(theta)**24 + 1.58991439764446e+19*cos(theta)**22 - 2.0575362793046e+18*cos(theta)**20 + 2.14091945820303e+17*cos(theta)**18 - 1.75824303330684e+16*cos(theta)**16 + 1.11281204639673e+15*cos(theta)**14 - 52605660375118.2*cos(theta)**12 + 1780499274234.77*cos(theta)**10 - 40650668361.5244*cos(theta)**8 + 572544624.810203*cos(theta)**6 - 4291938.71671817*cos(theta)**4 + 12811.7573633378*cos(theta)**2 - 6.35819223986988)*cos(phi)

#@torch.jit.script
def Yl63_m2(theta, phi):
    return 0.00111531910485384*(1.0 - cos(theta)**2)*(2.55573057357907e+21*cos(theta)**61 - 3.74158955971977e+22*cos(theta)**59 + 2.6023820067807e+23*cos(theta)**57 - 1.14418779141102e+24*cos(theta)**55 + 3.56957745849866e+24*cos(theta)**53 - 8.4083380133524e+24*cos(theta)**51 + 1.55371463290207e+25*cos(theta)**49 - 2.30994741882786e+25*cos(theta)**47 + 2.81199680152356e+25*cos(theta)**45 - 2.83779493731735e+25*cos(theta)**43 + 2.39488675551175e+25*cos(theta)**41 - 1.70026592166202e+25*cos(theta)**39 + 1.01933418119058e+25*cos(theta)**37 - 5.17042318867422e+24*cos(theta)**35 + 2.21962611635005e+24*cos(theta)**33 - 8.05472570056924e+23*cos(theta)**31 + 2.46411016497677e+23*cos(theta)**29 - 6.32782243504472e+22*cos(theta)**27 + 1.35596195036673e+22*cos(theta)**25 - 2.40560961034901e+21*cos(theta)**23 + 3.49781167481781e+20*cos(theta)**21 - 4.11507255860919e+19*cos(theta)**19 + 3.85365502476545e+18*cos(theta)**17 - 2.81318885329094e+17*cos(theta)**15 + 1.55793686495542e+16*cos(theta)**13 - 631267924501419.0*cos(theta)**11 + 17804992742347.7*cos(theta)**9 - 325205346892.196*cos(theta)**7 + 3435267748.86122*cos(theta)**5 - 17167754.8668727*cos(theta)**3 + 25623.5147266756*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl63_m3(theta, phi):
    return 1.75777084255962e-5*(1.0 - cos(theta)**2)**1.5*(1.55899564988324e+23*cos(theta)**60 - 2.20753784023466e+24*cos(theta)**58 + 1.483357743865e+25*cos(theta)**56 - 6.2930328527606e+25*cos(theta)**54 + 1.89187605300429e+26*cos(theta)**52 - 4.28825238680972e+26*cos(theta)**50 + 7.61320170122016e+26*cos(theta)**48 - 1.08567528684909e+27*cos(theta)**46 + 1.2653985606856e+27*cos(theta)**44 - 1.22025182304646e+27*cos(theta)**42 + 9.81903569759815e+26*cos(theta)**40 - 6.63103709448187e+26*cos(theta)**38 + 3.77153647040514e+26*cos(theta)**36 - 1.80964811603598e+26*cos(theta)**34 + 7.32476618395515e+25*cos(theta)**32 - 2.49696496717646e+25*cos(theta)**30 + 7.14591947843264e+24*cos(theta)**28 - 1.70851205746207e+24*cos(theta)**26 + 3.38990487591681e+23*cos(theta)**24 - 5.53290210380272e+22*cos(theta)**22 + 7.34540451711741e+21*cos(theta)**20 - 7.81863786135747e+20*cos(theta)**18 + 6.55121354210127e+19*cos(theta)**16 - 4.21978327993641e+18*cos(theta)**14 + 2.02531792444205e+17*cos(theta)**12 - 6.94394716951561e+15*cos(theta)**10 + 160244934681129.0*cos(theta)**8 - 2276437428245.37*cos(theta)**6 + 17176338744.3061*cos(theta)**4 - 51503264.600618*cos(theta)**2 + 25623.5147266756)*cos(3*phi)

#@torch.jit.script
def Yl63_m4(theta, phi):
    return 2.77235748188164e-7*(1.0 - cos(theta)**2)**2*(9.35397389929941e+24*cos(theta)**59 - 1.2803719473361e+26*cos(theta)**57 + 8.30680336564399e+26*cos(theta)**55 - 3.39823774049072e+27*cos(theta)**53 + 9.8377554756223e+27*cos(theta)**51 - 2.14412619340486e+28*cos(theta)**49 + 3.65433681658568e+28*cos(theta)**47 - 4.99410631950584e+28*cos(theta)**45 + 5.56775366701664e+28*cos(theta)**43 - 5.12505765679513e+28*cos(theta)**41 + 3.92761427903926e+28*cos(theta)**39 - 2.51979409590311e+28*cos(theta)**37 + 1.35775312934585e+28*cos(theta)**35 - 6.15280359452233e+27*cos(theta)**33 + 2.34392517886565e+27*cos(theta)**31 - 7.49089490152939e+26*cos(theta)**29 + 2.00085745396114e+26*cos(theta)**27 - 4.44213134940139e+25*cos(theta)**25 + 8.13577170220035e+24*cos(theta)**23 - 1.2172384628366e+24*cos(theta)**21 + 1.46908090342348e+23*cos(theta)**19 - 1.40735481504434e+22*cos(theta)**17 + 1.0481941667362e+21*cos(theta)**15 - 5.90769659191097e+19*cos(theta)**13 + 2.43038150933046e+18*cos(theta)**11 - 6.94394716951561e+16*cos(theta)**9 + 1.28195947744903e+15*cos(theta)**7 - 13658624569472.2*cos(theta)**5 + 68705354977.2244*cos(theta)**3 - 103006529.201236*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl63_m5(theta, phi):
    return 4.37692159974244e-9*(1.0 - cos(theta)**2)**2.5*(5.51884460058665e+26*cos(theta)**58 - 7.29812009981579e+27*cos(theta)**56 + 4.56874185110419e+28*cos(theta)**54 - 1.80106600246008e+29*cos(theta)**52 + 5.01725529256738e+29*cos(theta)**50 - 1.05062183476838e+30*cos(theta)**48 + 1.71753830379527e+30*cos(theta)**46 - 2.24734784377763e+30*cos(theta)**44 + 2.39413407681716e+30*cos(theta)**42 - 2.10127363928601e+30*cos(theta)**40 + 1.53176956882531e+30*cos(theta)**38 - 9.32323815484151e+29*cos(theta)**36 + 4.75213595271048e+29*cos(theta)**34 - 2.03042518619237e+29*cos(theta)**32 + 7.26616805448351e+28*cos(theta)**30 - 2.17235952144352e+28*cos(theta)**28 + 5.40231512569508e+27*cos(theta)**26 - 1.11053283735035e+27*cos(theta)**24 + 1.87122749150608e+26*cos(theta)**22 - 2.55620077195686e+25*cos(theta)**20 + 2.79125371650461e+24*cos(theta)**18 - 2.39250318557538e+23*cos(theta)**16 + 1.57229125010431e+22*cos(theta)**14 - 7.68000556948426e+20*cos(theta)**12 + 2.67341966026351e+19*cos(theta)**10 - 6.24955245256404e+17*cos(theta)**8 + 8.97371634214324e+15*cos(theta)**6 - 68293122847361.1*cos(theta)**4 + 206116064931.673*cos(theta)**2 - 103006529.201236)*cos(5*phi)

#@torch.jit.script
def Yl63_m6(theta, phi):
    return 6.91879121594119e-11*(1.0 - cos(theta)**2)**3*(3.20092986834026e+28*cos(theta)**57 - 4.08694725589684e+29*cos(theta)**55 + 2.46712059959626e+30*cos(theta)**53 - 9.36554321279243e+30*cos(theta)**51 + 2.50862764628369e+31*cos(theta)**49 - 5.04298480688823e+31*cos(theta)**47 + 7.90067619745823e+31*cos(theta)**45 - 9.88833051262155e+31*cos(theta)**43 + 1.00553631226321e+32*cos(theta)**41 - 8.40509455714402e+31*cos(theta)**39 + 5.82072436153619e+31*cos(theta)**37 - 3.35636573574294e+31*cos(theta)**35 + 1.61572622392156e+31*cos(theta)**33 - 6.49736059581558e+30*cos(theta)**31 + 2.17985041634505e+30*cos(theta)**29 - 6.08260666004186e+29*cos(theta)**27 + 1.40460193268072e+29*cos(theta)**25 - 2.66527880964084e+28*cos(theta)**23 + 4.11670048131338e+27*cos(theta)**21 - 5.11240154391372e+26*cos(theta)**19 + 5.02425668970831e+25*cos(theta)**17 - 3.82800509692061e+24*cos(theta)**15 + 2.20120775014603e+23*cos(theta)**13 - 9.21600668338111e+21*cos(theta)**11 + 2.67341966026351e+20*cos(theta)**9 - 4.99964196205124e+18*cos(theta)**7 + 5.38422980528595e+16*cos(theta)**5 - 273172491389444.0*cos(theta)**3 + 412232129863.346*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl63_m7(theta, phi):
    return 1.09532696037299e-12*(1.0 - cos(theta)**2)**3.5*(1.82453002495395e+30*cos(theta)**56 - 2.24782099074326e+31*cos(theta)**54 + 1.30757391778602e+32*cos(theta)**52 - 4.77642703852414e+32*cos(theta)**50 + 1.22922754667901e+33*cos(theta)**48 - 2.37020285923747e+33*cos(theta)**46 + 3.5553042888562e+33*cos(theta)**44 - 4.25198212042727e+33*cos(theta)**42 + 4.12269888027914e+33*cos(theta)**40 - 3.27798687728617e+33*cos(theta)**38 + 2.15366801376839e+33*cos(theta)**36 - 1.17472800751003e+33*cos(theta)**34 + 5.33189653894116e+32*cos(theta)**32 - 2.01418178470283e+32*cos(theta)**30 + 6.32156620740065e+31*cos(theta)**28 - 1.6423037982113e+31*cos(theta)**26 + 3.5115048317018e+30*cos(theta)**24 - 6.13014126217392e+29*cos(theta)**22 + 8.64507101075809e+28*cos(theta)**20 - 9.71356293343606e+27*cos(theta)**18 + 8.54123637250412e+26*cos(theta)**16 - 5.74200764538092e+25*cos(theta)**14 + 2.86157007518983e+24*cos(theta)**12 - 1.01376073517192e+23*cos(theta)**10 + 2.40607769423716e+21*cos(theta)**8 - 3.49974937343587e+19*cos(theta)**6 + 2.69211490264297e+17*cos(theta)**4 - 819517474168333.0*cos(theta)**2 + 412232129863.346)*cos(7*phi)

#@torch.jit.script
def Yl63_m8(theta, phi):
    return 1.73708307833159e-14*(1.0 - cos(theta)**2)**4*(1.02173681397421e+32*cos(theta)**55 - 1.21382333500136e+33*cos(theta)**53 + 6.79938437248731e+33*cos(theta)**51 - 2.38821351926207e+34*cos(theta)**49 + 5.90029222405923e+34*cos(theta)**47 - 1.09029331524924e+35*cos(theta)**45 + 1.56433388709673e+35*cos(theta)**43 - 1.78583249057945e+35*cos(theta)**41 + 1.64907955211166e+35*cos(theta)**39 - 1.24563501336874e+35*cos(theta)**37 + 7.7532048495662e+34*cos(theta)**35 - 3.9940752255341e+34*cos(theta)**33 + 1.70620689246117e+34*cos(theta)**31 - 6.04254535410849e+33*cos(theta)**29 + 1.77003853807218e+33*cos(theta)**27 - 4.26998987534939e+32*cos(theta)**25 + 8.42761159608432e+31*cos(theta)**23 - 1.34863107767826e+31*cos(theta)**21 + 1.72901420215162e+30*cos(theta)**19 - 1.74844132801849e+29*cos(theta)**17 + 1.36659781960066e+28*cos(theta)**15 - 8.03881070353329e+26*cos(theta)**13 + 3.4338840902278e+25*cos(theta)**11 - 1.01376073517192e+24*cos(theta)**9 + 1.92486215538973e+22*cos(theta)**7 - 2.09984962406152e+20*cos(theta)**5 + 1.07684596105719e+18*cos(theta)**3 - 1.63903494833667e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl63_m9(theta, phi):
    return 2.76040621600124e-16*(1.0 - cos(theta)**2)**4.5*(5.61955247685816e+33*cos(theta)**54 - 6.43326367550722e+34*cos(theta)**52 + 3.46768602996853e+35*cos(theta)**50 - 1.17022462443841e+36*cos(theta)**48 + 2.77313734530784e+36*cos(theta)**46 - 4.90631991862156e+36*cos(theta)**44 + 6.72663571451594e+36*cos(theta)**42 - 7.32191321137576e+36*cos(theta)**40 + 6.43141025323546e+36*cos(theta)**38 - 4.60884954946435e+36*cos(theta)**36 + 2.71362169734817e+36*cos(theta)**34 - 1.31804482442625e+36*cos(theta)**32 + 5.28924136662963e+35*cos(theta)**30 - 1.75233815269146e+35*cos(theta)**28 + 4.77910405279489e+34*cos(theta)**26 - 1.06749746883735e+34*cos(theta)**24 + 1.93835066709939e+33*cos(theta)**22 - 2.83212526312435e+32*cos(theta)**20 + 3.28512698408808e+31*cos(theta)**18 - 2.97235025763143e+30*cos(theta)**16 + 2.04989672940099e+29*cos(theta)**14 - 1.04504539145933e+28*cos(theta)**12 + 3.77727249925058e+26*cos(theta)**10 - 9.1238466165473e+24*cos(theta)**8 + 1.34740350877281e+23*cos(theta)**6 - 1.04992481203076e+21*cos(theta)**4 + 3.23053788317157e+18*cos(theta)**2 - 1.63903494833667e+15)*cos(9*phi)

#@torch.jit.script
def Yl63_m10(theta, phi):
    return 4.396577031332e-18*(1.0 - cos(theta)**2)**5*(3.03455833750341e+35*cos(theta)**53 - 3.34529711126375e+36*cos(theta)**51 + 1.73384301498426e+37*cos(theta)**49 - 5.61707819730439e+37*cos(theta)**47 + 1.27564317884161e+38*cos(theta)**45 - 2.15878076419349e+38*cos(theta)**43 + 2.82518700009669e+38*cos(theta)**41 - 2.9287652845503e+38*cos(theta)**39 + 2.44393589622948e+38*cos(theta)**37 - 1.65918583780717e+38*cos(theta)**35 + 9.22631377098378e+37*cos(theta)**33 - 4.21774343816401e+37*cos(theta)**31 + 1.58677240998889e+37*cos(theta)**29 - 4.90654682753609e+36*cos(theta)**27 + 1.24256705372667e+36*cos(theta)**25 - 2.56199392520963e+35*cos(theta)**23 + 4.26437146761867e+34*cos(theta)**21 - 5.6642505262487e+33*cos(theta)**19 + 5.91322857135854e+32*cos(theta)**17 - 4.7557604122103e+31*cos(theta)**15 + 2.86985542116138e+30*cos(theta)**13 - 1.25405446975119e+29*cos(theta)**11 + 3.77727249925058e+27*cos(theta)**9 - 7.29907729323784e+25*cos(theta)**7 + 8.08442105263685e+23*cos(theta)**5 - 4.19969924812304e+21*cos(theta)**3 + 6.46107576634314e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl63_m11(theta, phi):
    return 7.02038439282633e-20*(1.0 - cos(theta)**2)**5.5*(1.60831591887681e+37*cos(theta)**52 - 1.70610152674451e+38*cos(theta)**50 + 8.49583077342289e+38*cos(theta)**48 - 2.64002675273306e+39*cos(theta)**46 + 5.74039430478723e+39*cos(theta)**44 - 9.282757286032e+39*cos(theta)**42 + 1.15832667003964e+40*cos(theta)**40 - 1.14221846097462e+40*cos(theta)**38 + 9.04256281604906e+39*cos(theta)**36 - 5.80715043232508e+39*cos(theta)**34 + 3.04468354442465e+39*cos(theta)**32 - 1.30750046583084e+39*cos(theta)**30 + 4.60163998896778e+38*cos(theta)**28 - 1.32476764343474e+38*cos(theta)**26 + 3.10641763431668e+37*cos(theta)**24 - 5.89258602798216e+36*cos(theta)**22 + 8.9551800819992e+35*cos(theta)**20 - 1.07620759998725e+35*cos(theta)**18 + 1.00524885713095e+34*cos(theta)**16 - 7.13364061831544e+32*cos(theta)**14 + 3.7308120475098e+31*cos(theta)**12 - 1.37945991672631e+30*cos(theta)**10 + 3.39954524932552e+28*cos(theta)**8 - 5.10935410526649e+26*cos(theta)**6 + 4.04221052631842e+24*cos(theta)**4 - 1.25990977443691e+22*cos(theta)**2 + 6.46107576634314e+18)*cos(11*phi)

#@torch.jit.script
def Yl63_m12(theta, phi):
    return 1.12416119182533e-21*(1.0 - cos(theta)**2)**6*(8.36324277815939e+38*cos(theta)**51 - 8.53050763372257e+39*cos(theta)**49 + 4.07799877124299e+40*cos(theta)**47 - 1.21441230625721e+41*cos(theta)**45 + 2.52577349410638e+41*cos(theta)**43 - 3.89875806013344e+41*cos(theta)**41 + 4.63330668015858e+41*cos(theta)**39 - 4.34043015170355e+41*cos(theta)**37 + 3.25532261377766e+41*cos(theta)**35 - 1.97443114699053e+41*cos(theta)**33 + 9.74298734215887e+40*cos(theta)**31 - 3.92250139749253e+40*cos(theta)**29 + 1.28845919691098e+40*cos(theta)**27 - 3.44439587293034e+39*cos(theta)**25 + 7.45540232236003e+38*cos(theta)**23 - 1.29636892615607e+38*cos(theta)**21 + 1.79103601639984e+37*cos(theta)**19 - 1.93717367997706e+36*cos(theta)**17 + 1.60839817140952e+35*cos(theta)**15 - 9.98709686564162e+33*cos(theta)**13 + 4.47697445701176e+32*cos(theta)**11 - 1.37945991672631e+31*cos(theta)**9 + 2.71963619946042e+29*cos(theta)**7 - 3.06561246315989e+27*cos(theta)**5 + 1.61688421052737e+25*cos(theta)**3 - 2.51981954887382e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl63_m13(theta, phi):
    return 1.80566302240486e-23*(1.0 - cos(theta)**2)**6.5*(4.26525381686129e+40*cos(theta)**50 - 4.17994874052406e+41*cos(theta)**48 + 1.9166594224842e+42*cos(theta)**46 - 5.46485537815744e+42*cos(theta)**44 + 1.08608260246574e+43*cos(theta)**42 - 1.59849080465471e+43*cos(theta)**40 + 1.80698960526185e+43*cos(theta)**38 - 1.60595915613031e+43*cos(theta)**36 + 1.13936291482218e+43*cos(theta)**34 - 6.51562278506874e+42*cos(theta)**32 + 3.02032607606925e+42*cos(theta)**30 - 1.13752540527283e+42*cos(theta)**28 + 3.47883983165964e+41*cos(theta)**26 - 8.61098968232584e+40*cos(theta)**24 + 1.71474253414281e+40*cos(theta)**22 - 2.72237474492776e+39*cos(theta)**20 + 3.4029684311597e+38*cos(theta)**18 - 3.293195255961e+37*cos(theta)**16 + 2.41259725711428e+36*cos(theta)**14 - 1.29832259253341e+35*cos(theta)**12 + 4.92467190271294e+33*cos(theta)**10 - 1.24151392505368e+32*cos(theta)**8 + 1.90374533962229e+30*cos(theta)**6 - 1.53280623157995e+28*cos(theta)**4 + 4.85065263158211e+25*cos(theta)**2 - 2.51981954887382e+22)*cos(13*phi)

#@torch.jit.script
def Yl63_m14(theta, phi):
    return 2.91008945749061e-25*(1.0 - cos(theta)**2)**7*(2.13262690843064e+42*cos(theta)**49 - 2.00637539545155e+43*cos(theta)**47 + 8.81663334342734e+43*cos(theta)**45 - 2.40453636638927e+44*cos(theta)**43 + 4.56154693035612e+44*cos(theta)**41 - 6.39396321861884e+44*cos(theta)**39 + 6.86656049999501e+44*cos(theta)**37 - 5.78145296206913e+44*cos(theta)**35 + 3.87383391039542e+44*cos(theta)**33 - 2.084999291222e+44*cos(theta)**31 + 9.06097822820775e+43*cos(theta)**29 - 3.18507113476394e+43*cos(theta)**27 + 9.04498356231506e+42*cos(theta)**25 - 2.0666375237582e+42*cos(theta)**23 + 3.77243357511418e+41*cos(theta)**21 - 5.44474948985551e+40*cos(theta)**19 + 6.12534317608745e+39*cos(theta)**17 - 5.26911240953759e+38*cos(theta)**15 + 3.37763615996e+37*cos(theta)**13 - 1.55798711104009e+36*cos(theta)**11 + 4.92467190271294e+34*cos(theta)**9 - 9.93211140042945e+32*cos(theta)**7 + 1.14224720377338e+31*cos(theta)**5 - 6.13122492631979e+28*cos(theta)**3 + 9.70130526316422e+25*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl63_m15(theta, phi):
    return 4.70718208574704e-27*(1.0 - cos(theta)**2)**7.5*(1.04498718513102e+44*cos(theta)**48 - 9.42996435862228e+44*cos(theta)**46 + 3.9674850045423e+45*cos(theta)**44 - 1.03395063754739e+46*cos(theta)**42 + 1.87023424144601e+46*cos(theta)**40 - 2.49364565526135e+46*cos(theta)**38 + 2.54062738499815e+46*cos(theta)**36 - 2.02350853672419e+46*cos(theta)**34 + 1.27836519043049e+46*cos(theta)**32 - 6.46349780278819e+45*cos(theta)**30 + 2.62768368618025e+45*cos(theta)**28 - 8.59969206386263e+44*cos(theta)**26 + 2.26124589057877e+44*cos(theta)**24 - 4.75326630464386e+43*cos(theta)**22 + 7.92211050773977e+42*cos(theta)**20 - 1.03450240307255e+42*cos(theta)**18 + 1.04130833993487e+41*cos(theta)**16 - 7.90366861430639e+39*cos(theta)**14 + 4.39092700794799e+38*cos(theta)**12 - 1.7137858221441e+37*cos(theta)**10 + 4.43220471244164e+35*cos(theta)**8 - 6.95247798030062e+33*cos(theta)**6 + 5.71123601886688e+31*cos(theta)**4 - 1.83936747789594e+29*cos(theta)**2 + 9.70130526316422e+25)*cos(15*phi)

#@torch.jit.script
def Yl63_m16(theta, phi):
    return 7.64410834397408e-29*(1.0 - cos(theta)**2)**8*(5.01593848862887e+45*cos(theta)**47 - 4.33778360496625e+46*cos(theta)**45 + 1.74569340199861e+47*cos(theta)**43 - 4.34259267769903e+47*cos(theta)**41 + 7.48093696578404e+47*cos(theta)**39 - 9.47585348999312e+47*cos(theta)**37 + 9.14625858599336e+47*cos(theta)**35 - 6.87992902486226e+47*cos(theta)**33 + 4.09076860937756e+47*cos(theta)**31 - 1.93904934083646e+47*cos(theta)**29 + 7.35751432130469e+46*cos(theta)**27 - 2.23591993660428e+46*cos(theta)**25 + 5.42699013738904e+45*cos(theta)**23 - 1.04571858702165e+45*cos(theta)**21 + 1.58442210154795e+44*cos(theta)**19 - 1.86210432553059e+43*cos(theta)**17 + 1.66609334389579e+42*cos(theta)**15 - 1.10651360600289e+41*cos(theta)**13 + 5.26911240953759e+39*cos(theta)**11 - 1.7137858221441e+38*cos(theta)**9 + 3.54576376995331e+36*cos(theta)**7 - 4.17148678818037e+34*cos(theta)**5 + 2.28449440754675e+32*cos(theta)**3 - 3.67873495579187e+29*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl63_m17(theta, phi):
    return 1.24661661655909e-30*(1.0 - cos(theta)**2)**8.5*(2.35749108965557e+47*cos(theta)**46 - 1.95200262223481e+48*cos(theta)**44 + 7.50648162859404e+48*cos(theta)**42 - 1.7804629978566e+49*cos(theta)**40 + 2.91756541665578e+49*cos(theta)**38 - 3.50606579129745e+49*cos(theta)**36 + 3.20119050509768e+49*cos(theta)**34 - 2.27037657820455e+49*cos(theta)**32 + 1.26813826890704e+49*cos(theta)**30 - 5.62324308842573e+48*cos(theta)**28 + 1.98652886675227e+48*cos(theta)**26 - 5.58979984151071e+47*cos(theta)**24 + 1.24820773159948e+47*cos(theta)**22 - 2.19600903274546e+46*cos(theta)**20 + 3.01040199294111e+45*cos(theta)**18 - 3.165577353402e+44*cos(theta)**16 + 2.49914001584368e+43*cos(theta)**14 - 1.43846768780376e+42*cos(theta)**12 + 5.79602365049135e+40*cos(theta)**10 - 1.54240723992969e+39*cos(theta)**8 + 2.48203463896732e+37*cos(theta)**6 - 2.08574339409018e+35*cos(theta)**4 + 6.85348322264026e+32*cos(theta)**2 - 3.67873495579187e+29)*cos(17*phi)

#@torch.jit.script
def Yl63_m18(theta, phi):
    return 2.04226213911857e-32*(1.0 - cos(theta)**2)**9*(1.08444590124156e+49*cos(theta)**45 - 8.58881153783317e+49*cos(theta)**43 + 3.15272228400949e+50*cos(theta)**41 - 7.12185199142641e+50*cos(theta)**39 + 1.10867485832919e+51*cos(theta)**37 - 1.26218368486708e+51*cos(theta)**35 + 1.08840477173321e+51*cos(theta)**33 - 7.26520505025455e+50*cos(theta)**31 + 3.80441480672113e+50*cos(theta)**29 - 1.5745080647592e+50*cos(theta)**27 + 5.16497505355589e+49*cos(theta)**25 - 1.34155196196257e+49*cos(theta)**23 + 2.74605700951885e+48*cos(theta)**21 - 4.39201806549093e+47*cos(theta)**19 + 5.418723587294e+46*cos(theta)**17 - 5.06492376544319e+45*cos(theta)**15 + 3.49879602218115e+44*cos(theta)**13 - 1.72616122536452e+43*cos(theta)**11 + 5.79602365049135e+41*cos(theta)**9 - 1.23392579194375e+40*cos(theta)**7 + 1.48922078338039e+38*cos(theta)**5 - 8.34297357636074e+35*cos(theta)**3 + 1.37069664452805e+33*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl63_m19(theta, phi):
    return 3.36200459820719e-34*(1.0 - cos(theta)**2)**9.5*(4.88000655558703e+50*cos(theta)**44 - 3.69318896126827e+51*cos(theta)**42 + 1.29261613644389e+52*cos(theta)**40 - 2.7775222766563e+52*cos(theta)**38 + 4.10209697581802e+52*cos(theta)**36 - 4.41764289703479e+52*cos(theta)**34 + 3.59173574671959e+52*cos(theta)**32 - 2.25221356557891e+52*cos(theta)**30 + 1.10328029394913e+52*cos(theta)**28 - 4.25117177484985e+51*cos(theta)**26 + 1.29124376338897e+51*cos(theta)**24 - 3.08556951251391e+50*cos(theta)**22 + 5.76671971998959e+49*cos(theta)**20 - 8.34483432443277e+48*cos(theta)**18 + 9.21183009839981e+47*cos(theta)**16 - 7.59738564816479e+46*cos(theta)**14 + 4.5484348288355e+45*cos(theta)**12 - 1.89877734790097e+44*cos(theta)**10 + 5.21642128544222e+42*cos(theta)**8 - 8.63748054360627e+40*cos(theta)**6 + 7.44610391690196e+38*cos(theta)**4 - 2.50289207290822e+36*cos(theta)**2 + 1.37069664452805e+33)*cos(19*phi)

#@torch.jit.script
def Yl63_m20(theta, phi):
    return 5.56330562138451e-36*(1.0 - cos(theta)**2)**10*(2.14720288445829e+52*cos(theta)**43 - 1.55113936373267e+53*cos(theta)**41 + 5.17046454577557e+53*cos(theta)**39 - 1.05545846512939e+54*cos(theta)**37 + 1.47675491129449e+54*cos(theta)**35 - 1.50199858499183e+54*cos(theta)**33 + 1.14935543895027e+54*cos(theta)**31 - 6.75664069673673e+53*cos(theta)**29 + 3.08918482305756e+53*cos(theta)**27 - 1.10530466146096e+53*cos(theta)**25 + 3.09898503213354e+52*cos(theta)**23 - 6.7882529275306e+51*cos(theta)**21 + 1.15334394399792e+51*cos(theta)**19 - 1.5020701783979e+50*cos(theta)**17 + 1.47389281574397e+49*cos(theta)**15 - 1.06363399074307e+48*cos(theta)**13 + 5.4581217946026e+46*cos(theta)**11 - 1.89877734790097e+45*cos(theta)**9 + 4.17313702835377e+43*cos(theta)**7 - 5.18248832616376e+41*cos(theta)**5 + 2.97844156676078e+39*cos(theta)**3 - 5.00578414581644e+36*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl63_m21(theta, phi):
    return 9.25676093597681e-38*(1.0 - cos(theta)**2)**10.5*(9.23297240317066e+53*cos(theta)**42 - 6.35967139130395e+54*cos(theta)**40 + 2.01648117285247e+55*cos(theta)**38 - 3.90519632097876e+55*cos(theta)**36 + 5.16864218953071e+55*cos(theta)**34 - 4.95659533047304e+55*cos(theta)**32 + 3.56300186074583e+55*cos(theta)**30 - 1.95942580205365e+55*cos(theta)**28 + 8.34079902225541e+54*cos(theta)**26 - 2.7632616536524e+54*cos(theta)**24 + 7.12766557390713e+53*cos(theta)**22 - 1.42553311478143e+53*cos(theta)**20 + 2.19135349359604e+52*cos(theta)**18 - 2.55351930327643e+51*cos(theta)**16 + 2.21083922361595e+50*cos(theta)**14 - 1.38272418796599e+49*cos(theta)**12 + 6.00393397406286e+47*cos(theta)**10 - 1.70889961311087e+46*cos(theta)**8 + 2.92119591984764e+44*cos(theta)**6 - 2.59124416308188e+42*cos(theta)**4 + 8.93532470028235e+39*cos(theta)**2 - 5.00578414581644e+36)*cos(21*phi)

#@torch.jit.script
def Yl63_m22(theta, phi):
    return 1.54926225350494e-39*(1.0 - cos(theta)**2)**11*(3.87784840933168e+55*cos(theta)**41 - 2.54386855652158e+56*cos(theta)**39 + 7.6626284568394e+56*cos(theta)**37 - 1.40587067555235e+57*cos(theta)**35 + 1.75733834444044e+57*cos(theta)**33 - 1.58611050575137e+57*cos(theta)**31 + 1.06890055822375e+57*cos(theta)**29 - 5.48639224575022e+56*cos(theta)**27 + 2.16860774578641e+56*cos(theta)**25 - 6.63182796876577e+55*cos(theta)**23 + 1.56808642625957e+55*cos(theta)**21 - 2.85106622956285e+54*cos(theta)**19 + 3.94443628847288e+53*cos(theta)**17 - 4.08563088524228e+52*cos(theta)**15 + 3.09517491306233e+51*cos(theta)**13 - 1.65926902555919e+50*cos(theta)**11 + 6.00393397406286e+48*cos(theta)**9 - 1.3671196904887e+47*cos(theta)**7 + 1.75271755190858e+45*cos(theta)**5 - 1.03649766523275e+43*cos(theta)**3 + 1.78706494005647e+40*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl63_m23(theta, phi):
    return 2.60905831309973e-41*(1.0 - cos(theta)**2)**11.5*(1.58991784782599e+57*cos(theta)**40 - 9.92108737043417e+57*cos(theta)**38 + 2.83517252903058e+58*cos(theta)**36 - 4.92054736443323e+58*cos(theta)**34 + 5.79921653665345e+58*cos(theta)**32 - 4.91694256782925e+58*cos(theta)**30 + 3.09981161884888e+58*cos(theta)**28 - 1.48132590635256e+58*cos(theta)**26 + 5.42151936446602e+57*cos(theta)**24 - 1.52532043281613e+57*cos(theta)**22 + 3.2929814951451e+56*cos(theta)**20 - 5.41702583616942e+55*cos(theta)**18 + 6.7055416904039e+54*cos(theta)**16 - 6.12844632786342e+53*cos(theta)**14 + 4.02372738698104e+52*cos(theta)**12 - 1.82519592811511e+51*cos(theta)**10 + 5.40354057665657e+49*cos(theta)**8 - 9.56983783342087e+47*cos(theta)**6 + 8.76358775954292e+45*cos(theta)**4 - 3.10949299569826e+43*cos(theta)**2 + 1.78706494005647e+40)*cos(23*phi)

#@torch.jit.script
def Yl63_m24(theta, phi):
    return 4.42276805232852e-43*(1.0 - cos(theta)**2)**12*(6.35967139130395e+58*cos(theta)**39 - 3.77001320076498e+59*cos(theta)**37 + 1.02066211045101e+60*cos(theta)**35 - 1.6729861039073e+60*cos(theta)**33 + 1.8557492917291e+60*cos(theta)**31 - 1.47508277034878e+60*cos(theta)**29 + 8.67947253277685e+59*cos(theta)**27 - 3.85144735651666e+59*cos(theta)**25 + 1.30116464747184e+59*cos(theta)**23 - 3.35570495219548e+58*cos(theta)**21 + 6.58596299029019e+57*cos(theta)**19 - 9.75064650510496e+56*cos(theta)**17 + 1.07288667046462e+56*cos(theta)**15 - 8.57982485900879e+54*cos(theta)**13 + 4.82847286437724e+53*cos(theta)**11 - 1.82519592811511e+52*cos(theta)**9 + 4.32283246132526e+50*cos(theta)**7 - 5.74190270005252e+48*cos(theta)**5 + 3.50543510381717e+46*cos(theta)**3 - 6.21898599139652e+43*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl63_m25(theta, phi):
    return 7.54954058650599e-45*(1.0 - cos(theta)**2)**12.5*(2.48027184260854e+60*cos(theta)**38 - 1.39490488428304e+61*cos(theta)**36 + 3.57231738657853e+61*cos(theta)**34 - 5.52085414289409e+61*cos(theta)**32 + 5.75282280436023e+61*cos(theta)**30 - 4.27774003401145e+61*cos(theta)**28 + 2.34345758384975e+61*cos(theta)**26 - 9.62861839129164e+60*cos(theta)**24 + 2.99267868918524e+60*cos(theta)**22 - 7.0469803996105e+59*cos(theta)**20 + 1.25133296815514e+59*cos(theta)**18 - 1.65760990586784e+58*cos(theta)**16 + 1.60933000569693e+57*cos(theta)**14 - 1.11537723167114e+56*cos(theta)**12 + 5.31132015081497e+54*cos(theta)**10 - 1.6426763353036e+53*cos(theta)**8 + 3.02598272292768e+51*cos(theta)**6 - 2.87095135002626e+49*cos(theta)**4 + 1.05163053114515e+47*cos(theta)**2 - 6.21898599139652e+43)*cos(25*phi)

#@torch.jit.script
def Yl63_m26(theta, phi):
    return 1.29817643864673e-46*(1.0 - cos(theta)**2)**13*(9.42503300191246e+61*cos(theta)**37 - 5.02165758341896e+62*cos(theta)**35 + 1.2145879114367e+63*cos(theta)**33 - 1.76667332572611e+63*cos(theta)**31 + 1.72584684130807e+63*cos(theta)**29 - 1.19776720952321e+63*cos(theta)**27 + 6.09298971800935e+62*cos(theta)**25 - 2.31086841390999e+62*cos(theta)**23 + 6.58389311620753e+61*cos(theta)**21 - 1.4093960799221e+61*cos(theta)**19 + 2.25239934267925e+60*cos(theta)**17 - 2.65217584938855e+59*cos(theta)**15 + 2.25306200797571e+58*cos(theta)**13 - 1.33845267800537e+57*cos(theta)**11 + 5.31132015081497e+55*cos(theta)**9 - 1.31414106824288e+54*cos(theta)**7 + 1.81558963375661e+52*cos(theta)**5 - 1.1483805400105e+50*cos(theta)**3 + 2.1032610622903e+47*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl63_m27(theta, phi):
    return 2.24963264659303e-48*(1.0 - cos(theta)**2)**13.5*(3.48726221070761e+63*cos(theta)**36 - 1.75758015419664e+64*cos(theta)**34 + 4.00814010774111e+64*cos(theta)**32 - 5.47668730975093e+64*cos(theta)**30 + 5.0049558397934e+64*cos(theta)**28 - 3.23397146571266e+64*cos(theta)**26 + 1.52324742950234e+64*cos(theta)**24 - 5.31499735199299e+63*cos(theta)**22 + 1.38261755440358e+63*cos(theta)**20 - 2.67785255185199e+62*cos(theta)**18 + 3.82907888255472e+61*cos(theta)**16 - 3.97826377408282e+60*cos(theta)**14 + 2.92898061036842e+59*cos(theta)**12 - 1.47229794580591e+58*cos(theta)**10 + 4.78018813573347e+56*cos(theta)**8 - 9.19898747770015e+54*cos(theta)**6 + 9.07794816878304e+52*cos(theta)**4 - 3.44514162003151e+50*cos(theta)**2 + 2.1032610622903e+47)*cos(27*phi)

#@torch.jit.script
def Yl63_m28(theta, phi):
    return 3.93042631936345e-50*(1.0 - cos(theta)**2)**14*(1.25541439585474e+65*cos(theta)**35 - 5.97577252426856e+65*cos(theta)**33 + 1.28260483447715e+66*cos(theta)**31 - 1.64300619292528e+66*cos(theta)**29 + 1.40138763514215e+66*cos(theta)**27 - 8.4083258108529e+65*cos(theta)**25 + 3.65579383080561e+65*cos(theta)**23 - 1.16929941743846e+65*cos(theta)**21 + 2.76523510880716e+64*cos(theta)**19 - 4.82013459333359e+63*cos(theta)**17 + 6.12652621208755e+62*cos(theta)**15 - 5.56956928371595e+61*cos(theta)**13 + 3.51477673244211e+60*cos(theta)**11 - 1.47229794580591e+59*cos(theta)**9 + 3.82415050858678e+57*cos(theta)**7 - 5.51939248662009e+55*cos(theta)**5 + 3.63117926751322e+53*cos(theta)**3 - 6.89028324006303e+50*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl63_m29(theta, phi):
    return 6.92646626671411e-52*(1.0 - cos(theta)**2)**14.5*(4.39395038549159e+66*cos(theta)**34 - 1.97200493300862e+67*cos(theta)**32 + 3.97607498687918e+67*cos(theta)**30 - 4.76471795948331e+67*cos(theta)**28 + 3.78374661488381e+67*cos(theta)**26 - 2.10208145271323e+67*cos(theta)**24 + 8.40832581085291e+66*cos(theta)**22 - 2.45552877662076e+66*cos(theta)**20 + 5.25394670673361e+65*cos(theta)**18 - 8.19422880866709e+64*cos(theta)**16 + 9.18978931813132e+63*cos(theta)**14 - 7.24044006883074e+62*cos(theta)**12 + 3.86625440568632e+61*cos(theta)**10 - 1.32506815122532e+60*cos(theta)**8 + 2.67690535601074e+58*cos(theta)**6 - 2.75969624331004e+56*cos(theta)**4 + 1.08935378025396e+54*cos(theta)**2 - 6.89028324006303e+50)*cos(29*phi)

#@torch.jit.script
def Yl63_m30(theta, phi):
    return 1.23177331305232e-53*(1.0 - cos(theta)**2)**15*(1.49394313106714e+68*cos(theta)**33 - 6.3104157856276e+68*cos(theta)**31 + 1.19282249606375e+69*cos(theta)**29 - 1.33412102865533e+69*cos(theta)**27 + 9.8377411986979e+68*cos(theta)**25 - 5.04499548651174e+68*cos(theta)**23 + 1.84983167838764e+68*cos(theta)**21 - 4.91105755324152e+67*cos(theta)**19 + 9.45710407212049e+66*cos(theta)**17 - 1.31107660938674e+66*cos(theta)**15 + 1.28657050453838e+65*cos(theta)**13 - 8.68852808259689e+63*cos(theta)**11 + 3.86625440568632e+62*cos(theta)**9 - 1.06005452098025e+61*cos(theta)**7 + 1.60614321360645e+59*cos(theta)**5 - 1.10387849732402e+57*cos(theta)**3 + 2.17870756050793e+54*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl63_m31(theta, phi):
    return 2.21161686942766e-55*(1.0 - cos(theta)**2)**15.5*(4.93001233252156e+69*cos(theta)**32 - 1.95622889354456e+70*cos(theta)**30 + 3.45918523858488e+70*cos(theta)**28 - 3.60212677736938e+70*cos(theta)**26 + 2.45943529967447e+70*cos(theta)**24 - 1.1603489618977e+70*cos(theta)**22 + 3.88464652461404e+69*cos(theta)**20 - 9.33100935115889e+68*cos(theta)**18 + 1.60770769226048e+68*cos(theta)**16 - 1.9666149140801e+67*cos(theta)**14 + 1.6725416558999e+66*cos(theta)**12 - 9.55738089085657e+64*cos(theta)**10 + 3.47962896511768e+63*cos(theta)**8 - 7.42038164686178e+61*cos(theta)**6 + 8.03071606803223e+59*cos(theta)**4 - 3.31163549197205e+57*cos(theta)**2 + 2.17870756050793e+54)*cos(31*phi)

#@torch.jit.script
def Yl63_m32(theta, phi):
    return 4.01118878278105e-57*(1.0 - cos(theta)**2)**16*(1.5776039464069e+71*cos(theta)**31 - 5.86868668063367e+71*cos(theta)**29 + 9.68571866803768e+71*cos(theta)**27 - 9.3655296211604e+71*cos(theta)**25 + 5.90264471921874e+71*cos(theta)**23 - 2.55276771617494e+71*cos(theta)**21 + 7.76929304922808e+70*cos(theta)**19 - 1.6795816832086e+70*cos(theta)**17 + 2.57233230761677e+69*cos(theta)**15 - 2.75326087971214e+68*cos(theta)**13 + 2.00704998707988e+67*cos(theta)**11 - 9.55738089085657e+65*cos(theta)**9 + 2.78370317209415e+64*cos(theta)**7 - 4.45222898811707e+62*cos(theta)**5 + 3.21228642721289e+60*cos(theta)**3 - 6.62327098394411e+57*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl63_m33(theta, phi):
    return 7.35286578501069e-59*(1.0 - cos(theta)**2)**16.5*(4.89057223386139e+72*cos(theta)**30 - 1.70191913738376e+73*cos(theta)**28 + 2.61514404037017e+73*cos(theta)**26 - 2.3413824052901e+73*cos(theta)**24 + 1.35760828542031e+73*cos(theta)**22 - 5.36081220396738e+72*cos(theta)**20 + 1.47616567935334e+72*cos(theta)**18 - 2.85528886145462e+71*cos(theta)**16 + 3.85849846142516e+70*cos(theta)**14 - 3.57923914362579e+69*cos(theta)**12 + 2.20775498578787e+68*cos(theta)**10 - 8.60164280177092e+66*cos(theta)**8 + 1.9485922204659e+65*cos(theta)**6 - 2.22611449405853e+63*cos(theta)**4 + 9.63685928163868e+60*cos(theta)**2 - 6.62327098394411e+57)*cos(33*phi)

#@torch.jit.script
def Yl63_m34(theta, phi):
    return 1.36304484364465e-60*(1.0 - cos(theta)**2)**17*(1.46717167015842e+74*cos(theta)**29 - 4.76537358467454e+74*cos(theta)**27 + 6.79937450496245e+74*cos(theta)**25 - 5.61931777269624e+74*cos(theta)**23 + 2.98673822792468e+74*cos(theta)**21 - 1.07216244079348e+74*cos(theta)**19 + 2.657098222836e+73*cos(theta)**17 - 4.56846217832739e+72*cos(theta)**15 + 5.40189784599523e+71*cos(theta)**13 - 4.29508697235094e+70*cos(theta)**11 + 2.20775498578787e+69*cos(theta)**9 - 6.88131424141673e+67*cos(theta)**7 + 1.16915533227954e+66*cos(theta)**5 - 8.90445797623414e+63*cos(theta)**3 + 1.92737185632774e+61*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl63_m35(theta, phi):
    return 2.55680794638311e-62*(1.0 - cos(theta)**2)**17.5*(4.25479784345941e+75*cos(theta)**28 - 1.28665086786213e+76*cos(theta)**26 + 1.69984362624061e+76*cos(theta)**24 - 1.29244308772014e+76*cos(theta)**22 + 6.27215027864183e+75*cos(theta)**20 - 2.0371086375076e+75*cos(theta)**18 + 4.51706697882121e+74*cos(theta)**16 - 6.85269326749109e+73*cos(theta)**14 + 7.02246719979379e+72*cos(theta)**12 - 4.72459566958604e+71*cos(theta)**10 + 1.98697948720908e+70*cos(theta)**8 - 4.81691996899171e+68*cos(theta)**6 + 5.84577666139771e+66*cos(theta)**4 - 2.67133739287024e+64*cos(theta)**2 + 1.92737185632774e+61)*cos(35*phi)

#@torch.jit.script
def Yl63_m36(theta, phi):
    return 4.85625512444004e-64*(1.0 - cos(theta)**2)**18*(1.19134339616863e+77*cos(theta)**27 - 3.34529225644153e+77*cos(theta)**25 + 4.07962470297747e+77*cos(theta)**23 - 2.8433747929843e+77*cos(theta)**21 + 1.25443005572837e+77*cos(theta)**19 - 3.66679554751369e+76*cos(theta)**17 + 7.22730716611393e+75*cos(theta)**15 - 9.59377057448752e+74*cos(theta)**13 + 8.42696063975255e+73*cos(theta)**11 - 4.72459566958604e+72*cos(theta)**9 + 1.58958358976727e+71*cos(theta)**7 - 2.89015198139503e+69*cos(theta)**5 + 2.33831066455908e+67*cos(theta)**3 - 5.34267478574048e+64*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl63_m37(theta, phi):
    return 9.34586734449653e-66*(1.0 - cos(theta)**2)**18.5*(3.21662716965531e+78*cos(theta)**26 - 8.36323064110381e+78*cos(theta)**24 + 9.38313681684818e+78*cos(theta)**22 - 5.97108706526702e+78*cos(theta)**20 + 2.3834171058839e+78*cos(theta)**18 - 6.23355243077327e+77*cos(theta)**16 + 1.08409607491709e+77*cos(theta)**14 - 1.24719017468338e+76*cos(theta)**12 + 9.26965670372781e+74*cos(theta)**10 - 4.25213610262743e+73*cos(theta)**8 + 1.11270851283709e+72*cos(theta)**6 - 1.44507599069751e+70*cos(theta)**4 + 7.01493199367725e+67*cos(theta)**2 - 5.34267478574048e+64)*cos(37*phi)

#@torch.jit.script
def Yl63_m38(theta, phi):
    return 1.82377917122162e-67*(1.0 - cos(theta)**2)**19*(8.36323064110381e+79*cos(theta)**25 - 2.00717535386492e+80*cos(theta)**23 + 2.0642900997066e+80*cos(theta)**21 - 1.1942174130534e+80*cos(theta)**19 + 4.29015079059101e+79*cos(theta)**17 - 9.97368388923723e+78*cos(theta)**15 + 1.51773450488393e+78*cos(theta)**13 - 1.49662820962005e+77*cos(theta)**11 + 9.26965670372781e+75*cos(theta)**9 - 3.40170888210195e+74*cos(theta)**7 + 6.67625107702251e+72*cos(theta)**5 - 5.78030396279006e+70*cos(theta)**3 + 1.40298639873545e+68*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl63_m39(theta, phi):
    return 3.61162093063425e-69*(1.0 - cos(theta)**2)**19.5*(2.09080766027595e+81*cos(theta)**24 - 4.61650331388931e+81*cos(theta)**22 + 4.33500920938386e+81*cos(theta)**20 - 2.26901308480147e+81*cos(theta)**18 + 7.29325634400472e+80*cos(theta)**16 - 1.49605258338558e+80*cos(theta)**14 + 1.9730548563491e+79*cos(theta)**12 - 1.64629103058206e+78*cos(theta)**10 + 8.34269103335503e+76*cos(theta)**8 - 2.38119621747136e+75*cos(theta)**6 + 3.33812553851126e+73*cos(theta)**4 - 1.73409118883702e+71*cos(theta)**2 + 1.40298639873545e+68)*cos(39*phi)

#@torch.jit.script
def Yl63_m40(theta, phi):
    return 7.26403499967604e-71*(1.0 - cos(theta)**2)**20*(5.01793838466229e+82*cos(theta)**23 - 1.01563072905565e+83*cos(theta)**21 + 8.67001841876772e+82*cos(theta)**19 - 4.08422355264264e+82*cos(theta)**17 + 1.16692101504076e+82*cos(theta)**15 - 2.09447361673982e+81*cos(theta)**13 + 2.36766582761892e+80*cos(theta)**11 - 1.64629103058206e+79*cos(theta)**9 + 6.67415282668402e+77*cos(theta)**7 - 1.42871773048282e+76*cos(theta)**5 + 1.3352502154045e+74*cos(theta)**3 - 3.46818237767403e+71*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl63_m41(theta, phi):
    return 1.48524240553485e-72*(1.0 - cos(theta)**2)**20.5*(1.15412582847233e+84*cos(theta)**22 - 2.13282453101686e+84*cos(theta)**20 + 1.64730349956587e+84*cos(theta)**18 - 6.9431800394925e+83*cos(theta)**16 + 1.75038152256113e+83*cos(theta)**14 - 2.72281570176176e+82*cos(theta)**12 + 2.60443241038082e+81*cos(theta)**10 - 1.48166192752385e+80*cos(theta)**8 + 4.67190697867882e+78*cos(theta)**6 - 7.14358865241409e+76*cos(theta)**4 + 4.00575064621351e+74*cos(theta)**2 - 3.46818237767403e+71)*cos(41*phi)

#@torch.jit.script
def Yl63_m42(theta, phi):
    return 3.09023388571054e-74*(1.0 - cos(theta)**2)**21*(2.53907682263912e+85*cos(theta)**21 - 4.26564906203372e+85*cos(theta)**19 + 2.96514629921856e+85*cos(theta)**17 - 1.1109088063188e+85*cos(theta)**15 + 2.45053413158559e+84*cos(theta)**13 - 3.26737884211412e+83*cos(theta)**11 + 2.60443241038082e+82*cos(theta)**9 - 1.18532954201908e+81*cos(theta)**7 + 2.80314418720729e+79*cos(theta)**5 - 2.85743546096564e+77*cos(theta)**3 + 8.01150129242702e+74*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl63_m43(theta, phi):
    return 6.54981103284738e-76*(1.0 - cos(theta)**2)**21.5*(5.33206132754215e+86*cos(theta)**20 - 8.10473321786406e+86*cos(theta)**18 + 5.04074870867155e+86*cos(theta)**16 - 1.6663632094782e+86*cos(theta)**14 + 3.18569437106126e+85*cos(theta)**12 - 3.59411672632553e+84*cos(theta)**10 + 2.34398916934274e+83*cos(theta)**8 - 8.29730679413358e+81*cos(theta)**6 + 1.40157209360364e+80*cos(theta)**4 - 8.57230638289691e+77*cos(theta)**2 + 8.01150129242702e+74)*cos(43*phi)

#@torch.jit.script
def Yl63_m44(theta, phi):
    return 1.41586512251013e-77*(1.0 - cos(theta)**2)**22*(1.06641226550843e+88*cos(theta)**19 - 1.45885197921553e+88*cos(theta)**17 + 8.06519793387448e+87*cos(theta)**15 - 2.33290849326948e+87*cos(theta)**13 + 3.82283324527352e+86*cos(theta)**11 - 3.59411672632553e+85*cos(theta)**9 + 1.87519133547419e+84*cos(theta)**7 - 4.97838407648015e+82*cos(theta)**5 + 5.60628837441458e+80*cos(theta)**3 - 1.71446127657938e+78*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl63_m45(theta, phi):
    return 3.12559861334088e-79*(1.0 - cos(theta)**2)**22.5*(2.02618330446602e+89*cos(theta)**18 - 2.4800483646664e+89*cos(theta)**16 + 1.20977969008117e+89*cos(theta)**14 - 3.03278104125032e+88*cos(theta)**12 + 4.20511656980087e+87*cos(theta)**10 - 3.23470505369297e+86*cos(theta)**8 + 1.31263393483193e+85*cos(theta)**6 - 2.48919203824007e+83*cos(theta)**4 + 1.68188651232437e+81*cos(theta)**2 - 1.71446127657938e+78)*cos(45*phi)

#@torch.jit.script
def Yl63_m46(theta, phi):
    return 7.05640833077812e-81*(1.0 - cos(theta)**2)**23*(3.64712994803883e+90*cos(theta)**17 - 3.96807738346625e+90*cos(theta)**15 + 1.69369156611364e+90*cos(theta)**13 - 3.63933724950039e+89*cos(theta)**11 + 4.20511656980087e+88*cos(theta)**9 - 2.58776404295438e+87*cos(theta)**7 + 7.87580360899159e+85*cos(theta)**5 - 9.95676815296029e+83*cos(theta)**3 + 3.36377302464875e+81*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl63_m47(theta, phi):
    return 1.63178486528101e-82*(1.0 - cos(theta)**2)**23.5*(6.20012091166601e+91*cos(theta)**16 - 5.95211607519937e+91*cos(theta)**14 + 2.20179903594773e+91*cos(theta)**12 - 4.00327097445043e+90*cos(theta)**10 + 3.78460491282078e+89*cos(theta)**8 - 1.81143483006807e+88*cos(theta)**6 + 3.9379018044958e+86*cos(theta)**4 - 2.98703044588809e+84*cos(theta)**2 + 3.36377302464875e+81)*cos(47*phi)

#@torch.jit.script
def Yl63_m48(theta, phi):
    return 3.87205413057346e-84*(1.0 - cos(theta)**2)**24*(9.92019345866561e+92*cos(theta)**15 - 8.33296250527912e+92*cos(theta)**13 + 2.64215884313728e+92*cos(theta)**11 - 4.00327097445043e+91*cos(theta)**9 + 3.02768393025662e+90*cos(theta)**7 - 1.08686089804084e+89*cos(theta)**5 + 1.57516072179832e+87*cos(theta)**3 - 5.97406089177617e+84*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl63_m49(theta, phi):
    return 9.44684477121826e-86*(1.0 - cos(theta)**2)**24.5*(1.48802901879984e+94*cos(theta)**14 - 1.08328512568629e+94*cos(theta)**12 + 2.90637472745101e+93*cos(theta)**10 - 3.60294387700538e+92*cos(theta)**8 + 2.11937875117964e+91*cos(theta)**6 - 5.4343044902042e+89*cos(theta)**4 + 4.72548216539495e+87*cos(theta)**2 - 5.97406089177617e+84)*cos(49*phi)

#@torch.jit.script
def Yl63_m50(theta, phi):
    return 2.37510896857602e-87*(1.0 - cos(theta)**2)**25*(2.08324062631978e+95*cos(theta)**13 - 1.29994215082354e+95*cos(theta)**11 + 2.90637472745101e+94*cos(theta)**9 - 2.88235510160431e+93*cos(theta)**7 + 1.27162725070778e+92*cos(theta)**5 - 2.17372179608168e+90*cos(theta)**3 + 9.45096433078991e+87*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl63_m51(theta, phi):
    return 6.16963451904442e-89*(1.0 - cos(theta)**2)**25.5*(2.70821281421571e+96*cos(theta)**12 - 1.4299363659059e+96*cos(theta)**10 + 2.61573725470591e+95*cos(theta)**8 - 2.01764857112301e+94*cos(theta)**6 + 6.35813625353891e+92*cos(theta)**4 - 6.52116538824504e+90*cos(theta)**2 + 9.45096433078991e+87)*cos(51*phi)

#@torch.jit.script
def Yl63_m52(theta, phi):
    return 1.66080978368343e-90*(1.0 - cos(theta)**2)**26*(3.24985537705886e+97*cos(theta)**11 - 1.4299363659059e+97*cos(theta)**9 + 2.09258980376473e+96*cos(theta)**7 - 1.21058914267381e+95*cos(theta)**5 + 2.54325450141556e+93*cos(theta)**3 - 1.30423307764901e+91*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl63_m53(theta, phi):
    return 4.64937480003281e-92*(1.0 - cos(theta)**2)**26.5*(3.57484091476474e+98*cos(theta)**10 - 1.28694272931531e+98*cos(theta)**8 + 1.46481286263531e+97*cos(theta)**6 - 6.05294571336904e+95*cos(theta)**4 + 7.62976350424669e+93*cos(theta)**2 - 1.30423307764901e+91)*cos(53*phi)

#@torch.jit.script
def Yl63_m54(theta, phi):
    return 1.35925715104427e-93*(1.0 - cos(theta)**2)**27*(3.57484091476474e+99*cos(theta)**9 - 1.02955418345225e+99*cos(theta)**7 + 8.78887717581185e+97*cos(theta)**5 - 2.42117828534762e+96*cos(theta)**3 + 1.52595270084934e+94*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl63_m55(theta, phi):
    return 4.17099210816046e-95*(1.0 - cos(theta)**2)**27.5*(3.21735682328827e+100*cos(theta)**8 - 7.20687928416572e+99*cos(theta)**6 + 4.39443858790593e+98*cos(theta)**4 - 7.26353485604285e+96*cos(theta)**2 + 1.52595270084934e+94)*cos(55*phi)

#@torch.jit.script
def Yl63_m56(theta, phi):
    return 1.35182630770815e-96*(1.0 - cos(theta)**2)**28*(2.57388545863061e+101*cos(theta)**7 - 4.32412757049943e+100*cos(theta)**5 + 1.75777543516237e+99*cos(theta)**3 - 1.45270697120857e+97*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl63_m57(theta, phi):
    return 4.66424388581167e-98*(1.0 - cos(theta)**2)**28.5*(1.80171982104143e+102*cos(theta)**6 - 2.16206378524972e+101*cos(theta)**4 + 5.27332630548711e+99*cos(theta)**2 - 1.45270697120857e+97)*cos(57*phi)

#@torch.jit.script
def Yl63_m58(theta, phi):
    return 1.73106326608104e-99*(1.0 - cos(theta)**2)**29*(1.08103189262486e+103*cos(theta)**5 - 8.64825514099886e+101*cos(theta)**3 + 1.05466526109742e+100*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl63_m59(theta, phi):
    return 7.00887029457315e-101*(1.0 - cos(theta)**2)**29.5*(5.40515946312429e+103*cos(theta)**4 - 2.59447654229966e+102*cos(theta)**2 + 1.05466526109742e+100)*cos(59*phi)

#@torch.jit.script
def Yl63_m60(theta, phi):
    return 3.1598427589696e-102*(1.0 - cos(theta)**2)**30*(2.16206378524972e+104*cos(theta)**3 - 5.18895308459932e+102*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl63_m61(theta, phi):
    return 1.63830215199759e-103*(1.0 - cos(theta)**2)**30.5*(6.48619135574915e+104*cos(theta)**2 - 5.18895308459932e+102)*cos(61*phi)

#@torch.jit.script
def Yl63_m62(theta, phi):
    return 13.4413766257656*(1.0 - cos(theta)**2)**31*cos(62*phi)*cos(theta)

#@torch.jit.script
def Yl63_m63(theta, phi):
    return 1.19745300333825*(1.0 - cos(theta)**2)**31.5*cos(63*phi)

#@torch.jit.script
def Yl64_m_minus_64(theta, phi):
    return 1.20212145380472*(1.0 - cos(theta)**2)**32*sin(64*phi)

#@torch.jit.script
def Yl64_m_minus_63(theta, phi):
    return 13.6004517087224*(1.0 - cos(theta)**2)**31.5*sin(63*phi)*cos(theta)

#@torch.jit.script
def Yl64_m_minus_62(theta, phi):
    return 1.31566922853349e-105*(1.0 - cos(theta)**2)**31*(8.23746302180142e+106*cos(theta)**2 - 6.48619135574915e+104)*sin(62*phi)

#@torch.jit.script
def Yl64_m_minus_61(theta, phi):
    return 2.55795333449995e-104*(1.0 - cos(theta)**2)**30.5*(2.74582100726714e+106*cos(theta)**3 - 6.48619135574915e+104*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl64_m_minus_60(theta, phi):
    return 5.71975753921415e-103*(1.0 - cos(theta)**2)**30*(6.86455251816785e+105*cos(theta)**4 - 3.24309567787457e+104*cos(theta)**2 + 1.29723827114983e+102)*sin(60*phi)

#@torch.jit.script
def Yl64_m_minus_59(theta, phi):
    return 1.42420814176111e-101*(1.0 - cos(theta)**2)**29.5*(1.37291050363357e+105*cos(theta)**5 - 1.08103189262486e+104*cos(theta)**3 + 1.29723827114983e+102*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl64_m_minus_58(theta, phi):
    return 3.86902597215535e-100*(1.0 - cos(theta)**2)**29*(2.28818417272262e+104*cos(theta)**6 - 2.70257973156214e+103*cos(theta)**4 + 6.48619135574915e+101*cos(theta)**2 - 1.75777543516237e+99)*sin(58*phi)

#@torch.jit.script
def Yl64_m_minus_57(theta, phi):
    return 1.13065623091741e-98*(1.0 - cos(theta)**2)**28.5*(3.26883453246088e+103*cos(theta)**7 - 5.40515946312429e+102*cos(theta)**5 + 2.16206378524972e+101*cos(theta)**3 - 1.75777543516237e+99*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl64_m_minus_56(theta, phi):
    return 3.5177766275191e-97*(1.0 - cos(theta)**2)**28*(4.0860431655761e+102*cos(theta)**8 - 9.00859910520715e+101*cos(theta)**6 + 5.40515946312429e+100*cos(theta)**4 - 8.78887717581185e+98*cos(theta)**2 + 1.81588371401071e+96)*sin(56*phi)

#@torch.jit.script
def Yl64_m_minus_55(theta, phi):
    return 1.15605936669399e-95*(1.0 - cos(theta)**2)**27.5*(4.54004796175122e+101*cos(theta)**9 - 1.28694272931531e+101*cos(theta)**7 + 1.08103189262486e+100*cos(theta)**5 - 2.92962572527062e+98*cos(theta)**3 + 1.81588371401071e+96*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl64_m_minus_54(theta, phi):
    return 3.98798593100815e-94*(1.0 - cos(theta)**2)**27*(4.54004796175122e+100*cos(theta)**10 - 1.60867841164413e+100*cos(theta)**8 + 1.80171982104143e+99*cos(theta)**6 - 7.32406431317654e+97*cos(theta)**4 + 9.07941857005357e+95*cos(theta)**2 - 1.52595270084934e+93)*sin(54*phi)

#@torch.jit.script
def Yl64_m_minus_53(theta, phi):
    return 1.43678228198022e-92*(1.0 - cos(theta)**2)**26.5*(4.12731632886475e+99*cos(theta)**11 - 1.78742045738237e+99*cos(theta)**9 + 2.57388545863061e+98*cos(theta)**7 - 1.46481286263531e+97*cos(theta)**5 + 3.02647285668452e+95*cos(theta)**3 - 1.52595270084934e+93*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl64_m_minus_52(theta, phi):
    return 5.38362148506044e-91*(1.0 - cos(theta)**2)**26*(3.43943027405396e+98*cos(theta)**12 - 1.78742045738237e+98*cos(theta)**10 + 3.21735682328827e+97*cos(theta)**8 - 2.44135477105885e+96*cos(theta)**6 + 7.5661821417113e+94*cos(theta)**4 - 7.62976350424669e+92*cos(theta)**2 + 1.08686089804084e+90)*sin(52*phi)

#@torch.jit.script
def Yl64_m_minus_51(theta, phi):
    return 2.09062042188346e-89*(1.0 - cos(theta)**2)**25.5*(2.64571559542612e+97*cos(theta)**13 - 1.62492768852943e+97*cos(theta)**11 + 3.57484091476474e+96*cos(theta)**9 - 3.48764967294121e+95*cos(theta)**7 + 1.51323642834226e+94*cos(theta)**5 - 2.54325450141556e+92*cos(theta)**3 + 1.08686089804084e+90*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl64_m_minus_50(theta, phi):
    return 8.38857373748235e-88*(1.0 - cos(theta)**2)**25*(1.8897968538758e+96*cos(theta)**14 - 1.35410640710786e+96*cos(theta)**12 + 3.57484091476474e+95*cos(theta)**10 - 4.35956209117651e+94*cos(theta)**8 + 2.52206071390377e+93*cos(theta)**6 - 6.35813625353891e+91*cos(theta)**4 + 5.4343044902042e+89*cos(theta)**2 - 6.75068880770708e+86)*sin(50*phi)

#@torch.jit.script
def Yl64_m_minus_49(theta, phi):
    return 3.46885528073881e-86*(1.0 - cos(theta)**2)**24.5*(1.25986456925053e+95*cos(theta)**15 - 1.04162031315989e+95*cos(theta)**13 + 3.24985537705886e+94*cos(theta)**11 - 4.84395787908501e+93*cos(theta)**9 + 3.60294387700538e+92*cos(theta)**7 - 1.27162725070778e+91*cos(theta)**5 + 1.81143483006807e+89*cos(theta)**3 - 6.75068880770708e+86*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl64_m_minus_48(theta, phi):
    return 1.47497749750113e-84*(1.0 - cos(theta)**2)**24*(7.87415355781583e+93*cos(theta)**16 - 7.44014509399921e+93*cos(theta)**14 + 2.70821281421571e+93*cos(theta)**12 - 4.84395787908501e+92*cos(theta)**10 + 4.50367984625673e+91*cos(theta)**8 - 2.11937875117964e+90*cos(theta)**6 + 4.52858707517016e+88*cos(theta)**4 - 3.37534440385354e+86*cos(theta)**2 + 3.73378805736011e+83)*sin(48*phi)

#@torch.jit.script
def Yl64_m_minus_47(theta, phi):
    return 6.43604195832224e-83*(1.0 - cos(theta)**2)**23.5*(4.63185503400931e+92*cos(theta)**17 - 4.96009672933281e+92*cos(theta)**15 + 2.08324062631978e+92*cos(theta)**13 - 4.40359807189547e+91*cos(theta)**11 + 5.00408871806303e+90*cos(theta)**9 - 3.02768393025662e+89*cos(theta)**7 + 9.05717415034033e+87*cos(theta)**5 - 1.12511480128451e+86*cos(theta)**3 + 3.73378805736011e+83*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl64_m_minus_46(theta, phi):
    return 2.87684596227171e-81*(1.0 - cos(theta)**2)**23*(2.57325279667184e+91*cos(theta)**18 - 3.100060455833e+91*cos(theta)**16 + 1.48802901879984e+91*cos(theta)**14 - 3.66966505991289e+90*cos(theta)**12 + 5.00408871806303e+89*cos(theta)**10 - 3.78460491282078e+88*cos(theta)**8 + 1.50952902505672e+87*cos(theta)**6 - 2.81278700321128e+85*cos(theta)**4 + 1.86689402868005e+83*cos(theta)**2 - 1.86876279147153e+80)*sin(46*phi)

#@torch.jit.script
def Yl64_m_minus_45(theta, phi):
    return 1.31519379649676e-79*(1.0 - cos(theta)**2)**22.5*(1.35434357719571e+90*cos(theta)**19 - 1.82356497401941e+90*cos(theta)**17 + 9.92019345866561e+89*cos(theta)**15 - 2.82281927685607e+89*cos(theta)**13 + 4.54917156187548e+88*cos(theta)**11 - 4.20511656980087e+87*cos(theta)**9 + 2.15647003579532e+86*cos(theta)**7 - 5.62557400642256e+84*cos(theta)**5 + 6.22298009560018e+82*cos(theta)**3 - 1.86876279147153e+80*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl64_m_minus_44(theta, phi):
    return 6.14070166569664e-78*(1.0 - cos(theta)**2)**22*(6.77171788597853e+88*cos(theta)**20 - 1.01309165223301e+89*cos(theta)**18 + 6.20012091166601e+88*cos(theta)**16 - 2.01629948346862e+88*cos(theta)**14 + 3.7909763015629e+87*cos(theta)**12 - 4.20511656980087e+86*cos(theta)**10 + 2.69558754474415e+85*cos(theta)**8 - 9.37595667737094e+83*cos(theta)**6 + 1.55574502390005e+82*cos(theta)**4 - 9.34381395735763e+79*cos(theta)**2 + 8.57230638289691e+76)*sin(44*phi)

#@torch.jit.script
def Yl64_m_minus_43(theta, phi):
    return 2.92441850691721e-76*(1.0 - cos(theta)**2)**21.5*(3.22462756475168e+87*cos(theta)**21 - 5.33206132754215e+87*cos(theta)**19 + 3.64712994803883e+87*cos(theta)**17 - 1.34419965564575e+87*cos(theta)**15 + 2.91613561658685e+86*cos(theta)**13 - 3.82283324527352e+85*cos(theta)**11 + 2.99509727193794e+84*cos(theta)**9 - 1.33942238248156e+83*cos(theta)**7 + 3.11149004780009e+81*cos(theta)**5 - 3.11460465245254e+79*cos(theta)**3 + 8.57230638289691e+76*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl64_m_minus_42(theta, phi):
    return 1.41887047903867e-74*(1.0 - cos(theta)**2)**21*(1.46573980215985e+86*cos(theta)**22 - 2.66603066377107e+86*cos(theta)**20 + 2.02618330446602e+86*cos(theta)**18 - 8.40124784778592e+85*cos(theta)**16 + 2.08295401184775e+85*cos(theta)**14 - 3.18569437106126e+84*cos(theta)**12 + 2.99509727193794e+83*cos(theta)**10 - 1.67427797810195e+82*cos(theta)**8 + 5.18581674633348e+80*cos(theta)**6 - 7.78651163113136e+78*cos(theta)**4 + 4.28615319144845e+76*cos(theta)**2 - 3.64159149655773e+73)*sin(42*phi)

#@torch.jit.script
def Yl64_m_minus_41(theta, phi):
    return 7.00583014186664e-73*(1.0 - cos(theta)**2)**20.5*(6.37278174852111e+84*cos(theta)**23 - 1.26953841131956e+85*cos(theta)**21 + 1.06641226550843e+85*cos(theta)**19 - 4.9419104986976e+84*cos(theta)**17 + 1.3886360078985e+84*cos(theta)**15 - 2.45053413158559e+83*cos(theta)**13 + 2.72281570176176e+82*cos(theta)**11 - 1.86030886455773e+81*cos(theta)**9 + 7.40830963761926e+79*cos(theta)**7 - 1.55730232622627e+78*cos(theta)**5 + 1.42871773048282e+76*cos(theta)**3 - 3.64159149655773e+73*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl64_m_minus_40(theta, phi):
    return 3.51689881943242e-71*(1.0 - cos(theta)**2)**20*(2.65532572855046e+83*cos(theta)**24 - 5.77062914236163e+83*cos(theta)**22 + 5.33206132754215e+83*cos(theta)**20 - 2.74550583260978e+83*cos(theta)**18 + 8.67897504936562e+82*cos(theta)**16 - 1.75038152256113e+82*cos(theta)**14 + 2.26901308480147e+81*cos(theta)**12 - 1.86030886455773e+80*cos(theta)**10 + 9.26038704702408e+78*cos(theta)**8 - 2.59550387704379e+77*cos(theta)**6 + 3.57179432620705e+75*cos(theta)**4 - 1.82079574827887e+73*cos(theta)**2 + 1.44507599069751e+70)*sin(40*phi)

#@torch.jit.script
def Yl64_m_minus_39(theta, phi):
    return 1.79327357076174e-69*(1.0 - cos(theta)**2)**19.5*(1.06213029142018e+82*cos(theta)**25 - 2.50896919233114e+82*cos(theta)**23 + 2.53907682263912e+82*cos(theta)**21 - 1.44500306979462e+82*cos(theta)**19 + 5.10527944080331e+81*cos(theta)**17 - 1.16692101504076e+81*cos(theta)**15 + 1.74539468061651e+80*cos(theta)**13 - 1.69118987687066e+79*cos(theta)**11 + 1.02893189411379e+78*cos(theta)**9 - 3.70786268149112e+76*cos(theta)**7 + 7.14358865241409e+74*cos(theta)**5 - 6.06931916092956e+72*cos(theta)**3 + 1.44507599069751e+70*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl64_m_minus_38(theta, phi):
    return 9.28008243859333e-68*(1.0 - cos(theta)**2)**19*(4.08511650546225e+80*cos(theta)**26 - 1.04540383013798e+81*cos(theta)**24 + 1.15412582847233e+81*cos(theta)**22 - 7.2250153489731e+80*cos(theta)**20 + 2.83626635600184e+80*cos(theta)**18 - 7.29325634400472e+79*cos(theta)**16 + 1.24671048615465e+79*cos(theta)**14 - 1.40932489739222e+78*cos(theta)**12 + 1.02893189411379e+77*cos(theta)**10 - 4.6348283518639e+75*cos(theta)**8 + 1.19059810873568e+74*cos(theta)**6 - 1.51732979023239e+72*cos(theta)**4 + 7.22537995348757e+69*cos(theta)**2 - 5.39610153359789e+66)*sin(38*phi)

#@torch.jit.script
def Yl64_m_minus_37(theta, phi):
    return 4.87005428516727e-66*(1.0 - cos(theta)**2)**18.5*(1.51300611313417e+79*cos(theta)**27 - 4.18161532055191e+79*cos(theta)**25 + 5.01793838466229e+79*cos(theta)**23 - 3.440483499511e+79*cos(theta)**21 + 1.49277176631676e+79*cos(theta)**19 - 4.29015079059101e+78*cos(theta)**17 + 8.31140324103102e+77*cos(theta)**15 - 1.08409607491709e+77*cos(theta)**13 + 9.35392631012533e+75*cos(theta)**11 - 5.14980927984878e+74*cos(theta)**9 + 1.70085444105097e+73*cos(theta)**7 - 3.03465958046478e+71*cos(theta)**5 + 2.40845998449586e+69*cos(theta)**3 - 5.39610153359789e+66*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl64_m_minus_36(theta, phi):
    return 2.58984340217833e-64*(1.0 - cos(theta)**2)**18*(5.40359326119345e+77*cos(theta)**28 - 1.60831358482766e+78*cos(theta)**26 + 2.09080766027595e+78*cos(theta)**24 - 1.56385613614136e+78*cos(theta)**22 + 7.46385883158378e+77*cos(theta)**20 - 2.3834171058839e+77*cos(theta)**18 + 5.19462702564439e+76*cos(theta)**16 - 7.74354339226493e+75*cos(theta)**14 + 7.79493859177111e+74*cos(theta)**12 - 5.14980927984878e+73*cos(theta)**10 + 2.12606805131372e+72*cos(theta)**8 - 5.0577659674413e+70*cos(theta)**6 + 6.02114996123964e+68*cos(theta)**4 - 2.69805076679894e+66*cos(theta)**2 + 1.90809813776446e+63)*sin(36*phi)

#@torch.jit.script
def Yl64_m_minus_35(theta, phi):
    return 1.39467335454003e-62*(1.0 - cos(theta)**2)**17.5*(1.86330802110119e+76*cos(theta)**29 - 5.95671698084317e+76*cos(theta)**27 + 8.36323064110381e+76*cos(theta)**25 - 6.79937450496245e+76*cos(theta)**23 + 3.55421849123037e+76*cos(theta)**21 - 1.25443005572837e+76*cos(theta)**19 + 3.05566295626141e+75*cos(theta)**17 - 5.16236226150995e+74*cos(theta)**15 + 5.9961066090547e+73*cos(theta)**13 - 4.68164479986253e+72*cos(theta)**11 + 2.36229783479302e+71*cos(theta)**9 - 7.22537995348757e+69*cos(theta)**7 + 1.20422999224793e+68*cos(theta)**5 - 8.99350255599648e+65*cos(theta)**3 + 1.90809813776446e+63*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl64_m_minus_34(theta, phi):
    return 7.6006498963022e-61*(1.0 - cos(theta)**2)**17*(6.21102673700396e+74*cos(theta)**30 - 2.1273989217297e+75*cos(theta)**28 + 3.21662716965531e+75*cos(theta)**26 - 2.83307271040102e+75*cos(theta)**24 + 1.61555385965017e+75*cos(theta)**22 - 6.27215027864183e+74*cos(theta)**20 + 1.69759053125634e+74*cos(theta)**18 - 3.22647641344372e+73*cos(theta)**16 + 4.28293329218193e+72*cos(theta)**14 - 3.90137066655211e+71*cos(theta)**12 + 2.36229783479302e+70*cos(theta)**10 - 9.03172494185946e+68*cos(theta)**8 + 2.00704998707988e+67*cos(theta)**6 - 2.24837563899912e+65*cos(theta)**4 + 9.54049068882229e+62*cos(theta)**2 - 6.42457285442578e+59)*sin(34*phi)

#@torch.jit.script
def Yl64_m_minus_33(theta, phi):
    return 4.18933039917634e-59*(1.0 - cos(theta)**2)**16.5*(2.00355701193676e+73*cos(theta)**31 - 7.33585835079208e+73*cos(theta)**29 + 1.19134339616863e+74*cos(theta)**27 - 1.13322908416041e+74*cos(theta)**25 + 7.0241472158703e+73*cos(theta)**23 - 2.98673822792468e+73*cos(theta)**21 + 8.9346870066123e+72*cos(theta)**19 - 1.89792730202572e+72*cos(theta)**17 + 2.85528886145462e+71*cos(theta)**15 - 3.00105435888624e+70*cos(theta)**13 + 2.14754348617547e+69*cos(theta)**11 - 1.00352499353994e+68*cos(theta)**9 + 2.86721426725697e+66*cos(theta)**7 - 4.49675127799824e+64*cos(theta)**5 + 3.18016356294076e+62*cos(theta)**3 - 6.42457285442578e+59*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl64_m_minus_32(theta, phi):
    return 2.33402481684555e-57*(1.0 - cos(theta)**2)**16*(6.26111566230238e+71*cos(theta)**32 - 2.44528611693069e+72*cos(theta)**30 + 4.25479784345941e+72*cos(theta)**28 - 4.35857340061695e+72*cos(theta)**26 + 2.92672800661262e+72*cos(theta)**24 - 1.35760828542031e+72*cos(theta)**22 + 4.46734350330615e+71*cos(theta)**20 - 1.05440405668095e+71*cos(theta)**18 + 1.78455553840914e+70*cos(theta)**16 - 2.14361025634731e+69*cos(theta)**14 + 1.78961957181289e+68*cos(theta)**12 - 1.00352499353994e+67*cos(theta)**10 + 3.58401783407122e+65*cos(theta)**8 - 7.4945854633304e+63*cos(theta)**6 + 7.95040890735191e+61*cos(theta)**4 - 3.21228642721289e+59*cos(theta)**2 + 2.06977218248253e+56)*sin(32*phi)

#@torch.jit.script
def Yl64_m_minus_31(theta, phi):
    return 1.31370561417017e-55*(1.0 - cos(theta)**2)**15.5*(1.89730777645527e+70*cos(theta)**33 - 7.8880197320345e+70*cos(theta)**31 + 1.46717167015842e+71*cos(theta)**29 - 1.61428644467295e+71*cos(theta)**27 + 1.17069120264505e+71*cos(theta)**25 - 5.90264471921874e+70*cos(theta)**23 + 2.12730643014579e+70*cos(theta)**21 - 5.54949503516292e+69*cos(theta)**19 + 1.04973855200537e+69*cos(theta)**17 - 1.42907350423154e+68*cos(theta)**15 + 1.37663043985607e+67*cos(theta)**13 - 9.12295448672673e+65*cos(theta)**11 + 3.98224203785691e+64*cos(theta)**9 - 1.07065506619006e+63*cos(theta)**7 + 1.59008178147038e+61*cos(theta)**5 - 1.0707621424043e+59*cos(theta)**3 + 2.06977218248253e+56*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl64_m_minus_30(theta, phi):
    return 7.46619480288864e-54*(1.0 - cos(theta)**2)**15*(5.58031698957432e+68*cos(theta)**34 - 2.46500616626078e+69*cos(theta)**32 + 4.89057223386139e+69*cos(theta)**30 - 5.76530873097481e+69*cos(theta)**28 + 4.50265847171173e+69*cos(theta)**26 - 2.45943529967447e+69*cos(theta)**24 + 9.66957468248084e+68*cos(theta)**22 - 2.77474751758146e+68*cos(theta)**20 + 5.8318808444743e+67*cos(theta)**18 - 8.93170940144713e+66*cos(theta)**16 + 9.83307457040051e+65*cos(theta)**14 - 7.60246207227227e+64*cos(theta)**12 + 3.98224203785691e+63*cos(theta)**10 - 1.33831883273757e+62*cos(theta)**8 + 2.65013630245064e+60*cos(theta)**6 - 2.67690535601074e+58*cos(theta)**4 + 1.03488609124127e+56*cos(theta)**2 - 6.40796341325862e+52)*sin(30*phi)

#@torch.jit.script
def Yl64_m_minus_29(theta, phi):
    return 4.28249895862336e-52*(1.0 - cos(theta)**2)**14.5*(1.59437628273552e+67*cos(theta)**35 - 7.4697156553357e+67*cos(theta)**33 + 1.5776039464069e+68*cos(theta)**31 - 1.98803749343959e+68*cos(theta)**29 + 1.66765128581916e+68*cos(theta)**27 - 9.8377411986979e+67*cos(theta)**25 + 4.20416290542645e+67*cos(theta)**23 - 1.32130834170546e+67*cos(theta)**21 + 3.06941097077595e+66*cos(theta)**19 - 5.25394670673361e+65*cos(theta)**17 + 6.55538304693368e+64*cos(theta)**15 - 5.84804774790175e+63*cos(theta)**13 + 3.62022003441537e+62*cos(theta)**11 - 1.48702092526397e+61*cos(theta)**9 + 3.78590900350091e+59*cos(theta)**7 - 5.35381071202149e+57*cos(theta)**5 + 3.44962030413756e+55*cos(theta)**3 - 6.40796341325862e+52*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl64_m_minus_28(theta, phi):
    return 2.47793546047678e-50*(1.0 - cos(theta)**2)**14*(4.42882300759866e+65*cos(theta)**36 - 2.19697519274579e+66*cos(theta)**34 + 4.93001233252156e+66*cos(theta)**32 - 6.62679164479863e+66*cos(theta)**30 + 5.95589744935414e+66*cos(theta)**28 - 3.78374661488381e+66*cos(theta)**26 + 1.75173454392769e+66*cos(theta)**24 - 6.00594700775208e+65*cos(theta)**22 + 1.53470548538797e+65*cos(theta)**20 - 2.91885928151867e+64*cos(theta)**18 + 4.09711440433355e+63*cos(theta)**16 - 4.17717696278696e+62*cos(theta)**14 + 3.01685002867947e+61*cos(theta)**12 - 1.48702092526397e+60*cos(theta)**10 + 4.73238625437614e+58*cos(theta)**8 - 8.92301785336914e+56*cos(theta)**6 + 8.62405076034389e+54*cos(theta)**4 - 3.20398170662931e+52*cos(theta)**2 + 1.91396756668417e+49)*sin(28*phi)

#@torch.jit.script
def Yl64_m_minus_27(theta, phi):
    return 1.44572192187728e-48*(1.0 - cos(theta)**2)**13.5*(1.19697919124288e+64*cos(theta)**37 - 6.2770719792737e+64*cos(theta)**35 + 1.49394313106714e+65*cos(theta)**33 - 2.13767472412859e+65*cos(theta)**31 + 2.0537577411566e+65*cos(theta)**29 - 1.40138763514215e+65*cos(theta)**27 + 7.00693817571075e+64*cos(theta)**25 - 2.61128130771829e+64*cos(theta)**23 + 7.30812135899036e+63*cos(theta)**21 - 1.53624172711509e+63*cos(theta)**19 + 2.41006729666679e+62*cos(theta)**17 - 2.78478464185798e+61*cos(theta)**15 + 2.32065386821498e+60*cos(theta)**13 - 1.35183720478543e+59*cos(theta)**11 + 5.25820694930682e+57*cos(theta)**9 - 1.27471683619559e+56*cos(theta)**7 + 1.72481015206878e+54*cos(theta)**5 - 1.06799390220977e+52*cos(theta)**3 + 1.91396756668417e+49*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl64_m_minus_26(theta, phi):
    return 8.50153331177454e-47*(1.0 - cos(theta)**2)**13*(3.14994524011285e+62*cos(theta)**38 - 1.7436311053538e+63*cos(theta)**36 + 4.39395038549159e+63*cos(theta)**34 - 6.68023351290185e+63*cos(theta)**32 + 6.84585913718867e+63*cos(theta)**30 - 5.0049558397934e+63*cos(theta)**28 + 2.69497622142721e+63*cos(theta)**26 - 1.08803387821596e+63*cos(theta)**24 + 3.32187334499562e+62*cos(theta)**22 - 7.68120863557545e+61*cos(theta)**20 + 1.338926275926e+61*cos(theta)**18 - 1.74049040116124e+60*cos(theta)**16 + 1.65760990586784e+59*cos(theta)**14 - 1.12653100398785e+58*cos(theta)**12 + 5.25820694930682e+56*cos(theta)**10 - 1.59339604524449e+55*cos(theta)**8 + 2.8746835867813e+53*cos(theta)**6 - 2.66998475552442e+51*cos(theta)**4 + 9.56983783342087e+48*cos(theta)**2 - 5.5348975323429e+45)*sin(26*phi)

#@torch.jit.script
def Yl64_m_minus_25(theta, phi):
    return 5.03675491726324e-45*(1.0 - cos(theta)**2)**12.5*(8.07678266695602e+60*cos(theta)**39 - 4.71251650095623e+61*cos(theta)**37 + 1.25541439585474e+62*cos(theta)**35 - 2.02431318572783e+62*cos(theta)**33 + 2.20834165715763e+62*cos(theta)**31 - 1.72584684130807e+62*cos(theta)**29 + 9.98139341269338e+61*cos(theta)**27 - 4.35213551286382e+61*cos(theta)**25 + 1.44429275869375e+61*cos(theta)**23 - 3.65771839789307e+60*cos(theta)**21 + 7.0469803996105e+59*cos(theta)**19 - 1.02381788303602e+59*cos(theta)**17 + 1.10507327057856e+58*cos(theta)**15 - 8.66562310759888e+56*cos(theta)**13 + 4.78018813573347e+55*cos(theta)**11 - 1.77044005027166e+54*cos(theta)**9 + 4.10669083825899e+52*cos(theta)**7 - 5.33996951104885e+50*cos(theta)**5 + 3.18994594447362e+48*cos(theta)**3 - 5.5348975323429e+45*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl64_m_minus_24(theta, phi):
    return 3.0052168697751e-43*(1.0 - cos(theta)**2)**12*(2.01919566673901e+59*cos(theta)**40 - 1.24013592130427e+60*cos(theta)**38 + 3.48726221070761e+60*cos(theta)**36 - 5.95386231096421e+60*cos(theta)**34 + 6.90106767861761e+60*cos(theta)**32 - 5.75282280436023e+60*cos(theta)**30 + 3.56478336167621e+60*cos(theta)**28 - 1.67389827417839e+60*cos(theta)**26 + 6.01788649455728e+59*cos(theta)**24 - 1.66259927176958e+59*cos(theta)**22 + 3.52349019980525e+58*cos(theta)**20 - 5.68787712797789e+57*cos(theta)**18 + 6.90670794111601e+56*cos(theta)**16 - 6.18973079114206e+55*cos(theta)**14 + 3.98349011311122e+54*cos(theta)**12 - 1.77044005027166e+53*cos(theta)**10 + 5.13336354782374e+51*cos(theta)**8 - 8.89994918508141e+49*cos(theta)**6 + 7.97486486118406e+47*cos(theta)**4 - 2.76744876617145e+45*cos(theta)**2 + 1.55474649784913e+42)*sin(24*phi)

#@torch.jit.script
def Yl64_m_minus_23(theta, phi):
    return 1.80513248796996e-41*(1.0 - cos(theta)**2)**11.5*(4.92486747985123e+57*cos(theta)**41 - 3.17983569565198e+58*cos(theta)**39 + 9.42503300191246e+58*cos(theta)**37 - 1.70110351741835e+59*cos(theta)**35 + 2.09123262988412e+59*cos(theta)**33 - 1.8557492917291e+59*cos(theta)**31 + 1.22923564195731e+59*cos(theta)**29 - 6.19962323769775e+58*cos(theta)**27 + 2.40715459782291e+58*cos(theta)**25 - 7.22869248595469e+57*cos(theta)**23 + 1.67785247609774e+57*cos(theta)**21 - 2.993619541041e+56*cos(theta)**19 + 4.06276937712707e+55*cos(theta)**17 - 4.1264871940947e+54*cos(theta)**15 + 3.06422316393171e+53*cos(theta)**13 - 1.60949095479241e+52*cos(theta)**11 + 5.70373727535971e+50*cos(theta)**9 - 1.27142131215449e+49*cos(theta)**7 + 1.59497297223681e+47*cos(theta)**5 - 9.2248292205715e+44*cos(theta)**3 + 1.55474649784913e+42*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl64_m_minus_22(theta, phi):
    return 1.09117235370959e-39*(1.0 - cos(theta)**2)**11*(1.17258749520267e+56*cos(theta)**42 - 7.94958923912994e+56*cos(theta)**40 + 2.48027184260854e+57*cos(theta)**38 - 4.72528754838429e+57*cos(theta)**36 + 6.15068420554154e+57*cos(theta)**34 - 5.79921653665345e+57*cos(theta)**32 + 4.09745213985771e+57*cos(theta)**30 - 2.21415115632063e+57*cos(theta)**28 + 9.2582869147035e+56*cos(theta)**26 - 3.01195520248112e+56*cos(theta)**24 + 7.62660216408063e+55*cos(theta)**22 - 1.4968097705205e+55*cos(theta)**20 + 2.25709409840393e+54*cos(theta)**18 - 2.57905449630919e+53*cos(theta)**16 + 2.18873083137979e+52*cos(theta)**14 - 1.34124246232701e+51*cos(theta)**12 + 5.70373727535971e+49*cos(theta)**10 - 1.58927664019311e+48*cos(theta)**8 + 2.65828828706135e+46*cos(theta)**6 - 2.30620730514287e+44*cos(theta)**4 + 7.77373248924565e+41*cos(theta)**2 - 4.25491652394398e+38)*sin(22*phi)

#@torch.jit.script
def Yl64_m_minus_21(theta, phi):
    return 6.63554818846152e-38*(1.0 - cos(theta)**2)**10.5*(2.72694766326203e+54*cos(theta)**43 - 1.93892420466584e+55*cos(theta)**41 + 6.35967139130395e+55*cos(theta)**39 - 1.27710474280657e+56*cos(theta)**37 + 1.75733834444044e+56*cos(theta)**35 - 1.75733834444044e+56*cos(theta)**33 + 1.32175875479281e+56*cos(theta)**31 - 7.6350039873125e+55*cos(theta)**29 + 3.42899515359389e+55*cos(theta)**27 - 1.20478208099245e+55*cos(theta)**25 + 3.31591398438288e+54*cos(theta)**23 - 7.12766557390713e+53*cos(theta)**21 + 1.18794426231786e+53*cos(theta)**19 - 1.51709088018188e+52*cos(theta)**17 + 1.45915388758653e+51*cos(theta)**15 - 1.03172497102078e+50*cos(theta)**13 + 5.18521570487247e+48*cos(theta)**11 - 1.7658629335479e+47*cos(theta)**9 + 3.79755469580193e+45*cos(theta)**7 - 4.61241461028575e+43*cos(theta)**5 + 2.59124416308188e+41*cos(theta)**3 - 4.25491652394398e+38*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl64_m_minus_20(theta, phi):
    return 4.05800528717764e-36*(1.0 - cos(theta)**2)**10*(6.19760832559553e+52*cos(theta)**44 - 4.61648620158533e+53*cos(theta)**42 + 1.58991784782599e+54*cos(theta)**40 - 3.36080195475412e+54*cos(theta)**38 + 4.88149540122344e+54*cos(theta)**36 - 5.16864218953071e+54*cos(theta)**34 + 4.13049610872753e+54*cos(theta)**32 - 2.54500132910417e+54*cos(theta)**30 + 1.22464112628353e+54*cos(theta)**28 - 4.63377723458634e+53*cos(theta)**26 + 1.3816308268262e+53*cos(theta)**24 - 3.23984798813961e+52*cos(theta)**22 + 5.93972131158928e+51*cos(theta)**20 - 8.42828266767709e+50*cos(theta)**18 + 9.11971179741581e+49*cos(theta)**16 - 7.36946407871984e+48*cos(theta)**14 + 4.32101308739372e+47*cos(theta)**12 - 1.7658629335479e+46*cos(theta)**10 + 4.74694336975242e+44*cos(theta)**8 - 7.68735768380958e+42*cos(theta)**6 + 6.4781104077047e+40*cos(theta)**4 - 2.12745826197199e+38*cos(theta)**2 + 1.13767821495828e+35)*sin(20*phi)

#@torch.jit.script
def Yl64_m_minus_19(theta, phi):
    return 2.49493082314278e-34*(1.0 - cos(theta)**2)**9.5*(1.37724629457678e+51*cos(theta)**45 - 1.07360144222915e+52*cos(theta)**43 + 3.87784840933168e+52*cos(theta)**41 - 8.61744090962595e+52*cos(theta)**39 + 1.31932308141174e+53*cos(theta)**37 - 1.47675491129449e+53*cos(theta)**35 + 1.25166548749319e+53*cos(theta)**33 - 8.20968170678764e+52*cos(theta)**31 + 4.22290043546046e+52*cos(theta)**29 - 1.71621379058753e+52*cos(theta)**27 + 5.52652330730481e+51*cos(theta)**25 - 1.4086295600607e+51*cos(theta)**23 + 2.82843871980442e+50*cos(theta)**21 - 4.43593824614584e+49*cos(theta)**19 + 5.36453635142106e+48*cos(theta)**17 - 4.9129760524799e+47*cos(theta)**15 + 3.3238562210721e+46*cos(theta)**13 - 1.605329939589e+45*cos(theta)**11 + 5.27438152194713e+43*cos(theta)**9 - 1.09819395482994e+42*cos(theta)**7 + 1.29562208154094e+40*cos(theta)**5 - 7.09152753990663e+37*cos(theta)**3 + 1.13767821495828e+35*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl64_m_minus_18(theta, phi):
    return 1.54161692787926e-32*(1.0 - cos(theta)**2)**9*(2.99401368386257e+49*cos(theta)**46 - 2.44000327779352e+50*cos(theta)**44 + 9.23297240317066e+50*cos(theta)**42 - 2.15436022740649e+51*cos(theta)**40 + 3.47190284582037e+51*cos(theta)**38 - 4.10209697581802e+51*cos(theta)**36 + 3.68136908086233e+51*cos(theta)**34 - 2.56552553337114e+51*cos(theta)**32 + 1.40763347848682e+51*cos(theta)**30 - 6.12933496638404e+50*cos(theta)**28 + 2.12558588742493e+50*cos(theta)**26 - 5.86928983358624e+49*cos(theta)**24 + 1.28565396354746e+49*cos(theta)**22 - 2.21796912307292e+48*cos(theta)**20 + 2.9802979730117e+47*cos(theta)**18 - 3.07061003279994e+46*cos(theta)**16 + 2.3741830150515e+45*cos(theta)**14 - 1.3377749496575e+44*cos(theta)**12 + 5.27438152194713e+42*cos(theta)**10 - 1.37274244353743e+41*cos(theta)**8 + 2.15937013590157e+39*cos(theta)**6 - 1.77288188497666e+37*cos(theta)**4 + 5.68839107479141e+34*cos(theta)**2 - 2.97977531419142e+31)*sin(18*phi)

#@torch.jit.script
def Yl64_m_minus_17(theta, phi):
    return 9.57044927234678e-31*(1.0 - cos(theta)**2)**8.5*(6.37024188055867e+47*cos(theta)**47 - 5.42222950620781e+48*cos(theta)**45 + 2.14720288445829e+49*cos(theta)**43 - 5.25453714001582e+49*cos(theta)**41 + 8.90231498928301e+49*cos(theta)**39 - 1.10867485832919e+50*cos(theta)**37 + 1.05181973738924e+50*cos(theta)**35 - 7.77431979809435e+49*cos(theta)**33 + 4.54075315640909e+49*cos(theta)**31 - 2.11356378151174e+49*cos(theta)**29 + 7.87254032379602e+48*cos(theta)**27 - 2.3477159334345e+48*cos(theta)**25 + 5.58979984151071e+47*cos(theta)**23 - 1.05617577289187e+47*cos(theta)**21 + 1.56857788053247e+46*cos(theta)**19 - 1.80624119576467e+45*cos(theta)**17 + 1.582788676701e+44*cos(theta)**15 - 1.02905765358269e+43*cos(theta)**13 + 4.79489229267921e+41*cos(theta)**11 - 1.52526938170825e+40*cos(theta)**9 + 3.08481447985938e+38*cos(theta)**7 - 3.54576376995331e+36*cos(theta)**5 + 1.8961303582638e+34*cos(theta)**3 - 2.97977531419142e+31*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl64_m_minus_16(theta, phi):
    return 5.96754158074748e-29*(1.0 - cos(theta)**2)**8*(1.32713372511639e+46*cos(theta)**48 - 1.17874554482779e+47*cos(theta)**46 + 4.88000655558703e+47*cos(theta)**44 - 1.25108027143234e+48*cos(theta)**42 + 2.22557874732075e+48*cos(theta)**40 - 2.91756541665578e+48*cos(theta)**38 + 2.92172149274788e+48*cos(theta)**36 - 2.28656464649834e+48*cos(theta)**34 + 1.41898536137784e+48*cos(theta)**32 - 7.04521260503913e+47*cos(theta)**30 + 2.81162154421286e+47*cos(theta)**28 - 9.02967666705576e+46*cos(theta)**26 + 2.32908326729613e+46*cos(theta)**24 - 4.8007989676903e+45*cos(theta)**22 + 7.84288940266237e+44*cos(theta)**20 - 1.00346733098037e+44*cos(theta)**18 + 9.89242922938124e+42*cos(theta)**16 - 7.35041181130494e+41*cos(theta)**14 + 3.99574357723267e+40*cos(theta)**12 - 1.52526938170825e+39*cos(theta)**10 + 3.85601809982423e+37*cos(theta)**8 - 5.90960628325552e+35*cos(theta)**6 + 4.74032589565951e+33*cos(theta)**4 - 1.48988765709571e+31*cos(theta)**2 + 7.66403115789973e+27)*sin(16*phi)

#@torch.jit.script
def Yl64_m_minus_15(theta, phi):
    return 3.73627201727021e-27*(1.0 - cos(theta)**2)**7.5*(2.70843617370692e+44*cos(theta)**49 - 2.50796924431444e+45*cos(theta)**47 + 1.08444590124156e+46*cos(theta)**45 - 2.90948900333102e+46*cos(theta)**43 + 5.42824084712379e+46*cos(theta)**41 - 7.48093696578404e+46*cos(theta)**39 + 7.89654457499427e+46*cos(theta)**37 - 6.53304184713811e+46*cos(theta)**35 + 4.29995564053891e+46*cos(theta)**33 - 2.27264922743198e+46*cos(theta)**31 + 9.69524670418229e+45*cos(theta)**29 - 3.34432469150213e+45*cos(theta)**27 + 9.31633306918451e+44*cos(theta)**25 - 2.08730389899578e+44*cos(theta)**23 + 3.73470923936304e+43*cos(theta)**21 - 5.28140700515985e+42*cos(theta)**19 + 5.81907601728308e+41*cos(theta)**17 - 4.90027454086996e+40*cos(theta)**15 + 3.0736489055636e+39*cos(theta)**13 - 1.38660852882568e+38*cos(theta)**11 + 4.28446455536025e+36*cos(theta)**9 - 8.44229469036503e+34*cos(theta)**7 + 9.48065179131902e+32*cos(theta)**5 - 4.96629219031903e+30*cos(theta)**3 + 7.66403115789973e+27*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl64_m_minus_14(theta, phi):
    return 2.348210551011e-25*(1.0 - cos(theta)**2)**7*(5.41687234741383e+42*cos(theta)**50 - 5.22493592565508e+43*cos(theta)**48 + 2.35749108965557e+44*cos(theta)**46 - 6.6124750075705e+44*cos(theta)**44 + 1.29243829693423e+45*cos(theta)**42 - 1.87023424144601e+45*cos(theta)**40 + 2.07803804605112e+45*cos(theta)**38 - 1.81473384642725e+45*cos(theta)**36 + 1.26469283545262e+45*cos(theta)**34 - 7.10202883572493e+44*cos(theta)**32 + 3.2317489013941e+44*cos(theta)**30 - 1.19440167553648e+44*cos(theta)**28 + 3.58320502660943e+43*cos(theta)**26 - 8.6970995791491e+42*cos(theta)**24 + 1.69759510880138e+42*cos(theta)**22 - 2.64070350257992e+41*cos(theta)**20 + 3.23282000960171e+40*cos(theta)**18 - 3.06267158804373e+39*cos(theta)**16 + 2.195463503974e+38*cos(theta)**14 - 1.15550710735474e+37*cos(theta)**12 + 4.28446455536025e+35*cos(theta)**10 - 1.05528683629563e+34*cos(theta)**8 + 1.5801086318865e+32*cos(theta)**6 - 1.24157304757976e+30*cos(theta)**4 + 3.83201557894987e+27*cos(theta)**2 - 1.94026105263284e+24)*sin(14*phi)

#@torch.jit.script
def Yl64_m_minus_13(theta, phi):
    return 1.48104899061767e-23*(1.0 - cos(theta)**2)**6.5*(1.06213183282624e+41*cos(theta)**51 - 1.06631345421532e+42*cos(theta)**49 + 5.01593848862887e+42*cos(theta)**47 - 1.46943889057122e+43*cos(theta)**45 + 3.00567045798659e+43*cos(theta)**43 - 4.56154693035612e+43*cos(theta)**41 + 5.32830268218237e+43*cos(theta)**39 - 4.90468607142501e+43*cos(theta)**37 + 3.6134081012932e+43*cos(theta)**35 - 2.15212995021968e+43*cos(theta)**33 + 1.042499645611e+43*cos(theta)**31 - 4.11862646736716e+42*cos(theta)**29 + 1.32711297281831e+42*cos(theta)**27 - 3.47883983165964e+41*cos(theta)**25 + 7.38084829913643e+40*cos(theta)**23 - 1.25747785837139e+40*cos(theta)**21 + 1.70148421557985e+39*cos(theta)**19 - 1.80157152237866e+38*cos(theta)**17 + 1.46364233598266e+37*cos(theta)**15 - 8.88851621042104e+35*cos(theta)**13 + 3.89496777760023e+34*cos(theta)**11 - 1.17254092921737e+33*cos(theta)**9 + 2.25729804555215e+31*cos(theta)**7 - 2.48314609515951e+29*cos(theta)**5 + 1.27733852631662e+27*cos(theta)**3 - 1.94026105263284e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl64_m_minus_12(theta, phi):
    return 9.37165859114006e-22*(1.0 - cos(theta)**2)**6*(2.04256121697354e+39*cos(theta)**52 - 2.13262690843064e+40*cos(theta)**50 + 1.04498718513102e+41*cos(theta)**48 - 3.19443237080701e+41*cos(theta)**46 + 6.8310692226968e+41*cos(theta)**44 - 1.08608260246574e+42*cos(theta)**42 + 1.33207567054559e+42*cos(theta)**40 - 1.29070686090132e+42*cos(theta)**38 + 1.00372447258145e+42*cos(theta)**36 - 6.32979397123434e+41*cos(theta)**34 + 3.25781139253437e+41*cos(theta)**32 - 1.37287548912239e+41*cos(theta)**30 + 4.73968918863681e+40*cos(theta)**28 - 1.33801531986909e+40*cos(theta)**26 + 3.07535345797351e+39*cos(theta)**24 - 5.71580844714269e+38*cos(theta)**22 + 8.50742107789924e+37*cos(theta)**20 - 1.00087306798815e+37*cos(theta)**18 + 9.14776459989165e+35*cos(theta)**16 - 6.34894015030074e+34*cos(theta)**14 + 3.24580648133353e+33*cos(theta)**12 - 1.17254092921737e+32*cos(theta)**10 + 2.82162255694018e+30*cos(theta)**8 - 4.13857682526586e+28*cos(theta)**6 + 3.19334631579155e+26*cos(theta)**4 - 9.70130526316422e+23*cos(theta)**2 + 4.84580682475735e+20)*sin(12*phi)

#@torch.jit.script
def Yl64_m_minus_11(theta, phi):
    return 5.94786619359015e-20*(1.0 - cos(theta)**2)**5.5*(3.85388908862933e+37*cos(theta)**53 - 4.18162138907969e+38*cos(theta)**51 + 2.13262690843064e+39*cos(theta)**49 - 6.79666461873831e+39*cos(theta)**47 + 1.51801538282151e+40*cos(theta)**45 - 2.52577349410638e+40*cos(theta)**43 + 3.2489650501112e+40*cos(theta)**41 - 3.30950477154184e+40*cos(theta)**39 + 2.71276884481472e+40*cos(theta)**37 - 1.80851256320981e+40*cos(theta)**35 + 9.87215573495264e+39*cos(theta)**33 - 4.42863061007221e+39*cos(theta)**31 + 1.63437558228856e+39*cos(theta)**29 - 4.95561229581145e+38*cos(theta)**27 + 1.23014138318941e+38*cos(theta)**25 - 2.48513410745334e+37*cos(theta)**23 + 4.05115289423773e+36*cos(theta)**21 - 5.26775298941129e+35*cos(theta)**19 + 5.38103799993627e+34*cos(theta)**17 - 4.23262676686716e+33*cos(theta)**15 + 2.4967742164104e+32*cos(theta)**13 - 1.06594629928851e+31*cos(theta)**11 + 3.13513617437798e+29*cos(theta)**9 - 5.91225260752265e+27*cos(theta)**7 + 6.38669263158311e+25*cos(theta)**5 - 3.23376842105474e+23*cos(theta)**3 + 4.84580682475735e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl64_m_minus_10(theta, phi):
    return 3.78519886717003e-18*(1.0 - cos(theta)**2)**5*(7.13683164560986e+35*cos(theta)**54 - 8.04157959438403e+36*cos(theta)**52 + 4.26525381686129e+37*cos(theta)**50 - 1.41597179557048e+38*cos(theta)**48 + 3.30003344091633e+38*cos(theta)**46 - 5.74039430478723e+38*cos(theta)**44 + 7.73563107169333e+38*cos(theta)**42 - 8.2737619288546e+38*cos(theta)**40 + 7.13886538109136e+38*cos(theta)**38 - 5.02364600891614e+38*cos(theta)**36 + 2.90357521616254e+38*cos(theta)**34 - 1.38394706564757e+38*cos(theta)**32 + 5.44791860762852e+37*cos(theta)**30 - 1.76986153421838e+37*cos(theta)**28 + 4.73131301226694e+36*cos(theta)**26 - 1.03547254477223e+36*cos(theta)**24 + 1.84143313374442e+35*cos(theta)**22 - 2.63387649470565e+34*cos(theta)**20 + 2.98946555552015e+33*cos(theta)**18 - 2.64539172929198e+32*cos(theta)**16 + 1.78341015457886e+31*cos(theta)**14 - 8.88288582740429e+29*cos(theta)**12 + 3.13513617437798e+28*cos(theta)**10 - 7.39031575940331e+26*cos(theta)**8 + 1.06444877193052e+25*cos(theta)**6 - 8.08442105263685e+22*cos(theta)**4 + 2.42290341237868e+20*cos(theta)**2 - 1.19649551228577e+17)*sin(10*phi)

#@torch.jit.script
def Yl64_m_minus_9(theta, phi):
    return 2.41482634962813e-16*(1.0 - cos(theta)**2)**4.5*(1.29760575374725e+34*cos(theta)**55 - 1.5172791687517e+35*cos(theta)**53 + 8.36324277815939e+35*cos(theta)**51 - 2.8897383583071e+36*cos(theta)**49 + 7.02134774663049e+36*cos(theta)**47 - 1.27564317884161e+37*cos(theta)**45 + 1.79898397016124e+37*cos(theta)**43 - 2.01799071435478e+37*cos(theta)**41 + 1.83047830284394e+37*cos(theta)**39 - 1.35774216457193e+37*cos(theta)**37 + 8.29592918903583e+36*cos(theta)**35 - 4.19377898681081e+36*cos(theta)**33 + 1.75739309923501e+36*cos(theta)**31 - 6.10297080764957e+35*cos(theta)**29 + 1.75233815269146e+35*cos(theta)**27 - 4.14189017908891e+34*cos(theta)**25 + 8.0062310162801e+33*cos(theta)**23 - 1.25422690224078e+33*cos(theta)**21 + 1.57340292395797e+32*cos(theta)**19 - 1.55611278193646e+31*cos(theta)**17 + 1.18894010305257e+30*cos(theta)**15 - 6.8329890980033e+28*cos(theta)**13 + 2.85012379488908e+27*cos(theta)**11 - 8.21146195489257e+25*cos(theta)**9 + 1.52064110275788e+24*cos(theta)**7 - 1.61688421052737e+22*cos(theta)**5 + 8.07634470792892e+19*cos(theta)**3 - 1.19649551228577e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl64_m_minus_8(theta, phi):
    return 1.54397885962641e-14*(1.0 - cos(theta)**2)**4*(2.31715313169151e+32*cos(theta)**56 - 2.80977623842908e+33*cos(theta)**54 + 1.60831591887681e+34*cos(theta)**52 - 5.77947671661421e+34*cos(theta)**50 + 1.46278078054802e+35*cos(theta)**48 - 2.77313734530784e+35*cos(theta)**46 + 4.08859993218463e+35*cos(theta)**44 - 4.80473979608281e+35*cos(theta)**42 + 4.57619575710985e+35*cos(theta)**40 - 3.57300569624192e+35*cos(theta)**38 + 2.30442477473218e+35*cos(theta)**36 - 1.23346440788553e+35*cos(theta)**34 + 5.49185343510939e+34*cos(theta)**32 - 2.03432360254986e+34*cos(theta)**30 + 6.25835054532665e+33*cos(theta)**28 - 1.59303468426496e+33*cos(theta)**26 + 3.33592959011671e+32*cos(theta)**24 - 5.70103137382175e+31*cos(theta)**22 + 7.86701461978987e+30*cos(theta)**20 - 8.64507101075809e+29*cos(theta)**18 + 7.43087564407859e+28*cos(theta)**16 - 4.88070649857378e+27*cos(theta)**14 + 2.37510316240756e+26*cos(theta)**12 - 8.21146195489257e+24*cos(theta)**10 + 1.90080137844735e+23*cos(theta)**8 - 2.69480701754562e+21*cos(theta)**6 + 2.01908617698223e+19*cos(theta)**4 - 5.98247756142883e+16*cos(theta)**2 + 29268481220297.6)*sin(8*phi)

#@torch.jit.script
def Yl64_m_minus_7(theta, phi):
    return 9.89110986222795e-13*(1.0 - cos(theta)**2)**3.5*(4.06518093279213e+30*cos(theta)**57 - 5.10868406987105e+31*cos(theta)**55 + 3.03455833750341e+32*cos(theta)**53 - 1.13323072874788e+33*cos(theta)**51 + 2.98526689907759e+33*cos(theta)**49 - 5.90029222405923e+33*cos(theta)**47 + 9.08577762707697e+33*cos(theta)**45 - 1.11738134792624e+34*cos(theta)**43 + 1.11614530661216e+34*cos(theta)**41 - 9.16155306728698e+33*cos(theta)**39 + 6.22817506684372e+33*cos(theta)**37 - 3.52418402253009e+33*cos(theta)**35 + 1.66419801063921e+33*cos(theta)**33 - 6.56233420177373e+32*cos(theta)**31 + 2.1580519121816e+32*cos(theta)**29 - 5.90012846024061e+31*cos(theta)**27 + 1.33437183604668e+31*cos(theta)**25 - 2.47870929296598e+30*cos(theta)**23 + 3.74619743799517e+29*cos(theta)**21 - 4.55003737408321e+28*cos(theta)**19 + 4.37110332004623e+27*cos(theta)**17 - 3.25380433238252e+26*cos(theta)**15 + 1.8270024326212e+25*cos(theta)**13 - 7.4649654135387e+23*cos(theta)**11 + 2.11200153160817e+22*cos(theta)**9 - 3.84972431077945e+20*cos(theta)**7 + 4.03817235396446e+18*cos(theta)**5 - 1.99415918714294e+16*cos(theta)**3 + 29268481220297.6*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl64_m_minus_6(theta, phi):
    return 6.34728789038939e-11*(1.0 - cos(theta)**2)**3*(7.00893264274505e+28*cos(theta)**58 - 9.12265012476974e+29*cos(theta)**56 + 5.61955247685816e+30*cos(theta)**54 - 2.1792898629767e+31*cos(theta)**52 + 5.97053379815518e+31*cos(theta)**50 - 1.22922754667901e+32*cos(theta)**48 + 1.97516904936456e+32*cos(theta)**46 - 2.53950306346872e+32*cos(theta)**44 + 2.65748882526704e+32*cos(theta)**42 - 2.29038826682175e+32*cos(theta)**40 + 1.63899343864308e+32*cos(theta)**38 - 9.78940006258359e+31*cos(theta)**36 + 4.89470003129179e+31*cos(theta)**34 - 2.05072943805429e+31*cos(theta)**32 + 7.19350637393867e+30*cos(theta)**30 - 2.10718873580022e+30*cos(theta)**28 + 5.13219936941032e+29*cos(theta)**26 - 1.03279553873582e+29*cos(theta)**24 + 1.70281701727053e+28*cos(theta)**22 - 2.2750186870416e+27*cos(theta)**20 + 2.42839073335901e+26*cos(theta)**18 - 2.03362770773908e+25*cos(theta)**16 + 1.30500173758657e+24*cos(theta)**14 - 6.22080451128225e+22*cos(theta)**12 + 2.11200153160817e+21*cos(theta)**10 - 4.81215538847431e+19*cos(theta)**8 + 6.73028725660743e+17*cos(theta)**6 - 4.98539796785736e+15*cos(theta)**4 + 14634240610148.8*cos(theta)**2 - 7107450514.88528)*sin(6*phi)

#@torch.jit.script
def Yl64_m_minus_5(theta, phi):
    return 4.07908939001327e-9*(1.0 - cos(theta)**2)**2.5*(1.18795468521103e+27*cos(theta)**59 - 1.60046493417013e+28*cos(theta)**57 + 1.02173681397421e+29*cos(theta)**55 - 4.11186766599377e+29*cos(theta)**53 + 1.17069290159905e+30*cos(theta)**51 - 2.50862764628369e+30*cos(theta)**49 + 4.20248733907353e+30*cos(theta)**47 - 5.64334014104159e+30*cos(theta)**45 + 6.18020657038847e+30*cos(theta)**43 - 5.5863128459067e+30*cos(theta)**41 + 4.20254727857201e+30*cos(theta)**39 - 2.64578380069827e+30*cos(theta)**37 + 1.39848572322623e+30*cos(theta)**35 - 6.21433163046755e+29*cos(theta)**33 + 2.32048592707699e+29*cos(theta)**31 - 7.26616805448351e+28*cos(theta)**29 + 1.90081458126308e+28*cos(theta)**27 - 4.13118215494329e+27*cos(theta)**25 + 7.40355224900232e+26*cos(theta)**23 - 1.08334223192457e+26*cos(theta)**21 + 1.27810038597843e+25*cos(theta)**19 - 1.19625159278769e+24*cos(theta)**17 + 8.70001158391049e+22*cos(theta)**15 - 4.78523423944788e+21*cos(theta)**13 + 1.92000139237106e+20*cos(theta)**11 - 5.34683932052702e+18*cos(theta)**9 + 9.61469608086776e+16*cos(theta)**7 - 997079593571472.0*cos(theta)**5 + 4878080203382.93*cos(theta)**3 - 7107450514.88528*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl64_m_minus_4(theta, phi):
    return 2.6246016239063e-7*(1.0 - cos(theta)**2)**2*(1.97992447535171e+25*cos(theta)**60 - 2.75942230029333e+26*cos(theta)**58 + 1.82453002495395e+27*cos(theta)**56 - 7.61456975184032e+27*cos(theta)**54 + 2.2513325030751e+28*cos(theta)**52 - 5.01725529256737e+28*cos(theta)**50 + 8.75518195640318e+28*cos(theta)**48 - 1.22681307413948e+29*cos(theta)**46 + 1.40459240236102e+29*cos(theta)**44 - 1.33007448712064e+29*cos(theta)**42 + 1.050636819643e+29*cos(theta)**40 - 6.96258894920596e+28*cos(theta)**38 + 3.8846825645173e+28*cos(theta)**36 - 1.82774459719634e+28*cos(theta)**34 + 7.2515185221156e+27*cos(theta)**32 - 2.42205601816117e+27*cos(theta)**30 + 6.78862350451101e+26*cos(theta)**28 - 1.58891621343973e+26*cos(theta)**26 + 3.0848134370843e+25*cos(theta)**24 - 4.92428287238442e+24*cos(theta)**22 + 6.39050192989214e+23*cos(theta)**20 - 6.64584218215384e+22*cos(theta)**18 + 5.43750723994406e+21*cos(theta)**16 - 3.41802445674849e+20*cos(theta)**14 + 1.60000116030922e+19*cos(theta)**12 - 5.34683932052702e+17*cos(theta)**10 + 1.20183701010847e+16*cos(theta)**8 - 166179932261912.0*cos(theta)**6 + 1219520050845.73*cos(theta)**4 - 3553725257.44264*cos(theta)**2 + 1716775.48668727)*sin(4*phi)

#@torch.jit.script
def Yl64_m_minus_3(theta, phi):
    return 1.69037385575232e-5*(1.0 - cos(theta)**2)**1.5*(3.24577782844542e+23*cos(theta)**61 - 4.67698694964971e+24*cos(theta)**59 + 3.20092986834026e+25*cos(theta)**57 - 1.38446722760733e+26*cos(theta)**55 + 4.2477971756134e+26*cos(theta)**53 - 9.8377554756223e+26*cos(theta)**51 + 1.78677182783738e+27*cos(theta)**49 - 2.61024058327548e+27*cos(theta)**47 + 3.12131644969115e+27*cos(theta)**45 - 3.09319648167591e+27*cos(theta)**43 + 2.56252882839757e+27*cos(theta)**41 - 1.78527921774512e+27*cos(theta)**39 + 1.0499142066263e+27*cos(theta)**37 - 5.22212742056097e+26*cos(theta)**35 + 2.19742985518654e+26*cos(theta)**33 - 7.81308392955216e+25*cos(theta)**31 + 2.34090465672793e+25*cos(theta)**29 - 5.88487486459159e+24*cos(theta)**27 + 1.23392537483372e+24*cos(theta)**25 - 2.14099255321062e+23*cos(theta)**23 + 3.0430961570915e+22*cos(theta)**21 - 3.49781167481781e+21*cos(theta)**19 + 3.19853367055533e+20*cos(theta)**17 - 2.27868297116566e+19*cos(theta)**15 + 1.23077012331479e+18*cos(theta)**13 - 4.86076301866092e+16*cos(theta)**11 + 1.33537445567608e+15*cos(theta)**9 - 23739990323130.3*cos(theta)**7 + 243904010169.147*cos(theta)**5 - 1184575085.81421*cos(theta)**3 + 1716775.48668727*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl64_m_minus_2(theta, phi):
    return 0.00108947184955667*(1.0 - cos(theta)**2)*(5.23512552975069e+21*cos(theta)**62 - 7.79497824941618e+22*cos(theta)**60 + 5.51884460058665e+23*cos(theta)**58 - 2.47226290644166e+24*cos(theta)**56 + 7.86629106595075e+24*cos(theta)**54 - 1.89187605300429e+25*cos(theta)**52 + 3.57354365567477e+25*cos(theta)**50 - 5.43800121515726e+25*cos(theta)**48 + 6.78547054280684e+25*cos(theta)**46 - 7.02999200380889e+25*cos(theta)**44 + 6.1012591152323e+25*cos(theta)**42 - 4.4631980443628e+25*cos(theta)**40 + 2.76293212270078e+25*cos(theta)**38 - 1.45059095015582e+25*cos(theta)**36 + 6.46302898584278e+24*cos(theta)**34 - 2.44158872798505e+24*cos(theta)**32 + 7.80301552242645e+23*cos(theta)**30 - 2.10174102306842e+23*cos(theta)**28 + 4.74586682628354e+22*cos(theta)**26 - 8.92080230504424e+21*cos(theta)**24 + 1.38322552595068e+21*cos(theta)**22 - 1.74890583740891e+20*cos(theta)**20 + 1.77696315030851e+19*cos(theta)**18 - 1.42417685697854e+18*cos(theta)**16 + 8.79121516653418e+16*cos(theta)**14 - 4.0506358488841e+15*cos(theta)**12 + 133537445567608.0*cos(theta)**10 - 2967498790391.28*cos(theta)**8 + 40650668361.5244*cos(theta)**6 - 296143771.453553*cos(theta)**4 + 858387.743343633*cos(theta)**2 - 413.282495591542)*sin(2*phi)

#@torch.jit.script
def Yl64_m_minus_1(theta, phi):
    return 0.0702519293104469*(1.0 - cos(theta)**2)**0.5*(8.30972306309633e+19*cos(theta)**63 - 1.27786528678954e+21*cos(theta)**61 + 9.35397389929941e+21*cos(theta)**59 - 4.3373033446345e+22*cos(theta)**57 + 1.43023473926377e+23*cos(theta)**55 - 3.56957745849866e+23*cos(theta)**53 + 7.00694834446033e+23*cos(theta)**51 - 1.10979616635862e+24*cos(theta)**49 + 1.44371713676741e+24*cos(theta)**47 - 1.56222044529086e+24*cos(theta)**45 + 1.41889746865868e+24*cos(theta)**43 - 1.08858488886898e+24*cos(theta)**41 + 7.08444134025841e+23*cos(theta)**39 - 3.92051608150223e+23*cos(theta)**37 + 1.84657971024079e+23*cos(theta)**35 - 7.39875372116682e+22*cos(theta)**33 + 2.51710178142789e+22*cos(theta)**31 - 7.24738283816698e+21*cos(theta)**29 + 1.75772845417909e+21*cos(theta)**27 - 3.5683209220177e+20*cos(theta)**25 + 6.01402402587252e+19*cos(theta)**23 - 8.32812303528051e+18*cos(theta)**21 + 9.35243763320271e+17*cos(theta)**19 - 8.37751092340316e+16*cos(theta)**17 + 5.86081011102279e+15*cos(theta)**15 - 311587372991085.0*cos(theta)**13 + 12139767778873.4*cos(theta)**11 - 329722087821.254*cos(theta)**9 + 5807238337.36063*cos(theta)**7 - 59228754.2907107*cos(theta)**5 + 286129.247781211*cos(theta)**3 - 413.282495591542*cos(theta))*sin(phi)

#@torch.jit.script
def Yl64_m0(theta, phi):
    return 1.30691207991104e+19*cos(theta)**64 - 2.07459429378005e+20*cos(theta)**62 + 1.56922312381523e+21*cos(theta)**60 - 7.5271678296828e+21*cos(theta)**58 + 2.57074554183175e+22*cos(theta)**56 - 6.65369434356453e+22*cos(theta)**54 + 1.35633000080354e+23*cos(theta)**52 - 2.23415351685154e+23*cos(theta)**50 + 3.02747572803445e+23*cos(theta)**48 - 3.41841103225511e+23*cos(theta)**46 + 3.24592240218719e+23*cos(theta)**44 - 2.60887221110373e+23*cos(theta)**42 + 1.78272934425421e+23*cos(theta)**40 - 1.03848311315779e+23*cos(theta)**38 + 5.16303839144221e+22*cos(theta)**36 - 2.19037992364215e+22*cos(theta)**34 + 7.91754598687659e+21*cos(theta)**32 - 2.43164260649584e+21*cos(theta)**30 + 6.31878455093006e+20*cos(theta)**28 - 1.3814346791507e+20*cos(theta)**26 + 2.52228241979763e+19*cos(theta)**24 - 3.81034454222302e+18*cos(theta)**22 + 4.70689619921667e+17*cos(theta)**20 - 4.68470548900559e+16*cos(theta)**18 + 3.68703672745811e+15*cos(theta)**16 - 224022484706315.0*cos(theta)**14 + 10182840213923.4*cos(theta)**12 - 331885162527.874*cos(theta)**10 + 7306669429.42972*cos(theta)**8 - 99362187.4813172*cos(theta)**6 + 720015.851313893*cos(theta)**4 - 2079.9687568047*cos(theta)**2 + 0.999984979233028

#@torch.jit.script
def Yl64_m1(theta, phi):
    return 0.0702519293104469*(1.0 - cos(theta)**2)**0.5*(8.30972306309633e+19*cos(theta)**63 - 1.27786528678954e+21*cos(theta)**61 + 9.35397389929941e+21*cos(theta)**59 - 4.3373033446345e+22*cos(theta)**57 + 1.43023473926377e+23*cos(theta)**55 - 3.56957745849866e+23*cos(theta)**53 + 7.00694834446033e+23*cos(theta)**51 - 1.10979616635862e+24*cos(theta)**49 + 1.44371713676741e+24*cos(theta)**47 - 1.56222044529086e+24*cos(theta)**45 + 1.41889746865868e+24*cos(theta)**43 - 1.08858488886898e+24*cos(theta)**41 + 7.08444134025841e+23*cos(theta)**39 - 3.92051608150223e+23*cos(theta)**37 + 1.84657971024079e+23*cos(theta)**35 - 7.39875372116682e+22*cos(theta)**33 + 2.51710178142789e+22*cos(theta)**31 - 7.24738283816698e+21*cos(theta)**29 + 1.75772845417909e+21*cos(theta)**27 - 3.5683209220177e+20*cos(theta)**25 + 6.01402402587252e+19*cos(theta)**23 - 8.32812303528051e+18*cos(theta)**21 + 9.35243763320271e+17*cos(theta)**19 - 8.37751092340316e+16*cos(theta)**17 + 5.86081011102279e+15*cos(theta)**15 - 311587372991085.0*cos(theta)**13 + 12139767778873.4*cos(theta)**11 - 329722087821.254*cos(theta)**9 + 5807238337.36063*cos(theta)**7 - 59228754.2907107*cos(theta)**5 + 286129.247781211*cos(theta)**3 - 413.282495591542*cos(theta))*cos(phi)

#@torch.jit.script
def Yl64_m2(theta, phi):
    return 0.00108947184955667*(1.0 - cos(theta)**2)*(5.23512552975069e+21*cos(theta)**62 - 7.79497824941618e+22*cos(theta)**60 + 5.51884460058665e+23*cos(theta)**58 - 2.47226290644166e+24*cos(theta)**56 + 7.86629106595075e+24*cos(theta)**54 - 1.89187605300429e+25*cos(theta)**52 + 3.57354365567477e+25*cos(theta)**50 - 5.43800121515726e+25*cos(theta)**48 + 6.78547054280684e+25*cos(theta)**46 - 7.02999200380889e+25*cos(theta)**44 + 6.1012591152323e+25*cos(theta)**42 - 4.4631980443628e+25*cos(theta)**40 + 2.76293212270078e+25*cos(theta)**38 - 1.45059095015582e+25*cos(theta)**36 + 6.46302898584278e+24*cos(theta)**34 - 2.44158872798505e+24*cos(theta)**32 + 7.80301552242645e+23*cos(theta)**30 - 2.10174102306842e+23*cos(theta)**28 + 4.74586682628354e+22*cos(theta)**26 - 8.92080230504424e+21*cos(theta)**24 + 1.38322552595068e+21*cos(theta)**22 - 1.74890583740891e+20*cos(theta)**20 + 1.77696315030851e+19*cos(theta)**18 - 1.42417685697854e+18*cos(theta)**16 + 8.79121516653418e+16*cos(theta)**14 - 4.0506358488841e+15*cos(theta)**12 + 133537445567608.0*cos(theta)**10 - 2967498790391.28*cos(theta)**8 + 40650668361.5244*cos(theta)**6 - 296143771.453553*cos(theta)**4 + 858387.743343633*cos(theta)**2 - 413.282495591542)*cos(2*phi)

#@torch.jit.script
def Yl64_m3(theta, phi):
    return 1.69037385575232e-5*(1.0 - cos(theta)**2)**1.5*(3.24577782844542e+23*cos(theta)**61 - 4.67698694964971e+24*cos(theta)**59 + 3.20092986834026e+25*cos(theta)**57 - 1.38446722760733e+26*cos(theta)**55 + 4.2477971756134e+26*cos(theta)**53 - 9.8377554756223e+26*cos(theta)**51 + 1.78677182783738e+27*cos(theta)**49 - 2.61024058327548e+27*cos(theta)**47 + 3.12131644969115e+27*cos(theta)**45 - 3.09319648167591e+27*cos(theta)**43 + 2.56252882839757e+27*cos(theta)**41 - 1.78527921774512e+27*cos(theta)**39 + 1.0499142066263e+27*cos(theta)**37 - 5.22212742056097e+26*cos(theta)**35 + 2.19742985518654e+26*cos(theta)**33 - 7.81308392955216e+25*cos(theta)**31 + 2.34090465672793e+25*cos(theta)**29 - 5.88487486459159e+24*cos(theta)**27 + 1.23392537483372e+24*cos(theta)**25 - 2.14099255321062e+23*cos(theta)**23 + 3.0430961570915e+22*cos(theta)**21 - 3.49781167481781e+21*cos(theta)**19 + 3.19853367055533e+20*cos(theta)**17 - 2.27868297116566e+19*cos(theta)**15 + 1.23077012331479e+18*cos(theta)**13 - 4.86076301866092e+16*cos(theta)**11 + 1.33537445567608e+15*cos(theta)**9 - 23739990323130.3*cos(theta)**7 + 243904010169.147*cos(theta)**5 - 1184575085.81421*cos(theta)**3 + 1716775.48668727*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl64_m4(theta, phi):
    return 2.6246016239063e-7*(1.0 - cos(theta)**2)**2*(1.97992447535171e+25*cos(theta)**60 - 2.75942230029333e+26*cos(theta)**58 + 1.82453002495395e+27*cos(theta)**56 - 7.61456975184032e+27*cos(theta)**54 + 2.2513325030751e+28*cos(theta)**52 - 5.01725529256737e+28*cos(theta)**50 + 8.75518195640318e+28*cos(theta)**48 - 1.22681307413948e+29*cos(theta)**46 + 1.40459240236102e+29*cos(theta)**44 - 1.33007448712064e+29*cos(theta)**42 + 1.050636819643e+29*cos(theta)**40 - 6.96258894920596e+28*cos(theta)**38 + 3.8846825645173e+28*cos(theta)**36 - 1.82774459719634e+28*cos(theta)**34 + 7.2515185221156e+27*cos(theta)**32 - 2.42205601816117e+27*cos(theta)**30 + 6.78862350451101e+26*cos(theta)**28 - 1.58891621343973e+26*cos(theta)**26 + 3.0848134370843e+25*cos(theta)**24 - 4.92428287238442e+24*cos(theta)**22 + 6.39050192989214e+23*cos(theta)**20 - 6.64584218215384e+22*cos(theta)**18 + 5.43750723994406e+21*cos(theta)**16 - 3.41802445674849e+20*cos(theta)**14 + 1.60000116030922e+19*cos(theta)**12 - 5.34683932052702e+17*cos(theta)**10 + 1.20183701010847e+16*cos(theta)**8 - 166179932261912.0*cos(theta)**6 + 1219520050845.73*cos(theta)**4 - 3553725257.44264*cos(theta)**2 + 1716775.48668727)*cos(4*phi)

#@torch.jit.script
def Yl64_m5(theta, phi):
    return 4.07908939001327e-9*(1.0 - cos(theta)**2)**2.5*(1.18795468521103e+27*cos(theta)**59 - 1.60046493417013e+28*cos(theta)**57 + 1.02173681397421e+29*cos(theta)**55 - 4.11186766599377e+29*cos(theta)**53 + 1.17069290159905e+30*cos(theta)**51 - 2.50862764628369e+30*cos(theta)**49 + 4.20248733907353e+30*cos(theta)**47 - 5.64334014104159e+30*cos(theta)**45 + 6.18020657038847e+30*cos(theta)**43 - 5.5863128459067e+30*cos(theta)**41 + 4.20254727857201e+30*cos(theta)**39 - 2.64578380069827e+30*cos(theta)**37 + 1.39848572322623e+30*cos(theta)**35 - 6.21433163046755e+29*cos(theta)**33 + 2.32048592707699e+29*cos(theta)**31 - 7.26616805448351e+28*cos(theta)**29 + 1.90081458126308e+28*cos(theta)**27 - 4.13118215494329e+27*cos(theta)**25 + 7.40355224900232e+26*cos(theta)**23 - 1.08334223192457e+26*cos(theta)**21 + 1.27810038597843e+25*cos(theta)**19 - 1.19625159278769e+24*cos(theta)**17 + 8.70001158391049e+22*cos(theta)**15 - 4.78523423944788e+21*cos(theta)**13 + 1.92000139237106e+20*cos(theta)**11 - 5.34683932052702e+18*cos(theta)**9 + 9.61469608086776e+16*cos(theta)**7 - 997079593571472.0*cos(theta)**5 + 4878080203382.93*cos(theta)**3 - 7107450514.88528*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl64_m6(theta, phi):
    return 6.34728789038939e-11*(1.0 - cos(theta)**2)**3*(7.00893264274505e+28*cos(theta)**58 - 9.12265012476974e+29*cos(theta)**56 + 5.61955247685816e+30*cos(theta)**54 - 2.1792898629767e+31*cos(theta)**52 + 5.97053379815518e+31*cos(theta)**50 - 1.22922754667901e+32*cos(theta)**48 + 1.97516904936456e+32*cos(theta)**46 - 2.53950306346872e+32*cos(theta)**44 + 2.65748882526704e+32*cos(theta)**42 - 2.29038826682175e+32*cos(theta)**40 + 1.63899343864308e+32*cos(theta)**38 - 9.78940006258359e+31*cos(theta)**36 + 4.89470003129179e+31*cos(theta)**34 - 2.05072943805429e+31*cos(theta)**32 + 7.19350637393867e+30*cos(theta)**30 - 2.10718873580022e+30*cos(theta)**28 + 5.13219936941032e+29*cos(theta)**26 - 1.03279553873582e+29*cos(theta)**24 + 1.70281701727053e+28*cos(theta)**22 - 2.2750186870416e+27*cos(theta)**20 + 2.42839073335901e+26*cos(theta)**18 - 2.03362770773908e+25*cos(theta)**16 + 1.30500173758657e+24*cos(theta)**14 - 6.22080451128225e+22*cos(theta)**12 + 2.11200153160817e+21*cos(theta)**10 - 4.81215538847431e+19*cos(theta)**8 + 6.73028725660743e+17*cos(theta)**6 - 4.98539796785736e+15*cos(theta)**4 + 14634240610148.8*cos(theta)**2 - 7107450514.88528)*cos(6*phi)

#@torch.jit.script
def Yl64_m7(theta, phi):
    return 9.89110986222795e-13*(1.0 - cos(theta)**2)**3.5*(4.06518093279213e+30*cos(theta)**57 - 5.10868406987105e+31*cos(theta)**55 + 3.03455833750341e+32*cos(theta)**53 - 1.13323072874788e+33*cos(theta)**51 + 2.98526689907759e+33*cos(theta)**49 - 5.90029222405923e+33*cos(theta)**47 + 9.08577762707697e+33*cos(theta)**45 - 1.11738134792624e+34*cos(theta)**43 + 1.11614530661216e+34*cos(theta)**41 - 9.16155306728698e+33*cos(theta)**39 + 6.22817506684372e+33*cos(theta)**37 - 3.52418402253009e+33*cos(theta)**35 + 1.66419801063921e+33*cos(theta)**33 - 6.56233420177373e+32*cos(theta)**31 + 2.1580519121816e+32*cos(theta)**29 - 5.90012846024061e+31*cos(theta)**27 + 1.33437183604668e+31*cos(theta)**25 - 2.47870929296598e+30*cos(theta)**23 + 3.74619743799517e+29*cos(theta)**21 - 4.55003737408321e+28*cos(theta)**19 + 4.37110332004623e+27*cos(theta)**17 - 3.25380433238252e+26*cos(theta)**15 + 1.8270024326212e+25*cos(theta)**13 - 7.4649654135387e+23*cos(theta)**11 + 2.11200153160817e+22*cos(theta)**9 - 3.84972431077945e+20*cos(theta)**7 + 4.03817235396446e+18*cos(theta)**5 - 1.99415918714294e+16*cos(theta)**3 + 29268481220297.6*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl64_m8(theta, phi):
    return 1.54397885962641e-14*(1.0 - cos(theta)**2)**4*(2.31715313169151e+32*cos(theta)**56 - 2.80977623842908e+33*cos(theta)**54 + 1.60831591887681e+34*cos(theta)**52 - 5.77947671661421e+34*cos(theta)**50 + 1.46278078054802e+35*cos(theta)**48 - 2.77313734530784e+35*cos(theta)**46 + 4.08859993218463e+35*cos(theta)**44 - 4.80473979608281e+35*cos(theta)**42 + 4.57619575710985e+35*cos(theta)**40 - 3.57300569624192e+35*cos(theta)**38 + 2.30442477473218e+35*cos(theta)**36 - 1.23346440788553e+35*cos(theta)**34 + 5.49185343510939e+34*cos(theta)**32 - 2.03432360254986e+34*cos(theta)**30 + 6.25835054532665e+33*cos(theta)**28 - 1.59303468426496e+33*cos(theta)**26 + 3.33592959011671e+32*cos(theta)**24 - 5.70103137382175e+31*cos(theta)**22 + 7.86701461978987e+30*cos(theta)**20 - 8.64507101075809e+29*cos(theta)**18 + 7.43087564407859e+28*cos(theta)**16 - 4.88070649857378e+27*cos(theta)**14 + 2.37510316240756e+26*cos(theta)**12 - 8.21146195489257e+24*cos(theta)**10 + 1.90080137844735e+23*cos(theta)**8 - 2.69480701754562e+21*cos(theta)**6 + 2.01908617698223e+19*cos(theta)**4 - 5.98247756142883e+16*cos(theta)**2 + 29268481220297.6)*cos(8*phi)

#@torch.jit.script
def Yl64_m9(theta, phi):
    return 2.41482634962813e-16*(1.0 - cos(theta)**2)**4.5*(1.29760575374725e+34*cos(theta)**55 - 1.5172791687517e+35*cos(theta)**53 + 8.36324277815939e+35*cos(theta)**51 - 2.8897383583071e+36*cos(theta)**49 + 7.02134774663049e+36*cos(theta)**47 - 1.27564317884161e+37*cos(theta)**45 + 1.79898397016124e+37*cos(theta)**43 - 2.01799071435478e+37*cos(theta)**41 + 1.83047830284394e+37*cos(theta)**39 - 1.35774216457193e+37*cos(theta)**37 + 8.29592918903583e+36*cos(theta)**35 - 4.19377898681081e+36*cos(theta)**33 + 1.75739309923501e+36*cos(theta)**31 - 6.10297080764957e+35*cos(theta)**29 + 1.75233815269146e+35*cos(theta)**27 - 4.14189017908891e+34*cos(theta)**25 + 8.0062310162801e+33*cos(theta)**23 - 1.25422690224078e+33*cos(theta)**21 + 1.57340292395797e+32*cos(theta)**19 - 1.55611278193646e+31*cos(theta)**17 + 1.18894010305257e+30*cos(theta)**15 - 6.8329890980033e+28*cos(theta)**13 + 2.85012379488908e+27*cos(theta)**11 - 8.21146195489257e+25*cos(theta)**9 + 1.52064110275788e+24*cos(theta)**7 - 1.61688421052737e+22*cos(theta)**5 + 8.07634470792892e+19*cos(theta)**3 - 1.19649551228577e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl64_m10(theta, phi):
    return 3.78519886717003e-18*(1.0 - cos(theta)**2)**5*(7.13683164560986e+35*cos(theta)**54 - 8.04157959438403e+36*cos(theta)**52 + 4.26525381686129e+37*cos(theta)**50 - 1.41597179557048e+38*cos(theta)**48 + 3.30003344091633e+38*cos(theta)**46 - 5.74039430478723e+38*cos(theta)**44 + 7.73563107169333e+38*cos(theta)**42 - 8.2737619288546e+38*cos(theta)**40 + 7.13886538109136e+38*cos(theta)**38 - 5.02364600891614e+38*cos(theta)**36 + 2.90357521616254e+38*cos(theta)**34 - 1.38394706564757e+38*cos(theta)**32 + 5.44791860762852e+37*cos(theta)**30 - 1.76986153421838e+37*cos(theta)**28 + 4.73131301226694e+36*cos(theta)**26 - 1.03547254477223e+36*cos(theta)**24 + 1.84143313374442e+35*cos(theta)**22 - 2.63387649470565e+34*cos(theta)**20 + 2.98946555552015e+33*cos(theta)**18 - 2.64539172929198e+32*cos(theta)**16 + 1.78341015457886e+31*cos(theta)**14 - 8.88288582740429e+29*cos(theta)**12 + 3.13513617437798e+28*cos(theta)**10 - 7.39031575940331e+26*cos(theta)**8 + 1.06444877193052e+25*cos(theta)**6 - 8.08442105263685e+22*cos(theta)**4 + 2.42290341237868e+20*cos(theta)**2 - 1.19649551228577e+17)*cos(10*phi)

#@torch.jit.script
def Yl64_m11(theta, phi):
    return 5.94786619359015e-20*(1.0 - cos(theta)**2)**5.5*(3.85388908862933e+37*cos(theta)**53 - 4.18162138907969e+38*cos(theta)**51 + 2.13262690843064e+39*cos(theta)**49 - 6.79666461873831e+39*cos(theta)**47 + 1.51801538282151e+40*cos(theta)**45 - 2.52577349410638e+40*cos(theta)**43 + 3.2489650501112e+40*cos(theta)**41 - 3.30950477154184e+40*cos(theta)**39 + 2.71276884481472e+40*cos(theta)**37 - 1.80851256320981e+40*cos(theta)**35 + 9.87215573495264e+39*cos(theta)**33 - 4.42863061007221e+39*cos(theta)**31 + 1.63437558228856e+39*cos(theta)**29 - 4.95561229581145e+38*cos(theta)**27 + 1.23014138318941e+38*cos(theta)**25 - 2.48513410745334e+37*cos(theta)**23 + 4.05115289423773e+36*cos(theta)**21 - 5.26775298941129e+35*cos(theta)**19 + 5.38103799993627e+34*cos(theta)**17 - 4.23262676686716e+33*cos(theta)**15 + 2.4967742164104e+32*cos(theta)**13 - 1.06594629928851e+31*cos(theta)**11 + 3.13513617437798e+29*cos(theta)**9 - 5.91225260752265e+27*cos(theta)**7 + 6.38669263158311e+25*cos(theta)**5 - 3.23376842105474e+23*cos(theta)**3 + 4.84580682475735e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl64_m12(theta, phi):
    return 9.37165859114006e-22*(1.0 - cos(theta)**2)**6*(2.04256121697354e+39*cos(theta)**52 - 2.13262690843064e+40*cos(theta)**50 + 1.04498718513102e+41*cos(theta)**48 - 3.19443237080701e+41*cos(theta)**46 + 6.8310692226968e+41*cos(theta)**44 - 1.08608260246574e+42*cos(theta)**42 + 1.33207567054559e+42*cos(theta)**40 - 1.29070686090132e+42*cos(theta)**38 + 1.00372447258145e+42*cos(theta)**36 - 6.32979397123434e+41*cos(theta)**34 + 3.25781139253437e+41*cos(theta)**32 - 1.37287548912239e+41*cos(theta)**30 + 4.73968918863681e+40*cos(theta)**28 - 1.33801531986909e+40*cos(theta)**26 + 3.07535345797351e+39*cos(theta)**24 - 5.71580844714269e+38*cos(theta)**22 + 8.50742107789924e+37*cos(theta)**20 - 1.00087306798815e+37*cos(theta)**18 + 9.14776459989165e+35*cos(theta)**16 - 6.34894015030074e+34*cos(theta)**14 + 3.24580648133353e+33*cos(theta)**12 - 1.17254092921737e+32*cos(theta)**10 + 2.82162255694018e+30*cos(theta)**8 - 4.13857682526586e+28*cos(theta)**6 + 3.19334631579155e+26*cos(theta)**4 - 9.70130526316422e+23*cos(theta)**2 + 4.84580682475735e+20)*cos(12*phi)

#@torch.jit.script
def Yl64_m13(theta, phi):
    return 1.48104899061767e-23*(1.0 - cos(theta)**2)**6.5*(1.06213183282624e+41*cos(theta)**51 - 1.06631345421532e+42*cos(theta)**49 + 5.01593848862887e+42*cos(theta)**47 - 1.46943889057122e+43*cos(theta)**45 + 3.00567045798659e+43*cos(theta)**43 - 4.56154693035612e+43*cos(theta)**41 + 5.32830268218237e+43*cos(theta)**39 - 4.90468607142501e+43*cos(theta)**37 + 3.6134081012932e+43*cos(theta)**35 - 2.15212995021968e+43*cos(theta)**33 + 1.042499645611e+43*cos(theta)**31 - 4.11862646736716e+42*cos(theta)**29 + 1.32711297281831e+42*cos(theta)**27 - 3.47883983165964e+41*cos(theta)**25 + 7.38084829913643e+40*cos(theta)**23 - 1.25747785837139e+40*cos(theta)**21 + 1.70148421557985e+39*cos(theta)**19 - 1.80157152237866e+38*cos(theta)**17 + 1.46364233598266e+37*cos(theta)**15 - 8.88851621042104e+35*cos(theta)**13 + 3.89496777760023e+34*cos(theta)**11 - 1.17254092921737e+33*cos(theta)**9 + 2.25729804555215e+31*cos(theta)**7 - 2.48314609515951e+29*cos(theta)**5 + 1.27733852631662e+27*cos(theta)**3 - 1.94026105263284e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl64_m14(theta, phi):
    return 2.348210551011e-25*(1.0 - cos(theta)**2)**7*(5.41687234741383e+42*cos(theta)**50 - 5.22493592565508e+43*cos(theta)**48 + 2.35749108965557e+44*cos(theta)**46 - 6.6124750075705e+44*cos(theta)**44 + 1.29243829693423e+45*cos(theta)**42 - 1.87023424144601e+45*cos(theta)**40 + 2.07803804605112e+45*cos(theta)**38 - 1.81473384642725e+45*cos(theta)**36 + 1.26469283545262e+45*cos(theta)**34 - 7.10202883572493e+44*cos(theta)**32 + 3.2317489013941e+44*cos(theta)**30 - 1.19440167553648e+44*cos(theta)**28 + 3.58320502660943e+43*cos(theta)**26 - 8.6970995791491e+42*cos(theta)**24 + 1.69759510880138e+42*cos(theta)**22 - 2.64070350257992e+41*cos(theta)**20 + 3.23282000960171e+40*cos(theta)**18 - 3.06267158804373e+39*cos(theta)**16 + 2.195463503974e+38*cos(theta)**14 - 1.15550710735474e+37*cos(theta)**12 + 4.28446455536025e+35*cos(theta)**10 - 1.05528683629563e+34*cos(theta)**8 + 1.5801086318865e+32*cos(theta)**6 - 1.24157304757976e+30*cos(theta)**4 + 3.83201557894987e+27*cos(theta)**2 - 1.94026105263284e+24)*cos(14*phi)

#@torch.jit.script
def Yl64_m15(theta, phi):
    return 3.73627201727021e-27*(1.0 - cos(theta)**2)**7.5*(2.70843617370692e+44*cos(theta)**49 - 2.50796924431444e+45*cos(theta)**47 + 1.08444590124156e+46*cos(theta)**45 - 2.90948900333102e+46*cos(theta)**43 + 5.42824084712379e+46*cos(theta)**41 - 7.48093696578404e+46*cos(theta)**39 + 7.89654457499427e+46*cos(theta)**37 - 6.53304184713811e+46*cos(theta)**35 + 4.29995564053891e+46*cos(theta)**33 - 2.27264922743198e+46*cos(theta)**31 + 9.69524670418229e+45*cos(theta)**29 - 3.34432469150213e+45*cos(theta)**27 + 9.31633306918451e+44*cos(theta)**25 - 2.08730389899578e+44*cos(theta)**23 + 3.73470923936304e+43*cos(theta)**21 - 5.28140700515985e+42*cos(theta)**19 + 5.81907601728308e+41*cos(theta)**17 - 4.90027454086996e+40*cos(theta)**15 + 3.0736489055636e+39*cos(theta)**13 - 1.38660852882568e+38*cos(theta)**11 + 4.28446455536025e+36*cos(theta)**9 - 8.44229469036503e+34*cos(theta)**7 + 9.48065179131902e+32*cos(theta)**5 - 4.96629219031903e+30*cos(theta)**3 + 7.66403115789973e+27*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl64_m16(theta, phi):
    return 5.96754158074748e-29*(1.0 - cos(theta)**2)**8*(1.32713372511639e+46*cos(theta)**48 - 1.17874554482779e+47*cos(theta)**46 + 4.88000655558703e+47*cos(theta)**44 - 1.25108027143234e+48*cos(theta)**42 + 2.22557874732075e+48*cos(theta)**40 - 2.91756541665578e+48*cos(theta)**38 + 2.92172149274788e+48*cos(theta)**36 - 2.28656464649834e+48*cos(theta)**34 + 1.41898536137784e+48*cos(theta)**32 - 7.04521260503913e+47*cos(theta)**30 + 2.81162154421286e+47*cos(theta)**28 - 9.02967666705576e+46*cos(theta)**26 + 2.32908326729613e+46*cos(theta)**24 - 4.8007989676903e+45*cos(theta)**22 + 7.84288940266237e+44*cos(theta)**20 - 1.00346733098037e+44*cos(theta)**18 + 9.89242922938124e+42*cos(theta)**16 - 7.35041181130494e+41*cos(theta)**14 + 3.99574357723267e+40*cos(theta)**12 - 1.52526938170825e+39*cos(theta)**10 + 3.85601809982423e+37*cos(theta)**8 - 5.90960628325552e+35*cos(theta)**6 + 4.74032589565951e+33*cos(theta)**4 - 1.48988765709571e+31*cos(theta)**2 + 7.66403115789973e+27)*cos(16*phi)

#@torch.jit.script
def Yl64_m17(theta, phi):
    return 9.57044927234678e-31*(1.0 - cos(theta)**2)**8.5*(6.37024188055867e+47*cos(theta)**47 - 5.42222950620781e+48*cos(theta)**45 + 2.14720288445829e+49*cos(theta)**43 - 5.25453714001582e+49*cos(theta)**41 + 8.90231498928301e+49*cos(theta)**39 - 1.10867485832919e+50*cos(theta)**37 + 1.05181973738924e+50*cos(theta)**35 - 7.77431979809435e+49*cos(theta)**33 + 4.54075315640909e+49*cos(theta)**31 - 2.11356378151174e+49*cos(theta)**29 + 7.87254032379602e+48*cos(theta)**27 - 2.3477159334345e+48*cos(theta)**25 + 5.58979984151071e+47*cos(theta)**23 - 1.05617577289187e+47*cos(theta)**21 + 1.56857788053247e+46*cos(theta)**19 - 1.80624119576467e+45*cos(theta)**17 + 1.582788676701e+44*cos(theta)**15 - 1.02905765358269e+43*cos(theta)**13 + 4.79489229267921e+41*cos(theta)**11 - 1.52526938170825e+40*cos(theta)**9 + 3.08481447985938e+38*cos(theta)**7 - 3.54576376995331e+36*cos(theta)**5 + 1.8961303582638e+34*cos(theta)**3 - 2.97977531419142e+31*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl64_m18(theta, phi):
    return 1.54161692787926e-32*(1.0 - cos(theta)**2)**9*(2.99401368386257e+49*cos(theta)**46 - 2.44000327779352e+50*cos(theta)**44 + 9.23297240317066e+50*cos(theta)**42 - 2.15436022740649e+51*cos(theta)**40 + 3.47190284582037e+51*cos(theta)**38 - 4.10209697581802e+51*cos(theta)**36 + 3.68136908086233e+51*cos(theta)**34 - 2.56552553337114e+51*cos(theta)**32 + 1.40763347848682e+51*cos(theta)**30 - 6.12933496638404e+50*cos(theta)**28 + 2.12558588742493e+50*cos(theta)**26 - 5.86928983358624e+49*cos(theta)**24 + 1.28565396354746e+49*cos(theta)**22 - 2.21796912307292e+48*cos(theta)**20 + 2.9802979730117e+47*cos(theta)**18 - 3.07061003279994e+46*cos(theta)**16 + 2.3741830150515e+45*cos(theta)**14 - 1.3377749496575e+44*cos(theta)**12 + 5.27438152194713e+42*cos(theta)**10 - 1.37274244353743e+41*cos(theta)**8 + 2.15937013590157e+39*cos(theta)**6 - 1.77288188497666e+37*cos(theta)**4 + 5.68839107479141e+34*cos(theta)**2 - 2.97977531419142e+31)*cos(18*phi)

#@torch.jit.script
def Yl64_m19(theta, phi):
    return 2.49493082314278e-34*(1.0 - cos(theta)**2)**9.5*(1.37724629457678e+51*cos(theta)**45 - 1.07360144222915e+52*cos(theta)**43 + 3.87784840933168e+52*cos(theta)**41 - 8.61744090962595e+52*cos(theta)**39 + 1.31932308141174e+53*cos(theta)**37 - 1.47675491129449e+53*cos(theta)**35 + 1.25166548749319e+53*cos(theta)**33 - 8.20968170678764e+52*cos(theta)**31 + 4.22290043546046e+52*cos(theta)**29 - 1.71621379058753e+52*cos(theta)**27 + 5.52652330730481e+51*cos(theta)**25 - 1.4086295600607e+51*cos(theta)**23 + 2.82843871980442e+50*cos(theta)**21 - 4.43593824614584e+49*cos(theta)**19 + 5.36453635142106e+48*cos(theta)**17 - 4.9129760524799e+47*cos(theta)**15 + 3.3238562210721e+46*cos(theta)**13 - 1.605329939589e+45*cos(theta)**11 + 5.27438152194713e+43*cos(theta)**9 - 1.09819395482994e+42*cos(theta)**7 + 1.29562208154094e+40*cos(theta)**5 - 7.09152753990663e+37*cos(theta)**3 + 1.13767821495828e+35*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl64_m20(theta, phi):
    return 4.05800528717764e-36*(1.0 - cos(theta)**2)**10*(6.19760832559553e+52*cos(theta)**44 - 4.61648620158533e+53*cos(theta)**42 + 1.58991784782599e+54*cos(theta)**40 - 3.36080195475412e+54*cos(theta)**38 + 4.88149540122344e+54*cos(theta)**36 - 5.16864218953071e+54*cos(theta)**34 + 4.13049610872753e+54*cos(theta)**32 - 2.54500132910417e+54*cos(theta)**30 + 1.22464112628353e+54*cos(theta)**28 - 4.63377723458634e+53*cos(theta)**26 + 1.3816308268262e+53*cos(theta)**24 - 3.23984798813961e+52*cos(theta)**22 + 5.93972131158928e+51*cos(theta)**20 - 8.42828266767709e+50*cos(theta)**18 + 9.11971179741581e+49*cos(theta)**16 - 7.36946407871984e+48*cos(theta)**14 + 4.32101308739372e+47*cos(theta)**12 - 1.7658629335479e+46*cos(theta)**10 + 4.74694336975242e+44*cos(theta)**8 - 7.68735768380958e+42*cos(theta)**6 + 6.4781104077047e+40*cos(theta)**4 - 2.12745826197199e+38*cos(theta)**2 + 1.13767821495828e+35)*cos(20*phi)

#@torch.jit.script
def Yl64_m21(theta, phi):
    return 6.63554818846152e-38*(1.0 - cos(theta)**2)**10.5*(2.72694766326203e+54*cos(theta)**43 - 1.93892420466584e+55*cos(theta)**41 + 6.35967139130395e+55*cos(theta)**39 - 1.27710474280657e+56*cos(theta)**37 + 1.75733834444044e+56*cos(theta)**35 - 1.75733834444044e+56*cos(theta)**33 + 1.32175875479281e+56*cos(theta)**31 - 7.6350039873125e+55*cos(theta)**29 + 3.42899515359389e+55*cos(theta)**27 - 1.20478208099245e+55*cos(theta)**25 + 3.31591398438288e+54*cos(theta)**23 - 7.12766557390713e+53*cos(theta)**21 + 1.18794426231786e+53*cos(theta)**19 - 1.51709088018188e+52*cos(theta)**17 + 1.45915388758653e+51*cos(theta)**15 - 1.03172497102078e+50*cos(theta)**13 + 5.18521570487247e+48*cos(theta)**11 - 1.7658629335479e+47*cos(theta)**9 + 3.79755469580193e+45*cos(theta)**7 - 4.61241461028575e+43*cos(theta)**5 + 2.59124416308188e+41*cos(theta)**3 - 4.25491652394398e+38*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl64_m22(theta, phi):
    return 1.09117235370959e-39*(1.0 - cos(theta)**2)**11*(1.17258749520267e+56*cos(theta)**42 - 7.94958923912994e+56*cos(theta)**40 + 2.48027184260854e+57*cos(theta)**38 - 4.72528754838429e+57*cos(theta)**36 + 6.15068420554154e+57*cos(theta)**34 - 5.79921653665345e+57*cos(theta)**32 + 4.09745213985771e+57*cos(theta)**30 - 2.21415115632063e+57*cos(theta)**28 + 9.2582869147035e+56*cos(theta)**26 - 3.01195520248112e+56*cos(theta)**24 + 7.62660216408063e+55*cos(theta)**22 - 1.4968097705205e+55*cos(theta)**20 + 2.25709409840393e+54*cos(theta)**18 - 2.57905449630919e+53*cos(theta)**16 + 2.18873083137979e+52*cos(theta)**14 - 1.34124246232701e+51*cos(theta)**12 + 5.70373727535971e+49*cos(theta)**10 - 1.58927664019311e+48*cos(theta)**8 + 2.65828828706135e+46*cos(theta)**6 - 2.30620730514287e+44*cos(theta)**4 + 7.77373248924565e+41*cos(theta)**2 - 4.25491652394398e+38)*cos(22*phi)

#@torch.jit.script
def Yl64_m23(theta, phi):
    return 1.80513248796996e-41*(1.0 - cos(theta)**2)**11.5*(4.92486747985123e+57*cos(theta)**41 - 3.17983569565198e+58*cos(theta)**39 + 9.42503300191246e+58*cos(theta)**37 - 1.70110351741835e+59*cos(theta)**35 + 2.09123262988412e+59*cos(theta)**33 - 1.8557492917291e+59*cos(theta)**31 + 1.22923564195731e+59*cos(theta)**29 - 6.19962323769775e+58*cos(theta)**27 + 2.40715459782291e+58*cos(theta)**25 - 7.22869248595469e+57*cos(theta)**23 + 1.67785247609774e+57*cos(theta)**21 - 2.993619541041e+56*cos(theta)**19 + 4.06276937712707e+55*cos(theta)**17 - 4.1264871940947e+54*cos(theta)**15 + 3.06422316393171e+53*cos(theta)**13 - 1.60949095479241e+52*cos(theta)**11 + 5.70373727535971e+50*cos(theta)**9 - 1.27142131215449e+49*cos(theta)**7 + 1.59497297223681e+47*cos(theta)**5 - 9.2248292205715e+44*cos(theta)**3 + 1.55474649784913e+42*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl64_m24(theta, phi):
    return 3.0052168697751e-43*(1.0 - cos(theta)**2)**12*(2.01919566673901e+59*cos(theta)**40 - 1.24013592130427e+60*cos(theta)**38 + 3.48726221070761e+60*cos(theta)**36 - 5.95386231096421e+60*cos(theta)**34 + 6.90106767861761e+60*cos(theta)**32 - 5.75282280436023e+60*cos(theta)**30 + 3.56478336167621e+60*cos(theta)**28 - 1.67389827417839e+60*cos(theta)**26 + 6.01788649455728e+59*cos(theta)**24 - 1.66259927176958e+59*cos(theta)**22 + 3.52349019980525e+58*cos(theta)**20 - 5.68787712797789e+57*cos(theta)**18 + 6.90670794111601e+56*cos(theta)**16 - 6.18973079114206e+55*cos(theta)**14 + 3.98349011311122e+54*cos(theta)**12 - 1.77044005027166e+53*cos(theta)**10 + 5.13336354782374e+51*cos(theta)**8 - 8.89994918508141e+49*cos(theta)**6 + 7.97486486118406e+47*cos(theta)**4 - 2.76744876617145e+45*cos(theta)**2 + 1.55474649784913e+42)*cos(24*phi)

#@torch.jit.script
def Yl64_m25(theta, phi):
    return 5.03675491726324e-45*(1.0 - cos(theta)**2)**12.5*(8.07678266695602e+60*cos(theta)**39 - 4.71251650095623e+61*cos(theta)**37 + 1.25541439585474e+62*cos(theta)**35 - 2.02431318572783e+62*cos(theta)**33 + 2.20834165715763e+62*cos(theta)**31 - 1.72584684130807e+62*cos(theta)**29 + 9.98139341269338e+61*cos(theta)**27 - 4.35213551286382e+61*cos(theta)**25 + 1.44429275869375e+61*cos(theta)**23 - 3.65771839789307e+60*cos(theta)**21 + 7.0469803996105e+59*cos(theta)**19 - 1.02381788303602e+59*cos(theta)**17 + 1.10507327057856e+58*cos(theta)**15 - 8.66562310759888e+56*cos(theta)**13 + 4.78018813573347e+55*cos(theta)**11 - 1.77044005027166e+54*cos(theta)**9 + 4.10669083825899e+52*cos(theta)**7 - 5.33996951104885e+50*cos(theta)**5 + 3.18994594447362e+48*cos(theta)**3 - 5.5348975323429e+45*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl64_m26(theta, phi):
    return 8.50153331177454e-47*(1.0 - cos(theta)**2)**13*(3.14994524011285e+62*cos(theta)**38 - 1.7436311053538e+63*cos(theta)**36 + 4.39395038549159e+63*cos(theta)**34 - 6.68023351290185e+63*cos(theta)**32 + 6.84585913718867e+63*cos(theta)**30 - 5.0049558397934e+63*cos(theta)**28 + 2.69497622142721e+63*cos(theta)**26 - 1.08803387821596e+63*cos(theta)**24 + 3.32187334499562e+62*cos(theta)**22 - 7.68120863557545e+61*cos(theta)**20 + 1.338926275926e+61*cos(theta)**18 - 1.74049040116124e+60*cos(theta)**16 + 1.65760990586784e+59*cos(theta)**14 - 1.12653100398785e+58*cos(theta)**12 + 5.25820694930682e+56*cos(theta)**10 - 1.59339604524449e+55*cos(theta)**8 + 2.8746835867813e+53*cos(theta)**6 - 2.66998475552442e+51*cos(theta)**4 + 9.56983783342087e+48*cos(theta)**2 - 5.5348975323429e+45)*cos(26*phi)

#@torch.jit.script
def Yl64_m27(theta, phi):
    return 1.44572192187728e-48*(1.0 - cos(theta)**2)**13.5*(1.19697919124288e+64*cos(theta)**37 - 6.2770719792737e+64*cos(theta)**35 + 1.49394313106714e+65*cos(theta)**33 - 2.13767472412859e+65*cos(theta)**31 + 2.0537577411566e+65*cos(theta)**29 - 1.40138763514215e+65*cos(theta)**27 + 7.00693817571075e+64*cos(theta)**25 - 2.61128130771829e+64*cos(theta)**23 + 7.30812135899036e+63*cos(theta)**21 - 1.53624172711509e+63*cos(theta)**19 + 2.41006729666679e+62*cos(theta)**17 - 2.78478464185798e+61*cos(theta)**15 + 2.32065386821498e+60*cos(theta)**13 - 1.35183720478543e+59*cos(theta)**11 + 5.25820694930682e+57*cos(theta)**9 - 1.27471683619559e+56*cos(theta)**7 + 1.72481015206878e+54*cos(theta)**5 - 1.06799390220977e+52*cos(theta)**3 + 1.91396756668417e+49*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl64_m28(theta, phi):
    return 2.47793546047678e-50*(1.0 - cos(theta)**2)**14*(4.42882300759866e+65*cos(theta)**36 - 2.19697519274579e+66*cos(theta)**34 + 4.93001233252156e+66*cos(theta)**32 - 6.62679164479863e+66*cos(theta)**30 + 5.95589744935414e+66*cos(theta)**28 - 3.78374661488381e+66*cos(theta)**26 + 1.75173454392769e+66*cos(theta)**24 - 6.00594700775208e+65*cos(theta)**22 + 1.53470548538797e+65*cos(theta)**20 - 2.91885928151867e+64*cos(theta)**18 + 4.09711440433355e+63*cos(theta)**16 - 4.17717696278696e+62*cos(theta)**14 + 3.01685002867947e+61*cos(theta)**12 - 1.48702092526397e+60*cos(theta)**10 + 4.73238625437614e+58*cos(theta)**8 - 8.92301785336914e+56*cos(theta)**6 + 8.62405076034389e+54*cos(theta)**4 - 3.20398170662931e+52*cos(theta)**2 + 1.91396756668417e+49)*cos(28*phi)

#@torch.jit.script
def Yl64_m29(theta, phi):
    return 4.28249895862336e-52*(1.0 - cos(theta)**2)**14.5*(1.59437628273552e+67*cos(theta)**35 - 7.4697156553357e+67*cos(theta)**33 + 1.5776039464069e+68*cos(theta)**31 - 1.98803749343959e+68*cos(theta)**29 + 1.66765128581916e+68*cos(theta)**27 - 9.8377411986979e+67*cos(theta)**25 + 4.20416290542645e+67*cos(theta)**23 - 1.32130834170546e+67*cos(theta)**21 + 3.06941097077595e+66*cos(theta)**19 - 5.25394670673361e+65*cos(theta)**17 + 6.55538304693368e+64*cos(theta)**15 - 5.84804774790175e+63*cos(theta)**13 + 3.62022003441537e+62*cos(theta)**11 - 1.48702092526397e+61*cos(theta)**9 + 3.78590900350091e+59*cos(theta)**7 - 5.35381071202149e+57*cos(theta)**5 + 3.44962030413756e+55*cos(theta)**3 - 6.40796341325862e+52*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl64_m30(theta, phi):
    return 7.46619480288864e-54*(1.0 - cos(theta)**2)**15*(5.58031698957432e+68*cos(theta)**34 - 2.46500616626078e+69*cos(theta)**32 + 4.89057223386139e+69*cos(theta)**30 - 5.76530873097481e+69*cos(theta)**28 + 4.50265847171173e+69*cos(theta)**26 - 2.45943529967447e+69*cos(theta)**24 + 9.66957468248084e+68*cos(theta)**22 - 2.77474751758146e+68*cos(theta)**20 + 5.8318808444743e+67*cos(theta)**18 - 8.93170940144713e+66*cos(theta)**16 + 9.83307457040051e+65*cos(theta)**14 - 7.60246207227227e+64*cos(theta)**12 + 3.98224203785691e+63*cos(theta)**10 - 1.33831883273757e+62*cos(theta)**8 + 2.65013630245064e+60*cos(theta)**6 - 2.67690535601074e+58*cos(theta)**4 + 1.03488609124127e+56*cos(theta)**2 - 6.40796341325862e+52)*cos(30*phi)

#@torch.jit.script
def Yl64_m31(theta, phi):
    return 1.31370561417017e-55*(1.0 - cos(theta)**2)**15.5*(1.89730777645527e+70*cos(theta)**33 - 7.8880197320345e+70*cos(theta)**31 + 1.46717167015842e+71*cos(theta)**29 - 1.61428644467295e+71*cos(theta)**27 + 1.17069120264505e+71*cos(theta)**25 - 5.90264471921874e+70*cos(theta)**23 + 2.12730643014579e+70*cos(theta)**21 - 5.54949503516292e+69*cos(theta)**19 + 1.04973855200537e+69*cos(theta)**17 - 1.42907350423154e+68*cos(theta)**15 + 1.37663043985607e+67*cos(theta)**13 - 9.12295448672673e+65*cos(theta)**11 + 3.98224203785691e+64*cos(theta)**9 - 1.07065506619006e+63*cos(theta)**7 + 1.59008178147038e+61*cos(theta)**5 - 1.0707621424043e+59*cos(theta)**3 + 2.06977218248253e+56*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl64_m32(theta, phi):
    return 2.33402481684555e-57*(1.0 - cos(theta)**2)**16*(6.26111566230238e+71*cos(theta)**32 - 2.44528611693069e+72*cos(theta)**30 + 4.25479784345941e+72*cos(theta)**28 - 4.35857340061695e+72*cos(theta)**26 + 2.92672800661262e+72*cos(theta)**24 - 1.35760828542031e+72*cos(theta)**22 + 4.46734350330615e+71*cos(theta)**20 - 1.05440405668095e+71*cos(theta)**18 + 1.78455553840914e+70*cos(theta)**16 - 2.14361025634731e+69*cos(theta)**14 + 1.78961957181289e+68*cos(theta)**12 - 1.00352499353994e+67*cos(theta)**10 + 3.58401783407122e+65*cos(theta)**8 - 7.4945854633304e+63*cos(theta)**6 + 7.95040890735191e+61*cos(theta)**4 - 3.21228642721289e+59*cos(theta)**2 + 2.06977218248253e+56)*cos(32*phi)

#@torch.jit.script
def Yl64_m33(theta, phi):
    return 4.18933039917634e-59*(1.0 - cos(theta)**2)**16.5*(2.00355701193676e+73*cos(theta)**31 - 7.33585835079208e+73*cos(theta)**29 + 1.19134339616863e+74*cos(theta)**27 - 1.13322908416041e+74*cos(theta)**25 + 7.0241472158703e+73*cos(theta)**23 - 2.98673822792468e+73*cos(theta)**21 + 8.9346870066123e+72*cos(theta)**19 - 1.89792730202572e+72*cos(theta)**17 + 2.85528886145462e+71*cos(theta)**15 - 3.00105435888624e+70*cos(theta)**13 + 2.14754348617547e+69*cos(theta)**11 - 1.00352499353994e+68*cos(theta)**9 + 2.86721426725697e+66*cos(theta)**7 - 4.49675127799824e+64*cos(theta)**5 + 3.18016356294076e+62*cos(theta)**3 - 6.42457285442578e+59*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl64_m34(theta, phi):
    return 7.6006498963022e-61*(1.0 - cos(theta)**2)**17*(6.21102673700396e+74*cos(theta)**30 - 2.1273989217297e+75*cos(theta)**28 + 3.21662716965531e+75*cos(theta)**26 - 2.83307271040102e+75*cos(theta)**24 + 1.61555385965017e+75*cos(theta)**22 - 6.27215027864183e+74*cos(theta)**20 + 1.69759053125634e+74*cos(theta)**18 - 3.22647641344372e+73*cos(theta)**16 + 4.28293329218193e+72*cos(theta)**14 - 3.90137066655211e+71*cos(theta)**12 + 2.36229783479302e+70*cos(theta)**10 - 9.03172494185946e+68*cos(theta)**8 + 2.00704998707988e+67*cos(theta)**6 - 2.24837563899912e+65*cos(theta)**4 + 9.54049068882229e+62*cos(theta)**2 - 6.42457285442578e+59)*cos(34*phi)

#@torch.jit.script
def Yl64_m35(theta, phi):
    return 1.39467335454003e-62*(1.0 - cos(theta)**2)**17.5*(1.86330802110119e+76*cos(theta)**29 - 5.95671698084317e+76*cos(theta)**27 + 8.36323064110381e+76*cos(theta)**25 - 6.79937450496245e+76*cos(theta)**23 + 3.55421849123037e+76*cos(theta)**21 - 1.25443005572837e+76*cos(theta)**19 + 3.05566295626141e+75*cos(theta)**17 - 5.16236226150995e+74*cos(theta)**15 + 5.9961066090547e+73*cos(theta)**13 - 4.68164479986253e+72*cos(theta)**11 + 2.36229783479302e+71*cos(theta)**9 - 7.22537995348757e+69*cos(theta)**7 + 1.20422999224793e+68*cos(theta)**5 - 8.99350255599648e+65*cos(theta)**3 + 1.90809813776446e+63*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl64_m36(theta, phi):
    return 2.58984340217833e-64*(1.0 - cos(theta)**2)**18*(5.40359326119345e+77*cos(theta)**28 - 1.60831358482766e+78*cos(theta)**26 + 2.09080766027595e+78*cos(theta)**24 - 1.56385613614136e+78*cos(theta)**22 + 7.46385883158378e+77*cos(theta)**20 - 2.3834171058839e+77*cos(theta)**18 + 5.19462702564439e+76*cos(theta)**16 - 7.74354339226493e+75*cos(theta)**14 + 7.79493859177111e+74*cos(theta)**12 - 5.14980927984878e+73*cos(theta)**10 + 2.12606805131372e+72*cos(theta)**8 - 5.0577659674413e+70*cos(theta)**6 + 6.02114996123964e+68*cos(theta)**4 - 2.69805076679894e+66*cos(theta)**2 + 1.90809813776446e+63)*cos(36*phi)

#@torch.jit.script
def Yl64_m37(theta, phi):
    return 4.87005428516727e-66*(1.0 - cos(theta)**2)**18.5*(1.51300611313417e+79*cos(theta)**27 - 4.18161532055191e+79*cos(theta)**25 + 5.01793838466229e+79*cos(theta)**23 - 3.440483499511e+79*cos(theta)**21 + 1.49277176631676e+79*cos(theta)**19 - 4.29015079059101e+78*cos(theta)**17 + 8.31140324103102e+77*cos(theta)**15 - 1.08409607491709e+77*cos(theta)**13 + 9.35392631012533e+75*cos(theta)**11 - 5.14980927984878e+74*cos(theta)**9 + 1.70085444105097e+73*cos(theta)**7 - 3.03465958046478e+71*cos(theta)**5 + 2.40845998449586e+69*cos(theta)**3 - 5.39610153359789e+66*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl64_m38(theta, phi):
    return 9.28008243859333e-68*(1.0 - cos(theta)**2)**19*(4.08511650546225e+80*cos(theta)**26 - 1.04540383013798e+81*cos(theta)**24 + 1.15412582847233e+81*cos(theta)**22 - 7.2250153489731e+80*cos(theta)**20 + 2.83626635600184e+80*cos(theta)**18 - 7.29325634400472e+79*cos(theta)**16 + 1.24671048615465e+79*cos(theta)**14 - 1.40932489739222e+78*cos(theta)**12 + 1.02893189411379e+77*cos(theta)**10 - 4.6348283518639e+75*cos(theta)**8 + 1.19059810873568e+74*cos(theta)**6 - 1.51732979023239e+72*cos(theta)**4 + 7.22537995348757e+69*cos(theta)**2 - 5.39610153359789e+66)*cos(38*phi)

#@torch.jit.script
def Yl64_m39(theta, phi):
    return 1.79327357076174e-69*(1.0 - cos(theta)**2)**19.5*(1.06213029142018e+82*cos(theta)**25 - 2.50896919233114e+82*cos(theta)**23 + 2.53907682263912e+82*cos(theta)**21 - 1.44500306979462e+82*cos(theta)**19 + 5.10527944080331e+81*cos(theta)**17 - 1.16692101504076e+81*cos(theta)**15 + 1.74539468061651e+80*cos(theta)**13 - 1.69118987687066e+79*cos(theta)**11 + 1.02893189411379e+78*cos(theta)**9 - 3.70786268149112e+76*cos(theta)**7 + 7.14358865241409e+74*cos(theta)**5 - 6.06931916092956e+72*cos(theta)**3 + 1.44507599069751e+70*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl64_m40(theta, phi):
    return 3.51689881943242e-71*(1.0 - cos(theta)**2)**20*(2.65532572855046e+83*cos(theta)**24 - 5.77062914236163e+83*cos(theta)**22 + 5.33206132754215e+83*cos(theta)**20 - 2.74550583260978e+83*cos(theta)**18 + 8.67897504936562e+82*cos(theta)**16 - 1.75038152256113e+82*cos(theta)**14 + 2.26901308480147e+81*cos(theta)**12 - 1.86030886455773e+80*cos(theta)**10 + 9.26038704702408e+78*cos(theta)**8 - 2.59550387704379e+77*cos(theta)**6 + 3.57179432620705e+75*cos(theta)**4 - 1.82079574827887e+73*cos(theta)**2 + 1.44507599069751e+70)*cos(40*phi)

#@torch.jit.script
def Yl64_m41(theta, phi):
    return 7.00583014186664e-73*(1.0 - cos(theta)**2)**20.5*(6.37278174852111e+84*cos(theta)**23 - 1.26953841131956e+85*cos(theta)**21 + 1.06641226550843e+85*cos(theta)**19 - 4.9419104986976e+84*cos(theta)**17 + 1.3886360078985e+84*cos(theta)**15 - 2.45053413158559e+83*cos(theta)**13 + 2.72281570176176e+82*cos(theta)**11 - 1.86030886455773e+81*cos(theta)**9 + 7.40830963761926e+79*cos(theta)**7 - 1.55730232622627e+78*cos(theta)**5 + 1.42871773048282e+76*cos(theta)**3 - 3.64159149655773e+73*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl64_m42(theta, phi):
    return 1.41887047903867e-74*(1.0 - cos(theta)**2)**21*(1.46573980215985e+86*cos(theta)**22 - 2.66603066377107e+86*cos(theta)**20 + 2.02618330446602e+86*cos(theta)**18 - 8.40124784778592e+85*cos(theta)**16 + 2.08295401184775e+85*cos(theta)**14 - 3.18569437106126e+84*cos(theta)**12 + 2.99509727193794e+83*cos(theta)**10 - 1.67427797810195e+82*cos(theta)**8 + 5.18581674633348e+80*cos(theta)**6 - 7.78651163113136e+78*cos(theta)**4 + 4.28615319144845e+76*cos(theta)**2 - 3.64159149655773e+73)*cos(42*phi)

#@torch.jit.script
def Yl64_m43(theta, phi):
    return 2.92441850691721e-76*(1.0 - cos(theta)**2)**21.5*(3.22462756475168e+87*cos(theta)**21 - 5.33206132754215e+87*cos(theta)**19 + 3.64712994803883e+87*cos(theta)**17 - 1.34419965564575e+87*cos(theta)**15 + 2.91613561658685e+86*cos(theta)**13 - 3.82283324527352e+85*cos(theta)**11 + 2.99509727193794e+84*cos(theta)**9 - 1.33942238248156e+83*cos(theta)**7 + 3.11149004780009e+81*cos(theta)**5 - 3.11460465245254e+79*cos(theta)**3 + 8.57230638289691e+76*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl64_m44(theta, phi):
    return 6.14070166569664e-78*(1.0 - cos(theta)**2)**22*(6.77171788597853e+88*cos(theta)**20 - 1.01309165223301e+89*cos(theta)**18 + 6.20012091166601e+88*cos(theta)**16 - 2.01629948346862e+88*cos(theta)**14 + 3.7909763015629e+87*cos(theta)**12 - 4.20511656980087e+86*cos(theta)**10 + 2.69558754474415e+85*cos(theta)**8 - 9.37595667737094e+83*cos(theta)**6 + 1.55574502390005e+82*cos(theta)**4 - 9.34381395735763e+79*cos(theta)**2 + 8.57230638289691e+76)*cos(44*phi)

#@torch.jit.script
def Yl64_m45(theta, phi):
    return 1.31519379649676e-79*(1.0 - cos(theta)**2)**22.5*(1.35434357719571e+90*cos(theta)**19 - 1.82356497401941e+90*cos(theta)**17 + 9.92019345866561e+89*cos(theta)**15 - 2.82281927685607e+89*cos(theta)**13 + 4.54917156187548e+88*cos(theta)**11 - 4.20511656980087e+87*cos(theta)**9 + 2.15647003579532e+86*cos(theta)**7 - 5.62557400642256e+84*cos(theta)**5 + 6.22298009560018e+82*cos(theta)**3 - 1.86876279147153e+80*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl64_m46(theta, phi):
    return 2.87684596227171e-81*(1.0 - cos(theta)**2)**23*(2.57325279667184e+91*cos(theta)**18 - 3.100060455833e+91*cos(theta)**16 + 1.48802901879984e+91*cos(theta)**14 - 3.66966505991289e+90*cos(theta)**12 + 5.00408871806303e+89*cos(theta)**10 - 3.78460491282078e+88*cos(theta)**8 + 1.50952902505672e+87*cos(theta)**6 - 2.81278700321128e+85*cos(theta)**4 + 1.86689402868005e+83*cos(theta)**2 - 1.86876279147153e+80)*cos(46*phi)

#@torch.jit.script
def Yl64_m47(theta, phi):
    return 6.43604195832224e-83*(1.0 - cos(theta)**2)**23.5*(4.63185503400931e+92*cos(theta)**17 - 4.96009672933281e+92*cos(theta)**15 + 2.08324062631978e+92*cos(theta)**13 - 4.40359807189547e+91*cos(theta)**11 + 5.00408871806303e+90*cos(theta)**9 - 3.02768393025662e+89*cos(theta)**7 + 9.05717415034033e+87*cos(theta)**5 - 1.12511480128451e+86*cos(theta)**3 + 3.73378805736011e+83*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl64_m48(theta, phi):
    return 1.47497749750113e-84*(1.0 - cos(theta)**2)**24*(7.87415355781583e+93*cos(theta)**16 - 7.44014509399921e+93*cos(theta)**14 + 2.70821281421571e+93*cos(theta)**12 - 4.84395787908501e+92*cos(theta)**10 + 4.50367984625673e+91*cos(theta)**8 - 2.11937875117964e+90*cos(theta)**6 + 4.52858707517016e+88*cos(theta)**4 - 3.37534440385354e+86*cos(theta)**2 + 3.73378805736011e+83)*cos(48*phi)

#@torch.jit.script
def Yl64_m49(theta, phi):
    return 3.46885528073881e-86*(1.0 - cos(theta)**2)**24.5*(1.25986456925053e+95*cos(theta)**15 - 1.04162031315989e+95*cos(theta)**13 + 3.24985537705886e+94*cos(theta)**11 - 4.84395787908501e+93*cos(theta)**9 + 3.60294387700538e+92*cos(theta)**7 - 1.27162725070778e+91*cos(theta)**5 + 1.81143483006807e+89*cos(theta)**3 - 6.75068880770708e+86*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl64_m50(theta, phi):
    return 8.38857373748235e-88*(1.0 - cos(theta)**2)**25*(1.8897968538758e+96*cos(theta)**14 - 1.35410640710786e+96*cos(theta)**12 + 3.57484091476474e+95*cos(theta)**10 - 4.35956209117651e+94*cos(theta)**8 + 2.52206071390377e+93*cos(theta)**6 - 6.35813625353891e+91*cos(theta)**4 + 5.4343044902042e+89*cos(theta)**2 - 6.75068880770708e+86)*cos(50*phi)

#@torch.jit.script
def Yl64_m51(theta, phi):
    return 2.09062042188346e-89*(1.0 - cos(theta)**2)**25.5*(2.64571559542612e+97*cos(theta)**13 - 1.62492768852943e+97*cos(theta)**11 + 3.57484091476474e+96*cos(theta)**9 - 3.48764967294121e+95*cos(theta)**7 + 1.51323642834226e+94*cos(theta)**5 - 2.54325450141556e+92*cos(theta)**3 + 1.08686089804084e+90*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl64_m52(theta, phi):
    return 5.38362148506044e-91*(1.0 - cos(theta)**2)**26*(3.43943027405396e+98*cos(theta)**12 - 1.78742045738237e+98*cos(theta)**10 + 3.21735682328827e+97*cos(theta)**8 - 2.44135477105885e+96*cos(theta)**6 + 7.5661821417113e+94*cos(theta)**4 - 7.62976350424669e+92*cos(theta)**2 + 1.08686089804084e+90)*cos(52*phi)

#@torch.jit.script
def Yl64_m53(theta, phi):
    return 1.43678228198022e-92*(1.0 - cos(theta)**2)**26.5*(4.12731632886475e+99*cos(theta)**11 - 1.78742045738237e+99*cos(theta)**9 + 2.57388545863061e+98*cos(theta)**7 - 1.46481286263531e+97*cos(theta)**5 + 3.02647285668452e+95*cos(theta)**3 - 1.52595270084934e+93*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl64_m54(theta, phi):
    return 3.98798593100815e-94*(1.0 - cos(theta)**2)**27*(4.54004796175122e+100*cos(theta)**10 - 1.60867841164413e+100*cos(theta)**8 + 1.80171982104143e+99*cos(theta)**6 - 7.32406431317654e+97*cos(theta)**4 + 9.07941857005357e+95*cos(theta)**2 - 1.52595270084934e+93)*cos(54*phi)

#@torch.jit.script
def Yl64_m55(theta, phi):
    return 1.15605936669399e-95*(1.0 - cos(theta)**2)**27.5*(4.54004796175122e+101*cos(theta)**9 - 1.28694272931531e+101*cos(theta)**7 + 1.08103189262486e+100*cos(theta)**5 - 2.92962572527062e+98*cos(theta)**3 + 1.81588371401071e+96*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl64_m56(theta, phi):
    return 3.5177766275191e-97*(1.0 - cos(theta)**2)**28*(4.0860431655761e+102*cos(theta)**8 - 9.00859910520715e+101*cos(theta)**6 + 5.40515946312429e+100*cos(theta)**4 - 8.78887717581185e+98*cos(theta)**2 + 1.81588371401071e+96)*cos(56*phi)

#@torch.jit.script
def Yl64_m57(theta, phi):
    return 1.13065623091741e-98*(1.0 - cos(theta)**2)**28.5*(3.26883453246088e+103*cos(theta)**7 - 5.40515946312429e+102*cos(theta)**5 + 2.16206378524972e+101*cos(theta)**3 - 1.75777543516237e+99*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl64_m58(theta, phi):
    return 3.86902597215535e-100*(1.0 - cos(theta)**2)**29*(2.28818417272262e+104*cos(theta)**6 - 2.70257973156214e+103*cos(theta)**4 + 6.48619135574915e+101*cos(theta)**2 - 1.75777543516237e+99)*cos(58*phi)

#@torch.jit.script
def Yl64_m59(theta, phi):
    return 1.42420814176111e-101*(1.0 - cos(theta)**2)**29.5*(1.37291050363357e+105*cos(theta)**5 - 1.08103189262486e+104*cos(theta)**3 + 1.29723827114983e+102*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl64_m60(theta, phi):
    return 5.71975753921415e-103*(1.0 - cos(theta)**2)**30*(6.86455251816785e+105*cos(theta)**4 - 3.24309567787457e+104*cos(theta)**2 + 1.29723827114983e+102)*cos(60*phi)

#@torch.jit.script
def Yl64_m61(theta, phi):
    return 2.55795333449995e-104*(1.0 - cos(theta)**2)**30.5*(2.74582100726714e+106*cos(theta)**3 - 6.48619135574915e+104*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl64_m62(theta, phi):
    return 1.31566922853349e-105*(1.0 - cos(theta)**2)**31*(8.23746302180142e+106*cos(theta)**2 - 6.48619135574915e+104)*cos(62*phi)

#@torch.jit.script
def Yl64_m63(theta, phi):
    return 13.6004517087224*(1.0 - cos(theta)**2)**31.5*cos(63*phi)*cos(theta)

#@torch.jit.script
def Yl64_m64(theta, phi):
    return 1.20212145380472*(1.0 - cos(theta)**2)**32*cos(64*phi)

#@torch.jit.script
def Yl65_m_minus_65(theta, phi):
    return 1.20673614046122*(1.0 - cos(theta)**2)**32.5*sin(65*phi)

#@torch.jit.script
def Yl65_m_minus_64(theta, phi):
    return 13.7589089193287*(1.0 - cos(theta)**2)**32*sin(64*phi)*cos(theta)

#@torch.jit.script
def Yl65_m_minus_63(theta, phi):
    return 1.039873868417e-107*(1.0 - cos(theta)**2)**31.5*(1.06263272981238e+109*cos(theta)**2 - 8.23746302180142e+106)*sin(63*phi)

#@torch.jit.script
def Yl65_m_minus_62(theta, phi):
    return 2.03772829958056e-106*(1.0 - cos(theta)**2)**31*(3.54210909937461e+108*cos(theta)**3 - 8.23746302180142e+106*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl65_m_minus_61(theta, phi):
    return 4.59280633647778e-105*(1.0 - cos(theta)**2)**30.5*(8.85527274843652e+107*cos(theta)**4 - 4.11873151090071e+106*cos(theta)**2 + 1.62154783893729e+104)*sin(61*phi)

#@torch.jit.script
def Yl65_m_minus_60(theta, phi):
    return 1.15278524140301e-103*(1.0 - cos(theta)**2)**30*(1.7710545496873e+107*cos(theta)**5 - 1.37291050363357e+106*cos(theta)**3 + 1.62154783893729e+104*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl65_m_minus_59(theta, phi):
    return 3.15703240337733e-102*(1.0 - cos(theta)**2)**29.5*(2.95175758281217e+106*cos(theta)**6 - 3.43227625908392e+105*cos(theta)**4 + 8.10773919468643e+103*cos(theta)**2 - 2.16206378524972e+101)*sin(59*phi)

#@torch.jit.script
def Yl65_m_minus_58(theta, phi):
    return 9.30119826759211e-101*(1.0 - cos(theta)**2)**29*(4.21679654687453e+105*cos(theta)**7 - 6.86455251816785e+104*cos(theta)**5 + 2.70257973156214e+103*cos(theta)**3 - 2.16206378524972e+101*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl65_m_minus_57(theta, phi):
    return 2.91767189014888e-99*(1.0 - cos(theta)**2)**28.5*(5.27099568359317e+104*cos(theta)**8 - 1.14409208636131e+104*cos(theta)**6 + 6.75644932890536e+102*cos(theta)**4 - 1.08103189262486e+101*cos(theta)**2 + 2.19721929395296e+98)*sin(57*phi)

#@torch.jit.script
def Yl65_m_minus_56(theta, phi):
    return 9.66802180691806e-98*(1.0 - cos(theta)**2)**28*(5.85666187065908e+103*cos(theta)**9 - 1.63441726623044e+103*cos(theta)**7 + 1.35128986578107e+102*cos(theta)**5 - 3.60343964208286e+100*cos(theta)**3 + 2.19721929395296e+98*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl65_m_minus_55(theta, phi):
    return 3.36302663158415e-96*(1.0 - cos(theta)**2)**27.5*(5.85666187065908e+102*cos(theta)**10 - 2.04302158278805e+102*cos(theta)**8 + 2.25214977630179e+101*cos(theta)**6 - 9.00859910520715e+99*cos(theta)**4 + 1.09860964697648e+98*cos(theta)**2 - 1.81588371401071e+95)*sin(55*phi)

#@torch.jit.script
def Yl65_m_minus_54(theta, phi):
    return 1.2218482526346e-94*(1.0 - cos(theta)**2)**27*(5.32423806423552e+101*cos(theta)**11 - 2.27002398087561e+101*cos(theta)**9 + 3.21735682328827e+100*cos(theta)**7 - 1.80171982104143e+99*cos(theta)**5 + 3.66203215658827e+97*cos(theta)**3 - 1.81588371401071e+95*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl65_m_minus_53(theta, phi):
    return 4.6172285861995e-93*(1.0 - cos(theta)**2)**26.5*(4.4368650535296e+100*cos(theta)**12 - 2.27002398087561e+100*cos(theta)**10 + 4.02169602911033e+99*cos(theta)**8 - 3.00286636840238e+98*cos(theta)**6 + 9.15508039147068e+96*cos(theta)**4 - 9.07941857005356e+94*cos(theta)**2 + 1.27162725070778e+92)*sin(53*phi)

#@torch.jit.script
def Yl65_m_minus_52(theta, phi):
    return 1.80839815636967e-91*(1.0 - cos(theta)**2)**26*(3.41297311809969e+99*cos(theta)**13 - 2.06365816443237e+99*cos(theta)**11 + 4.46855114345593e+98*cos(theta)**9 - 4.28980909771769e+97*cos(theta)**7 + 1.83101607829414e+96*cos(theta)**5 - 3.02647285668452e+94*cos(theta)**3 + 1.27162725070778e+92*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl65_m_minus_51(theta, phi):
    return 7.31898748122476e-90*(1.0 - cos(theta)**2)**25.5*(2.43783794149978e+98*cos(theta)**14 - 1.71971513702698e+98*cos(theta)**12 + 4.46855114345593e+97*cos(theta)**10 - 5.36226137214711e+96*cos(theta)**8 + 3.05169346382356e+95*cos(theta)**6 - 7.5661821417113e+93*cos(theta)**4 + 6.35813625353891e+91*cos(theta)**2 - 7.76329212886314e+88)*sin(51*phi)

#@torch.jit.script
def Yl65_m_minus_50(theta, phi):
    return 3.05299173411205e-88*(1.0 - cos(theta)**2)**25*(1.62522529433319e+97*cos(theta)**15 - 1.32285779771306e+97*cos(theta)**13 + 4.06231922132357e+96*cos(theta)**11 - 5.95806819127457e+95*cos(theta)**9 + 4.35956209117651e+94*cos(theta)**7 - 1.51323642834226e+93*cos(theta)**5 + 2.11937875117964e+91*cos(theta)**3 - 7.76329212886314e+88*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl65_m_minus_49(theta, phi):
    return 1.30958755692561e-86*(1.0 - cos(theta)**2)**24.5*(1.01576580895824e+96*cos(theta)**16 - 9.448984269379e+95*cos(theta)**14 + 3.38526601776964e+95*cos(theta)**12 - 5.95806819127457e+94*cos(theta)**10 + 5.44945261397064e+93*cos(theta)**8 - 2.52206071390377e+92*cos(theta)**6 + 5.29844687794909e+90*cos(theta)**4 - 3.88164606443157e+88*cos(theta)**2 + 4.21918050481692e+85)*sin(49*phi)

#@torch.jit.script
def Yl65_m_minus_48(theta, phi):
    return 5.76516081754449e-85*(1.0 - cos(theta)**2)**24*(5.97509299387201e+94*cos(theta)**17 - 6.29932284625267e+94*cos(theta)**15 + 2.60405078289972e+94*cos(theta)**13 - 5.41642562843143e+93*cos(theta)**11 + 6.05494734885627e+92*cos(theta)**9 - 3.60294387700538e+91*cos(theta)**7 + 1.05968937558982e+90*cos(theta)**5 - 1.29388202147719e+88*cos(theta)**3 + 4.21918050481692e+85*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl65_m_minus_47(theta, phi):
    return 2.60008113717387e-83*(1.0 - cos(theta)**2)**23.5*(3.31949610770667e+93*cos(theta)**18 - 3.93707677890792e+93*cos(theta)**16 + 1.8600362734998e+93*cos(theta)**14 - 4.51368802369285e+92*cos(theta)**12 + 6.05494734885627e+91*cos(theta)**10 - 4.50367984625673e+90*cos(theta)**8 + 1.76614895931636e+89*cos(theta)**6 - 3.23470505369297e+87*cos(theta)**4 + 2.10959025240846e+85*cos(theta)**2 - 2.07432669853339e+82)*sin(47*phi)

#@torch.jit.script
def Yl65_m_minus_46(theta, phi):
    return 1.19942393862722e-81*(1.0 - cos(theta)**2)**23*(1.74710321458246e+92*cos(theta)**19 - 2.31592751700466e+92*cos(theta)**17 + 1.2400241823332e+92*cos(theta)**15 - 3.47206771053296e+91*cos(theta)**13 + 5.50449758986933e+90*cos(theta)**11 - 5.00408871806303e+89*cos(theta)**9 + 2.52306994188052e+88*cos(theta)**7 - 6.46941010738595e+86*cos(theta)**5 + 7.03196750802821e+84*cos(theta)**3 - 2.07432669853339e+82*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl65_m_minus_45(theta, phi):
    return 5.65131089368255e-80*(1.0 - cos(theta)**2)**22.5*(8.7355160729123e+90*cos(theta)**20 - 1.28662639833592e+91*cos(theta)**18 + 7.75015113958251e+90*cos(theta)**16 - 2.4800483646664e+90*cos(theta)**14 + 4.58708132489111e+89*cos(theta)**12 - 5.00408871806303e+88*cos(theta)**10 + 3.15383742735065e+87*cos(theta)**8 - 1.07823501789766e+86*cos(theta)**6 + 1.75799187700705e+84*cos(theta)**4 - 1.0371633492667e+82*cos(theta)**2 + 9.34381395735763e+78)*sin(45*phi)

#@torch.jit.script
def Yl65_m_minus_44(theta, phi):
    return 2.71615900174119e-78*(1.0 - cos(theta)**2)**22*(4.15976955852967e+89*cos(theta)**21 - 6.77171788597853e+89*cos(theta)**19 + 4.55891243504854e+89*cos(theta)**17 - 1.65336557644427e+89*cos(theta)**15 + 3.52852409607009e+88*cos(theta)**13 - 4.54917156187548e+87*cos(theta)**11 + 3.50426380816739e+86*cos(theta)**9 - 1.5403357398538e+85*cos(theta)**7 + 3.5159837540141e+83*cos(theta)**5 - 3.45721116422232e+81*cos(theta)**3 + 9.34381395735763e+78*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl65_m_minus_43(theta, phi):
    return 1.33008617371695e-76*(1.0 - cos(theta)**2)**21.5*(1.89080434478621e+88*cos(theta)**22 - 3.38585894298926e+88*cos(theta)**20 + 2.53272913058252e+88*cos(theta)**18 - 1.03335348527767e+88*cos(theta)**16 + 2.52037435433578e+87*cos(theta)**14 - 3.7909763015629e+86*cos(theta)**12 + 3.50426380816739e+85*cos(theta)**10 - 1.92541967481725e+84*cos(theta)**8 + 5.85997292335684e+82*cos(theta)**6 - 8.64302791055581e+80*cos(theta)**4 + 4.67190697867882e+78*cos(theta)**2 - 3.89650290131678e+75)*sin(43*phi)

#@torch.jit.script
def Yl65_m_minus_42(theta, phi):
    return 6.62911533020075e-75*(1.0 - cos(theta)**2)**21*(8.22088845559223e+86*cos(theta)**23 - 1.61231378237584e+87*cos(theta)**21 + 1.33301533188554e+87*cos(theta)**19 - 6.07854991339805e+86*cos(theta)**17 + 1.68024956955718e+86*cos(theta)**15 - 2.91613561658685e+85*cos(theta)**13 + 3.18569437106126e+84*cos(theta)**11 - 2.13935519424139e+83*cos(theta)**9 + 8.37138989050977e+81*cos(theta)**7 - 1.72860558211116e+80*cos(theta)**5 + 1.55730232622627e+78*cos(theta)**3 - 3.89650290131678e+75*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl65_m_minus_41(theta, phi):
    return 3.35933321831746e-73*(1.0 - cos(theta)**2)**20.5*(3.42537018983009e+85*cos(theta)**24 - 7.32869901079927e+85*cos(theta)**22 + 6.66507665942768e+85*cos(theta)**20 - 3.37697217411003e+85*cos(theta)**18 + 1.05015598097324e+85*cos(theta)**16 - 2.08295401184775e+84*cos(theta)**14 + 2.65474530921772e+83*cos(theta)**12 - 2.13935519424139e+82*cos(theta)**10 + 1.04642373631372e+81*cos(theta)**8 - 2.8810093035186e+79*cos(theta)**6 + 3.89325581556568e+77*cos(theta)**4 - 1.94825145065839e+75*cos(theta)**2 + 1.51732979023239e+72)*sin(41*phi)

#@torch.jit.script
def Yl65_m_minus_40(theta, phi):
    return 1.7293226168064e-71*(1.0 - cos(theta)**2)**20*(1.37014807593204e+84*cos(theta)**25 - 3.18639087426055e+84*cos(theta)**23 + 3.1738460282989e+84*cos(theta)**21 - 1.77735377584738e+84*cos(theta)**19 + 6.177388123372e+83*cos(theta)**17 - 1.3886360078985e+83*cos(theta)**15 + 2.04211177632132e+82*cos(theta)**13 - 1.94486835840126e+81*cos(theta)**11 + 1.16269304034858e+80*cos(theta)**9 - 4.11572757645515e+78*cos(theta)**7 + 7.78651163113136e+76*cos(theta)**5 - 6.49417150219463e+74*cos(theta)**3 + 1.51732979023239e+72*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl65_m_minus_39(theta, phi):
    return 9.03560724383533e-70*(1.0 - cos(theta)**2)**19.5*(5.2698002920463e+82*cos(theta)**26 - 1.32766286427523e+83*cos(theta)**24 + 1.44265728559041e+83*cos(theta)**22 - 8.88676887923691e+82*cos(theta)**20 + 3.43188229076222e+82*cos(theta)**18 - 8.67897504936562e+81*cos(theta)**16 + 1.45865126880094e+81*cos(theta)**14 - 1.62072363200105e+80*cos(theta)**12 + 1.16269304034858e+79*cos(theta)**10 - 5.14465947056893e+77*cos(theta)**8 + 1.29775193852189e+76*cos(theta)**6 - 1.62354287554866e+74*cos(theta)**4 + 7.58664895116195e+71*cos(theta)**2 - 5.55798457960582e+68)*sin(39*phi)

#@torch.jit.script
def Yl65_m_minus_38(theta, phi):
    return 4.7880193475768e-68*(1.0 - cos(theta)**2)**19*(1.95177788594307e+81*cos(theta)**27 - 5.31065145710092e+81*cos(theta)**25 + 6.27242298082786e+81*cos(theta)**23 - 4.23179470439853e+81*cos(theta)**21 + 1.80625383724327e+81*cos(theta)**19 - 5.10527944080331e+80*cos(theta)**17 + 9.7243417920063e+79*cos(theta)**15 - 1.24671048615465e+79*cos(theta)**13 + 1.05699367304416e+78*cos(theta)**11 - 5.71628830063215e+76*cos(theta)**9 + 1.85393134074556e+75*cos(theta)**7 - 3.24708575109731e+73*cos(theta)**5 + 2.52888298372065e+71*cos(theta)**3 - 5.55798457960582e+68*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl65_m_minus_37(theta, phi):
    return 2.5713045876105e-66*(1.0 - cos(theta)**2)**18.5*(6.97063530693955e+79*cos(theta)**28 - 2.04255825273112e+80*cos(theta)**26 + 2.61350957534494e+80*cos(theta)**24 - 1.92354304745388e+80*cos(theta)**22 + 9.03126918621637e+79*cos(theta)**20 - 2.83626635600184e+79*cos(theta)**18 + 6.07771362000394e+78*cos(theta)**16 - 8.90507490110467e+77*cos(theta)**14 + 8.80828060870136e+76*cos(theta)**12 - 5.71628830063215e+75*cos(theta)**10 + 2.31741417593195e+74*cos(theta)**8 - 5.41180958516219e+72*cos(theta)**6 + 6.32220745930162e+70*cos(theta)**4 - 2.77899228980291e+68*cos(theta)**2 + 1.9271791191421e+65)*sin(37*phi)

#@torch.jit.script
def Yl65_m_minus_36(theta, phi):
    return 1.39846824565112e-64*(1.0 - cos(theta)**2)**18*(2.40366734722053e+78*cos(theta)**29 - 7.56503056567083e+78*cos(theta)**27 + 1.04540383013798e+79*cos(theta)**25 - 8.36323064110381e+78*cos(theta)**23 + 4.30060437438875e+78*cos(theta)**21 - 1.49277176631676e+78*cos(theta)**19 + 3.57512565882584e+77*cos(theta)**17 - 5.93671660073644e+76*cos(theta)**15 + 6.77560046823181e+75*cos(theta)**13 - 5.19662572784741e+74*cos(theta)**11 + 2.57490463992439e+73*cos(theta)**9 - 7.7311565502317e+71*cos(theta)**7 + 1.26444149186032e+70*cos(theta)**5 - 9.26330763267637e+67*cos(theta)**3 + 1.9271791191421e+65*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl65_m_minus_35(theta, phi):
    return 7.6979294003689e-63*(1.0 - cos(theta)**2)**17.5*(8.01222449073511e+76*cos(theta)**30 - 2.70179663059672e+77*cos(theta)**28 + 4.02078396206914e+77*cos(theta)**26 - 3.48467943379326e+77*cos(theta)**24 + 1.9548201701767e+77*cos(theta)**22 - 7.46385883158378e+76*cos(theta)**20 + 1.98618092156991e+76*cos(theta)**18 - 3.71044787546028e+75*cos(theta)**16 + 4.83971462016558e+74*cos(theta)**14 - 4.33052143987284e+73*cos(theta)**12 + 2.57490463992439e+72*cos(theta)**10 - 9.66394568778962e+70*cos(theta)**8 + 2.10740248643387e+69*cos(theta)**6 - 2.31582690816909e+67*cos(theta)**4 + 9.63589559571051e+64*cos(theta)**2 - 6.36032712588153e+61)*sin(35*phi)

#@torch.jit.script
def Yl65_m_minus_34(theta, phi):
    return 4.28602569829554e-61*(1.0 - cos(theta)**2)**17*(2.58458854539842e+75*cos(theta)**31 - 9.31654010550595e+75*cos(theta)**29 + 1.48917924521079e+76*cos(theta)**27 - 1.3938717735173e+76*cos(theta)**25 + 8.49921813120306e+75*cos(theta)**23 - 3.55421849123037e+75*cos(theta)**21 + 1.04535837977364e+75*cos(theta)**19 - 2.18261639732958e+74*cos(theta)**17 + 3.22647641344372e+73*cos(theta)**15 - 3.33117033836372e+72*cos(theta)**13 + 2.34082239993126e+71*cos(theta)**11 - 1.07377174308774e+70*cos(theta)**9 + 3.01057498061982e+68*cos(theta)**7 - 4.63165381633819e+66*cos(theta)**5 + 3.21196519857017e+64*cos(theta)**3 - 6.36032712588153e+61*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl65_m_minus_33(theta, phi):
    return 2.41238909787524e-59*(1.0 - cos(theta)**2)**16.5*(8.07683920437007e+73*cos(theta)**32 - 3.10551336850198e+74*cos(theta)**30 + 5.31849730432426e+74*cos(theta)**28 - 5.36104528275885e+74*cos(theta)**26 + 3.54134088800128e+74*cos(theta)**24 - 1.61555385965017e+74*cos(theta)**22 + 5.22679189886819e+73*cos(theta)**20 - 1.2125646651831e+73*cos(theta)**18 + 2.01654775840232e+72*cos(theta)**16 - 2.37940738454552e+71*cos(theta)**14 + 1.95068533327605e+70*cos(theta)**12 - 1.07377174308774e+69*cos(theta)**10 + 3.76321872577478e+67*cos(theta)**8 - 7.71942302723031e+65*cos(theta)**6 + 8.02991299642543e+63*cos(theta)**4 - 3.18016356294076e+61*cos(theta)**2 + 2.00767901700806e+58)*sin(33*phi)

#@torch.jit.script
def Yl65_m_minus_32(theta, phi):
    return 1.37188391746445e-57*(1.0 - cos(theta)**2)**16*(2.4475270316273e+72*cos(theta)**33 - 1.00177850596838e+73*cos(theta)**31 + 1.83396458769802e+73*cos(theta)**29 - 1.98557232694772e+73*cos(theta)**27 + 1.41653635520051e+73*cos(theta)**25 - 7.0241472158703e+72*cos(theta)**23 + 2.48894852327057e+72*cos(theta)**21 - 6.38191929043735e+71*cos(theta)**19 + 1.18620456376607e+71*cos(theta)**17 - 1.58627158969701e+70*cos(theta)**15 + 1.50052717944312e+69*cos(theta)**13 - 9.7615613007976e+67*cos(theta)**11 + 4.18135413974975e+66*cos(theta)**9 - 1.10277471817576e+65*cos(theta)**7 + 1.60598259928509e+63*cos(theta)**5 - 1.06005452098025e+61*cos(theta)**3 + 2.00767901700806e+58*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl65_m_minus_31(theta, phi):
    return 7.87848460233697e-56*(1.0 - cos(theta)**2)**15.5*(7.19860891655087e+70*cos(theta)**34 - 3.13055783115119e+71*cos(theta)**32 + 6.11321529232674e+71*cos(theta)**30 - 7.09132973909901e+71*cos(theta)**28 + 5.44821675077119e+71*cos(theta)**26 - 2.92672800661262e+71*cos(theta)**24 + 1.13134023785026e+71*cos(theta)**22 - 3.19095964521868e+70*cos(theta)**20 + 6.59002535425596e+69*cos(theta)**18 - 9.91419743560632e+68*cos(theta)**16 + 1.07180512817366e+68*cos(theta)**14 - 8.13463441733133e+66*cos(theta)**12 + 4.18135413974975e+65*cos(theta)**10 - 1.3784683977197e+64*cos(theta)**8 + 2.67663766547514e+62*cos(theta)**6 - 2.65013630245064e+60*cos(theta)**4 + 1.00383950850403e+58*cos(theta)**2 - 6.08756524259569e+54)*sin(31*phi)

#@torch.jit.script
def Yl65_m_minus_30(theta, phi):
    return 4.5668035424607e-54*(1.0 - cos(theta)**2)**15*(2.05674540472882e+69*cos(theta)**35 - 9.48653888227634e+69*cos(theta)**33 + 1.97200493300862e+70*cos(theta)**31 - 2.44528611693069e+70*cos(theta)**29 + 2.01785805584118e+70*cos(theta)**27 - 1.17069120264505e+70*cos(theta)**25 + 4.91887059934895e+69*cos(theta)**23 - 1.51950459296127e+69*cos(theta)**21 + 3.46843439697682e+68*cos(theta)**19 - 5.8318808444743e+67*cos(theta)**17 + 7.14536752115771e+66*cos(theta)**15 - 6.25741109025487e+65*cos(theta)**13 + 3.80123103613614e+64*cos(theta)**11 - 1.53163155302189e+63*cos(theta)**9 + 3.82376809353592e+61*cos(theta)**7 - 5.30027260490127e+59*cos(theta)**5 + 3.34613169501343e+57*cos(theta)**3 - 6.08756524259569e+54*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl65_m_minus_29(theta, phi):
    return 2.67070169649057e-52*(1.0 - cos(theta)**2)**14.5*(5.71318167980228e+67*cos(theta)**36 - 2.79015849478716e+68*cos(theta)**34 + 6.16251541565195e+68*cos(theta)**32 - 8.15095372310231e+68*cos(theta)**30 + 7.20663591371851e+68*cos(theta)**28 - 4.50265847171173e+68*cos(theta)**26 + 2.0495294163954e+68*cos(theta)**24 - 6.90683905891489e+67*cos(theta)**22 + 1.73421719848841e+67*cos(theta)**20 - 3.23993380248572e+66*cos(theta)**18 + 4.46585470072357e+65*cos(theta)**16 - 4.46957935018205e+64*cos(theta)**14 + 3.16769253011345e+63*cos(theta)**12 - 1.53163155302189e+62*cos(theta)**10 + 4.7797101169199e+60*cos(theta)**8 - 8.83378767483545e+58*cos(theta)**6 + 8.36532923753357e+56*cos(theta)**4 - 3.04378262129784e+54*cos(theta)**2 + 1.77998983701628e+51)*sin(29*phi)

#@torch.jit.script
def Yl65_m_minus_28(theta, phi):
    return 1.57503486261719e-50*(1.0 - cos(theta)**2)**14*(1.54410315670332e+66*cos(theta)**37 - 7.9718814136776e+66*cos(theta)**35 + 1.86742891383393e+67*cos(theta)**33 - 2.62933991067817e+67*cos(theta)**31 + 2.48504686679949e+67*cos(theta)**29 - 1.66765128581916e+67*cos(theta)**27 + 8.19811766558158e+66*cos(theta)**25 - 3.00297350387604e+66*cos(theta)**23 + 8.2581771356591e+65*cos(theta)**21 - 1.70522831709775e+65*cos(theta)**19 + 2.6269733533668e+64*cos(theta)**17 - 2.97971956678803e+63*cos(theta)**15 + 2.43668656162573e+62*cos(theta)**13 - 1.39239232092899e+61*cos(theta)**11 + 5.31078901879989e+59*cos(theta)**9 - 1.26196966783364e+58*cos(theta)**7 + 1.67306584750671e+56*cos(theta)**5 - 1.01459420709928e+54*cos(theta)**3 + 1.77998983701628e+51*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl65_m_minus_27(theta, phi):
    return 9.3631815364416e-49*(1.0 - cos(theta)**2)**13.5*(4.06342935974557e+64*cos(theta)**38 - 2.21441150379933e+65*cos(theta)**36 + 5.49243798186449e+65*cos(theta)**34 - 8.21668722086927e+65*cos(theta)**32 + 8.28348955599829e+65*cos(theta)**30 - 5.95589744935414e+65*cos(theta)**28 + 3.15312217906984e+65*cos(theta)**26 - 1.25123895994835e+65*cos(theta)**24 + 3.75371687984505e+64*cos(theta)**22 - 8.52614158548875e+63*cos(theta)**20 + 1.45942964075934e+63*cos(theta)**18 - 1.86232472924252e+62*cos(theta)**16 + 1.74049040116124e+61*cos(theta)**14 - 1.16032693410749e+60*cos(theta)**12 + 5.31078901879989e+58*cos(theta)**10 - 1.57746208479205e+57*cos(theta)**8 + 2.78844307917786e+55*cos(theta)**6 - 2.5364855177482e+53*cos(theta)**4 + 8.89994918508141e+50*cos(theta)**2 - 5.03675675443204e+47)*sin(27*phi)

#@torch.jit.script
def Yl65_m_minus_26(theta, phi):
    return 5.60853792464566e-47*(1.0 - cos(theta)**2)**13*(1.04190496403733e+63*cos(theta)**39 - 5.98489595621441e+63*cos(theta)**37 + 1.56926799481842e+64*cos(theta)**35 - 2.48990521844523e+64*cos(theta)**33 + 2.67209340516074e+64*cos(theta)**31 - 2.0537577411566e+64*cos(theta)**29 + 1.16782302928513e+64*cos(theta)**27 - 5.0049558397934e+63*cos(theta)**25 + 1.63205081732393e+63*cos(theta)**23 - 4.06006742166131e+62*cos(theta)**21 + 7.68120863557545e+61*cos(theta)**19 - 1.09548513484854e+61*cos(theta)**17 + 1.16032693410749e+60*cos(theta)**15 - 8.92559180082685e+58*cos(theta)**13 + 4.8279900170908e+57*cos(theta)**11 - 1.75273564976894e+56*cos(theta)**9 + 3.98349011311122e+54*cos(theta)**7 - 5.07297103549641e+52*cos(theta)**5 + 2.96664972836047e+50*cos(theta)**3 - 5.03675675443204e+47*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl65_m_minus_25(theta, phi):
    return 3.38376623681316e-45*(1.0 - cos(theta)**2)**12.5*(2.60476241009332e+61*cos(theta)**40 - 1.57497262005642e+62*cos(theta)**38 + 4.35907776338451e+62*cos(theta)**36 - 7.32325064248598e+62*cos(theta)**34 + 8.35029189112731e+62*cos(theta)**32 - 6.84585913718867e+62*cos(theta)**30 + 4.17079653316116e+62*cos(theta)**28 - 1.92498301530515e+62*cos(theta)**26 + 6.80021173884972e+61*cos(theta)**24 - 1.84548519166423e+61*cos(theta)**22 + 3.84060431778773e+60*cos(theta)**20 - 6.08602852693634e+59*cos(theta)**18 + 7.25204333817181e+58*cos(theta)**16 - 6.37542271487632e+57*cos(theta)**14 + 4.02332501424234e+56*cos(theta)**12 - 1.75273564976894e+55*cos(theta)**10 + 4.97936264138903e+53*cos(theta)**8 - 8.45495172582734e+51*cos(theta)**6 + 7.41662432090118e+49*cos(theta)**4 - 2.51837837721602e+47*cos(theta)**2 + 1.38372438308572e+44)*sin(25*phi)

#@torch.jit.script
def Yl65_m_minus_24(theta, phi):
    return 2.05548132705004e-43*(1.0 - cos(theta)**2)**12*(6.35307904900809e+59*cos(theta)**41 - 4.03839133347801e+60*cos(theta)**39 + 1.17812912523906e+61*cos(theta)**37 - 2.09235732642457e+61*cos(theta)**35 + 2.53039148215979e+61*cos(theta)**33 - 2.20834165715763e+61*cos(theta)**31 + 1.43820570109006e+61*cos(theta)**29 - 7.12956672335242e+60*cos(theta)**27 + 2.72008469553989e+60*cos(theta)**25 - 8.0238486594097e+59*cos(theta)**23 + 1.82885919894654e+59*cos(theta)**21 - 3.20317290891387e+58*cos(theta)**19 + 4.26590784598342e+57*cos(theta)**17 - 4.25028180991755e+56*cos(theta)**15 + 3.09486539557103e+55*cos(theta)**13 - 1.59339604524449e+54*cos(theta)**11 + 5.53262515709892e+52*cos(theta)**9 - 1.20785024654676e+51*cos(theta)**7 + 1.48332486418024e+49*cos(theta)**5 - 8.39459459072006e+46*cos(theta)**3 + 1.38372438308572e+44*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl65_m_minus_23(theta, phi):
    return 1.25670454085725e-41*(1.0 - cos(theta)**2)**11.5*(1.51263786881145e+58*cos(theta)**42 - 1.0095978333695e+59*cos(theta)**40 + 3.10033980326068e+59*cos(theta)**38 - 5.81210368451268e+59*cos(theta)**36 + 7.44232788870526e+59*cos(theta)**34 - 6.90106767861761e+59*cos(theta)**32 + 4.79401900363352e+59*cos(theta)**30 - 2.54627382976872e+59*cos(theta)**28 + 1.0461864213615e+59*cos(theta)**26 - 3.34327027475404e+58*cos(theta)**24 + 8.31299635884789e+57*cos(theta)**22 - 1.60158645445693e+57*cos(theta)**20 + 2.36994880332412e+56*cos(theta)**18 - 2.65642613119847e+55*cos(theta)**16 + 2.21061813969359e+54*cos(theta)**14 - 1.32783003770374e+53*cos(theta)**12 + 5.53262515709892e+51*cos(theta)**10 - 1.50981280818345e+50*cos(theta)**8 + 2.47220810696706e+48*cos(theta)**6 - 2.09864864768002e+46*cos(theta)**4 + 6.91862191542862e+43*cos(theta)**2 - 3.70177737583126e+40)*sin(23*phi)

#@torch.jit.script
def Yl65_m_minus_22(theta, phi):
    return 7.73052071376472e-40*(1.0 - cos(theta)**2)**11*(3.51776248560802e+56*cos(theta)**43 - 2.46243373992562e+57*cos(theta)**41 + 7.94958923912994e+57*cos(theta)**39 - 1.57083883365208e+58*cos(theta)**37 + 2.12637939677293e+58*cos(theta)**35 - 2.09123262988412e+58*cos(theta)**33 + 1.54645774310759e+58*cos(theta)**31 - 8.78025458540938e+57*cos(theta)**29 + 3.8747645235611e+57*cos(theta)**27 - 1.33730810990162e+57*cos(theta)**25 + 3.61434624297734e+56*cos(theta)**23 - 7.62660216408063e+55*cos(theta)**21 + 1.24734147543375e+55*cos(theta)**19 - 1.56260360658733e+54*cos(theta)**17 + 1.47374542646239e+53*cos(theta)**15 - 1.02140772131057e+52*cos(theta)**13 + 5.02965923372629e+50*cos(theta)**11 - 1.6775697868705e+49*cos(theta)**9 + 3.5317258670958e+47*cos(theta)**7 - 4.19729729536003e+45*cos(theta)**5 + 2.30620730514287e+43*cos(theta)**3 - 3.70177737583126e+40*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl65_m_minus_21(theta, phi):
    return 4.78293757576616e-38*(1.0 - cos(theta)**2)**10.5*(7.99491474001823e+54*cos(theta)**44 - 5.86293747601337e+55*cos(theta)**42 + 1.98739730978249e+56*cos(theta)**40 - 4.13378640434757e+56*cos(theta)**38 + 5.90660943548037e+56*cos(theta)**36 - 6.15068420554154e+56*cos(theta)**34 + 4.83268044721121e+56*cos(theta)**32 - 2.92675152846979e+56*cos(theta)**30 + 1.38384447270039e+56*cos(theta)**28 - 5.14349273039083e+55*cos(theta)**26 + 1.50597760124056e+55*cos(theta)**24 - 3.46663734730938e+54*cos(theta)**22 + 6.23670737716874e+53*cos(theta)**20 - 8.68113114770741e+52*cos(theta)**18 + 9.21090891538997e+51*cos(theta)**16 - 7.29576943793265e+50*cos(theta)**14 + 4.19138269477191e+49*cos(theta)**12 - 1.6775697868705e+48*cos(theta)**10 + 4.41465733386975e+46*cos(theta)**8 - 6.99549549226672e+44*cos(theta)**6 + 5.76551826285719e+42*cos(theta)**4 - 1.85088868791563e+40*cos(theta)**2 + 9.6702648271454e+36)*sin(21*phi)

#@torch.jit.script
def Yl65_m_minus_20(theta, phi):
    return 2.97543313609508e-36*(1.0 - cos(theta)**2)**10*(1.77664772000405e+53*cos(theta)**45 - 1.36347383163102e+54*cos(theta)**43 + 4.8473105116646e+54*cos(theta)**41 - 1.05994523188399e+55*cos(theta)**39 + 1.59638092850821e+55*cos(theta)**37 - 1.75733834444044e+55*cos(theta)**35 + 1.46444862036703e+55*cos(theta)**33 - 9.44113396280578e+54*cos(theta)**31 + 4.77187749207031e+54*cos(theta)**29 - 1.90499730755216e+54*cos(theta)**27 + 6.02391040496224e+53*cos(theta)**25 - 1.50723362926495e+53*cos(theta)**23 + 2.96986065579464e+52*cos(theta)**21 - 4.56901639353021e+51*cos(theta)**19 + 5.41818171493527e+50*cos(theta)**17 - 4.8638462919551e+49*cos(theta)**15 + 3.22414053443993e+48*cos(theta)**13 - 1.52506344260955e+47*cos(theta)**11 + 4.90517481541083e+45*cos(theta)**9 - 9.99356498895246e+43*cos(theta)**7 + 1.15310365257144e+42*cos(theta)**5 - 6.16962895971877e+39*cos(theta)**3 + 9.6702648271454e+36*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl65_m_minus_19(theta, phi):
    return 1.86053812587183e-34*(1.0 - cos(theta)**2)**9.5*(3.86227765218272e+51*cos(theta)**46 - 3.09880416279776e+52*cos(theta)**44 + 1.15412155039633e+53*cos(theta)**42 - 2.64986307970998e+53*cos(theta)**40 + 4.20100244344265e+53*cos(theta)**38 - 4.88149540122344e+53*cos(theta)**36 + 4.30720182460892e+53*cos(theta)**34 - 2.95035436337681e+53*cos(theta)**32 + 1.5906258306901e+53*cos(theta)**30 - 6.80356181268629e+52*cos(theta)**28 + 2.31688861729317e+52*cos(theta)**26 - 6.28014012193728e+51*cos(theta)**24 + 1.34993666172484e+51*cos(theta)**22 - 2.28450819676511e+50*cos(theta)**20 + 3.01010095274182e+49*cos(theta)**18 - 3.03990393247194e+48*cos(theta)**16 + 2.30295752459995e+47*cos(theta)**14 - 1.27088620217462e+46*cos(theta)**12 + 4.90517481541083e+44*cos(theta)**10 - 1.24919562361906e+43*cos(theta)**8 + 1.9218394209524e+41*cos(theta)**6 - 1.54240723992969e+39*cos(theta)**4 + 4.8351324135727e+36*cos(theta)**2 - 2.47321351077888e+33)*sin(19*phi)

#@torch.jit.script
def Yl65_m_minus_18(theta, phi):
    return 1.16903400982024e-32*(1.0 - cos(theta)**2)**9*(8.21761202592068e+49*cos(theta)**47 - 6.88623147288392e+50*cos(theta)**45 + 2.68400360557287e+51*cos(theta)**43 - 6.46308068221946e+51*cos(theta)**41 + 1.07718011370324e+52*cos(theta)**39 - 1.31932308141174e+52*cos(theta)**37 + 1.23062909274541e+52*cos(theta)**35 - 8.94046776780851e+51*cos(theta)**33 + 5.13105106674227e+51*cos(theta)**31 - 2.34605579747803e+51*cos(theta)**29 + 8.58106895293766e+50*cos(theta)**27 - 2.51205604877491e+50*cos(theta)**25 + 5.86928983358624e+49*cos(theta)**23 - 1.08786104607862e+49*cos(theta)**21 + 1.5842636593378e+48*cos(theta)**19 - 1.78817878380702e+47*cos(theta)**17 + 1.53530501639997e+46*cos(theta)**15 - 9.77604770903557e+44*cos(theta)**13 + 4.45924983219166e+43*cos(theta)**11 - 1.38799513735451e+42*cos(theta)**9 + 2.74548488707485e+40*cos(theta)**7 - 3.08481447985938e+38*cos(theta)**5 + 1.61171080452423e+36*cos(theta)**3 - 2.47321351077888e+33*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl65_m_minus_17(theta, phi):
    return 7.37881820904114e-31*(1.0 - cos(theta)**2)**8.5*(1.71200250540014e+48*cos(theta)**48 - 1.49700684193129e+49*cos(theta)**46 + 6.10000819448379e+49*cos(theta)**44 - 1.53882873386178e+50*cos(theta)**42 + 2.69295028425811e+50*cos(theta)**40 - 3.47190284582037e+50*cos(theta)**38 + 3.41841414651502e+50*cos(theta)**36 - 2.62954934347309e+50*cos(theta)**34 + 1.60345345835696e+50*cos(theta)**32 - 7.82018599159344e+49*cos(theta)**30 + 3.06466748319202e+49*cos(theta)**28 - 9.66175403374966e+48*cos(theta)**26 + 2.44553743066093e+48*cos(theta)**24 - 4.94482293672101e+47*cos(theta)**22 + 7.921318296689e+46*cos(theta)**20 - 9.93432657670567e+45*cos(theta)**18 + 9.5956563524998e+44*cos(theta)**16 - 6.98289122073969e+43*cos(theta)**14 + 3.71604152682639e+42*cos(theta)**12 - 1.38799513735451e+41*cos(theta)**10 + 3.43185610884356e+39*cos(theta)**8 - 5.14135746643231e+37*cos(theta)**6 + 4.02927701131058e+35*cos(theta)**4 - 1.23660675538944e+33*cos(theta)**2 + 6.20786523789878e+29)*sin(17*phi)

#@torch.jit.script
def Yl65_m_minus_16(theta, phi):
    return 4.67726285230182e-29*(1.0 - cos(theta)**2)**8*(3.49388266408192e+46*cos(theta)**49 - 3.18512094027933e+47*cos(theta)**47 + 1.35555737655195e+48*cos(theta)**45 - 3.57867147409716e+48*cos(theta)**43 + 6.56817142501978e+48*cos(theta)**41 - 8.90231498928301e+48*cos(theta)**39 + 9.23895715274329e+48*cos(theta)**37 - 7.51299812420883e+48*cos(theta)**35 + 4.85894987380897e+48*cos(theta)**33 - 2.5226406424495e+48*cos(theta)**31 + 1.05678189075587e+48*cos(theta)**29 - 3.57842741990728e+47*cos(theta)**27 + 9.78214972264374e+46*cos(theta)**25 - 2.14992301596566e+46*cos(theta)**23 + 3.77205633175667e+45*cos(theta)**21 - 5.22859293510825e+44*cos(theta)**19 + 5.64450373676459e+43*cos(theta)**17 - 4.65526081382646e+42*cos(theta)**15 + 2.85849348217414e+41*cos(theta)**13 - 1.26181376123137e+40*cos(theta)**11 + 3.81317345427063e+38*cos(theta)**9 - 7.34479638061758e+36*cos(theta)**7 + 8.05855402262117e+34*cos(theta)**5 - 4.12202251796479e+32*cos(theta)**3 + 6.20786523789878e+29*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl65_m_minus_15(theta, phi):
    return 2.9765918522291e-27*(1.0 - cos(theta)**2)**7.5*(6.98776532816385e+44*cos(theta)**50 - 6.63566862558195e+45*cos(theta)**48 + 2.94686386206946e+46*cos(theta)**46 - 8.13334425931172e+46*cos(theta)**44 + 1.56385033929042e+47*cos(theta)**42 - 2.22557874732075e+47*cos(theta)**40 + 2.43130451387981e+47*cos(theta)**38 - 2.08694392339134e+47*cos(theta)**36 + 1.42910290406146e+47*cos(theta)**34 - 7.88325200765467e+46*cos(theta)**32 + 3.52260630251957e+46*cos(theta)**30 - 1.27800979282403e+46*cos(theta)**28 + 3.7623652779399e+45*cos(theta)**26 - 8.95801256652357e+44*cos(theta)**24 + 1.71457105988939e+44*cos(theta)**22 - 2.61429646755412e+43*cos(theta)**20 + 3.13583540931366e+42*cos(theta)**18 - 2.90953800864154e+41*cos(theta)**16 + 2.04178105869582e+40*cos(theta)**14 - 1.05151146769281e+39*cos(theta)**12 + 3.81317345427063e+37*cos(theta)**10 - 9.18099547577197e+35*cos(theta)**8 + 1.34309233710353e+34*cos(theta)**6 - 1.0305056294912e+32*cos(theta)**4 + 3.10393261894939e+29*cos(theta)**2 - 1.53280623157995e+26)*sin(15*phi)

#@torch.jit.script
def Yl65_m_minus_14(theta, phi):
    return 1.90129440496224e-25*(1.0 - cos(theta)**2)**7*(1.37015006434585e+43*cos(theta)**51 - 1.35421808685346e+44*cos(theta)**49 + 6.26992311078609e+44*cos(theta)**47 - 1.8074098354026e+45*cos(theta)**45 + 3.63686125416378e+45*cos(theta)**43 - 5.42824084712379e+45*cos(theta)**41 + 6.23411413815337e+45*cos(theta)**39 - 5.64038898213876e+45*cos(theta)**37 + 4.08315115446132e+45*cos(theta)**35 - 2.38886424474384e+45*cos(theta)**33 + 1.13632461371599e+45*cos(theta)**31 - 4.40693032008286e+44*cos(theta)**29 + 1.39346862145922e+44*cos(theta)**27 - 3.58320502660943e+43*cos(theta)**25 + 7.4546567821278e+42*cos(theta)**23 - 1.24490307978768e+42*cos(theta)**21 + 1.65043968911245e+41*cos(theta)**19 - 1.71149294625973e+40*cos(theta)**17 + 1.36118737246388e+39*cos(theta)**15 - 8.08854975148315e+37*cos(theta)**13 + 3.46652132206421e+36*cos(theta)**11 - 1.02011060841911e+35*cos(theta)**9 + 1.91870333871933e+33*cos(theta)**7 - 2.0610112589824e+31*cos(theta)**5 + 1.03464420631646e+29*cos(theta)**3 - 1.53280623157995e+26*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl65_m_minus_13(theta, phi):
    return 1.2186095790741e-23*(1.0 - cos(theta)**2)**6.5*(2.63490396989587e+41*cos(theta)**52 - 2.70843617370692e+42*cos(theta)**50 + 1.30623398141377e+43*cos(theta)**48 - 3.92915181609262e+43*cos(theta)**46 + 8.26559375946313e+43*cos(theta)**44 - 1.29243829693423e+44*cos(theta)**42 + 1.55852853453834e+44*cos(theta)**40 - 1.48431289003652e+44*cos(theta)**38 + 1.13420865401703e+44*cos(theta)**36 - 7.02607130807012e+43*cos(theta)**34 + 3.55101441786247e+43*cos(theta)**32 - 1.46897677336095e+43*cos(theta)**30 + 4.97667364806865e+42*cos(theta)**28 - 1.37815577946516e+42*cos(theta)**26 + 3.10610699255325e+41*cos(theta)**24 - 5.65865036267127e+40*cos(theta)**22 + 8.25219844556226e+39*cos(theta)**20 - 9.50829414588738e+38*cos(theta)**18 + 8.50742107789924e+37*cos(theta)**16 - 5.77753553677368e+36*cos(theta)**14 + 2.88876776838684e+35*cos(theta)**12 - 1.02011060841911e+34*cos(theta)**10 + 2.39837917339916e+32*cos(theta)**8 - 3.43501876497066e+30*cos(theta)**6 + 2.58661051579116e+28*cos(theta)**4 - 7.66403115789973e+25*cos(theta)**2 + 3.73127125506316e+22)*sin(13*phi)

#@torch.jit.script
def Yl65_m_minus_12(theta, phi):
    return 7.83519525722043e-22*(1.0 - cos(theta)**2)**6*(4.97151692433183e+39*cos(theta)**53 - 5.31065916413121e+40*cos(theta)**51 + 2.6657836355383e+41*cos(theta)**49 - 8.35989748104812e+41*cos(theta)**47 + 1.83679861321403e+42*cos(theta)**45 - 3.00567045798659e+42*cos(theta)**43 + 3.8012891086301e+42*cos(theta)**41 - 3.80593048727312e+42*cos(theta)**39 + 3.06542879464063e+42*cos(theta)**37 - 2.00744894516289e+42*cos(theta)**35 + 1.07606497510984e+42*cos(theta)**33 - 4.73863475277727e+41*cos(theta)**31 + 1.71609436140298e+41*cos(theta)**29 - 5.1042806646858e+40*cos(theta)**27 + 1.2424427970213e+40*cos(theta)**25 - 2.46028276637881e+39*cos(theta)**23 + 3.9296183074106e+38*cos(theta)**21 - 5.00436533994073e+37*cos(theta)**19 + 5.00436533994073e+36*cos(theta)**17 - 3.85169035784912e+35*cos(theta)**15 + 2.22212905260526e+34*cos(theta)**13 - 9.27373280381008e+32*cos(theta)**11 + 2.66486574822129e+31*cos(theta)**9 - 4.9071696642438e+29*cos(theta)**7 + 5.17322103158232e+27*cos(theta)**5 - 2.55467705263324e+25*cos(theta)**3 + 3.73127125506316e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl65_m_minus_11(theta, phi):
    return 5.05233415225719e-20*(1.0 - cos(theta)**2)**5.5*(9.20651282283672e+37*cos(theta)**54 - 1.02128060848677e+39*cos(theta)**52 + 5.33156727107661e+39*cos(theta)**50 - 1.74164530855169e+40*cos(theta)**48 + 3.99304046350876e+40*cos(theta)**46 - 6.8310692226968e+40*cos(theta)**44 + 9.0506883538812e+40*cos(theta)**42 - 9.5148262181828e+40*cos(theta)**40 + 8.06691788063324e+40*cos(theta)**38 - 5.57624706989692e+40*cos(theta)**36 + 3.16489698561717e+40*cos(theta)**34 - 1.4808233602429e+40*cos(theta)**32 + 5.72031453800994e+39*cos(theta)**30 - 1.82295738024493e+39*cos(theta)**28 + 4.77862614238961e+38*cos(theta)**26 - 1.0251178193245e+38*cos(theta)**24 + 1.78619013973209e+37*cos(theta)**22 - 2.50218266997036e+36*cos(theta)**20 + 2.78020296663374e+35*cos(theta)**18 - 2.4073064736557e+34*cos(theta)**16 + 1.58723503757519e+33*cos(theta)**14 - 7.72811066984173e+31*cos(theta)**12 + 2.66486574822129e+30*cos(theta)**10 - 6.13396208030475e+28*cos(theta)**8 + 8.6220350526372e+26*cos(theta)**6 - 6.38669263158311e+24*cos(theta)**4 + 1.86563562753158e+22*cos(theta)**2 - 8.97371634214324e+18)*sin(11*phi)

#@torch.jit.script
def Yl65_m_minus_10(theta, phi):
    return 3.26648153237928e-18*(1.0 - cos(theta)**2)**5*(1.67391142233395e+36*cos(theta)**55 - 1.92694454431466e+37*cos(theta)**53 + 1.04540534726992e+38*cos(theta)**51 - 3.55437818071774e+38*cos(theta)**49 + 8.49583077342289e+38*cos(theta)**47 - 1.51801538282151e+39*cos(theta)**45 + 2.10481124508865e+39*cos(theta)**43 - 2.320689321508e+39*cos(theta)**41 + 2.06844048221365e+39*cos(theta)**39 - 1.50709380267484e+39*cos(theta)**37 + 9.04256281604906e+38*cos(theta)**35 - 4.48734351588756e+38*cos(theta)**33 + 1.84526275419676e+38*cos(theta)**31 - 6.28605993187906e+37*cos(theta)**29 + 1.76986153421838e+37*cos(theta)**27 - 4.10047127729802e+36*cos(theta)**25 + 7.7660440857917e+35*cos(theta)**23 - 1.19151555712874e+35*cos(theta)**21 + 1.46326471928091e+34*cos(theta)**19 - 1.41606263156218e+33*cos(theta)**17 + 1.05815669171679e+32*cos(theta)**15 - 5.94470051526287e+30*cos(theta)**13 + 2.42260522565571e+29*cos(theta)**11 - 6.81551342256083e+27*cos(theta)**9 + 1.23171929323389e+26*cos(theta)**7 - 1.27733852631662e+24*cos(theta)**5 + 6.21878542510527e+21*cos(theta)**3 - 8.97371634214324e+18*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl65_m_minus_9(theta, phi):
    return 2.11692198074881e-16*(1.0 - cos(theta)**2)**4.5*(2.98912753988205e+34*cos(theta)**56 - 3.56841582280493e+35*cos(theta)**54 + 2.01039489859601e+36*cos(theta)**52 - 7.10875636143548e+36*cos(theta)**50 + 1.7699647444631e+37*cos(theta)**48 - 3.30003344091633e+37*cos(theta)**46 + 4.78366192065602e+37*cos(theta)**44 - 5.52545076549524e+37*cos(theta)**42 + 5.17110120553413e+37*cos(theta)**40 - 3.96603632282853e+37*cos(theta)**38 + 2.51182300445807e+37*cos(theta)**36 - 1.31980691643752e+37*cos(theta)**34 + 5.76644610686486e+36*cos(theta)**32 - 2.09535331062635e+36*cos(theta)**30 + 6.32093405077991e+35*cos(theta)**28 - 1.57710433742231e+35*cos(theta)**26 + 3.23585170241321e+34*cos(theta)**24 - 5.41597980513066e+33*cos(theta)**22 + 7.31632359640457e+32*cos(theta)**20 - 7.86701461978987e+31*cos(theta)**18 + 6.61347932322994e+30*cos(theta)**16 - 4.24621465375919e+29*cos(theta)**14 + 2.01883768804643e+28*cos(theta)**12 - 6.81551342256083e+26*cos(theta)**10 + 1.53964911654236e+25*cos(theta)**8 - 2.12889754386104e+23*cos(theta)**6 + 1.55469635627632e+21*cos(theta)**4 - 4.48685817107162e+18*cos(theta)**2 + 2.13659912908172e+15)*sin(9*phi)

#@torch.jit.script
def Yl65_m_minus_8(theta, phi):
    return 1.37485893388855e-14*(1.0 - cos(theta)**2)**4*(5.24408340330185e+32*cos(theta)**57 - 6.48802876873624e+33*cos(theta)**55 + 3.79319792187926e+34*cos(theta)**53 - 1.3938737963599e+35*cos(theta)**51 + 3.61217294788388e+35*cos(theta)**49 - 7.02134774663049e+35*cos(theta)**47 + 1.06303598236801e+36*cos(theta)**45 - 1.28498855011517e+36*cos(theta)**43 + 1.26124419647174e+36*cos(theta)**41 - 1.01693239046886e+36*cos(theta)**39 + 6.78871082285965e+35*cos(theta)**37 - 3.7708769041072e+35*cos(theta)**35 + 1.74740791117117e+35*cos(theta)**33 - 6.75920422782694e+34*cos(theta)**31 + 2.17963243130342e+34*cos(theta)**29 - 5.8411271756382e+33*cos(theta)**27 + 1.29434068096528e+33*cos(theta)**25 - 2.35477382831768e+32*cos(theta)**23 + 3.48396361733551e+31*cos(theta)**21 - 4.14053401041572e+30*cos(theta)**19 + 3.89028195484114e+29*cos(theta)**17 - 2.83080976917279e+28*cos(theta)**15 + 1.55295206772802e+27*cos(theta)**13 - 6.19592129323712e+25*cos(theta)**11 + 1.71072124060262e+24*cos(theta)**9 - 3.04128220551577e+22*cos(theta)**7 + 3.10939271255263e+20*cos(theta)**5 - 1.49561939035721e+18*cos(theta)**3 + 2.13659912908172e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl65_m_minus_7(theta, phi):
    return 8.94609626093219e-13*(1.0 - cos(theta)**2)**3.5*(9.04152310914111e+30*cos(theta)**58 - 1.15857656584576e+32*cos(theta)**56 + 7.0244405960727e+32*cos(theta)**54 - 2.68052653146134e+33*cos(theta)**52 + 7.22434589576776e+33*cos(theta)**50 - 1.46278078054802e+34*cos(theta)**48 + 2.31094778775653e+34*cos(theta)**46 - 2.92042852298903e+34*cos(theta)**44 + 3.00296237255176e+34*cos(theta)**42 - 2.54233097617214e+34*cos(theta)**40 + 1.78650284812096e+34*cos(theta)**38 - 1.04746580669644e+34*cos(theta)**36 + 5.13943503285638e+33*cos(theta)**34 - 2.11225132119592e+33*cos(theta)**32 + 7.26544143767806e+32*cos(theta)**30 - 2.08611684844222e+32*cos(theta)**28 + 4.97823338832801e+31*cos(theta)**26 - 9.81155761799032e+30*cos(theta)**24 + 1.5836198260616e+30*cos(theta)**22 - 2.07026700520786e+29*cos(theta)**20 + 2.16126775268952e+28*cos(theta)**18 - 1.769256105733e+27*cos(theta)**16 + 1.10925147694859e+26*cos(theta)**14 - 5.16326774436427e+24*cos(theta)**12 + 1.71072124060262e+23*cos(theta)**10 - 3.80160275689471e+21*cos(theta)**8 + 5.18232118758772e+19*cos(theta)**6 - 3.73904847589302e+17*cos(theta)**4 + 1.06829956454086e+15*cos(theta)**2 - 504628986556.855)*sin(7*phi)

#@torch.jit.script
def Yl65_m_minus_6(theta, phi):
    return 5.8307687961392e-11*(1.0 - cos(theta)**2)**3*(1.53246154392222e+29*cos(theta)**59 - 2.03259046639606e+30*cos(theta)**57 + 1.27717101746776e+31*cos(theta)**55 - 5.05759722917234e+31*cos(theta)**53 + 1.41653841093486e+32*cos(theta)**51 - 2.98526689907759e+32*cos(theta)**49 + 4.91691018671603e+32*cos(theta)**47 - 6.48984116219783e+32*cos(theta)**45 + 6.98363342453897e+32*cos(theta)**43 - 6.20080725895643e+32*cos(theta)**41 + 4.58077653364349e+32*cos(theta)**39 - 2.83098866674715e+32*cos(theta)**37 + 1.46841000938754e+32*cos(theta)**35 - 6.40076157938158e+31*cos(theta)**33 + 2.34369078634776e+31*cos(theta)**31 - 7.19350637393867e+30*cos(theta)**29 + 1.84379014382519e+30*cos(theta)**27 - 3.92462304719613e+29*cos(theta)**25 + 6.88530359157216e+28*cos(theta)**23 - 9.85841431051361e+27*cos(theta)**21 + 1.1375093435208e+27*cos(theta)**19 - 1.04073888572529e+26*cos(theta)**17 + 7.39500984632391e+24*cos(theta)**15 - 3.97174441874174e+23*cos(theta)**13 + 1.55520112782056e+22*cos(theta)**11 - 4.22400306321634e+20*cos(theta)**9 + 7.40331598226818e+18*cos(theta)**7 - 7.47809695178604e+16*cos(theta)**5 + 356099854846954.0*cos(theta)**3 - 504628986556.855*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl65_m_minus_5(theta, phi):
    return 3.80566556402649e-9*(1.0 - cos(theta)**2)**2.5*(2.5541025732037e+27*cos(theta)**60 - 3.50446632137253e+28*cos(theta)**58 + 2.28066253119243e+29*cos(theta)**56 - 9.3659207947636e+29*cos(theta)**54 + 2.72411232872088e+30*cos(theta)**52 - 5.97053379815518e+30*cos(theta)**50 + 1.02435628889917e+31*cos(theta)**48 - 1.4108350352604e+31*cos(theta)**46 + 1.58718941466795e+31*cos(theta)**44 - 1.47638268070391e+31*cos(theta)**42 + 1.14519413341087e+31*cos(theta)**40 - 7.44997017565038e+30*cos(theta)**38 + 4.07891669274316e+30*cos(theta)**36 - 1.88257693511223e+30*cos(theta)**34 + 7.32403370733675e+29*cos(theta)**32 - 2.39783545797956e+29*cos(theta)**30 + 6.58496479937568e+28*cos(theta)**28 - 1.50947040276774e+28*cos(theta)**26 + 2.8688764964884e+27*cos(theta)**24 - 4.48109741386982e+26*cos(theta)**22 + 5.68754671760401e+25*cos(theta)**20 - 5.78188269847385e+24*cos(theta)**18 + 4.62188115395245e+23*cos(theta)**16 - 2.83696029910125e+22*cos(theta)**14 + 1.29600093985047e+21*cos(theta)**12 - 4.22400306321634e+19*cos(theta)**10 + 9.25414497783522e+17*cos(theta)**8 - 1.24634949196434e+16*cos(theta)**6 + 89024963711738.5*cos(theta)**4 - 252314493278.428*cos(theta)**2 + 118457508.581421)*sin(5*phi)

#@torch.jit.script
def Yl65_m_minus_4(theta, phi):
    return 2.4868211826522e-7*(1.0 - cos(theta)**2)**2*(4.1870533986946e+25*cos(theta)**61 - 5.93977342605513e+26*cos(theta)**59 + 4.00116233542532e+27*cos(theta)**57 - 1.70289468995702e+28*cos(theta)**55 + 5.13983458249222e+28*cos(theta)**53 - 1.17069290159905e+29*cos(theta)**51 + 2.09052303856974e+29*cos(theta)**49 - 3.00177667076681e+29*cos(theta)**47 + 3.527087588151e+29*cos(theta)**45 - 3.43344809466026e+29*cos(theta)**43 + 2.79315642295335e+29*cos(theta)**41 - 1.91024876298728e+29*cos(theta)**39 + 1.10240991695761e+29*cos(theta)**37 - 5.37879124317779e+28*cos(theta)**35 + 2.21940415373841e+28*cos(theta)**33 - 7.73495309025664e+27*cos(theta)**31 + 2.2706775170261e+27*cos(theta)**29 - 5.59063112136201e+26*cos(theta)**27 + 1.14755059859536e+26*cos(theta)**25 - 1.94830322342166e+25*cos(theta)**23 + 2.70835557981143e+24*cos(theta)**21 - 3.0430961570915e+23*cos(theta)**19 + 2.71875361997203e+22*cos(theta)**17 - 1.8913068660675e+21*cos(theta)**15 + 9.96923799884976e+19*cos(theta)**13 - 3.84000278474213e+18*cos(theta)**11 + 1.02823833087058e+17*cos(theta)**9 - 1.78049927423477e+15*cos(theta)**7 + 17804992742347.7*cos(theta)**5 - 84104831092.8092*cos(theta)**3 + 118457508.581421*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl65_m_minus_3(theta, phi):
    return 1.6265407497268e-5*(1.0 - cos(theta)**2)**1.5*(6.75331193337838e+23*cos(theta)**62 - 9.89962237675855e+24*cos(theta)**60 + 6.89855575073332e+25*cos(theta)**58 - 3.04088337492325e+26*cos(theta)**56 + 9.51821218980041e+26*cos(theta)**54 - 2.2513325030751e+27*cos(theta)**52 + 4.18104607713948e+27*cos(theta)**50 - 6.25370139743085e+27*cos(theta)**48 + 7.66758171337173e+27*cos(theta)**46 - 7.80329112422787e+27*cos(theta)**44 + 6.65037243560321e+27*cos(theta)**42 - 4.77562190746819e+27*cos(theta)**40 + 2.90107872883582e+27*cos(theta)**38 - 1.4941086786605e+27*cos(theta)**36 + 6.52765927570121e+26*cos(theta)**34 - 2.4171728407052e+26*cos(theta)**32 + 7.56892505675365e+25*cos(theta)**30 - 1.996653971915e+25*cos(theta)**28 + 4.41365614844369e+24*cos(theta)**26 - 8.11793009759026e+23*cos(theta)**24 + 1.23107071809611e+23*cos(theta)**22 - 1.52154807854575e+22*cos(theta)**20 + 1.51041867776224e+21*cos(theta)**18 - 1.18206679129219e+20*cos(theta)**16 + 7.12088428489269e+18*cos(theta)**14 - 3.20000232061844e+17*cos(theta)**12 + 1.02823833087058e+16*cos(theta)**10 - 222562409279346.0*cos(theta)**8 + 2967498790391.28*cos(theta)**6 - 21026207773.2023*cos(theta)**4 + 59228754.2907107*cos(theta)**2 - 27689.9272046333)*sin(3*phi)

#@torch.jit.script
def Yl65_m_minus_2(theta, phi):
    return 0.00106460788688961*(1.0 - cos(theta)**2)*(1.07195427513943e+22*cos(theta)**63 - 1.62288891422271e+23*cos(theta)**61 + 1.16924673741243e+24*cos(theta)**59 - 5.33488311390043e+24*cos(theta)**57 + 1.73058403450916e+25*cos(theta)**55 - 4.2477971756134e+25*cos(theta)**53 + 8.19812956301859e+25*cos(theta)**51 - 1.27626559131242e+26*cos(theta)**49 + 1.63140036454718e+26*cos(theta)**47 - 1.73406469427286e+26*cos(theta)**45 + 1.54659824083796e+26*cos(theta)**43 - 1.1647858310898e+26*cos(theta)**41 + 7.43866340727133e+25*cos(theta)**39 - 4.03813156394729e+25*cos(theta)**37 + 1.8650455073432e+25*cos(theta)**35 - 7.32476618395515e+24*cos(theta)**33 + 2.44158872798505e+24*cos(theta)**31 - 6.88501369625863e+23*cos(theta)**29 + 1.63468746238655e+23*cos(theta)**27 - 3.24717203903611e+22*cos(theta)**25 + 5.35248138302655e+21*cos(theta)**23 - 7.24546704069404e+20*cos(theta)**21 + 7.9495719882223e+19*cos(theta)**19 - 6.95333406642462e+18*cos(theta)**17 + 4.74725618992846e+17*cos(theta)**15 - 2.46154024662957e+16*cos(theta)**13 + 934762118973255.0*cos(theta)**11 - 24729156586594.0*cos(theta)**9 + 423928398627.326*cos(theta)**7 - 4205241554.64046*cos(theta)**5 + 19742918.0969036*cos(theta)**3 - 27689.9272046333*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl65_m_minus_1(theta, phi):
    return 0.0697135289432729*(1.0 - cos(theta)**2)**0.5*(1.67492855490535e+20*cos(theta)**64 - 2.61756276487534e+21*cos(theta)**62 + 1.94874456235404e+22*cos(theta)**60 - 9.19807433431109e+22*cos(theta)**58 + 3.09032863305208e+23*cos(theta)**56 - 7.86629106595075e+23*cos(theta)**54 + 1.57656337750357e+24*cos(theta)**52 - 2.55253118262483e+24*cos(theta)**50 + 3.39875075947329e+24*cos(theta)**48 - 3.76970585711491e+24*cos(theta)**46 + 3.51499600190444e+24*cos(theta)**44 - 2.77329959783287e+24*cos(theta)**42 + 1.85966585181783e+24*cos(theta)**40 - 1.06266620103876e+24*cos(theta)**38 + 5.18068196484223e+23*cos(theta)**36 - 2.15434299528093e+23*cos(theta)**34 + 7.62996477495328e+22*cos(theta)**32 - 2.29500456541954e+22*cos(theta)**30 + 5.8381695085234e+21*cos(theta)**28 - 1.24891232270619e+21*cos(theta)**26 + 2.23020057626106e+20*cos(theta)**24 - 3.29339410940638e+19*cos(theta)**22 + 3.97478599411115e+18*cos(theta)**20 - 3.8629633702359e+17*cos(theta)**18 + 2.96703511870529e+16*cos(theta)**16 - 1.75824303330684e+15*cos(theta)**14 + 77896843247771.2*cos(theta)**12 - 2472915658659.4*cos(theta)**10 + 52991049828.4158*cos(theta)**8 - 700873592.440077*cos(theta)**6 + 4935729.52422589*cos(theta)**4 - 13844.9636023167*cos(theta)**2 + 6.45753899361785)*sin(phi)

#@torch.jit.script
def Yl65_m0(theta, phi):
    return 2.61374682660235e+19*cos(theta)**65 - 4.21441348785495e+20*cos(theta)**63 + 3.24045257550422e+21*cos(theta)**61 - 1.58134085684606e+22*cos(theta)**59 + 5.49933781720246e+22*cos(theta)**57 - 1.45073440599258e+23*cos(theta)**55 + 3.017283743556e+23*cos(theta)**53 - 5.07669963201486e+23*cos(theta)**51 + 7.03564351175972e+23*cos(theta)**49 - 8.13561137643012e+23*cos(theta)**47 + 7.92305936749636e+23*cos(theta)**45 - 6.54197562453828e+23*cos(theta)**43 + 4.60078192286454e+23*cos(theta)**41 - 2.76383968992595e+23*cos(theta)**39 + 1.42025326645987e+23*cos(theta)**37 - 6.24348960701169e+22*cos(theta)**35 + 2.34525019960351e+22*cos(theta)**33 - 7.50935176101063e+21*cos(theta)**31 + 2.04201670694149e+21*cos(theta)**29 - 4.69190030004665e+20*cos(theta)**27 + 9.04866486437569e+19*cos(theta)**25 - 1.45243416763655e+19*cos(theta)**23 + 1.91988424457704e+18*cos(theta)**21 - 2.06227975120808e+17*cos(theta)**19 + 1.77033050932019e+16*cos(theta)**17 - 1.18896271243232e+15*cos(theta)**15 + 60779496010415.8*cos(theta)**13 - 2280327411646.19*cos(theta)**11 + 59722860781.2097*cos(theta)**9 - 1015598955.18354*cos(theta)**7 + 10012947.4454715*cos(theta)**5 - 46811.3485061782*cos(theta)**3 + 65.5009540664806*cos(theta)

#@torch.jit.script
def Yl65_m1(theta, phi):
    return 0.0697135289432729*(1.0 - cos(theta)**2)**0.5*(1.67492855490535e+20*cos(theta)**64 - 2.61756276487534e+21*cos(theta)**62 + 1.94874456235404e+22*cos(theta)**60 - 9.19807433431109e+22*cos(theta)**58 + 3.09032863305208e+23*cos(theta)**56 - 7.86629106595075e+23*cos(theta)**54 + 1.57656337750357e+24*cos(theta)**52 - 2.55253118262483e+24*cos(theta)**50 + 3.39875075947329e+24*cos(theta)**48 - 3.76970585711491e+24*cos(theta)**46 + 3.51499600190444e+24*cos(theta)**44 - 2.77329959783287e+24*cos(theta)**42 + 1.85966585181783e+24*cos(theta)**40 - 1.06266620103876e+24*cos(theta)**38 + 5.18068196484223e+23*cos(theta)**36 - 2.15434299528093e+23*cos(theta)**34 + 7.62996477495328e+22*cos(theta)**32 - 2.29500456541954e+22*cos(theta)**30 + 5.8381695085234e+21*cos(theta)**28 - 1.24891232270619e+21*cos(theta)**26 + 2.23020057626106e+20*cos(theta)**24 - 3.29339410940638e+19*cos(theta)**22 + 3.97478599411115e+18*cos(theta)**20 - 3.8629633702359e+17*cos(theta)**18 + 2.96703511870529e+16*cos(theta)**16 - 1.75824303330684e+15*cos(theta)**14 + 77896843247771.2*cos(theta)**12 - 2472915658659.4*cos(theta)**10 + 52991049828.4158*cos(theta)**8 - 700873592.440077*cos(theta)**6 + 4935729.52422589*cos(theta)**4 - 13844.9636023167*cos(theta)**2 + 6.45753899361785)*cos(phi)

#@torch.jit.script
def Yl65_m2(theta, phi):
    return 0.00106460788688961*(1.0 - cos(theta)**2)*(1.07195427513943e+22*cos(theta)**63 - 1.62288891422271e+23*cos(theta)**61 + 1.16924673741243e+24*cos(theta)**59 - 5.33488311390043e+24*cos(theta)**57 + 1.73058403450916e+25*cos(theta)**55 - 4.2477971756134e+25*cos(theta)**53 + 8.19812956301859e+25*cos(theta)**51 - 1.27626559131242e+26*cos(theta)**49 + 1.63140036454718e+26*cos(theta)**47 - 1.73406469427286e+26*cos(theta)**45 + 1.54659824083796e+26*cos(theta)**43 - 1.1647858310898e+26*cos(theta)**41 + 7.43866340727133e+25*cos(theta)**39 - 4.03813156394729e+25*cos(theta)**37 + 1.8650455073432e+25*cos(theta)**35 - 7.32476618395515e+24*cos(theta)**33 + 2.44158872798505e+24*cos(theta)**31 - 6.88501369625863e+23*cos(theta)**29 + 1.63468746238655e+23*cos(theta)**27 - 3.24717203903611e+22*cos(theta)**25 + 5.35248138302655e+21*cos(theta)**23 - 7.24546704069404e+20*cos(theta)**21 + 7.9495719882223e+19*cos(theta)**19 - 6.95333406642462e+18*cos(theta)**17 + 4.74725618992846e+17*cos(theta)**15 - 2.46154024662957e+16*cos(theta)**13 + 934762118973255.0*cos(theta)**11 - 24729156586594.0*cos(theta)**9 + 423928398627.326*cos(theta)**7 - 4205241554.64046*cos(theta)**5 + 19742918.0969036*cos(theta)**3 - 27689.9272046333*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl65_m3(theta, phi):
    return 1.6265407497268e-5*(1.0 - cos(theta)**2)**1.5*(6.75331193337838e+23*cos(theta)**62 - 9.89962237675855e+24*cos(theta)**60 + 6.89855575073332e+25*cos(theta)**58 - 3.04088337492325e+26*cos(theta)**56 + 9.51821218980041e+26*cos(theta)**54 - 2.2513325030751e+27*cos(theta)**52 + 4.18104607713948e+27*cos(theta)**50 - 6.25370139743085e+27*cos(theta)**48 + 7.66758171337173e+27*cos(theta)**46 - 7.80329112422787e+27*cos(theta)**44 + 6.65037243560321e+27*cos(theta)**42 - 4.77562190746819e+27*cos(theta)**40 + 2.90107872883582e+27*cos(theta)**38 - 1.4941086786605e+27*cos(theta)**36 + 6.52765927570121e+26*cos(theta)**34 - 2.4171728407052e+26*cos(theta)**32 + 7.56892505675365e+25*cos(theta)**30 - 1.996653971915e+25*cos(theta)**28 + 4.41365614844369e+24*cos(theta)**26 - 8.11793009759026e+23*cos(theta)**24 + 1.23107071809611e+23*cos(theta)**22 - 1.52154807854575e+22*cos(theta)**20 + 1.51041867776224e+21*cos(theta)**18 - 1.18206679129219e+20*cos(theta)**16 + 7.12088428489269e+18*cos(theta)**14 - 3.20000232061844e+17*cos(theta)**12 + 1.02823833087058e+16*cos(theta)**10 - 222562409279346.0*cos(theta)**8 + 2967498790391.28*cos(theta)**6 - 21026207773.2023*cos(theta)**4 + 59228754.2907107*cos(theta)**2 - 27689.9272046333)*cos(3*phi)

#@torch.jit.script
def Yl65_m4(theta, phi):
    return 2.4868211826522e-7*(1.0 - cos(theta)**2)**2*(4.1870533986946e+25*cos(theta)**61 - 5.93977342605513e+26*cos(theta)**59 + 4.00116233542532e+27*cos(theta)**57 - 1.70289468995702e+28*cos(theta)**55 + 5.13983458249222e+28*cos(theta)**53 - 1.17069290159905e+29*cos(theta)**51 + 2.09052303856974e+29*cos(theta)**49 - 3.00177667076681e+29*cos(theta)**47 + 3.527087588151e+29*cos(theta)**45 - 3.43344809466026e+29*cos(theta)**43 + 2.79315642295335e+29*cos(theta)**41 - 1.91024876298728e+29*cos(theta)**39 + 1.10240991695761e+29*cos(theta)**37 - 5.37879124317779e+28*cos(theta)**35 + 2.21940415373841e+28*cos(theta)**33 - 7.73495309025664e+27*cos(theta)**31 + 2.2706775170261e+27*cos(theta)**29 - 5.59063112136201e+26*cos(theta)**27 + 1.14755059859536e+26*cos(theta)**25 - 1.94830322342166e+25*cos(theta)**23 + 2.70835557981143e+24*cos(theta)**21 - 3.0430961570915e+23*cos(theta)**19 + 2.71875361997203e+22*cos(theta)**17 - 1.8913068660675e+21*cos(theta)**15 + 9.96923799884976e+19*cos(theta)**13 - 3.84000278474213e+18*cos(theta)**11 + 1.02823833087058e+17*cos(theta)**9 - 1.78049927423477e+15*cos(theta)**7 + 17804992742347.7*cos(theta)**5 - 84104831092.8092*cos(theta)**3 + 118457508.581421*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl65_m5(theta, phi):
    return 3.80566556402649e-9*(1.0 - cos(theta)**2)**2.5*(2.5541025732037e+27*cos(theta)**60 - 3.50446632137253e+28*cos(theta)**58 + 2.28066253119243e+29*cos(theta)**56 - 9.3659207947636e+29*cos(theta)**54 + 2.72411232872088e+30*cos(theta)**52 - 5.97053379815518e+30*cos(theta)**50 + 1.02435628889917e+31*cos(theta)**48 - 1.4108350352604e+31*cos(theta)**46 + 1.58718941466795e+31*cos(theta)**44 - 1.47638268070391e+31*cos(theta)**42 + 1.14519413341087e+31*cos(theta)**40 - 7.44997017565038e+30*cos(theta)**38 + 4.07891669274316e+30*cos(theta)**36 - 1.88257693511223e+30*cos(theta)**34 + 7.32403370733675e+29*cos(theta)**32 - 2.39783545797956e+29*cos(theta)**30 + 6.58496479937568e+28*cos(theta)**28 - 1.50947040276774e+28*cos(theta)**26 + 2.8688764964884e+27*cos(theta)**24 - 4.48109741386982e+26*cos(theta)**22 + 5.68754671760401e+25*cos(theta)**20 - 5.78188269847385e+24*cos(theta)**18 + 4.62188115395245e+23*cos(theta)**16 - 2.83696029910125e+22*cos(theta)**14 + 1.29600093985047e+21*cos(theta)**12 - 4.22400306321634e+19*cos(theta)**10 + 9.25414497783522e+17*cos(theta)**8 - 1.24634949196434e+16*cos(theta)**6 + 89024963711738.5*cos(theta)**4 - 252314493278.428*cos(theta)**2 + 118457508.581421)*cos(5*phi)

#@torch.jit.script
def Yl65_m6(theta, phi):
    return 5.8307687961392e-11*(1.0 - cos(theta)**2)**3*(1.53246154392222e+29*cos(theta)**59 - 2.03259046639606e+30*cos(theta)**57 + 1.27717101746776e+31*cos(theta)**55 - 5.05759722917234e+31*cos(theta)**53 + 1.41653841093486e+32*cos(theta)**51 - 2.98526689907759e+32*cos(theta)**49 + 4.91691018671603e+32*cos(theta)**47 - 6.48984116219783e+32*cos(theta)**45 + 6.98363342453897e+32*cos(theta)**43 - 6.20080725895643e+32*cos(theta)**41 + 4.58077653364349e+32*cos(theta)**39 - 2.83098866674715e+32*cos(theta)**37 + 1.46841000938754e+32*cos(theta)**35 - 6.40076157938158e+31*cos(theta)**33 + 2.34369078634776e+31*cos(theta)**31 - 7.19350637393867e+30*cos(theta)**29 + 1.84379014382519e+30*cos(theta)**27 - 3.92462304719613e+29*cos(theta)**25 + 6.88530359157216e+28*cos(theta)**23 - 9.85841431051361e+27*cos(theta)**21 + 1.1375093435208e+27*cos(theta)**19 - 1.04073888572529e+26*cos(theta)**17 + 7.39500984632391e+24*cos(theta)**15 - 3.97174441874174e+23*cos(theta)**13 + 1.55520112782056e+22*cos(theta)**11 - 4.22400306321634e+20*cos(theta)**9 + 7.40331598226818e+18*cos(theta)**7 - 7.47809695178604e+16*cos(theta)**5 + 356099854846954.0*cos(theta)**3 - 504628986556.855*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl65_m7(theta, phi):
    return 8.94609626093219e-13*(1.0 - cos(theta)**2)**3.5*(9.04152310914111e+30*cos(theta)**58 - 1.15857656584576e+32*cos(theta)**56 + 7.0244405960727e+32*cos(theta)**54 - 2.68052653146134e+33*cos(theta)**52 + 7.22434589576776e+33*cos(theta)**50 - 1.46278078054802e+34*cos(theta)**48 + 2.31094778775653e+34*cos(theta)**46 - 2.92042852298903e+34*cos(theta)**44 + 3.00296237255176e+34*cos(theta)**42 - 2.54233097617214e+34*cos(theta)**40 + 1.78650284812096e+34*cos(theta)**38 - 1.04746580669644e+34*cos(theta)**36 + 5.13943503285638e+33*cos(theta)**34 - 2.11225132119592e+33*cos(theta)**32 + 7.26544143767806e+32*cos(theta)**30 - 2.08611684844222e+32*cos(theta)**28 + 4.97823338832801e+31*cos(theta)**26 - 9.81155761799032e+30*cos(theta)**24 + 1.5836198260616e+30*cos(theta)**22 - 2.07026700520786e+29*cos(theta)**20 + 2.16126775268952e+28*cos(theta)**18 - 1.769256105733e+27*cos(theta)**16 + 1.10925147694859e+26*cos(theta)**14 - 5.16326774436427e+24*cos(theta)**12 + 1.71072124060262e+23*cos(theta)**10 - 3.80160275689471e+21*cos(theta)**8 + 5.18232118758772e+19*cos(theta)**6 - 3.73904847589302e+17*cos(theta)**4 + 1.06829956454086e+15*cos(theta)**2 - 504628986556.855)*cos(7*phi)

#@torch.jit.script
def Yl65_m8(theta, phi):
    return 1.37485893388855e-14*(1.0 - cos(theta)**2)**4*(5.24408340330185e+32*cos(theta)**57 - 6.48802876873624e+33*cos(theta)**55 + 3.79319792187926e+34*cos(theta)**53 - 1.3938737963599e+35*cos(theta)**51 + 3.61217294788388e+35*cos(theta)**49 - 7.02134774663049e+35*cos(theta)**47 + 1.06303598236801e+36*cos(theta)**45 - 1.28498855011517e+36*cos(theta)**43 + 1.26124419647174e+36*cos(theta)**41 - 1.01693239046886e+36*cos(theta)**39 + 6.78871082285965e+35*cos(theta)**37 - 3.7708769041072e+35*cos(theta)**35 + 1.74740791117117e+35*cos(theta)**33 - 6.75920422782694e+34*cos(theta)**31 + 2.17963243130342e+34*cos(theta)**29 - 5.8411271756382e+33*cos(theta)**27 + 1.29434068096528e+33*cos(theta)**25 - 2.35477382831768e+32*cos(theta)**23 + 3.48396361733551e+31*cos(theta)**21 - 4.14053401041572e+30*cos(theta)**19 + 3.89028195484114e+29*cos(theta)**17 - 2.83080976917279e+28*cos(theta)**15 + 1.55295206772802e+27*cos(theta)**13 - 6.19592129323712e+25*cos(theta)**11 + 1.71072124060262e+24*cos(theta)**9 - 3.04128220551577e+22*cos(theta)**7 + 3.10939271255263e+20*cos(theta)**5 - 1.49561939035721e+18*cos(theta)**3 + 2.13659912908172e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl65_m9(theta, phi):
    return 2.11692198074881e-16*(1.0 - cos(theta)**2)**4.5*(2.98912753988205e+34*cos(theta)**56 - 3.56841582280493e+35*cos(theta)**54 + 2.01039489859601e+36*cos(theta)**52 - 7.10875636143548e+36*cos(theta)**50 + 1.7699647444631e+37*cos(theta)**48 - 3.30003344091633e+37*cos(theta)**46 + 4.78366192065602e+37*cos(theta)**44 - 5.52545076549524e+37*cos(theta)**42 + 5.17110120553413e+37*cos(theta)**40 - 3.96603632282853e+37*cos(theta)**38 + 2.51182300445807e+37*cos(theta)**36 - 1.31980691643752e+37*cos(theta)**34 + 5.76644610686486e+36*cos(theta)**32 - 2.09535331062635e+36*cos(theta)**30 + 6.32093405077991e+35*cos(theta)**28 - 1.57710433742231e+35*cos(theta)**26 + 3.23585170241321e+34*cos(theta)**24 - 5.41597980513066e+33*cos(theta)**22 + 7.31632359640457e+32*cos(theta)**20 - 7.86701461978987e+31*cos(theta)**18 + 6.61347932322994e+30*cos(theta)**16 - 4.24621465375919e+29*cos(theta)**14 + 2.01883768804643e+28*cos(theta)**12 - 6.81551342256083e+26*cos(theta)**10 + 1.53964911654236e+25*cos(theta)**8 - 2.12889754386104e+23*cos(theta)**6 + 1.55469635627632e+21*cos(theta)**4 - 4.48685817107162e+18*cos(theta)**2 + 2.13659912908172e+15)*cos(9*phi)

#@torch.jit.script
def Yl65_m10(theta, phi):
    return 3.26648153237928e-18*(1.0 - cos(theta)**2)**5*(1.67391142233395e+36*cos(theta)**55 - 1.92694454431466e+37*cos(theta)**53 + 1.04540534726992e+38*cos(theta)**51 - 3.55437818071774e+38*cos(theta)**49 + 8.49583077342289e+38*cos(theta)**47 - 1.51801538282151e+39*cos(theta)**45 + 2.10481124508865e+39*cos(theta)**43 - 2.320689321508e+39*cos(theta)**41 + 2.06844048221365e+39*cos(theta)**39 - 1.50709380267484e+39*cos(theta)**37 + 9.04256281604906e+38*cos(theta)**35 - 4.48734351588756e+38*cos(theta)**33 + 1.84526275419676e+38*cos(theta)**31 - 6.28605993187906e+37*cos(theta)**29 + 1.76986153421838e+37*cos(theta)**27 - 4.10047127729802e+36*cos(theta)**25 + 7.7660440857917e+35*cos(theta)**23 - 1.19151555712874e+35*cos(theta)**21 + 1.46326471928091e+34*cos(theta)**19 - 1.41606263156218e+33*cos(theta)**17 + 1.05815669171679e+32*cos(theta)**15 - 5.94470051526287e+30*cos(theta)**13 + 2.42260522565571e+29*cos(theta)**11 - 6.81551342256083e+27*cos(theta)**9 + 1.23171929323389e+26*cos(theta)**7 - 1.27733852631662e+24*cos(theta)**5 + 6.21878542510527e+21*cos(theta)**3 - 8.97371634214324e+18*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl65_m11(theta, phi):
    return 5.05233415225719e-20*(1.0 - cos(theta)**2)**5.5*(9.20651282283672e+37*cos(theta)**54 - 1.02128060848677e+39*cos(theta)**52 + 5.33156727107661e+39*cos(theta)**50 - 1.74164530855169e+40*cos(theta)**48 + 3.99304046350876e+40*cos(theta)**46 - 6.8310692226968e+40*cos(theta)**44 + 9.0506883538812e+40*cos(theta)**42 - 9.5148262181828e+40*cos(theta)**40 + 8.06691788063324e+40*cos(theta)**38 - 5.57624706989692e+40*cos(theta)**36 + 3.16489698561717e+40*cos(theta)**34 - 1.4808233602429e+40*cos(theta)**32 + 5.72031453800994e+39*cos(theta)**30 - 1.82295738024493e+39*cos(theta)**28 + 4.77862614238961e+38*cos(theta)**26 - 1.0251178193245e+38*cos(theta)**24 + 1.78619013973209e+37*cos(theta)**22 - 2.50218266997036e+36*cos(theta)**20 + 2.78020296663374e+35*cos(theta)**18 - 2.4073064736557e+34*cos(theta)**16 + 1.58723503757519e+33*cos(theta)**14 - 7.72811066984173e+31*cos(theta)**12 + 2.66486574822129e+30*cos(theta)**10 - 6.13396208030475e+28*cos(theta)**8 + 8.6220350526372e+26*cos(theta)**6 - 6.38669263158311e+24*cos(theta)**4 + 1.86563562753158e+22*cos(theta)**2 - 8.97371634214324e+18)*cos(11*phi)

#@torch.jit.script
def Yl65_m12(theta, phi):
    return 7.83519525722043e-22*(1.0 - cos(theta)**2)**6*(4.97151692433183e+39*cos(theta)**53 - 5.31065916413121e+40*cos(theta)**51 + 2.6657836355383e+41*cos(theta)**49 - 8.35989748104812e+41*cos(theta)**47 + 1.83679861321403e+42*cos(theta)**45 - 3.00567045798659e+42*cos(theta)**43 + 3.8012891086301e+42*cos(theta)**41 - 3.80593048727312e+42*cos(theta)**39 + 3.06542879464063e+42*cos(theta)**37 - 2.00744894516289e+42*cos(theta)**35 + 1.07606497510984e+42*cos(theta)**33 - 4.73863475277727e+41*cos(theta)**31 + 1.71609436140298e+41*cos(theta)**29 - 5.1042806646858e+40*cos(theta)**27 + 1.2424427970213e+40*cos(theta)**25 - 2.46028276637881e+39*cos(theta)**23 + 3.9296183074106e+38*cos(theta)**21 - 5.00436533994073e+37*cos(theta)**19 + 5.00436533994073e+36*cos(theta)**17 - 3.85169035784912e+35*cos(theta)**15 + 2.22212905260526e+34*cos(theta)**13 - 9.27373280381008e+32*cos(theta)**11 + 2.66486574822129e+31*cos(theta)**9 - 4.9071696642438e+29*cos(theta)**7 + 5.17322103158232e+27*cos(theta)**5 - 2.55467705263324e+25*cos(theta)**3 + 3.73127125506316e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl65_m13(theta, phi):
    return 1.2186095790741e-23*(1.0 - cos(theta)**2)**6.5*(2.63490396989587e+41*cos(theta)**52 - 2.70843617370692e+42*cos(theta)**50 + 1.30623398141377e+43*cos(theta)**48 - 3.92915181609262e+43*cos(theta)**46 + 8.26559375946313e+43*cos(theta)**44 - 1.29243829693423e+44*cos(theta)**42 + 1.55852853453834e+44*cos(theta)**40 - 1.48431289003652e+44*cos(theta)**38 + 1.13420865401703e+44*cos(theta)**36 - 7.02607130807012e+43*cos(theta)**34 + 3.55101441786247e+43*cos(theta)**32 - 1.46897677336095e+43*cos(theta)**30 + 4.97667364806865e+42*cos(theta)**28 - 1.37815577946516e+42*cos(theta)**26 + 3.10610699255325e+41*cos(theta)**24 - 5.65865036267127e+40*cos(theta)**22 + 8.25219844556226e+39*cos(theta)**20 - 9.50829414588738e+38*cos(theta)**18 + 8.50742107789924e+37*cos(theta)**16 - 5.77753553677368e+36*cos(theta)**14 + 2.88876776838684e+35*cos(theta)**12 - 1.02011060841911e+34*cos(theta)**10 + 2.39837917339916e+32*cos(theta)**8 - 3.43501876497066e+30*cos(theta)**6 + 2.58661051579116e+28*cos(theta)**4 - 7.66403115789973e+25*cos(theta)**2 + 3.73127125506316e+22)*cos(13*phi)

#@torch.jit.script
def Yl65_m14(theta, phi):
    return 1.90129440496224e-25*(1.0 - cos(theta)**2)**7*(1.37015006434585e+43*cos(theta)**51 - 1.35421808685346e+44*cos(theta)**49 + 6.26992311078609e+44*cos(theta)**47 - 1.8074098354026e+45*cos(theta)**45 + 3.63686125416378e+45*cos(theta)**43 - 5.42824084712379e+45*cos(theta)**41 + 6.23411413815337e+45*cos(theta)**39 - 5.64038898213876e+45*cos(theta)**37 + 4.08315115446132e+45*cos(theta)**35 - 2.38886424474384e+45*cos(theta)**33 + 1.13632461371599e+45*cos(theta)**31 - 4.40693032008286e+44*cos(theta)**29 + 1.39346862145922e+44*cos(theta)**27 - 3.58320502660943e+43*cos(theta)**25 + 7.4546567821278e+42*cos(theta)**23 - 1.24490307978768e+42*cos(theta)**21 + 1.65043968911245e+41*cos(theta)**19 - 1.71149294625973e+40*cos(theta)**17 + 1.36118737246388e+39*cos(theta)**15 - 8.08854975148315e+37*cos(theta)**13 + 3.46652132206421e+36*cos(theta)**11 - 1.02011060841911e+35*cos(theta)**9 + 1.91870333871933e+33*cos(theta)**7 - 2.0610112589824e+31*cos(theta)**5 + 1.03464420631646e+29*cos(theta)**3 - 1.53280623157995e+26*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl65_m15(theta, phi):
    return 2.9765918522291e-27*(1.0 - cos(theta)**2)**7.5*(6.98776532816385e+44*cos(theta)**50 - 6.63566862558195e+45*cos(theta)**48 + 2.94686386206946e+46*cos(theta)**46 - 8.13334425931172e+46*cos(theta)**44 + 1.56385033929042e+47*cos(theta)**42 - 2.22557874732075e+47*cos(theta)**40 + 2.43130451387981e+47*cos(theta)**38 - 2.08694392339134e+47*cos(theta)**36 + 1.42910290406146e+47*cos(theta)**34 - 7.88325200765467e+46*cos(theta)**32 + 3.52260630251957e+46*cos(theta)**30 - 1.27800979282403e+46*cos(theta)**28 + 3.7623652779399e+45*cos(theta)**26 - 8.95801256652357e+44*cos(theta)**24 + 1.71457105988939e+44*cos(theta)**22 - 2.61429646755412e+43*cos(theta)**20 + 3.13583540931366e+42*cos(theta)**18 - 2.90953800864154e+41*cos(theta)**16 + 2.04178105869582e+40*cos(theta)**14 - 1.05151146769281e+39*cos(theta)**12 + 3.81317345427063e+37*cos(theta)**10 - 9.18099547577197e+35*cos(theta)**8 + 1.34309233710353e+34*cos(theta)**6 - 1.0305056294912e+32*cos(theta)**4 + 3.10393261894939e+29*cos(theta)**2 - 1.53280623157995e+26)*cos(15*phi)

#@torch.jit.script
def Yl65_m16(theta, phi):
    return 4.67726285230182e-29*(1.0 - cos(theta)**2)**8*(3.49388266408192e+46*cos(theta)**49 - 3.18512094027933e+47*cos(theta)**47 + 1.35555737655195e+48*cos(theta)**45 - 3.57867147409716e+48*cos(theta)**43 + 6.56817142501978e+48*cos(theta)**41 - 8.90231498928301e+48*cos(theta)**39 + 9.23895715274329e+48*cos(theta)**37 - 7.51299812420883e+48*cos(theta)**35 + 4.85894987380897e+48*cos(theta)**33 - 2.5226406424495e+48*cos(theta)**31 + 1.05678189075587e+48*cos(theta)**29 - 3.57842741990728e+47*cos(theta)**27 + 9.78214972264374e+46*cos(theta)**25 - 2.14992301596566e+46*cos(theta)**23 + 3.77205633175667e+45*cos(theta)**21 - 5.22859293510825e+44*cos(theta)**19 + 5.64450373676459e+43*cos(theta)**17 - 4.65526081382646e+42*cos(theta)**15 + 2.85849348217414e+41*cos(theta)**13 - 1.26181376123137e+40*cos(theta)**11 + 3.81317345427063e+38*cos(theta)**9 - 7.34479638061758e+36*cos(theta)**7 + 8.05855402262117e+34*cos(theta)**5 - 4.12202251796479e+32*cos(theta)**3 + 6.20786523789878e+29*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl65_m17(theta, phi):
    return 7.37881820904114e-31*(1.0 - cos(theta)**2)**8.5*(1.71200250540014e+48*cos(theta)**48 - 1.49700684193129e+49*cos(theta)**46 + 6.10000819448379e+49*cos(theta)**44 - 1.53882873386178e+50*cos(theta)**42 + 2.69295028425811e+50*cos(theta)**40 - 3.47190284582037e+50*cos(theta)**38 + 3.41841414651502e+50*cos(theta)**36 - 2.62954934347309e+50*cos(theta)**34 + 1.60345345835696e+50*cos(theta)**32 - 7.82018599159344e+49*cos(theta)**30 + 3.06466748319202e+49*cos(theta)**28 - 9.66175403374966e+48*cos(theta)**26 + 2.44553743066093e+48*cos(theta)**24 - 4.94482293672101e+47*cos(theta)**22 + 7.921318296689e+46*cos(theta)**20 - 9.93432657670567e+45*cos(theta)**18 + 9.5956563524998e+44*cos(theta)**16 - 6.98289122073969e+43*cos(theta)**14 + 3.71604152682639e+42*cos(theta)**12 - 1.38799513735451e+41*cos(theta)**10 + 3.43185610884356e+39*cos(theta)**8 - 5.14135746643231e+37*cos(theta)**6 + 4.02927701131058e+35*cos(theta)**4 - 1.23660675538944e+33*cos(theta)**2 + 6.20786523789878e+29)*cos(17*phi)

#@torch.jit.script
def Yl65_m18(theta, phi):
    return 1.16903400982024e-32*(1.0 - cos(theta)**2)**9*(8.21761202592068e+49*cos(theta)**47 - 6.88623147288392e+50*cos(theta)**45 + 2.68400360557287e+51*cos(theta)**43 - 6.46308068221946e+51*cos(theta)**41 + 1.07718011370324e+52*cos(theta)**39 - 1.31932308141174e+52*cos(theta)**37 + 1.23062909274541e+52*cos(theta)**35 - 8.94046776780851e+51*cos(theta)**33 + 5.13105106674227e+51*cos(theta)**31 - 2.34605579747803e+51*cos(theta)**29 + 8.58106895293766e+50*cos(theta)**27 - 2.51205604877491e+50*cos(theta)**25 + 5.86928983358624e+49*cos(theta)**23 - 1.08786104607862e+49*cos(theta)**21 + 1.5842636593378e+48*cos(theta)**19 - 1.78817878380702e+47*cos(theta)**17 + 1.53530501639997e+46*cos(theta)**15 - 9.77604770903557e+44*cos(theta)**13 + 4.45924983219166e+43*cos(theta)**11 - 1.38799513735451e+42*cos(theta)**9 + 2.74548488707485e+40*cos(theta)**7 - 3.08481447985938e+38*cos(theta)**5 + 1.61171080452423e+36*cos(theta)**3 - 2.47321351077888e+33*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl65_m19(theta, phi):
    return 1.86053812587183e-34*(1.0 - cos(theta)**2)**9.5*(3.86227765218272e+51*cos(theta)**46 - 3.09880416279776e+52*cos(theta)**44 + 1.15412155039633e+53*cos(theta)**42 - 2.64986307970998e+53*cos(theta)**40 + 4.20100244344265e+53*cos(theta)**38 - 4.88149540122344e+53*cos(theta)**36 + 4.30720182460892e+53*cos(theta)**34 - 2.95035436337681e+53*cos(theta)**32 + 1.5906258306901e+53*cos(theta)**30 - 6.80356181268629e+52*cos(theta)**28 + 2.31688861729317e+52*cos(theta)**26 - 6.28014012193728e+51*cos(theta)**24 + 1.34993666172484e+51*cos(theta)**22 - 2.28450819676511e+50*cos(theta)**20 + 3.01010095274182e+49*cos(theta)**18 - 3.03990393247194e+48*cos(theta)**16 + 2.30295752459995e+47*cos(theta)**14 - 1.27088620217462e+46*cos(theta)**12 + 4.90517481541083e+44*cos(theta)**10 - 1.24919562361906e+43*cos(theta)**8 + 1.9218394209524e+41*cos(theta)**6 - 1.54240723992969e+39*cos(theta)**4 + 4.8351324135727e+36*cos(theta)**2 - 2.47321351077888e+33)*cos(19*phi)

#@torch.jit.script
def Yl65_m20(theta, phi):
    return 2.97543313609508e-36*(1.0 - cos(theta)**2)**10*(1.77664772000405e+53*cos(theta)**45 - 1.36347383163102e+54*cos(theta)**43 + 4.8473105116646e+54*cos(theta)**41 - 1.05994523188399e+55*cos(theta)**39 + 1.59638092850821e+55*cos(theta)**37 - 1.75733834444044e+55*cos(theta)**35 + 1.46444862036703e+55*cos(theta)**33 - 9.44113396280578e+54*cos(theta)**31 + 4.77187749207031e+54*cos(theta)**29 - 1.90499730755216e+54*cos(theta)**27 + 6.02391040496224e+53*cos(theta)**25 - 1.50723362926495e+53*cos(theta)**23 + 2.96986065579464e+52*cos(theta)**21 - 4.56901639353021e+51*cos(theta)**19 + 5.41818171493527e+50*cos(theta)**17 - 4.8638462919551e+49*cos(theta)**15 + 3.22414053443993e+48*cos(theta)**13 - 1.52506344260955e+47*cos(theta)**11 + 4.90517481541083e+45*cos(theta)**9 - 9.99356498895246e+43*cos(theta)**7 + 1.15310365257144e+42*cos(theta)**5 - 6.16962895971877e+39*cos(theta)**3 + 9.6702648271454e+36*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl65_m21(theta, phi):
    return 4.78293757576616e-38*(1.0 - cos(theta)**2)**10.5*(7.99491474001823e+54*cos(theta)**44 - 5.86293747601337e+55*cos(theta)**42 + 1.98739730978249e+56*cos(theta)**40 - 4.13378640434757e+56*cos(theta)**38 + 5.90660943548037e+56*cos(theta)**36 - 6.15068420554154e+56*cos(theta)**34 + 4.83268044721121e+56*cos(theta)**32 - 2.92675152846979e+56*cos(theta)**30 + 1.38384447270039e+56*cos(theta)**28 - 5.14349273039083e+55*cos(theta)**26 + 1.50597760124056e+55*cos(theta)**24 - 3.46663734730938e+54*cos(theta)**22 + 6.23670737716874e+53*cos(theta)**20 - 8.68113114770741e+52*cos(theta)**18 + 9.21090891538997e+51*cos(theta)**16 - 7.29576943793265e+50*cos(theta)**14 + 4.19138269477191e+49*cos(theta)**12 - 1.6775697868705e+48*cos(theta)**10 + 4.41465733386975e+46*cos(theta)**8 - 6.99549549226672e+44*cos(theta)**6 + 5.76551826285719e+42*cos(theta)**4 - 1.85088868791563e+40*cos(theta)**2 + 9.6702648271454e+36)*cos(21*phi)

#@torch.jit.script
def Yl65_m22(theta, phi):
    return 7.73052071376472e-40*(1.0 - cos(theta)**2)**11*(3.51776248560802e+56*cos(theta)**43 - 2.46243373992562e+57*cos(theta)**41 + 7.94958923912994e+57*cos(theta)**39 - 1.57083883365208e+58*cos(theta)**37 + 2.12637939677293e+58*cos(theta)**35 - 2.09123262988412e+58*cos(theta)**33 + 1.54645774310759e+58*cos(theta)**31 - 8.78025458540938e+57*cos(theta)**29 + 3.8747645235611e+57*cos(theta)**27 - 1.33730810990162e+57*cos(theta)**25 + 3.61434624297734e+56*cos(theta)**23 - 7.62660216408063e+55*cos(theta)**21 + 1.24734147543375e+55*cos(theta)**19 - 1.56260360658733e+54*cos(theta)**17 + 1.47374542646239e+53*cos(theta)**15 - 1.02140772131057e+52*cos(theta)**13 + 5.02965923372629e+50*cos(theta)**11 - 1.6775697868705e+49*cos(theta)**9 + 3.5317258670958e+47*cos(theta)**7 - 4.19729729536003e+45*cos(theta)**5 + 2.30620730514287e+43*cos(theta)**3 - 3.70177737583126e+40*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl65_m23(theta, phi):
    return 1.25670454085725e-41*(1.0 - cos(theta)**2)**11.5*(1.51263786881145e+58*cos(theta)**42 - 1.0095978333695e+59*cos(theta)**40 + 3.10033980326068e+59*cos(theta)**38 - 5.81210368451268e+59*cos(theta)**36 + 7.44232788870526e+59*cos(theta)**34 - 6.90106767861761e+59*cos(theta)**32 + 4.79401900363352e+59*cos(theta)**30 - 2.54627382976872e+59*cos(theta)**28 + 1.0461864213615e+59*cos(theta)**26 - 3.34327027475404e+58*cos(theta)**24 + 8.31299635884789e+57*cos(theta)**22 - 1.60158645445693e+57*cos(theta)**20 + 2.36994880332412e+56*cos(theta)**18 - 2.65642613119847e+55*cos(theta)**16 + 2.21061813969359e+54*cos(theta)**14 - 1.32783003770374e+53*cos(theta)**12 + 5.53262515709892e+51*cos(theta)**10 - 1.50981280818345e+50*cos(theta)**8 + 2.47220810696706e+48*cos(theta)**6 - 2.09864864768002e+46*cos(theta)**4 + 6.91862191542862e+43*cos(theta)**2 - 3.70177737583126e+40)*cos(23*phi)

#@torch.jit.script
def Yl65_m24(theta, phi):
    return 2.05548132705004e-43*(1.0 - cos(theta)**2)**12*(6.35307904900809e+59*cos(theta)**41 - 4.03839133347801e+60*cos(theta)**39 + 1.17812912523906e+61*cos(theta)**37 - 2.09235732642457e+61*cos(theta)**35 + 2.53039148215979e+61*cos(theta)**33 - 2.20834165715763e+61*cos(theta)**31 + 1.43820570109006e+61*cos(theta)**29 - 7.12956672335242e+60*cos(theta)**27 + 2.72008469553989e+60*cos(theta)**25 - 8.0238486594097e+59*cos(theta)**23 + 1.82885919894654e+59*cos(theta)**21 - 3.20317290891387e+58*cos(theta)**19 + 4.26590784598342e+57*cos(theta)**17 - 4.25028180991755e+56*cos(theta)**15 + 3.09486539557103e+55*cos(theta)**13 - 1.59339604524449e+54*cos(theta)**11 + 5.53262515709892e+52*cos(theta)**9 - 1.20785024654676e+51*cos(theta)**7 + 1.48332486418024e+49*cos(theta)**5 - 8.39459459072006e+46*cos(theta)**3 + 1.38372438308572e+44*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl65_m25(theta, phi):
    return 3.38376623681316e-45*(1.0 - cos(theta)**2)**12.5*(2.60476241009332e+61*cos(theta)**40 - 1.57497262005642e+62*cos(theta)**38 + 4.35907776338451e+62*cos(theta)**36 - 7.32325064248598e+62*cos(theta)**34 + 8.35029189112731e+62*cos(theta)**32 - 6.84585913718867e+62*cos(theta)**30 + 4.17079653316116e+62*cos(theta)**28 - 1.92498301530515e+62*cos(theta)**26 + 6.80021173884972e+61*cos(theta)**24 - 1.84548519166423e+61*cos(theta)**22 + 3.84060431778773e+60*cos(theta)**20 - 6.08602852693634e+59*cos(theta)**18 + 7.25204333817181e+58*cos(theta)**16 - 6.37542271487632e+57*cos(theta)**14 + 4.02332501424234e+56*cos(theta)**12 - 1.75273564976894e+55*cos(theta)**10 + 4.97936264138903e+53*cos(theta)**8 - 8.45495172582734e+51*cos(theta)**6 + 7.41662432090118e+49*cos(theta)**4 - 2.51837837721602e+47*cos(theta)**2 + 1.38372438308572e+44)*cos(25*phi)

#@torch.jit.script
def Yl65_m26(theta, phi):
    return 5.60853792464566e-47*(1.0 - cos(theta)**2)**13*(1.04190496403733e+63*cos(theta)**39 - 5.98489595621441e+63*cos(theta)**37 + 1.56926799481842e+64*cos(theta)**35 - 2.48990521844523e+64*cos(theta)**33 + 2.67209340516074e+64*cos(theta)**31 - 2.0537577411566e+64*cos(theta)**29 + 1.16782302928513e+64*cos(theta)**27 - 5.0049558397934e+63*cos(theta)**25 + 1.63205081732393e+63*cos(theta)**23 - 4.06006742166131e+62*cos(theta)**21 + 7.68120863557545e+61*cos(theta)**19 - 1.09548513484854e+61*cos(theta)**17 + 1.16032693410749e+60*cos(theta)**15 - 8.92559180082685e+58*cos(theta)**13 + 4.8279900170908e+57*cos(theta)**11 - 1.75273564976894e+56*cos(theta)**9 + 3.98349011311122e+54*cos(theta)**7 - 5.07297103549641e+52*cos(theta)**5 + 2.96664972836047e+50*cos(theta)**3 - 5.03675675443204e+47*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl65_m27(theta, phi):
    return 9.3631815364416e-49*(1.0 - cos(theta)**2)**13.5*(4.06342935974557e+64*cos(theta)**38 - 2.21441150379933e+65*cos(theta)**36 + 5.49243798186449e+65*cos(theta)**34 - 8.21668722086927e+65*cos(theta)**32 + 8.28348955599829e+65*cos(theta)**30 - 5.95589744935414e+65*cos(theta)**28 + 3.15312217906984e+65*cos(theta)**26 - 1.25123895994835e+65*cos(theta)**24 + 3.75371687984505e+64*cos(theta)**22 - 8.52614158548875e+63*cos(theta)**20 + 1.45942964075934e+63*cos(theta)**18 - 1.86232472924252e+62*cos(theta)**16 + 1.74049040116124e+61*cos(theta)**14 - 1.16032693410749e+60*cos(theta)**12 + 5.31078901879989e+58*cos(theta)**10 - 1.57746208479205e+57*cos(theta)**8 + 2.78844307917786e+55*cos(theta)**6 - 2.5364855177482e+53*cos(theta)**4 + 8.89994918508141e+50*cos(theta)**2 - 5.03675675443204e+47)*cos(27*phi)

#@torch.jit.script
def Yl65_m28(theta, phi):
    return 1.57503486261719e-50*(1.0 - cos(theta)**2)**14*(1.54410315670332e+66*cos(theta)**37 - 7.9718814136776e+66*cos(theta)**35 + 1.86742891383393e+67*cos(theta)**33 - 2.62933991067817e+67*cos(theta)**31 + 2.48504686679949e+67*cos(theta)**29 - 1.66765128581916e+67*cos(theta)**27 + 8.19811766558158e+66*cos(theta)**25 - 3.00297350387604e+66*cos(theta)**23 + 8.2581771356591e+65*cos(theta)**21 - 1.70522831709775e+65*cos(theta)**19 + 2.6269733533668e+64*cos(theta)**17 - 2.97971956678803e+63*cos(theta)**15 + 2.43668656162573e+62*cos(theta)**13 - 1.39239232092899e+61*cos(theta)**11 + 5.31078901879989e+59*cos(theta)**9 - 1.26196966783364e+58*cos(theta)**7 + 1.67306584750671e+56*cos(theta)**5 - 1.01459420709928e+54*cos(theta)**3 + 1.77998983701628e+51*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl65_m29(theta, phi):
    return 2.67070169649057e-52*(1.0 - cos(theta)**2)**14.5*(5.71318167980228e+67*cos(theta)**36 - 2.79015849478716e+68*cos(theta)**34 + 6.16251541565195e+68*cos(theta)**32 - 8.15095372310231e+68*cos(theta)**30 + 7.20663591371851e+68*cos(theta)**28 - 4.50265847171173e+68*cos(theta)**26 + 2.0495294163954e+68*cos(theta)**24 - 6.90683905891489e+67*cos(theta)**22 + 1.73421719848841e+67*cos(theta)**20 - 3.23993380248572e+66*cos(theta)**18 + 4.46585470072357e+65*cos(theta)**16 - 4.46957935018205e+64*cos(theta)**14 + 3.16769253011345e+63*cos(theta)**12 - 1.53163155302189e+62*cos(theta)**10 + 4.7797101169199e+60*cos(theta)**8 - 8.83378767483545e+58*cos(theta)**6 + 8.36532923753357e+56*cos(theta)**4 - 3.04378262129784e+54*cos(theta)**2 + 1.77998983701628e+51)*cos(29*phi)

#@torch.jit.script
def Yl65_m30(theta, phi):
    return 4.5668035424607e-54*(1.0 - cos(theta)**2)**15*(2.05674540472882e+69*cos(theta)**35 - 9.48653888227634e+69*cos(theta)**33 + 1.97200493300862e+70*cos(theta)**31 - 2.44528611693069e+70*cos(theta)**29 + 2.01785805584118e+70*cos(theta)**27 - 1.17069120264505e+70*cos(theta)**25 + 4.91887059934895e+69*cos(theta)**23 - 1.51950459296127e+69*cos(theta)**21 + 3.46843439697682e+68*cos(theta)**19 - 5.8318808444743e+67*cos(theta)**17 + 7.14536752115771e+66*cos(theta)**15 - 6.25741109025487e+65*cos(theta)**13 + 3.80123103613614e+64*cos(theta)**11 - 1.53163155302189e+63*cos(theta)**9 + 3.82376809353592e+61*cos(theta)**7 - 5.30027260490127e+59*cos(theta)**5 + 3.34613169501343e+57*cos(theta)**3 - 6.08756524259569e+54*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl65_m31(theta, phi):
    return 7.87848460233697e-56*(1.0 - cos(theta)**2)**15.5*(7.19860891655087e+70*cos(theta)**34 - 3.13055783115119e+71*cos(theta)**32 + 6.11321529232674e+71*cos(theta)**30 - 7.09132973909901e+71*cos(theta)**28 + 5.44821675077119e+71*cos(theta)**26 - 2.92672800661262e+71*cos(theta)**24 + 1.13134023785026e+71*cos(theta)**22 - 3.19095964521868e+70*cos(theta)**20 + 6.59002535425596e+69*cos(theta)**18 - 9.91419743560632e+68*cos(theta)**16 + 1.07180512817366e+68*cos(theta)**14 - 8.13463441733133e+66*cos(theta)**12 + 4.18135413974975e+65*cos(theta)**10 - 1.3784683977197e+64*cos(theta)**8 + 2.67663766547514e+62*cos(theta)**6 - 2.65013630245064e+60*cos(theta)**4 + 1.00383950850403e+58*cos(theta)**2 - 6.08756524259569e+54)*cos(31*phi)

#@torch.jit.script
def Yl65_m32(theta, phi):
    return 1.37188391746445e-57*(1.0 - cos(theta)**2)**16*(2.4475270316273e+72*cos(theta)**33 - 1.00177850596838e+73*cos(theta)**31 + 1.83396458769802e+73*cos(theta)**29 - 1.98557232694772e+73*cos(theta)**27 + 1.41653635520051e+73*cos(theta)**25 - 7.0241472158703e+72*cos(theta)**23 + 2.48894852327057e+72*cos(theta)**21 - 6.38191929043735e+71*cos(theta)**19 + 1.18620456376607e+71*cos(theta)**17 - 1.58627158969701e+70*cos(theta)**15 + 1.50052717944312e+69*cos(theta)**13 - 9.7615613007976e+67*cos(theta)**11 + 4.18135413974975e+66*cos(theta)**9 - 1.10277471817576e+65*cos(theta)**7 + 1.60598259928509e+63*cos(theta)**5 - 1.06005452098025e+61*cos(theta)**3 + 2.00767901700806e+58*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl65_m33(theta, phi):
    return 2.41238909787524e-59*(1.0 - cos(theta)**2)**16.5*(8.07683920437007e+73*cos(theta)**32 - 3.10551336850198e+74*cos(theta)**30 + 5.31849730432426e+74*cos(theta)**28 - 5.36104528275885e+74*cos(theta)**26 + 3.54134088800128e+74*cos(theta)**24 - 1.61555385965017e+74*cos(theta)**22 + 5.22679189886819e+73*cos(theta)**20 - 1.2125646651831e+73*cos(theta)**18 + 2.01654775840232e+72*cos(theta)**16 - 2.37940738454552e+71*cos(theta)**14 + 1.95068533327605e+70*cos(theta)**12 - 1.07377174308774e+69*cos(theta)**10 + 3.76321872577478e+67*cos(theta)**8 - 7.71942302723031e+65*cos(theta)**6 + 8.02991299642543e+63*cos(theta)**4 - 3.18016356294076e+61*cos(theta)**2 + 2.00767901700806e+58)*cos(33*phi)

#@torch.jit.script
def Yl65_m34(theta, phi):
    return 4.28602569829554e-61*(1.0 - cos(theta)**2)**17*(2.58458854539842e+75*cos(theta)**31 - 9.31654010550595e+75*cos(theta)**29 + 1.48917924521079e+76*cos(theta)**27 - 1.3938717735173e+76*cos(theta)**25 + 8.49921813120306e+75*cos(theta)**23 - 3.55421849123037e+75*cos(theta)**21 + 1.04535837977364e+75*cos(theta)**19 - 2.18261639732958e+74*cos(theta)**17 + 3.22647641344372e+73*cos(theta)**15 - 3.33117033836372e+72*cos(theta)**13 + 2.34082239993126e+71*cos(theta)**11 - 1.07377174308774e+70*cos(theta)**9 + 3.01057498061982e+68*cos(theta)**7 - 4.63165381633819e+66*cos(theta)**5 + 3.21196519857017e+64*cos(theta)**3 - 6.36032712588153e+61*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl65_m35(theta, phi):
    return 7.6979294003689e-63*(1.0 - cos(theta)**2)**17.5*(8.01222449073511e+76*cos(theta)**30 - 2.70179663059672e+77*cos(theta)**28 + 4.02078396206914e+77*cos(theta)**26 - 3.48467943379326e+77*cos(theta)**24 + 1.9548201701767e+77*cos(theta)**22 - 7.46385883158378e+76*cos(theta)**20 + 1.98618092156991e+76*cos(theta)**18 - 3.71044787546028e+75*cos(theta)**16 + 4.83971462016558e+74*cos(theta)**14 - 4.33052143987284e+73*cos(theta)**12 + 2.57490463992439e+72*cos(theta)**10 - 9.66394568778962e+70*cos(theta)**8 + 2.10740248643387e+69*cos(theta)**6 - 2.31582690816909e+67*cos(theta)**4 + 9.63589559571051e+64*cos(theta)**2 - 6.36032712588153e+61)*cos(35*phi)

#@torch.jit.script
def Yl65_m36(theta, phi):
    return 1.39846824565112e-64*(1.0 - cos(theta)**2)**18*(2.40366734722053e+78*cos(theta)**29 - 7.56503056567083e+78*cos(theta)**27 + 1.04540383013798e+79*cos(theta)**25 - 8.36323064110381e+78*cos(theta)**23 + 4.30060437438875e+78*cos(theta)**21 - 1.49277176631676e+78*cos(theta)**19 + 3.57512565882584e+77*cos(theta)**17 - 5.93671660073644e+76*cos(theta)**15 + 6.77560046823181e+75*cos(theta)**13 - 5.19662572784741e+74*cos(theta)**11 + 2.57490463992439e+73*cos(theta)**9 - 7.7311565502317e+71*cos(theta)**7 + 1.26444149186032e+70*cos(theta)**5 - 9.26330763267637e+67*cos(theta)**3 + 1.9271791191421e+65*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl65_m37(theta, phi):
    return 2.5713045876105e-66*(1.0 - cos(theta)**2)**18.5*(6.97063530693955e+79*cos(theta)**28 - 2.04255825273112e+80*cos(theta)**26 + 2.61350957534494e+80*cos(theta)**24 - 1.92354304745388e+80*cos(theta)**22 + 9.03126918621637e+79*cos(theta)**20 - 2.83626635600184e+79*cos(theta)**18 + 6.07771362000394e+78*cos(theta)**16 - 8.90507490110467e+77*cos(theta)**14 + 8.80828060870136e+76*cos(theta)**12 - 5.71628830063215e+75*cos(theta)**10 + 2.31741417593195e+74*cos(theta)**8 - 5.41180958516219e+72*cos(theta)**6 + 6.32220745930162e+70*cos(theta)**4 - 2.77899228980291e+68*cos(theta)**2 + 1.9271791191421e+65)*cos(37*phi)

#@torch.jit.script
def Yl65_m38(theta, phi):
    return 4.7880193475768e-68*(1.0 - cos(theta)**2)**19*(1.95177788594307e+81*cos(theta)**27 - 5.31065145710092e+81*cos(theta)**25 + 6.27242298082786e+81*cos(theta)**23 - 4.23179470439853e+81*cos(theta)**21 + 1.80625383724327e+81*cos(theta)**19 - 5.10527944080331e+80*cos(theta)**17 + 9.7243417920063e+79*cos(theta)**15 - 1.24671048615465e+79*cos(theta)**13 + 1.05699367304416e+78*cos(theta)**11 - 5.71628830063215e+76*cos(theta)**9 + 1.85393134074556e+75*cos(theta)**7 - 3.24708575109731e+73*cos(theta)**5 + 2.52888298372065e+71*cos(theta)**3 - 5.55798457960582e+68*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl65_m39(theta, phi):
    return 9.03560724383533e-70*(1.0 - cos(theta)**2)**19.5*(5.2698002920463e+82*cos(theta)**26 - 1.32766286427523e+83*cos(theta)**24 + 1.44265728559041e+83*cos(theta)**22 - 8.88676887923691e+82*cos(theta)**20 + 3.43188229076222e+82*cos(theta)**18 - 8.67897504936562e+81*cos(theta)**16 + 1.45865126880094e+81*cos(theta)**14 - 1.62072363200105e+80*cos(theta)**12 + 1.16269304034858e+79*cos(theta)**10 - 5.14465947056893e+77*cos(theta)**8 + 1.29775193852189e+76*cos(theta)**6 - 1.62354287554866e+74*cos(theta)**4 + 7.58664895116195e+71*cos(theta)**2 - 5.55798457960582e+68)*cos(39*phi)

#@torch.jit.script
def Yl65_m40(theta, phi):
    return 1.7293226168064e-71*(1.0 - cos(theta)**2)**20*(1.37014807593204e+84*cos(theta)**25 - 3.18639087426055e+84*cos(theta)**23 + 3.1738460282989e+84*cos(theta)**21 - 1.77735377584738e+84*cos(theta)**19 + 6.177388123372e+83*cos(theta)**17 - 1.3886360078985e+83*cos(theta)**15 + 2.04211177632132e+82*cos(theta)**13 - 1.94486835840126e+81*cos(theta)**11 + 1.16269304034858e+80*cos(theta)**9 - 4.11572757645515e+78*cos(theta)**7 + 7.78651163113136e+76*cos(theta)**5 - 6.49417150219463e+74*cos(theta)**3 + 1.51732979023239e+72*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl65_m41(theta, phi):
    return 3.35933321831746e-73*(1.0 - cos(theta)**2)**20.5*(3.42537018983009e+85*cos(theta)**24 - 7.32869901079927e+85*cos(theta)**22 + 6.66507665942768e+85*cos(theta)**20 - 3.37697217411003e+85*cos(theta)**18 + 1.05015598097324e+85*cos(theta)**16 - 2.08295401184775e+84*cos(theta)**14 + 2.65474530921772e+83*cos(theta)**12 - 2.13935519424139e+82*cos(theta)**10 + 1.04642373631372e+81*cos(theta)**8 - 2.8810093035186e+79*cos(theta)**6 + 3.89325581556568e+77*cos(theta)**4 - 1.94825145065839e+75*cos(theta)**2 + 1.51732979023239e+72)*cos(41*phi)

#@torch.jit.script
def Yl65_m42(theta, phi):
    return 6.62911533020075e-75*(1.0 - cos(theta)**2)**21*(8.22088845559223e+86*cos(theta)**23 - 1.61231378237584e+87*cos(theta)**21 + 1.33301533188554e+87*cos(theta)**19 - 6.07854991339805e+86*cos(theta)**17 + 1.68024956955718e+86*cos(theta)**15 - 2.91613561658685e+85*cos(theta)**13 + 3.18569437106126e+84*cos(theta)**11 - 2.13935519424139e+83*cos(theta)**9 + 8.37138989050977e+81*cos(theta)**7 - 1.72860558211116e+80*cos(theta)**5 + 1.55730232622627e+78*cos(theta)**3 - 3.89650290131678e+75*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl65_m43(theta, phi):
    return 1.33008617371695e-76*(1.0 - cos(theta)**2)**21.5*(1.89080434478621e+88*cos(theta)**22 - 3.38585894298926e+88*cos(theta)**20 + 2.53272913058252e+88*cos(theta)**18 - 1.03335348527767e+88*cos(theta)**16 + 2.52037435433578e+87*cos(theta)**14 - 3.7909763015629e+86*cos(theta)**12 + 3.50426380816739e+85*cos(theta)**10 - 1.92541967481725e+84*cos(theta)**8 + 5.85997292335684e+82*cos(theta)**6 - 8.64302791055581e+80*cos(theta)**4 + 4.67190697867882e+78*cos(theta)**2 - 3.89650290131678e+75)*cos(43*phi)

#@torch.jit.script
def Yl65_m44(theta, phi):
    return 2.71615900174119e-78*(1.0 - cos(theta)**2)**22*(4.15976955852967e+89*cos(theta)**21 - 6.77171788597853e+89*cos(theta)**19 + 4.55891243504854e+89*cos(theta)**17 - 1.65336557644427e+89*cos(theta)**15 + 3.52852409607009e+88*cos(theta)**13 - 4.54917156187548e+87*cos(theta)**11 + 3.50426380816739e+86*cos(theta)**9 - 1.5403357398538e+85*cos(theta)**7 + 3.5159837540141e+83*cos(theta)**5 - 3.45721116422232e+81*cos(theta)**3 + 9.34381395735763e+78*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl65_m45(theta, phi):
    return 5.65131089368255e-80*(1.0 - cos(theta)**2)**22.5*(8.7355160729123e+90*cos(theta)**20 - 1.28662639833592e+91*cos(theta)**18 + 7.75015113958251e+90*cos(theta)**16 - 2.4800483646664e+90*cos(theta)**14 + 4.58708132489111e+89*cos(theta)**12 - 5.00408871806303e+88*cos(theta)**10 + 3.15383742735065e+87*cos(theta)**8 - 1.07823501789766e+86*cos(theta)**6 + 1.75799187700705e+84*cos(theta)**4 - 1.0371633492667e+82*cos(theta)**2 + 9.34381395735763e+78)*cos(45*phi)

#@torch.jit.script
def Yl65_m46(theta, phi):
    return 1.19942393862722e-81*(1.0 - cos(theta)**2)**23*(1.74710321458246e+92*cos(theta)**19 - 2.31592751700466e+92*cos(theta)**17 + 1.2400241823332e+92*cos(theta)**15 - 3.47206771053296e+91*cos(theta)**13 + 5.50449758986933e+90*cos(theta)**11 - 5.00408871806303e+89*cos(theta)**9 + 2.52306994188052e+88*cos(theta)**7 - 6.46941010738595e+86*cos(theta)**5 + 7.03196750802821e+84*cos(theta)**3 - 2.07432669853339e+82*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl65_m47(theta, phi):
    return 2.60008113717387e-83*(1.0 - cos(theta)**2)**23.5*(3.31949610770667e+93*cos(theta)**18 - 3.93707677890792e+93*cos(theta)**16 + 1.8600362734998e+93*cos(theta)**14 - 4.51368802369285e+92*cos(theta)**12 + 6.05494734885627e+91*cos(theta)**10 - 4.50367984625673e+90*cos(theta)**8 + 1.76614895931636e+89*cos(theta)**6 - 3.23470505369297e+87*cos(theta)**4 + 2.10959025240846e+85*cos(theta)**2 - 2.07432669853339e+82)*cos(47*phi)

#@torch.jit.script
def Yl65_m48(theta, phi):
    return 5.76516081754449e-85*(1.0 - cos(theta)**2)**24*(5.97509299387201e+94*cos(theta)**17 - 6.29932284625267e+94*cos(theta)**15 + 2.60405078289972e+94*cos(theta)**13 - 5.41642562843143e+93*cos(theta)**11 + 6.05494734885627e+92*cos(theta)**9 - 3.60294387700538e+91*cos(theta)**7 + 1.05968937558982e+90*cos(theta)**5 - 1.29388202147719e+88*cos(theta)**3 + 4.21918050481692e+85*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl65_m49(theta, phi):
    return 1.30958755692561e-86*(1.0 - cos(theta)**2)**24.5*(1.01576580895824e+96*cos(theta)**16 - 9.448984269379e+95*cos(theta)**14 + 3.38526601776964e+95*cos(theta)**12 - 5.95806819127457e+94*cos(theta)**10 + 5.44945261397064e+93*cos(theta)**8 - 2.52206071390377e+92*cos(theta)**6 + 5.29844687794909e+90*cos(theta)**4 - 3.88164606443157e+88*cos(theta)**2 + 4.21918050481692e+85)*cos(49*phi)

#@torch.jit.script
def Yl65_m50(theta, phi):
    return 3.05299173411205e-88*(1.0 - cos(theta)**2)**25*(1.62522529433319e+97*cos(theta)**15 - 1.32285779771306e+97*cos(theta)**13 + 4.06231922132357e+96*cos(theta)**11 - 5.95806819127457e+95*cos(theta)**9 + 4.35956209117651e+94*cos(theta)**7 - 1.51323642834226e+93*cos(theta)**5 + 2.11937875117964e+91*cos(theta)**3 - 7.76329212886314e+88*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl65_m51(theta, phi):
    return 7.31898748122476e-90*(1.0 - cos(theta)**2)**25.5*(2.43783794149978e+98*cos(theta)**14 - 1.71971513702698e+98*cos(theta)**12 + 4.46855114345593e+97*cos(theta)**10 - 5.36226137214711e+96*cos(theta)**8 + 3.05169346382356e+95*cos(theta)**6 - 7.5661821417113e+93*cos(theta)**4 + 6.35813625353891e+91*cos(theta)**2 - 7.76329212886314e+88)*cos(51*phi)

#@torch.jit.script
def Yl65_m52(theta, phi):
    return 1.80839815636967e-91*(1.0 - cos(theta)**2)**26*(3.41297311809969e+99*cos(theta)**13 - 2.06365816443237e+99*cos(theta)**11 + 4.46855114345593e+98*cos(theta)**9 - 4.28980909771769e+97*cos(theta)**7 + 1.83101607829414e+96*cos(theta)**5 - 3.02647285668452e+94*cos(theta)**3 + 1.27162725070778e+92*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl65_m53(theta, phi):
    return 4.6172285861995e-93*(1.0 - cos(theta)**2)**26.5*(4.4368650535296e+100*cos(theta)**12 - 2.27002398087561e+100*cos(theta)**10 + 4.02169602911033e+99*cos(theta)**8 - 3.00286636840238e+98*cos(theta)**6 + 9.15508039147068e+96*cos(theta)**4 - 9.07941857005356e+94*cos(theta)**2 + 1.27162725070778e+92)*cos(53*phi)

#@torch.jit.script
def Yl65_m54(theta, phi):
    return 1.2218482526346e-94*(1.0 - cos(theta)**2)**27*(5.32423806423552e+101*cos(theta)**11 - 2.27002398087561e+101*cos(theta)**9 + 3.21735682328827e+100*cos(theta)**7 - 1.80171982104143e+99*cos(theta)**5 + 3.66203215658827e+97*cos(theta)**3 - 1.81588371401071e+95*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl65_m55(theta, phi):
    return 3.36302663158415e-96*(1.0 - cos(theta)**2)**27.5*(5.85666187065908e+102*cos(theta)**10 - 2.04302158278805e+102*cos(theta)**8 + 2.25214977630179e+101*cos(theta)**6 - 9.00859910520715e+99*cos(theta)**4 + 1.09860964697648e+98*cos(theta)**2 - 1.81588371401071e+95)*cos(55*phi)

#@torch.jit.script
def Yl65_m56(theta, phi):
    return 9.66802180691806e-98*(1.0 - cos(theta)**2)**28*(5.85666187065908e+103*cos(theta)**9 - 1.63441726623044e+103*cos(theta)**7 + 1.35128986578107e+102*cos(theta)**5 - 3.60343964208286e+100*cos(theta)**3 + 2.19721929395296e+98*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl65_m57(theta, phi):
    return 2.91767189014888e-99*(1.0 - cos(theta)**2)**28.5*(5.27099568359317e+104*cos(theta)**8 - 1.14409208636131e+104*cos(theta)**6 + 6.75644932890536e+102*cos(theta)**4 - 1.08103189262486e+101*cos(theta)**2 + 2.19721929395296e+98)*cos(57*phi)

#@torch.jit.script
def Yl65_m58(theta, phi):
    return 9.30119826759211e-101*(1.0 - cos(theta)**2)**29*(4.21679654687453e+105*cos(theta)**7 - 6.86455251816785e+104*cos(theta)**5 + 2.70257973156214e+103*cos(theta)**3 - 2.16206378524972e+101*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl65_m59(theta, phi):
    return 3.15703240337733e-102*(1.0 - cos(theta)**2)**29.5*(2.95175758281217e+106*cos(theta)**6 - 3.43227625908392e+105*cos(theta)**4 + 8.10773919468643e+103*cos(theta)**2 - 2.16206378524972e+101)*cos(59*phi)

#@torch.jit.script
def Yl65_m60(theta, phi):
    return 1.15278524140301e-103*(1.0 - cos(theta)**2)**30*(1.7710545496873e+107*cos(theta)**5 - 1.37291050363357e+106*cos(theta)**3 + 1.62154783893729e+104*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl65_m61(theta, phi):
    return 4.59280633647778e-105*(1.0 - cos(theta)**2)**30.5*(8.85527274843652e+107*cos(theta)**4 - 4.11873151090071e+106*cos(theta)**2 + 1.62154783893729e+104)*cos(61*phi)

#@torch.jit.script
def Yl65_m62(theta, phi):
    return 2.03772829958056e-106*(1.0 - cos(theta)**2)**31*(3.54210909937461e+108*cos(theta)**3 - 8.23746302180142e+106*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl65_m63(theta, phi):
    return 1.039873868417e-107*(1.0 - cos(theta)**2)**31.5*(1.06263272981238e+109*cos(theta)**2 - 8.23746302180142e+106)*cos(63*phi)

#@torch.jit.script
def Yl65_m64(theta, phi):
    return 13.7589089193287*(1.0 - cos(theta)**2)**32*cos(64*phi)*cos(theta)

#@torch.jit.script
def Yl65_m65(theta, phi):
    return 1.20673614046122*(1.0 - cos(theta)**2)**32.5*cos(65*phi)

#@torch.jit.script
def Yl66_m_minus_66(theta, phi):
    return 1.21129848618741*(1.0 - cos(theta)**2)**33*sin(66*phi)

#@torch.jit.script
def Yl66_m_minus_65(theta, phi):
    return 13.9167600751205*(1.0 - cos(theta)**2)**32.5*sin(65*phi)*cos(theta)

#@torch.jit.script
def Yl66_m_minus_64(theta, phi):
    return 8.09103921464814e-110*(1.0 - cos(theta)**2)**32*(1.39204887605422e+111*cos(theta)**2 - 1.06263272981238e+109)*sin(64*phi)

#@torch.jit.script
def Yl66_m_minus_63(theta, phi):
    return 1.59785221699192e-108*(1.0 - cos(theta)**2)**31.5*(4.64016292018074e+110*cos(theta)**3 - 1.06263272981238e+109*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl66_m_minus_62(theta, phi):
    return 3.62962251617235e-107*(1.0 - cos(theta)**2)**31*(1.16004073004518e+110*cos(theta)**4 - 5.31316364906191e+108*cos(theta)**2 + 2.05936575545035e+106)*sin(62*phi)

#@torch.jit.script
def Yl66_m_minus_61(theta, phi):
    return 9.18229935818876e-106*(1.0 - cos(theta)**2)**30.5*(2.32008146009037e+109*cos(theta)**5 - 1.7710545496873e+108*cos(theta)**3 + 2.05936575545035e+106*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl66_m_minus_60(theta, phi):
    return 2.53471382182656e-104*(1.0 - cos(theta)**2)**30*(3.86680243348395e+108*cos(theta)**6 - 4.42763637421826e+107*cos(theta)**4 + 1.02968287772518e+106*cos(theta)**2 - 2.70257973156214e+103)*sin(60*phi)

#@torch.jit.script
def Yl66_m_minus_59(theta, phi):
    return 7.52771599347949e-103*(1.0 - cos(theta)**2)**29.5*(5.52400347640564e+107*cos(theta)**7 - 8.85527274843652e+106*cos(theta)**5 + 3.43227625908392e+105*cos(theta)**3 - 2.70257973156214e+103*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl66_m_minus_58(theta, phi):
    return 2.38047281182724e-101*(1.0 - cos(theta)**2)**29*(6.90500434550705e+106*cos(theta)**8 - 1.47587879140609e+106*cos(theta)**6 + 8.58069064770981e+104*cos(theta)**4 - 1.35128986578107e+103*cos(theta)**2 + 2.70257973156214e+100)*sin(58*phi)

#@torch.jit.script
def Yl66_m_minus_57(theta, phi):
    return 7.95234701302649e-100*(1.0 - cos(theta)**2)**28.5*(7.67222705056339e+105*cos(theta)**9 - 2.10839827343727e+105*cos(theta)**7 + 1.71613812954196e+104*cos(theta)**5 - 4.50429955260357e+102*cos(theta)**3 + 2.70257973156214e+100*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl66_m_minus_56(theta, phi):
    return 2.78899591805326e-98*(1.0 - cos(theta)**2)**28*(7.67222705056339e+104*cos(theta)**10 - 2.63549784179658e+104*cos(theta)**8 + 2.86023021590327e+103*cos(theta)**6 - 1.12607488815089e+102*cos(theta)**4 + 1.35128986578107e+100*cos(theta)**2 - 2.19721929395296e+97)*sin(56*phi)

#@torch.jit.script
def Yl66_m_minus_55(theta, phi):
    return 1.02170174835378e-96*(1.0 - cos(theta)**2)**27.5*(6.97475186414853e+103*cos(theta)**11 - 2.92833093532954e+103*cos(theta)**9 + 4.0860431655761e+102*cos(theta)**7 - 2.25214977630179e+101*cos(theta)**5 + 4.50429955260357e+99*cos(theta)**3 - 2.19721929395296e+97*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl66_m_minus_54(theta, phi):
    return 3.89320654432752e-95*(1.0 - cos(theta)**2)**27*(5.81229322012378e+102*cos(theta)**12 - 2.92833093532954e+102*cos(theta)**10 + 5.10755395697012e+101*cos(theta)**8 - 3.75358296050298e+100*cos(theta)**6 + 1.12607488815089e+99*cos(theta)**4 - 1.09860964697648e+97*cos(theta)**2 + 1.51323642834226e+94)*sin(54*phi)

#@torch.jit.script
def Yl66_m_minus_53(theta, phi):
    return 1.53769337733501e-93*(1.0 - cos(theta)**2)**26.5*(4.4709947847106e+101*cos(theta)**13 - 2.66211903211776e+101*cos(theta)**11 + 5.67505995218903e+100*cos(theta)**9 - 5.36226137214711e+99*cos(theta)**7 + 2.25214977630179e+98*cos(theta)**5 - 3.66203215658827e+96*cos(theta)**3 + 1.51323642834226e+94*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl66_m_minus_52(theta, phi):
    return 6.27635127858387e-92*(1.0 - cos(theta)**2)**26*(3.19356770336471e+100*cos(theta)**14 - 2.2184325267648e+100*cos(theta)**12 + 5.67505995218903e+99*cos(theta)**10 - 6.70282671518389e+98*cos(theta)**8 + 3.75358296050298e+97*cos(theta)**6 - 9.15508039147068e+95*cos(theta)**4 + 7.5661821417113e+93*cos(theta)**2 - 9.08305179076987e+90)*sin(52*phi)

#@torch.jit.script
def Yl66_m_minus_51(theta, phi):
    return 2.64054683936417e-90*(1.0 - cos(theta)**2)**25.5*(2.12904513557648e+99*cos(theta)**15 - 1.70648655904985e+99*cos(theta)**13 + 5.15914541108093e+98*cos(theta)**11 - 7.44758523909321e+97*cos(theta)**9 + 5.36226137214711e+96*cos(theta)**7 - 1.83101607829414e+95*cos(theta)**5 + 2.52206071390377e+93*cos(theta)**3 - 9.08305179076987e+90*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl66_m_minus_50(theta, phi):
    return 1.14247524295103e-88*(1.0 - cos(theta)**2)**25*(1.3306532097353e+98*cos(theta)**16 - 1.21891897074989e+98*cos(theta)**14 + 4.29928784256744e+97*cos(theta)**12 - 7.44758523909321e+96*cos(theta)**10 + 6.70282671518389e+95*cos(theta)**8 - 3.05169346382356e+94*cos(theta)**6 + 6.30515178475942e+92*cos(theta)**4 - 4.54152589538494e+90*cos(theta)**2 + 4.85205758053946e+87)*sin(50*phi)

#@torch.jit.script
def Yl66_m_minus_49(theta, phi):
    return 5.07341341746446e-87*(1.0 - cos(theta)**2)**24.5*(7.82737182197234e+96*cos(theta)**17 - 8.12612647166594e+96*cos(theta)**15 + 3.30714449428265e+96*cos(theta)**13 - 6.77053203553928e+95*cos(theta)**11 + 7.44758523909321e+94*cos(theta)**9 - 4.35956209117651e+93*cos(theta)**7 + 1.26103035695188e+92*cos(theta)**5 - 1.51384196512831e+90*cos(theta)**3 + 4.85205758053946e+87*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl66_m_minus_48(theta, phi):
    return 2.30826372124878e-85*(1.0 - cos(theta)**2)**24*(4.34853990109574e+95*cos(theta)**18 - 5.07882904479121e+95*cos(theta)**16 + 2.36224606734475e+95*cos(theta)**14 - 5.64211002961607e+94*cos(theta)**12 + 7.44758523909321e+93*cos(theta)**10 - 5.44945261397064e+92*cos(theta)**8 + 2.10171726158647e+91*cos(theta)**6 - 3.78460491282078e+89*cos(theta)**4 + 2.42602879026973e+87*cos(theta)**2 - 2.34398916934274e+84)*sin(48*phi)

#@torch.jit.script
def Yl66_m_minus_47(theta, phi):
    return 1.07427297867911e-83*(1.0 - cos(theta)**2)**23.5*(2.28870521110302e+94*cos(theta)**19 - 2.98754649693601e+94*cos(theta)**17 + 1.57483071156317e+94*cos(theta)**15 - 4.34008463816621e+93*cos(theta)**13 + 6.77053203553928e+92*cos(theta)**11 - 6.05494734885627e+91*cos(theta)**9 + 3.00245323083782e+90*cos(theta)**7 - 7.56920982564156e+88*cos(theta)**5 + 8.08676263423244e+86*cos(theta)**3 - 2.34398916934274e+84*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl66_m_minus_46(theta, phi):
    return 5.10703543941824e-82*(1.0 - cos(theta)**2)**23*(1.14435260555151e+93*cos(theta)**20 - 1.65974805385334e+93*cos(theta)**18 + 9.84269194726979e+92*cos(theta)**16 - 3.100060455833e+92*cos(theta)**14 + 5.64211002961607e+91*cos(theta)**12 - 6.05494734885627e+90*cos(theta)**10 + 3.75306653854727e+89*cos(theta)**8 - 1.26153497094026e+88*cos(theta)**6 + 2.02169065855811e+86*cos(theta)**4 - 1.17199458467137e+84*cos(theta)**2 + 1.0371633492667e+81)*sin(46*phi)

#@torch.jit.script
def Yl66_m_minus_45(theta, phi):
    return 2.47678055999563e-80*(1.0 - cos(theta)**2)**22.5*(5.44929812167386e+91*cos(theta)**21 - 8.7355160729123e+91*cos(theta)**19 + 5.78981879251164e+91*cos(theta)**17 - 2.06670697055534e+91*cos(theta)**15 + 4.34008463816621e+90*cos(theta)**13 - 5.50449758986933e+89*cos(theta)**11 + 4.17007393171919e+88*cos(theta)**9 - 1.80219281562894e+87*cos(theta)**7 + 4.04338131711622e+85*cos(theta)**5 - 3.90664861557123e+83*cos(theta)**3 + 1.0371633492667e+81*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl66_m_minus_44(theta, phi):
    return 1.22394065310672e-78*(1.0 - cos(theta)**2)**22*(2.47695369166994e+90*cos(theta)**22 - 4.36775803645615e+90*cos(theta)**20 + 3.2165659958398e+90*cos(theta)**18 - 1.29169185659709e+90*cos(theta)**16 + 3.100060455833e+89*cos(theta)**14 - 4.58708132489111e+88*cos(theta)**12 + 4.17007393171919e+87*cos(theta)**10 - 2.25274101953618e+86*cos(theta)**8 + 6.73896886186036e+84*cos(theta)**6 - 9.76662153892806e+82*cos(theta)**4 + 5.18581674633348e+80*cos(theta)**2 - 4.24718816243529e+77)*sin(44*phi)

#@torch.jit.script
def Yl66_m_minus_43(theta, phi):
    return 6.15631198648028e-77*(1.0 - cos(theta)**2)**21.5*(1.07693638768258e+89*cos(theta)**23 - 2.07988477926483e+89*cos(theta)**21 + 1.69292947149463e+89*cos(theta)**19 - 7.59818739174756e+88*cos(theta)**17 + 2.06670697055534e+88*cos(theta)**15 - 3.52852409607009e+87*cos(theta)**13 + 3.7909763015629e+86*cos(theta)**11 - 2.50304557726242e+85*cos(theta)**9 + 9.62709837408623e+83*cos(theta)**7 - 1.95332430778561e+82*cos(theta)**5 + 1.72860558211116e+80*cos(theta)**3 - 4.24718816243529e+77*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl66_m_minus_42(theta, phi):
    return 3.14875949781955e-75*(1.0 - cos(theta)**2)**21*(4.48723494867742e+87*cos(theta)**24 - 9.45402172393106e+87*cos(theta)**22 + 8.46464735747316e+87*cos(theta)**20 - 4.22121521763753e+87*cos(theta)**18 + 1.29169185659709e+87*cos(theta)**16 - 2.52037435433578e+86*cos(theta)**14 + 3.15914691796909e+85*cos(theta)**12 - 2.50304557726242e+84*cos(theta)**10 + 1.20338729676078e+83*cos(theta)**8 - 3.25554051297602e+81*cos(theta)**6 + 4.3215139552779e+79*cos(theta)**4 - 2.12359408121764e+77*cos(theta)**2 + 1.62354287554866e+74)*sin(42*phi)

#@torch.jit.script
def Yl66_m_minus_41(theta, phi):
    return 1.63614342931156e-73*(1.0 - cos(theta)**2)**20.5*(1.79489397947097e+86*cos(theta)**25 - 4.11044422779611e+86*cos(theta)**23 + 4.0307844559396e+86*cos(theta)**21 - 2.22169221980923e+86*cos(theta)**19 + 7.59818739174756e+85*cos(theta)**17 - 1.68024956955718e+85*cos(theta)**15 + 2.43011301382237e+84*cos(theta)**13 - 2.27549597932947e+83*cos(theta)**11 + 1.33709699640087e+82*cos(theta)**9 - 4.65077216139432e+80*cos(theta)**7 + 8.64302791055581e+78*cos(theta)**5 - 7.07864693739214e+76*cos(theta)**3 + 1.62354287554866e+74*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl66_m_minus_40(theta, phi):
    return 8.62978419417266e-72*(1.0 - cos(theta)**2)**20*(6.90343838258065e+84*cos(theta)**26 - 1.71268509491505e+85*cos(theta)**24 + 1.83217475269982e+85*cos(theta)**22 - 1.11084610990461e+85*cos(theta)**20 + 4.22121521763753e+84*cos(theta)**18 - 1.05015598097324e+84*cos(theta)**16 + 1.73579500987312e+83*cos(theta)**14 - 1.89624664944123e+82*cos(theta)**12 + 1.33709699640087e+81*cos(theta)**10 - 5.81346520174289e+79*cos(theta)**8 + 1.4405046517593e+78*cos(theta)**6 - 1.76966173434804e+76*cos(theta)**4 + 8.11771437774329e+73*cos(theta)**2 - 5.83588380858611e+70)*sin(40*phi)

#@torch.jit.script
def Yl66_m_minus_39(theta, phi):
    return 4.61673290900756e-70*(1.0 - cos(theta)**2)**19.5*(2.55682903058543e+83*cos(theta)**27 - 6.85074037966019e+83*cos(theta)**25 + 7.96597718565138e+83*cos(theta)**23 - 5.28974338049816e+83*cos(theta)**21 + 2.22169221980923e+83*cos(theta)**19 - 6.177388123372e+82*cos(theta)**17 + 1.15719667324875e+82*cos(theta)**15 - 1.45865126880094e+81*cos(theta)**13 + 1.21554272400079e+80*cos(theta)**11 - 6.45940577971433e+78*cos(theta)**9 + 2.05786378822757e+77*cos(theta)**7 - 3.53932346869607e+75*cos(theta)**5 + 2.70590479258109e+73*cos(theta)**3 - 5.83588380858611e+70*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl66_m_minus_38(theta, phi):
    return 2.50327415386636e-68*(1.0 - cos(theta)**2)**19*(9.13153225209081e+81*cos(theta)**28 - 2.63490014602315e+82*cos(theta)**26 + 3.31915716068808e+82*cos(theta)**24 - 2.40442880931735e+82*cos(theta)**22 + 1.11084610990461e+82*cos(theta)**20 - 3.43188229076222e+81*cos(theta)**18 + 7.23247920780468e+80*cos(theta)**16 - 1.04189376342925e+80*cos(theta)**14 + 1.01295227000066e+79*cos(theta)**12 - 6.45940577971433e+77*cos(theta)**10 + 2.57232973528447e+76*cos(theta)**8 - 5.89887244782679e+74*cos(theta)**6 + 6.76476198145274e+72*cos(theta)**4 - 2.91794190429306e+70*cos(theta)**2 + 1.98499449271637e+67)*sin(38*phi)

#@torch.jit.script
def Yl66_m_minus_37(theta, phi):
    return 1.37475112555243e-66*(1.0 - cos(theta)**2)**18.5*(3.1488042248589e+80*cos(theta)**29 - 9.75888942971537e+80*cos(theta)**27 + 1.32766286427523e+81*cos(theta)**25 - 1.04540383013798e+81*cos(theta)**23 + 5.28974338049816e+80*cos(theta)**21 - 1.80625383724327e+80*cos(theta)**19 + 4.25439953400275e+79*cos(theta)**17 - 6.94595842286164e+78*cos(theta)**15 + 7.79194053846658e+77*cos(theta)**13 - 5.87218707246757e+76*cos(theta)**11 + 2.85814415031607e+75*cos(theta)**9 - 8.42696063975255e+73*cos(theta)**7 + 1.35295239629055e+72*cos(theta)**5 - 9.72647301431019e+69*cos(theta)**3 + 1.98499449271637e+67*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl66_m_minus_36(theta, phi):
    return 7.64193472281181e-65*(1.0 - cos(theta)**2)**18*(1.0496014082863e+79*cos(theta)**30 - 3.48531765346977e+79*cos(theta)**28 + 5.10639563182781e+79*cos(theta)**26 - 4.35584929224157e+79*cos(theta)**24 + 2.40442880931735e+79*cos(theta)**22 - 9.03126918621637e+78*cos(theta)**20 + 2.3635552966682e+78*cos(theta)**18 - 4.34122401428853e+77*cos(theta)**16 + 5.56567181319042e+76*cos(theta)**14 - 4.89348922705631e+75*cos(theta)**12 + 2.85814415031607e+74*cos(theta)**10 - 1.05337007996907e+73*cos(theta)**8 + 2.25492066048425e+71*cos(theta)**6 - 2.43161825357755e+69*cos(theta)**4 + 9.92497246358183e+66*cos(theta)**2 - 6.42393039714034e+63)*sin(36*phi)

#@torch.jit.script
def Yl66_m_minus_35(theta, phi):
    return 4.29718703182676e-63*(1.0 - cos(theta)**2)**17.5*(3.38581099447194e+77*cos(theta)**31 - 1.20183367361027e+78*cos(theta)**29 + 1.89125764141771e+78*cos(theta)**27 - 1.74233971689663e+78*cos(theta)**25 + 1.04540383013798e+78*cos(theta)**23 - 4.30060437438875e+77*cos(theta)**21 + 1.24397647193063e+77*cos(theta)**19 - 2.5536611848756e+76*cos(theta)**17 + 3.71044787546028e+75*cos(theta)**15 - 3.76422248235101e+74*cos(theta)**13 + 2.5983128639237e+73*cos(theta)**11 - 1.17041119996563e+72*cos(theta)**9 + 3.22131522926321e+70*cos(theta)**7 - 4.8632365071551e+68*cos(theta)**5 + 3.30832415452728e+66*cos(theta)**3 - 6.42393039714034e+63*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl66_m_minus_34(theta, phi):
    return 2.44298011783085e-61*(1.0 - cos(theta)**2)**17*(1.05806593577248e+76*cos(theta)**32 - 4.00611224536756e+76*cos(theta)**30 + 6.75449157649181e+76*cos(theta)**28 - 6.70130660344857e+76*cos(theta)**26 + 4.35584929224157e+76*cos(theta)**24 - 1.9548201701767e+76*cos(theta)**22 + 6.21988235965315e+75*cos(theta)**20 - 1.41870065826422e+75*cos(theta)**18 + 2.31902992216267e+74*cos(theta)**16 - 2.68873034453643e+73*cos(theta)**14 + 2.16526071993642e+72*cos(theta)**12 - 1.17041119996563e+71*cos(theta)**10 + 4.02664403657901e+69*cos(theta)**8 - 8.10539417859183e+67*cos(theta)**6 + 8.27081038631819e+65*cos(theta)**4 - 3.21196519857017e+63*cos(theta)**2 + 1.98760222683798e+60)*sin(34*phi)

#@torch.jit.script
def Yl66_m_minus_33(theta, phi):
    return 1.40338523311262e-59*(1.0 - cos(theta)**2)**16.5*(3.20626041143176e+74*cos(theta)**33 - 1.29229427269921e+75*cos(theta)**31 + 2.32913502637649e+75*cos(theta)**29 - 2.48196540868465e+75*cos(theta)**27 + 1.74233971689663e+75*cos(theta)**25 - 8.49921813120306e+74*cos(theta)**23 + 2.96184874269198e+74*cos(theta)**21 - 7.46684556981171e+73*cos(theta)**19 + 1.36413524833098e+73*cos(theta)**17 - 1.79248689635762e+72*cos(theta)**15 + 1.66558516918186e+71*cos(theta)**13 - 1.06401018178694e+70*cos(theta)**11 + 4.47404892953223e+68*cos(theta)**9 - 1.15791345408455e+67*cos(theta)**7 + 1.65416207726364e+65*cos(theta)**5 - 1.07065506619006e+63*cos(theta)**3 + 1.98760222683798e+60*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl66_m_minus_32(theta, phi):
    return 8.14205362223649e-58*(1.0 - cos(theta)**2)**16*(9.43017768068164e+72*cos(theta)**34 - 4.03841960218504e+73*cos(theta)**32 + 7.76378342125496e+73*cos(theta)**30 - 8.86416217387377e+73*cos(theta)**28 + 6.70130660344857e+73*cos(theta)**26 - 3.54134088800128e+73*cos(theta)**24 + 1.34629488304181e+73*cos(theta)**22 - 3.73342278490585e+72*cos(theta)**20 + 7.57852915739436e+71*cos(theta)**18 - 1.12030431022351e+71*cos(theta)**16 + 1.18970369227276e+70*cos(theta)**14 - 8.86675151489115e+68*cos(theta)**12 + 4.47404892953223e+67*cos(theta)**10 - 1.44739181760568e+66*cos(theta)**8 + 2.7569367954394e+64*cos(theta)**6 - 2.67663766547514e+62*cos(theta)**4 + 9.93801113418988e+59*cos(theta)**2 - 5.90493828531782e+56)*sin(32*phi)

#@torch.jit.script
def Yl66_m_minus_31(theta, phi):
    return 4.76849155973558e-56*(1.0 - cos(theta)**2)**15.5*(2.69433648019475e+71*cos(theta)**35 - 1.22376351581365e+72*cos(theta)**33 + 2.50444626492095e+72*cos(theta)**31 - 3.05660764616337e+72*cos(theta)**29 + 2.48196540868465e+72*cos(theta)**27 - 1.41653635520051e+72*cos(theta)**25 + 5.85345601322525e+71*cos(theta)**23 - 1.77782037376469e+71*cos(theta)**21 + 3.98869955652335e+70*cos(theta)**19 - 6.59002535425596e+69*cos(theta)**17 + 7.93135794848505e+68*cos(theta)**15 - 6.82057808837781e+67*cos(theta)**13 + 4.06731720866567e+66*cos(theta)**11 - 1.60821313067298e+65*cos(theta)**9 + 3.93848113634199e+63*cos(theta)**7 - 5.35327533095028e+61*cos(theta)**5 + 3.31267037806329e+59*cos(theta)**3 - 5.90493828531782e+56*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl66_m_minus_30(theta, phi):
    return 2.81785171805404e-54*(1.0 - cos(theta)**2)**15*(7.48426800054098e+69*cos(theta)**36 - 3.59930445827543e+70*cos(theta)**34 + 7.82639457787798e+70*cos(theta)**32 - 1.01886921538779e+71*cos(theta)**30 + 8.86416217387377e+70*cos(theta)**28 - 5.44821675077119e+70*cos(theta)**26 + 2.43894000551052e+70*cos(theta)**24 - 8.08100169893042e+69*cos(theta)**22 + 1.99434977826167e+69*cos(theta)**20 - 3.66112519680887e+68*cos(theta)**18 + 4.95709871780316e+67*cos(theta)**16 - 4.87184149169844e+66*cos(theta)**14 + 3.38943100722139e+65*cos(theta)**12 - 1.60821313067298e+64*cos(theta)**10 + 4.92310142042749e+62*cos(theta)**8 - 8.92212555158381e+60*cos(theta)**6 + 8.28167594515824e+58*cos(theta)**4 - 2.95246914265891e+56*cos(theta)**2 + 1.69099034516547e+53)*sin(30*phi)

#@torch.jit.script
def Yl66_m_minus_29(theta, phi):
    return 1.67940180002128e-52*(1.0 - cos(theta)**2)**14.5*(2.02277513528135e+68*cos(theta)**37 - 1.02837270236441e+69*cos(theta)**35 + 2.37163472056908e+69*cos(theta)**33 - 3.28667488834771e+69*cos(theta)**31 + 3.05660764616337e+69*cos(theta)**29 - 2.01785805584118e+69*cos(theta)**27 + 9.75576002204208e+68*cos(theta)**25 - 3.51347899953496e+68*cos(theta)**23 + 9.49690370600797e+67*cos(theta)**21 - 1.92690799832046e+67*cos(theta)**19 + 2.91594042223715e+66*cos(theta)**17 - 3.24789432779896e+65*cos(theta)**15 + 2.60725462093953e+64*cos(theta)**13 - 1.46201193697544e+63*cos(theta)**11 + 5.47011268936388e+61*cos(theta)**9 - 1.27458936451197e+60*cos(theta)**7 + 1.65633518903165e+58*cos(theta)**5 - 9.84156380886303e+55*cos(theta)**3 + 1.69099034516547e+53*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl66_m_minus_28(theta, phi):
    return 1.00903961098423e-50*(1.0 - cos(theta)**2)**14*(5.3230924612667e+66*cos(theta)**38 - 2.85659083990114e+67*cos(theta)**36 + 6.9753962369679e+67*cos(theta)**34 - 1.02708590260866e+68*cos(theta)**32 + 1.01886921538779e+68*cos(theta)**30 - 7.20663591371851e+67*cos(theta)**28 + 3.75221539309311e+67*cos(theta)**26 - 1.46394958313957e+67*cos(theta)**24 + 4.3167744118218e+66*cos(theta)**22 - 9.63453999160229e+65*cos(theta)**20 + 1.61996690124286e+65*cos(theta)**18 - 2.02993395487435e+64*cos(theta)**16 + 1.86232472924252e+63*cos(theta)**14 - 1.21834328081286e+62*cos(theta)**12 + 5.47011268936388e+60*cos(theta)**10 - 1.59323670563997e+59*cos(theta)**8 + 2.76055864838608e+57*cos(theta)**6 - 2.46039095221576e+55*cos(theta)**4 + 8.45495172582734e+52*cos(theta)**2 - 4.6841837816218e+49)*sin(28*phi)

#@torch.jit.script
def Yl66_m_minus_27(theta, phi):
    return 6.1094827877146e-49*(1.0 - cos(theta)**2)**13.5*(1.3648955028889e+65*cos(theta)**39 - 7.72051578351659e+65*cos(theta)**37 + 1.9929703534194e+66*cos(theta)**35 - 3.11238152305654e+66*cos(theta)**33 + 3.28667488834771e+66*cos(theta)**31 - 2.48504686679949e+66*cos(theta)**29 + 1.3897094048493e+66*cos(theta)**27 - 5.85579833255827e+65*cos(theta)**25 + 1.87685843992252e+65*cos(theta)**23 - 4.58787618647728e+64*cos(theta)**21 + 8.52614158548875e+63*cos(theta)**19 - 1.19407879698491e+63*cos(theta)**17 + 1.24154981949501e+62*cos(theta)**15 - 9.37187139086819e+60*cos(theta)**13 + 4.97282971760353e+59*cos(theta)**11 - 1.77026300626663e+58*cos(theta)**9 + 3.94365521198011e+56*cos(theta)**7 - 4.92078190443151e+54*cos(theta)**5 + 2.81831724194245e+52*cos(theta)**3 - 4.6841837816218e+49*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl66_m_minus_26(theta, phi):
    return 3.72628368957836e-47*(1.0 - cos(theta)**2)**13*(3.41223875722224e+63*cos(theta)**40 - 2.03171467987279e+64*cos(theta)**38 + 5.53602875949833e+64*cos(theta)**36 - 9.15406330310747e+64*cos(theta)**34 + 1.02708590260866e+65*cos(theta)**32 - 8.28348955599829e+64*cos(theta)**30 + 4.96324787446178e+64*cos(theta)**28 - 2.25223012790703e+64*cos(theta)**26 + 7.82024349967718e+63*cos(theta)**24 - 2.08539826658058e+63*cos(theta)**22 + 4.26307079274438e+62*cos(theta)**20 - 6.63377109436062e+61*cos(theta)**18 + 7.75968637184384e+60*cos(theta)**16 - 6.69419385062013e+59*cos(theta)**14 + 4.14402476466961e+58*cos(theta)**12 - 1.77026300626663e+57*cos(theta)**10 + 4.92956901497514e+55*cos(theta)**8 - 8.20130317405252e+53*cos(theta)**6 + 7.04579310485612e+51*cos(theta)**4 - 2.3420918908109e+49*cos(theta)**2 + 1.25918918860801e+46)*sin(26*phi)

#@torch.jit.script
def Yl66_m_minus_25(theta, phi):
    return 2.28855712600846e-45*(1.0 - cos(theta)**2)**12.5*(8.3225335542006e+61*cos(theta)**41 - 5.20952482018663e+62*cos(theta)**39 + 1.4962239890536e+63*cos(theta)**37 - 2.61544665803071e+63*cos(theta)**35 + 3.11238152305654e+63*cos(theta)**33 - 2.67209340516074e+63*cos(theta)**31 + 1.71146478429717e+63*cos(theta)**29 - 8.34159306632233e+62*cos(theta)**27 + 3.12809739987087e+62*cos(theta)**25 - 9.06694898513296e+61*cos(theta)**23 + 2.03003371083065e+61*cos(theta)**21 - 3.49145847071611e+60*cos(theta)**19 + 4.56452139520226e+59*cos(theta)**17 - 4.46279590041342e+58*cos(theta)**15 + 3.18771135743816e+57*cos(theta)**13 - 1.60933000569693e+56*cos(theta)**11 + 5.47729890552793e+54*cos(theta)**9 - 1.17161473915036e+53*cos(theta)**7 + 1.40915862097122e+51*cos(theta)**5 - 7.80697296936966e+48*cos(theta)**3 + 1.25918918860801e+46*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl66_m_minus_24(theta, phi):
    return 1.41483924860861e-43*(1.0 - cos(theta)**2)**12*(1.981555608143e+60*cos(theta)**42 - 1.30238120504666e+61*cos(theta)**40 + 3.93743155014106e+61*cos(theta)**38 - 7.26512960564085e+61*cos(theta)**36 + 9.15406330310748e+61*cos(theta)**34 - 8.35029189112731e+61*cos(theta)**32 + 5.70488261432389e+61*cos(theta)**30 - 2.9791403808294e+61*cos(theta)**28 + 1.20311438456572e+61*cos(theta)**26 - 3.77789541047207e+60*cos(theta)**24 + 9.22742595832116e+59*cos(theta)**22 - 1.74572923535806e+59*cos(theta)**20 + 2.53584521955681e+58*cos(theta)**18 - 2.78924743775839e+57*cos(theta)**16 + 2.2769366838844e+56*cos(theta)**14 - 1.34110833808078e+55*cos(theta)**12 + 5.47729890552793e+53*cos(theta)**10 - 1.46451842393795e+52*cos(theta)**8 + 2.34859770161871e+50*cos(theta)**6 - 1.95174324234241e+48*cos(theta)**4 + 6.29594594304005e+45*cos(theta)**2 - 3.29458186448982e+42)*sin(24*phi)

#@torch.jit.script
def Yl66_m_minus_23(theta, phi):
    return 8.8016193309476e-42*(1.0 - cos(theta)**2)**11.5*(4.60826885614651e+58*cos(theta)**43 - 3.17653952450404e+59*cos(theta)**41 + 1.0095978333695e+60*cos(theta)**39 - 1.9635485420651e+60*cos(theta)**37 + 2.61544665803071e+60*cos(theta)**35 - 2.53039148215979e+60*cos(theta)**33 + 1.84028471429803e+60*cos(theta)**31 - 1.0272897864929e+60*cos(theta)**29 + 4.45597920209526e+59*cos(theta)**27 - 1.51115816418883e+59*cos(theta)**25 + 4.01192432970485e+58*cos(theta)**23 - 8.31299635884789e+57*cos(theta)**21 + 1.33465537871411e+57*cos(theta)**19 - 1.6407337869167e+56*cos(theta)**17 + 1.51795778925627e+55*cos(theta)**15 - 1.03162179852368e+54*cos(theta)**13 + 4.97936264138903e+52*cos(theta)**11 - 1.62724269326439e+51*cos(theta)**9 + 3.35513957374101e+49*cos(theta)**7 - 3.90348648468483e+47*cos(theta)**5 + 2.09864864768002e+45*cos(theta)**3 - 3.29458186448982e+42*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl66_m_minus_22(theta, phi):
    return 5.50787306633424e-40*(1.0 - cos(theta)**2)**11*(1.04733383094239e+57*cos(theta)**44 - 7.56318934405725e+57*cos(theta)**42 + 2.52399458342376e+58*cos(theta)**40 - 5.16723300543446e+58*cos(theta)**38 + 7.26512960564085e+58*cos(theta)**36 - 7.44232788870526e+58*cos(theta)**34 + 5.75088973218134e+58*cos(theta)**32 - 3.42429928830966e+58*cos(theta)**30 + 1.59142114360545e+58*cos(theta)**28 - 5.81214678534164e+57*cos(theta)**26 + 1.67163513737702e+57*cos(theta)**24 - 3.77863470856722e+56*cos(theta)**22 + 6.67327689357055e+55*cos(theta)**20 - 9.11518770509278e+54*cos(theta)**18 + 9.48723618285166e+53*cos(theta)**16 - 7.36872713231197e+52*cos(theta)**14 + 4.14946886782419e+51*cos(theta)**12 - 1.62724269326439e+50*cos(theta)**10 + 4.19392446717626e+48*cos(theta)**8 - 6.50581080780805e+46*cos(theta)**6 + 5.24662161920004e+44*cos(theta)**4 - 1.64729093224491e+42*cos(theta)**2 + 8.4131303996165e+38)*sin(22*phi)

#@torch.jit.script
def Yl66_m_minus_21(theta, phi):
    return 3.46602360394165e-38*(1.0 - cos(theta)**2)**10.5*(2.32740851320531e+55*cos(theta)**45 - 1.75888124280401e+56*cos(theta)**43 + 6.15608434981404e+56*cos(theta)**41 - 1.32493153985499e+57*cos(theta)**39 + 1.9635485420651e+57*cos(theta)**37 - 2.12637939677293e+57*cos(theta)**35 + 1.74269385823677e+57*cos(theta)**33 - 1.10461267364828e+57*cos(theta)**31 + 5.48765911588086e+56*cos(theta)**29 - 2.15264695753394e+56*cos(theta)**27 + 6.68654054950809e+55*cos(theta)**25 - 1.64288465589879e+55*cos(theta)**23 + 3.17775090170026e+54*cos(theta)**21 - 4.79746721320672e+53*cos(theta)**19 + 5.58072716638333e+52*cos(theta)**17 - 4.91248475487465e+51*cos(theta)**15 + 3.19189912909553e+50*cos(theta)**13 - 1.47931153933126e+49*cos(theta)**11 + 4.65991607464029e+47*cos(theta)**9 - 9.29401543972579e+45*cos(theta)**7 + 1.04932432384001e+44*cos(theta)**5 - 5.4909697741497e+41*cos(theta)**3 + 8.4131303996165e+38*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl66_m_minus_20(theta, phi):
    return 2.19265376043663e-36*(1.0 - cos(theta)**2)**10*(5.05958372435937e+53*cos(theta)**46 - 3.99745737000912e+54*cos(theta)**44 + 1.46573436900334e+55*cos(theta)**42 - 3.31232884963748e+55*cos(theta)**40 + 5.16723300543446e+55*cos(theta)**38 - 5.90660943548037e+55*cos(theta)**36 + 5.12557017128462e+55*cos(theta)**34 - 3.45191460515086e+55*cos(theta)**32 + 1.82921970529362e+55*cos(theta)**30 - 7.68802484833551e+54*cos(theta)**28 + 2.57174636519542e+54*cos(theta)**26 - 6.84535273291163e+53*cos(theta)**24 + 1.44443222804557e+53*cos(theta)**22 - 2.39873360660336e+52*cos(theta)**20 + 3.10040398132407e+51*cos(theta)**18 - 3.07030297179666e+50*cos(theta)**16 + 2.27992794935395e+49*cos(theta)**14 - 1.23275961610939e+48*cos(theta)**12 + 4.65991607464029e+46*cos(theta)**10 - 1.16175192996572e+45*cos(theta)**8 + 1.74887387306668e+43*cos(theta)**6 - 1.37274244353743e+41*cos(theta)**4 + 4.20656519980825e+38*cos(theta)**2 - 2.10223148416204e+35)*sin(20*phi)

#@torch.jit.script
def Yl66_m_minus_19(theta, phi):
    return 1.39401745807505e-34*(1.0 - cos(theta)**2)**9.5*(1.07650717539561e+52*cos(theta)**47 - 8.88323860002026e+52*cos(theta)**45 + 3.40868457907754e+53*cos(theta)**43 - 8.07885085277433e+53*cos(theta)**41 + 1.32493153985499e+54*cos(theta)**39 - 1.59638092850821e+54*cos(theta)**37 + 1.46444862036703e+54*cos(theta)**35 - 1.0460347288336e+54*cos(theta)**33 + 5.90070872675361e+53*cos(theta)**31 - 2.65104305115017e+53*cos(theta)**29 + 9.5249865377608e+52*cos(theta)**27 - 2.73814109316465e+52*cos(theta)**25 + 6.28014012193728e+51*cos(theta)**23 - 1.14225409838255e+51*cos(theta)**21 + 1.63179156911793e+50*cos(theta)**19 - 1.80606057164509e+49*cos(theta)**17 + 1.51995196623597e+48*cos(theta)**15 - 9.48276627776451e+46*cos(theta)**13 + 4.23628734058208e+45*cos(theta)**11 - 1.29083547773969e+44*cos(theta)**9 + 2.49839124723811e+42*cos(theta)**7 - 2.74548488707485e+40*cos(theta)**5 + 1.40218839993608e+38*cos(theta)**3 - 2.10223148416204e+35*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl66_m_minus_18(theta, phi):
    return 8.90426946332235e-33*(1.0 - cos(theta)**2)**9*(2.24272328207419e+50*cos(theta)**48 - 1.93113882609136e+51*cos(theta)**46 + 7.74701040699441e+51*cos(theta)**44 - 1.92353591732722e+52*cos(theta)**42 + 3.31232884963748e+52*cos(theta)**40 - 4.20100244344265e+52*cos(theta)**38 + 4.06791283435287e+52*cos(theta)**36 - 3.07657273186352e+52*cos(theta)**34 + 1.8439714771105e+52*cos(theta)**32 - 8.83681017050058e+51*cos(theta)**30 + 3.40178090634314e+51*cos(theta)**28 - 1.05313118967871e+51*cos(theta)**26 + 2.6167250508072e+50*cos(theta)**24 - 5.19206408355706e+49*cos(theta)**22 + 8.15895784558967e+48*cos(theta)**20 - 1.00336698424727e+48*cos(theta)**18 + 9.4996997889748e+46*cos(theta)**16 - 6.7734044841175e+45*cos(theta)**14 + 3.53023945048507e+44*cos(theta)**12 - 1.29083547773969e+43*cos(theta)**10 + 3.12298905904764e+41*cos(theta)**8 - 4.57580814512475e+39*cos(theta)**6 + 3.50547099984021e+37*cos(theta)**4 - 1.05111574208102e+35*cos(theta)**2 + 5.15252814745599e+31)*sin(18*phi)

#@torch.jit.script
def Yl66_m_minus_17(theta, phi):
    return 5.71262843535419e-31*(1.0 - cos(theta)**2)**8.5*(4.57698628994732e+48*cos(theta)**49 - 4.10880601296034e+49*cos(theta)**47 + 1.72155786822098e+50*cos(theta)**45 - 4.47333934262145e+50*cos(theta)**43 + 8.07885085277433e+50*cos(theta)**41 - 1.07718011370324e+51*cos(theta)**39 + 1.09943590117645e+51*cos(theta)**37 - 8.79020780532433e+50*cos(theta)**35 + 5.58779235488032e+50*cos(theta)**33 - 2.85058392596793e+50*cos(theta)**31 + 1.17302789873902e+50*cos(theta)**29 - 3.90048588769894e+49*cos(theta)**27 + 1.04669002032288e+49*cos(theta)**25 - 2.25741916676394e+48*cos(theta)**23 + 3.88521802170937e+47*cos(theta)**21 - 5.28087886445933e+46*cos(theta)**19 + 5.58805869939694e+45*cos(theta)**17 - 4.51560298941167e+44*cos(theta)**15 + 2.71556880806544e+43*cos(theta)**13 - 1.17348679794518e+42*cos(theta)**11 + 3.46998784338627e+40*cos(theta)**9 - 6.53686877874965e+38*cos(theta)**7 + 7.01094199968042e+36*cos(theta)**5 - 3.50371914027007e+34*cos(theta)**3 + 5.15252814745599e+31*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl66_m_minus_16(theta, phi):
    return 3.68010343751003e-29*(1.0 - cos(theta)**2)**8*(9.15397257989464e+46*cos(theta)**50 - 8.56001252700071e+47*cos(theta)**48 + 3.74251710482822e+48*cos(theta)**46 - 1.01666803241396e+49*cos(theta)**44 + 1.92353591732722e+49*cos(theta)**42 - 2.69295028425811e+49*cos(theta)**40 + 2.89325237151698e+49*cos(theta)**38 - 2.44172439036787e+49*cos(theta)**36 + 1.64346833967068e+49*cos(theta)**34 - 8.90807476864978e+48*cos(theta)**32 + 3.91009299579672e+48*cos(theta)**30 - 1.39303067417819e+48*cos(theta)**28 + 4.02573084739569e+47*cos(theta)**26 - 9.40591319484975e+46*cos(theta)**24 + 1.76600819168608e+46*cos(theta)**22 - 2.64043943222967e+45*cos(theta)**20 + 3.10447705522052e+44*cos(theta)**18 - 2.82225186838229e+43*cos(theta)**16 + 1.93969200576103e+42*cos(theta)**14 - 9.77905664954312e+40*cos(theta)**12 + 3.46998784338627e+39*cos(theta)**10 - 8.17108597343706e+37*cos(theta)**8 + 1.16849033328007e+36*cos(theta)**6 - 8.75929785067518e+33*cos(theta)**4 + 2.576264073728e+31*cos(theta)**2 - 1.24157304757976e+28)*sin(16*phi)

#@torch.jit.script
def Yl66_m_minus_15(theta, phi):
    return 2.37986345410096e-27*(1.0 - cos(theta)**2)**7.5*(1.79489658429307e+45*cos(theta)**51 - 1.74694133204096e+46*cos(theta)**49 + 7.96280235069834e+46*cos(theta)**47 - 2.25926229425326e+47*cos(theta)**45 + 4.47333934262145e+47*cos(theta)**43 - 6.56817142501978e+47*cos(theta)**41 + 7.41859582440251e+47*cos(theta)**39 - 6.59925510910235e+47*cos(theta)**37 + 4.69562382763052e+47*cos(theta)**35 - 2.69941659656054e+47*cos(theta)**33 + 1.26132032122475e+47*cos(theta)**31 - 4.80355404889032e+46*cos(theta)**29 + 1.49101142496137e+46*cos(theta)**27 - 3.7623652779399e+45*cos(theta)**25 + 7.67829648559163e+44*cos(theta)**23 - 1.25735211058556e+44*cos(theta)**21 + 1.63393529222133e+43*cos(theta)**19 - 1.66014815787194e+42*cos(theta)**17 + 1.29312800384068e+41*cos(theta)**15 - 7.52235126887933e+39*cos(theta)**13 + 3.15453440307843e+38*cos(theta)**11 - 9.07898441493006e+36*cos(theta)**9 + 1.66927190468581e+35*cos(theta)**7 - 1.75185957013504e+33*cos(theta)**5 + 8.58754691242665e+30*cos(theta)**3 - 1.24157304757976e+28*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl66_m_minus_14(theta, phi):
    return 1.54452954822549e-25*(1.0 - cos(theta)**2)**7*(3.45172420056359e+43*cos(theta)**52 - 3.49388266408192e+44*cos(theta)**50 + 1.65891715639549e+45*cos(theta)**48 - 4.91143977011577e+45*cos(theta)**46 + 1.01666803241396e+46*cos(theta)**44 - 1.56385033929042e+46*cos(theta)**42 + 1.85464895610063e+46*cos(theta)**40 - 1.73664608134272e+46*cos(theta)**38 + 1.30433995211959e+46*cos(theta)**36 - 7.93946057811923e+45*cos(theta)**34 + 3.94162600382734e+45*cos(theta)**32 - 1.60118468296344e+45*cos(theta)**30 + 5.32504080343346e+44*cos(theta)**28 - 1.44706356843842e+44*cos(theta)**26 + 3.19929020232985e+43*cos(theta)**24 - 5.71523686629798e+42*cos(theta)**22 + 8.16967646110664e+41*cos(theta)**20 - 9.22304532151076e+40*cos(theta)**18 + 8.08205002400428e+39*cos(theta)**16 - 5.37310804919952e+38*cos(theta)**14 + 2.62877866923202e+37*cos(theta)**12 - 9.07898441493006e+35*cos(theta)**10 + 2.08658988085727e+34*cos(theta)**8 - 2.91976595022506e+32*cos(theta)**6 + 2.14688672810666e+30*cos(theta)**4 - 6.20786523789878e+27*cos(theta)**2 + 2.9477042914999e+24)*sin(14*phi)

#@torch.jit.script
def Yl66_m_minus_13(theta, phi):
    return 1.00572477683751e-23*(1.0 - cos(theta)**2)**6.5*(6.5126871708747e+41*cos(theta)**53 - 6.85075032172926e+42*cos(theta)**51 + 3.38554521713365e+43*cos(theta)**49 - 1.04498718513102e+44*cos(theta)**47 + 2.25926229425326e+44*cos(theta)**45 - 3.63686125416378e+44*cos(theta)**43 + 4.52353403926982e+44*cos(theta)**41 - 4.45293867010955e+44*cos(theta)**39 + 3.52524311383673e+44*cos(theta)**37 - 2.26841730803407e+44*cos(theta)**35 + 1.19443212237192e+44*cos(theta)**33 - 5.16511188052722e+43*cos(theta)**31 + 1.83622096670119e+43*cos(theta)**29 - 5.35949469792008e+42*cos(theta)**27 + 1.27971608093194e+42*cos(theta)**25 - 2.4848855940426e+41*cos(theta)**23 + 3.89032212433649e+40*cos(theta)**21 - 4.85423437974251e+39*cos(theta)**19 + 4.75414707294369e+38*cos(theta)**17 - 3.58207203279968e+37*cos(theta)**15 + 2.02213743787079e+36*cos(theta)**13 - 8.25362219539097e+34*cos(theta)**11 + 2.31843320095252e+33*cos(theta)**9 - 4.17109421460723e+31*cos(theta)**7 + 4.29377345621333e+29*cos(theta)**5 - 2.06928841263293e+27*cos(theta)**3 + 2.9477042914999e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl66_m_minus_12(theta, phi):
    return 6.56885348131129e-22*(1.0 - cos(theta)**2)**6*(1.20605317979161e+40*cos(theta)**54 - 1.31745198494793e+41*cos(theta)**52 + 6.77109043426729e+41*cos(theta)**50 - 2.17705663568962e+42*cos(theta)**48 + 4.91143977011577e+42*cos(theta)**46 - 8.26559375946313e+42*cos(theta)**44 + 1.07703191411186e+43*cos(theta)**42 - 1.11323466752739e+43*cos(theta)**40 + 9.27695556272823e+42*cos(theta)**38 - 6.30115918898352e+42*cos(theta)**36 + 3.51303565403506e+42*cos(theta)**34 - 1.61409746266476e+42*cos(theta)**32 + 6.12073655567064e+41*cos(theta)**30 - 1.91410524925717e+41*cos(theta)**28 + 4.9219849266613e+40*cos(theta)**26 - 1.03536899751775e+40*cos(theta)**24 + 1.76832823833477e+39*cos(theta)**22 - 2.42711718987125e+38*cos(theta)**20 + 2.64119281830205e+37*cos(theta)**18 - 2.2387950204998e+36*cos(theta)**16 + 1.44438388419342e+35*cos(theta)**14 - 6.87801849615914e+33*cos(theta)**12 + 2.31843320095252e+32*cos(theta)**10 - 5.21386776825904e+30*cos(theta)**8 + 7.15628909368888e+28*cos(theta)**6 - 5.17322103158232e+26*cos(theta)**4 + 1.47385214574995e+24*cos(theta)**2 - 6.9097615834503e+20)*sin(12*phi)

#@torch.jit.script
def Yl66_m_minus_11(theta, phi):
    return 4.30247366863335e-20*(1.0 - cos(theta)**2)**5.5*(2.19282396325747e+38*cos(theta)**55 - 2.48575846216591e+39*cos(theta)**53 + 1.3276647910328e+40*cos(theta)**51 - 4.44297272589717e+40*cos(theta)**49 + 1.04498718513102e+41*cos(theta)**47 - 1.83679861321403e+41*cos(theta)**45 + 2.50472538165549e+41*cos(theta)**43 - 2.71520650616436e+41*cos(theta)**41 + 2.3787065545457e+41*cos(theta)**39 - 1.70301599702257e+41*cos(theta)**37 + 1.00372447258145e+41*cos(theta)**35 - 4.89120443231745e+40*cos(theta)**33 + 1.97443114699053e+40*cos(theta)**31 - 6.60036292847301e+39*cos(theta)**29 + 1.82295738024493e+39*cos(theta)**27 - 4.141475990071e+38*cos(theta)**25 + 7.68838364493378e+37*cos(theta)**23 - 1.15577009041488e+37*cos(theta)**21 + 1.39010148331687e+36*cos(theta)**19 - 1.31693824735282e+35*cos(theta)**17 + 9.62922589462279e+33*cos(theta)**15 - 5.29078345858395e+32*cos(theta)**13 + 2.10766654632047e+31*cos(theta)**11 - 5.79318640917671e+29*cos(theta)**9 + 1.02232701338413e+28*cos(theta)**7 - 1.03464420631646e+26*cos(theta)**5 + 4.91284048583316e+23*cos(theta)**3 - 6.9097615834503e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl66_m_minus_10(theta, phi):
    return 2.82525464222165e-18*(1.0 - cos(theta)**2)**5*(3.91575707724549e+36*cos(theta)**56 - 4.60325641141836e+37*cos(theta)**54 + 2.55320152121693e+38*cos(theta)**52 - 8.88594545179435e+38*cos(theta)**50 + 2.17705663568962e+39*cos(theta)**48 - 3.99304046350876e+39*cos(theta)**46 + 5.69255768558067e+39*cos(theta)**44 - 6.46477739562943e+39*cos(theta)**42 + 5.94676638636425e+39*cos(theta)**40 - 4.48162104479624e+39*cos(theta)**38 + 2.78812353494846e+39*cos(theta)**36 - 1.4385895389169e+39*cos(theta)**34 + 6.1700973343454e+38*cos(theta)**32 - 2.20012097615767e+38*cos(theta)**30 + 6.51056207230331e+37*cos(theta)**28 - 1.59287538079654e+37*cos(theta)**26 + 3.20349318538908e+36*cos(theta)**24 - 5.25350041097674e+35*cos(theta)**22 + 6.95050741658435e+34*cos(theta)**20 - 7.31632359640457e+33*cos(theta)**18 + 6.01826618413925e+32*cos(theta)**16 - 3.77913104184568e+31*cos(theta)**14 + 1.75638878860039e+30*cos(theta)**12 - 5.79318640917671e+28*cos(theta)**10 + 1.27790876673016e+27*cos(theta)**8 - 1.72440701052744e+25*cos(theta)**6 + 1.22821012145829e+23*cos(theta)**4 - 3.45488079172515e+20*cos(theta)**2 + 1.60244934681129e+17)*sin(10*phi)

#@torch.jit.script
def Yl66_m_minus_9(theta, phi):
    return 1.85952414216614e-16*(1.0 - cos(theta)**2)**4.5*(6.86974925832542e+34*cos(theta)**57 - 8.36955711166975e+35*cos(theta)**55 + 4.81736136078666e+36*cos(theta)**53 - 1.74234224544987e+37*cos(theta)**51 + 4.44297272589717e+37*cos(theta)**49 - 8.49583077342289e+37*cos(theta)**47 + 1.26501281901793e+38*cos(theta)**45 - 1.50343660363475e+38*cos(theta)**43 + 1.4504308259425e+38*cos(theta)**41 - 1.14913360122981e+38*cos(theta)**39 + 7.53546901337422e+37*cos(theta)**37 - 4.11025582547685e+37*cos(theta)**35 + 1.86972646495315e+37*cos(theta)**33 - 7.09716443921829e+36*cos(theta)**31 + 2.24502140424252e+36*cos(theta)**29 - 5.89953844739458e+35*cos(theta)**27 + 1.28139727415563e+35*cos(theta)**25 - 2.28413061346815e+34*cos(theta)**23 + 3.30976543646874e+33*cos(theta)**21 - 3.85069662968662e+32*cos(theta)**19 + 3.54015657890544e+31*cos(theta)**17 - 2.51942069456379e+30*cos(theta)**15 + 1.35106829892338e+29*cos(theta)**13 - 5.26653309925155e+27*cos(theta)**11 + 1.41989862970017e+26*cos(theta)**9 - 2.46343858646777e+24*cos(theta)**7 + 2.45642024291658e+22*cos(theta)**5 - 1.15162693057505e+20*cos(theta)**3 + 1.60244934681129e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl66_m_minus_8(theta, phi):
    return 1.22644040432258e-14*(1.0 - cos(theta)**2)**4*(1.18443952729749e+33*cos(theta)**58 - 1.49456376994103e+34*cos(theta)**56 + 8.92103955701233e+34*cos(theta)**54 - 3.35065816432668e+35*cos(theta)**52 + 8.88594545179435e+35*cos(theta)**50 - 1.7699647444631e+36*cos(theta)**48 + 2.75002786743027e+36*cos(theta)**46 - 3.41690137189716e+36*cos(theta)**44 + 3.45340672843452e+36*cos(theta)**42 - 2.87283400307452e+36*cos(theta)**40 + 1.98301816141427e+36*cos(theta)**38 - 1.14173772929912e+36*cos(theta)**36 + 5.49919548515633e+35*cos(theta)**34 - 2.21786388725572e+35*cos(theta)**32 + 7.4834046808084e+34*cos(theta)**30 - 2.10697801692664e+34*cos(theta)**28 + 4.92845105444473e+33*cos(theta)**26 - 9.51721088945061e+32*cos(theta)**24 + 1.50443883475852e+32*cos(theta)**22 - 1.92534831484331e+31*cos(theta)**20 + 1.96675365494747e+30*cos(theta)**18 - 1.57463793410237e+29*cos(theta)**16 + 9.65048784945271e+27*cos(theta)**14 - 4.38877758270963e+26*cos(theta)**12 + 1.41989862970017e+25*cos(theta)**10 - 3.07929823308471e+23*cos(theta)**8 + 4.0940337381943e+21*cos(theta)**6 - 2.87906732643762e+19*cos(theta)**4 + 8.01224673405647e+16*cos(theta)**2 - 36837916018650.4)*sin(8*phi)

#@torch.jit.script
def Yl66_m_minus_7(theta, phi):
    return 8.10379255740153e-13*(1.0 - cos(theta)**2)**3.5*(2.00752462253811e+31*cos(theta)**59 - 2.62204170165092e+32*cos(theta)**57 + 1.62200719218406e+33*cos(theta)**55 - 6.32199653646543e+33*cos(theta)**53 + 1.74234224544987e+34*cos(theta)**51 - 3.61217294788388e+34*cos(theta)**49 + 5.85112312219207e+34*cos(theta)**47 - 7.59311415977147e+34*cos(theta)**45 + 8.03117843821982e+34*cos(theta)**43 - 7.00691220262077e+34*cos(theta)**41 + 5.08466195234428e+34*cos(theta)**39 - 3.08577764675439e+34*cos(theta)**37 + 1.57119871004467e+34*cos(theta)**35 - 6.72079965835065e+33*cos(theta)**33 + 2.41400150993819e+33*cos(theta)**31 - 7.26544143767806e+32*cos(theta)**29 + 1.82535224238694e+32*cos(theta)**27 - 3.80688435578025e+31*cos(theta)**25 + 6.54103841199355e+30*cos(theta)**23 - 9.16832530877766e+29*cos(theta)**21 + 1.03513350260393e+29*cos(theta)**19 - 9.2625760829551e+27*cos(theta)**17 + 6.43365856630181e+26*cos(theta)**15 - 3.37598275593048e+25*cos(theta)**13 + 1.29081693609107e+24*cos(theta)**11 - 3.42144248120524e+22*cos(theta)**9 + 5.84861962599186e+20*cos(theta)**7 - 5.75813465287525e+18*cos(theta)**5 + 2.67074891135216e+16*cos(theta)**3 - 36837916018650.4*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl66_m_minus_6(theta, phi):
    return 5.36321701689086e-11*(1.0 - cos(theta)**2)**3*(3.34587437089685e+29*cos(theta)**60 - 4.52076155457056e+30*cos(theta)**58 + 2.89644141461439e+31*cos(theta)**56 - 1.17074009934545e+32*cos(theta)**54 + 3.35065816432668e+32*cos(theta)**52 - 7.22434589576776e+32*cos(theta)**50 + 1.21898398379002e+33*cos(theta)**48 - 1.65067699125467e+33*cos(theta)**46 + 1.82526782686814e+33*cos(theta)**44 - 1.66831242919542e+33*cos(theta)**42 + 1.27116548808607e+33*cos(theta)**40 - 8.12046749145892e+32*cos(theta)**38 + 4.36444086123518e+32*cos(theta)**36 - 1.97670578186784e+32*cos(theta)**34 + 7.54375471855686e+31*cos(theta)**32 - 2.42181381255935e+31*cos(theta)**30 + 6.51911515138192e+30*cos(theta)**28 - 1.46418629068471e+30*cos(theta)**26 + 2.72543267166398e+29*cos(theta)**24 - 4.16742059489894e+28*cos(theta)**22 + 5.17566751301965e+27*cos(theta)**20 - 5.14587560164172e+26*cos(theta)**18 + 4.02103660393863e+25*cos(theta)**16 - 2.41141625423606e+24*cos(theta)**14 + 1.07568078007589e+23*cos(theta)**12 - 3.42144248120524e+21*cos(theta)**10 + 7.31077453248982e+19*cos(theta)**8 - 9.59689108812541e+17*cos(theta)**6 + 6.67687227838039e+15*cos(theta)**4 - 18418958009325.2*cos(theta)**2 + 8410483109.28092)*sin(6*phi)

#@torch.jit.script
def Yl66_m_minus_5(theta, phi):
    return 3.5543200899049e-9*(1.0 - cos(theta)**2)**2.5*(5.48503995228992e+27*cos(theta)**61 - 7.66230771961111e+28*cos(theta)**59 + 5.08147616599016e+29*cos(theta)**57 - 2.12861836244627e+30*cos(theta)**55 + 6.32199653646543e+30*cos(theta)**53 - 1.41653841093486e+31*cos(theta)**51 + 2.48772241589799e+31*cos(theta)**49 - 3.51207870479716e+31*cos(theta)**47 + 4.05615072637365e+31*cos(theta)**45 - 3.8797963469661e+31*cos(theta)**43 + 3.10040362947822e+31*cos(theta)**41 - 2.08217115165613e+31*cos(theta)**39 + 1.17957861114464e+31*cos(theta)**37 - 5.64773080533668e+30*cos(theta)**35 + 2.28598627835056e+30*cos(theta)**33 - 7.8123026211592e+29*cos(theta)**31 + 2.24797074185584e+29*cos(theta)**29 - 5.42291218772115e+28*cos(theta)**27 + 1.09017306866559e+28*cos(theta)**25 - 1.81192199778215e+27*cos(theta)**23 + 2.4646035776284e+26*cos(theta)**21 - 2.70835557981143e+25*cos(theta)**19 + 2.36531564937566e+24*cos(theta)**17 - 1.60761083615737e+23*cos(theta)**15 + 8.2744675390453e+21*cos(theta)**13 - 3.11040225564113e+20*cos(theta)**11 + 8.12308281387758e+18*cos(theta)**9 - 1.37098444116077e+17*cos(theta)**7 + 1.33537445567608e+15*cos(theta)**5 - 6139652669775.07*cos(theta)**3 + 8410483109.28092*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl66_m_minus_4(theta, phi):
    return 2.35820499764566e-7*(1.0 - cos(theta)**2)**2*(8.84683863272568e+25*cos(theta)**62 - 1.27705128660185e+27*cos(theta)**60 + 8.76116580343131e+27*cos(theta)**58 - 3.80110421865406e+28*cos(theta)**56 + 1.17074009934545e+29*cos(theta)**54 - 2.72411232872088e+29*cos(theta)**52 + 4.97544483179598e+29*cos(theta)**50 - 7.31683063499409e+29*cos(theta)**48 + 8.81771897037749e+29*cos(theta)**46 - 8.81771897037749e+29*cos(theta)**44 + 7.38191340351956e+29*cos(theta)**42 - 5.20542787914033e+29*cos(theta)**40 + 3.10415423985433e+29*cos(theta)**38 - 1.56881411259352e+29*cos(theta)**36 + 6.72348905397224e+28*cos(theta)**34 - 2.44134456911225e+28*cos(theta)**32 + 7.49323580618612e+27*cos(theta)**30 - 1.93675435275755e+27*cos(theta)**28 + 4.19297334102151e+26*cos(theta)**26 - 7.54967499075894e+25*cos(theta)**24 + 1.12027435346746e+25*cos(theta)**22 - 1.35417778990572e+24*cos(theta)**20 + 1.31406424965315e+23*cos(theta)**18 - 1.00475677259836e+22*cos(theta)**16 + 5.91033395646093e+20*cos(theta)**14 - 2.59200187970094e+19*cos(theta)**12 + 8.12308281387758e+17*cos(theta)**10 - 1.71373055145097e+16*cos(theta)**8 + 222562409279346.0*cos(theta)**6 - 1534913167443.77*cos(theta)**4 + 4205241554.64046*cos(theta)**2 - 1910604.9771197)*sin(4*phi)

#@torch.jit.script
def Yl66_m_minus_3(theta, phi):
    return 1.56603278625198e-5*(1.0 - cos(theta)**2)**1.5*(1.40426010043265e+24*cos(theta)**63 - 2.0935266993473e+25*cos(theta)**61 + 1.48494335651378e+26*cos(theta)**59 - 6.66860389237554e+26*cos(theta)**57 + 2.12861836244627e+27*cos(theta)**55 - 5.13983458249222e+27*cos(theta)**53 + 9.75577417999212e+27*cos(theta)**51 - 1.49323074183553e+28*cos(theta)**49 + 1.87611041922925e+28*cos(theta)**47 - 1.95949310452833e+28*cos(theta)**45 + 1.71672404733013e+28*cos(theta)**43 - 1.26961655588789e+28*cos(theta)**41 + 7.95936984578032e+27*cos(theta)**39 - 4.24003814214466e+27*cos(theta)**37 + 1.9209968725635e+27*cos(theta)**35 - 7.3980138457947e+26*cos(theta)**33 + 2.4171728407052e+26*cos(theta)**31 - 6.67846328537087e+25*cos(theta)**29 + 1.55295308926722e+25*cos(theta)**27 - 3.01986999630358e+24*cos(theta)**25 + 4.87075805855416e+23*cos(theta)**23 - 6.4484656662177e+22*cos(theta)**21 + 6.9161276297534e+21*cos(theta)**19 - 5.91033395646093e+20*cos(theta)**17 + 3.94022263764062e+19*cos(theta)**15 - 1.99384759976995e+18*cos(theta)**13 + 7.38462073988871e+16*cos(theta)**11 - 1.90414505716774e+15*cos(theta)**9 + 31794629897049.5*cos(theta)**7 - 306982633488.754*cos(theta)**5 + 1401747184.88015*cos(theta)**3 - 1910604.9771197*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl66_m_minus_2(theta, phi):
    return 0.00104067562499143*(1.0 - cos(theta)**2)*(2.19415640692601e+22*cos(theta)**64 - 3.37665596668919e+23*cos(theta)**62 + 2.47490559418964e+24*cos(theta)**60 - 1.14975929178889e+25*cos(theta)**58 + 3.80110421865406e+25*cos(theta)**56 - 9.51821218980041e+25*cos(theta)**54 + 1.87611041922925e+26*cos(theta)**52 - 2.98646148367106e+26*cos(theta)**50 + 3.90856337339428e+26*cos(theta)**48 - 4.25976761853985e+26*cos(theta)**46 + 3.90164556211393e+26*cos(theta)**44 - 3.02289656163782e+26*cos(theta)**42 + 1.98984246144508e+26*cos(theta)**40 - 1.1157995110907e+26*cos(theta)**38 + 5.33610242378749e+25*cos(theta)**36 - 2.17588642523374e+25*cos(theta)**34 + 7.55366512720375e+24*cos(theta)**32 - 2.22615442845696e+24*cos(theta)**30 + 5.54626103309723e+23*cos(theta)**28 - 1.16148846011676e+23*cos(theta)**26 + 2.02948252439757e+22*cos(theta)**24 - 2.93112075737168e+21*cos(theta)**22 + 3.4580638148767e+20*cos(theta)**20 - 3.28351886470052e+19*cos(theta)**18 + 2.46263914852539e+18*cos(theta)**16 - 1.42417685697854e+17*cos(theta)**14 + 6.15385061657393e+15*cos(theta)**12 - 190414505716774.0*cos(theta)**10 + 3974328737131.18*cos(theta)**8 - 51163772248.1256*cos(theta)**6 + 350436796.220038*cos(theta)**4 - 955302.48855985*cos(theta)**2 + 432.655112572396)*sin(2*phi)

#@torch.jit.script
def Yl66_m_minus_1(theta, phi):
    return 0.0691873214072833*(1.0 - cos(theta)**2)**0.5*(3.37562524142463e+20*cos(theta)**65 - 5.35977137569713e+21*cos(theta)**63 + 4.05722228555678e+22*cos(theta)**61 - 1.94874456235404e+23*cos(theta)**59 + 6.66860389237554e+23*cos(theta)**57 - 1.73058403450916e+24*cos(theta)**55 + 3.53983097967784e+24*cos(theta)**53 - 5.85580683072756e+24*cos(theta)**51 + 7.97665994570261e+24*cos(theta)**49 - 9.06333535859543e+24*cos(theta)**47 + 8.6703234713643e+24*cos(theta)**45 - 7.02999200380889e+24*cos(theta)**43 + 4.85327429620751e+24*cos(theta)**41 - 2.86102438741205e+24*cos(theta)**39 + 1.44218984426689e+24*cos(theta)**37 - 6.21681835781067e+23*cos(theta)**35 + 2.28898943248598e+23*cos(theta)**33 - 7.18114331760309e+22*cos(theta)**31 + 1.91250380451629e+22*cos(theta)**29 - 4.30180911154356e+21*cos(theta)**27 + 8.11793009759026e+20*cos(theta)**25 - 1.27440032929204e+20*cos(theta)**23 + 1.64669705470319e+19*cos(theta)**21 - 1.72816782352659e+18*cos(theta)**19 + 1.44861126383846e+17*cos(theta)**17 - 9.49451237985691e+15*cos(theta)**15 + 473373124351840.0*cos(theta)**13 - 17310409610615.8*cos(theta)**11 + 441592081903.465*cos(theta)**9 - 7309110321.1608*cos(theta)**7 + 70087359.2440077*cos(theta)**5 - 318434.162853283*cos(theta)**3 + 432.655112572396*cos(theta))*sin(phi)

#@torch.jit.script
def Yl66_m0(theta, phi):
    return 5.22734364262563e+19*cos(theta)**66 - 8.55927642246715e+20*cos(theta)**64 + 6.68817878592782e+21*cos(theta)**62 - 3.31951340792376e+22*cos(theta)**60 + 1.17510774640501e+23*cos(theta)**58 - 3.15846033302029e+23*cos(theta)**56 + 6.69976434277032e+23*cos(theta)**54 - 1.15094391050472e+24*cos(theta)**52 + 1.63050387321502e+24*cos(theta)**50 - 1.92982342481971e+24*cos(theta)**48 + 1.92640780813862e+24*cos(theta)**46 - 1.63295010763593e+24*cos(theta)**44 + 1.18101743258684e+24*cos(theta)**42 - 7.31025168553033e+23*cos(theta)**40 + 3.87890905762834e+23*cos(theta)**38 - 1.76496638673963e+23*cos(theta)**36 + 6.88074767107651e+22*cos(theta)**34 - 2.2935825570255e+22*cos(theta)**32 + 6.51556098673912e+21*cos(theta)**30 - 1.57023214915874e+21*cos(theta)**28 + 3.19111694829033e+20*cos(theta)**26 - 5.42706963994954e+19*cos(theta)**24 + 7.65000623404532e+18*cos(theta)**22 - 8.83134152955757e+17*cos(theta)**20 + 8.22526907164676e+16*cos(theta)**18 - 6.06489719499737e+15*cos(theta)**16 + 345578187749138.0*cos(theta)**14 - 14743373223240.3*cos(theta)**12 + 451327751731.846*cos(theta)**10 - 9337815553.07267*cos(theta)**8 + 119387596.112345*cos(theta)**6 - 813636.502355824*cos(theta)**4 + 2210.9687564017*cos(theta)**2 - 0.999985869019311

#@torch.jit.script
def Yl66_m1(theta, phi):
    return 0.0691873214072833*(1.0 - cos(theta)**2)**0.5*(3.37562524142463e+20*cos(theta)**65 - 5.35977137569713e+21*cos(theta)**63 + 4.05722228555678e+22*cos(theta)**61 - 1.94874456235404e+23*cos(theta)**59 + 6.66860389237554e+23*cos(theta)**57 - 1.73058403450916e+24*cos(theta)**55 + 3.53983097967784e+24*cos(theta)**53 - 5.85580683072756e+24*cos(theta)**51 + 7.97665994570261e+24*cos(theta)**49 - 9.06333535859543e+24*cos(theta)**47 + 8.6703234713643e+24*cos(theta)**45 - 7.02999200380889e+24*cos(theta)**43 + 4.85327429620751e+24*cos(theta)**41 - 2.86102438741205e+24*cos(theta)**39 + 1.44218984426689e+24*cos(theta)**37 - 6.21681835781067e+23*cos(theta)**35 + 2.28898943248598e+23*cos(theta)**33 - 7.18114331760309e+22*cos(theta)**31 + 1.91250380451629e+22*cos(theta)**29 - 4.30180911154356e+21*cos(theta)**27 + 8.11793009759026e+20*cos(theta)**25 - 1.27440032929204e+20*cos(theta)**23 + 1.64669705470319e+19*cos(theta)**21 - 1.72816782352659e+18*cos(theta)**19 + 1.44861126383846e+17*cos(theta)**17 - 9.49451237985691e+15*cos(theta)**15 + 473373124351840.0*cos(theta)**13 - 17310409610615.8*cos(theta)**11 + 441592081903.465*cos(theta)**9 - 7309110321.1608*cos(theta)**7 + 70087359.2440077*cos(theta)**5 - 318434.162853283*cos(theta)**3 + 432.655112572396*cos(theta))*cos(phi)

#@torch.jit.script
def Yl66_m2(theta, phi):
    return 0.00104067562499143*(1.0 - cos(theta)**2)*(2.19415640692601e+22*cos(theta)**64 - 3.37665596668919e+23*cos(theta)**62 + 2.47490559418964e+24*cos(theta)**60 - 1.14975929178889e+25*cos(theta)**58 + 3.80110421865406e+25*cos(theta)**56 - 9.51821218980041e+25*cos(theta)**54 + 1.87611041922925e+26*cos(theta)**52 - 2.98646148367106e+26*cos(theta)**50 + 3.90856337339428e+26*cos(theta)**48 - 4.25976761853985e+26*cos(theta)**46 + 3.90164556211393e+26*cos(theta)**44 - 3.02289656163782e+26*cos(theta)**42 + 1.98984246144508e+26*cos(theta)**40 - 1.1157995110907e+26*cos(theta)**38 + 5.33610242378749e+25*cos(theta)**36 - 2.17588642523374e+25*cos(theta)**34 + 7.55366512720375e+24*cos(theta)**32 - 2.22615442845696e+24*cos(theta)**30 + 5.54626103309723e+23*cos(theta)**28 - 1.16148846011676e+23*cos(theta)**26 + 2.02948252439757e+22*cos(theta)**24 - 2.93112075737168e+21*cos(theta)**22 + 3.4580638148767e+20*cos(theta)**20 - 3.28351886470052e+19*cos(theta)**18 + 2.46263914852539e+18*cos(theta)**16 - 1.42417685697854e+17*cos(theta)**14 + 6.15385061657393e+15*cos(theta)**12 - 190414505716774.0*cos(theta)**10 + 3974328737131.18*cos(theta)**8 - 51163772248.1256*cos(theta)**6 + 350436796.220038*cos(theta)**4 - 955302.48855985*cos(theta)**2 + 432.655112572396)*cos(2*phi)

#@torch.jit.script
def Yl66_m3(theta, phi):
    return 1.56603278625198e-5*(1.0 - cos(theta)**2)**1.5*(1.40426010043265e+24*cos(theta)**63 - 2.0935266993473e+25*cos(theta)**61 + 1.48494335651378e+26*cos(theta)**59 - 6.66860389237554e+26*cos(theta)**57 + 2.12861836244627e+27*cos(theta)**55 - 5.13983458249222e+27*cos(theta)**53 + 9.75577417999212e+27*cos(theta)**51 - 1.49323074183553e+28*cos(theta)**49 + 1.87611041922925e+28*cos(theta)**47 - 1.95949310452833e+28*cos(theta)**45 + 1.71672404733013e+28*cos(theta)**43 - 1.26961655588789e+28*cos(theta)**41 + 7.95936984578032e+27*cos(theta)**39 - 4.24003814214466e+27*cos(theta)**37 + 1.9209968725635e+27*cos(theta)**35 - 7.3980138457947e+26*cos(theta)**33 + 2.4171728407052e+26*cos(theta)**31 - 6.67846328537087e+25*cos(theta)**29 + 1.55295308926722e+25*cos(theta)**27 - 3.01986999630358e+24*cos(theta)**25 + 4.87075805855416e+23*cos(theta)**23 - 6.4484656662177e+22*cos(theta)**21 + 6.9161276297534e+21*cos(theta)**19 - 5.91033395646093e+20*cos(theta)**17 + 3.94022263764062e+19*cos(theta)**15 - 1.99384759976995e+18*cos(theta)**13 + 7.38462073988871e+16*cos(theta)**11 - 1.90414505716774e+15*cos(theta)**9 + 31794629897049.5*cos(theta)**7 - 306982633488.754*cos(theta)**5 + 1401747184.88015*cos(theta)**3 - 1910604.9771197*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl66_m4(theta, phi):
    return 2.35820499764566e-7*(1.0 - cos(theta)**2)**2*(8.84683863272568e+25*cos(theta)**62 - 1.27705128660185e+27*cos(theta)**60 + 8.76116580343131e+27*cos(theta)**58 - 3.80110421865406e+28*cos(theta)**56 + 1.17074009934545e+29*cos(theta)**54 - 2.72411232872088e+29*cos(theta)**52 + 4.97544483179598e+29*cos(theta)**50 - 7.31683063499409e+29*cos(theta)**48 + 8.81771897037749e+29*cos(theta)**46 - 8.81771897037749e+29*cos(theta)**44 + 7.38191340351956e+29*cos(theta)**42 - 5.20542787914033e+29*cos(theta)**40 + 3.10415423985433e+29*cos(theta)**38 - 1.56881411259352e+29*cos(theta)**36 + 6.72348905397224e+28*cos(theta)**34 - 2.44134456911225e+28*cos(theta)**32 + 7.49323580618612e+27*cos(theta)**30 - 1.93675435275755e+27*cos(theta)**28 + 4.19297334102151e+26*cos(theta)**26 - 7.54967499075894e+25*cos(theta)**24 + 1.12027435346746e+25*cos(theta)**22 - 1.35417778990572e+24*cos(theta)**20 + 1.31406424965315e+23*cos(theta)**18 - 1.00475677259836e+22*cos(theta)**16 + 5.91033395646093e+20*cos(theta)**14 - 2.59200187970094e+19*cos(theta)**12 + 8.12308281387758e+17*cos(theta)**10 - 1.71373055145097e+16*cos(theta)**8 + 222562409279346.0*cos(theta)**6 - 1534913167443.77*cos(theta)**4 + 4205241554.64046*cos(theta)**2 - 1910604.9771197)*cos(4*phi)

#@torch.jit.script
def Yl66_m5(theta, phi):
    return 3.5543200899049e-9*(1.0 - cos(theta)**2)**2.5*(5.48503995228992e+27*cos(theta)**61 - 7.66230771961111e+28*cos(theta)**59 + 5.08147616599016e+29*cos(theta)**57 - 2.12861836244627e+30*cos(theta)**55 + 6.32199653646543e+30*cos(theta)**53 - 1.41653841093486e+31*cos(theta)**51 + 2.48772241589799e+31*cos(theta)**49 - 3.51207870479716e+31*cos(theta)**47 + 4.05615072637365e+31*cos(theta)**45 - 3.8797963469661e+31*cos(theta)**43 + 3.10040362947822e+31*cos(theta)**41 - 2.08217115165613e+31*cos(theta)**39 + 1.17957861114464e+31*cos(theta)**37 - 5.64773080533668e+30*cos(theta)**35 + 2.28598627835056e+30*cos(theta)**33 - 7.8123026211592e+29*cos(theta)**31 + 2.24797074185584e+29*cos(theta)**29 - 5.42291218772115e+28*cos(theta)**27 + 1.09017306866559e+28*cos(theta)**25 - 1.81192199778215e+27*cos(theta)**23 + 2.4646035776284e+26*cos(theta)**21 - 2.70835557981143e+25*cos(theta)**19 + 2.36531564937566e+24*cos(theta)**17 - 1.60761083615737e+23*cos(theta)**15 + 8.2744675390453e+21*cos(theta)**13 - 3.11040225564113e+20*cos(theta)**11 + 8.12308281387758e+18*cos(theta)**9 - 1.37098444116077e+17*cos(theta)**7 + 1.33537445567608e+15*cos(theta)**5 - 6139652669775.07*cos(theta)**3 + 8410483109.28092*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl66_m6(theta, phi):
    return 5.36321701689086e-11*(1.0 - cos(theta)**2)**3*(3.34587437089685e+29*cos(theta)**60 - 4.52076155457056e+30*cos(theta)**58 + 2.89644141461439e+31*cos(theta)**56 - 1.17074009934545e+32*cos(theta)**54 + 3.35065816432668e+32*cos(theta)**52 - 7.22434589576776e+32*cos(theta)**50 + 1.21898398379002e+33*cos(theta)**48 - 1.65067699125467e+33*cos(theta)**46 + 1.82526782686814e+33*cos(theta)**44 - 1.66831242919542e+33*cos(theta)**42 + 1.27116548808607e+33*cos(theta)**40 - 8.12046749145892e+32*cos(theta)**38 + 4.36444086123518e+32*cos(theta)**36 - 1.97670578186784e+32*cos(theta)**34 + 7.54375471855686e+31*cos(theta)**32 - 2.42181381255935e+31*cos(theta)**30 + 6.51911515138192e+30*cos(theta)**28 - 1.46418629068471e+30*cos(theta)**26 + 2.72543267166398e+29*cos(theta)**24 - 4.16742059489894e+28*cos(theta)**22 + 5.17566751301965e+27*cos(theta)**20 - 5.14587560164172e+26*cos(theta)**18 + 4.02103660393863e+25*cos(theta)**16 - 2.41141625423606e+24*cos(theta)**14 + 1.07568078007589e+23*cos(theta)**12 - 3.42144248120524e+21*cos(theta)**10 + 7.31077453248982e+19*cos(theta)**8 - 9.59689108812541e+17*cos(theta)**6 + 6.67687227838039e+15*cos(theta)**4 - 18418958009325.2*cos(theta)**2 + 8410483109.28092)*cos(6*phi)

#@torch.jit.script
def Yl66_m7(theta, phi):
    return 8.10379255740153e-13*(1.0 - cos(theta)**2)**3.5*(2.00752462253811e+31*cos(theta)**59 - 2.62204170165092e+32*cos(theta)**57 + 1.62200719218406e+33*cos(theta)**55 - 6.32199653646543e+33*cos(theta)**53 + 1.74234224544987e+34*cos(theta)**51 - 3.61217294788388e+34*cos(theta)**49 + 5.85112312219207e+34*cos(theta)**47 - 7.59311415977147e+34*cos(theta)**45 + 8.03117843821982e+34*cos(theta)**43 - 7.00691220262077e+34*cos(theta)**41 + 5.08466195234428e+34*cos(theta)**39 - 3.08577764675439e+34*cos(theta)**37 + 1.57119871004467e+34*cos(theta)**35 - 6.72079965835065e+33*cos(theta)**33 + 2.41400150993819e+33*cos(theta)**31 - 7.26544143767806e+32*cos(theta)**29 + 1.82535224238694e+32*cos(theta)**27 - 3.80688435578025e+31*cos(theta)**25 + 6.54103841199355e+30*cos(theta)**23 - 9.16832530877766e+29*cos(theta)**21 + 1.03513350260393e+29*cos(theta)**19 - 9.2625760829551e+27*cos(theta)**17 + 6.43365856630181e+26*cos(theta)**15 - 3.37598275593048e+25*cos(theta)**13 + 1.29081693609107e+24*cos(theta)**11 - 3.42144248120524e+22*cos(theta)**9 + 5.84861962599186e+20*cos(theta)**7 - 5.75813465287525e+18*cos(theta)**5 + 2.67074891135216e+16*cos(theta)**3 - 36837916018650.4*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl66_m8(theta, phi):
    return 1.22644040432258e-14*(1.0 - cos(theta)**2)**4*(1.18443952729749e+33*cos(theta)**58 - 1.49456376994103e+34*cos(theta)**56 + 8.92103955701233e+34*cos(theta)**54 - 3.35065816432668e+35*cos(theta)**52 + 8.88594545179435e+35*cos(theta)**50 - 1.7699647444631e+36*cos(theta)**48 + 2.75002786743027e+36*cos(theta)**46 - 3.41690137189716e+36*cos(theta)**44 + 3.45340672843452e+36*cos(theta)**42 - 2.87283400307452e+36*cos(theta)**40 + 1.98301816141427e+36*cos(theta)**38 - 1.14173772929912e+36*cos(theta)**36 + 5.49919548515633e+35*cos(theta)**34 - 2.21786388725572e+35*cos(theta)**32 + 7.4834046808084e+34*cos(theta)**30 - 2.10697801692664e+34*cos(theta)**28 + 4.92845105444473e+33*cos(theta)**26 - 9.51721088945061e+32*cos(theta)**24 + 1.50443883475852e+32*cos(theta)**22 - 1.92534831484331e+31*cos(theta)**20 + 1.96675365494747e+30*cos(theta)**18 - 1.57463793410237e+29*cos(theta)**16 + 9.65048784945271e+27*cos(theta)**14 - 4.38877758270963e+26*cos(theta)**12 + 1.41989862970017e+25*cos(theta)**10 - 3.07929823308471e+23*cos(theta)**8 + 4.0940337381943e+21*cos(theta)**6 - 2.87906732643762e+19*cos(theta)**4 + 8.01224673405647e+16*cos(theta)**2 - 36837916018650.4)*cos(8*phi)

#@torch.jit.script
def Yl66_m9(theta, phi):
    return 1.85952414216614e-16*(1.0 - cos(theta)**2)**4.5*(6.86974925832542e+34*cos(theta)**57 - 8.36955711166975e+35*cos(theta)**55 + 4.81736136078666e+36*cos(theta)**53 - 1.74234224544987e+37*cos(theta)**51 + 4.44297272589717e+37*cos(theta)**49 - 8.49583077342289e+37*cos(theta)**47 + 1.26501281901793e+38*cos(theta)**45 - 1.50343660363475e+38*cos(theta)**43 + 1.4504308259425e+38*cos(theta)**41 - 1.14913360122981e+38*cos(theta)**39 + 7.53546901337422e+37*cos(theta)**37 - 4.11025582547685e+37*cos(theta)**35 + 1.86972646495315e+37*cos(theta)**33 - 7.09716443921829e+36*cos(theta)**31 + 2.24502140424252e+36*cos(theta)**29 - 5.89953844739458e+35*cos(theta)**27 + 1.28139727415563e+35*cos(theta)**25 - 2.28413061346815e+34*cos(theta)**23 + 3.30976543646874e+33*cos(theta)**21 - 3.85069662968662e+32*cos(theta)**19 + 3.54015657890544e+31*cos(theta)**17 - 2.51942069456379e+30*cos(theta)**15 + 1.35106829892338e+29*cos(theta)**13 - 5.26653309925155e+27*cos(theta)**11 + 1.41989862970017e+26*cos(theta)**9 - 2.46343858646777e+24*cos(theta)**7 + 2.45642024291658e+22*cos(theta)**5 - 1.15162693057505e+20*cos(theta)**3 + 1.60244934681129e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl66_m10(theta, phi):
    return 2.82525464222165e-18*(1.0 - cos(theta)**2)**5*(3.91575707724549e+36*cos(theta)**56 - 4.60325641141836e+37*cos(theta)**54 + 2.55320152121693e+38*cos(theta)**52 - 8.88594545179435e+38*cos(theta)**50 + 2.17705663568962e+39*cos(theta)**48 - 3.99304046350876e+39*cos(theta)**46 + 5.69255768558067e+39*cos(theta)**44 - 6.46477739562943e+39*cos(theta)**42 + 5.94676638636425e+39*cos(theta)**40 - 4.48162104479624e+39*cos(theta)**38 + 2.78812353494846e+39*cos(theta)**36 - 1.4385895389169e+39*cos(theta)**34 + 6.1700973343454e+38*cos(theta)**32 - 2.20012097615767e+38*cos(theta)**30 + 6.51056207230331e+37*cos(theta)**28 - 1.59287538079654e+37*cos(theta)**26 + 3.20349318538908e+36*cos(theta)**24 - 5.25350041097674e+35*cos(theta)**22 + 6.95050741658435e+34*cos(theta)**20 - 7.31632359640457e+33*cos(theta)**18 + 6.01826618413925e+32*cos(theta)**16 - 3.77913104184568e+31*cos(theta)**14 + 1.75638878860039e+30*cos(theta)**12 - 5.79318640917671e+28*cos(theta)**10 + 1.27790876673016e+27*cos(theta)**8 - 1.72440701052744e+25*cos(theta)**6 + 1.22821012145829e+23*cos(theta)**4 - 3.45488079172515e+20*cos(theta)**2 + 1.60244934681129e+17)*cos(10*phi)

#@torch.jit.script
def Yl66_m11(theta, phi):
    return 4.30247366863335e-20*(1.0 - cos(theta)**2)**5.5*(2.19282396325747e+38*cos(theta)**55 - 2.48575846216591e+39*cos(theta)**53 + 1.3276647910328e+40*cos(theta)**51 - 4.44297272589717e+40*cos(theta)**49 + 1.04498718513102e+41*cos(theta)**47 - 1.83679861321403e+41*cos(theta)**45 + 2.50472538165549e+41*cos(theta)**43 - 2.71520650616436e+41*cos(theta)**41 + 2.3787065545457e+41*cos(theta)**39 - 1.70301599702257e+41*cos(theta)**37 + 1.00372447258145e+41*cos(theta)**35 - 4.89120443231745e+40*cos(theta)**33 + 1.97443114699053e+40*cos(theta)**31 - 6.60036292847301e+39*cos(theta)**29 + 1.82295738024493e+39*cos(theta)**27 - 4.141475990071e+38*cos(theta)**25 + 7.68838364493378e+37*cos(theta)**23 - 1.15577009041488e+37*cos(theta)**21 + 1.39010148331687e+36*cos(theta)**19 - 1.31693824735282e+35*cos(theta)**17 + 9.62922589462279e+33*cos(theta)**15 - 5.29078345858395e+32*cos(theta)**13 + 2.10766654632047e+31*cos(theta)**11 - 5.79318640917671e+29*cos(theta)**9 + 1.02232701338413e+28*cos(theta)**7 - 1.03464420631646e+26*cos(theta)**5 + 4.91284048583316e+23*cos(theta)**3 - 6.9097615834503e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl66_m12(theta, phi):
    return 6.56885348131129e-22*(1.0 - cos(theta)**2)**6*(1.20605317979161e+40*cos(theta)**54 - 1.31745198494793e+41*cos(theta)**52 + 6.77109043426729e+41*cos(theta)**50 - 2.17705663568962e+42*cos(theta)**48 + 4.91143977011577e+42*cos(theta)**46 - 8.26559375946313e+42*cos(theta)**44 + 1.07703191411186e+43*cos(theta)**42 - 1.11323466752739e+43*cos(theta)**40 + 9.27695556272823e+42*cos(theta)**38 - 6.30115918898352e+42*cos(theta)**36 + 3.51303565403506e+42*cos(theta)**34 - 1.61409746266476e+42*cos(theta)**32 + 6.12073655567064e+41*cos(theta)**30 - 1.91410524925717e+41*cos(theta)**28 + 4.9219849266613e+40*cos(theta)**26 - 1.03536899751775e+40*cos(theta)**24 + 1.76832823833477e+39*cos(theta)**22 - 2.42711718987125e+38*cos(theta)**20 + 2.64119281830205e+37*cos(theta)**18 - 2.2387950204998e+36*cos(theta)**16 + 1.44438388419342e+35*cos(theta)**14 - 6.87801849615914e+33*cos(theta)**12 + 2.31843320095252e+32*cos(theta)**10 - 5.21386776825904e+30*cos(theta)**8 + 7.15628909368888e+28*cos(theta)**6 - 5.17322103158232e+26*cos(theta)**4 + 1.47385214574995e+24*cos(theta)**2 - 6.9097615834503e+20)*cos(12*phi)

#@torch.jit.script
def Yl66_m13(theta, phi):
    return 1.00572477683751e-23*(1.0 - cos(theta)**2)**6.5*(6.5126871708747e+41*cos(theta)**53 - 6.85075032172926e+42*cos(theta)**51 + 3.38554521713365e+43*cos(theta)**49 - 1.04498718513102e+44*cos(theta)**47 + 2.25926229425326e+44*cos(theta)**45 - 3.63686125416378e+44*cos(theta)**43 + 4.52353403926982e+44*cos(theta)**41 - 4.45293867010955e+44*cos(theta)**39 + 3.52524311383673e+44*cos(theta)**37 - 2.26841730803407e+44*cos(theta)**35 + 1.19443212237192e+44*cos(theta)**33 - 5.16511188052722e+43*cos(theta)**31 + 1.83622096670119e+43*cos(theta)**29 - 5.35949469792008e+42*cos(theta)**27 + 1.27971608093194e+42*cos(theta)**25 - 2.4848855940426e+41*cos(theta)**23 + 3.89032212433649e+40*cos(theta)**21 - 4.85423437974251e+39*cos(theta)**19 + 4.75414707294369e+38*cos(theta)**17 - 3.58207203279968e+37*cos(theta)**15 + 2.02213743787079e+36*cos(theta)**13 - 8.25362219539097e+34*cos(theta)**11 + 2.31843320095252e+33*cos(theta)**9 - 4.17109421460723e+31*cos(theta)**7 + 4.29377345621333e+29*cos(theta)**5 - 2.06928841263293e+27*cos(theta)**3 + 2.9477042914999e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl66_m14(theta, phi):
    return 1.54452954822549e-25*(1.0 - cos(theta)**2)**7*(3.45172420056359e+43*cos(theta)**52 - 3.49388266408192e+44*cos(theta)**50 + 1.65891715639549e+45*cos(theta)**48 - 4.91143977011577e+45*cos(theta)**46 + 1.01666803241396e+46*cos(theta)**44 - 1.56385033929042e+46*cos(theta)**42 + 1.85464895610063e+46*cos(theta)**40 - 1.73664608134272e+46*cos(theta)**38 + 1.30433995211959e+46*cos(theta)**36 - 7.93946057811923e+45*cos(theta)**34 + 3.94162600382734e+45*cos(theta)**32 - 1.60118468296344e+45*cos(theta)**30 + 5.32504080343346e+44*cos(theta)**28 - 1.44706356843842e+44*cos(theta)**26 + 3.19929020232985e+43*cos(theta)**24 - 5.71523686629798e+42*cos(theta)**22 + 8.16967646110664e+41*cos(theta)**20 - 9.22304532151076e+40*cos(theta)**18 + 8.08205002400428e+39*cos(theta)**16 - 5.37310804919952e+38*cos(theta)**14 + 2.62877866923202e+37*cos(theta)**12 - 9.07898441493006e+35*cos(theta)**10 + 2.08658988085727e+34*cos(theta)**8 - 2.91976595022506e+32*cos(theta)**6 + 2.14688672810666e+30*cos(theta)**4 - 6.20786523789878e+27*cos(theta)**2 + 2.9477042914999e+24)*cos(14*phi)

#@torch.jit.script
def Yl66_m15(theta, phi):
    return 2.37986345410096e-27*(1.0 - cos(theta)**2)**7.5*(1.79489658429307e+45*cos(theta)**51 - 1.74694133204096e+46*cos(theta)**49 + 7.96280235069834e+46*cos(theta)**47 - 2.25926229425326e+47*cos(theta)**45 + 4.47333934262145e+47*cos(theta)**43 - 6.56817142501978e+47*cos(theta)**41 + 7.41859582440251e+47*cos(theta)**39 - 6.59925510910235e+47*cos(theta)**37 + 4.69562382763052e+47*cos(theta)**35 - 2.69941659656054e+47*cos(theta)**33 + 1.26132032122475e+47*cos(theta)**31 - 4.80355404889032e+46*cos(theta)**29 + 1.49101142496137e+46*cos(theta)**27 - 3.7623652779399e+45*cos(theta)**25 + 7.67829648559163e+44*cos(theta)**23 - 1.25735211058556e+44*cos(theta)**21 + 1.63393529222133e+43*cos(theta)**19 - 1.66014815787194e+42*cos(theta)**17 + 1.29312800384068e+41*cos(theta)**15 - 7.52235126887933e+39*cos(theta)**13 + 3.15453440307843e+38*cos(theta)**11 - 9.07898441493006e+36*cos(theta)**9 + 1.66927190468581e+35*cos(theta)**7 - 1.75185957013504e+33*cos(theta)**5 + 8.58754691242665e+30*cos(theta)**3 - 1.24157304757976e+28*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl66_m16(theta, phi):
    return 3.68010343751003e-29*(1.0 - cos(theta)**2)**8*(9.15397257989464e+46*cos(theta)**50 - 8.56001252700071e+47*cos(theta)**48 + 3.74251710482822e+48*cos(theta)**46 - 1.01666803241396e+49*cos(theta)**44 + 1.92353591732722e+49*cos(theta)**42 - 2.69295028425811e+49*cos(theta)**40 + 2.89325237151698e+49*cos(theta)**38 - 2.44172439036787e+49*cos(theta)**36 + 1.64346833967068e+49*cos(theta)**34 - 8.90807476864978e+48*cos(theta)**32 + 3.91009299579672e+48*cos(theta)**30 - 1.39303067417819e+48*cos(theta)**28 + 4.02573084739569e+47*cos(theta)**26 - 9.40591319484975e+46*cos(theta)**24 + 1.76600819168608e+46*cos(theta)**22 - 2.64043943222967e+45*cos(theta)**20 + 3.10447705522052e+44*cos(theta)**18 - 2.82225186838229e+43*cos(theta)**16 + 1.93969200576103e+42*cos(theta)**14 - 9.77905664954312e+40*cos(theta)**12 + 3.46998784338627e+39*cos(theta)**10 - 8.17108597343706e+37*cos(theta)**8 + 1.16849033328007e+36*cos(theta)**6 - 8.75929785067518e+33*cos(theta)**4 + 2.576264073728e+31*cos(theta)**2 - 1.24157304757976e+28)*cos(16*phi)

#@torch.jit.script
def Yl66_m17(theta, phi):
    return 5.71262843535419e-31*(1.0 - cos(theta)**2)**8.5*(4.57698628994732e+48*cos(theta)**49 - 4.10880601296034e+49*cos(theta)**47 + 1.72155786822098e+50*cos(theta)**45 - 4.47333934262145e+50*cos(theta)**43 + 8.07885085277433e+50*cos(theta)**41 - 1.07718011370324e+51*cos(theta)**39 + 1.09943590117645e+51*cos(theta)**37 - 8.79020780532433e+50*cos(theta)**35 + 5.58779235488032e+50*cos(theta)**33 - 2.85058392596793e+50*cos(theta)**31 + 1.17302789873902e+50*cos(theta)**29 - 3.90048588769894e+49*cos(theta)**27 + 1.04669002032288e+49*cos(theta)**25 - 2.25741916676394e+48*cos(theta)**23 + 3.88521802170937e+47*cos(theta)**21 - 5.28087886445933e+46*cos(theta)**19 + 5.58805869939694e+45*cos(theta)**17 - 4.51560298941167e+44*cos(theta)**15 + 2.71556880806544e+43*cos(theta)**13 - 1.17348679794518e+42*cos(theta)**11 + 3.46998784338627e+40*cos(theta)**9 - 6.53686877874965e+38*cos(theta)**7 + 7.01094199968042e+36*cos(theta)**5 - 3.50371914027007e+34*cos(theta)**3 + 5.15252814745599e+31*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl66_m18(theta, phi):
    return 8.90426946332235e-33*(1.0 - cos(theta)**2)**9*(2.24272328207419e+50*cos(theta)**48 - 1.93113882609136e+51*cos(theta)**46 + 7.74701040699441e+51*cos(theta)**44 - 1.92353591732722e+52*cos(theta)**42 + 3.31232884963748e+52*cos(theta)**40 - 4.20100244344265e+52*cos(theta)**38 + 4.06791283435287e+52*cos(theta)**36 - 3.07657273186352e+52*cos(theta)**34 + 1.8439714771105e+52*cos(theta)**32 - 8.83681017050058e+51*cos(theta)**30 + 3.40178090634314e+51*cos(theta)**28 - 1.05313118967871e+51*cos(theta)**26 + 2.6167250508072e+50*cos(theta)**24 - 5.19206408355706e+49*cos(theta)**22 + 8.15895784558967e+48*cos(theta)**20 - 1.00336698424727e+48*cos(theta)**18 + 9.4996997889748e+46*cos(theta)**16 - 6.7734044841175e+45*cos(theta)**14 + 3.53023945048507e+44*cos(theta)**12 - 1.29083547773969e+43*cos(theta)**10 + 3.12298905904764e+41*cos(theta)**8 - 4.57580814512475e+39*cos(theta)**6 + 3.50547099984021e+37*cos(theta)**4 - 1.05111574208102e+35*cos(theta)**2 + 5.15252814745599e+31)*cos(18*phi)

#@torch.jit.script
def Yl66_m19(theta, phi):
    return 1.39401745807505e-34*(1.0 - cos(theta)**2)**9.5*(1.07650717539561e+52*cos(theta)**47 - 8.88323860002026e+52*cos(theta)**45 + 3.40868457907754e+53*cos(theta)**43 - 8.07885085277433e+53*cos(theta)**41 + 1.32493153985499e+54*cos(theta)**39 - 1.59638092850821e+54*cos(theta)**37 + 1.46444862036703e+54*cos(theta)**35 - 1.0460347288336e+54*cos(theta)**33 + 5.90070872675361e+53*cos(theta)**31 - 2.65104305115017e+53*cos(theta)**29 + 9.5249865377608e+52*cos(theta)**27 - 2.73814109316465e+52*cos(theta)**25 + 6.28014012193728e+51*cos(theta)**23 - 1.14225409838255e+51*cos(theta)**21 + 1.63179156911793e+50*cos(theta)**19 - 1.80606057164509e+49*cos(theta)**17 + 1.51995196623597e+48*cos(theta)**15 - 9.48276627776451e+46*cos(theta)**13 + 4.23628734058208e+45*cos(theta)**11 - 1.29083547773969e+44*cos(theta)**9 + 2.49839124723811e+42*cos(theta)**7 - 2.74548488707485e+40*cos(theta)**5 + 1.40218839993608e+38*cos(theta)**3 - 2.10223148416204e+35*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl66_m20(theta, phi):
    return 2.19265376043663e-36*(1.0 - cos(theta)**2)**10*(5.05958372435937e+53*cos(theta)**46 - 3.99745737000912e+54*cos(theta)**44 + 1.46573436900334e+55*cos(theta)**42 - 3.31232884963748e+55*cos(theta)**40 + 5.16723300543446e+55*cos(theta)**38 - 5.90660943548037e+55*cos(theta)**36 + 5.12557017128462e+55*cos(theta)**34 - 3.45191460515086e+55*cos(theta)**32 + 1.82921970529362e+55*cos(theta)**30 - 7.68802484833551e+54*cos(theta)**28 + 2.57174636519542e+54*cos(theta)**26 - 6.84535273291163e+53*cos(theta)**24 + 1.44443222804557e+53*cos(theta)**22 - 2.39873360660336e+52*cos(theta)**20 + 3.10040398132407e+51*cos(theta)**18 - 3.07030297179666e+50*cos(theta)**16 + 2.27992794935395e+49*cos(theta)**14 - 1.23275961610939e+48*cos(theta)**12 + 4.65991607464029e+46*cos(theta)**10 - 1.16175192996572e+45*cos(theta)**8 + 1.74887387306668e+43*cos(theta)**6 - 1.37274244353743e+41*cos(theta)**4 + 4.20656519980825e+38*cos(theta)**2 - 2.10223148416204e+35)*cos(20*phi)

#@torch.jit.script
def Yl66_m21(theta, phi):
    return 3.46602360394165e-38*(1.0 - cos(theta)**2)**10.5*(2.32740851320531e+55*cos(theta)**45 - 1.75888124280401e+56*cos(theta)**43 + 6.15608434981404e+56*cos(theta)**41 - 1.32493153985499e+57*cos(theta)**39 + 1.9635485420651e+57*cos(theta)**37 - 2.12637939677293e+57*cos(theta)**35 + 1.74269385823677e+57*cos(theta)**33 - 1.10461267364828e+57*cos(theta)**31 + 5.48765911588086e+56*cos(theta)**29 - 2.15264695753394e+56*cos(theta)**27 + 6.68654054950809e+55*cos(theta)**25 - 1.64288465589879e+55*cos(theta)**23 + 3.17775090170026e+54*cos(theta)**21 - 4.79746721320672e+53*cos(theta)**19 + 5.58072716638333e+52*cos(theta)**17 - 4.91248475487465e+51*cos(theta)**15 + 3.19189912909553e+50*cos(theta)**13 - 1.47931153933126e+49*cos(theta)**11 + 4.65991607464029e+47*cos(theta)**9 - 9.29401543972579e+45*cos(theta)**7 + 1.04932432384001e+44*cos(theta)**5 - 5.4909697741497e+41*cos(theta)**3 + 8.4131303996165e+38*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl66_m22(theta, phi):
    return 5.50787306633424e-40*(1.0 - cos(theta)**2)**11*(1.04733383094239e+57*cos(theta)**44 - 7.56318934405725e+57*cos(theta)**42 + 2.52399458342376e+58*cos(theta)**40 - 5.16723300543446e+58*cos(theta)**38 + 7.26512960564085e+58*cos(theta)**36 - 7.44232788870526e+58*cos(theta)**34 + 5.75088973218134e+58*cos(theta)**32 - 3.42429928830966e+58*cos(theta)**30 + 1.59142114360545e+58*cos(theta)**28 - 5.81214678534164e+57*cos(theta)**26 + 1.67163513737702e+57*cos(theta)**24 - 3.77863470856722e+56*cos(theta)**22 + 6.67327689357055e+55*cos(theta)**20 - 9.11518770509278e+54*cos(theta)**18 + 9.48723618285166e+53*cos(theta)**16 - 7.36872713231197e+52*cos(theta)**14 + 4.14946886782419e+51*cos(theta)**12 - 1.62724269326439e+50*cos(theta)**10 + 4.19392446717626e+48*cos(theta)**8 - 6.50581080780805e+46*cos(theta)**6 + 5.24662161920004e+44*cos(theta)**4 - 1.64729093224491e+42*cos(theta)**2 + 8.4131303996165e+38)*cos(22*phi)

#@torch.jit.script
def Yl66_m23(theta, phi):
    return 8.8016193309476e-42*(1.0 - cos(theta)**2)**11.5*(4.60826885614651e+58*cos(theta)**43 - 3.17653952450404e+59*cos(theta)**41 + 1.0095978333695e+60*cos(theta)**39 - 1.9635485420651e+60*cos(theta)**37 + 2.61544665803071e+60*cos(theta)**35 - 2.53039148215979e+60*cos(theta)**33 + 1.84028471429803e+60*cos(theta)**31 - 1.0272897864929e+60*cos(theta)**29 + 4.45597920209526e+59*cos(theta)**27 - 1.51115816418883e+59*cos(theta)**25 + 4.01192432970485e+58*cos(theta)**23 - 8.31299635884789e+57*cos(theta)**21 + 1.33465537871411e+57*cos(theta)**19 - 1.6407337869167e+56*cos(theta)**17 + 1.51795778925627e+55*cos(theta)**15 - 1.03162179852368e+54*cos(theta)**13 + 4.97936264138903e+52*cos(theta)**11 - 1.62724269326439e+51*cos(theta)**9 + 3.35513957374101e+49*cos(theta)**7 - 3.90348648468483e+47*cos(theta)**5 + 2.09864864768002e+45*cos(theta)**3 - 3.29458186448982e+42*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl66_m24(theta, phi):
    return 1.41483924860861e-43*(1.0 - cos(theta)**2)**12*(1.981555608143e+60*cos(theta)**42 - 1.30238120504666e+61*cos(theta)**40 + 3.93743155014106e+61*cos(theta)**38 - 7.26512960564085e+61*cos(theta)**36 + 9.15406330310748e+61*cos(theta)**34 - 8.35029189112731e+61*cos(theta)**32 + 5.70488261432389e+61*cos(theta)**30 - 2.9791403808294e+61*cos(theta)**28 + 1.20311438456572e+61*cos(theta)**26 - 3.77789541047207e+60*cos(theta)**24 + 9.22742595832116e+59*cos(theta)**22 - 1.74572923535806e+59*cos(theta)**20 + 2.53584521955681e+58*cos(theta)**18 - 2.78924743775839e+57*cos(theta)**16 + 2.2769366838844e+56*cos(theta)**14 - 1.34110833808078e+55*cos(theta)**12 + 5.47729890552793e+53*cos(theta)**10 - 1.46451842393795e+52*cos(theta)**8 + 2.34859770161871e+50*cos(theta)**6 - 1.95174324234241e+48*cos(theta)**4 + 6.29594594304005e+45*cos(theta)**2 - 3.29458186448982e+42)*cos(24*phi)

#@torch.jit.script
def Yl66_m25(theta, phi):
    return 2.28855712600846e-45*(1.0 - cos(theta)**2)**12.5*(8.3225335542006e+61*cos(theta)**41 - 5.20952482018663e+62*cos(theta)**39 + 1.4962239890536e+63*cos(theta)**37 - 2.61544665803071e+63*cos(theta)**35 + 3.11238152305654e+63*cos(theta)**33 - 2.67209340516074e+63*cos(theta)**31 + 1.71146478429717e+63*cos(theta)**29 - 8.34159306632233e+62*cos(theta)**27 + 3.12809739987087e+62*cos(theta)**25 - 9.06694898513296e+61*cos(theta)**23 + 2.03003371083065e+61*cos(theta)**21 - 3.49145847071611e+60*cos(theta)**19 + 4.56452139520226e+59*cos(theta)**17 - 4.46279590041342e+58*cos(theta)**15 + 3.18771135743816e+57*cos(theta)**13 - 1.60933000569693e+56*cos(theta)**11 + 5.47729890552793e+54*cos(theta)**9 - 1.17161473915036e+53*cos(theta)**7 + 1.40915862097122e+51*cos(theta)**5 - 7.80697296936966e+48*cos(theta)**3 + 1.25918918860801e+46*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl66_m26(theta, phi):
    return 3.72628368957836e-47*(1.0 - cos(theta)**2)**13*(3.41223875722224e+63*cos(theta)**40 - 2.03171467987279e+64*cos(theta)**38 + 5.53602875949833e+64*cos(theta)**36 - 9.15406330310747e+64*cos(theta)**34 + 1.02708590260866e+65*cos(theta)**32 - 8.28348955599829e+64*cos(theta)**30 + 4.96324787446178e+64*cos(theta)**28 - 2.25223012790703e+64*cos(theta)**26 + 7.82024349967718e+63*cos(theta)**24 - 2.08539826658058e+63*cos(theta)**22 + 4.26307079274438e+62*cos(theta)**20 - 6.63377109436062e+61*cos(theta)**18 + 7.75968637184384e+60*cos(theta)**16 - 6.69419385062013e+59*cos(theta)**14 + 4.14402476466961e+58*cos(theta)**12 - 1.77026300626663e+57*cos(theta)**10 + 4.92956901497514e+55*cos(theta)**8 - 8.20130317405252e+53*cos(theta)**6 + 7.04579310485612e+51*cos(theta)**4 - 2.3420918908109e+49*cos(theta)**2 + 1.25918918860801e+46)*cos(26*phi)

#@torch.jit.script
def Yl66_m27(theta, phi):
    return 6.1094827877146e-49*(1.0 - cos(theta)**2)**13.5*(1.3648955028889e+65*cos(theta)**39 - 7.72051578351659e+65*cos(theta)**37 + 1.9929703534194e+66*cos(theta)**35 - 3.11238152305654e+66*cos(theta)**33 + 3.28667488834771e+66*cos(theta)**31 - 2.48504686679949e+66*cos(theta)**29 + 1.3897094048493e+66*cos(theta)**27 - 5.85579833255827e+65*cos(theta)**25 + 1.87685843992252e+65*cos(theta)**23 - 4.58787618647728e+64*cos(theta)**21 + 8.52614158548875e+63*cos(theta)**19 - 1.19407879698491e+63*cos(theta)**17 + 1.24154981949501e+62*cos(theta)**15 - 9.37187139086819e+60*cos(theta)**13 + 4.97282971760353e+59*cos(theta)**11 - 1.77026300626663e+58*cos(theta)**9 + 3.94365521198011e+56*cos(theta)**7 - 4.92078190443151e+54*cos(theta)**5 + 2.81831724194245e+52*cos(theta)**3 - 4.6841837816218e+49*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl66_m28(theta, phi):
    return 1.00903961098423e-50*(1.0 - cos(theta)**2)**14*(5.3230924612667e+66*cos(theta)**38 - 2.85659083990114e+67*cos(theta)**36 + 6.9753962369679e+67*cos(theta)**34 - 1.02708590260866e+68*cos(theta)**32 + 1.01886921538779e+68*cos(theta)**30 - 7.20663591371851e+67*cos(theta)**28 + 3.75221539309311e+67*cos(theta)**26 - 1.46394958313957e+67*cos(theta)**24 + 4.3167744118218e+66*cos(theta)**22 - 9.63453999160229e+65*cos(theta)**20 + 1.61996690124286e+65*cos(theta)**18 - 2.02993395487435e+64*cos(theta)**16 + 1.86232472924252e+63*cos(theta)**14 - 1.21834328081286e+62*cos(theta)**12 + 5.47011268936388e+60*cos(theta)**10 - 1.59323670563997e+59*cos(theta)**8 + 2.76055864838608e+57*cos(theta)**6 - 2.46039095221576e+55*cos(theta)**4 + 8.45495172582734e+52*cos(theta)**2 - 4.6841837816218e+49)*cos(28*phi)

#@torch.jit.script
def Yl66_m29(theta, phi):
    return 1.67940180002128e-52*(1.0 - cos(theta)**2)**14.5*(2.02277513528135e+68*cos(theta)**37 - 1.02837270236441e+69*cos(theta)**35 + 2.37163472056908e+69*cos(theta)**33 - 3.28667488834771e+69*cos(theta)**31 + 3.05660764616337e+69*cos(theta)**29 - 2.01785805584118e+69*cos(theta)**27 + 9.75576002204208e+68*cos(theta)**25 - 3.51347899953496e+68*cos(theta)**23 + 9.49690370600797e+67*cos(theta)**21 - 1.92690799832046e+67*cos(theta)**19 + 2.91594042223715e+66*cos(theta)**17 - 3.24789432779896e+65*cos(theta)**15 + 2.60725462093953e+64*cos(theta)**13 - 1.46201193697544e+63*cos(theta)**11 + 5.47011268936388e+61*cos(theta)**9 - 1.27458936451197e+60*cos(theta)**7 + 1.65633518903165e+58*cos(theta)**5 - 9.84156380886303e+55*cos(theta)**3 + 1.69099034516547e+53*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl66_m30(theta, phi):
    return 2.81785171805404e-54*(1.0 - cos(theta)**2)**15*(7.48426800054098e+69*cos(theta)**36 - 3.59930445827543e+70*cos(theta)**34 + 7.82639457787798e+70*cos(theta)**32 - 1.01886921538779e+71*cos(theta)**30 + 8.86416217387377e+70*cos(theta)**28 - 5.44821675077119e+70*cos(theta)**26 + 2.43894000551052e+70*cos(theta)**24 - 8.08100169893042e+69*cos(theta)**22 + 1.99434977826167e+69*cos(theta)**20 - 3.66112519680887e+68*cos(theta)**18 + 4.95709871780316e+67*cos(theta)**16 - 4.87184149169844e+66*cos(theta)**14 + 3.38943100722139e+65*cos(theta)**12 - 1.60821313067298e+64*cos(theta)**10 + 4.92310142042749e+62*cos(theta)**8 - 8.92212555158381e+60*cos(theta)**6 + 8.28167594515824e+58*cos(theta)**4 - 2.95246914265891e+56*cos(theta)**2 + 1.69099034516547e+53)*cos(30*phi)

#@torch.jit.script
def Yl66_m31(theta, phi):
    return 4.76849155973558e-56*(1.0 - cos(theta)**2)**15.5*(2.69433648019475e+71*cos(theta)**35 - 1.22376351581365e+72*cos(theta)**33 + 2.50444626492095e+72*cos(theta)**31 - 3.05660764616337e+72*cos(theta)**29 + 2.48196540868465e+72*cos(theta)**27 - 1.41653635520051e+72*cos(theta)**25 + 5.85345601322525e+71*cos(theta)**23 - 1.77782037376469e+71*cos(theta)**21 + 3.98869955652335e+70*cos(theta)**19 - 6.59002535425596e+69*cos(theta)**17 + 7.93135794848505e+68*cos(theta)**15 - 6.82057808837781e+67*cos(theta)**13 + 4.06731720866567e+66*cos(theta)**11 - 1.60821313067298e+65*cos(theta)**9 + 3.93848113634199e+63*cos(theta)**7 - 5.35327533095028e+61*cos(theta)**5 + 3.31267037806329e+59*cos(theta)**3 - 5.90493828531782e+56*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl66_m32(theta, phi):
    return 8.14205362223649e-58*(1.0 - cos(theta)**2)**16*(9.43017768068164e+72*cos(theta)**34 - 4.03841960218504e+73*cos(theta)**32 + 7.76378342125496e+73*cos(theta)**30 - 8.86416217387377e+73*cos(theta)**28 + 6.70130660344857e+73*cos(theta)**26 - 3.54134088800128e+73*cos(theta)**24 + 1.34629488304181e+73*cos(theta)**22 - 3.73342278490585e+72*cos(theta)**20 + 7.57852915739436e+71*cos(theta)**18 - 1.12030431022351e+71*cos(theta)**16 + 1.18970369227276e+70*cos(theta)**14 - 8.86675151489115e+68*cos(theta)**12 + 4.47404892953223e+67*cos(theta)**10 - 1.44739181760568e+66*cos(theta)**8 + 2.7569367954394e+64*cos(theta)**6 - 2.67663766547514e+62*cos(theta)**4 + 9.93801113418988e+59*cos(theta)**2 - 5.90493828531782e+56)*cos(32*phi)

#@torch.jit.script
def Yl66_m33(theta, phi):
    return 1.40338523311262e-59*(1.0 - cos(theta)**2)**16.5*(3.20626041143176e+74*cos(theta)**33 - 1.29229427269921e+75*cos(theta)**31 + 2.32913502637649e+75*cos(theta)**29 - 2.48196540868465e+75*cos(theta)**27 + 1.74233971689663e+75*cos(theta)**25 - 8.49921813120306e+74*cos(theta)**23 + 2.96184874269198e+74*cos(theta)**21 - 7.46684556981171e+73*cos(theta)**19 + 1.36413524833098e+73*cos(theta)**17 - 1.79248689635762e+72*cos(theta)**15 + 1.66558516918186e+71*cos(theta)**13 - 1.06401018178694e+70*cos(theta)**11 + 4.47404892953223e+68*cos(theta)**9 - 1.15791345408455e+67*cos(theta)**7 + 1.65416207726364e+65*cos(theta)**5 - 1.07065506619006e+63*cos(theta)**3 + 1.98760222683798e+60*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl66_m34(theta, phi):
    return 2.44298011783085e-61*(1.0 - cos(theta)**2)**17*(1.05806593577248e+76*cos(theta)**32 - 4.00611224536756e+76*cos(theta)**30 + 6.75449157649181e+76*cos(theta)**28 - 6.70130660344857e+76*cos(theta)**26 + 4.35584929224157e+76*cos(theta)**24 - 1.9548201701767e+76*cos(theta)**22 + 6.21988235965315e+75*cos(theta)**20 - 1.41870065826422e+75*cos(theta)**18 + 2.31902992216267e+74*cos(theta)**16 - 2.68873034453643e+73*cos(theta)**14 + 2.16526071993642e+72*cos(theta)**12 - 1.17041119996563e+71*cos(theta)**10 + 4.02664403657901e+69*cos(theta)**8 - 8.10539417859183e+67*cos(theta)**6 + 8.27081038631819e+65*cos(theta)**4 - 3.21196519857017e+63*cos(theta)**2 + 1.98760222683798e+60)*cos(34*phi)

#@torch.jit.script
def Yl66_m35(theta, phi):
    return 4.29718703182676e-63*(1.0 - cos(theta)**2)**17.5*(3.38581099447194e+77*cos(theta)**31 - 1.20183367361027e+78*cos(theta)**29 + 1.89125764141771e+78*cos(theta)**27 - 1.74233971689663e+78*cos(theta)**25 + 1.04540383013798e+78*cos(theta)**23 - 4.30060437438875e+77*cos(theta)**21 + 1.24397647193063e+77*cos(theta)**19 - 2.5536611848756e+76*cos(theta)**17 + 3.71044787546028e+75*cos(theta)**15 - 3.76422248235101e+74*cos(theta)**13 + 2.5983128639237e+73*cos(theta)**11 - 1.17041119996563e+72*cos(theta)**9 + 3.22131522926321e+70*cos(theta)**7 - 4.8632365071551e+68*cos(theta)**5 + 3.30832415452728e+66*cos(theta)**3 - 6.42393039714034e+63*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl66_m36(theta, phi):
    return 7.64193472281181e-65*(1.0 - cos(theta)**2)**18*(1.0496014082863e+79*cos(theta)**30 - 3.48531765346977e+79*cos(theta)**28 + 5.10639563182781e+79*cos(theta)**26 - 4.35584929224157e+79*cos(theta)**24 + 2.40442880931735e+79*cos(theta)**22 - 9.03126918621637e+78*cos(theta)**20 + 2.3635552966682e+78*cos(theta)**18 - 4.34122401428853e+77*cos(theta)**16 + 5.56567181319042e+76*cos(theta)**14 - 4.89348922705631e+75*cos(theta)**12 + 2.85814415031607e+74*cos(theta)**10 - 1.05337007996907e+73*cos(theta)**8 + 2.25492066048425e+71*cos(theta)**6 - 2.43161825357755e+69*cos(theta)**4 + 9.92497246358183e+66*cos(theta)**2 - 6.42393039714034e+63)*cos(36*phi)

#@torch.jit.script
def Yl66_m37(theta, phi):
    return 1.37475112555243e-66*(1.0 - cos(theta)**2)**18.5*(3.1488042248589e+80*cos(theta)**29 - 9.75888942971537e+80*cos(theta)**27 + 1.32766286427523e+81*cos(theta)**25 - 1.04540383013798e+81*cos(theta)**23 + 5.28974338049816e+80*cos(theta)**21 - 1.80625383724327e+80*cos(theta)**19 + 4.25439953400275e+79*cos(theta)**17 - 6.94595842286164e+78*cos(theta)**15 + 7.79194053846658e+77*cos(theta)**13 - 5.87218707246757e+76*cos(theta)**11 + 2.85814415031607e+75*cos(theta)**9 - 8.42696063975255e+73*cos(theta)**7 + 1.35295239629055e+72*cos(theta)**5 - 9.72647301431019e+69*cos(theta)**3 + 1.98499449271637e+67*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl66_m38(theta, phi):
    return 2.50327415386636e-68*(1.0 - cos(theta)**2)**19*(9.13153225209081e+81*cos(theta)**28 - 2.63490014602315e+82*cos(theta)**26 + 3.31915716068808e+82*cos(theta)**24 - 2.40442880931735e+82*cos(theta)**22 + 1.11084610990461e+82*cos(theta)**20 - 3.43188229076222e+81*cos(theta)**18 + 7.23247920780468e+80*cos(theta)**16 - 1.04189376342925e+80*cos(theta)**14 + 1.01295227000066e+79*cos(theta)**12 - 6.45940577971433e+77*cos(theta)**10 + 2.57232973528447e+76*cos(theta)**8 - 5.89887244782679e+74*cos(theta)**6 + 6.76476198145274e+72*cos(theta)**4 - 2.91794190429306e+70*cos(theta)**2 + 1.98499449271637e+67)*cos(38*phi)

#@torch.jit.script
def Yl66_m39(theta, phi):
    return 4.61673290900756e-70*(1.0 - cos(theta)**2)**19.5*(2.55682903058543e+83*cos(theta)**27 - 6.85074037966019e+83*cos(theta)**25 + 7.96597718565138e+83*cos(theta)**23 - 5.28974338049816e+83*cos(theta)**21 + 2.22169221980923e+83*cos(theta)**19 - 6.177388123372e+82*cos(theta)**17 + 1.15719667324875e+82*cos(theta)**15 - 1.45865126880094e+81*cos(theta)**13 + 1.21554272400079e+80*cos(theta)**11 - 6.45940577971433e+78*cos(theta)**9 + 2.05786378822757e+77*cos(theta)**7 - 3.53932346869607e+75*cos(theta)**5 + 2.70590479258109e+73*cos(theta)**3 - 5.83588380858611e+70*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl66_m40(theta, phi):
    return 8.62978419417266e-72*(1.0 - cos(theta)**2)**20*(6.90343838258065e+84*cos(theta)**26 - 1.71268509491505e+85*cos(theta)**24 + 1.83217475269982e+85*cos(theta)**22 - 1.11084610990461e+85*cos(theta)**20 + 4.22121521763753e+84*cos(theta)**18 - 1.05015598097324e+84*cos(theta)**16 + 1.73579500987312e+83*cos(theta)**14 - 1.89624664944123e+82*cos(theta)**12 + 1.33709699640087e+81*cos(theta)**10 - 5.81346520174289e+79*cos(theta)**8 + 1.4405046517593e+78*cos(theta)**6 - 1.76966173434804e+76*cos(theta)**4 + 8.11771437774329e+73*cos(theta)**2 - 5.83588380858611e+70)*cos(40*phi)

#@torch.jit.script
def Yl66_m41(theta, phi):
    return 1.63614342931156e-73*(1.0 - cos(theta)**2)**20.5*(1.79489397947097e+86*cos(theta)**25 - 4.11044422779611e+86*cos(theta)**23 + 4.0307844559396e+86*cos(theta)**21 - 2.22169221980923e+86*cos(theta)**19 + 7.59818739174756e+85*cos(theta)**17 - 1.68024956955718e+85*cos(theta)**15 + 2.43011301382237e+84*cos(theta)**13 - 2.27549597932947e+83*cos(theta)**11 + 1.33709699640087e+82*cos(theta)**9 - 4.65077216139432e+80*cos(theta)**7 + 8.64302791055581e+78*cos(theta)**5 - 7.07864693739214e+76*cos(theta)**3 + 1.62354287554866e+74*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl66_m42(theta, phi):
    return 3.14875949781955e-75*(1.0 - cos(theta)**2)**21*(4.48723494867742e+87*cos(theta)**24 - 9.45402172393106e+87*cos(theta)**22 + 8.46464735747316e+87*cos(theta)**20 - 4.22121521763753e+87*cos(theta)**18 + 1.29169185659709e+87*cos(theta)**16 - 2.52037435433578e+86*cos(theta)**14 + 3.15914691796909e+85*cos(theta)**12 - 2.50304557726242e+84*cos(theta)**10 + 1.20338729676078e+83*cos(theta)**8 - 3.25554051297602e+81*cos(theta)**6 + 4.3215139552779e+79*cos(theta)**4 - 2.12359408121764e+77*cos(theta)**2 + 1.62354287554866e+74)*cos(42*phi)

#@torch.jit.script
def Yl66_m43(theta, phi):
    return 6.15631198648028e-77*(1.0 - cos(theta)**2)**21.5*(1.07693638768258e+89*cos(theta)**23 - 2.07988477926483e+89*cos(theta)**21 + 1.69292947149463e+89*cos(theta)**19 - 7.59818739174756e+88*cos(theta)**17 + 2.06670697055534e+88*cos(theta)**15 - 3.52852409607009e+87*cos(theta)**13 + 3.7909763015629e+86*cos(theta)**11 - 2.50304557726242e+85*cos(theta)**9 + 9.62709837408623e+83*cos(theta)**7 - 1.95332430778561e+82*cos(theta)**5 + 1.72860558211116e+80*cos(theta)**3 - 4.24718816243529e+77*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl66_m44(theta, phi):
    return 1.22394065310672e-78*(1.0 - cos(theta)**2)**22*(2.47695369166994e+90*cos(theta)**22 - 4.36775803645615e+90*cos(theta)**20 + 3.2165659958398e+90*cos(theta)**18 - 1.29169185659709e+90*cos(theta)**16 + 3.100060455833e+89*cos(theta)**14 - 4.58708132489111e+88*cos(theta)**12 + 4.17007393171919e+87*cos(theta)**10 - 2.25274101953618e+86*cos(theta)**8 + 6.73896886186036e+84*cos(theta)**6 - 9.76662153892806e+82*cos(theta)**4 + 5.18581674633348e+80*cos(theta)**2 - 4.24718816243529e+77)*cos(44*phi)

#@torch.jit.script
def Yl66_m45(theta, phi):
    return 2.47678055999563e-80*(1.0 - cos(theta)**2)**22.5*(5.44929812167386e+91*cos(theta)**21 - 8.7355160729123e+91*cos(theta)**19 + 5.78981879251164e+91*cos(theta)**17 - 2.06670697055534e+91*cos(theta)**15 + 4.34008463816621e+90*cos(theta)**13 - 5.50449758986933e+89*cos(theta)**11 + 4.17007393171919e+88*cos(theta)**9 - 1.80219281562894e+87*cos(theta)**7 + 4.04338131711622e+85*cos(theta)**5 - 3.90664861557123e+83*cos(theta)**3 + 1.0371633492667e+81*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl66_m46(theta, phi):
    return 5.10703543941824e-82*(1.0 - cos(theta)**2)**23*(1.14435260555151e+93*cos(theta)**20 - 1.65974805385334e+93*cos(theta)**18 + 9.84269194726979e+92*cos(theta)**16 - 3.100060455833e+92*cos(theta)**14 + 5.64211002961607e+91*cos(theta)**12 - 6.05494734885627e+90*cos(theta)**10 + 3.75306653854727e+89*cos(theta)**8 - 1.26153497094026e+88*cos(theta)**6 + 2.02169065855811e+86*cos(theta)**4 - 1.17199458467137e+84*cos(theta)**2 + 1.0371633492667e+81)*cos(46*phi)

#@torch.jit.script
def Yl66_m47(theta, phi):
    return 1.07427297867911e-83*(1.0 - cos(theta)**2)**23.5*(2.28870521110302e+94*cos(theta)**19 - 2.98754649693601e+94*cos(theta)**17 + 1.57483071156317e+94*cos(theta)**15 - 4.34008463816621e+93*cos(theta)**13 + 6.77053203553928e+92*cos(theta)**11 - 6.05494734885627e+91*cos(theta)**9 + 3.00245323083782e+90*cos(theta)**7 - 7.56920982564156e+88*cos(theta)**5 + 8.08676263423244e+86*cos(theta)**3 - 2.34398916934274e+84*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl66_m48(theta, phi):
    return 2.30826372124878e-85*(1.0 - cos(theta)**2)**24*(4.34853990109574e+95*cos(theta)**18 - 5.07882904479121e+95*cos(theta)**16 + 2.36224606734475e+95*cos(theta)**14 - 5.64211002961607e+94*cos(theta)**12 + 7.44758523909321e+93*cos(theta)**10 - 5.44945261397064e+92*cos(theta)**8 + 2.10171726158647e+91*cos(theta)**6 - 3.78460491282078e+89*cos(theta)**4 + 2.42602879026973e+87*cos(theta)**2 - 2.34398916934274e+84)*cos(48*phi)

#@torch.jit.script
def Yl66_m49(theta, phi):
    return 5.07341341746446e-87*(1.0 - cos(theta)**2)**24.5*(7.82737182197234e+96*cos(theta)**17 - 8.12612647166594e+96*cos(theta)**15 + 3.30714449428265e+96*cos(theta)**13 - 6.77053203553928e+95*cos(theta)**11 + 7.44758523909321e+94*cos(theta)**9 - 4.35956209117651e+93*cos(theta)**7 + 1.26103035695188e+92*cos(theta)**5 - 1.51384196512831e+90*cos(theta)**3 + 4.85205758053946e+87*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl66_m50(theta, phi):
    return 1.14247524295103e-88*(1.0 - cos(theta)**2)**25*(1.3306532097353e+98*cos(theta)**16 - 1.21891897074989e+98*cos(theta)**14 + 4.29928784256744e+97*cos(theta)**12 - 7.44758523909321e+96*cos(theta)**10 + 6.70282671518389e+95*cos(theta)**8 - 3.05169346382356e+94*cos(theta)**6 + 6.30515178475942e+92*cos(theta)**4 - 4.54152589538494e+90*cos(theta)**2 + 4.85205758053946e+87)*cos(50*phi)

#@torch.jit.script
def Yl66_m51(theta, phi):
    return 2.64054683936417e-90*(1.0 - cos(theta)**2)**25.5*(2.12904513557648e+99*cos(theta)**15 - 1.70648655904985e+99*cos(theta)**13 + 5.15914541108093e+98*cos(theta)**11 - 7.44758523909321e+97*cos(theta)**9 + 5.36226137214711e+96*cos(theta)**7 - 1.83101607829414e+95*cos(theta)**5 + 2.52206071390377e+93*cos(theta)**3 - 9.08305179076987e+90*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl66_m52(theta, phi):
    return 6.27635127858387e-92*(1.0 - cos(theta)**2)**26*(3.19356770336471e+100*cos(theta)**14 - 2.2184325267648e+100*cos(theta)**12 + 5.67505995218903e+99*cos(theta)**10 - 6.70282671518389e+98*cos(theta)**8 + 3.75358296050298e+97*cos(theta)**6 - 9.15508039147068e+95*cos(theta)**4 + 7.5661821417113e+93*cos(theta)**2 - 9.08305179076987e+90)*cos(52*phi)

#@torch.jit.script
def Yl66_m53(theta, phi):
    return 1.53769337733501e-93*(1.0 - cos(theta)**2)**26.5*(4.4709947847106e+101*cos(theta)**13 - 2.66211903211776e+101*cos(theta)**11 + 5.67505995218903e+100*cos(theta)**9 - 5.36226137214711e+99*cos(theta)**7 + 2.25214977630179e+98*cos(theta)**5 - 3.66203215658827e+96*cos(theta)**3 + 1.51323642834226e+94*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl66_m54(theta, phi):
    return 3.89320654432752e-95*(1.0 - cos(theta)**2)**27*(5.81229322012378e+102*cos(theta)**12 - 2.92833093532954e+102*cos(theta)**10 + 5.10755395697012e+101*cos(theta)**8 - 3.75358296050298e+100*cos(theta)**6 + 1.12607488815089e+99*cos(theta)**4 - 1.09860964697648e+97*cos(theta)**2 + 1.51323642834226e+94)*cos(54*phi)

#@torch.jit.script
def Yl66_m55(theta, phi):
    return 1.02170174835378e-96*(1.0 - cos(theta)**2)**27.5*(6.97475186414853e+103*cos(theta)**11 - 2.92833093532954e+103*cos(theta)**9 + 4.0860431655761e+102*cos(theta)**7 - 2.25214977630179e+101*cos(theta)**5 + 4.50429955260357e+99*cos(theta)**3 - 2.19721929395296e+97*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl66_m56(theta, phi):
    return 2.78899591805326e-98*(1.0 - cos(theta)**2)**28*(7.67222705056339e+104*cos(theta)**10 - 2.63549784179658e+104*cos(theta)**8 + 2.86023021590327e+103*cos(theta)**6 - 1.12607488815089e+102*cos(theta)**4 + 1.35128986578107e+100*cos(theta)**2 - 2.19721929395296e+97)*cos(56*phi)

#@torch.jit.script
def Yl66_m57(theta, phi):
    return 7.95234701302649e-100*(1.0 - cos(theta)**2)**28.5*(7.67222705056339e+105*cos(theta)**9 - 2.10839827343727e+105*cos(theta)**7 + 1.71613812954196e+104*cos(theta)**5 - 4.50429955260357e+102*cos(theta)**3 + 2.70257973156214e+100*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl66_m58(theta, phi):
    return 2.38047281182724e-101*(1.0 - cos(theta)**2)**29*(6.90500434550705e+106*cos(theta)**8 - 1.47587879140609e+106*cos(theta)**6 + 8.58069064770981e+104*cos(theta)**4 - 1.35128986578107e+103*cos(theta)**2 + 2.70257973156214e+100)*cos(58*phi)

#@torch.jit.script
def Yl66_m59(theta, phi):
    return 7.52771599347949e-103*(1.0 - cos(theta)**2)**29.5*(5.52400347640564e+107*cos(theta)**7 - 8.85527274843652e+106*cos(theta)**5 + 3.43227625908392e+105*cos(theta)**3 - 2.70257973156214e+103*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl66_m60(theta, phi):
    return 2.53471382182656e-104*(1.0 - cos(theta)**2)**30*(3.86680243348395e+108*cos(theta)**6 - 4.42763637421826e+107*cos(theta)**4 + 1.02968287772518e+106*cos(theta)**2 - 2.70257973156214e+103)*cos(60*phi)

#@torch.jit.script
def Yl66_m61(theta, phi):
    return 9.18229935818876e-106*(1.0 - cos(theta)**2)**30.5*(2.32008146009037e+109*cos(theta)**5 - 1.7710545496873e+108*cos(theta)**3 + 2.05936575545035e+106*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl66_m62(theta, phi):
    return 3.62962251617235e-107*(1.0 - cos(theta)**2)**31*(1.16004073004518e+110*cos(theta)**4 - 5.31316364906191e+108*cos(theta)**2 + 2.05936575545035e+106)*cos(62*phi)

#@torch.jit.script
def Yl66_m63(theta, phi):
    return 1.59785221699192e-108*(1.0 - cos(theta)**2)**31.5*(4.64016292018074e+110*cos(theta)**3 - 1.06263272981238e+109*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl66_m64(theta, phi):
    return 8.09103921464814e-110*(1.0 - cos(theta)**2)**32*(1.39204887605422e+111*cos(theta)**2 - 1.06263272981238e+109)*cos(64*phi)

#@torch.jit.script
def Yl66_m65(theta, phi):
    return 13.9167600751205*(1.0 - cos(theta)**2)**32.5*cos(65*phi)*cos(theta)

#@torch.jit.script
def Yl66_m66(theta, phi):
    return 1.21129848618741*(1.0 - cos(theta)**2)**33*cos(66*phi)

#@torch.jit.script
def Yl67_m_minus_67(theta, phi):
    return 1.21580985556888*(1.0 - cos(theta)**2)**33.5*sin(67*phi)

#@torch.jit.script
def Yl67_m_minus_66(theta, phi):
    return 14.0740165928703*(1.0 - cos(theta)**2)**33*sin(66*phi)*cos(theta)

#@torch.jit.script
def Yl67_m_minus_65(theta, phi):
    return 6.19901598722085e-112*(1.0 - cos(theta)**2)**32.5*(1.85142500515211e+113*cos(theta)**2 - 1.39204887605422e+111)*sin(65*phi)

#@torch.jit.script
def Yl67_m_minus_64(theta, phi):
    return 1.23358860594157e-110*(1.0 - cos(theta)**2)**32*(6.17141668384038e+112*cos(theta)**3 - 1.39204887605422e+111*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl67_m_minus_63(theta, phi):
    return 2.82381338746639e-109*(1.0 - cos(theta)**2)**31.5*(1.5428541709601e+112*cos(theta)**4 - 6.96024438027111e+110*cos(theta)**2 + 2.65658182453096e+108)*sin(63*phi)

#@torch.jit.script
def Yl67_m_minus_62(theta, phi):
    return 7.19933978271784e-108*(1.0 - cos(theta)**2)**31*(3.08570834192019e+111*cos(theta)**5 - 2.32008146009037e+110*cos(theta)**3 + 2.65658182453096e+108*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl67_m_minus_61(theta, phi):
    return 2.00291791693111e-106*(1.0 - cos(theta)**2)**30.5*(5.14284723653365e+110*cos(theta)**6 - 5.80020365022592e+109*cos(theta)**4 + 1.32829091226548e+108*cos(theta)**2 - 3.43227625908392e+105)*sin(61*phi)

#@torch.jit.script
def Yl67_m_minus_60(theta, phi):
    return 5.99538609518972e-105*(1.0 - cos(theta)**2)**30*(7.3469246236195e+109*cos(theta)**7 - 1.16004073004518e+109*cos(theta)**5 + 4.42763637421826e+107*cos(theta)**3 - 3.43227625908392e+105*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl67_m_minus_59(theta, phi):
    return 1.91101462321146e-103*(1.0 - cos(theta)**2)**29.5*(9.18365577952438e+108*cos(theta)**8 - 1.93340121674197e+108*cos(theta)**6 + 1.10690909355457e+107*cos(theta)**4 - 1.71613812954196e+105*cos(theta)**2 + 3.37822466445268e+102)*sin(59*phi)

#@torch.jit.script
def Yl67_m_minus_58(theta, phi):
    return 6.43532578305497e-102*(1.0 - cos(theta)**2)**29*(1.02040619772493e+108*cos(theta)**9 - 2.76200173820282e+107*cos(theta)**7 + 2.21381818710913e+106*cos(theta)**5 - 5.72046043180654e+104*cos(theta)**3 + 3.37822466445268e+102*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl67_m_minus_57(theta, phi):
    return 2.2752312501714e-100*(1.0 - cos(theta)**2)**28.5*(1.02040619772493e+107*cos(theta)**10 - 3.45250217275352e+106*cos(theta)**8 + 3.68969697851522e+105*cos(theta)**6 - 1.43011510795163e+104*cos(theta)**4 + 1.68911233222634e+102*cos(theta)**2 - 2.70257973156214e+99)*sin(57*phi)

#@torch.jit.script
def Yl67_m_minus_56(theta, phi):
    return 8.40296837894555e-99*(1.0 - cos(theta)**2)**28*(9.27641997931755e+105*cos(theta)**11 - 3.83611352528169e+105*cos(theta)**9 + 5.27099568359317e+104*cos(theta)**7 - 2.86023021590327e+103*cos(theta)**5 + 5.63037444075447e+101*cos(theta)**3 - 2.70257973156214e+99*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl67_m_minus_55(theta, phi):
    return 3.22831502961648e-97*(1.0 - cos(theta)**2)**27.5*(7.73034998276463e+104*cos(theta)**12 - 3.83611352528169e+104*cos(theta)**10 + 6.58874460449146e+103*cos(theta)**8 - 4.76705035983878e+102*cos(theta)**6 + 1.40759361018862e+101*cos(theta)**4 - 1.35128986578107e+99*cos(theta)**2 + 1.83101607829414e+96)*sin(55*phi)

#@torch.jit.script
def Yl67_m_minus_54(theta, phi):
    return 1.28566404778581e-95*(1.0 - cos(theta)**2)**27*(5.9464230636651e+103*cos(theta)**13 - 3.48737593207427e+103*cos(theta)**11 + 7.32082733832384e+102*cos(theta)**9 - 6.81007194262683e+101*cos(theta)**7 + 2.81518722037723e+100*cos(theta)**5 - 4.50429955260357e+98*cos(theta)**3 + 1.83101607829414e+96*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl67_m_minus_53(theta, phi):
    return 5.29156581943822e-94*(1.0 - cos(theta)**2)**26.5*(4.24744504547507e+102*cos(theta)**14 - 2.90614661006189e+102*cos(theta)**12 + 7.32082733832384e+101*cos(theta)**10 - 8.51258992828354e+100*cos(theta)**8 + 4.69197870062872e+99*cos(theta)**6 - 1.12607488815089e+98*cos(theta)**4 + 9.15508039147068e+95*cos(theta)**2 - 1.08088316310161e+93)*sin(53*phi)

#@torch.jit.script
def Yl67_m_minus_52(theta, phi):
    return 2.24502124441183e-92*(1.0 - cos(theta)**2)**26*(2.83163003031671e+101*cos(theta)**15 - 2.2354973923553e+101*cos(theta)**13 + 6.6552975802944e+100*cos(theta)**11 - 9.45843325364838e+99*cos(theta)**9 + 6.70282671518389e+98*cos(theta)**7 - 2.25214977630179e+97*cos(theta)**5 + 3.05169346382356e+95*cos(theta)**3 - 1.08088316310161e+93*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl67_m_minus_51(theta, phi):
    return 9.79611617861195e-91*(1.0 - cos(theta)**2)**25.5*(1.76976876894795e+100*cos(theta)**16 - 1.59678385168236e+100*cos(theta)**14 + 5.546081316912e+99*cos(theta)**12 - 9.45843325364838e+98*cos(theta)**10 + 8.37853339397986e+97*cos(theta)**8 - 3.75358296050298e+96*cos(theta)**6 + 7.6292336595589e+94*cos(theta)**4 - 5.40441581550807e+92*cos(theta)**2 + 5.67690736923117e+89)*sin(51*phi)

#@torch.jit.script
def Yl67_m_minus_50(theta, phi):
    return 4.38752285148277e-89*(1.0 - cos(theta)**2)**25*(1.04104045232232e+99*cos(theta)**17 - 1.06452256778824e+99*cos(theta)**15 + 4.26621639762462e+98*cos(theta)**13 - 8.59857568513489e+97*cos(theta)**11 + 9.30948154886651e+96*cos(theta)**9 - 5.36226137214711e+95*cos(theta)**7 + 1.52584673191178e+94*cos(theta)**5 - 1.80147193850269e+92*cos(theta)**3 + 5.67690736923117e+89*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl67_m_minus_49(theta, phi):
    return 2.01348581724404e-87*(1.0 - cos(theta)**2)**24.5*(5.78355806845734e+97*cos(theta)**18 - 6.65326604867649e+97*cos(theta)**16 + 3.04729742687473e+97*cos(theta)**14 - 7.16547973761241e+96*cos(theta)**12 + 9.30948154886651e+95*cos(theta)**10 - 6.70282671518389e+94*cos(theta)**8 + 2.54307788651963e+93*cos(theta)**6 - 4.50367984625673e+91*cos(theta)**4 + 2.83845368461559e+89*cos(theta)**2 - 2.69558754474415e+86)*sin(49*phi)

#@torch.jit.script
def Yl67_m_minus_48(theta, phi):
    return 9.45266724278357e-86*(1.0 - cos(theta)**2)**24*(3.04397793076702e+96*cos(theta)**19 - 3.91368591098617e+96*cos(theta)**17 + 2.03153161791648e+96*cos(theta)**15 - 5.51190749047108e+95*cos(theta)**13 + 8.4631650444241e+94*cos(theta)**11 - 7.44758523909321e+93*cos(theta)**9 + 3.63296840931376e+92*cos(theta)**7 - 9.00735969251346e+90*cos(theta)**5 + 9.46151228205195e+88*cos(theta)**3 - 2.69558754474415e+86*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl67_m_minus_47(theta, phi):
    return 4.5333399542327e-84*(1.0 - cos(theta)**2)**23.5*(1.52198896538351e+95*cos(theta)**20 - 2.17426995054787e+95*cos(theta)**18 + 1.2697072611978e+95*cos(theta)**16 - 3.93707677890792e+94*cos(theta)**14 + 7.05263753702009e+93*cos(theta)**12 - 7.44758523909321e+92*cos(theta)**10 + 4.5412105116422e+91*cos(theta)**8 - 1.50122661541891e+90*cos(theta)**6 + 2.36537807051299e+88*cos(theta)**4 - 1.34779377237207e+86*cos(theta)**2 + 1.17199458467137e+83)*sin(47*phi)

#@torch.jit.script
def Yl67_m_minus_46(theta, phi):
    return 2.21809611402884e-82*(1.0 - cos(theta)**2)**23*(7.24756650182624e+93*cos(theta)**21 - 1.14435260555151e+94*cos(theta)**19 + 7.46886624234002e+93*cos(theta)**17 - 2.62471785260528e+93*cos(theta)**15 + 5.42510579770776e+92*cos(theta)**13 - 6.77053203553928e+91*cos(theta)**11 + 5.04578945738022e+90*cos(theta)**9 - 2.14460945059844e+89*cos(theta)**7 + 4.73075614102598e+87*cos(theta)**5 - 4.49264590790691e+85*cos(theta)**3 + 1.17199458467137e+83*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl67_m_minus_45(theta, phi):
    return 1.10593836277071e-80*(1.0 - cos(theta)**2)**22.5*(3.29434840992102e+92*cos(theta)**22 - 5.72176302775756e+92*cos(theta)**20 + 4.14937013463334e+92*cos(theta)**18 - 1.6404486578783e+92*cos(theta)**16 + 3.87507556979126e+91*cos(theta)**14 - 5.64211002961607e+90*cos(theta)**12 + 5.04578945738022e+89*cos(theta)**10 - 2.68076181324805e+88*cos(theta)**8 + 7.88459356837663e+86*cos(theta)**6 - 1.12316147697673e+85*cos(theta)**4 + 5.85997292335684e+82*cos(theta)**2 - 4.71437886030317e+79)*sin(45*phi)

#@torch.jit.script
def Yl67_m_minus_44(theta, phi):
    return 5.61311386838957e-79*(1.0 - cos(theta)**2)**22*(1.43232539561783e+91*cos(theta)**23 - 2.72464906083693e+91*cos(theta)**21 + 2.18387901822807e+91*cos(theta)**19 - 9.6496979875194e+90*cos(theta)**17 + 2.58338371319417e+90*cos(theta)**15 - 4.34008463816621e+89*cos(theta)**13 + 4.58708132489111e+88*cos(theta)**11 - 2.97862423694228e+87*cos(theta)**9 + 1.12637050976809e+86*cos(theta)**7 - 2.24632295395345e+84*cos(theta)**5 + 1.95332430778561e+82*cos(theta)**3 - 4.71437886030317e+79*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl67_m_minus_43(theta, phi):
    return 2.8971498754101e-77*(1.0 - cos(theta)**2)**21.5*(5.96802248174097e+89*cos(theta)**24 - 1.23847684583497e+90*cos(theta)**22 + 1.09193950911404e+90*cos(theta)**20 - 5.36094332639967e+89*cos(theta)**18 + 1.61461482074636e+89*cos(theta)**16 - 3.100060455833e+88*cos(theta)**14 + 3.82256777074259e+87*cos(theta)**12 - 2.97862423694228e+86*cos(theta)**10 + 1.40796313721011e+85*cos(theta)**8 - 3.74387158992242e+83*cos(theta)**6 + 4.88331076946403e+81*cos(theta)**4 - 2.35718943015158e+79*cos(theta)**2 + 1.76966173434804e+76)*sin(43*phi)

#@torch.jit.script
def Yl67_m_minus_42(theta, phi):
    return 1.51927821190258e-75*(1.0 - cos(theta)**2)**21*(2.38720899269639e+88*cos(theta)**25 - 5.38468193841291e+88*cos(theta)**23 + 5.19971194816208e+88*cos(theta)**21 - 2.82154911915772e+88*cos(theta)**19 + 9.49773423968445e+87*cos(theta)**17 - 2.06670697055534e+87*cos(theta)**15 + 2.94043674672507e+86*cos(theta)**13 - 2.70784021540207e+85*cos(theta)**11 + 1.56440348578901e+84*cos(theta)**9 - 5.34838798560346e+82*cos(theta)**7 + 9.76662153892806e+80*cos(theta)**5 - 7.85729810050528e+78*cos(theta)**3 + 1.76966173434804e+76*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl67_m_minus_41(theta, phi):
    return 8.08792718324593e-74*(1.0 - cos(theta)**2)**20.5*(9.18157304883227e+86*cos(theta)**26 - 2.24361747433871e+87*cos(theta)**24 + 2.36350543098277e+87*cos(theta)**22 - 1.41077455957886e+87*cos(theta)**20 + 5.27651902204692e+86*cos(theta)**18 - 1.29169185659709e+86*cos(theta)**16 + 2.10031196194648e+85*cos(theta)**14 - 2.25653351283506e+84*cos(theta)**12 + 1.56440348578901e+83*cos(theta)**10 - 6.68548498200433e+81*cos(theta)**8 + 1.62777025648801e+80*cos(theta)**6 - 1.96432452512632e+78*cos(theta)**4 + 8.84830867174018e+75*cos(theta)**2 - 6.24439567518714e+72)*sin(41*phi)

#@torch.jit.script
def Yl67_m_minus_40(theta, phi):
    return 4.36748067895281e-72*(1.0 - cos(theta)**2)**20*(3.40058261067862e+85*cos(theta)**27 - 8.97446989735485e+85*cos(theta)**25 + 1.02761105694903e+86*cos(theta)**23 - 6.71797409323267e+85*cos(theta)**21 + 2.77711527476154e+85*cos(theta)**19 - 7.59818739174756e+84*cos(theta)**17 + 1.40020797463099e+84*cos(theta)**15 - 1.73579500987312e+83*cos(theta)**13 + 1.42218498708092e+82*cos(theta)**11 - 7.42831664667148e+80*cos(theta)**9 + 2.32538608069716e+79*cos(theta)**7 - 3.92864905025264e+77*cos(theta)**5 + 2.94943622391339e+75*cos(theta)**3 - 6.24439567518714e+72*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl67_m_minus_39(theta, phi):
    return 2.3905723769247e-70*(1.0 - cos(theta)**2)**19.5*(1.21449378952808e+84*cos(theta)**28 - 3.45171919129033e+84*cos(theta)**26 + 4.28171273728762e+84*cos(theta)**24 - 3.05362458783303e+84*cos(theta)**22 + 1.38855763738077e+84*cos(theta)**20 - 4.22121521763753e+83*cos(theta)**18 + 8.75129984144367e+82*cos(theta)**16 - 1.2398535784808e+82*cos(theta)**14 + 1.18515415590077e+81*cos(theta)**12 - 7.42831664667148e+79*cos(theta)**10 + 2.90673260087145e+78*cos(theta)**8 - 6.54774841708773e+76*cos(theta)**6 + 7.37359055978348e+74*cos(theta)**4 - 3.12219783759357e+72*cos(theta)**2 + 2.08424421735218e+69)*sin(39*phi)

#@torch.jit.script
def Yl67_m_minus_38(theta, phi):
    return 1.3254209426954e-68*(1.0 - cos(theta)**2)**19*(4.18790961906234e+82*cos(theta)**29 - 1.27841451529271e+83*cos(theta)**27 + 1.71268509491505e+83*cos(theta)**25 - 1.32766286427523e+83*cos(theta)**23 + 6.6121792256227e+82*cos(theta)**21 - 2.22169221980923e+82*cos(theta)**19 + 5.14782343614333e+81*cos(theta)**17 - 8.26569052320535e+80*cos(theta)**15 + 9.1165704300059e+79*cos(theta)**13 - 6.75301513333771e+78*cos(theta)**11 + 3.22970288985716e+77*cos(theta)**9 - 9.35392631012533e+75*cos(theta)**7 + 1.4747181119567e+74*cos(theta)**5 - 1.04073261253119e+72*cos(theta)**3 + 2.08424421735218e+69*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl67_m_minus_37(theta, phi):
    return 7.43890659123167e-67*(1.0 - cos(theta)**2)**18.5*(1.39596987302078e+81*cos(theta)**30 - 4.56576612604541e+81*cos(theta)**28 + 6.58725036505787e+81*cos(theta)**26 - 5.53192860114679e+81*cos(theta)**24 + 3.00553601164668e+81*cos(theta)**22 - 1.11084610990461e+81*cos(theta)**20 + 2.85990190896852e+80*cos(theta)**18 - 5.16605657700335e+79*cos(theta)**16 + 6.51183602143279e+78*cos(theta)**14 - 5.62751261111476e+77*cos(theta)**12 + 3.22970288985716e+76*cos(theta)**10 - 1.16924078876567e+75*cos(theta)**8 + 2.45786351992783e+73*cos(theta)**6 - 2.60183153132798e+71*cos(theta)**4 + 1.04212210867609e+69*cos(theta)**2 - 6.61664830905455e+65)*sin(37*phi)

#@torch.jit.script
def Yl67_m_minus_36(theta, phi):
    return 4.22383186247248e-65*(1.0 - cos(theta)**2)**18*(4.50312862264767e+79*cos(theta)**31 - 1.57440211242945e+80*cos(theta)**29 + 2.43972235742884e+80*cos(theta)**27 - 2.21277144045872e+80*cos(theta)**25 + 1.30675478767247e+80*cos(theta)**23 - 5.28974338049816e+79*cos(theta)**21 + 1.50521153103606e+79*cos(theta)**19 - 3.03885681000197e+78*cos(theta)**17 + 4.34122401428853e+77*cos(theta)**15 - 4.32885585470366e+76*cos(theta)**13 + 2.93609353623379e+75*cos(theta)**11 - 1.29915643196185e+74*cos(theta)**9 + 3.5112335998969e+72*cos(theta)**7 - 5.20366306265595e+70*cos(theta)**5 + 3.47374036225364e+68*cos(theta)**3 - 6.61664830905455e+65*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl67_m_minus_35(theta, phi):
    return 2.42493567885078e-63*(1.0 - cos(theta)**2)**17.5*(1.4072276945774e+78*cos(theta)**32 - 5.2480070414315e+78*cos(theta)**30 + 8.71329413367444e+78*cos(theta)**28 - 8.51065938637968e+78*cos(theta)**26 + 5.44481161530196e+78*cos(theta)**24 - 2.40442880931735e+78*cos(theta)**22 + 7.52605765518031e+77*cos(theta)**20 - 1.68825378333443e+77*cos(theta)**18 + 2.71326500893033e+76*cos(theta)**16 - 3.0920398962169e+75*cos(theta)**14 + 2.44674461352815e+74*cos(theta)**12 - 1.29915643196185e+73*cos(theta)**10 + 4.38904199987112e+71*cos(theta)**8 - 8.67277177109325e+69*cos(theta)**6 + 8.6843509056341e+67*cos(theta)**4 - 3.30832415452728e+65*cos(theta)**2 + 2.00747824910636e+62)*sin(35*phi)

#@torch.jit.script
def Yl67_m_minus_34(theta, phi):
    return 1.40688072396819e-61*(1.0 - cos(theta)**2)**17*(4.26432634720424e+76*cos(theta)**33 - 1.69290549723597e+77*cos(theta)**31 + 3.00458418402567e+77*cos(theta)**29 - 3.15209606902951e+77*cos(theta)**27 + 2.17792464612078e+77*cos(theta)**25 - 1.04540383013798e+77*cos(theta)**23 + 3.58383697865729e+76*cos(theta)**21 - 8.88554622807593e+75*cos(theta)**19 + 1.59603824054725e+75*cos(theta)**17 - 2.06135993081127e+74*cos(theta)**15 + 1.8821112411755e+73*cos(theta)**13 - 1.1810513017835e+72*cos(theta)**11 + 4.87671333319013e+70*cos(theta)**9 - 1.23896739587046e+69*cos(theta)**7 + 1.73687018112682e+67*cos(theta)**5 - 1.10277471817576e+65*cos(theta)**3 + 2.00747824910636e+62*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl67_m_minus_33(theta, phi):
    return 8.24436905872075e-60*(1.0 - cos(theta)**2)**16.5*(1.25421363153066e+75*cos(theta)**34 - 5.2903296788624e+75*cos(theta)**32 + 1.00152806134189e+76*cos(theta)**30 - 1.12574859608197e+76*cos(theta)**28 + 8.37663325431071e+75*cos(theta)**26 - 4.35584929224157e+75*cos(theta)**24 + 1.62901680848059e+75*cos(theta)**22 - 4.44277311403796e+74*cos(theta)**20 + 8.8668791141514e+73*cos(theta)**18 - 1.28834995675704e+73*cos(theta)**16 + 1.34436517226822e+72*cos(theta)**14 - 9.84209418152918e+70*cos(theta)**12 + 4.87671333319013e+69*cos(theta)**10 - 1.54870924483808e+68*cos(theta)**8 + 2.89478363521137e+66*cos(theta)**6 - 2.7569367954394e+64*cos(theta)**4 + 1.00373912455318e+62*cos(theta)**2 - 5.84588890246464e+58)*sin(33*phi)

#@torch.jit.script
def Yl67_m_minus_32(theta, phi):
    return 4.87743451127099e-58*(1.0 - cos(theta)**2)**16*(3.58346751865902e+73*cos(theta)**35 - 1.60313020571588e+74*cos(theta)**33 + 3.23073568174803e+74*cos(theta)**31 - 3.88189171062748e+74*cos(theta)**29 + 3.10245676085582e+74*cos(theta)**27 - 1.74233971689663e+74*cos(theta)**25 + 7.08268177600255e+73*cos(theta)**23 - 2.11560624477998e+73*cos(theta)**21 + 4.66677848113232e+72*cos(theta)**19 - 7.57852915739436e+71*cos(theta)**17 + 8.96243448178811e+70*cos(theta)**15 - 7.57084167809937e+69*cos(theta)**13 + 4.43337575744558e+68*cos(theta)**11 - 1.72078804982009e+67*cos(theta)**9 + 4.13540519315909e+65*cos(theta)**7 - 5.51387359087879e+63*cos(theta)**5 + 3.34579708184393e+61*cos(theta)**3 - 5.84588890246464e+58*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl67_m_minus_31(theta, phi):
    return 2.91179163841494e-56*(1.0 - cos(theta)**2)**15.5*(9.95407644071951e+71*cos(theta)**36 - 4.71508884034082e+72*cos(theta)**34 + 1.00960490054626e+73*cos(theta)**32 - 1.29396390354249e+73*cos(theta)**30 + 1.10802027173422e+73*cos(theta)**28 - 6.70130660344857e+72*cos(theta)**26 + 2.95111740666773e+72*cos(theta)**24 - 9.6163920217272e+71*cos(theta)**22 + 2.33338924056616e+71*cos(theta)**20 - 4.2102939763302e+70*cos(theta)**18 + 5.60152155111757e+69*cos(theta)**16 - 5.40774405578526e+68*cos(theta)**14 + 3.69447979787131e+67*cos(theta)**12 - 1.72078804982009e+66*cos(theta)**10 + 5.16925649144887e+64*cos(theta)**8 - 9.18978931813132e+62*cos(theta)**6 + 8.36449270460982e+60*cos(theta)**4 - 2.92294445123232e+58*cos(theta)**2 + 1.6402606348105e+55)*sin(31*phi)

#@torch.jit.script
def Yl67_m_minus_30(theta, phi):
    return 1.75337251484502e-54*(1.0 - cos(theta)**2)**15*(2.69029092992419e+70*cos(theta)**37 - 1.34716824009738e+71*cos(theta)**35 + 3.05940878953412e+71*cos(theta)**33 - 4.17407710820159e+71*cos(theta)**31 + 3.82075955770421e+71*cos(theta)**29 - 2.48196540868465e+71*cos(theta)**27 + 1.18044696266709e+71*cos(theta)**25 - 4.18104000944661e+70*cos(theta)**23 + 1.11113773360293e+70*cos(theta)**21 - 2.21594419806853e+69*cos(theta)**19 + 3.29501267712798e+68*cos(theta)**17 - 3.60516270385684e+67*cos(theta)**15 + 2.84190753682409e+66*cos(theta)**13 - 1.56435277256372e+65*cos(theta)**11 + 5.74361832383208e+63*cos(theta)**9 - 1.31282704544733e+62*cos(theta)**7 + 1.67289854092196e+60*cos(theta)**5 - 9.7431481707744e+57*cos(theta)**3 + 1.6402606348105e+55*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl67_m_minus_29(theta, phi):
    return 1.06451518251504e-52*(1.0 - cos(theta)**2)**14.5*(7.07971297348471e+68*cos(theta)**38 - 3.74213400027049e+69*cos(theta)**36 + 8.99826114568859e+69*cos(theta)**34 - 1.304399096313e+70*cos(theta)**32 + 1.27358651923474e+70*cos(theta)**30 - 8.86416217387377e+69*cos(theta)**28 + 4.54018062564266e+69*cos(theta)**26 - 1.74210000393609e+69*cos(theta)**24 + 5.05062606183151e+68*cos(theta)**22 - 1.10797209903426e+68*cos(theta)**20 + 1.83056259840443e+67*cos(theta)**18 - 2.25322668991053e+66*cos(theta)**16 + 2.02993395487435e+65*cos(theta)**14 - 1.30362731046977e+64*cos(theta)**12 + 5.74361832383208e+62*cos(theta)**10 - 1.64103380680916e+61*cos(theta)**8 + 2.78816423486994e+59*cos(theta)**6 - 2.4357870426936e+57*cos(theta)**4 + 8.20130317405252e+54*cos(theta)**2 - 4.44997459254071e+51)*sin(29*phi)

#@torch.jit.script
def Yl67_m_minus_28(theta, phi):
    return 6.51358042579195e-51*(1.0 - cos(theta)**2)**14*(1.81531101884223e+67*cos(theta)**39 - 1.01138756764067e+68*cos(theta)**37 + 2.57093175591102e+68*cos(theta)**35 - 3.95272453428181e+68*cos(theta)**33 + 4.10834361043463e+68*cos(theta)**31 - 3.05660764616337e+68*cos(theta)**29 + 1.68154837986765e+68*cos(theta)**27 - 6.96840001574434e+67*cos(theta)**25 + 2.19592437470935e+67*cos(theta)**23 - 5.27605761444887e+66*cos(theta)**21 + 9.63453999160229e+65*cos(theta)**19 - 1.32542746465325e+65*cos(theta)**17 + 1.35328930324957e+64*cos(theta)**15 - 1.0027902388229e+63*cos(theta)**13 + 5.22147120348371e+61*cos(theta)**11 - 1.82337089645463e+60*cos(theta)**9 + 3.98309176409991e+58*cos(theta)**7 - 4.8715740853872e+56*cos(theta)**5 + 2.73376772468417e+54*cos(theta)**3 - 4.44997459254071e+51*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl67_m_minus_27(theta, phi):
    return 4.01524063862165e-49*(1.0 - cos(theta)**2)**13.5*(4.53827754710559e+65*cos(theta)**40 - 2.66154623063335e+66*cos(theta)**38 + 7.14147709975285e+66*cos(theta)**36 - 1.16256603949465e+67*cos(theta)**34 + 1.28385737826082e+67*cos(theta)**32 - 1.01886921538779e+67*cos(theta)**30 + 6.00552992809876e+66*cos(theta)**28 - 2.68015385220936e+66*cos(theta)**26 + 9.1496848946223e+65*cos(theta)**24 - 2.39820800656767e+65*cos(theta)**22 + 4.81726999580114e+64*cos(theta)**20 - 7.36348591474028e+63*cos(theta)**18 + 8.45805814530978e+62*cos(theta)**16 - 7.16278742016354e+61*cos(theta)**14 + 4.35122600290309e+60*cos(theta)**12 - 1.82337089645463e+59*cos(theta)**10 + 4.97886470512489e+57*cos(theta)**8 - 8.119290142312e+55*cos(theta)**6 + 6.83441931171044e+53*cos(theta)**4 - 2.22498729627035e+51*cos(theta)**2 + 1.17104594540545e+48)*sin(27*phi)

#@torch.jit.script
def Yl67_m_minus_26(theta, phi):
    return 2.49268519002688e-47*(1.0 - cos(theta)**2)**13*(1.10689696270868e+64*cos(theta)**41 - 6.82447751444449e+64*cos(theta)**39 + 1.93012894587915e+65*cos(theta)**37 - 3.321617255699e+65*cos(theta)**35 + 3.89047690382068e+65*cos(theta)**33 - 3.28667488834771e+65*cos(theta)**31 + 2.07087238899957e+65*cos(theta)**29 - 9.92649574892357e+64*cos(theta)**27 + 3.65987395784892e+64*cos(theta)**25 - 1.04269913329029e+64*cos(theta)**23 + 2.29393809323864e+63*cos(theta)**21 - 3.87551890249489e+62*cos(theta)**19 + 4.97532832077046e+61*cos(theta)**17 - 4.77519161344236e+60*cos(theta)**15 + 3.34709692531007e+59*cos(theta)**13 - 1.65760990586784e+58*cos(theta)**11 + 5.53207189458321e+56*cos(theta)**9 - 1.15989859175886e+55*cos(theta)**7 + 1.36688386234209e+53*cos(theta)**5 - 7.41662432090118e+50*cos(theta)**3 + 1.17104594540545e+48*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl67_m_minus_25(theta, phi):
    return 1.55787838926532e-45*(1.0 - cos(theta)**2)**12.5*(2.63546895883019e+62*cos(theta)**42 - 1.70611937861112e+63*cos(theta)**40 + 5.07928669968197e+63*cos(theta)**38 - 9.22671459916388e+63*cos(theta)**36 + 1.14425791288843e+64*cos(theta)**34 - 1.02708590260866e+64*cos(theta)**32 + 6.90290796333191e+63*cos(theta)**30 - 3.54517705318699e+63*cos(theta)**28 + 1.40764382994189e+63*cos(theta)**26 - 4.34457972204288e+62*cos(theta)**24 + 1.04269913329029e+62*cos(theta)**22 - 1.93775945124744e+61*cos(theta)**20 + 2.76407128931692e+60*cos(theta)**18 - 2.98449475840148e+59*cos(theta)**16 + 2.39078351807862e+58*cos(theta)**14 - 1.3813415882232e+57*cos(theta)**12 + 5.53207189458321e+55*cos(theta)**10 - 1.44987323969857e+54*cos(theta)**8 + 2.27813977057014e+52*cos(theta)**6 - 1.85415608022529e+50*cos(theta)**4 + 5.85522972702724e+47*cos(theta)**2 - 2.99806949668574e+44)*sin(25*phi)

#@torch.jit.script
def Yl67_m_minus_24(theta, phi):
    return 9.79854732071393e-44*(1.0 - cos(theta)**2)**12*(6.12899757867486e+60*cos(theta)**43 - 4.1612667771003e+61*cos(theta)**41 + 1.30238120504666e+62*cos(theta)**39 - 2.49370664842267e+62*cos(theta)**37 + 3.26930832253838e+62*cos(theta)**35 - 3.11238152305654e+62*cos(theta)**33 + 2.22674450430062e+62*cos(theta)**31 - 1.22247484592655e+62*cos(theta)**29 + 5.21349566645145e+61*cos(theta)**27 - 1.73783188881715e+61*cos(theta)**25 + 4.53347449256648e+60*cos(theta)**23 - 9.22742595832116e+59*cos(theta)**21 + 1.45477436279838e+59*cos(theta)**19 - 1.75558515200087e+58*cos(theta)**17 + 1.59385567871908e+57*cos(theta)**15 - 1.06257045247939e+56*cos(theta)**13 + 5.02915626780292e+54*cos(theta)**11 - 1.61097026633175e+53*cos(theta)**9 + 3.25448538652878e+51*cos(theta)**7 - 3.70831216045059e+49*cos(theta)**5 + 1.95174324234241e+47*cos(theta)**3 - 2.99806949668574e+44*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl67_m_minus_23(theta, phi):
    return 6.20024325735262e-42*(1.0 - cos(theta)**2)**11.5*(1.39295399515338e+59*cos(theta)**44 - 9.907778040715e+59*cos(theta)**42 + 3.25595301261665e+60*cos(theta)**40 - 6.56238591690177e+60*cos(theta)**38 + 9.08141200705107e+60*cos(theta)**36 - 9.15406330310748e+60*cos(theta)**34 + 6.95857657593942e+60*cos(theta)**32 - 4.07491615308849e+60*cos(theta)**30 + 1.86196273801838e+60*cos(theta)**28 - 6.68396880314289e+59*cos(theta)**26 + 1.88894770523603e+59*cos(theta)**24 - 4.19428452650962e+58*cos(theta)**22 + 7.2738718139919e+57*cos(theta)**20 - 9.75325084444927e+56*cos(theta)**18 + 9.96159799199425e+55*cos(theta)**16 - 7.58978894628133e+54*cos(theta)**14 + 4.19096355650243e+53*cos(theta)**12 - 1.61097026633175e+52*cos(theta)**10 + 4.06810673316097e+50*cos(theta)**8 - 6.18052026741765e+48*cos(theta)**6 + 4.87935810585604e+46*cos(theta)**4 - 1.49903474834287e+44*cos(theta)**2 + 7.48768605565868e+40)*sin(23*phi)

#@torch.jit.script
def Yl67_m_minus_22(theta, phi):
    return 3.94581064705218e-40*(1.0 - cos(theta)**2)**11*(3.09545332256306e+57*cos(theta)**45 - 2.30413442807325e+58*cos(theta)**43 + 7.94134881126011e+58*cos(theta)**41 - 1.68266305561584e+59*cos(theta)**39 + 2.45443567758137e+59*cos(theta)**37 - 2.61544665803071e+59*cos(theta)**35 + 2.10865956846649e+59*cos(theta)**33 - 1.31448908164145e+59*cos(theta)**31 + 6.42056116558061e+58*cos(theta)**29 - 2.47554400116403e+58*cos(theta)**27 + 7.55579082094414e+57*cos(theta)**25 - 1.82360196804766e+57*cos(theta)**23 + 3.46374848285329e+56*cos(theta)**21 - 5.1332899181312e+55*cos(theta)**19 + 5.8597635247025e+54*cos(theta)**17 - 5.05985929752089e+53*cos(theta)**15 + 3.22381812038649e+52*cos(theta)**13 - 1.46451842393795e+51*cos(theta)**11 + 4.52011859240108e+49*cos(theta)**9 - 8.8293146677395e+47*cos(theta)**7 + 9.75871621171208e+45*cos(theta)**5 - 4.99678249447623e+43*cos(theta)**3 + 7.48768605565868e+40*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl67_m_minus_21(theta, phi):
    return 2.52470220592105e-38*(1.0 - cos(theta)**2)**10.5*(6.72924635339796e+55*cos(theta)**46 - 5.23666915471194e+56*cos(theta)**44 + 1.89079733601431e+57*cos(theta)**42 - 4.20665763903959e+57*cos(theta)**40 + 6.45904125679308e+57*cos(theta)**38 - 7.26512960564085e+57*cos(theta)**36 + 6.20193990725439e+57*cos(theta)**34 - 4.10777838012953e+57*cos(theta)**32 + 2.14018705519354e+57*cos(theta)**30 - 8.84122857558583e+56*cos(theta)**28 + 2.90607339267082e+56*cos(theta)**26 - 7.59834153353191e+55*cos(theta)**24 + 1.57443112856968e+55*cos(theta)**22 - 2.5666449590656e+54*cos(theta)**20 + 3.25542418039028e+53*cos(theta)**18 - 3.16241206095056e+52*cos(theta)**16 + 2.30272722884749e+51*cos(theta)**14 - 1.22043201994829e+50*cos(theta)**12 + 4.52011859240108e+48*cos(theta)**10 - 1.10366433346744e+47*cos(theta)**8 + 1.62645270195201e+45*cos(theta)**6 - 1.24919562361906e+43*cos(theta)**4 + 3.74384302782934e+40*cos(theta)**2 - 1.82894139122098e+37)*sin(21*phi)

#@torch.jit.script
def Yl67_m_minus_20(theta, phi):
    return 1.6236799377161e-36*(1.0 - cos(theta)**2)**10*(1.43175454327616e+54*cos(theta)**47 - 1.16370425660265e+55*cos(theta)**45 + 4.39720310701003e+55*cos(theta)**43 - 1.02601405830234e+56*cos(theta)**41 + 1.65616442481874e+56*cos(theta)**39 - 1.9635485420651e+56*cos(theta)**37 + 1.77198283064411e+56*cos(theta)**35 - 1.24478132731198e+56*cos(theta)**33 + 6.90382921030173e+55*cos(theta)**31 - 3.0486995088227e+55*cos(theta)**29 + 1.07632347876697e+55*cos(theta)**27 - 3.03933661341277e+54*cos(theta)**25 + 6.84535273291163e+53*cos(theta)**23 - 1.22221188526933e+53*cos(theta)**21 + 1.71338114757383e+52*cos(theta)**19 - 1.86024238879444e+51*cos(theta)**17 + 1.53515148589833e+50*cos(theta)**15 - 9.38793861498686e+48*cos(theta)**13 + 4.10919872036462e+47*cos(theta)**11 - 1.22629370385271e+46*cos(theta)**9 + 2.32350385993145e+44*cos(theta)**7 - 2.49839124723811e+42*cos(theta)**5 + 1.24794767594311e+40*cos(theta)**3 - 1.82894139122098e+37*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl67_m_minus_19(theta, phi):
    return 1.04925408703669e-34*(1.0 - cos(theta)**2)**9.5*(2.98282196515867e+52*cos(theta)**48 - 2.52979186217968e+53*cos(theta)**46 + 9.99364342502279e+53*cos(theta)**44 - 2.44289061500557e+54*cos(theta)**42 + 4.14041106204684e+54*cos(theta)**40 - 5.16723300543446e+54*cos(theta)**38 + 4.92217452956697e+54*cos(theta)**36 - 3.66112155091758e+54*cos(theta)**34 + 2.15744662821929e+54*cos(theta)**32 - 1.01623316960757e+54*cos(theta)**30 + 3.84401242416775e+53*cos(theta)**28 - 1.16897562054337e+53*cos(theta)**26 + 2.85223030537985e+52*cos(theta)**24 - 5.55550856940605e+51*cos(theta)**22 + 8.56690573786915e+50*cos(theta)**20 - 1.03346799377469e+50*cos(theta)**18 + 9.59469678686455e+48*cos(theta)**16 - 6.70567043927633e+47*cos(theta)**14 + 3.42433226697052e+46*cos(theta)**12 - 1.22629370385271e+45*cos(theta)**10 + 2.90437982491431e+43*cos(theta)**8 - 4.16398541206352e+41*cos(theta)**6 + 3.11986918985779e+39*cos(theta)**4 - 9.14470695610489e+36*cos(theta)**2 + 4.37964892533759e+33)*sin(19*phi)

#@torch.jit.script
def Yl67_m_minus_18(theta, phi):
    return 6.81126747561255e-33*(1.0 - cos(theta)**2)**9*(6.08739176562994e+50*cos(theta)**49 - 5.38253587697805e+51*cos(theta)**47 + 2.22080965000506e+52*cos(theta)**45 - 5.68114096512924e+52*cos(theta)**43 + 1.00985635659679e+53*cos(theta)**41 - 1.32493153985499e+53*cos(theta)**39 + 1.33031744042351e+53*cos(theta)**37 - 1.0460347288336e+53*cos(theta)**35 + 6.53771705520997e+52*cos(theta)**33 - 3.27817151486312e+52*cos(theta)**31 + 1.32552152557509e+52*cos(theta)**29 - 4.32953933534582e+51*cos(theta)**27 + 1.14089212215194e+51*cos(theta)**25 - 2.41543850843742e+50*cos(theta)**23 + 4.07947892279483e+49*cos(theta)**21 - 5.43930523039311e+48*cos(theta)**19 + 5.64393928639091e+47*cos(theta)**17 - 4.47044695951755e+46*cos(theta)**15 + 2.63410174382347e+45*cos(theta)**13 - 1.11481245804792e+44*cos(theta)**11 + 3.22708869434923e+42*cos(theta)**9 - 5.94855058866218e+40*cos(theta)**7 + 6.23973837971557e+38*cos(theta)**5 - 3.04823565203496e+36*cos(theta)**3 + 4.37964892533759e+33*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl67_m_minus_17(theta, phi):
    return 4.44040313094919e-31*(1.0 - cos(theta)**2)**8.5*(1.21747835312599e+49*cos(theta)**50 - 1.12136164103709e+50*cos(theta)**48 + 4.8278470652284e+50*cos(theta)**46 - 1.29116840116574e+51*cos(theta)**44 + 2.40441989665903e+51*cos(theta)**42 - 3.31232884963748e+51*cos(theta)**40 + 3.50083536953554e+51*cos(theta)**38 - 2.90565202453776e+51*cos(theta)**36 + 1.9228579574147e+51*cos(theta)**34 - 1.02442859839472e+51*cos(theta)**32 + 4.41840508525029e+50*cos(theta)**30 - 1.54626404833779e+50*cos(theta)**28 + 4.3880466236613e+49*cos(theta)**26 - 1.00643271184892e+49*cos(theta)**24 + 1.85430860127038e+48*cos(theta)**22 - 2.71965261519656e+47*cos(theta)**20 + 3.13552182577273e+46*cos(theta)**18 - 2.79402934969847e+45*cos(theta)**16 + 1.8815012455882e+44*cos(theta)**14 - 9.29010381706597e+42*cos(theta)**12 + 3.22708869434923e+41*cos(theta)**10 - 7.43568823582772e+39*cos(theta)**8 + 1.03995639661926e+38*cos(theta)**6 - 7.62058913008741e+35*cos(theta)**4 + 2.1898244626688e+33*cos(theta)**2 - 1.0305056294912e+30)*sin(17*phi)

#@torch.jit.script
def Yl67_m_minus_16(theta, phi):
    return 2.90634476570711e-29*(1.0 - cos(theta)**2)**8*(2.38721245710978e+47*cos(theta)**51 - 2.28849314497366e+48*cos(theta)**49 + 1.02720150324009e+49*cos(theta)**47 - 2.86926311370163e+49*cos(theta)**45 + 5.59167417827681e+49*cos(theta)**43 - 8.07885085277433e+49*cos(theta)**41 + 8.97650094752703e+49*cos(theta)**39 - 7.8531135798318e+49*cos(theta)**37 + 5.49387987832771e+49*cos(theta)**35 - 3.10432908604462e+49*cos(theta)**33 + 1.42529196298397e+49*cos(theta)**31 - 5.33194499426825e+48*cos(theta)**29 + 1.62520245320789e+48*cos(theta)**27 - 4.02573084739569e+47*cos(theta)**25 + 8.06221130987121e+46*cos(theta)**23 - 1.29507267390312e+46*cos(theta)**21 + 1.65027464514354e+45*cos(theta)**19 - 1.64354667629322e+44*cos(theta)**17 + 1.25433416372546e+43*cos(theta)**15 - 7.14623370543536e+41*cos(theta)**13 + 2.93371699486294e+40*cos(theta)**11 - 8.26187581758636e+38*cos(theta)**9 + 1.48565199517037e+37*cos(theta)**7 - 1.52411782601748e+35*cos(theta)**5 + 7.29941487556265e+32*cos(theta)**3 - 1.0305056294912e+30*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl67_m_minus_15(theta, phi):
    return 1.9093601283182e-27*(1.0 - cos(theta)**2)**7.5*(4.59079318674957e+45*cos(theta)**52 - 4.57698628994732e+46*cos(theta)**50 + 2.14000313175018e+47*cos(theta)**48 - 6.23752850804703e+47*cos(theta)**46 + 1.27083504051746e+48*cos(theta)**44 - 1.92353591732722e+48*cos(theta)**42 + 2.24412523688176e+48*cos(theta)**40 - 2.06660883679784e+48*cos(theta)**38 + 1.52607774397992e+48*cos(theta)**36 - 9.13037966483712e+47*cos(theta)**34 + 4.45403738432489e+47*cos(theta)**32 - 1.77731499808942e+47*cos(theta)**30 + 5.80429447574247e+46*cos(theta)**28 - 1.54835801822911e+46*cos(theta)**26 + 3.35925471244634e+45*cos(theta)**24 - 5.88669397228692e+44*cos(theta)**22 + 8.25137322571771e+43*cos(theta)**20 - 9.13081486829566e+42*cos(theta)**18 + 7.83958852328415e+41*cos(theta)**16 - 5.10445264673954e+40*cos(theta)**14 + 2.44476416238578e+39*cos(theta)**12 - 8.26187581758636e+37*cos(theta)**10 + 1.85706499396297e+36*cos(theta)**8 - 2.5401963766958e+34*cos(theta)**6 + 1.82485371889066e+32*cos(theta)**4 - 5.15252814745599e+29*cos(theta)**2 + 2.38764047611492e+26)*sin(15*phi)

#@torch.jit.script
def Yl67_m_minus_14(theta, phi):
    return 1.25873036862192e-25*(1.0 - cos(theta)**2)**7*(8.66187393726335e+43*cos(theta)**53 - 8.97448292146533e+44*cos(theta)**51 + 4.3673533301024e+45*cos(theta)**49 - 1.32713372511639e+46*cos(theta)**47 + 2.82407786781657e+46*cos(theta)**45 - 4.47333934262145e+46*cos(theta)**43 + 5.47347618751648e+46*cos(theta)**41 - 5.29899701743036e+46*cos(theta)**39 + 4.12453444318897e+46*cos(theta)**37 - 2.60867990423918e+46*cos(theta)**35 + 1.34970829828027e+46*cos(theta)**33 - 5.73327418738522e+45*cos(theta)**31 + 2.0014808537043e+45*cos(theta)**29 - 5.73465932677449e+44*cos(theta)**27 + 1.34370188497854e+44*cos(theta)**25 - 2.55943216186388e+43*cos(theta)**23 + 3.92922534557986e+42*cos(theta)**21 - 4.80569203594508e+41*cos(theta)**19 + 4.61152266075538e+40*cos(theta)**17 - 3.4029684311597e+39*cos(theta)**15 + 1.88058781721983e+38*cos(theta)**13 - 7.51079619780578e+36*cos(theta)**11 + 2.06340554884774e+35*cos(theta)**9 - 3.62885196670829e+33*cos(theta)**7 + 3.64970743778133e+31*cos(theta)**5 - 1.71750938248533e+29*cos(theta)**3 + 2.38764047611492e+26*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl67_m_minus_13(theta, phi):
    return 8.32476724254649e-24*(1.0 - cos(theta)**2)**6.5*(1.60405072912284e+42*cos(theta)**54 - 1.72586210028179e+43*cos(theta)**52 + 8.73470666020481e+43*cos(theta)**50 - 2.76486192732581e+44*cos(theta)**48 + 6.13929971264471e+44*cos(theta)**46 - 1.01666803241396e+45*cos(theta)**44 + 1.30320861607535e+45*cos(theta)**42 - 1.32474925435759e+45*cos(theta)**40 + 1.0854038008392e+45*cos(theta)**38 - 7.24633306733105e+44*cos(theta)**36 + 3.96973028905962e+44*cos(theta)**34 - 1.79164818355788e+44*cos(theta)**32 + 6.671602845681e+43*cos(theta)**30 - 2.04809261670518e+43*cos(theta)**28 + 5.16808417299437e+42*cos(theta)**26 - 1.06643006744328e+42*cos(theta)**24 + 1.78601152071812e+41*cos(theta)**22 - 2.40284601797254e+40*cos(theta)**20 + 2.56195703375299e+39*cos(theta)**18 - 2.12685526947481e+38*cos(theta)**16 + 1.34327701229988e+37*cos(theta)**14 - 6.25899683150482e+35*cos(theta)**12 + 2.06340554884774e+34*cos(theta)**10 - 4.53606495838536e+32*cos(theta)**8 + 6.08284572963554e+30*cos(theta)**6 - 4.29377345621333e+28*cos(theta)**4 + 1.19382023805746e+26*cos(theta)**2 - 5.45871165092574e+22)*sin(13*phi)

#@torch.jit.script
def Yl67_m_minus_12(theta, phi):
    return 5.52202588211365e-22*(1.0 - cos(theta)**2)**6*(2.91645587113244e+40*cos(theta)**55 - 3.25634358543735e+41*cos(theta)**53 + 1.71268758043232e+42*cos(theta)**51 - 5.64257536188941e+42*cos(theta)**49 + 1.30623398141377e+43*cos(theta)**47 - 2.25926229425326e+43*cos(theta)**45 + 3.03071771180315e+43*cos(theta)**43 - 3.23109574233559e+43*cos(theta)**41 + 2.78308666881847e+43*cos(theta)**39 - 1.95846839657596e+43*cos(theta)**37 + 1.13420865401703e+43*cos(theta)**35 - 5.42923691987236e+42*cos(theta)**33 + 2.15212995021968e+42*cos(theta)**31 - 7.06238833346612e+41*cos(theta)**29 + 1.91410524925717e+41*cos(theta)**27 - 4.26572026977313e+40*cos(theta)**25 + 7.76526748138312e+39*cos(theta)**23 - 1.14421238951073e+39*cos(theta)**21 + 1.34839843881736e+38*cos(theta)**19 - 1.25109133498518e+37*cos(theta)**17 + 8.9551800819992e+35*cos(theta)**15 - 4.8146129473114e+34*cos(theta)**13 + 1.87582322622522e+33*cos(theta)**11 - 5.04007217598374e+31*cos(theta)**9 + 8.68977961376506e+29*cos(theta)**7 - 8.58754691242665e+27*cos(theta)**5 + 3.97940079352486e+25*cos(theta)**3 - 5.45871165092574e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl67_m_minus_11(theta, phi):
    return 3.6728737220908e-20*(1.0 - cos(theta)**2)**5.5*(5.2079569127365e+38*cos(theta)**56 - 6.03026589895805e+39*cos(theta)**54 + 3.29362996236984e+40*cos(theta)**52 - 1.12851507237788e+41*cos(theta)**50 + 2.72132079461202e+41*cos(theta)**48 - 4.91143977011577e+41*cos(theta)**46 + 6.88799479955261e+41*cos(theta)**44 - 7.69308510079902e+41*cos(theta)**42 + 6.95771667204617e+41*cos(theta)**40 - 5.15386420151568e+41*cos(theta)**38 + 3.15057959449176e+41*cos(theta)**36 - 1.59683438819775e+41*cos(theta)**34 + 6.72540609443649e+40*cos(theta)**32 - 2.35412944448871e+40*cos(theta)**30 + 6.83609017591848e+39*cos(theta)**28 - 1.64066164222043e+39*cos(theta)**26 + 3.23552811724297e+38*cos(theta)**24 - 5.20096540686697e+37*cos(theta)**22 + 6.74199219408682e+36*cos(theta)**20 - 6.95050741658435e+35*cos(theta)**18 + 5.5969875512495e+34*cos(theta)**16 - 3.43900924807957e+33*cos(theta)**14 + 1.56318602185435e+32*cos(theta)**12 - 5.04007217598374e+30*cos(theta)**10 + 1.08622245172063e+29*cos(theta)**8 - 1.43125781873778e+27*cos(theta)**6 + 9.94850198381215e+24*cos(theta)**4 - 2.72935582546287e+22*cos(theta)**2 + 1.2338859970447e+19)*sin(11*phi)

#@torch.jit.script
def Yl67_m_minus_10(theta, phi):
    return 2.44901094584075e-18*(1.0 - cos(theta)**2)**5*(9.13676651357281e+36*cos(theta)**57 - 1.09641198162874e+38*cos(theta)**55 + 6.21439615541479e+38*cos(theta)**53 - 2.21277465172134e+39*cos(theta)**51 + 5.55371590737147e+39*cos(theta)**49 - 1.04498718513102e+40*cos(theta)**47 + 1.53066551101169e+40*cos(theta)**45 - 1.78908955832535e+40*cos(theta)**43 + 1.69700406635272e+40*cos(theta)**41 - 1.32150364141428e+40*cos(theta)**39 + 8.51507998511286e+39*cos(theta)**37 - 4.5623839662793e+39*cos(theta)**35 + 2.03800184679894e+39*cos(theta)**33 - 7.59396594996357e+38*cos(theta)**31 + 2.35727247445465e+38*cos(theta)**29 - 6.07652460081642e+37*cos(theta)**27 + 1.29421124689719e+37*cos(theta)**25 - 2.26128930733347e+36*cos(theta)**23 + 3.21047247337467e+35*cos(theta)**21 - 3.65816179820229e+34*cos(theta)**19 + 3.29234561838206e+33*cos(theta)**17 - 2.29267283205305e+32*cos(theta)**15 + 1.20245078604181e+31*cos(theta)**13 - 4.58188379634885e+29*cos(theta)**11 + 1.20691383524515e+28*cos(theta)**9 - 2.04465402676825e+26*cos(theta)**7 + 1.98970039676243e+24*cos(theta)**5 - 9.09785275154289e+21*cos(theta)**3 + 1.2338859970447e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl67_m_minus_9(theta, phi):
    return 1.63662840929083e-16*(1.0 - cos(theta)**2)**4.5*(1.57530457130566e+35*cos(theta)**58 - 1.95787853862274e+36*cos(theta)**56 + 1.15081410285459e+37*cos(theta)**54 - 4.25533586869488e+37*cos(theta)**52 + 1.11074318147429e+38*cos(theta)**50 - 2.17705663568962e+38*cos(theta)**48 + 3.32753371959063e+38*cos(theta)**46 - 4.06611263255762e+38*cos(theta)**44 + 4.04048587226839e+38*cos(theta)**42 - 3.30375910353569e+38*cos(theta)**40 + 2.24081052239812e+38*cos(theta)**38 - 1.26732887952203e+38*cos(theta)**36 + 5.9941230788204e+37*cos(theta)**34 - 2.37311435936362e+37*cos(theta)**32 + 7.85757491484882e+36*cos(theta)**30 - 2.17018735743444e+36*cos(theta)**28 + 4.97773556498918e+35*cos(theta)**26 - 9.42203878055611e+34*cos(theta)**24 + 1.45930566971576e+34*cos(theta)**22 - 1.82908089910114e+33*cos(theta)**20 + 1.82908089910114e+32*cos(theta)**18 - 1.43292052003315e+31*cos(theta)**16 + 8.58893418601291e+29*cos(theta)**14 - 3.81823649695738e+28*cos(theta)**12 + 1.20691383524515e+27*cos(theta)**10 - 2.55581753346031e+25*cos(theta)**8 + 3.31616732793738e+23*cos(theta)**6 - 2.27446318788572e+21*cos(theta)**4 + 6.16942998522348e+18*cos(theta)**2 - 2.76284370139878e+15)*sin(9*phi)

#@torch.jit.script
def Yl67_m_minus_8(theta, phi):
    return 1.09593018183818e-14*(1.0 - cos(theta)**2)**4*(2.67000774797569e+33*cos(theta)**59 - 3.43487462916271e+34*cos(theta)**57 + 2.09238927791744e+35*cos(theta)**55 - 8.0289356013111e+35*cos(theta)**53 + 2.17792780681234e+36*cos(theta)**51 - 4.44297272589717e+36*cos(theta)**49 + 7.07985897785241e+36*cos(theta)**47 - 9.03580585012804e+36*cos(theta)**45 + 9.39647877271719e+36*cos(theta)**43 - 8.05794903301388e+36*cos(theta)**41 + 5.74566800614903e+36*cos(theta)**39 - 3.42521318789737e+36*cos(theta)**37 + 1.71260659394869e+36*cos(theta)**35 - 7.1912556344352e+35*cos(theta)**33 + 2.5347015854351e+35*cos(theta)**31 - 7.4834046808084e+34*cos(theta)**29 + 1.84360576481081e+34*cos(theta)**27 - 3.76881551222244e+33*cos(theta)**25 + 6.34480725963374e+32*cos(theta)**23 - 8.70990904333878e+31*cos(theta)**21 + 9.62674157421655e+30*cos(theta)**19 - 8.42894423548914e+29*cos(theta)**17 + 5.72595612400861e+28*cos(theta)**15 - 2.93710499765952e+27*cos(theta)**13 + 1.09719439567741e+26*cos(theta)**11 - 2.83979725940035e+24*cos(theta)**9 + 4.73738189705341e+22*cos(theta)**7 - 4.54892637577145e+20*cos(theta)**5 + 2.05647666174116e+18*cos(theta)**3 - 2.76284370139878e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl67_m_minus_7(theta, phi):
    return 7.35172315555162e-13*(1.0 - cos(theta)**2)**3.5*(4.45001291329281e+31*cos(theta)**60 - 5.92219763648743e+32*cos(theta)**58 + 3.73640942485257e+33*cos(theta)**56 - 1.48683992616872e+34*cos(theta)**54 + 4.18832270540835e+34*cos(theta)**52 - 8.88594545179435e+34*cos(theta)**50 + 1.47497062038592e+35*cos(theta)**48 - 1.96430561959305e+35*cos(theta)**46 + 2.13556335743572e+35*cos(theta)**44 - 1.91855929357473e+35*cos(theta)**42 + 1.43641700153726e+35*cos(theta)**40 - 9.0137189155194e+34*cos(theta)**38 + 4.75724053874635e+34*cos(theta)**36 - 2.11507518659859e+34*cos(theta)**34 + 7.9209424544847e+33*cos(theta)**32 - 2.49446822693613e+33*cos(theta)**30 + 6.58430630289574e+32*cos(theta)**28 - 1.44954442777786e+32*cos(theta)**26 + 2.64366969151406e+31*cos(theta)**24 - 3.95904956515399e+30*cos(theta)**22 + 4.81337078710827e+29*cos(theta)**20 - 4.68274679749397e+28*cos(theta)**18 + 3.57872257750538e+27*cos(theta)**16 - 2.09793214118537e+26*cos(theta)**14 + 9.14328663064506e+24*cos(theta)**12 - 2.83979725940035e+23*cos(theta)**10 + 5.92172737131676e+21*cos(theta)**8 - 7.58154395961908e+19*cos(theta)**6 + 5.1411916543529e+17*cos(theta)**4 - 1.38142185069939e+15*cos(theta)**2 + 613965266977.507)*sin(7*phi)

#@torch.jit.script
def Yl67_m_minus_6(theta, phi):
    return 4.93935137207726e-11*(1.0 - cos(theta)**2)**3*(7.2951031365456e+29*cos(theta)**61 - 1.00376231126906e+31*cos(theta)**59 + 6.55510425412731e+31*cos(theta)**57 - 2.70334532030677e+32*cos(theta)**55 + 7.90249567058179e+32*cos(theta)**53 - 1.74234224544987e+33*cos(theta)**51 + 3.01014412323657e+33*cos(theta)**49 - 4.17937365870862e+33*cos(theta)**47 + 4.74569634985717e+33*cos(theta)**45 - 4.46176579901101e+33*cos(theta)**43 + 3.50345610131038e+33*cos(theta)**41 - 2.31120997833831e+33*cos(theta)**39 + 1.28574068614766e+33*cos(theta)**37 - 6.04307196171025e+32*cos(theta)**35 + 2.40028559226809e+32*cos(theta)**33 - 8.04667169979398e+31*cos(theta)**31 + 2.27045044927439e+31*cos(theta)**29 - 5.36868306584394e+30*cos(theta)**27 + 1.05746787660562e+30*cos(theta)**25 - 1.72132589789304e+29*cos(theta)**23 + 2.29208132719442e+28*cos(theta)**21 - 2.4646035776284e+27*cos(theta)**19 + 2.10513092794434e+26*cos(theta)**17 - 1.39862142745691e+25*cos(theta)**15 + 7.03329740818851e+23*cos(theta)**13 - 2.58163387218213e+22*cos(theta)**11 + 6.57969707924084e+20*cos(theta)**9 - 1.08307770851701e+19*cos(theta)**7 + 1.02823833087058e+17*cos(theta)**5 - 460473950233130.0*cos(theta)**3 + 613965266977.507*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl67_m_minus_5(theta, phi):
    return 3.32297593863068e-9*(1.0 - cos(theta)**2)**2.5*(1.17662953815252e+28*cos(theta)**62 - 1.67293718544843e+29*cos(theta)**60 + 1.13019038864264e+30*cos(theta)**58 - 4.82740235769065e+30*cos(theta)**56 + 1.46342512418181e+31*cos(theta)**54 - 3.35065816432668e+31*cos(theta)**52 + 6.02028824647314e+31*cos(theta)**50 - 8.70702845564296e+31*cos(theta)**48 + 1.03167311953417e+32*cos(theta)**46 - 1.01403768159341e+32*cos(theta)**44 + 8.34156214597711e+31*cos(theta)**42 - 5.77802494584577e+31*cos(theta)**40 + 3.38352812144121e+31*cos(theta)**38 - 1.67863110047507e+31*cos(theta)**36 + 7.05966350667086e+30*cos(theta)**34 - 2.51458490618562e+30*cos(theta)**32 + 7.56816816424798e+29*cos(theta)**30 - 1.91738680922998e+29*cos(theta)**28 + 4.06718414079086e+28*cos(theta)**26 - 7.172191241221e+27*cos(theta)**24 + 1.04185514872473e+27*cos(theta)**22 - 1.2323017888142e+26*cos(theta)**20 + 1.1695171821913e+25*cos(theta)**18 - 8.74138392160571e+23*cos(theta)**16 + 5.02378386299179e+22*cos(theta)**14 - 2.15136156015178e+21*cos(theta)**12 + 6.57969707924084e+19*cos(theta)**10 - 1.35384713564626e+18*cos(theta)**8 + 1.71373055145097e+16*cos(theta)**6 - 115118487558283.0*cos(theta)**4 + 306982633488.754*cos(theta)**2 - 135652953.375499)*sin(5*phi)

#@torch.jit.script
def Yl67_m_minus_4(theta, phi):
    return 2.23801874403292e-7*(1.0 - cos(theta)**2)**2*(1.86766593357542e+26*cos(theta)**63 - 2.74251997614496e+27*cos(theta)**61 + 1.91557692990278e+28*cos(theta)**59 - 8.46912694331694e+28*cos(theta)**57 + 2.66077295305784e+29*cos(theta)**55 - 6.32199653646543e+29*cos(theta)**53 + 1.18044867577905e+30*cos(theta)**51 - 1.77694458278428e+30*cos(theta)**49 + 2.19504919049823e+30*cos(theta)**47 - 2.25341707020758e+30*cos(theta)**45 + 1.93989817348305e+30*cos(theta)**43 - 1.40927437703555e+30*cos(theta)**41 + 8.67571313190055e+29*cos(theta)**39 - 4.53684081209478e+29*cos(theta)**37 + 2.01704671619167e+29*cos(theta)**35 - 7.61995426116854e+28*cos(theta)**33 + 2.44134456911225e+28*cos(theta)**31 - 6.61167865251716e+27*cos(theta)**29 + 1.50636449658921e+27*cos(theta)**27 - 2.8688764964884e+26*cos(theta)**25 + 4.52980499445537e+25*cos(theta)**23 - 5.8681037562581e+24*cos(theta)**21 + 6.15535359048053e+23*cos(theta)**19 - 5.14199054212101e+22*cos(theta)**17 + 3.34918924199453e+21*cos(theta)**15 - 1.65489350780906e+20*cos(theta)**13 + 5.98154279930986e+18*cos(theta)**11 - 1.50427459516252e+17*cos(theta)**9 + 2.44818650207281e+15*cos(theta)**7 - 23023697511656.5*cos(theta)**5 + 102327544496.251*cos(theta)**3 - 135652953.375499*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl67_m_minus_3(theta, phi):
    return 1.5086304905918e-5*(1.0 - cos(theta)**2)**1.5*(2.9182280212116e+24*cos(theta)**64 - 4.42341931636284e+25*cos(theta)**62 + 3.19262821650463e+26*cos(theta)**60 - 1.46019430057189e+27*cos(theta)**58 + 4.75138027331757e+27*cos(theta)**56 - 1.17074009934545e+28*cos(theta)**54 + 2.2700936072674e+28*cos(theta)**52 - 3.55388916556856e+28*cos(theta)**50 + 4.5730191468713e+28*cos(theta)**48 - 4.89873276132083e+28*cos(theta)**46 + 4.40885948518875e+28*cos(theta)**44 - 3.35541518341798e+28*cos(theta)**42 + 2.16892828297514e+28*cos(theta)**40 - 1.19390547686705e+28*cos(theta)**38 + 5.60290754497687e+27*cos(theta)**36 - 2.24116301799075e+27*cos(theta)**34 + 7.62920177847579e+26*cos(theta)**32 - 2.20389288417239e+26*cos(theta)**30 + 5.37987320210431e+25*cos(theta)**28 - 1.10341403711092e+25*cos(theta)**26 + 1.88741874768974e+24*cos(theta)**24 - 2.66731988920823e+23*cos(theta)**22 + 3.07767679524026e+22*cos(theta)**20 - 2.85666141228945e+21*cos(theta)**18 + 2.09324327624658e+20*cos(theta)**16 - 1.18206679129219e+19*cos(theta)**14 + 4.98461899942488e+17*cos(theta)**12 - 1.50427459516252e+16*cos(theta)**10 + 306023312759101.0*cos(theta)**8 - 3837282918609.42*cos(theta)**6 + 25581886124.0628*cos(theta)**4 - 67826476.6877494*cos(theta)**2 + 29853.2027674953)*sin(3*phi)

#@torch.jit.script
def Yl67_m_minus_2(theta, phi):
    return 0.0010176269014232*(1.0 - cos(theta)**2)*(4.48958157109476e+22*cos(theta)**65 - 7.02130050216324e+23*cos(theta)**63 + 5.23381674836825e+24*cos(theta)**61 - 2.47490559418964e+25*cos(theta)**59 + 8.33575486546942e+25*cos(theta)**57 - 2.12861836244627e+26*cos(theta)**55 + 4.28319548541018e+26*cos(theta)**53 - 6.9684101285658e+26*cos(theta)**51 + 9.33269213647205e+26*cos(theta)**49 - 1.04228356623847e+27*cos(theta)**47 + 9.79746552264166e+26*cos(theta)**45 - 7.80329112422787e+26*cos(theta)**43 + 5.29006898286619e+26*cos(theta)**41 - 3.06129609453089e+26*cos(theta)**39 + 1.51429933648023e+26*cos(theta)**37 - 6.40332290854499e+25*cos(theta)**35 + 2.31187932681084e+25*cos(theta)**33 - 7.10933188442706e+24*cos(theta)**31 + 1.8551286903808e+24*cos(theta)**29 - 4.08671865596638e+23*cos(theta)**27 + 7.54967499075894e+22*cos(theta)**25 - 1.15970429965575e+22*cos(theta)**23 + 1.46556037868584e+21*cos(theta)**21 - 1.50350600646813e+20*cos(theta)**19 + 1.23131957426269e+19*cos(theta)**17 - 7.88044527528124e+17*cos(theta)**15 + 3.83432230724991e+16*cos(theta)**13 - 1.36752235923865e+15*cos(theta)**11 + 34002590306566.8*cos(theta)**9 - 548183274087.06*cos(theta)**7 + 5116377224.81256*cos(theta)**5 - 22608825.5625831*cos(theta)**3 + 29853.2027674953*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl67_m_minus_1(theta, phi):
    return 0.068672853303309*(1.0 - cos(theta)**2)**0.5*(6.80239631984055e+20*cos(theta)**66 - 1.09707820346301e+22*cos(theta)**64 + 8.44163991672298e+22*cos(theta)**62 - 4.12484265698273e+23*cos(theta)**60 + 1.43719911473611e+24*cos(theta)**58 - 3.80110421865406e+24*cos(theta)**56 + 7.93184349150034e+24*cos(theta)**54 - 1.34007887087804e+25*cos(theta)**52 + 1.86653842729441e+25*cos(theta)**50 - 2.17142409633015e+25*cos(theta)**48 + 2.12988380926993e+25*cos(theta)**46 - 1.77347525550633e+25*cos(theta)**44 + 1.25954023401576e+25*cos(theta)**42 - 7.65324023632723e+24*cos(theta)**40 + 3.98499825389536e+24*cos(theta)**38 - 1.77870080792916e+24*cos(theta)**36 + 6.79964507885542e+23*cos(theta)**34 - 2.22166621388346e+23*cos(theta)**32 + 6.18376230126933e+22*cos(theta)**30 - 1.45954237713085e+22*cos(theta)**28 + 2.9037211502919e+21*cos(theta)**26 - 4.83210124856563e+20*cos(theta)**24 + 6.66163808493564e+19*cos(theta)**22 - 7.51753003234066e+18*cos(theta)**20 + 6.84066430145941e+17*cos(theta)**18 - 4.92527829705077e+16*cos(theta)**16 + 2.73880164803565e+15*cos(theta)**14 - 113960196603221.0*cos(theta)**12 + 3400259030656.68*cos(theta)**10 - 68522909260.8825*cos(theta)**8 + 852729537.46876*cos(theta)**6 - 5652206.39064578*cos(theta)**4 + 14926.6013837477*cos(theta)**2 - 6.55538049352115)*sin(phi)

#@torch.jit.script
def Yl67_m0(theta, phi):
    return 1.04543961615921e+20*cos(theta)**67 - 1.73794510626166e+21*cos(theta)**65 + 1.37974267978025e+22*cos(theta)**63 - 6.96288747703055e+22*cos(theta)**61 + 2.50828426830037e+23*cos(theta)**59 - 6.8666790128991e+23*cos(theta)**57 + 1.48498911986273e+24*cos(theta)**55 - 2.60355235300609e+24*cos(theta)**53 + 3.76858733449831e+24*cos(theta)**51 - 4.56310432239824e+24*cos(theta)**49 + 4.66627015925246e+24*cos(theta)**47 - 4.05811588266445e+24*cos(theta)**45 + 3.01616721008844e+24*cos(theta)**43 - 1.92208820798155e+24*cos(theta)**41 + 1.0521444129138e+24*cos(theta)**39 - 4.95008895218493e+23*cos(theta)**37 + 2.00046070519124e+23*cos(theta)**35 - 6.9322895724449e+22*cos(theta)**33 + 2.05401172516886e+22*cos(theta)**31 - 5.18239529139186e+21*cos(theta)**29 + 1.10739604647637e+21*cos(theta)**27 - 1.99025095910499e+20*cos(theta)**25 + 2.98239404461287e+19*cos(theta)**23 - 3.68610499895973e+18*cos(theta)**21 + 3.707289510448e+17*cos(theta)**19 - 2.98327767664286e+16*cos(theta)**17 + 1.8801008527499e+15*cos(theta)**15 - 90265473040118.8*cos(theta)**13 + 3182959718412.87*cos(theta)**11 - 78398022621.0066*cos(theta)**9 + 1254368361.93611*cos(theta)**7 - 11640183.650313*cos(theta)**5 + 51233.2026862366*cos(theta)**3 - 67.5009258053183*cos(theta)

#@torch.jit.script
def Yl67_m1(theta, phi):
    return 0.068672853303309*(1.0 - cos(theta)**2)**0.5*(6.80239631984055e+20*cos(theta)**66 - 1.09707820346301e+22*cos(theta)**64 + 8.44163991672298e+22*cos(theta)**62 - 4.12484265698273e+23*cos(theta)**60 + 1.43719911473611e+24*cos(theta)**58 - 3.80110421865406e+24*cos(theta)**56 + 7.93184349150034e+24*cos(theta)**54 - 1.34007887087804e+25*cos(theta)**52 + 1.86653842729441e+25*cos(theta)**50 - 2.17142409633015e+25*cos(theta)**48 + 2.12988380926993e+25*cos(theta)**46 - 1.77347525550633e+25*cos(theta)**44 + 1.25954023401576e+25*cos(theta)**42 - 7.65324023632723e+24*cos(theta)**40 + 3.98499825389536e+24*cos(theta)**38 - 1.77870080792916e+24*cos(theta)**36 + 6.79964507885542e+23*cos(theta)**34 - 2.22166621388346e+23*cos(theta)**32 + 6.18376230126933e+22*cos(theta)**30 - 1.45954237713085e+22*cos(theta)**28 + 2.9037211502919e+21*cos(theta)**26 - 4.83210124856563e+20*cos(theta)**24 + 6.66163808493564e+19*cos(theta)**22 - 7.51753003234066e+18*cos(theta)**20 + 6.84066430145941e+17*cos(theta)**18 - 4.92527829705077e+16*cos(theta)**16 + 2.73880164803565e+15*cos(theta)**14 - 113960196603221.0*cos(theta)**12 + 3400259030656.68*cos(theta)**10 - 68522909260.8825*cos(theta)**8 + 852729537.46876*cos(theta)**6 - 5652206.39064578*cos(theta)**4 + 14926.6013837477*cos(theta)**2 - 6.55538049352115)*cos(phi)

#@torch.jit.script
def Yl67_m2(theta, phi):
    return 0.0010176269014232*(1.0 - cos(theta)**2)*(4.48958157109476e+22*cos(theta)**65 - 7.02130050216324e+23*cos(theta)**63 + 5.23381674836825e+24*cos(theta)**61 - 2.47490559418964e+25*cos(theta)**59 + 8.33575486546942e+25*cos(theta)**57 - 2.12861836244627e+26*cos(theta)**55 + 4.28319548541018e+26*cos(theta)**53 - 6.9684101285658e+26*cos(theta)**51 + 9.33269213647205e+26*cos(theta)**49 - 1.04228356623847e+27*cos(theta)**47 + 9.79746552264166e+26*cos(theta)**45 - 7.80329112422787e+26*cos(theta)**43 + 5.29006898286619e+26*cos(theta)**41 - 3.06129609453089e+26*cos(theta)**39 + 1.51429933648023e+26*cos(theta)**37 - 6.40332290854499e+25*cos(theta)**35 + 2.31187932681084e+25*cos(theta)**33 - 7.10933188442706e+24*cos(theta)**31 + 1.8551286903808e+24*cos(theta)**29 - 4.08671865596638e+23*cos(theta)**27 + 7.54967499075894e+22*cos(theta)**25 - 1.15970429965575e+22*cos(theta)**23 + 1.46556037868584e+21*cos(theta)**21 - 1.50350600646813e+20*cos(theta)**19 + 1.23131957426269e+19*cos(theta)**17 - 7.88044527528124e+17*cos(theta)**15 + 3.83432230724991e+16*cos(theta)**13 - 1.36752235923865e+15*cos(theta)**11 + 34002590306566.8*cos(theta)**9 - 548183274087.06*cos(theta)**7 + 5116377224.81256*cos(theta)**5 - 22608825.5625831*cos(theta)**3 + 29853.2027674953*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl67_m3(theta, phi):
    return 1.5086304905918e-5*(1.0 - cos(theta)**2)**1.5*(2.9182280212116e+24*cos(theta)**64 - 4.42341931636284e+25*cos(theta)**62 + 3.19262821650463e+26*cos(theta)**60 - 1.46019430057189e+27*cos(theta)**58 + 4.75138027331757e+27*cos(theta)**56 - 1.17074009934545e+28*cos(theta)**54 + 2.2700936072674e+28*cos(theta)**52 - 3.55388916556856e+28*cos(theta)**50 + 4.5730191468713e+28*cos(theta)**48 - 4.89873276132083e+28*cos(theta)**46 + 4.40885948518875e+28*cos(theta)**44 - 3.35541518341798e+28*cos(theta)**42 + 2.16892828297514e+28*cos(theta)**40 - 1.19390547686705e+28*cos(theta)**38 + 5.60290754497687e+27*cos(theta)**36 - 2.24116301799075e+27*cos(theta)**34 + 7.62920177847579e+26*cos(theta)**32 - 2.20389288417239e+26*cos(theta)**30 + 5.37987320210431e+25*cos(theta)**28 - 1.10341403711092e+25*cos(theta)**26 + 1.88741874768974e+24*cos(theta)**24 - 2.66731988920823e+23*cos(theta)**22 + 3.07767679524026e+22*cos(theta)**20 - 2.85666141228945e+21*cos(theta)**18 + 2.09324327624658e+20*cos(theta)**16 - 1.18206679129219e+19*cos(theta)**14 + 4.98461899942488e+17*cos(theta)**12 - 1.50427459516252e+16*cos(theta)**10 + 306023312759101.0*cos(theta)**8 - 3837282918609.42*cos(theta)**6 + 25581886124.0628*cos(theta)**4 - 67826476.6877494*cos(theta)**2 + 29853.2027674953)*cos(3*phi)

#@torch.jit.script
def Yl67_m4(theta, phi):
    return 2.23801874403292e-7*(1.0 - cos(theta)**2)**2*(1.86766593357542e+26*cos(theta)**63 - 2.74251997614496e+27*cos(theta)**61 + 1.91557692990278e+28*cos(theta)**59 - 8.46912694331694e+28*cos(theta)**57 + 2.66077295305784e+29*cos(theta)**55 - 6.32199653646543e+29*cos(theta)**53 + 1.18044867577905e+30*cos(theta)**51 - 1.77694458278428e+30*cos(theta)**49 + 2.19504919049823e+30*cos(theta)**47 - 2.25341707020758e+30*cos(theta)**45 + 1.93989817348305e+30*cos(theta)**43 - 1.40927437703555e+30*cos(theta)**41 + 8.67571313190055e+29*cos(theta)**39 - 4.53684081209478e+29*cos(theta)**37 + 2.01704671619167e+29*cos(theta)**35 - 7.61995426116854e+28*cos(theta)**33 + 2.44134456911225e+28*cos(theta)**31 - 6.61167865251716e+27*cos(theta)**29 + 1.50636449658921e+27*cos(theta)**27 - 2.8688764964884e+26*cos(theta)**25 + 4.52980499445537e+25*cos(theta)**23 - 5.8681037562581e+24*cos(theta)**21 + 6.15535359048053e+23*cos(theta)**19 - 5.14199054212101e+22*cos(theta)**17 + 3.34918924199453e+21*cos(theta)**15 - 1.65489350780906e+20*cos(theta)**13 + 5.98154279930986e+18*cos(theta)**11 - 1.50427459516252e+17*cos(theta)**9 + 2.44818650207281e+15*cos(theta)**7 - 23023697511656.5*cos(theta)**5 + 102327544496.251*cos(theta)**3 - 135652953.375499*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl67_m5(theta, phi):
    return 3.32297593863068e-9*(1.0 - cos(theta)**2)**2.5*(1.17662953815252e+28*cos(theta)**62 - 1.67293718544843e+29*cos(theta)**60 + 1.13019038864264e+30*cos(theta)**58 - 4.82740235769065e+30*cos(theta)**56 + 1.46342512418181e+31*cos(theta)**54 - 3.35065816432668e+31*cos(theta)**52 + 6.02028824647314e+31*cos(theta)**50 - 8.70702845564296e+31*cos(theta)**48 + 1.03167311953417e+32*cos(theta)**46 - 1.01403768159341e+32*cos(theta)**44 + 8.34156214597711e+31*cos(theta)**42 - 5.77802494584577e+31*cos(theta)**40 + 3.38352812144121e+31*cos(theta)**38 - 1.67863110047507e+31*cos(theta)**36 + 7.05966350667086e+30*cos(theta)**34 - 2.51458490618562e+30*cos(theta)**32 + 7.56816816424798e+29*cos(theta)**30 - 1.91738680922998e+29*cos(theta)**28 + 4.06718414079086e+28*cos(theta)**26 - 7.172191241221e+27*cos(theta)**24 + 1.04185514872473e+27*cos(theta)**22 - 1.2323017888142e+26*cos(theta)**20 + 1.1695171821913e+25*cos(theta)**18 - 8.74138392160571e+23*cos(theta)**16 + 5.02378386299179e+22*cos(theta)**14 - 2.15136156015178e+21*cos(theta)**12 + 6.57969707924084e+19*cos(theta)**10 - 1.35384713564626e+18*cos(theta)**8 + 1.71373055145097e+16*cos(theta)**6 - 115118487558283.0*cos(theta)**4 + 306982633488.754*cos(theta)**2 - 135652953.375499)*cos(5*phi)

#@torch.jit.script
def Yl67_m6(theta, phi):
    return 4.93935137207726e-11*(1.0 - cos(theta)**2)**3*(7.2951031365456e+29*cos(theta)**61 - 1.00376231126906e+31*cos(theta)**59 + 6.55510425412731e+31*cos(theta)**57 - 2.70334532030677e+32*cos(theta)**55 + 7.90249567058179e+32*cos(theta)**53 - 1.74234224544987e+33*cos(theta)**51 + 3.01014412323657e+33*cos(theta)**49 - 4.17937365870862e+33*cos(theta)**47 + 4.74569634985717e+33*cos(theta)**45 - 4.46176579901101e+33*cos(theta)**43 + 3.50345610131038e+33*cos(theta)**41 - 2.31120997833831e+33*cos(theta)**39 + 1.28574068614766e+33*cos(theta)**37 - 6.04307196171025e+32*cos(theta)**35 + 2.40028559226809e+32*cos(theta)**33 - 8.04667169979398e+31*cos(theta)**31 + 2.27045044927439e+31*cos(theta)**29 - 5.36868306584394e+30*cos(theta)**27 + 1.05746787660562e+30*cos(theta)**25 - 1.72132589789304e+29*cos(theta)**23 + 2.29208132719442e+28*cos(theta)**21 - 2.4646035776284e+27*cos(theta)**19 + 2.10513092794434e+26*cos(theta)**17 - 1.39862142745691e+25*cos(theta)**15 + 7.03329740818851e+23*cos(theta)**13 - 2.58163387218213e+22*cos(theta)**11 + 6.57969707924084e+20*cos(theta)**9 - 1.08307770851701e+19*cos(theta)**7 + 1.02823833087058e+17*cos(theta)**5 - 460473950233130.0*cos(theta)**3 + 613965266977.507*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl67_m7(theta, phi):
    return 7.35172315555162e-13*(1.0 - cos(theta)**2)**3.5*(4.45001291329281e+31*cos(theta)**60 - 5.92219763648743e+32*cos(theta)**58 + 3.73640942485257e+33*cos(theta)**56 - 1.48683992616872e+34*cos(theta)**54 + 4.18832270540835e+34*cos(theta)**52 - 8.88594545179435e+34*cos(theta)**50 + 1.47497062038592e+35*cos(theta)**48 - 1.96430561959305e+35*cos(theta)**46 + 2.13556335743572e+35*cos(theta)**44 - 1.91855929357473e+35*cos(theta)**42 + 1.43641700153726e+35*cos(theta)**40 - 9.0137189155194e+34*cos(theta)**38 + 4.75724053874635e+34*cos(theta)**36 - 2.11507518659859e+34*cos(theta)**34 + 7.9209424544847e+33*cos(theta)**32 - 2.49446822693613e+33*cos(theta)**30 + 6.58430630289574e+32*cos(theta)**28 - 1.44954442777786e+32*cos(theta)**26 + 2.64366969151406e+31*cos(theta)**24 - 3.95904956515399e+30*cos(theta)**22 + 4.81337078710827e+29*cos(theta)**20 - 4.68274679749397e+28*cos(theta)**18 + 3.57872257750538e+27*cos(theta)**16 - 2.09793214118537e+26*cos(theta)**14 + 9.14328663064506e+24*cos(theta)**12 - 2.83979725940035e+23*cos(theta)**10 + 5.92172737131676e+21*cos(theta)**8 - 7.58154395961908e+19*cos(theta)**6 + 5.1411916543529e+17*cos(theta)**4 - 1.38142185069939e+15*cos(theta)**2 + 613965266977.507)*cos(7*phi)

#@torch.jit.script
def Yl67_m8(theta, phi):
    return 1.09593018183818e-14*(1.0 - cos(theta)**2)**4*(2.67000774797569e+33*cos(theta)**59 - 3.43487462916271e+34*cos(theta)**57 + 2.09238927791744e+35*cos(theta)**55 - 8.0289356013111e+35*cos(theta)**53 + 2.17792780681234e+36*cos(theta)**51 - 4.44297272589717e+36*cos(theta)**49 + 7.07985897785241e+36*cos(theta)**47 - 9.03580585012804e+36*cos(theta)**45 + 9.39647877271719e+36*cos(theta)**43 - 8.05794903301388e+36*cos(theta)**41 + 5.74566800614903e+36*cos(theta)**39 - 3.42521318789737e+36*cos(theta)**37 + 1.71260659394869e+36*cos(theta)**35 - 7.1912556344352e+35*cos(theta)**33 + 2.5347015854351e+35*cos(theta)**31 - 7.4834046808084e+34*cos(theta)**29 + 1.84360576481081e+34*cos(theta)**27 - 3.76881551222244e+33*cos(theta)**25 + 6.34480725963374e+32*cos(theta)**23 - 8.70990904333878e+31*cos(theta)**21 + 9.62674157421655e+30*cos(theta)**19 - 8.42894423548914e+29*cos(theta)**17 + 5.72595612400861e+28*cos(theta)**15 - 2.93710499765952e+27*cos(theta)**13 + 1.09719439567741e+26*cos(theta)**11 - 2.83979725940035e+24*cos(theta)**9 + 4.73738189705341e+22*cos(theta)**7 - 4.54892637577145e+20*cos(theta)**5 + 2.05647666174116e+18*cos(theta)**3 - 2.76284370139878e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl67_m9(theta, phi):
    return 1.63662840929083e-16*(1.0 - cos(theta)**2)**4.5*(1.57530457130566e+35*cos(theta)**58 - 1.95787853862274e+36*cos(theta)**56 + 1.15081410285459e+37*cos(theta)**54 - 4.25533586869488e+37*cos(theta)**52 + 1.11074318147429e+38*cos(theta)**50 - 2.17705663568962e+38*cos(theta)**48 + 3.32753371959063e+38*cos(theta)**46 - 4.06611263255762e+38*cos(theta)**44 + 4.04048587226839e+38*cos(theta)**42 - 3.30375910353569e+38*cos(theta)**40 + 2.24081052239812e+38*cos(theta)**38 - 1.26732887952203e+38*cos(theta)**36 + 5.9941230788204e+37*cos(theta)**34 - 2.37311435936362e+37*cos(theta)**32 + 7.85757491484882e+36*cos(theta)**30 - 2.17018735743444e+36*cos(theta)**28 + 4.97773556498918e+35*cos(theta)**26 - 9.42203878055611e+34*cos(theta)**24 + 1.45930566971576e+34*cos(theta)**22 - 1.82908089910114e+33*cos(theta)**20 + 1.82908089910114e+32*cos(theta)**18 - 1.43292052003315e+31*cos(theta)**16 + 8.58893418601291e+29*cos(theta)**14 - 3.81823649695738e+28*cos(theta)**12 + 1.20691383524515e+27*cos(theta)**10 - 2.55581753346031e+25*cos(theta)**8 + 3.31616732793738e+23*cos(theta)**6 - 2.27446318788572e+21*cos(theta)**4 + 6.16942998522348e+18*cos(theta)**2 - 2.76284370139878e+15)*cos(9*phi)

#@torch.jit.script
def Yl67_m10(theta, phi):
    return 2.44901094584075e-18*(1.0 - cos(theta)**2)**5*(9.13676651357281e+36*cos(theta)**57 - 1.09641198162874e+38*cos(theta)**55 + 6.21439615541479e+38*cos(theta)**53 - 2.21277465172134e+39*cos(theta)**51 + 5.55371590737147e+39*cos(theta)**49 - 1.04498718513102e+40*cos(theta)**47 + 1.53066551101169e+40*cos(theta)**45 - 1.78908955832535e+40*cos(theta)**43 + 1.69700406635272e+40*cos(theta)**41 - 1.32150364141428e+40*cos(theta)**39 + 8.51507998511286e+39*cos(theta)**37 - 4.5623839662793e+39*cos(theta)**35 + 2.03800184679894e+39*cos(theta)**33 - 7.59396594996357e+38*cos(theta)**31 + 2.35727247445465e+38*cos(theta)**29 - 6.07652460081642e+37*cos(theta)**27 + 1.29421124689719e+37*cos(theta)**25 - 2.26128930733347e+36*cos(theta)**23 + 3.21047247337467e+35*cos(theta)**21 - 3.65816179820229e+34*cos(theta)**19 + 3.29234561838206e+33*cos(theta)**17 - 2.29267283205305e+32*cos(theta)**15 + 1.20245078604181e+31*cos(theta)**13 - 4.58188379634885e+29*cos(theta)**11 + 1.20691383524515e+28*cos(theta)**9 - 2.04465402676825e+26*cos(theta)**7 + 1.98970039676243e+24*cos(theta)**5 - 9.09785275154289e+21*cos(theta)**3 + 1.2338859970447e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl67_m11(theta, phi):
    return 3.6728737220908e-20*(1.0 - cos(theta)**2)**5.5*(5.2079569127365e+38*cos(theta)**56 - 6.03026589895805e+39*cos(theta)**54 + 3.29362996236984e+40*cos(theta)**52 - 1.12851507237788e+41*cos(theta)**50 + 2.72132079461202e+41*cos(theta)**48 - 4.91143977011577e+41*cos(theta)**46 + 6.88799479955261e+41*cos(theta)**44 - 7.69308510079902e+41*cos(theta)**42 + 6.95771667204617e+41*cos(theta)**40 - 5.15386420151568e+41*cos(theta)**38 + 3.15057959449176e+41*cos(theta)**36 - 1.59683438819775e+41*cos(theta)**34 + 6.72540609443649e+40*cos(theta)**32 - 2.35412944448871e+40*cos(theta)**30 + 6.83609017591848e+39*cos(theta)**28 - 1.64066164222043e+39*cos(theta)**26 + 3.23552811724297e+38*cos(theta)**24 - 5.20096540686697e+37*cos(theta)**22 + 6.74199219408682e+36*cos(theta)**20 - 6.95050741658435e+35*cos(theta)**18 + 5.5969875512495e+34*cos(theta)**16 - 3.43900924807957e+33*cos(theta)**14 + 1.56318602185435e+32*cos(theta)**12 - 5.04007217598374e+30*cos(theta)**10 + 1.08622245172063e+29*cos(theta)**8 - 1.43125781873778e+27*cos(theta)**6 + 9.94850198381215e+24*cos(theta)**4 - 2.72935582546287e+22*cos(theta)**2 + 1.2338859970447e+19)*cos(11*phi)

#@torch.jit.script
def Yl67_m12(theta, phi):
    return 5.52202588211365e-22*(1.0 - cos(theta)**2)**6*(2.91645587113244e+40*cos(theta)**55 - 3.25634358543735e+41*cos(theta)**53 + 1.71268758043232e+42*cos(theta)**51 - 5.64257536188941e+42*cos(theta)**49 + 1.30623398141377e+43*cos(theta)**47 - 2.25926229425326e+43*cos(theta)**45 + 3.03071771180315e+43*cos(theta)**43 - 3.23109574233559e+43*cos(theta)**41 + 2.78308666881847e+43*cos(theta)**39 - 1.95846839657596e+43*cos(theta)**37 + 1.13420865401703e+43*cos(theta)**35 - 5.42923691987236e+42*cos(theta)**33 + 2.15212995021968e+42*cos(theta)**31 - 7.06238833346612e+41*cos(theta)**29 + 1.91410524925717e+41*cos(theta)**27 - 4.26572026977313e+40*cos(theta)**25 + 7.76526748138312e+39*cos(theta)**23 - 1.14421238951073e+39*cos(theta)**21 + 1.34839843881736e+38*cos(theta)**19 - 1.25109133498518e+37*cos(theta)**17 + 8.9551800819992e+35*cos(theta)**15 - 4.8146129473114e+34*cos(theta)**13 + 1.87582322622522e+33*cos(theta)**11 - 5.04007217598374e+31*cos(theta)**9 + 8.68977961376506e+29*cos(theta)**7 - 8.58754691242665e+27*cos(theta)**5 + 3.97940079352486e+25*cos(theta)**3 - 5.45871165092574e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl67_m13(theta, phi):
    return 8.32476724254649e-24*(1.0 - cos(theta)**2)**6.5*(1.60405072912284e+42*cos(theta)**54 - 1.72586210028179e+43*cos(theta)**52 + 8.73470666020481e+43*cos(theta)**50 - 2.76486192732581e+44*cos(theta)**48 + 6.13929971264471e+44*cos(theta)**46 - 1.01666803241396e+45*cos(theta)**44 + 1.30320861607535e+45*cos(theta)**42 - 1.32474925435759e+45*cos(theta)**40 + 1.0854038008392e+45*cos(theta)**38 - 7.24633306733105e+44*cos(theta)**36 + 3.96973028905962e+44*cos(theta)**34 - 1.79164818355788e+44*cos(theta)**32 + 6.671602845681e+43*cos(theta)**30 - 2.04809261670518e+43*cos(theta)**28 + 5.16808417299437e+42*cos(theta)**26 - 1.06643006744328e+42*cos(theta)**24 + 1.78601152071812e+41*cos(theta)**22 - 2.40284601797254e+40*cos(theta)**20 + 2.56195703375299e+39*cos(theta)**18 - 2.12685526947481e+38*cos(theta)**16 + 1.34327701229988e+37*cos(theta)**14 - 6.25899683150482e+35*cos(theta)**12 + 2.06340554884774e+34*cos(theta)**10 - 4.53606495838536e+32*cos(theta)**8 + 6.08284572963554e+30*cos(theta)**6 - 4.29377345621333e+28*cos(theta)**4 + 1.19382023805746e+26*cos(theta)**2 - 5.45871165092574e+22)*cos(13*phi)

#@torch.jit.script
def Yl67_m14(theta, phi):
    return 1.25873036862192e-25*(1.0 - cos(theta)**2)**7*(8.66187393726335e+43*cos(theta)**53 - 8.97448292146533e+44*cos(theta)**51 + 4.3673533301024e+45*cos(theta)**49 - 1.32713372511639e+46*cos(theta)**47 + 2.82407786781657e+46*cos(theta)**45 - 4.47333934262145e+46*cos(theta)**43 + 5.47347618751648e+46*cos(theta)**41 - 5.29899701743036e+46*cos(theta)**39 + 4.12453444318897e+46*cos(theta)**37 - 2.60867990423918e+46*cos(theta)**35 + 1.34970829828027e+46*cos(theta)**33 - 5.73327418738522e+45*cos(theta)**31 + 2.0014808537043e+45*cos(theta)**29 - 5.73465932677449e+44*cos(theta)**27 + 1.34370188497854e+44*cos(theta)**25 - 2.55943216186388e+43*cos(theta)**23 + 3.92922534557986e+42*cos(theta)**21 - 4.80569203594508e+41*cos(theta)**19 + 4.61152266075538e+40*cos(theta)**17 - 3.4029684311597e+39*cos(theta)**15 + 1.88058781721983e+38*cos(theta)**13 - 7.51079619780578e+36*cos(theta)**11 + 2.06340554884774e+35*cos(theta)**9 - 3.62885196670829e+33*cos(theta)**7 + 3.64970743778133e+31*cos(theta)**5 - 1.71750938248533e+29*cos(theta)**3 + 2.38764047611492e+26*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl67_m15(theta, phi):
    return 1.9093601283182e-27*(1.0 - cos(theta)**2)**7.5*(4.59079318674957e+45*cos(theta)**52 - 4.57698628994732e+46*cos(theta)**50 + 2.14000313175018e+47*cos(theta)**48 - 6.23752850804703e+47*cos(theta)**46 + 1.27083504051746e+48*cos(theta)**44 - 1.92353591732722e+48*cos(theta)**42 + 2.24412523688176e+48*cos(theta)**40 - 2.06660883679784e+48*cos(theta)**38 + 1.52607774397992e+48*cos(theta)**36 - 9.13037966483712e+47*cos(theta)**34 + 4.45403738432489e+47*cos(theta)**32 - 1.77731499808942e+47*cos(theta)**30 + 5.80429447574247e+46*cos(theta)**28 - 1.54835801822911e+46*cos(theta)**26 + 3.35925471244634e+45*cos(theta)**24 - 5.88669397228692e+44*cos(theta)**22 + 8.25137322571771e+43*cos(theta)**20 - 9.13081486829566e+42*cos(theta)**18 + 7.83958852328415e+41*cos(theta)**16 - 5.10445264673954e+40*cos(theta)**14 + 2.44476416238578e+39*cos(theta)**12 - 8.26187581758636e+37*cos(theta)**10 + 1.85706499396297e+36*cos(theta)**8 - 2.5401963766958e+34*cos(theta)**6 + 1.82485371889066e+32*cos(theta)**4 - 5.15252814745599e+29*cos(theta)**2 + 2.38764047611492e+26)*cos(15*phi)

#@torch.jit.script
def Yl67_m16(theta, phi):
    return 2.90634476570711e-29*(1.0 - cos(theta)**2)**8*(2.38721245710978e+47*cos(theta)**51 - 2.28849314497366e+48*cos(theta)**49 + 1.02720150324009e+49*cos(theta)**47 - 2.86926311370163e+49*cos(theta)**45 + 5.59167417827681e+49*cos(theta)**43 - 8.07885085277433e+49*cos(theta)**41 + 8.97650094752703e+49*cos(theta)**39 - 7.8531135798318e+49*cos(theta)**37 + 5.49387987832771e+49*cos(theta)**35 - 3.10432908604462e+49*cos(theta)**33 + 1.42529196298397e+49*cos(theta)**31 - 5.33194499426825e+48*cos(theta)**29 + 1.62520245320789e+48*cos(theta)**27 - 4.02573084739569e+47*cos(theta)**25 + 8.06221130987121e+46*cos(theta)**23 - 1.29507267390312e+46*cos(theta)**21 + 1.65027464514354e+45*cos(theta)**19 - 1.64354667629322e+44*cos(theta)**17 + 1.25433416372546e+43*cos(theta)**15 - 7.14623370543536e+41*cos(theta)**13 + 2.93371699486294e+40*cos(theta)**11 - 8.26187581758636e+38*cos(theta)**9 + 1.48565199517037e+37*cos(theta)**7 - 1.52411782601748e+35*cos(theta)**5 + 7.29941487556265e+32*cos(theta)**3 - 1.0305056294912e+30*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl67_m17(theta, phi):
    return 4.44040313094919e-31*(1.0 - cos(theta)**2)**8.5*(1.21747835312599e+49*cos(theta)**50 - 1.12136164103709e+50*cos(theta)**48 + 4.8278470652284e+50*cos(theta)**46 - 1.29116840116574e+51*cos(theta)**44 + 2.40441989665903e+51*cos(theta)**42 - 3.31232884963748e+51*cos(theta)**40 + 3.50083536953554e+51*cos(theta)**38 - 2.90565202453776e+51*cos(theta)**36 + 1.9228579574147e+51*cos(theta)**34 - 1.02442859839472e+51*cos(theta)**32 + 4.41840508525029e+50*cos(theta)**30 - 1.54626404833779e+50*cos(theta)**28 + 4.3880466236613e+49*cos(theta)**26 - 1.00643271184892e+49*cos(theta)**24 + 1.85430860127038e+48*cos(theta)**22 - 2.71965261519656e+47*cos(theta)**20 + 3.13552182577273e+46*cos(theta)**18 - 2.79402934969847e+45*cos(theta)**16 + 1.8815012455882e+44*cos(theta)**14 - 9.29010381706597e+42*cos(theta)**12 + 3.22708869434923e+41*cos(theta)**10 - 7.43568823582772e+39*cos(theta)**8 + 1.03995639661926e+38*cos(theta)**6 - 7.62058913008741e+35*cos(theta)**4 + 2.1898244626688e+33*cos(theta)**2 - 1.0305056294912e+30)*cos(17*phi)

#@torch.jit.script
def Yl67_m18(theta, phi):
    return 6.81126747561255e-33*(1.0 - cos(theta)**2)**9*(6.08739176562994e+50*cos(theta)**49 - 5.38253587697805e+51*cos(theta)**47 + 2.22080965000506e+52*cos(theta)**45 - 5.68114096512924e+52*cos(theta)**43 + 1.00985635659679e+53*cos(theta)**41 - 1.32493153985499e+53*cos(theta)**39 + 1.33031744042351e+53*cos(theta)**37 - 1.0460347288336e+53*cos(theta)**35 + 6.53771705520997e+52*cos(theta)**33 - 3.27817151486312e+52*cos(theta)**31 + 1.32552152557509e+52*cos(theta)**29 - 4.32953933534582e+51*cos(theta)**27 + 1.14089212215194e+51*cos(theta)**25 - 2.41543850843742e+50*cos(theta)**23 + 4.07947892279483e+49*cos(theta)**21 - 5.43930523039311e+48*cos(theta)**19 + 5.64393928639091e+47*cos(theta)**17 - 4.47044695951755e+46*cos(theta)**15 + 2.63410174382347e+45*cos(theta)**13 - 1.11481245804792e+44*cos(theta)**11 + 3.22708869434923e+42*cos(theta)**9 - 5.94855058866218e+40*cos(theta)**7 + 6.23973837971557e+38*cos(theta)**5 - 3.04823565203496e+36*cos(theta)**3 + 4.37964892533759e+33*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl67_m19(theta, phi):
    return 1.04925408703669e-34*(1.0 - cos(theta)**2)**9.5*(2.98282196515867e+52*cos(theta)**48 - 2.52979186217968e+53*cos(theta)**46 + 9.99364342502279e+53*cos(theta)**44 - 2.44289061500557e+54*cos(theta)**42 + 4.14041106204684e+54*cos(theta)**40 - 5.16723300543446e+54*cos(theta)**38 + 4.92217452956697e+54*cos(theta)**36 - 3.66112155091758e+54*cos(theta)**34 + 2.15744662821929e+54*cos(theta)**32 - 1.01623316960757e+54*cos(theta)**30 + 3.84401242416775e+53*cos(theta)**28 - 1.16897562054337e+53*cos(theta)**26 + 2.85223030537985e+52*cos(theta)**24 - 5.55550856940605e+51*cos(theta)**22 + 8.56690573786915e+50*cos(theta)**20 - 1.03346799377469e+50*cos(theta)**18 + 9.59469678686455e+48*cos(theta)**16 - 6.70567043927633e+47*cos(theta)**14 + 3.42433226697052e+46*cos(theta)**12 - 1.22629370385271e+45*cos(theta)**10 + 2.90437982491431e+43*cos(theta)**8 - 4.16398541206352e+41*cos(theta)**6 + 3.11986918985779e+39*cos(theta)**4 - 9.14470695610489e+36*cos(theta)**2 + 4.37964892533759e+33)*cos(19*phi)

#@torch.jit.script
def Yl67_m20(theta, phi):
    return 1.6236799377161e-36*(1.0 - cos(theta)**2)**10*(1.43175454327616e+54*cos(theta)**47 - 1.16370425660265e+55*cos(theta)**45 + 4.39720310701003e+55*cos(theta)**43 - 1.02601405830234e+56*cos(theta)**41 + 1.65616442481874e+56*cos(theta)**39 - 1.9635485420651e+56*cos(theta)**37 + 1.77198283064411e+56*cos(theta)**35 - 1.24478132731198e+56*cos(theta)**33 + 6.90382921030173e+55*cos(theta)**31 - 3.0486995088227e+55*cos(theta)**29 + 1.07632347876697e+55*cos(theta)**27 - 3.03933661341277e+54*cos(theta)**25 + 6.84535273291163e+53*cos(theta)**23 - 1.22221188526933e+53*cos(theta)**21 + 1.71338114757383e+52*cos(theta)**19 - 1.86024238879444e+51*cos(theta)**17 + 1.53515148589833e+50*cos(theta)**15 - 9.38793861498686e+48*cos(theta)**13 + 4.10919872036462e+47*cos(theta)**11 - 1.22629370385271e+46*cos(theta)**9 + 2.32350385993145e+44*cos(theta)**7 - 2.49839124723811e+42*cos(theta)**5 + 1.24794767594311e+40*cos(theta)**3 - 1.82894139122098e+37*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl67_m21(theta, phi):
    return 2.52470220592105e-38*(1.0 - cos(theta)**2)**10.5*(6.72924635339796e+55*cos(theta)**46 - 5.23666915471194e+56*cos(theta)**44 + 1.89079733601431e+57*cos(theta)**42 - 4.20665763903959e+57*cos(theta)**40 + 6.45904125679308e+57*cos(theta)**38 - 7.26512960564085e+57*cos(theta)**36 + 6.20193990725439e+57*cos(theta)**34 - 4.10777838012953e+57*cos(theta)**32 + 2.14018705519354e+57*cos(theta)**30 - 8.84122857558583e+56*cos(theta)**28 + 2.90607339267082e+56*cos(theta)**26 - 7.59834153353191e+55*cos(theta)**24 + 1.57443112856968e+55*cos(theta)**22 - 2.5666449590656e+54*cos(theta)**20 + 3.25542418039028e+53*cos(theta)**18 - 3.16241206095056e+52*cos(theta)**16 + 2.30272722884749e+51*cos(theta)**14 - 1.22043201994829e+50*cos(theta)**12 + 4.52011859240108e+48*cos(theta)**10 - 1.10366433346744e+47*cos(theta)**8 + 1.62645270195201e+45*cos(theta)**6 - 1.24919562361906e+43*cos(theta)**4 + 3.74384302782934e+40*cos(theta)**2 - 1.82894139122098e+37)*cos(21*phi)

#@torch.jit.script
def Yl67_m22(theta, phi):
    return 3.94581064705218e-40*(1.0 - cos(theta)**2)**11*(3.09545332256306e+57*cos(theta)**45 - 2.30413442807325e+58*cos(theta)**43 + 7.94134881126011e+58*cos(theta)**41 - 1.68266305561584e+59*cos(theta)**39 + 2.45443567758137e+59*cos(theta)**37 - 2.61544665803071e+59*cos(theta)**35 + 2.10865956846649e+59*cos(theta)**33 - 1.31448908164145e+59*cos(theta)**31 + 6.42056116558061e+58*cos(theta)**29 - 2.47554400116403e+58*cos(theta)**27 + 7.55579082094414e+57*cos(theta)**25 - 1.82360196804766e+57*cos(theta)**23 + 3.46374848285329e+56*cos(theta)**21 - 5.1332899181312e+55*cos(theta)**19 + 5.8597635247025e+54*cos(theta)**17 - 5.05985929752089e+53*cos(theta)**15 + 3.22381812038649e+52*cos(theta)**13 - 1.46451842393795e+51*cos(theta)**11 + 4.52011859240108e+49*cos(theta)**9 - 8.8293146677395e+47*cos(theta)**7 + 9.75871621171208e+45*cos(theta)**5 - 4.99678249447623e+43*cos(theta)**3 + 7.48768605565868e+40*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl67_m23(theta, phi):
    return 6.20024325735262e-42*(1.0 - cos(theta)**2)**11.5*(1.39295399515338e+59*cos(theta)**44 - 9.907778040715e+59*cos(theta)**42 + 3.25595301261665e+60*cos(theta)**40 - 6.56238591690177e+60*cos(theta)**38 + 9.08141200705107e+60*cos(theta)**36 - 9.15406330310748e+60*cos(theta)**34 + 6.95857657593942e+60*cos(theta)**32 - 4.07491615308849e+60*cos(theta)**30 + 1.86196273801838e+60*cos(theta)**28 - 6.68396880314289e+59*cos(theta)**26 + 1.88894770523603e+59*cos(theta)**24 - 4.19428452650962e+58*cos(theta)**22 + 7.2738718139919e+57*cos(theta)**20 - 9.75325084444927e+56*cos(theta)**18 + 9.96159799199425e+55*cos(theta)**16 - 7.58978894628133e+54*cos(theta)**14 + 4.19096355650243e+53*cos(theta)**12 - 1.61097026633175e+52*cos(theta)**10 + 4.06810673316097e+50*cos(theta)**8 - 6.18052026741765e+48*cos(theta)**6 + 4.87935810585604e+46*cos(theta)**4 - 1.49903474834287e+44*cos(theta)**2 + 7.48768605565868e+40)*cos(23*phi)

#@torch.jit.script
def Yl67_m24(theta, phi):
    return 9.79854732071393e-44*(1.0 - cos(theta)**2)**12*(6.12899757867486e+60*cos(theta)**43 - 4.1612667771003e+61*cos(theta)**41 + 1.30238120504666e+62*cos(theta)**39 - 2.49370664842267e+62*cos(theta)**37 + 3.26930832253838e+62*cos(theta)**35 - 3.11238152305654e+62*cos(theta)**33 + 2.22674450430062e+62*cos(theta)**31 - 1.22247484592655e+62*cos(theta)**29 + 5.21349566645145e+61*cos(theta)**27 - 1.73783188881715e+61*cos(theta)**25 + 4.53347449256648e+60*cos(theta)**23 - 9.22742595832116e+59*cos(theta)**21 + 1.45477436279838e+59*cos(theta)**19 - 1.75558515200087e+58*cos(theta)**17 + 1.59385567871908e+57*cos(theta)**15 - 1.06257045247939e+56*cos(theta)**13 + 5.02915626780292e+54*cos(theta)**11 - 1.61097026633175e+53*cos(theta)**9 + 3.25448538652878e+51*cos(theta)**7 - 3.70831216045059e+49*cos(theta)**5 + 1.95174324234241e+47*cos(theta)**3 - 2.99806949668574e+44*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl67_m25(theta, phi):
    return 1.55787838926532e-45*(1.0 - cos(theta)**2)**12.5*(2.63546895883019e+62*cos(theta)**42 - 1.70611937861112e+63*cos(theta)**40 + 5.07928669968197e+63*cos(theta)**38 - 9.22671459916388e+63*cos(theta)**36 + 1.14425791288843e+64*cos(theta)**34 - 1.02708590260866e+64*cos(theta)**32 + 6.90290796333191e+63*cos(theta)**30 - 3.54517705318699e+63*cos(theta)**28 + 1.40764382994189e+63*cos(theta)**26 - 4.34457972204288e+62*cos(theta)**24 + 1.04269913329029e+62*cos(theta)**22 - 1.93775945124744e+61*cos(theta)**20 + 2.76407128931692e+60*cos(theta)**18 - 2.98449475840148e+59*cos(theta)**16 + 2.39078351807862e+58*cos(theta)**14 - 1.3813415882232e+57*cos(theta)**12 + 5.53207189458321e+55*cos(theta)**10 - 1.44987323969857e+54*cos(theta)**8 + 2.27813977057014e+52*cos(theta)**6 - 1.85415608022529e+50*cos(theta)**4 + 5.85522972702724e+47*cos(theta)**2 - 2.99806949668574e+44)*cos(25*phi)

#@torch.jit.script
def Yl67_m26(theta, phi):
    return 2.49268519002688e-47*(1.0 - cos(theta)**2)**13*(1.10689696270868e+64*cos(theta)**41 - 6.82447751444449e+64*cos(theta)**39 + 1.93012894587915e+65*cos(theta)**37 - 3.321617255699e+65*cos(theta)**35 + 3.89047690382068e+65*cos(theta)**33 - 3.28667488834771e+65*cos(theta)**31 + 2.07087238899957e+65*cos(theta)**29 - 9.92649574892357e+64*cos(theta)**27 + 3.65987395784892e+64*cos(theta)**25 - 1.04269913329029e+64*cos(theta)**23 + 2.29393809323864e+63*cos(theta)**21 - 3.87551890249489e+62*cos(theta)**19 + 4.97532832077046e+61*cos(theta)**17 - 4.77519161344236e+60*cos(theta)**15 + 3.34709692531007e+59*cos(theta)**13 - 1.65760990586784e+58*cos(theta)**11 + 5.53207189458321e+56*cos(theta)**9 - 1.15989859175886e+55*cos(theta)**7 + 1.36688386234209e+53*cos(theta)**5 - 7.41662432090118e+50*cos(theta)**3 + 1.17104594540545e+48*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl67_m27(theta, phi):
    return 4.01524063862165e-49*(1.0 - cos(theta)**2)**13.5*(4.53827754710559e+65*cos(theta)**40 - 2.66154623063335e+66*cos(theta)**38 + 7.14147709975285e+66*cos(theta)**36 - 1.16256603949465e+67*cos(theta)**34 + 1.28385737826082e+67*cos(theta)**32 - 1.01886921538779e+67*cos(theta)**30 + 6.00552992809876e+66*cos(theta)**28 - 2.68015385220936e+66*cos(theta)**26 + 9.1496848946223e+65*cos(theta)**24 - 2.39820800656767e+65*cos(theta)**22 + 4.81726999580114e+64*cos(theta)**20 - 7.36348591474028e+63*cos(theta)**18 + 8.45805814530978e+62*cos(theta)**16 - 7.16278742016354e+61*cos(theta)**14 + 4.35122600290309e+60*cos(theta)**12 - 1.82337089645463e+59*cos(theta)**10 + 4.97886470512489e+57*cos(theta)**8 - 8.119290142312e+55*cos(theta)**6 + 6.83441931171044e+53*cos(theta)**4 - 2.22498729627035e+51*cos(theta)**2 + 1.17104594540545e+48)*cos(27*phi)

#@torch.jit.script
def Yl67_m28(theta, phi):
    return 6.51358042579195e-51*(1.0 - cos(theta)**2)**14*(1.81531101884223e+67*cos(theta)**39 - 1.01138756764067e+68*cos(theta)**37 + 2.57093175591102e+68*cos(theta)**35 - 3.95272453428181e+68*cos(theta)**33 + 4.10834361043463e+68*cos(theta)**31 - 3.05660764616337e+68*cos(theta)**29 + 1.68154837986765e+68*cos(theta)**27 - 6.96840001574434e+67*cos(theta)**25 + 2.19592437470935e+67*cos(theta)**23 - 5.27605761444887e+66*cos(theta)**21 + 9.63453999160229e+65*cos(theta)**19 - 1.32542746465325e+65*cos(theta)**17 + 1.35328930324957e+64*cos(theta)**15 - 1.0027902388229e+63*cos(theta)**13 + 5.22147120348371e+61*cos(theta)**11 - 1.82337089645463e+60*cos(theta)**9 + 3.98309176409991e+58*cos(theta)**7 - 4.8715740853872e+56*cos(theta)**5 + 2.73376772468417e+54*cos(theta)**3 - 4.44997459254071e+51*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl67_m29(theta, phi):
    return 1.06451518251504e-52*(1.0 - cos(theta)**2)**14.5*(7.07971297348471e+68*cos(theta)**38 - 3.74213400027049e+69*cos(theta)**36 + 8.99826114568859e+69*cos(theta)**34 - 1.304399096313e+70*cos(theta)**32 + 1.27358651923474e+70*cos(theta)**30 - 8.86416217387377e+69*cos(theta)**28 + 4.54018062564266e+69*cos(theta)**26 - 1.74210000393609e+69*cos(theta)**24 + 5.05062606183151e+68*cos(theta)**22 - 1.10797209903426e+68*cos(theta)**20 + 1.83056259840443e+67*cos(theta)**18 - 2.25322668991053e+66*cos(theta)**16 + 2.02993395487435e+65*cos(theta)**14 - 1.30362731046977e+64*cos(theta)**12 + 5.74361832383208e+62*cos(theta)**10 - 1.64103380680916e+61*cos(theta)**8 + 2.78816423486994e+59*cos(theta)**6 - 2.4357870426936e+57*cos(theta)**4 + 8.20130317405252e+54*cos(theta)**2 - 4.44997459254071e+51)*cos(29*phi)

#@torch.jit.script
def Yl67_m30(theta, phi):
    return 1.75337251484502e-54*(1.0 - cos(theta)**2)**15*(2.69029092992419e+70*cos(theta)**37 - 1.34716824009738e+71*cos(theta)**35 + 3.05940878953412e+71*cos(theta)**33 - 4.17407710820159e+71*cos(theta)**31 + 3.82075955770421e+71*cos(theta)**29 - 2.48196540868465e+71*cos(theta)**27 + 1.18044696266709e+71*cos(theta)**25 - 4.18104000944661e+70*cos(theta)**23 + 1.11113773360293e+70*cos(theta)**21 - 2.21594419806853e+69*cos(theta)**19 + 3.29501267712798e+68*cos(theta)**17 - 3.60516270385684e+67*cos(theta)**15 + 2.84190753682409e+66*cos(theta)**13 - 1.56435277256372e+65*cos(theta)**11 + 5.74361832383208e+63*cos(theta)**9 - 1.31282704544733e+62*cos(theta)**7 + 1.67289854092196e+60*cos(theta)**5 - 9.7431481707744e+57*cos(theta)**3 + 1.6402606348105e+55*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl67_m31(theta, phi):
    return 2.91179163841494e-56*(1.0 - cos(theta)**2)**15.5*(9.95407644071951e+71*cos(theta)**36 - 4.71508884034082e+72*cos(theta)**34 + 1.00960490054626e+73*cos(theta)**32 - 1.29396390354249e+73*cos(theta)**30 + 1.10802027173422e+73*cos(theta)**28 - 6.70130660344857e+72*cos(theta)**26 + 2.95111740666773e+72*cos(theta)**24 - 9.6163920217272e+71*cos(theta)**22 + 2.33338924056616e+71*cos(theta)**20 - 4.2102939763302e+70*cos(theta)**18 + 5.60152155111757e+69*cos(theta)**16 - 5.40774405578526e+68*cos(theta)**14 + 3.69447979787131e+67*cos(theta)**12 - 1.72078804982009e+66*cos(theta)**10 + 5.16925649144887e+64*cos(theta)**8 - 9.18978931813132e+62*cos(theta)**6 + 8.36449270460982e+60*cos(theta)**4 - 2.92294445123232e+58*cos(theta)**2 + 1.6402606348105e+55)*cos(31*phi)

#@torch.jit.script
def Yl67_m32(theta, phi):
    return 4.87743451127099e-58*(1.0 - cos(theta)**2)**16*(3.58346751865902e+73*cos(theta)**35 - 1.60313020571588e+74*cos(theta)**33 + 3.23073568174803e+74*cos(theta)**31 - 3.88189171062748e+74*cos(theta)**29 + 3.10245676085582e+74*cos(theta)**27 - 1.74233971689663e+74*cos(theta)**25 + 7.08268177600255e+73*cos(theta)**23 - 2.11560624477998e+73*cos(theta)**21 + 4.66677848113232e+72*cos(theta)**19 - 7.57852915739436e+71*cos(theta)**17 + 8.96243448178811e+70*cos(theta)**15 - 7.57084167809937e+69*cos(theta)**13 + 4.43337575744558e+68*cos(theta)**11 - 1.72078804982009e+67*cos(theta)**9 + 4.13540519315909e+65*cos(theta)**7 - 5.51387359087879e+63*cos(theta)**5 + 3.34579708184393e+61*cos(theta)**3 - 5.84588890246464e+58*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl67_m33(theta, phi):
    return 8.24436905872075e-60*(1.0 - cos(theta)**2)**16.5*(1.25421363153066e+75*cos(theta)**34 - 5.2903296788624e+75*cos(theta)**32 + 1.00152806134189e+76*cos(theta)**30 - 1.12574859608197e+76*cos(theta)**28 + 8.37663325431071e+75*cos(theta)**26 - 4.35584929224157e+75*cos(theta)**24 + 1.62901680848059e+75*cos(theta)**22 - 4.44277311403796e+74*cos(theta)**20 + 8.8668791141514e+73*cos(theta)**18 - 1.28834995675704e+73*cos(theta)**16 + 1.34436517226822e+72*cos(theta)**14 - 9.84209418152918e+70*cos(theta)**12 + 4.87671333319013e+69*cos(theta)**10 - 1.54870924483808e+68*cos(theta)**8 + 2.89478363521137e+66*cos(theta)**6 - 2.7569367954394e+64*cos(theta)**4 + 1.00373912455318e+62*cos(theta)**2 - 5.84588890246464e+58)*cos(33*phi)

#@torch.jit.script
def Yl67_m34(theta, phi):
    return 1.40688072396819e-61*(1.0 - cos(theta)**2)**17*(4.26432634720424e+76*cos(theta)**33 - 1.69290549723597e+77*cos(theta)**31 + 3.00458418402567e+77*cos(theta)**29 - 3.15209606902951e+77*cos(theta)**27 + 2.17792464612078e+77*cos(theta)**25 - 1.04540383013798e+77*cos(theta)**23 + 3.58383697865729e+76*cos(theta)**21 - 8.88554622807593e+75*cos(theta)**19 + 1.59603824054725e+75*cos(theta)**17 - 2.06135993081127e+74*cos(theta)**15 + 1.8821112411755e+73*cos(theta)**13 - 1.1810513017835e+72*cos(theta)**11 + 4.87671333319013e+70*cos(theta)**9 - 1.23896739587046e+69*cos(theta)**7 + 1.73687018112682e+67*cos(theta)**5 - 1.10277471817576e+65*cos(theta)**3 + 2.00747824910636e+62*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl67_m35(theta, phi):
    return 2.42493567885078e-63*(1.0 - cos(theta)**2)**17.5*(1.4072276945774e+78*cos(theta)**32 - 5.2480070414315e+78*cos(theta)**30 + 8.71329413367444e+78*cos(theta)**28 - 8.51065938637968e+78*cos(theta)**26 + 5.44481161530196e+78*cos(theta)**24 - 2.40442880931735e+78*cos(theta)**22 + 7.52605765518031e+77*cos(theta)**20 - 1.68825378333443e+77*cos(theta)**18 + 2.71326500893033e+76*cos(theta)**16 - 3.0920398962169e+75*cos(theta)**14 + 2.44674461352815e+74*cos(theta)**12 - 1.29915643196185e+73*cos(theta)**10 + 4.38904199987112e+71*cos(theta)**8 - 8.67277177109325e+69*cos(theta)**6 + 8.6843509056341e+67*cos(theta)**4 - 3.30832415452728e+65*cos(theta)**2 + 2.00747824910636e+62)*cos(35*phi)

#@torch.jit.script
def Yl67_m36(theta, phi):
    return 4.22383186247248e-65*(1.0 - cos(theta)**2)**18*(4.50312862264767e+79*cos(theta)**31 - 1.57440211242945e+80*cos(theta)**29 + 2.43972235742884e+80*cos(theta)**27 - 2.21277144045872e+80*cos(theta)**25 + 1.30675478767247e+80*cos(theta)**23 - 5.28974338049816e+79*cos(theta)**21 + 1.50521153103606e+79*cos(theta)**19 - 3.03885681000197e+78*cos(theta)**17 + 4.34122401428853e+77*cos(theta)**15 - 4.32885585470366e+76*cos(theta)**13 + 2.93609353623379e+75*cos(theta)**11 - 1.29915643196185e+74*cos(theta)**9 + 3.5112335998969e+72*cos(theta)**7 - 5.20366306265595e+70*cos(theta)**5 + 3.47374036225364e+68*cos(theta)**3 - 6.61664830905455e+65*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl67_m37(theta, phi):
    return 7.43890659123167e-67*(1.0 - cos(theta)**2)**18.5*(1.39596987302078e+81*cos(theta)**30 - 4.56576612604541e+81*cos(theta)**28 + 6.58725036505787e+81*cos(theta)**26 - 5.53192860114679e+81*cos(theta)**24 + 3.00553601164668e+81*cos(theta)**22 - 1.11084610990461e+81*cos(theta)**20 + 2.85990190896852e+80*cos(theta)**18 - 5.16605657700335e+79*cos(theta)**16 + 6.51183602143279e+78*cos(theta)**14 - 5.62751261111476e+77*cos(theta)**12 + 3.22970288985716e+76*cos(theta)**10 - 1.16924078876567e+75*cos(theta)**8 + 2.45786351992783e+73*cos(theta)**6 - 2.60183153132798e+71*cos(theta)**4 + 1.04212210867609e+69*cos(theta)**2 - 6.61664830905455e+65)*cos(37*phi)

#@torch.jit.script
def Yl67_m38(theta, phi):
    return 1.3254209426954e-68*(1.0 - cos(theta)**2)**19*(4.18790961906234e+82*cos(theta)**29 - 1.27841451529271e+83*cos(theta)**27 + 1.71268509491505e+83*cos(theta)**25 - 1.32766286427523e+83*cos(theta)**23 + 6.6121792256227e+82*cos(theta)**21 - 2.22169221980923e+82*cos(theta)**19 + 5.14782343614333e+81*cos(theta)**17 - 8.26569052320535e+80*cos(theta)**15 + 9.1165704300059e+79*cos(theta)**13 - 6.75301513333771e+78*cos(theta)**11 + 3.22970288985716e+77*cos(theta)**9 - 9.35392631012533e+75*cos(theta)**7 + 1.4747181119567e+74*cos(theta)**5 - 1.04073261253119e+72*cos(theta)**3 + 2.08424421735218e+69*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl67_m39(theta, phi):
    return 2.3905723769247e-70*(1.0 - cos(theta)**2)**19.5*(1.21449378952808e+84*cos(theta)**28 - 3.45171919129033e+84*cos(theta)**26 + 4.28171273728762e+84*cos(theta)**24 - 3.05362458783303e+84*cos(theta)**22 + 1.38855763738077e+84*cos(theta)**20 - 4.22121521763753e+83*cos(theta)**18 + 8.75129984144367e+82*cos(theta)**16 - 1.2398535784808e+82*cos(theta)**14 + 1.18515415590077e+81*cos(theta)**12 - 7.42831664667148e+79*cos(theta)**10 + 2.90673260087145e+78*cos(theta)**8 - 6.54774841708773e+76*cos(theta)**6 + 7.37359055978348e+74*cos(theta)**4 - 3.12219783759357e+72*cos(theta)**2 + 2.08424421735218e+69)*cos(39*phi)

#@torch.jit.script
def Yl67_m40(theta, phi):
    return 4.36748067895281e-72*(1.0 - cos(theta)**2)**20*(3.40058261067862e+85*cos(theta)**27 - 8.97446989735485e+85*cos(theta)**25 + 1.02761105694903e+86*cos(theta)**23 - 6.71797409323267e+85*cos(theta)**21 + 2.77711527476154e+85*cos(theta)**19 - 7.59818739174756e+84*cos(theta)**17 + 1.40020797463099e+84*cos(theta)**15 - 1.73579500987312e+83*cos(theta)**13 + 1.42218498708092e+82*cos(theta)**11 - 7.42831664667148e+80*cos(theta)**9 + 2.32538608069716e+79*cos(theta)**7 - 3.92864905025264e+77*cos(theta)**5 + 2.94943622391339e+75*cos(theta)**3 - 6.24439567518714e+72*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl67_m41(theta, phi):
    return 8.08792718324593e-74*(1.0 - cos(theta)**2)**20.5*(9.18157304883227e+86*cos(theta)**26 - 2.24361747433871e+87*cos(theta)**24 + 2.36350543098277e+87*cos(theta)**22 - 1.41077455957886e+87*cos(theta)**20 + 5.27651902204692e+86*cos(theta)**18 - 1.29169185659709e+86*cos(theta)**16 + 2.10031196194648e+85*cos(theta)**14 - 2.25653351283506e+84*cos(theta)**12 + 1.56440348578901e+83*cos(theta)**10 - 6.68548498200433e+81*cos(theta)**8 + 1.62777025648801e+80*cos(theta)**6 - 1.96432452512632e+78*cos(theta)**4 + 8.84830867174018e+75*cos(theta)**2 - 6.24439567518714e+72)*cos(41*phi)

#@torch.jit.script
def Yl67_m42(theta, phi):
    return 1.51927821190258e-75*(1.0 - cos(theta)**2)**21*(2.38720899269639e+88*cos(theta)**25 - 5.38468193841291e+88*cos(theta)**23 + 5.19971194816208e+88*cos(theta)**21 - 2.82154911915772e+88*cos(theta)**19 + 9.49773423968445e+87*cos(theta)**17 - 2.06670697055534e+87*cos(theta)**15 + 2.94043674672507e+86*cos(theta)**13 - 2.70784021540207e+85*cos(theta)**11 + 1.56440348578901e+84*cos(theta)**9 - 5.34838798560346e+82*cos(theta)**7 + 9.76662153892806e+80*cos(theta)**5 - 7.85729810050528e+78*cos(theta)**3 + 1.76966173434804e+76*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl67_m43(theta, phi):
    return 2.8971498754101e-77*(1.0 - cos(theta)**2)**21.5*(5.96802248174097e+89*cos(theta)**24 - 1.23847684583497e+90*cos(theta)**22 + 1.09193950911404e+90*cos(theta)**20 - 5.36094332639967e+89*cos(theta)**18 + 1.61461482074636e+89*cos(theta)**16 - 3.100060455833e+88*cos(theta)**14 + 3.82256777074259e+87*cos(theta)**12 - 2.97862423694228e+86*cos(theta)**10 + 1.40796313721011e+85*cos(theta)**8 - 3.74387158992242e+83*cos(theta)**6 + 4.88331076946403e+81*cos(theta)**4 - 2.35718943015158e+79*cos(theta)**2 + 1.76966173434804e+76)*cos(43*phi)

#@torch.jit.script
def Yl67_m44(theta, phi):
    return 5.61311386838957e-79*(1.0 - cos(theta)**2)**22*(1.43232539561783e+91*cos(theta)**23 - 2.72464906083693e+91*cos(theta)**21 + 2.18387901822807e+91*cos(theta)**19 - 9.6496979875194e+90*cos(theta)**17 + 2.58338371319417e+90*cos(theta)**15 - 4.34008463816621e+89*cos(theta)**13 + 4.58708132489111e+88*cos(theta)**11 - 2.97862423694228e+87*cos(theta)**9 + 1.12637050976809e+86*cos(theta)**7 - 2.24632295395345e+84*cos(theta)**5 + 1.95332430778561e+82*cos(theta)**3 - 4.71437886030317e+79*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl67_m45(theta, phi):
    return 1.10593836277071e-80*(1.0 - cos(theta)**2)**22.5*(3.29434840992102e+92*cos(theta)**22 - 5.72176302775756e+92*cos(theta)**20 + 4.14937013463334e+92*cos(theta)**18 - 1.6404486578783e+92*cos(theta)**16 + 3.87507556979126e+91*cos(theta)**14 - 5.64211002961607e+90*cos(theta)**12 + 5.04578945738022e+89*cos(theta)**10 - 2.68076181324805e+88*cos(theta)**8 + 7.88459356837663e+86*cos(theta)**6 - 1.12316147697673e+85*cos(theta)**4 + 5.85997292335684e+82*cos(theta)**2 - 4.71437886030317e+79)*cos(45*phi)

#@torch.jit.script
def Yl67_m46(theta, phi):
    return 2.21809611402884e-82*(1.0 - cos(theta)**2)**23*(7.24756650182624e+93*cos(theta)**21 - 1.14435260555151e+94*cos(theta)**19 + 7.46886624234002e+93*cos(theta)**17 - 2.62471785260528e+93*cos(theta)**15 + 5.42510579770776e+92*cos(theta)**13 - 6.77053203553928e+91*cos(theta)**11 + 5.04578945738022e+90*cos(theta)**9 - 2.14460945059844e+89*cos(theta)**7 + 4.73075614102598e+87*cos(theta)**5 - 4.49264590790691e+85*cos(theta)**3 + 1.17199458467137e+83*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl67_m47(theta, phi):
    return 4.5333399542327e-84*(1.0 - cos(theta)**2)**23.5*(1.52198896538351e+95*cos(theta)**20 - 2.17426995054787e+95*cos(theta)**18 + 1.2697072611978e+95*cos(theta)**16 - 3.93707677890792e+94*cos(theta)**14 + 7.05263753702009e+93*cos(theta)**12 - 7.44758523909321e+92*cos(theta)**10 + 4.5412105116422e+91*cos(theta)**8 - 1.50122661541891e+90*cos(theta)**6 + 2.36537807051299e+88*cos(theta)**4 - 1.34779377237207e+86*cos(theta)**2 + 1.17199458467137e+83)*cos(47*phi)

#@torch.jit.script
def Yl67_m48(theta, phi):
    return 9.45266724278357e-86*(1.0 - cos(theta)**2)**24*(3.04397793076702e+96*cos(theta)**19 - 3.91368591098617e+96*cos(theta)**17 + 2.03153161791648e+96*cos(theta)**15 - 5.51190749047108e+95*cos(theta)**13 + 8.4631650444241e+94*cos(theta)**11 - 7.44758523909321e+93*cos(theta)**9 + 3.63296840931376e+92*cos(theta)**7 - 9.00735969251346e+90*cos(theta)**5 + 9.46151228205195e+88*cos(theta)**3 - 2.69558754474415e+86*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl67_m49(theta, phi):
    return 2.01348581724404e-87*(1.0 - cos(theta)**2)**24.5*(5.78355806845734e+97*cos(theta)**18 - 6.65326604867649e+97*cos(theta)**16 + 3.04729742687473e+97*cos(theta)**14 - 7.16547973761241e+96*cos(theta)**12 + 9.30948154886651e+95*cos(theta)**10 - 6.70282671518389e+94*cos(theta)**8 + 2.54307788651963e+93*cos(theta)**6 - 4.50367984625673e+91*cos(theta)**4 + 2.83845368461559e+89*cos(theta)**2 - 2.69558754474415e+86)*cos(49*phi)

#@torch.jit.script
def Yl67_m50(theta, phi):
    return 4.38752285148277e-89*(1.0 - cos(theta)**2)**25*(1.04104045232232e+99*cos(theta)**17 - 1.06452256778824e+99*cos(theta)**15 + 4.26621639762462e+98*cos(theta)**13 - 8.59857568513489e+97*cos(theta)**11 + 9.30948154886651e+96*cos(theta)**9 - 5.36226137214711e+95*cos(theta)**7 + 1.52584673191178e+94*cos(theta)**5 - 1.80147193850269e+92*cos(theta)**3 + 5.67690736923117e+89*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl67_m51(theta, phi):
    return 9.79611617861195e-91*(1.0 - cos(theta)**2)**25.5*(1.76976876894795e+100*cos(theta)**16 - 1.59678385168236e+100*cos(theta)**14 + 5.546081316912e+99*cos(theta)**12 - 9.45843325364838e+98*cos(theta)**10 + 8.37853339397986e+97*cos(theta)**8 - 3.75358296050298e+96*cos(theta)**6 + 7.6292336595589e+94*cos(theta)**4 - 5.40441581550807e+92*cos(theta)**2 + 5.67690736923117e+89)*cos(51*phi)

#@torch.jit.script
def Yl67_m52(theta, phi):
    return 2.24502124441183e-92*(1.0 - cos(theta)**2)**26*(2.83163003031671e+101*cos(theta)**15 - 2.2354973923553e+101*cos(theta)**13 + 6.6552975802944e+100*cos(theta)**11 - 9.45843325364838e+99*cos(theta)**9 + 6.70282671518389e+98*cos(theta)**7 - 2.25214977630179e+97*cos(theta)**5 + 3.05169346382356e+95*cos(theta)**3 - 1.08088316310161e+93*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl67_m53(theta, phi):
    return 5.29156581943822e-94*(1.0 - cos(theta)**2)**26.5*(4.24744504547507e+102*cos(theta)**14 - 2.90614661006189e+102*cos(theta)**12 + 7.32082733832384e+101*cos(theta)**10 - 8.51258992828354e+100*cos(theta)**8 + 4.69197870062872e+99*cos(theta)**6 - 1.12607488815089e+98*cos(theta)**4 + 9.15508039147068e+95*cos(theta)**2 - 1.08088316310161e+93)*cos(53*phi)

#@torch.jit.script
def Yl67_m54(theta, phi):
    return 1.28566404778581e-95*(1.0 - cos(theta)**2)**27*(5.9464230636651e+103*cos(theta)**13 - 3.48737593207427e+103*cos(theta)**11 + 7.32082733832384e+102*cos(theta)**9 - 6.81007194262683e+101*cos(theta)**7 + 2.81518722037723e+100*cos(theta)**5 - 4.50429955260357e+98*cos(theta)**3 + 1.83101607829414e+96*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl67_m55(theta, phi):
    return 3.22831502961648e-97*(1.0 - cos(theta)**2)**27.5*(7.73034998276463e+104*cos(theta)**12 - 3.83611352528169e+104*cos(theta)**10 + 6.58874460449146e+103*cos(theta)**8 - 4.76705035983878e+102*cos(theta)**6 + 1.40759361018862e+101*cos(theta)**4 - 1.35128986578107e+99*cos(theta)**2 + 1.83101607829414e+96)*cos(55*phi)

#@torch.jit.script
def Yl67_m56(theta, phi):
    return 8.40296837894555e-99*(1.0 - cos(theta)**2)**28*(9.27641997931755e+105*cos(theta)**11 - 3.83611352528169e+105*cos(theta)**9 + 5.27099568359317e+104*cos(theta)**7 - 2.86023021590327e+103*cos(theta)**5 + 5.63037444075447e+101*cos(theta)**3 - 2.70257973156214e+99*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl67_m57(theta, phi):
    return 2.2752312501714e-100*(1.0 - cos(theta)**2)**28.5*(1.02040619772493e+107*cos(theta)**10 - 3.45250217275352e+106*cos(theta)**8 + 3.68969697851522e+105*cos(theta)**6 - 1.43011510795163e+104*cos(theta)**4 + 1.68911233222634e+102*cos(theta)**2 - 2.70257973156214e+99)*cos(57*phi)

#@torch.jit.script
def Yl67_m58(theta, phi):
    return 6.43532578305497e-102*(1.0 - cos(theta)**2)**29*(1.02040619772493e+108*cos(theta)**9 - 2.76200173820282e+107*cos(theta)**7 + 2.21381818710913e+106*cos(theta)**5 - 5.72046043180654e+104*cos(theta)**3 + 3.37822466445268e+102*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl67_m59(theta, phi):
    return 1.91101462321146e-103*(1.0 - cos(theta)**2)**29.5*(9.18365577952438e+108*cos(theta)**8 - 1.93340121674197e+108*cos(theta)**6 + 1.10690909355457e+107*cos(theta)**4 - 1.71613812954196e+105*cos(theta)**2 + 3.37822466445268e+102)*cos(59*phi)

#@torch.jit.script
def Yl67_m60(theta, phi):
    return 5.99538609518972e-105*(1.0 - cos(theta)**2)**30*(7.3469246236195e+109*cos(theta)**7 - 1.16004073004518e+109*cos(theta)**5 + 4.42763637421826e+107*cos(theta)**3 - 3.43227625908392e+105*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl67_m61(theta, phi):
    return 2.00291791693111e-106*(1.0 - cos(theta)**2)**30.5*(5.14284723653365e+110*cos(theta)**6 - 5.80020365022592e+109*cos(theta)**4 + 1.32829091226548e+108*cos(theta)**2 - 3.43227625908392e+105)*cos(61*phi)

#@torch.jit.script
def Yl67_m62(theta, phi):
    return 7.19933978271784e-108*(1.0 - cos(theta)**2)**31*(3.08570834192019e+111*cos(theta)**5 - 2.32008146009037e+110*cos(theta)**3 + 2.65658182453096e+108*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl67_m63(theta, phi):
    return 2.82381338746639e-109*(1.0 - cos(theta)**2)**31.5*(1.5428541709601e+112*cos(theta)**4 - 6.96024438027111e+110*cos(theta)**2 + 2.65658182453096e+108)*cos(63*phi)

#@torch.jit.script
def Yl67_m64(theta, phi):
    return 1.23358860594157e-110*(1.0 - cos(theta)**2)**32*(6.17141668384038e+112*cos(theta)**3 - 1.39204887605422e+111*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl67_m65(theta, phi):
    return 6.19901598722085e-112*(1.0 - cos(theta)**2)**32.5*(1.85142500515211e+113*cos(theta)**2 - 1.39204887605422e+111)*cos(65*phi)

#@torch.jit.script
def Yl67_m66(theta, phi):
    return 14.0740165928703*(1.0 - cos(theta)**2)**33*cos(66*phi)*cos(theta)

#@torch.jit.script
def Yl67_m67(theta, phi):
    return 1.21580985556888*(1.0 - cos(theta)**2)**33.5*cos(67*phi)

#@torch.jit.script
def Yl68_m_minus_68(theta, phi):
    return 1.22027155810609*(1.0 - cos(theta)**2)**34*sin(68*phi)

#@torch.jit.script
def Yl68_m_minus_67(theta, phi):
    return 14.2306895079291*(1.0 - cos(theta)**2)**33.5*sin(67*phi)*cos(theta)

#@torch.jit.script
def Yl68_m_minus_66(theta, phi):
    return 4.6777600020732e-114*(1.0 - cos(theta)**2)**33*(2.49942375695535e+115*cos(theta)**2 - 1.85142500515211e+113)*sin(66*phi)

#@torch.jit.script
def Yl68_m_minus_65(theta, phi):
    return 9.37887964101915e-113*(1.0 - cos(theta)**2)**32.5*(8.33141252318451e+114*cos(theta)**3 - 1.85142500515211e+113*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl68_m_minus_64(theta, phi):
    return 2.16325033055874e-111*(1.0 - cos(theta)**2)**32*(2.08285313079613e+114*cos(theta)**4 - 9.25712502576057e+112*cos(theta)**2 + 3.48012219013555e+110)*sin(64*phi)

#@torch.jit.script
def Yl68_m_minus_63(theta, phi):
    return 5.55749072438024e-110*(1.0 - cos(theta)**2)**31.5*(4.16570626159226e+113*cos(theta)**5 - 3.08570834192019e+112*cos(theta)**3 + 3.48012219013555e+110*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl68_m_minus_62(theta, phi):
    return 1.55808095672644e-108*(1.0 - cos(theta)**2)**31*(6.94284376932043e+112*cos(theta)**6 - 7.71427085480048e+111*cos(theta)**4 + 1.74006109506778e+110*cos(theta)**2 - 4.42763637421826e+107)*sin(62*phi)

#@torch.jit.script
def Yl68_m_minus_61(theta, phi):
    return 4.70013915072667e-107*(1.0 - cos(theta)**2)**30.5*(9.91834824188633e+111*cos(theta)**7 - 1.54285417096009e+111*cos(theta)**5 + 5.80020365022592e+109*cos(theta)**3 - 4.42763637421826e+107*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl68_m_minus_60(theta, phi):
    return 1.50990827182819e-105*(1.0 - cos(theta)**2)**30*(1.23979353023579e+111*cos(theta)**8 - 2.57142361826683e+110*cos(theta)**6 + 1.45005091255648e+109*cos(theta)**4 - 2.21381818710913e+107*cos(theta)**2 + 4.2903453238549e+104)*sin(60*phi)

#@torch.jit.script
def Yl68_m_minus_59(theta, phi):
    return 5.12479861430099e-104*(1.0 - cos(theta)**2)**29.5*(1.37754836692866e+110*cos(theta)**9 - 3.67346231180975e+109*cos(theta)**7 + 2.90010182511296e+108*cos(theta)**5 - 7.37939395703043e+106*cos(theta)**3 + 4.2903453238549e+104*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl68_m_minus_58(theta, phi):
    return 1.82632752438246e-102*(1.0 - cos(theta)**2)**29*(1.37754836692866e+109*cos(theta)**10 - 4.59182788976219e+108*cos(theta)**8 + 4.83350304185493e+107*cos(theta)**6 - 1.84484848925761e+106*cos(theta)**4 + 2.14517266192745e+104*cos(theta)**2 - 3.37822466445268e+101)*sin(58*phi)

#@torch.jit.script
def Yl68_m_minus_57(theta, phi):
    return 6.79923856448301e-101*(1.0 - cos(theta)**2)**28.5*(1.25231669720787e+108*cos(theta)**11 - 5.10203098862465e+107*cos(theta)**9 + 6.90500434550705e+106*cos(theta)**7 - 3.68969697851522e+105*cos(theta)**5 + 7.15057553975817e+103*cos(theta)**3 - 3.37822466445268e+101*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl68_m_minus_56(theta, phi):
    return 2.63333377271339e-99*(1.0 - cos(theta)**2)**28*(1.04359724767322e+107*cos(theta)**12 - 5.10203098862465e+106*cos(theta)**10 + 8.63125543188381e+105*cos(theta)**8 - 6.14949496419203e+104*cos(theta)**6 + 1.78764388493954e+103*cos(theta)**4 - 1.68911233222634e+101*cos(theta)**2 + 2.25214977630179e+98)*sin(56*phi)

#@torch.jit.script
def Yl68_m_minus_55(theta, phi):
    return 1.05727613113712e-97*(1.0 - cos(theta)**2)**27.5*(8.02767113594788e+105*cos(theta)**13 - 4.63820998965878e+105*cos(theta)**11 + 9.59028381320424e+104*cos(theta)**9 - 8.78499280598861e+103*cos(theta)**7 + 3.57528776987909e+102*cos(theta)**5 - 5.63037444075447e+100*cos(theta)**3 + 2.25214977630179e+98*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl68_m_minus_54(theta, phi):
    return 4.38737747599552e-96*(1.0 - cos(theta)**2)**27*(5.73405081139134e+104*cos(theta)**14 - 3.86517499138231e+104*cos(theta)**12 + 9.59028381320424e+103*cos(theta)**10 - 1.09812410074858e+103*cos(theta)**8 + 5.95881294979848e+101*cos(theta)**6 - 1.40759361018862e+100*cos(theta)**4 + 1.12607488815089e+98*cos(theta)**2 - 1.30786862735295e+95)*sin(54*phi)

#@torch.jit.script
def Yl68_m_minus_53(theta, phi):
    return 1.87685424164684e-94*(1.0 - cos(theta)**2)**26.5*(3.82270054092756e+103*cos(theta)**15 - 2.97321153183255e+103*cos(theta)**13 + 8.71843983018567e+102*cos(theta)**11 - 1.22013788972064e+102*cos(theta)**9 + 8.51258992828354e+100*cos(theta)**7 - 2.81518722037723e+99*cos(theta)**5 + 3.75358296050298e+97*cos(theta)**3 - 1.30786862735295e+95*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl68_m_minus_52(theta, phi):
    return 8.25815866324608e-93*(1.0 - cos(theta)**2)**26*(2.38918783807973e+102*cos(theta)**16 - 2.12372252273753e+102*cos(theta)**14 + 7.26536652515472e+101*cos(theta)**12 - 1.22013788972064e+101*cos(theta)**10 + 1.06407374103544e+100*cos(theta)**8 - 4.69197870062872e+98*cos(theta)**6 + 9.38395740125744e+96*cos(theta)**4 - 6.53934313676477e+94*cos(theta)**2 + 6.75551976938509e+91)*sin(52*phi)

#@torch.jit.script
def Yl68_m_minus_51(theta, phi):
    return 3.72990960205454e-91*(1.0 - cos(theta)**2)**25.5*(1.40540461063513e+101*cos(theta)**17 - 1.41581501515836e+101*cos(theta)**15 + 5.58874348088825e+100*cos(theta)**13 - 1.1092162633824e+100*cos(theta)**11 + 1.18230415670605e+99*cos(theta)**9 - 6.70282671518389e+97*cos(theta)**7 + 1.87679148025149e+96*cos(theta)**5 - 2.17978104558826e+94*cos(theta)**3 + 6.75551976938509e+91*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl68_m_minus_50(theta, phi):
    return 1.72626728289121e-89*(1.0 - cos(theta)**2)**25*(7.80780339241741e+99*cos(theta)**18 - 8.84884384473973e+99*cos(theta)**16 + 3.99195962920589e+99*cos(theta)**14 - 9.24346886152e+98*cos(theta)**12 + 1.18230415670605e+98*cos(theta)**10 - 8.37853339397986e+96*cos(theta)**8 + 3.12798580041915e+95*cos(theta)**6 - 5.44945261397064e+93*cos(theta)**4 + 3.37775988469255e+91*cos(theta)**2 - 3.15383742735065e+88)*sin(50*phi)

#@torch.jit.script
def Yl68_m_minus_49(theta, phi):
    return 8.17383456958882e-88*(1.0 - cos(theta)**2)**24.5*(4.10937020653548e+98*cos(theta)**19 - 5.2052022616116e+98*cos(theta)**17 + 2.66130641947059e+98*cos(theta)**15 - 7.1103606627077e+97*cos(theta)**13 + 1.07482196064186e+97*cos(theta)**11 - 9.30948154886651e+95*cos(theta)**9 + 4.46855114345593e+94*cos(theta)**7 - 1.08989052279413e+93*cos(theta)**5 + 1.12591996156418e+91*cos(theta)**3 - 3.15383742735065e+88*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl68_m_minus_48(theta, phi):
    return 3.95397366551868e-86*(1.0 - cos(theta)**2)**24*(2.05468510326774e+97*cos(theta)**20 - 2.89177903422867e+97*cos(theta)**18 + 1.66331651216912e+97*cos(theta)**16 - 5.07882904479121e+96*cos(theta)**14 + 8.95684967201551e+95*cos(theta)**12 - 9.30948154886651e+94*cos(theta)**10 + 5.58568892931991e+93*cos(theta)**8 - 1.81648420465688e+92*cos(theta)**6 + 2.81479990391046e+90*cos(theta)**4 - 1.57691871367533e+88*cos(theta)**2 + 1.34779377237207e+85)*sin(48*phi)

#@torch.jit.script
def Yl68_m_minus_47(theta, phi):
    return 1.95151733974338e-84*(1.0 - cos(theta)**2)**23.5*(9.78421477746542e+95*cos(theta)**21 - 1.52198896538351e+96*cos(theta)**19 + 9.78421477746542e+95*cos(theta)**17 - 3.38588602986081e+95*cos(theta)**15 + 6.88988436308885e+94*cos(theta)**13 - 8.4631650444241e+93*cos(theta)**11 + 6.20632103257767e+92*cos(theta)**9 - 2.59497743522412e+91*cos(theta)**7 + 5.62959980782091e+89*cos(theta)**5 - 5.25639571225108e+87*cos(theta)**3 + 1.34779377237207e+85*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl68_m_minus_46(theta, phi):
    return 9.81595762833013e-83*(1.0 - cos(theta)**2)**23*(4.44737035339337e+94*cos(theta)**22 - 7.60994482691755e+94*cos(theta)**20 + 5.43567487636968e+94*cos(theta)**18 - 2.116178768663e+94*cos(theta)**16 + 4.92134597363489e+93*cos(theta)**14 - 7.05263753702008e+92*cos(theta)**12 + 6.20632103257767e+91*cos(theta)**10 - 3.24372179403014e+90*cos(theta)**8 + 9.38266634636818e+88*cos(theta)**6 - 1.31409892806277e+87*cos(theta)**4 + 6.73896886186036e+84*cos(theta)**2 - 5.32724811214258e+81)*sin(46*phi)

#@torch.jit.script
def Yl68_m_minus_45(theta, phi):
    return 5.02630708722213e-81*(1.0 - cos(theta)**2)**22.5*(1.93363928408408e+93*cos(theta)**23 - 3.62378325091312e+93*cos(theta)**21 + 2.86088151387878e+93*cos(theta)**19 - 1.24481104039e+93*cos(theta)**17 + 3.2808973157566e+92*cos(theta)**15 - 5.42510579770776e+91*cos(theta)**13 + 5.64211002961607e+90*cos(theta)**11 - 3.60413532670016e+89*cos(theta)**9 + 1.34038090662403e+88*cos(theta)**7 - 2.62819785612554e+86*cos(theta)**5 + 2.24632295395345e+84*cos(theta)**3 - 5.32724811214258e+81*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl68_m_minus_44(theta, phi):
    return 2.61754321988924e-79*(1.0 - cos(theta)**2)**22*(8.05683035035031e+91*cos(theta)**24 - 1.64717420496051e+92*cos(theta)**22 + 1.43044075693939e+92*cos(theta)**20 - 6.91561689105557e+91*cos(theta)**18 + 2.05056082234787e+91*cos(theta)**16 - 3.87507556979126e+90*cos(theta)**14 + 4.70175835801339e+89*cos(theta)**12 - 3.60413532670016e+88*cos(theta)**10 + 1.67547613328003e+87*cos(theta)**8 - 4.38032976020924e+85*cos(theta)**6 + 5.61580738488364e+83*cos(theta)**4 - 2.66362405607129e+81*cos(theta)**2 + 1.96432452512632e+78)*sin(44*phi)

#@torch.jit.script
def Yl68_m_minus_43(theta, phi):
    return 1.38507368115804e-77*(1.0 - cos(theta)**2)**21.5*(3.22273214014013e+90*cos(theta)**25 - 7.16162697808917e+90*cos(theta)**23 + 6.81162265209233e+90*cos(theta)**21 - 3.63979836371346e+90*cos(theta)**19 + 1.20621224843993e+90*cos(theta)**17 - 2.58338371319417e+89*cos(theta)**15 + 3.61673719847184e+88*cos(theta)**13 - 3.27648666063651e+87*cos(theta)**11 + 1.86164014808893e+86*cos(theta)**9 - 6.25761394315605e+84*cos(theta)**7 + 1.12316147697673e+83*cos(theta)**5 - 8.87874685357097e+80*cos(theta)**3 + 1.96432452512632e+78*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl68_m_minus_42(theta, phi):
    return 7.44082414054722e-76*(1.0 - cos(theta)**2)**21*(1.23951236159236e+89*cos(theta)**26 - 2.98401124087049e+89*cos(theta)**24 + 3.09619211458742e+89*cos(theta)**22 - 1.81989918185673e+89*cos(theta)**20 + 6.70117915799958e+88*cos(theta)**18 - 1.61461482074636e+88*cos(theta)**16 + 2.58338371319417e+87*cos(theta)**14 - 2.73040555053042e+86*cos(theta)**12 + 1.86164014808893e+85*cos(theta)**10 - 7.82201742894506e+83*cos(theta)**8 + 1.87193579496121e+82*cos(theta)**6 - 2.21968671339274e+80*cos(theta)**4 + 9.8216226256316e+77*cos(theta)**2 - 6.80639128595399e+74)*sin(42*phi)

#@torch.jit.script
def Yl68_m_minus_41(theta, phi):
    return 4.05507849190289e-74*(1.0 - cos(theta)**2)**20.5*(4.59078652441613e+87*cos(theta)**27 - 1.19360449634819e+88*cos(theta)**25 + 1.34617048460323e+88*cos(theta)**23 - 8.66618658027014e+87*cos(theta)**21 + 3.52693639894715e+87*cos(theta)**19 - 9.49773423968445e+86*cos(theta)**17 + 1.72225580879611e+86*cos(theta)**15 - 2.10031196194648e+85*cos(theta)**13 + 1.6924001346263e+84*cos(theta)**11 - 8.69113047660563e+82*cos(theta)**9 + 2.67419399280173e+81*cos(theta)**7 - 4.43937342678548e+79*cos(theta)**5 + 3.27387420854387e+77*cos(theta)**3 - 6.80639128595399e+74*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl68_m_minus_40(theta, phi):
    return 2.24022443358709e-72*(1.0 - cos(theta)**2)**20*(1.6395666158629e+86*cos(theta)**28 - 4.59078652441613e+86*cos(theta)**26 + 5.60904368584678e+86*cos(theta)**24 - 3.93917571830461e+86*cos(theta)**22 + 1.76346819947357e+86*cos(theta)**20 - 5.27651902204692e+85*cos(theta)**18 + 1.07640988049757e+85*cos(theta)**16 - 1.50022282996177e+84*cos(theta)**14 + 1.41033344552191e+83*cos(theta)**12 - 8.69113047660563e+81*cos(theta)**10 + 3.34274249100216e+80*cos(theta)**8 - 7.39895571130914e+78*cos(theta)**6 + 8.18468552135967e+76*cos(theta)**4 - 3.40319564297699e+74*cos(theta)**2 + 2.23014131256684e+71)*sin(40*phi)

#@torch.jit.script
def Yl68_m_minus_39(theta, phi):
    return 1.25372534736348e-70*(1.0 - cos(theta)**2)**19.5*(5.65367798573415e+84*cos(theta)**29 - 1.70029130533931e+85*cos(theta)**27 + 2.24361747433871e+85*cos(theta)**25 - 1.71268509491505e+85*cos(theta)**23 + 8.39746761654083e+84*cos(theta)**21 - 2.77711527476153e+84*cos(theta)**19 + 6.3318228264563e+83*cos(theta)**17 - 1.00014855330785e+83*cos(theta)**15 + 1.0848718811707e+82*cos(theta)**13 - 7.90102770600512e+80*cos(theta)**11 + 3.71415832333574e+79*cos(theta)**9 - 1.05699367304416e+78*cos(theta)**7 + 1.63693710427193e+76*cos(theta)**5 - 1.134398547659e+74*cos(theta)**3 + 2.23014131256684e+71*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl68_m_minus_38(theta, phi):
    return 7.10321438621669e-69*(1.0 - cos(theta)**2)**19*(1.88455932857805e+83*cos(theta)**30 - 6.07246894764039e+83*cos(theta)**28 + 8.62929797822582e+83*cos(theta)**26 - 7.13618789547936e+83*cos(theta)**24 + 3.81703073479129e+83*cos(theta)**22 - 1.38855763738077e+83*cos(theta)**20 + 3.51767934803128e+82*cos(theta)**18 - 6.25092845817405e+81*cos(theta)**16 + 7.74908486550502e+80*cos(theta)**14 - 6.58418975500426e+79*cos(theta)**12 + 3.71415832333574e+78*cos(theta)**10 - 1.3212420913052e+77*cos(theta)**8 + 2.72822850711989e+75*cos(theta)**6 - 2.83599636914749e+73*cos(theta)**4 + 1.11507065628342e+71*cos(theta)**2 - 6.94748072450728e+67)*sin(38*phi)

#@torch.jit.script
def Yl68_m_minus_37(theta, phi):
    return 4.07182122728887e-67*(1.0 - cos(theta)**2)**18.5*(6.07922364057436e+81*cos(theta)**31 - 2.09395480953117e+82*cos(theta)**29 + 3.19603628823178e+82*cos(theta)**27 - 2.85447515819175e+82*cos(theta)**25 + 1.65957858034404e+82*cos(theta)**23 - 6.6121792256227e+81*cos(theta)**21 + 1.85141018317436e+81*cos(theta)**19 - 3.67701674010238e+80*cos(theta)**17 + 5.16605657700335e+79*cos(theta)**15 - 5.06476135000328e+78*cos(theta)**13 + 3.37650756666885e+77*cos(theta)**11 - 1.46804676811689e+76*cos(theta)**9 + 3.89746929588556e+74*cos(theta)**7 - 5.67199273829499e+72*cos(theta)**5 + 3.71690218761139e+70*cos(theta)**3 - 6.94748072450728e+67*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl68_m_minus_36(theta, phi):
    return 2.36025181791098e-65*(1.0 - cos(theta)**2)**18*(1.89975738767949e+80*cos(theta)**32 - 6.97984936510389e+80*cos(theta)**30 + 1.14144153151135e+81*cos(theta)**28 - 1.09787506084298e+81*cos(theta)**26 + 6.91491075143349e+80*cos(theta)**24 - 3.00553601164668e+80*cos(theta)**22 + 9.25705091587178e+79*cos(theta)**20 - 2.04278707783466e+79*cos(theta)**18 + 3.22878536062709e+78*cos(theta)**16 - 3.61768667857377e+77*cos(theta)**14 + 2.81375630555738e+76*cos(theta)**12 - 1.46804676811689e+75*cos(theta)**10 + 4.87183661985694e+73*cos(theta)**8 - 9.45332123049165e+71*cos(theta)**6 + 9.29225546902849e+69*cos(theta)**4 - 3.47374036225364e+67*cos(theta)**2 + 2.06770259657955e+64)*sin(36*phi)

#@torch.jit.script
def Yl68_m_minus_35(theta, phi):
    return 1.3827127910757e-63*(1.0 - cos(theta)**2)**17.5*(5.75684056872572e+78*cos(theta)**33 - 2.25156431132384e+79*cos(theta)**31 + 3.93600528107362e+79*cos(theta)**29 - 4.06620392904807e+79*cos(theta)**27 + 2.7659643005734e+79*cos(theta)**25 - 1.30675478767247e+79*cos(theta)**23 + 4.40811948374847e+78*cos(theta)**21 - 1.07515109359719e+78*cos(theta)**19 + 1.89928550625123e+77*cos(theta)**17 - 2.41179111904918e+76*cos(theta)**15 + 2.16442792735183e+75*cos(theta)**13 - 1.33458797101536e+74*cos(theta)**11 + 5.41315179984105e+72*cos(theta)**9 - 1.35047446149881e+71*cos(theta)**7 + 1.8584510938057e+69*cos(theta)**5 - 1.15791345408455e+67*cos(theta)**3 + 2.06770259657955e+64*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl68_m_minus_34(theta, phi):
    return 8.18257606652113e-62*(1.0 - cos(theta)**2)**17*(1.69318840256639e+77*cos(theta)**34 - 7.03613847288699e+77*cos(theta)**32 + 1.31200176035787e+78*cos(theta)**30 - 1.45221568894574e+78*cos(theta)**28 + 1.06383242329746e+78*cos(theta)**26 - 5.44481161530196e+77*cos(theta)**24 + 2.00369067443112e+77*cos(theta)**22 - 5.37575546798594e+76*cos(theta)**20 + 1.05515861458402e+76*cos(theta)**18 - 1.50736944940574e+75*cos(theta)**16 + 1.54601994810845e+74*cos(theta)**14 - 1.1121566425128e+73*cos(theta)**12 + 5.41315179984105e+71*cos(theta)**10 - 1.68809307687351e+70*cos(theta)**8 + 3.09741848967616e+68*cos(theta)**6 - 2.89478363521137e+66*cos(theta)**4 + 1.03385129828977e+64*cos(theta)**2 - 5.90434779148928e+60)*sin(34*phi)

#@torch.jit.script
def Yl68_m_minus_33(theta, phi):
    return 4.88904640365914e-60*(1.0 - cos(theta)**2)**16.5*(4.83768115018968e+75*cos(theta)**35 - 2.13216317360212e+76*cos(theta)**33 + 4.23226374308992e+76*cos(theta)**31 - 5.00764030670945e+76*cos(theta)**29 + 3.94012008628689e+76*cos(theta)**27 - 2.17792464612078e+76*cos(theta)**25 + 8.71169858448314e+75*cos(theta)**23 - 2.55988355618378e+75*cos(theta)**21 + 5.55346639254746e+74*cos(theta)**19 - 8.8668791141514e+73*cos(theta)**17 + 1.03067996540563e+73*cos(theta)**15 - 8.55505109625229e+71*cos(theta)**13 + 4.92104709076459e+70*cos(theta)**11 - 1.8756589743039e+69*cos(theta)**9 + 4.42488355668023e+67*cos(theta)**7 - 5.78956727042273e+65*cos(theta)**5 + 3.44617099429925e+63*cos(theta)**3 - 5.90434779148928e+60*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl68_m_minus_32(theta, phi):
    return 2.94805849575977e-58*(1.0 - cos(theta)**2)**16*(1.34380031949713e+74*cos(theta)**36 - 6.27106815765329e+74*cos(theta)**34 + 1.3225824197156e+75*cos(theta)**32 - 1.66921343556982e+75*cos(theta)**30 + 1.40718574510246e+75*cos(theta)**28 - 8.37663325431071e+74*cos(theta)**26 + 3.62987441020131e+74*cos(theta)**24 - 1.16358343462899e+74*cos(theta)**22 + 2.77673319627373e+73*cos(theta)**20 - 4.92604395230633e+72*cos(theta)**18 + 6.4417497837852e+71*cos(theta)**16 - 6.11075078303735e+70*cos(theta)**14 + 4.10087257563716e+69*cos(theta)**12 - 1.8756589743039e+68*cos(theta)**10 + 5.53110444585029e+66*cos(theta)**8 - 9.64927878403789e+64*cos(theta)**6 + 8.61542748574811e+62*cos(theta)**4 - 2.95217389574464e+60*cos(theta)**2 + 1.6238580284624e+57)*sin(32*phi)

#@torch.jit.script
def Yl68_m_minus_31(theta, phi):
    return 1.79323397551348e-56*(1.0 - cos(theta)**2)**15.5*(3.63189275539766e+72*cos(theta)**37 - 1.79173375932951e+73*cos(theta)**35 + 4.0078255142897e+73*cos(theta)**33 - 5.38455946958005e+73*cos(theta)**31 + 4.85236463828435e+73*cos(theta)**29 - 3.10245676085582e+73*cos(theta)**27 + 1.45194976408052e+73*cos(theta)**25 - 5.05905841143039e+72*cos(theta)**23 + 1.32225390298749e+72*cos(theta)**21 - 2.59265471174018e+71*cos(theta)**19 + 3.78926457869718e+70*cos(theta)**17 - 4.07383385535823e+69*cos(theta)**15 + 3.15451736587474e+68*cos(theta)**13 - 1.70514452209445e+67*cos(theta)**11 + 6.14567160650032e+65*cos(theta)**9 - 1.3784683977197e+64*cos(theta)**7 + 1.72308549714962e+62*cos(theta)**5 - 9.84057965248214e+59*cos(theta)**3 + 1.6238580284624e+57*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl68_m_minus_30(theta, phi):
    return 1.09988265729126e-54*(1.0 - cos(theta)**2)**15*(9.55761251420436e+70*cos(theta)**38 - 4.97703822035975e+71*cos(theta)**36 + 1.1787722100852e+72*cos(theta)**34 - 1.68267483424377e+72*cos(theta)**32 + 1.61745487942812e+72*cos(theta)**30 - 1.10802027173422e+72*cos(theta)**28 + 5.58442216954047e+71*cos(theta)**26 - 2.10794100476266e+71*cos(theta)**24 + 6.0102450135795e+70*cos(theta)**22 - 1.29632735587009e+70*cos(theta)**20 + 2.1051469881651e+69*cos(theta)**18 - 2.5461461595989e+68*cos(theta)**16 + 2.25322668991053e+67*cos(theta)**14 - 1.42095376841204e+66*cos(theta)**12 + 6.14567160650032e+64*cos(theta)**10 - 1.72308549714962e+63*cos(theta)**8 + 2.87180916191604e+61*cos(theta)**6 - 2.46014491312054e+59*cos(theta)**4 + 8.119290142312e+56*cos(theta)**2 - 4.31647535476449e+53)*sin(30*phi)

#@torch.jit.script
def Yl68_m_minus_29(theta, phi):
    return 6.79973042715234e-53*(1.0 - cos(theta)**2)**14.5*(2.45066987543702e+69*cos(theta)**39 - 1.3451454649621e+70*cos(theta)**37 + 3.36792060024344e+70*cos(theta)**35 - 5.09901464922353e+70*cos(theta)**33 + 5.21759638525199e+70*cos(theta)**31 - 3.82075955770421e+70*cos(theta)**29 + 2.06830450723721e+70*cos(theta)**27 - 8.43176401905066e+69*cos(theta)**25 + 2.61315000590413e+69*cos(theta)**23 - 6.17298740890518e+68*cos(theta)**21 + 1.10797209903426e+68*cos(theta)**19 - 1.49773303505817e+67*cos(theta)**17 + 1.50215112660702e+66*cos(theta)**15 - 1.09304136031696e+65*cos(theta)**13 + 5.58697418772756e+63*cos(theta)**11 - 1.91453944127736e+62*cos(theta)**9 + 4.10258451702291e+60*cos(theta)**7 - 4.92028982624107e+58*cos(theta)**5 + 2.70643004743733e+56*cos(theta)**3 - 4.31647535476449e+53*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl68_m_minus_28(theta, phi):
    return 4.23552801267956e-51*(1.0 - cos(theta)**2)**14*(6.12667468859254e+67*cos(theta)**40 - 3.53985648674236e+68*cos(theta)**38 + 9.35533500067623e+68*cos(theta)**36 - 1.4997101909481e+69*cos(theta)**34 + 1.63049887039125e+69*cos(theta)**32 - 1.27358651923474e+69*cos(theta)**30 + 7.38680181156147e+68*cos(theta)**28 - 3.24298616117333e+68*cos(theta)**26 + 1.08881250246005e+68*cos(theta)**24 - 2.80590336768417e+67*cos(theta)**22 + 5.53986049517131e+66*cos(theta)**20 - 8.32073908365652e+65*cos(theta)**18 + 9.38844454129386e+64*cos(theta)**16 - 7.80743828797826e+63*cos(theta)**14 + 4.6558118231063e+62*cos(theta)**12 - 1.91453944127736e+61*cos(theta)**10 + 5.12823064627864e+59*cos(theta)**8 - 8.20048304373512e+57*cos(theta)**6 + 6.76607511859333e+55*cos(theta)**4 - 2.15823767738224e+53*cos(theta)**2 + 1.11249364813518e+50)*sin(28*phi)

#@torch.jit.script
def Yl68_m_minus_27(theta, phi):
    return 2.65726644395734e-49*(1.0 - cos(theta)**2)**13.5*(1.49431089965672e+66*cos(theta)**41 - 9.07655509421117e+66*cos(theta)**39 + 2.52846891910168e+67*cos(theta)**37 - 4.28488625985171e+67*cos(theta)**35 + 4.94090566785226e+67*cos(theta)**33 - 4.10834361043463e+67*cos(theta)**31 + 2.54717303846947e+67*cos(theta)**29 - 1.20110598561975e+67*cos(theta)**27 + 4.35525000984022e+66*cos(theta)**25 - 1.21995798594964e+66*cos(theta)**23 + 2.63802880722444e+65*cos(theta)**21 - 4.37933635981922e+64*cos(theta)**19 + 5.52261443605521e+63*cos(theta)**17 - 5.20495885865218e+62*cos(theta)**15 + 3.58139371008177e+61*cos(theta)**13 - 1.74049040116124e+60*cos(theta)**11 + 5.69803405142071e+58*cos(theta)**9 - 1.17149757767645e+57*cos(theta)**7 + 1.35321502371867e+55*cos(theta)**5 - 7.19412559127414e+52*cos(theta)**3 + 1.11249364813518e+50*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl68_m_minus_26(theta, phi):
    return 1.67850079437529e-47*(1.0 - cos(theta)**2)**13*(3.55788309442076e+64*cos(theta)**42 - 2.26913877355279e+65*cos(theta)**40 + 6.65386557658338e+65*cos(theta)**38 - 1.19024618329214e+66*cos(theta)**36 + 1.45320754936831e+66*cos(theta)**34 - 1.28385737826082e+66*cos(theta)**32 + 8.49057679489824e+65*cos(theta)**30 - 4.28966423435626e+65*cos(theta)**28 + 1.67509615763085e+65*cos(theta)**26 - 5.08315827479017e+64*cos(theta)**24 + 1.19910400328383e+64*cos(theta)**22 - 2.18966817990961e+63*cos(theta)**20 + 3.06811913114179e+62*cos(theta)**18 - 3.25309928665761e+61*cos(theta)**16 + 2.55813836434412e+60*cos(theta)**14 - 1.45040866763436e+59*cos(theta)**12 + 5.69803405142071e+57*cos(theta)**10 - 1.46437197209556e+56*cos(theta)**8 + 2.25535837286444e+54*cos(theta)**6 - 1.79853139781854e+52*cos(theta)**4 + 5.56246824067588e+49*cos(theta)**2 - 2.78820463191774e+46)*sin(26*phi)

#@torch.jit.script
def Yl68_m_minus_25(theta, phi):
    return 1.06713583921524e-45*(1.0 - cos(theta)**2)**12.5*(8.27414673121106e+62*cos(theta)**43 - 5.5344848135434e+63*cos(theta)**41 + 1.70611937861112e+64*cos(theta)**39 - 3.21688157646525e+64*cos(theta)**37 + 4.15202156962375e+64*cos(theta)**35 - 3.89047690382068e+64*cos(theta)**33 + 2.73889574028976e+64*cos(theta)**31 - 1.47919456357112e+64*cos(theta)**29 + 6.20405984307723e+63*cos(theta)**27 - 2.03326330991607e+63*cos(theta)**25 + 5.21349566645145e+62*cos(theta)**23 - 1.04269913329029e+62*cos(theta)**21 + 1.6147995427062e+61*cos(theta)**19 - 1.91358781568095e+60*cos(theta)**17 + 1.70542557622942e+59*cos(theta)**15 - 1.11569897510336e+58*cos(theta)**13 + 5.18003095583701e+56*cos(theta)**11 - 1.62707996899506e+55*cos(theta)**9 + 3.22194053266349e+53*cos(theta)**7 - 3.59706279563707e+51*cos(theta)**5 + 1.85415608022529e+49*cos(theta)**3 - 2.78820463191774e+46*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl68_m_minus_24(theta, phi):
    return 6.82633375692216e-44*(1.0 - cos(theta)**2)**12*(1.88048789345706e+61*cos(theta)**44 - 1.31773447941509e+62*cos(theta)**42 + 4.26529844652781e+62*cos(theta)**40 - 8.46547783280328e+62*cos(theta)**38 + 1.15333932489549e+63*cos(theta)**36 - 1.14425791288843e+63*cos(theta)**34 + 8.55904918840549e+62*cos(theta)**32 - 4.93064854523708e+62*cos(theta)**30 + 2.21573565824187e+62*cos(theta)**28 - 7.82024349967718e+61*cos(theta)**26 + 2.17228986102144e+61*cos(theta)**24 - 4.73954151495587e+60*cos(theta)**22 + 8.07399771353101e+59*cos(theta)**20 - 1.06310434204497e+59*cos(theta)**18 + 1.06589098514338e+58*cos(theta)**16 - 7.9692783935954e+56*cos(theta)**14 + 4.31669246319751e+55*cos(theta)**12 - 1.62707996899506e+54*cos(theta)**10 + 4.02742566582936e+52*cos(theta)**8 - 5.99510465939512e+50*cos(theta)**6 + 4.63539020056324e+48*cos(theta)**4 - 1.39410231595887e+46*cos(theta)**2 + 6.8137943106494e+42)*sin(24*phi)

#@torch.jit.script
def Yl68_m_minus_23(theta, phi):
    return 4.39225644517833e-42*(1.0 - cos(theta)**2)**11.5*(4.17886198546013e+59*cos(theta)**45 - 3.06449878933743e+60*cos(theta)**43 + 1.04031669427507e+61*cos(theta)**41 - 2.17063534174443e+61*cos(theta)**39 + 3.11713331052834e+61*cos(theta)**37 - 3.26930832253838e+61*cos(theta)**35 + 2.59365126921378e+61*cos(theta)**33 - 1.59053178878615e+61*cos(theta)**31 + 7.64046778704092e+60*cos(theta)**29 - 2.89638648136192e+60*cos(theta)**27 + 8.68915944408576e+59*cos(theta)**25 - 2.06067022389386e+59*cos(theta)**23 + 3.84476081596715e+58*cos(theta)**21 - 5.595286010763e+57*cos(theta)**19 + 6.26994697143167e+56*cos(theta)**17 - 5.31285226239693e+55*cos(theta)**15 + 3.32053266399808e+54*cos(theta)**13 - 1.47916360817733e+53*cos(theta)**11 + 4.47491740647707e+51*cos(theta)**9 - 8.56443522770731e+49*cos(theta)**7 + 9.27078040112647e+47*cos(theta)**5 - 4.64700771986289e+45*cos(theta)**3 + 6.8137943106494e+42*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl68_m_minus_22(theta, phi):
    return 2.84175937094191e-40*(1.0 - cos(theta)**2)**11*(9.08448257708724e+57*cos(theta)**46 - 6.96476997576688e+58*cos(theta)**44 + 2.47694451017875e+59*cos(theta)**42 - 5.42658835436108e+59*cos(theta)**40 + 8.20298239612721e+59*cos(theta)**38 - 9.08141200705107e+59*cos(theta)**36 + 7.6283860859229e+59*cos(theta)**34 - 4.97041183995673e+59*cos(theta)**32 + 2.54682259568031e+59*cos(theta)**30 - 1.03442374334354e+59*cos(theta)**28 + 3.34198440157144e+58*cos(theta)**26 - 8.58612593289106e+57*cos(theta)**24 + 1.74761855271234e+57*cos(theta)**22 - 2.7976430053815e+56*cos(theta)**20 + 3.4833038730176e+55*cos(theta)**18 - 3.32053266399808e+54*cos(theta)**16 + 2.37180904571292e+53*cos(theta)**14 - 1.23263634014777e+52*cos(theta)**12 + 4.47491740647707e+50*cos(theta)**10 - 1.07055440346341e+49*cos(theta)**8 + 1.54513006685441e+47*cos(theta)**6 - 1.16175192996572e+45*cos(theta)**4 + 3.4068971553247e+42*cos(theta)**2 - 1.62775783818667e+39)*sin(22*phi)

#@torch.jit.script
def Yl68_m_minus_21(theta, phi):
    return 1.84823625230872e-38*(1.0 - cos(theta)**2)**10.5*(1.93286863342282e+56*cos(theta)**47 - 1.54772666128153e+57*cos(theta)**45 + 5.76033607018314e+57*cos(theta)**43 - 1.32355813521002e+58*cos(theta)**41 + 2.1033288195198e+58*cos(theta)**39 - 2.45443567758137e+58*cos(theta)**37 + 2.17953888169226e+58*cos(theta)**35 - 1.50618540604749e+58*cos(theta)**33 + 8.21555676025906e+57*cos(theta)**31 - 3.56697842532256e+57*cos(theta)**29 + 1.23777200058202e+57*cos(theta)**27 - 3.43445037315643e+56*cos(theta)**25 + 7.59834153353191e+55*cos(theta)**23 - 1.33221095494357e+55*cos(theta)**21 + 1.833317827904e+54*cos(theta)**19 - 1.95325450823417e+53*cos(theta)**17 + 1.58120603047528e+52*cos(theta)**15 - 9.48181800113673e+50*cos(theta)**13 + 4.06810673316097e+49*cos(theta)**11 - 1.18950489273713e+48*cos(theta)**9 + 2.20732866693487e+46*cos(theta)**7 - 2.32350385993145e+44*cos(theta)**5 + 1.13563238510823e+42*cos(theta)**3 - 1.62775783818667e+39*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl68_m_minus_20(theta, phi):
    return 1.2080171682495e-36*(1.0 - cos(theta)**2)**10*(4.0268096529642e+54*cos(theta)**48 - 3.36462317669898e+55*cos(theta)**46 + 1.30916728867799e+56*cos(theta)**44 - 3.15132889335719e+56*cos(theta)**42 + 5.25832204879949e+56*cos(theta)**40 - 6.45904125679308e+56*cos(theta)**38 + 6.05427467136738e+56*cos(theta)**36 - 4.42995707661028e+56*cos(theta)**34 + 2.56736148758096e+56*cos(theta)**32 - 1.18899280844085e+56*cos(theta)**30 + 4.42061428779292e+55*cos(theta)**28 - 1.32094245121401e+55*cos(theta)**26 + 3.16597563897163e+54*cos(theta)**24 - 6.0555043406526e+53*cos(theta)**22 + 9.16658913951999e+52*cos(theta)**20 - 1.08514139346343e+52*cos(theta)**18 + 9.88253769047048e+50*cos(theta)**16 - 6.77272714366909e+49*cos(theta)**14 + 3.39008894430081e+48*cos(theta)**12 - 1.18950489273713e+47*cos(theta)**10 + 2.75916083366859e+45*cos(theta)**8 - 3.87250643321908e+43*cos(theta)**6 + 2.83908096277058e+41*cos(theta)**4 - 8.13878919093335e+38*cos(theta)**2 + 3.81029456504371e+35)*sin(20*phi)

#@torch.jit.script
def Yl68_m_minus_19(theta, phi):
    return 7.93254386973263e-35*(1.0 - cos(theta)**2)**9.5*(8.21797888360041e+52*cos(theta)**49 - 7.1587727163808e+53*cos(theta)**47 + 2.90926064150663e+54*cos(theta)**45 - 7.32867184501671e+54*cos(theta)**43 + 1.28251757287793e+55*cos(theta)**41 - 1.65616442481874e+55*cos(theta)**39 + 1.63629045172091e+55*cos(theta)**37 - 1.26570202188865e+55*cos(theta)**35 + 7.77988329569987e+54*cos(theta)**33 - 3.83546067238985e+54*cos(theta)**31 + 1.52434975441135e+54*cos(theta)**29 - 4.89237944894078e+53*cos(theta)**27 + 1.26639025558865e+53*cos(theta)**25 - 2.63282797419678e+52*cos(theta)**23 + 4.36504244739047e+51*cos(theta)**21 - 5.71127049191277e+50*cos(theta)**19 + 5.81325746498264e+49*cos(theta)**17 - 4.51515142911273e+48*cos(theta)**15 + 2.60776072638524e+47*cos(theta)**13 - 1.08136808430648e+46*cos(theta)**11 + 3.06573425963177e+44*cos(theta)**9 - 5.53215204745582e+42*cos(theta)**7 + 5.67816192554117e+40*cos(theta)**5 - 2.71292973031112e+38*cos(theta)**3 + 3.81029456504371e+35*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl68_m_minus_18(theta, phi):
    return 5.23187200977587e-33*(1.0 - cos(theta)**2)**9*(1.64359577672008e+51*cos(theta)**50 - 1.49141098257933e+52*cos(theta)**48 + 6.32447965544921e+52*cos(theta)**46 - 1.6656072375038e+53*cos(theta)**44 + 3.05361326875696e+53*cos(theta)**42 - 4.14041106204684e+53*cos(theta)**40 + 4.30602750452872e+53*cos(theta)**38 - 3.5158389496907e+53*cos(theta)**36 + 2.28820096932349e+53*cos(theta)**34 - 1.19858146012183e+53*cos(theta)**32 + 5.08116584803783e+52*cos(theta)**30 - 1.74727837462171e+52*cos(theta)**28 + 4.87073175226405e+51*cos(theta)**26 - 1.09701165591533e+51*cos(theta)**24 + 1.98411020335931e+50*cos(theta)**22 - 2.85563524595638e+49*cos(theta)**20 + 3.22958748054591e+48*cos(theta)**18 - 2.82196964319546e+47*cos(theta)**16 + 1.86268623313231e+46*cos(theta)**14 - 9.01140070255399e+44*cos(theta)**12 + 3.06573425963177e+43*cos(theta)**10 - 6.91519005931978e+41*cos(theta)**8 + 9.46360320923528e+39*cos(theta)**6 - 6.78232432577779e+37*cos(theta)**4 + 1.90514728252185e+35*cos(theta)**2 - 8.75929785067518e+31)*sin(18*phi)

#@torch.jit.script
def Yl68_m_minus_17(theta, phi):
    return 3.46490574202534e-31*(1.0 - cos(theta)**2)**8.5*(3.2227368170982e+49*cos(theta)**51 - 3.04369588281497e+50*cos(theta)**49 + 1.34563396924451e+51*cos(theta)**47 - 3.70134941667511e+51*cos(theta)**45 + 7.10142620641154e+51*cos(theta)**43 - 1.00985635659679e+52*cos(theta)**41 + 1.10410961654583e+52*cos(theta)**39 - 9.50226743159647e+51*cos(theta)**37 + 6.53771705520997e+51*cos(theta)**35 - 3.63206503067221e+51*cos(theta)**33 + 1.63908575743156e+51*cos(theta)**31 - 6.02509784352312e+50*cos(theta)**29 + 1.80397472306076e+50*cos(theta)**27 - 4.3880466236613e+49*cos(theta)**25 + 8.6265661015622e+48*cos(theta)**23 - 1.35982630759828e+48*cos(theta)**21 + 1.69978288449785e+47*cos(theta)**19 - 1.65998214305615e+46*cos(theta)**17 + 1.24179082208821e+45*cos(theta)**15 - 6.9318466942723e+43*cos(theta)**13 + 2.78703114511979e+42*cos(theta)**11 - 7.68354451035531e+40*cos(theta)**9 + 1.35194331560504e+39*cos(theta)**7 - 1.35646486515556e+37*cos(theta)**5 + 6.35049094173951e+34*cos(theta)**3 - 8.75929785067518e+31*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl68_m_minus_16(theta, phi):
    return 2.303576075604e-29*(1.0 - cos(theta)**2)**8*(6.19757080211193e+47*cos(theta)**52 - 6.08739176562993e+48*cos(theta)**50 + 2.80340410259273e+49*cos(theta)**48 - 8.04641177538067e+49*cos(theta)**46 + 1.61396050145717e+50*cos(theta)**44 - 2.40441989665903e+50*cos(theta)**42 + 2.76027404136456e+50*cos(theta)**40 - 2.50059669252539e+50*cos(theta)**38 + 1.8160325153361e+50*cos(theta)**36 - 1.06825442078594e+50*cos(theta)**34 + 5.12214299197362e+49*cos(theta)**32 - 2.00836594784104e+49*cos(theta)**30 + 6.44276686807414e+48*cos(theta)**28 - 1.68771023986973e+48*cos(theta)**26 + 3.59440254231758e+47*cos(theta)**24 - 6.18102867090126e+46*cos(theta)**22 + 8.49891442248924e+45*cos(theta)**20 - 9.22212301697861e+44*cos(theta)**18 + 7.76119263805131e+43*cos(theta)**16 - 4.95131906733736e+42*cos(theta)**14 + 2.32252595426649e+41*cos(theta)**12 - 7.68354451035531e+39*cos(theta)**10 + 1.6899291445063e+38*cos(theta)**8 - 2.26077477525926e+36*cos(theta)**6 + 1.58762273543488e+34*cos(theta)**4 - 4.37964892533759e+31*cos(theta)**2 + 1.98174159517538e+28)*sin(16*phi)

#@torch.jit.script
def Yl68_m_minus_15(theta, phi):
    return 1.53702218920533e-27*(1.0 - cos(theta)**2)**7.5*(1.16935298153055e+46*cos(theta)**53 - 1.19360622855489e+47*cos(theta)**51 + 5.72123286243415e+47*cos(theta)**49 - 1.71200250540014e+48*cos(theta)**47 + 3.58657889212704e+48*cos(theta)**45 - 5.59167417827681e+48*cos(theta)**43 + 6.73237571064528e+48*cos(theta)**41 - 6.41178639109074e+48*cos(theta)**39 + 4.90819598739487e+48*cos(theta)**37 - 3.05215548795984e+48*cos(theta)**35 + 1.55216454302231e+48*cos(theta)**33 - 6.4785998317453e+47*cos(theta)**31 + 2.22164374761177e+47*cos(theta)**29 - 6.25077866618419e+46*cos(theta)**27 + 1.43776101692703e+46*cos(theta)**25 - 2.68740376995707e+45*cos(theta)**23 + 4.04710210594726e+44*cos(theta)**21 - 4.85374895630453e+43*cos(theta)**19 + 4.56540743414783e+42*cos(theta)**17 - 3.3008793782249e+41*cos(theta)**15 + 1.78655842635884e+40*cos(theta)**13 - 6.98504046395937e+38*cos(theta)**11 + 1.87769904945144e+37*cos(theta)**9 - 3.22967825037038e+35*cos(theta)**7 + 3.17524547086975e+33*cos(theta)**5 - 1.45988297511253e+31*cos(theta)**3 + 1.98174159517538e+28*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl68_m_minus_14(theta, phi):
    return 1.02900163147154e-25*(1.0 - cos(theta)**2)**7*(2.16546848431584e+44*cos(theta)**54 - 2.29539659337479e+45*cos(theta)**52 + 1.14424657248683e+46*cos(theta)**50 - 3.5666718862503e+46*cos(theta)**48 + 7.79691063505879e+46*cos(theta)**46 - 1.27083504051746e+47*cos(theta)**44 + 1.60294659777268e+47*cos(theta)**42 - 1.60294659777268e+47*cos(theta)**40 + 1.29163052299865e+47*cos(theta)**38 - 8.47820968877733e+46*cos(theta)**36 + 4.56518983241856e+46*cos(theta)**34 - 2.0245624474204e+46*cos(theta)**32 + 7.4054791587059e+45*cos(theta)**30 - 2.23242095220864e+45*cos(theta)**28 + 5.52985006510397e+44*cos(theta)**26 - 1.11975157081545e+44*cos(theta)**24 + 1.83959186633966e+43*cos(theta)**22 - 2.42687447815227e+42*cos(theta)**20 + 2.53633746341546e+41*cos(theta)**18 - 2.06304961139057e+40*cos(theta)**16 + 1.27611316168489e+39*cos(theta)**14 - 5.82086705329948e+37*cos(theta)**12 + 1.87769904945144e+36*cos(theta)**10 - 4.03709781296297e+34*cos(theta)**8 + 5.29207578478292e+32*cos(theta)**6 - 3.64970743778133e+30*cos(theta)**4 + 9.9087079758769e+27*cos(theta)**2 - 4.42155643724985e+24)*sin(14*phi)

#@torch.jit.script
def Yl68_m_minus_13(theta, phi):
    return 6.9104182598781e-24*(1.0 - cos(theta)**2)**6.5*(3.93721542602879e+42*cos(theta)**55 - 4.33093696863167e+43*cos(theta)**53 + 2.24362073036633e+44*cos(theta)**51 - 7.27892221683734e+44*cos(theta)**49 + 1.65891715639549e+45*cos(theta)**47 - 2.82407786781657e+45*cos(theta)**45 + 3.72778278551787e+45*cos(theta)**43 - 3.90962584822606e+45*cos(theta)**41 + 3.31187313589398e+45*cos(theta)**39 - 2.29140802399387e+45*cos(theta)**37 + 1.30433995211959e+45*cos(theta)**35 - 6.13503771945577e+44*cos(theta)**33 + 2.38886424474384e+44*cos(theta)**31 - 7.69800328347807e+43*cos(theta)**29 + 2.04809261670518e+43*cos(theta)**27 - 4.47900628326178e+42*cos(theta)**25 + 7.99822550582462e+41*cos(theta)**23 - 1.15565451340584e+41*cos(theta)**21 + 1.33491445442919e+40*cos(theta)**19 - 1.21355859493563e+39*cos(theta)**17 + 8.50742107789924e+37*cos(theta)**15 - 4.4775900409996e+36*cos(theta)**13 + 1.70699913586495e+35*cos(theta)**11 - 4.48566423662553e+33*cos(theta)**9 + 7.5601082639756e+31*cos(theta)**7 - 7.29941487556265e+29*cos(theta)**5 + 3.30290265862563e+27*cos(theta)**3 - 4.42155643724985e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl68_m_minus_12(theta, phi):
    return 4.65415515499867e-22*(1.0 - cos(theta)**2)**6*(7.03074183219428e+40*cos(theta)**56 - 8.02025364561421e+41*cos(theta)**54 + 4.31465525070449e+42*cos(theta)**52 - 1.45578444336747e+43*cos(theta)**50 + 3.45607740915726e+43*cos(theta)**48 - 6.13929971264472e+43*cos(theta)**46 + 8.47223360344971e+43*cos(theta)**44 - 9.30863297196681e+43*cos(theta)**42 + 8.27968283973494e+43*cos(theta)**40 - 6.03002111577335e+43*cos(theta)**38 + 3.62316653366552e+43*cos(theta)**36 - 1.80442285866346e+43*cos(theta)**34 + 7.4652007648245e+42*cos(theta)**32 - 2.56600109449269e+42*cos(theta)**30 + 7.31461648823277e+41*cos(theta)**28 - 1.72269472433146e+41*cos(theta)**26 + 3.33259396076026e+40*cos(theta)**24 - 5.25297506093564e+39*cos(theta)**22 + 6.67457227214595e+38*cos(theta)**20 - 6.74199219408681e+37*cos(theta)**18 + 5.31713817368702e+36*cos(theta)**16 - 3.198278600714e+35*cos(theta)**14 + 1.42249927988746e+34*cos(theta)**12 - 4.48566423662553e+32*cos(theta)**10 + 9.45013532996951e+30*cos(theta)**8 - 1.21656914592711e+29*cos(theta)**6 + 8.25725664656409e+26*cos(theta)**4 - 2.21077821862492e+24*cos(theta)**2 + 9.7476993766531e+20)*sin(12*phi)

#@torch.jit.script
def Yl68_m_minus_11(theta, phi):
    return 3.14284728459738e-20*(1.0 - cos(theta)**2)**5.5*(1.23346347933233e+39*cos(theta)**57 - 1.45822793556622e+40*cos(theta)**55 + 8.14085896359337e+40*cos(theta)**53 - 2.85447930072053e+41*cos(theta)**51 + 7.05321920236176e+41*cos(theta)**49 - 1.30623398141377e+42*cos(theta)**47 + 1.88271857854438e+42*cos(theta)**45 - 2.16479836557368e+42*cos(theta)**43 + 2.01943483895974e+42*cos(theta)**41 - 1.5461592604547e+42*cos(theta)**39 + 9.79234198287979e+41*cos(theta)**37 - 5.15549388189561e+41*cos(theta)**35 + 2.26218204994682e+41*cos(theta)**33 - 8.27742288546029e+40*cos(theta)**31 + 2.52228154766647e+40*cos(theta)**29 - 6.38035083085724e+39*cos(theta)**27 + 1.3330375843041e+39*cos(theta)**25 - 2.2839022004068e+38*cos(theta)**23 + 3.17836774864093e+37*cos(theta)**21 - 3.54841694425622e+36*cos(theta)**19 + 3.12772833746296e+35*cos(theta)**17 - 2.13218573380933e+34*cos(theta)**15 + 1.09423021529804e+33*cos(theta)**13 - 4.07787657875048e+31*cos(theta)**11 + 1.05001503666328e+30*cos(theta)**9 - 1.73795592275301e+28*cos(theta)**7 + 1.65145132931282e+26*cos(theta)**5 - 7.36926072874974e+23*cos(theta)**3 + 9.7476993766531e+20*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl68_m_minus_10(theta, phi):
    return 2.12740816128001e-18*(1.0 - cos(theta)**2)**5*(2.12666117126264e+37*cos(theta)**58 - 2.60397845636825e+38*cos(theta)**56 + 1.50756647473951e+39*cos(theta)**54 - 5.4893832706164e+39*cos(theta)**52 + 1.41064384047235e+40*cos(theta)**50 - 2.72132079461202e+40*cos(theta)**48 + 4.09286647509648e+40*cos(theta)**46 - 4.91999628539472e+40*cos(theta)**44 + 4.80817818799939e+40*cos(theta)**42 - 3.86539815113676e+40*cos(theta)**40 + 2.57693210075784e+40*cos(theta)**38 - 1.43208163385989e+40*cos(theta)**36 + 6.65347661749064e+39*cos(theta)**34 - 2.58669465170634e+39*cos(theta)**32 + 8.40760515888824e+38*cos(theta)**30 - 2.27869672530616e+38*cos(theta)**28 + 5.12706763193886e+37*cos(theta)**26 - 9.51625916836167e+36*cos(theta)**24 + 1.4447126130186e+36*cos(theta)**22 - 1.77420847212811e+35*cos(theta)**20 + 1.73762685414609e+34*cos(theta)**18 - 1.33261608363083e+33*cos(theta)**16 + 7.81593010927175e+31*cos(theta)**14 - 3.39823048229206e+30*cos(theta)**12 + 1.05001503666328e+29*cos(theta)**10 - 2.17244490344127e+27*cos(theta)**8 + 2.75241888218803e+25*cos(theta)**6 - 1.84231518218744e+23*cos(theta)**4 + 4.87384968832655e+20*cos(theta)**2 - 2.12738965007706e+17)*sin(10*phi)

#@torch.jit.script
def Yl68_m_minus_9(theta, phi):
    return 1.44319205099325e-16*(1.0 - cos(theta)**2)**4.5*(3.60451045976718e+35*cos(theta)**59 - 4.5683832567864e+36*cos(theta)**57 + 2.74102995407184e+37*cos(theta)**55 - 1.03573269256913e+38*cos(theta)**53 + 2.76596831465167e+38*cos(theta)**51 - 5.55371590737147e+38*cos(theta)**49 + 8.70822654275846e+38*cos(theta)**47 - 1.09333250786549e+39*cos(theta)**45 + 1.11818097395335e+39*cos(theta)**43 - 9.42780036862625e+38*cos(theta)**41 + 6.60751820707139e+38*cos(theta)**39 - 3.87049090232403e+38*cos(theta)**37 + 1.90099331928304e+38*cos(theta)**35 - 7.83846864153437e+37*cos(theta)**33 + 2.71213069641556e+37*cos(theta)**31 - 7.85757491484882e+36*cos(theta)**29 + 1.89891393775513e+36*cos(theta)**27 - 3.80650366734467e+35*cos(theta)**25 + 6.28135918703741e+34*cos(theta)**23 - 8.44861177203862e+33*cos(theta)**21 + 9.14540449550572e+32*cos(theta)**19 - 7.8389181390049e+31*cos(theta)**17 + 5.21062007284783e+30*cos(theta)**15 - 2.61402344791697e+29*cos(theta)**13 + 9.54559124239344e+27*cos(theta)**11 - 2.4138276704903e+26*cos(theta)**9 + 3.93202697455433e+24*cos(theta)**7 - 3.68463036437487e+22*cos(theta)**5 + 1.62461656277552e+20*cos(theta)**3 - 2.12738965007706e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl68_m_minus_8(theta, phi):
    return 9.80946034588623e-15*(1.0 - cos(theta)**2)**4*(6.0075174329453e+33*cos(theta)**60 - 7.87652285652828e+34*cos(theta)**58 + 4.89469634655686e+35*cos(theta)**56 - 1.91802350475765e+36*cos(theta)**54 + 5.3191698358686e+36*cos(theta)**52 - 1.11074318147429e+37*cos(theta)**50 + 1.81421386307468e+37*cos(theta)**48 - 2.37680979970759e+37*cos(theta)**46 + 2.54132039534851e+37*cos(theta)**44 - 2.24471437348244e+37*cos(theta)**42 + 1.65187955176785e+37*cos(theta)**40 - 1.01855023745369e+37*cos(theta)**38 + 5.28053699800845e+36*cos(theta)**36 - 2.30543195339246e+36*cos(theta)**34 + 8.47540842629863e+35*cos(theta)**32 - 2.61919163828294e+35*cos(theta)**30 + 6.78183549198261e+34*cos(theta)**28 - 1.46403987205564e+34*cos(theta)**26 + 2.61723299459892e+33*cos(theta)**24 - 3.84027807819937e+32*cos(theta)**22 + 4.57270224775286e+31*cos(theta)**20 - 4.35495452166939e+30*cos(theta)**18 + 3.2566375455299e+29*cos(theta)**16 - 1.86715960565498e+28*cos(theta)**14 + 7.9546593686612e+26*cos(theta)**12 - 2.4138276704903e+25*cos(theta)**10 + 4.91503371819291e+23*cos(theta)**8 - 6.14105060729145e+21*cos(theta)**6 + 4.06154140693879e+19*cos(theta)**4 - 1.06369482503853e+17*cos(theta)**2 + 46047395023313.0)*sin(8*phi)

#@torch.jit.script
def Yl68_m_minus_7(theta, phi):
    return 6.67908283313328e-13*(1.0 - cos(theta)**2)**3.5*(9.84838923433656e+31*cos(theta)**61 - 1.33500387398784e+33*cos(theta)**59 + 8.58718657290677e+33*cos(theta)**57 - 3.48731546319573e+34*cos(theta)**55 + 1.00361695016389e+35*cos(theta)**53 - 2.17792780681234e+35*cos(theta)**51 + 3.70247727158098e+35*cos(theta)**49 - 5.05704212703743e+35*cos(theta)**47 + 5.64737865633003e+35*cos(theta)**45 - 5.22026598484288e+35*cos(theta)**43 + 4.02897451650694e+35*cos(theta)**41 - 2.61166727552229e+35*cos(theta)**39 + 1.4271721616239e+35*cos(theta)**37 - 6.58694843826417e+34*cos(theta)**35 + 2.56830558372686e+34*cos(theta)**33 - 8.44900528478368e+33*cos(theta)**31 + 2.33856396275263e+33*cos(theta)**29 - 5.42236989650238e+32*cos(theta)**27 + 1.04689319783957e+32*cos(theta)**25 - 1.66968612095625e+31*cos(theta)**23 + 2.17747726083469e+30*cos(theta)**21 - 2.29208132719442e+29*cos(theta)**19 + 1.91566914442935e+28*cos(theta)**17 - 1.24477307043665e+27*cos(theta)**15 + 6.118968745124e+25*cos(theta)**13 - 2.19438879135481e+24*cos(theta)**11 + 5.4611485757699e+22*cos(theta)**9 - 8.77292943898779e+20*cos(theta)**7 + 8.12308281387758e+18*cos(theta)**5 - 3.5456494167951e+16*cos(theta)**3 + 46047395023313.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl68_m_minus_6(theta, phi):
    return 4.55452726237454e-11*(1.0 - cos(theta)**2)**3*(1.5884498765059e+30*cos(theta)**62 - 2.22500645664641e+31*cos(theta)**60 + 1.48054940912186e+32*cos(theta)**58 - 6.22734904142094e+32*cos(theta)**56 + 1.8585499077109e+33*cos(theta)**54 - 4.18832270540835e+33*cos(theta)**52 + 7.40495454316196e+33*cos(theta)**50 - 1.0535504431328e+34*cos(theta)**48 + 1.22769101224566e+34*cos(theta)**46 - 1.18642408746429e+34*cos(theta)**44 + 9.59279646787367e+33*cos(theta)**42 - 6.52916818880572e+33*cos(theta)**40 + 3.75571621479975e+33*cos(theta)**38 - 1.82970789951783e+33*cos(theta)**36 + 7.55383995213781e+32*cos(theta)**34 - 2.6403141514949e+32*cos(theta)**32 + 7.79521320917542e+31*cos(theta)**30 - 1.93656067732228e+31*cos(theta)**28 + 4.02651229938295e+30*cos(theta)**26 - 6.95702550398437e+29*cos(theta)**24 + 9.89762391288498e+28*cos(theta)**22 - 1.14604066359721e+28*cos(theta)**20 + 1.06426063579408e+27*cos(theta)**18 - 7.77983169022909e+25*cos(theta)**16 + 4.37069196080286e+24*cos(theta)**14 - 1.82865732612901e+23*cos(theta)**12 + 5.4611485757699e+21*cos(theta)**10 - 1.09661617987347e+20*cos(theta)**8 + 1.35384713564626e+18*cos(theta)**6 - 8.86412354198776e+15*cos(theta)**4 + 23023697511656.5*cos(theta)**2 - 9902665596.41141)*sin(6*phi)

#@torch.jit.script
def Yl68_m_minus_5(theta, phi):
    return 3.10977838498613e-9*(1.0 - cos(theta)**2)**2.5*(2.52134901032682e+28*cos(theta)**63 - 3.6475515682728e+29*cos(theta)**61 + 2.50940577817264e+30*cos(theta)**59 - 1.09251737568788e+31*cos(theta)**57 + 3.37918165038346e+31*cos(theta)**55 - 7.90249567058179e+31*cos(theta)**53 + 1.45195187120823e+32*cos(theta)**51 - 2.15010294516898e+32*cos(theta)**49 + 2.61210853669289e+32*cos(theta)**47 - 2.63649797214287e+32*cos(theta)**45 + 2.23088289950551e+32*cos(theta)**43 - 1.59248004605017e+32*cos(theta)**41 + 9.63004157640961e+31*cos(theta)**39 - 4.94515648518331e+31*cos(theta)**37 + 2.15823998632509e+31*cos(theta)**35 - 8.00095197422697e+30*cos(theta)**33 + 2.51458490618562e+30*cos(theta)**31 - 6.67779543904233e+29*cos(theta)**29 + 1.49130085162332e+29*cos(theta)**27 - 2.78281020159375e+28*cos(theta)**25 + 4.3033147447326e+27*cos(theta)**23 - 5.45733649332004e+26*cos(theta)**21 + 5.60137176733728e+25*cos(theta)**19 - 4.5763715824877e+24*cos(theta)**17 + 2.91379464053524e+23*cos(theta)**15 - 1.4066594816377e+22*cos(theta)**13 + 4.96468052342718e+20*cos(theta)**11 - 1.21846242208164e+19*cos(theta)**9 + 1.93406733663752e+17*cos(theta)**7 - 1.77282470839755e+15*cos(theta)**5 + 7674565837218.84*cos(theta)**3 - 9902665596.41141*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl68_m_minus_4(theta, phi):
    return 2.12559665347432e-7*(1.0 - cos(theta)**2)**2*(3.93960782863566e+26*cos(theta)**64 - 5.88314769076258e+27*cos(theta)**62 + 4.18234296362107e+28*cos(theta)**60 - 1.88365064773773e+29*cos(theta)**58 + 6.03425294711332e+29*cos(theta)**56 - 1.46342512418181e+30*cos(theta)**54 + 2.7922151369389e+30*cos(theta)**52 - 4.30020589033795e+30*cos(theta)**50 + 5.44189278477685e+30*cos(theta)**48 - 5.73151733074537e+30*cos(theta)**46 + 5.07018840796706e+30*cos(theta)**44 - 3.79161915726232e+30*cos(theta)**42 + 2.4075103941024e+30*cos(theta)**40 - 1.30135696978508e+30*cos(theta)**38 + 5.99511107312525e+29*cos(theta)**36 - 2.35322116889029e+29*cos(theta)**34 + 7.85807783183006e+28*cos(theta)**32 - 2.22593181301411e+28*cos(theta)**30 + 5.32607447008327e+27*cos(theta)**28 - 1.07031161599759e+27*cos(theta)**26 + 1.79304781030525e+26*cos(theta)**24 - 2.48060749696365e+25*cos(theta)**22 + 2.80068588366864e+24*cos(theta)**20 - 2.54242865693761e+23*cos(theta)**18 + 1.82112165033452e+22*cos(theta)**16 - 1.00475677259836e+21*cos(theta)**14 + 4.13723376952265e+19*cos(theta)**12 - 1.21846242208164e+18*cos(theta)**10 + 2.4175841707969e+16*cos(theta)**8 - 295470784732925.0*cos(theta)**6 + 1918641459304.71*cos(theta)**4 - 4951332798.2057*cos(theta)**2 + 2119577.39649217)*sin(4*phi)

#@torch.jit.script
def Yl68_m_minus_3(theta, phi):
    return 1.45413184077863e-5*(1.0 - cos(theta)**2)**1.5*(6.06093512097793e+24*cos(theta)**65 - 9.33832966787711e+25*cos(theta)**63 + 6.8562999403624e+26*cos(theta)**61 - 3.19262821650463e+27*cos(theta)**59 + 1.05864086791462e+28*cos(theta)**57 - 2.66077295305784e+28*cos(theta)**55 + 5.26833044705452e+28*cos(theta)**53 - 8.43177625556462e+28*cos(theta)**51 + 1.11059036424017e+29*cos(theta)**49 - 1.21947177249901e+29*cos(theta)**47 + 1.12670853510379e+29*cos(theta)**45 - 8.81771897037749e+28*cos(theta)**43 + 5.87197657098147e+28*cos(theta)**41 - 3.33681274303867e+28*cos(theta)**39 + 1.62030029003385e+28*cos(theta)**37 - 6.72348905397224e+27*cos(theta)**35 + 2.38123570661517e+27*cos(theta)**33 - 7.18042520327133e+26*cos(theta)**31 + 1.83657740347699e+26*cos(theta)**29 - 3.96411709628739e+25*cos(theta)**27 + 7.172191241221e+24*cos(theta)**25 - 1.07852499867985e+24*cos(theta)**23 + 1.33365994460411e+23*cos(theta)**21 - 1.33812034575664e+22*cos(theta)**19 + 1.07124802960854e+21*cos(theta)**17 - 6.69837848398905e+19*cos(theta)**15 + 3.18248751501742e+18*cos(theta)**13 - 1.10769311098331e+17*cos(theta)**11 + 2.68620463421878e+15*cos(theta)**9 - 42210112104703.6*cos(theta)**7 + 383728291860.942*cos(theta)**5 - 1650444266.06857*cos(theta)**3 + 2119577.39649217*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl68_m_minus_2(theta, phi):
    return 0.000995416708568641*(1.0 - cos(theta)**2)*(9.18323503178475e+22*cos(theta)**66 - 1.4591140106058e+24*cos(theta)**64 + 1.10585482909071e+25*cos(theta)**62 - 5.32104702750772e+25*cos(theta)**60 + 1.82524287571486e+26*cos(theta)**58 - 4.75138027331757e+26*cos(theta)**56 + 9.75616749454542e+26*cos(theta)**54 - 1.62149543376243e+27*cos(theta)**52 + 2.22118072848035e+27*cos(theta)**50 - 2.54056619270628e+27*cos(theta)**48 + 2.44936638066041e+27*cos(theta)**46 - 2.00402703872216e+27*cos(theta)**44 + 1.39808965975749e+27*cos(theta)**42 - 8.34203185759668e+26*cos(theta)**40 + 4.26394813166803e+26*cos(theta)**38 - 1.86763584832562e+26*cos(theta)**36 + 7.00363443122109e+25*cos(theta)**34 - 2.24388287602229e+25*cos(theta)**32 + 6.12192467825663e+24*cos(theta)**30 - 1.41575610581692e+24*cos(theta)**28 + 2.75853509277731e+23*cos(theta)**26 - 4.49385416116604e+22*cos(theta)**24 + 6.06209065729143e+21*cos(theta)**22 - 6.69060172878318e+20*cos(theta)**20 + 5.95137794226969e+19*cos(theta)**18 - 4.18648655249316e+18*cos(theta)**16 + 2.27320536786959e+17*cos(theta)**14 - 9.23077592486089e+15*cos(theta)**12 + 268620463421878.0*cos(theta)**10 - 5276264013087.95*cos(theta)**8 + 63954715310.157*cos(theta)**6 - 412611066.517142*cos(theta)**4 + 1059788.69824608*cos(theta)**2 - 452.321254052959)*sin(2*phi)

#@torch.jit.script
def Yl68_m_minus_1(theta, phi):
    return 0.0681696944920679*(1.0 - cos(theta)**2)**0.5*(1.37063209429623e+21*cos(theta)**67 - 2.24479078554738e+22*cos(theta)**65 + 1.75532512554081e+23*cos(theta)**63 - 8.72302791394708e+23*cos(theta)**61 + 3.09363199273705e+24*cos(theta)**59 - 8.33575486546943e+24*cos(theta)**57 + 1.77384863537189e+25*cos(theta)**55 - 3.05942534672156e+25*cos(theta)**53 + 4.35525633035362e+25*cos(theta)**51 - 5.1848289647067e+25*cos(theta)**49 + 5.21141783119237e+25*cos(theta)**47 - 4.45339341938257e+25*cos(theta)**45 + 3.25137130176161e+25*cos(theta)**43 - 2.034641916487e+25*cos(theta)**41 + 1.09332003376103e+25*cos(theta)**39 - 5.04766445493412e+24*cos(theta)**37 + 2.00103840892031e+24*cos(theta)**35 - 6.79964507885542e+23*cos(theta)**33 + 1.97481441234085e+23*cos(theta)**31 - 4.88191760626526e+22*cos(theta)**29 + 1.0216796639916e+22*cos(theta)**27 - 1.79754166446642e+21*cos(theta)**25 + 2.63569159012671e+20*cos(theta)**23 - 3.18600082323009e+19*cos(theta)**21 + 3.13230418014194e+18*cos(theta)**19 - 2.46263914852539e+17*cos(theta)**17 + 1.51547024524639e+16*cos(theta)**15 - 710059686527761.0*cos(theta)**13 + 24420042129261.6*cos(theta)**11 - 586251557009.772*cos(theta)**9 + 9136387901.451*cos(theta)**7 - 82522213.3034284*cos(theta)**5 + 353262.899415361*cos(theta)**3 - 452.321254052959*cos(theta))*sin(phi)

#@torch.jit.script
def Yl68_m0(theta, phi):
    return 2.09082270908381e+20*cos(theta)**68 - 3.52806972688365e+21*cos(theta)**66 + 2.84500359555091e+22*cos(theta)**64 - 1.45942169176352e+23*cos(theta)**62 + 5.34838453318763e+23*cos(theta)**60 - 1.490809547046e+24*cos(theta)**58 + 3.28574424168939e+24*cos(theta)**56 - 5.87694092009484e+24*cos(theta)**54 + 8.68791576100796e+24*cos(theta)**52 - 1.07564671326765e+25*cos(theta)**50 + 1.12621130235288e+25*cos(theta)**48 - 1.00424217316526e+25*cos(theta)**46 + 7.66512278190298e+24*cos(theta)**44 - 5.02509088820528e+24*cos(theta)**42 + 2.83525770297821e+24*cos(theta)**40 - 1.37788224817633e+24*cos(theta)**38 + 5.76578107421403e+23*cos(theta)**36 - 2.07449576056815e+23*cos(theta)**34 + 6.40149681891493e+22*cos(theta)**32 - 1.68800766729495e+22*cos(theta)**30 + 3.78496564573868e+21*cos(theta)**28 - 7.17151385508382e+20*cos(theta)**26 + 1.13917008939503e+20*cos(theta)**24 - 1.50220231568576e+19*cos(theta)**22 + 1.62457272904218e+18*cos(theta)**20 - 1.41916698169202e+17*cos(theta)**18 + 9.82500218094477e+15*cos(theta)**16 - 526104534454874.0*cos(theta)**14 + 21109132555288.2*cos(theta)**12 - 608119925206.905*cos(theta)**10 + 11846492049.4852*cos(theta)**8 - 142667431.133585*cos(theta)**6 + 916100.799231066*cos(theta)**4 - 2345.96875603346*cos(theta)**2 + 0.999986682026197

#@torch.jit.script
def Yl68_m1(theta, phi):
    return 0.0681696944920679*(1.0 - cos(theta)**2)**0.5*(1.37063209429623e+21*cos(theta)**67 - 2.24479078554738e+22*cos(theta)**65 + 1.75532512554081e+23*cos(theta)**63 - 8.72302791394708e+23*cos(theta)**61 + 3.09363199273705e+24*cos(theta)**59 - 8.33575486546943e+24*cos(theta)**57 + 1.77384863537189e+25*cos(theta)**55 - 3.05942534672156e+25*cos(theta)**53 + 4.35525633035362e+25*cos(theta)**51 - 5.1848289647067e+25*cos(theta)**49 + 5.21141783119237e+25*cos(theta)**47 - 4.45339341938257e+25*cos(theta)**45 + 3.25137130176161e+25*cos(theta)**43 - 2.034641916487e+25*cos(theta)**41 + 1.09332003376103e+25*cos(theta)**39 - 5.04766445493412e+24*cos(theta)**37 + 2.00103840892031e+24*cos(theta)**35 - 6.79964507885542e+23*cos(theta)**33 + 1.97481441234085e+23*cos(theta)**31 - 4.88191760626526e+22*cos(theta)**29 + 1.0216796639916e+22*cos(theta)**27 - 1.79754166446642e+21*cos(theta)**25 + 2.63569159012671e+20*cos(theta)**23 - 3.18600082323009e+19*cos(theta)**21 + 3.13230418014194e+18*cos(theta)**19 - 2.46263914852539e+17*cos(theta)**17 + 1.51547024524639e+16*cos(theta)**15 - 710059686527761.0*cos(theta)**13 + 24420042129261.6*cos(theta)**11 - 586251557009.772*cos(theta)**9 + 9136387901.451*cos(theta)**7 - 82522213.3034284*cos(theta)**5 + 353262.899415361*cos(theta)**3 - 452.321254052959*cos(theta))*cos(phi)

#@torch.jit.script
def Yl68_m2(theta, phi):
    return 0.000995416708568641*(1.0 - cos(theta)**2)*(9.18323503178475e+22*cos(theta)**66 - 1.4591140106058e+24*cos(theta)**64 + 1.10585482909071e+25*cos(theta)**62 - 5.32104702750772e+25*cos(theta)**60 + 1.82524287571486e+26*cos(theta)**58 - 4.75138027331757e+26*cos(theta)**56 + 9.75616749454542e+26*cos(theta)**54 - 1.62149543376243e+27*cos(theta)**52 + 2.22118072848035e+27*cos(theta)**50 - 2.54056619270628e+27*cos(theta)**48 + 2.44936638066041e+27*cos(theta)**46 - 2.00402703872216e+27*cos(theta)**44 + 1.39808965975749e+27*cos(theta)**42 - 8.34203185759668e+26*cos(theta)**40 + 4.26394813166803e+26*cos(theta)**38 - 1.86763584832562e+26*cos(theta)**36 + 7.00363443122109e+25*cos(theta)**34 - 2.24388287602229e+25*cos(theta)**32 + 6.12192467825663e+24*cos(theta)**30 - 1.41575610581692e+24*cos(theta)**28 + 2.75853509277731e+23*cos(theta)**26 - 4.49385416116604e+22*cos(theta)**24 + 6.06209065729143e+21*cos(theta)**22 - 6.69060172878318e+20*cos(theta)**20 + 5.95137794226969e+19*cos(theta)**18 - 4.18648655249316e+18*cos(theta)**16 + 2.27320536786959e+17*cos(theta)**14 - 9.23077592486089e+15*cos(theta)**12 + 268620463421878.0*cos(theta)**10 - 5276264013087.95*cos(theta)**8 + 63954715310.157*cos(theta)**6 - 412611066.517142*cos(theta)**4 + 1059788.69824608*cos(theta)**2 - 452.321254052959)*cos(2*phi)

#@torch.jit.script
def Yl68_m3(theta, phi):
    return 1.45413184077863e-5*(1.0 - cos(theta)**2)**1.5*(6.06093512097793e+24*cos(theta)**65 - 9.33832966787711e+25*cos(theta)**63 + 6.8562999403624e+26*cos(theta)**61 - 3.19262821650463e+27*cos(theta)**59 + 1.05864086791462e+28*cos(theta)**57 - 2.66077295305784e+28*cos(theta)**55 + 5.26833044705452e+28*cos(theta)**53 - 8.43177625556462e+28*cos(theta)**51 + 1.11059036424017e+29*cos(theta)**49 - 1.21947177249901e+29*cos(theta)**47 + 1.12670853510379e+29*cos(theta)**45 - 8.81771897037749e+28*cos(theta)**43 + 5.87197657098147e+28*cos(theta)**41 - 3.33681274303867e+28*cos(theta)**39 + 1.62030029003385e+28*cos(theta)**37 - 6.72348905397224e+27*cos(theta)**35 + 2.38123570661517e+27*cos(theta)**33 - 7.18042520327133e+26*cos(theta)**31 + 1.83657740347699e+26*cos(theta)**29 - 3.96411709628739e+25*cos(theta)**27 + 7.172191241221e+24*cos(theta)**25 - 1.07852499867985e+24*cos(theta)**23 + 1.33365994460411e+23*cos(theta)**21 - 1.33812034575664e+22*cos(theta)**19 + 1.07124802960854e+21*cos(theta)**17 - 6.69837848398905e+19*cos(theta)**15 + 3.18248751501742e+18*cos(theta)**13 - 1.10769311098331e+17*cos(theta)**11 + 2.68620463421878e+15*cos(theta)**9 - 42210112104703.6*cos(theta)**7 + 383728291860.942*cos(theta)**5 - 1650444266.06857*cos(theta)**3 + 2119577.39649217*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl68_m4(theta, phi):
    return 2.12559665347432e-7*(1.0 - cos(theta)**2)**2*(3.93960782863566e+26*cos(theta)**64 - 5.88314769076258e+27*cos(theta)**62 + 4.18234296362107e+28*cos(theta)**60 - 1.88365064773773e+29*cos(theta)**58 + 6.03425294711332e+29*cos(theta)**56 - 1.46342512418181e+30*cos(theta)**54 + 2.7922151369389e+30*cos(theta)**52 - 4.30020589033795e+30*cos(theta)**50 + 5.44189278477685e+30*cos(theta)**48 - 5.73151733074537e+30*cos(theta)**46 + 5.07018840796706e+30*cos(theta)**44 - 3.79161915726232e+30*cos(theta)**42 + 2.4075103941024e+30*cos(theta)**40 - 1.30135696978508e+30*cos(theta)**38 + 5.99511107312525e+29*cos(theta)**36 - 2.35322116889029e+29*cos(theta)**34 + 7.85807783183006e+28*cos(theta)**32 - 2.22593181301411e+28*cos(theta)**30 + 5.32607447008327e+27*cos(theta)**28 - 1.07031161599759e+27*cos(theta)**26 + 1.79304781030525e+26*cos(theta)**24 - 2.48060749696365e+25*cos(theta)**22 + 2.80068588366864e+24*cos(theta)**20 - 2.54242865693761e+23*cos(theta)**18 + 1.82112165033452e+22*cos(theta)**16 - 1.00475677259836e+21*cos(theta)**14 + 4.13723376952265e+19*cos(theta)**12 - 1.21846242208164e+18*cos(theta)**10 + 2.4175841707969e+16*cos(theta)**8 - 295470784732925.0*cos(theta)**6 + 1918641459304.71*cos(theta)**4 - 4951332798.2057*cos(theta)**2 + 2119577.39649217)*cos(4*phi)

#@torch.jit.script
def Yl68_m5(theta, phi):
    return 3.10977838498613e-9*(1.0 - cos(theta)**2)**2.5*(2.52134901032682e+28*cos(theta)**63 - 3.6475515682728e+29*cos(theta)**61 + 2.50940577817264e+30*cos(theta)**59 - 1.09251737568788e+31*cos(theta)**57 + 3.37918165038346e+31*cos(theta)**55 - 7.90249567058179e+31*cos(theta)**53 + 1.45195187120823e+32*cos(theta)**51 - 2.15010294516898e+32*cos(theta)**49 + 2.61210853669289e+32*cos(theta)**47 - 2.63649797214287e+32*cos(theta)**45 + 2.23088289950551e+32*cos(theta)**43 - 1.59248004605017e+32*cos(theta)**41 + 9.63004157640961e+31*cos(theta)**39 - 4.94515648518331e+31*cos(theta)**37 + 2.15823998632509e+31*cos(theta)**35 - 8.00095197422697e+30*cos(theta)**33 + 2.51458490618562e+30*cos(theta)**31 - 6.67779543904233e+29*cos(theta)**29 + 1.49130085162332e+29*cos(theta)**27 - 2.78281020159375e+28*cos(theta)**25 + 4.3033147447326e+27*cos(theta)**23 - 5.45733649332004e+26*cos(theta)**21 + 5.60137176733728e+25*cos(theta)**19 - 4.5763715824877e+24*cos(theta)**17 + 2.91379464053524e+23*cos(theta)**15 - 1.4066594816377e+22*cos(theta)**13 + 4.96468052342718e+20*cos(theta)**11 - 1.21846242208164e+19*cos(theta)**9 + 1.93406733663752e+17*cos(theta)**7 - 1.77282470839755e+15*cos(theta)**5 + 7674565837218.84*cos(theta)**3 - 9902665596.41141*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl68_m6(theta, phi):
    return 4.55452726237454e-11*(1.0 - cos(theta)**2)**3*(1.5884498765059e+30*cos(theta)**62 - 2.22500645664641e+31*cos(theta)**60 + 1.48054940912186e+32*cos(theta)**58 - 6.22734904142094e+32*cos(theta)**56 + 1.8585499077109e+33*cos(theta)**54 - 4.18832270540835e+33*cos(theta)**52 + 7.40495454316196e+33*cos(theta)**50 - 1.0535504431328e+34*cos(theta)**48 + 1.22769101224566e+34*cos(theta)**46 - 1.18642408746429e+34*cos(theta)**44 + 9.59279646787367e+33*cos(theta)**42 - 6.52916818880572e+33*cos(theta)**40 + 3.75571621479975e+33*cos(theta)**38 - 1.82970789951783e+33*cos(theta)**36 + 7.55383995213781e+32*cos(theta)**34 - 2.6403141514949e+32*cos(theta)**32 + 7.79521320917542e+31*cos(theta)**30 - 1.93656067732228e+31*cos(theta)**28 + 4.02651229938295e+30*cos(theta)**26 - 6.95702550398437e+29*cos(theta)**24 + 9.89762391288498e+28*cos(theta)**22 - 1.14604066359721e+28*cos(theta)**20 + 1.06426063579408e+27*cos(theta)**18 - 7.77983169022909e+25*cos(theta)**16 + 4.37069196080286e+24*cos(theta)**14 - 1.82865732612901e+23*cos(theta)**12 + 5.4611485757699e+21*cos(theta)**10 - 1.09661617987347e+20*cos(theta)**8 + 1.35384713564626e+18*cos(theta)**6 - 8.86412354198776e+15*cos(theta)**4 + 23023697511656.5*cos(theta)**2 - 9902665596.41141)*cos(6*phi)

#@torch.jit.script
def Yl68_m7(theta, phi):
    return 6.67908283313328e-13*(1.0 - cos(theta)**2)**3.5*(9.84838923433656e+31*cos(theta)**61 - 1.33500387398784e+33*cos(theta)**59 + 8.58718657290677e+33*cos(theta)**57 - 3.48731546319573e+34*cos(theta)**55 + 1.00361695016389e+35*cos(theta)**53 - 2.17792780681234e+35*cos(theta)**51 + 3.70247727158098e+35*cos(theta)**49 - 5.05704212703743e+35*cos(theta)**47 + 5.64737865633003e+35*cos(theta)**45 - 5.22026598484288e+35*cos(theta)**43 + 4.02897451650694e+35*cos(theta)**41 - 2.61166727552229e+35*cos(theta)**39 + 1.4271721616239e+35*cos(theta)**37 - 6.58694843826417e+34*cos(theta)**35 + 2.56830558372686e+34*cos(theta)**33 - 8.44900528478368e+33*cos(theta)**31 + 2.33856396275263e+33*cos(theta)**29 - 5.42236989650238e+32*cos(theta)**27 + 1.04689319783957e+32*cos(theta)**25 - 1.66968612095625e+31*cos(theta)**23 + 2.17747726083469e+30*cos(theta)**21 - 2.29208132719442e+29*cos(theta)**19 + 1.91566914442935e+28*cos(theta)**17 - 1.24477307043665e+27*cos(theta)**15 + 6.118968745124e+25*cos(theta)**13 - 2.19438879135481e+24*cos(theta)**11 + 5.4611485757699e+22*cos(theta)**9 - 8.77292943898779e+20*cos(theta)**7 + 8.12308281387758e+18*cos(theta)**5 - 3.5456494167951e+16*cos(theta)**3 + 46047395023313.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl68_m8(theta, phi):
    return 9.80946034588623e-15*(1.0 - cos(theta)**2)**4*(6.0075174329453e+33*cos(theta)**60 - 7.87652285652828e+34*cos(theta)**58 + 4.89469634655686e+35*cos(theta)**56 - 1.91802350475765e+36*cos(theta)**54 + 5.3191698358686e+36*cos(theta)**52 - 1.11074318147429e+37*cos(theta)**50 + 1.81421386307468e+37*cos(theta)**48 - 2.37680979970759e+37*cos(theta)**46 + 2.54132039534851e+37*cos(theta)**44 - 2.24471437348244e+37*cos(theta)**42 + 1.65187955176785e+37*cos(theta)**40 - 1.01855023745369e+37*cos(theta)**38 + 5.28053699800845e+36*cos(theta)**36 - 2.30543195339246e+36*cos(theta)**34 + 8.47540842629863e+35*cos(theta)**32 - 2.61919163828294e+35*cos(theta)**30 + 6.78183549198261e+34*cos(theta)**28 - 1.46403987205564e+34*cos(theta)**26 + 2.61723299459892e+33*cos(theta)**24 - 3.84027807819937e+32*cos(theta)**22 + 4.57270224775286e+31*cos(theta)**20 - 4.35495452166939e+30*cos(theta)**18 + 3.2566375455299e+29*cos(theta)**16 - 1.86715960565498e+28*cos(theta)**14 + 7.9546593686612e+26*cos(theta)**12 - 2.4138276704903e+25*cos(theta)**10 + 4.91503371819291e+23*cos(theta)**8 - 6.14105060729145e+21*cos(theta)**6 + 4.06154140693879e+19*cos(theta)**4 - 1.06369482503853e+17*cos(theta)**2 + 46047395023313.0)*cos(8*phi)

#@torch.jit.script
def Yl68_m9(theta, phi):
    return 1.44319205099325e-16*(1.0 - cos(theta)**2)**4.5*(3.60451045976718e+35*cos(theta)**59 - 4.5683832567864e+36*cos(theta)**57 + 2.74102995407184e+37*cos(theta)**55 - 1.03573269256913e+38*cos(theta)**53 + 2.76596831465167e+38*cos(theta)**51 - 5.55371590737147e+38*cos(theta)**49 + 8.70822654275846e+38*cos(theta)**47 - 1.09333250786549e+39*cos(theta)**45 + 1.11818097395335e+39*cos(theta)**43 - 9.42780036862625e+38*cos(theta)**41 + 6.60751820707139e+38*cos(theta)**39 - 3.87049090232403e+38*cos(theta)**37 + 1.90099331928304e+38*cos(theta)**35 - 7.83846864153437e+37*cos(theta)**33 + 2.71213069641556e+37*cos(theta)**31 - 7.85757491484882e+36*cos(theta)**29 + 1.89891393775513e+36*cos(theta)**27 - 3.80650366734467e+35*cos(theta)**25 + 6.28135918703741e+34*cos(theta)**23 - 8.44861177203862e+33*cos(theta)**21 + 9.14540449550572e+32*cos(theta)**19 - 7.8389181390049e+31*cos(theta)**17 + 5.21062007284783e+30*cos(theta)**15 - 2.61402344791697e+29*cos(theta)**13 + 9.54559124239344e+27*cos(theta)**11 - 2.4138276704903e+26*cos(theta)**9 + 3.93202697455433e+24*cos(theta)**7 - 3.68463036437487e+22*cos(theta)**5 + 1.62461656277552e+20*cos(theta)**3 - 2.12738965007706e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl68_m10(theta, phi):
    return 2.12740816128001e-18*(1.0 - cos(theta)**2)**5*(2.12666117126264e+37*cos(theta)**58 - 2.60397845636825e+38*cos(theta)**56 + 1.50756647473951e+39*cos(theta)**54 - 5.4893832706164e+39*cos(theta)**52 + 1.41064384047235e+40*cos(theta)**50 - 2.72132079461202e+40*cos(theta)**48 + 4.09286647509648e+40*cos(theta)**46 - 4.91999628539472e+40*cos(theta)**44 + 4.80817818799939e+40*cos(theta)**42 - 3.86539815113676e+40*cos(theta)**40 + 2.57693210075784e+40*cos(theta)**38 - 1.43208163385989e+40*cos(theta)**36 + 6.65347661749064e+39*cos(theta)**34 - 2.58669465170634e+39*cos(theta)**32 + 8.40760515888824e+38*cos(theta)**30 - 2.27869672530616e+38*cos(theta)**28 + 5.12706763193886e+37*cos(theta)**26 - 9.51625916836167e+36*cos(theta)**24 + 1.4447126130186e+36*cos(theta)**22 - 1.77420847212811e+35*cos(theta)**20 + 1.73762685414609e+34*cos(theta)**18 - 1.33261608363083e+33*cos(theta)**16 + 7.81593010927175e+31*cos(theta)**14 - 3.39823048229206e+30*cos(theta)**12 + 1.05001503666328e+29*cos(theta)**10 - 2.17244490344127e+27*cos(theta)**8 + 2.75241888218803e+25*cos(theta)**6 - 1.84231518218744e+23*cos(theta)**4 + 4.87384968832655e+20*cos(theta)**2 - 2.12738965007706e+17)*cos(10*phi)

#@torch.jit.script
def Yl68_m11(theta, phi):
    return 3.14284728459738e-20*(1.0 - cos(theta)**2)**5.5*(1.23346347933233e+39*cos(theta)**57 - 1.45822793556622e+40*cos(theta)**55 + 8.14085896359337e+40*cos(theta)**53 - 2.85447930072053e+41*cos(theta)**51 + 7.05321920236176e+41*cos(theta)**49 - 1.30623398141377e+42*cos(theta)**47 + 1.88271857854438e+42*cos(theta)**45 - 2.16479836557368e+42*cos(theta)**43 + 2.01943483895974e+42*cos(theta)**41 - 1.5461592604547e+42*cos(theta)**39 + 9.79234198287979e+41*cos(theta)**37 - 5.15549388189561e+41*cos(theta)**35 + 2.26218204994682e+41*cos(theta)**33 - 8.27742288546029e+40*cos(theta)**31 + 2.52228154766647e+40*cos(theta)**29 - 6.38035083085724e+39*cos(theta)**27 + 1.3330375843041e+39*cos(theta)**25 - 2.2839022004068e+38*cos(theta)**23 + 3.17836774864093e+37*cos(theta)**21 - 3.54841694425622e+36*cos(theta)**19 + 3.12772833746296e+35*cos(theta)**17 - 2.13218573380933e+34*cos(theta)**15 + 1.09423021529804e+33*cos(theta)**13 - 4.07787657875048e+31*cos(theta)**11 + 1.05001503666328e+30*cos(theta)**9 - 1.73795592275301e+28*cos(theta)**7 + 1.65145132931282e+26*cos(theta)**5 - 7.36926072874974e+23*cos(theta)**3 + 9.7476993766531e+20*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl68_m12(theta, phi):
    return 4.65415515499867e-22*(1.0 - cos(theta)**2)**6*(7.03074183219428e+40*cos(theta)**56 - 8.02025364561421e+41*cos(theta)**54 + 4.31465525070449e+42*cos(theta)**52 - 1.45578444336747e+43*cos(theta)**50 + 3.45607740915726e+43*cos(theta)**48 - 6.13929971264472e+43*cos(theta)**46 + 8.47223360344971e+43*cos(theta)**44 - 9.30863297196681e+43*cos(theta)**42 + 8.27968283973494e+43*cos(theta)**40 - 6.03002111577335e+43*cos(theta)**38 + 3.62316653366552e+43*cos(theta)**36 - 1.80442285866346e+43*cos(theta)**34 + 7.4652007648245e+42*cos(theta)**32 - 2.56600109449269e+42*cos(theta)**30 + 7.31461648823277e+41*cos(theta)**28 - 1.72269472433146e+41*cos(theta)**26 + 3.33259396076026e+40*cos(theta)**24 - 5.25297506093564e+39*cos(theta)**22 + 6.67457227214595e+38*cos(theta)**20 - 6.74199219408681e+37*cos(theta)**18 + 5.31713817368702e+36*cos(theta)**16 - 3.198278600714e+35*cos(theta)**14 + 1.42249927988746e+34*cos(theta)**12 - 4.48566423662553e+32*cos(theta)**10 + 9.45013532996951e+30*cos(theta)**8 - 1.21656914592711e+29*cos(theta)**6 + 8.25725664656409e+26*cos(theta)**4 - 2.21077821862492e+24*cos(theta)**2 + 9.7476993766531e+20)*cos(12*phi)

#@torch.jit.script
def Yl68_m13(theta, phi):
    return 6.9104182598781e-24*(1.0 - cos(theta)**2)**6.5*(3.93721542602879e+42*cos(theta)**55 - 4.33093696863167e+43*cos(theta)**53 + 2.24362073036633e+44*cos(theta)**51 - 7.27892221683734e+44*cos(theta)**49 + 1.65891715639549e+45*cos(theta)**47 - 2.82407786781657e+45*cos(theta)**45 + 3.72778278551787e+45*cos(theta)**43 - 3.90962584822606e+45*cos(theta)**41 + 3.31187313589398e+45*cos(theta)**39 - 2.29140802399387e+45*cos(theta)**37 + 1.30433995211959e+45*cos(theta)**35 - 6.13503771945577e+44*cos(theta)**33 + 2.38886424474384e+44*cos(theta)**31 - 7.69800328347807e+43*cos(theta)**29 + 2.04809261670518e+43*cos(theta)**27 - 4.47900628326178e+42*cos(theta)**25 + 7.99822550582462e+41*cos(theta)**23 - 1.15565451340584e+41*cos(theta)**21 + 1.33491445442919e+40*cos(theta)**19 - 1.21355859493563e+39*cos(theta)**17 + 8.50742107789924e+37*cos(theta)**15 - 4.4775900409996e+36*cos(theta)**13 + 1.70699913586495e+35*cos(theta)**11 - 4.48566423662553e+33*cos(theta)**9 + 7.5601082639756e+31*cos(theta)**7 - 7.29941487556265e+29*cos(theta)**5 + 3.30290265862563e+27*cos(theta)**3 - 4.42155643724985e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl68_m14(theta, phi):
    return 1.02900163147154e-25*(1.0 - cos(theta)**2)**7*(2.16546848431584e+44*cos(theta)**54 - 2.29539659337479e+45*cos(theta)**52 + 1.14424657248683e+46*cos(theta)**50 - 3.5666718862503e+46*cos(theta)**48 + 7.79691063505879e+46*cos(theta)**46 - 1.27083504051746e+47*cos(theta)**44 + 1.60294659777268e+47*cos(theta)**42 - 1.60294659777268e+47*cos(theta)**40 + 1.29163052299865e+47*cos(theta)**38 - 8.47820968877733e+46*cos(theta)**36 + 4.56518983241856e+46*cos(theta)**34 - 2.0245624474204e+46*cos(theta)**32 + 7.4054791587059e+45*cos(theta)**30 - 2.23242095220864e+45*cos(theta)**28 + 5.52985006510397e+44*cos(theta)**26 - 1.11975157081545e+44*cos(theta)**24 + 1.83959186633966e+43*cos(theta)**22 - 2.42687447815227e+42*cos(theta)**20 + 2.53633746341546e+41*cos(theta)**18 - 2.06304961139057e+40*cos(theta)**16 + 1.27611316168489e+39*cos(theta)**14 - 5.82086705329948e+37*cos(theta)**12 + 1.87769904945144e+36*cos(theta)**10 - 4.03709781296297e+34*cos(theta)**8 + 5.29207578478292e+32*cos(theta)**6 - 3.64970743778133e+30*cos(theta)**4 + 9.9087079758769e+27*cos(theta)**2 - 4.42155643724985e+24)*cos(14*phi)

#@torch.jit.script
def Yl68_m15(theta, phi):
    return 1.53702218920533e-27*(1.0 - cos(theta)**2)**7.5*(1.16935298153055e+46*cos(theta)**53 - 1.19360622855489e+47*cos(theta)**51 + 5.72123286243415e+47*cos(theta)**49 - 1.71200250540014e+48*cos(theta)**47 + 3.58657889212704e+48*cos(theta)**45 - 5.59167417827681e+48*cos(theta)**43 + 6.73237571064528e+48*cos(theta)**41 - 6.41178639109074e+48*cos(theta)**39 + 4.90819598739487e+48*cos(theta)**37 - 3.05215548795984e+48*cos(theta)**35 + 1.55216454302231e+48*cos(theta)**33 - 6.4785998317453e+47*cos(theta)**31 + 2.22164374761177e+47*cos(theta)**29 - 6.25077866618419e+46*cos(theta)**27 + 1.43776101692703e+46*cos(theta)**25 - 2.68740376995707e+45*cos(theta)**23 + 4.04710210594726e+44*cos(theta)**21 - 4.85374895630453e+43*cos(theta)**19 + 4.56540743414783e+42*cos(theta)**17 - 3.3008793782249e+41*cos(theta)**15 + 1.78655842635884e+40*cos(theta)**13 - 6.98504046395937e+38*cos(theta)**11 + 1.87769904945144e+37*cos(theta)**9 - 3.22967825037038e+35*cos(theta)**7 + 3.17524547086975e+33*cos(theta)**5 - 1.45988297511253e+31*cos(theta)**3 + 1.98174159517538e+28*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl68_m16(theta, phi):
    return 2.303576075604e-29*(1.0 - cos(theta)**2)**8*(6.19757080211193e+47*cos(theta)**52 - 6.08739176562993e+48*cos(theta)**50 + 2.80340410259273e+49*cos(theta)**48 - 8.04641177538067e+49*cos(theta)**46 + 1.61396050145717e+50*cos(theta)**44 - 2.40441989665903e+50*cos(theta)**42 + 2.76027404136456e+50*cos(theta)**40 - 2.50059669252539e+50*cos(theta)**38 + 1.8160325153361e+50*cos(theta)**36 - 1.06825442078594e+50*cos(theta)**34 + 5.12214299197362e+49*cos(theta)**32 - 2.00836594784104e+49*cos(theta)**30 + 6.44276686807414e+48*cos(theta)**28 - 1.68771023986973e+48*cos(theta)**26 + 3.59440254231758e+47*cos(theta)**24 - 6.18102867090126e+46*cos(theta)**22 + 8.49891442248924e+45*cos(theta)**20 - 9.22212301697861e+44*cos(theta)**18 + 7.76119263805131e+43*cos(theta)**16 - 4.95131906733736e+42*cos(theta)**14 + 2.32252595426649e+41*cos(theta)**12 - 7.68354451035531e+39*cos(theta)**10 + 1.6899291445063e+38*cos(theta)**8 - 2.26077477525926e+36*cos(theta)**6 + 1.58762273543488e+34*cos(theta)**4 - 4.37964892533759e+31*cos(theta)**2 + 1.98174159517538e+28)*cos(16*phi)

#@torch.jit.script
def Yl68_m17(theta, phi):
    return 3.46490574202534e-31*(1.0 - cos(theta)**2)**8.5*(3.2227368170982e+49*cos(theta)**51 - 3.04369588281497e+50*cos(theta)**49 + 1.34563396924451e+51*cos(theta)**47 - 3.70134941667511e+51*cos(theta)**45 + 7.10142620641154e+51*cos(theta)**43 - 1.00985635659679e+52*cos(theta)**41 + 1.10410961654583e+52*cos(theta)**39 - 9.50226743159647e+51*cos(theta)**37 + 6.53771705520997e+51*cos(theta)**35 - 3.63206503067221e+51*cos(theta)**33 + 1.63908575743156e+51*cos(theta)**31 - 6.02509784352312e+50*cos(theta)**29 + 1.80397472306076e+50*cos(theta)**27 - 4.3880466236613e+49*cos(theta)**25 + 8.6265661015622e+48*cos(theta)**23 - 1.35982630759828e+48*cos(theta)**21 + 1.69978288449785e+47*cos(theta)**19 - 1.65998214305615e+46*cos(theta)**17 + 1.24179082208821e+45*cos(theta)**15 - 6.9318466942723e+43*cos(theta)**13 + 2.78703114511979e+42*cos(theta)**11 - 7.68354451035531e+40*cos(theta)**9 + 1.35194331560504e+39*cos(theta)**7 - 1.35646486515556e+37*cos(theta)**5 + 6.35049094173951e+34*cos(theta)**3 - 8.75929785067518e+31*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl68_m18(theta, phi):
    return 5.23187200977587e-33*(1.0 - cos(theta)**2)**9*(1.64359577672008e+51*cos(theta)**50 - 1.49141098257933e+52*cos(theta)**48 + 6.32447965544921e+52*cos(theta)**46 - 1.6656072375038e+53*cos(theta)**44 + 3.05361326875696e+53*cos(theta)**42 - 4.14041106204684e+53*cos(theta)**40 + 4.30602750452872e+53*cos(theta)**38 - 3.5158389496907e+53*cos(theta)**36 + 2.28820096932349e+53*cos(theta)**34 - 1.19858146012183e+53*cos(theta)**32 + 5.08116584803783e+52*cos(theta)**30 - 1.74727837462171e+52*cos(theta)**28 + 4.87073175226405e+51*cos(theta)**26 - 1.09701165591533e+51*cos(theta)**24 + 1.98411020335931e+50*cos(theta)**22 - 2.85563524595638e+49*cos(theta)**20 + 3.22958748054591e+48*cos(theta)**18 - 2.82196964319546e+47*cos(theta)**16 + 1.86268623313231e+46*cos(theta)**14 - 9.01140070255399e+44*cos(theta)**12 + 3.06573425963177e+43*cos(theta)**10 - 6.91519005931978e+41*cos(theta)**8 + 9.46360320923528e+39*cos(theta)**6 - 6.78232432577779e+37*cos(theta)**4 + 1.90514728252185e+35*cos(theta)**2 - 8.75929785067518e+31)*cos(18*phi)

#@torch.jit.script
def Yl68_m19(theta, phi):
    return 7.93254386973263e-35*(1.0 - cos(theta)**2)**9.5*(8.21797888360041e+52*cos(theta)**49 - 7.1587727163808e+53*cos(theta)**47 + 2.90926064150663e+54*cos(theta)**45 - 7.32867184501671e+54*cos(theta)**43 + 1.28251757287793e+55*cos(theta)**41 - 1.65616442481874e+55*cos(theta)**39 + 1.63629045172091e+55*cos(theta)**37 - 1.26570202188865e+55*cos(theta)**35 + 7.77988329569987e+54*cos(theta)**33 - 3.83546067238985e+54*cos(theta)**31 + 1.52434975441135e+54*cos(theta)**29 - 4.89237944894078e+53*cos(theta)**27 + 1.26639025558865e+53*cos(theta)**25 - 2.63282797419678e+52*cos(theta)**23 + 4.36504244739047e+51*cos(theta)**21 - 5.71127049191277e+50*cos(theta)**19 + 5.81325746498264e+49*cos(theta)**17 - 4.51515142911273e+48*cos(theta)**15 + 2.60776072638524e+47*cos(theta)**13 - 1.08136808430648e+46*cos(theta)**11 + 3.06573425963177e+44*cos(theta)**9 - 5.53215204745582e+42*cos(theta)**7 + 5.67816192554117e+40*cos(theta)**5 - 2.71292973031112e+38*cos(theta)**3 + 3.81029456504371e+35*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl68_m20(theta, phi):
    return 1.2080171682495e-36*(1.0 - cos(theta)**2)**10*(4.0268096529642e+54*cos(theta)**48 - 3.36462317669898e+55*cos(theta)**46 + 1.30916728867799e+56*cos(theta)**44 - 3.15132889335719e+56*cos(theta)**42 + 5.25832204879949e+56*cos(theta)**40 - 6.45904125679308e+56*cos(theta)**38 + 6.05427467136738e+56*cos(theta)**36 - 4.42995707661028e+56*cos(theta)**34 + 2.56736148758096e+56*cos(theta)**32 - 1.18899280844085e+56*cos(theta)**30 + 4.42061428779292e+55*cos(theta)**28 - 1.32094245121401e+55*cos(theta)**26 + 3.16597563897163e+54*cos(theta)**24 - 6.0555043406526e+53*cos(theta)**22 + 9.16658913951999e+52*cos(theta)**20 - 1.08514139346343e+52*cos(theta)**18 + 9.88253769047048e+50*cos(theta)**16 - 6.77272714366909e+49*cos(theta)**14 + 3.39008894430081e+48*cos(theta)**12 - 1.18950489273713e+47*cos(theta)**10 + 2.75916083366859e+45*cos(theta)**8 - 3.87250643321908e+43*cos(theta)**6 + 2.83908096277058e+41*cos(theta)**4 - 8.13878919093335e+38*cos(theta)**2 + 3.81029456504371e+35)*cos(20*phi)

#@torch.jit.script
def Yl68_m21(theta, phi):
    return 1.84823625230872e-38*(1.0 - cos(theta)**2)**10.5*(1.93286863342282e+56*cos(theta)**47 - 1.54772666128153e+57*cos(theta)**45 + 5.76033607018314e+57*cos(theta)**43 - 1.32355813521002e+58*cos(theta)**41 + 2.1033288195198e+58*cos(theta)**39 - 2.45443567758137e+58*cos(theta)**37 + 2.17953888169226e+58*cos(theta)**35 - 1.50618540604749e+58*cos(theta)**33 + 8.21555676025906e+57*cos(theta)**31 - 3.56697842532256e+57*cos(theta)**29 + 1.23777200058202e+57*cos(theta)**27 - 3.43445037315643e+56*cos(theta)**25 + 7.59834153353191e+55*cos(theta)**23 - 1.33221095494357e+55*cos(theta)**21 + 1.833317827904e+54*cos(theta)**19 - 1.95325450823417e+53*cos(theta)**17 + 1.58120603047528e+52*cos(theta)**15 - 9.48181800113673e+50*cos(theta)**13 + 4.06810673316097e+49*cos(theta)**11 - 1.18950489273713e+48*cos(theta)**9 + 2.20732866693487e+46*cos(theta)**7 - 2.32350385993145e+44*cos(theta)**5 + 1.13563238510823e+42*cos(theta)**3 - 1.62775783818667e+39*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl68_m22(theta, phi):
    return 2.84175937094191e-40*(1.0 - cos(theta)**2)**11*(9.08448257708724e+57*cos(theta)**46 - 6.96476997576688e+58*cos(theta)**44 + 2.47694451017875e+59*cos(theta)**42 - 5.42658835436108e+59*cos(theta)**40 + 8.20298239612721e+59*cos(theta)**38 - 9.08141200705107e+59*cos(theta)**36 + 7.6283860859229e+59*cos(theta)**34 - 4.97041183995673e+59*cos(theta)**32 + 2.54682259568031e+59*cos(theta)**30 - 1.03442374334354e+59*cos(theta)**28 + 3.34198440157144e+58*cos(theta)**26 - 8.58612593289106e+57*cos(theta)**24 + 1.74761855271234e+57*cos(theta)**22 - 2.7976430053815e+56*cos(theta)**20 + 3.4833038730176e+55*cos(theta)**18 - 3.32053266399808e+54*cos(theta)**16 + 2.37180904571292e+53*cos(theta)**14 - 1.23263634014777e+52*cos(theta)**12 + 4.47491740647707e+50*cos(theta)**10 - 1.07055440346341e+49*cos(theta)**8 + 1.54513006685441e+47*cos(theta)**6 - 1.16175192996572e+45*cos(theta)**4 + 3.4068971553247e+42*cos(theta)**2 - 1.62775783818667e+39)*cos(22*phi)

#@torch.jit.script
def Yl68_m23(theta, phi):
    return 4.39225644517833e-42*(1.0 - cos(theta)**2)**11.5*(4.17886198546013e+59*cos(theta)**45 - 3.06449878933743e+60*cos(theta)**43 + 1.04031669427507e+61*cos(theta)**41 - 2.17063534174443e+61*cos(theta)**39 + 3.11713331052834e+61*cos(theta)**37 - 3.26930832253838e+61*cos(theta)**35 + 2.59365126921378e+61*cos(theta)**33 - 1.59053178878615e+61*cos(theta)**31 + 7.64046778704092e+60*cos(theta)**29 - 2.89638648136192e+60*cos(theta)**27 + 8.68915944408576e+59*cos(theta)**25 - 2.06067022389386e+59*cos(theta)**23 + 3.84476081596715e+58*cos(theta)**21 - 5.595286010763e+57*cos(theta)**19 + 6.26994697143167e+56*cos(theta)**17 - 5.31285226239693e+55*cos(theta)**15 + 3.32053266399808e+54*cos(theta)**13 - 1.47916360817733e+53*cos(theta)**11 + 4.47491740647707e+51*cos(theta)**9 - 8.56443522770731e+49*cos(theta)**7 + 9.27078040112647e+47*cos(theta)**5 - 4.64700771986289e+45*cos(theta)**3 + 6.8137943106494e+42*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl68_m24(theta, phi):
    return 6.82633375692216e-44*(1.0 - cos(theta)**2)**12*(1.88048789345706e+61*cos(theta)**44 - 1.31773447941509e+62*cos(theta)**42 + 4.26529844652781e+62*cos(theta)**40 - 8.46547783280328e+62*cos(theta)**38 + 1.15333932489549e+63*cos(theta)**36 - 1.14425791288843e+63*cos(theta)**34 + 8.55904918840549e+62*cos(theta)**32 - 4.93064854523708e+62*cos(theta)**30 + 2.21573565824187e+62*cos(theta)**28 - 7.82024349967718e+61*cos(theta)**26 + 2.17228986102144e+61*cos(theta)**24 - 4.73954151495587e+60*cos(theta)**22 + 8.07399771353101e+59*cos(theta)**20 - 1.06310434204497e+59*cos(theta)**18 + 1.06589098514338e+58*cos(theta)**16 - 7.9692783935954e+56*cos(theta)**14 + 4.31669246319751e+55*cos(theta)**12 - 1.62707996899506e+54*cos(theta)**10 + 4.02742566582936e+52*cos(theta)**8 - 5.99510465939512e+50*cos(theta)**6 + 4.63539020056324e+48*cos(theta)**4 - 1.39410231595887e+46*cos(theta)**2 + 6.8137943106494e+42)*cos(24*phi)

#@torch.jit.script
def Yl68_m25(theta, phi):
    return 1.06713583921524e-45*(1.0 - cos(theta)**2)**12.5*(8.27414673121106e+62*cos(theta)**43 - 5.5344848135434e+63*cos(theta)**41 + 1.70611937861112e+64*cos(theta)**39 - 3.21688157646525e+64*cos(theta)**37 + 4.15202156962375e+64*cos(theta)**35 - 3.89047690382068e+64*cos(theta)**33 + 2.73889574028976e+64*cos(theta)**31 - 1.47919456357112e+64*cos(theta)**29 + 6.20405984307723e+63*cos(theta)**27 - 2.03326330991607e+63*cos(theta)**25 + 5.21349566645145e+62*cos(theta)**23 - 1.04269913329029e+62*cos(theta)**21 + 1.6147995427062e+61*cos(theta)**19 - 1.91358781568095e+60*cos(theta)**17 + 1.70542557622942e+59*cos(theta)**15 - 1.11569897510336e+58*cos(theta)**13 + 5.18003095583701e+56*cos(theta)**11 - 1.62707996899506e+55*cos(theta)**9 + 3.22194053266349e+53*cos(theta)**7 - 3.59706279563707e+51*cos(theta)**5 + 1.85415608022529e+49*cos(theta)**3 - 2.78820463191774e+46*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl68_m26(theta, phi):
    return 1.67850079437529e-47*(1.0 - cos(theta)**2)**13*(3.55788309442076e+64*cos(theta)**42 - 2.26913877355279e+65*cos(theta)**40 + 6.65386557658338e+65*cos(theta)**38 - 1.19024618329214e+66*cos(theta)**36 + 1.45320754936831e+66*cos(theta)**34 - 1.28385737826082e+66*cos(theta)**32 + 8.49057679489824e+65*cos(theta)**30 - 4.28966423435626e+65*cos(theta)**28 + 1.67509615763085e+65*cos(theta)**26 - 5.08315827479017e+64*cos(theta)**24 + 1.19910400328383e+64*cos(theta)**22 - 2.18966817990961e+63*cos(theta)**20 + 3.06811913114179e+62*cos(theta)**18 - 3.25309928665761e+61*cos(theta)**16 + 2.55813836434412e+60*cos(theta)**14 - 1.45040866763436e+59*cos(theta)**12 + 5.69803405142071e+57*cos(theta)**10 - 1.46437197209556e+56*cos(theta)**8 + 2.25535837286444e+54*cos(theta)**6 - 1.79853139781854e+52*cos(theta)**4 + 5.56246824067588e+49*cos(theta)**2 - 2.78820463191774e+46)*cos(26*phi)

#@torch.jit.script
def Yl68_m27(theta, phi):
    return 2.65726644395734e-49*(1.0 - cos(theta)**2)**13.5*(1.49431089965672e+66*cos(theta)**41 - 9.07655509421117e+66*cos(theta)**39 + 2.52846891910168e+67*cos(theta)**37 - 4.28488625985171e+67*cos(theta)**35 + 4.94090566785226e+67*cos(theta)**33 - 4.10834361043463e+67*cos(theta)**31 + 2.54717303846947e+67*cos(theta)**29 - 1.20110598561975e+67*cos(theta)**27 + 4.35525000984022e+66*cos(theta)**25 - 1.21995798594964e+66*cos(theta)**23 + 2.63802880722444e+65*cos(theta)**21 - 4.37933635981922e+64*cos(theta)**19 + 5.52261443605521e+63*cos(theta)**17 - 5.20495885865218e+62*cos(theta)**15 + 3.58139371008177e+61*cos(theta)**13 - 1.74049040116124e+60*cos(theta)**11 + 5.69803405142071e+58*cos(theta)**9 - 1.17149757767645e+57*cos(theta)**7 + 1.35321502371867e+55*cos(theta)**5 - 7.19412559127414e+52*cos(theta)**3 + 1.11249364813518e+50*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl68_m28(theta, phi):
    return 4.23552801267956e-51*(1.0 - cos(theta)**2)**14*(6.12667468859254e+67*cos(theta)**40 - 3.53985648674236e+68*cos(theta)**38 + 9.35533500067623e+68*cos(theta)**36 - 1.4997101909481e+69*cos(theta)**34 + 1.63049887039125e+69*cos(theta)**32 - 1.27358651923474e+69*cos(theta)**30 + 7.38680181156147e+68*cos(theta)**28 - 3.24298616117333e+68*cos(theta)**26 + 1.08881250246005e+68*cos(theta)**24 - 2.80590336768417e+67*cos(theta)**22 + 5.53986049517131e+66*cos(theta)**20 - 8.32073908365652e+65*cos(theta)**18 + 9.38844454129386e+64*cos(theta)**16 - 7.80743828797826e+63*cos(theta)**14 + 4.6558118231063e+62*cos(theta)**12 - 1.91453944127736e+61*cos(theta)**10 + 5.12823064627864e+59*cos(theta)**8 - 8.20048304373512e+57*cos(theta)**6 + 6.76607511859333e+55*cos(theta)**4 - 2.15823767738224e+53*cos(theta)**2 + 1.11249364813518e+50)*cos(28*phi)

#@torch.jit.script
def Yl68_m29(theta, phi):
    return 6.79973042715234e-53*(1.0 - cos(theta)**2)**14.5*(2.45066987543702e+69*cos(theta)**39 - 1.3451454649621e+70*cos(theta)**37 + 3.36792060024344e+70*cos(theta)**35 - 5.09901464922353e+70*cos(theta)**33 + 5.21759638525199e+70*cos(theta)**31 - 3.82075955770421e+70*cos(theta)**29 + 2.06830450723721e+70*cos(theta)**27 - 8.43176401905066e+69*cos(theta)**25 + 2.61315000590413e+69*cos(theta)**23 - 6.17298740890518e+68*cos(theta)**21 + 1.10797209903426e+68*cos(theta)**19 - 1.49773303505817e+67*cos(theta)**17 + 1.50215112660702e+66*cos(theta)**15 - 1.09304136031696e+65*cos(theta)**13 + 5.58697418772756e+63*cos(theta)**11 - 1.91453944127736e+62*cos(theta)**9 + 4.10258451702291e+60*cos(theta)**7 - 4.92028982624107e+58*cos(theta)**5 + 2.70643004743733e+56*cos(theta)**3 - 4.31647535476449e+53*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl68_m30(theta, phi):
    return 1.09988265729126e-54*(1.0 - cos(theta)**2)**15*(9.55761251420436e+70*cos(theta)**38 - 4.97703822035975e+71*cos(theta)**36 + 1.1787722100852e+72*cos(theta)**34 - 1.68267483424377e+72*cos(theta)**32 + 1.61745487942812e+72*cos(theta)**30 - 1.10802027173422e+72*cos(theta)**28 + 5.58442216954047e+71*cos(theta)**26 - 2.10794100476266e+71*cos(theta)**24 + 6.0102450135795e+70*cos(theta)**22 - 1.29632735587009e+70*cos(theta)**20 + 2.1051469881651e+69*cos(theta)**18 - 2.5461461595989e+68*cos(theta)**16 + 2.25322668991053e+67*cos(theta)**14 - 1.42095376841204e+66*cos(theta)**12 + 6.14567160650032e+64*cos(theta)**10 - 1.72308549714962e+63*cos(theta)**8 + 2.87180916191604e+61*cos(theta)**6 - 2.46014491312054e+59*cos(theta)**4 + 8.119290142312e+56*cos(theta)**2 - 4.31647535476449e+53)*cos(30*phi)

#@torch.jit.script
def Yl68_m31(theta, phi):
    return 1.79323397551348e-56*(1.0 - cos(theta)**2)**15.5*(3.63189275539766e+72*cos(theta)**37 - 1.79173375932951e+73*cos(theta)**35 + 4.0078255142897e+73*cos(theta)**33 - 5.38455946958005e+73*cos(theta)**31 + 4.85236463828435e+73*cos(theta)**29 - 3.10245676085582e+73*cos(theta)**27 + 1.45194976408052e+73*cos(theta)**25 - 5.05905841143039e+72*cos(theta)**23 + 1.32225390298749e+72*cos(theta)**21 - 2.59265471174018e+71*cos(theta)**19 + 3.78926457869718e+70*cos(theta)**17 - 4.07383385535823e+69*cos(theta)**15 + 3.15451736587474e+68*cos(theta)**13 - 1.70514452209445e+67*cos(theta)**11 + 6.14567160650032e+65*cos(theta)**9 - 1.3784683977197e+64*cos(theta)**7 + 1.72308549714962e+62*cos(theta)**5 - 9.84057965248214e+59*cos(theta)**3 + 1.6238580284624e+57*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl68_m32(theta, phi):
    return 2.94805849575977e-58*(1.0 - cos(theta)**2)**16*(1.34380031949713e+74*cos(theta)**36 - 6.27106815765329e+74*cos(theta)**34 + 1.3225824197156e+75*cos(theta)**32 - 1.66921343556982e+75*cos(theta)**30 + 1.40718574510246e+75*cos(theta)**28 - 8.37663325431071e+74*cos(theta)**26 + 3.62987441020131e+74*cos(theta)**24 - 1.16358343462899e+74*cos(theta)**22 + 2.77673319627373e+73*cos(theta)**20 - 4.92604395230633e+72*cos(theta)**18 + 6.4417497837852e+71*cos(theta)**16 - 6.11075078303735e+70*cos(theta)**14 + 4.10087257563716e+69*cos(theta)**12 - 1.8756589743039e+68*cos(theta)**10 + 5.53110444585029e+66*cos(theta)**8 - 9.64927878403789e+64*cos(theta)**6 + 8.61542748574811e+62*cos(theta)**4 - 2.95217389574464e+60*cos(theta)**2 + 1.6238580284624e+57)*cos(32*phi)

#@torch.jit.script
def Yl68_m33(theta, phi):
    return 4.88904640365914e-60*(1.0 - cos(theta)**2)**16.5*(4.83768115018968e+75*cos(theta)**35 - 2.13216317360212e+76*cos(theta)**33 + 4.23226374308992e+76*cos(theta)**31 - 5.00764030670945e+76*cos(theta)**29 + 3.94012008628689e+76*cos(theta)**27 - 2.17792464612078e+76*cos(theta)**25 + 8.71169858448314e+75*cos(theta)**23 - 2.55988355618378e+75*cos(theta)**21 + 5.55346639254746e+74*cos(theta)**19 - 8.8668791141514e+73*cos(theta)**17 + 1.03067996540563e+73*cos(theta)**15 - 8.55505109625229e+71*cos(theta)**13 + 4.92104709076459e+70*cos(theta)**11 - 1.8756589743039e+69*cos(theta)**9 + 4.42488355668023e+67*cos(theta)**7 - 5.78956727042273e+65*cos(theta)**5 + 3.44617099429925e+63*cos(theta)**3 - 5.90434779148928e+60*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl68_m34(theta, phi):
    return 8.18257606652113e-62*(1.0 - cos(theta)**2)**17*(1.69318840256639e+77*cos(theta)**34 - 7.03613847288699e+77*cos(theta)**32 + 1.31200176035787e+78*cos(theta)**30 - 1.45221568894574e+78*cos(theta)**28 + 1.06383242329746e+78*cos(theta)**26 - 5.44481161530196e+77*cos(theta)**24 + 2.00369067443112e+77*cos(theta)**22 - 5.37575546798594e+76*cos(theta)**20 + 1.05515861458402e+76*cos(theta)**18 - 1.50736944940574e+75*cos(theta)**16 + 1.54601994810845e+74*cos(theta)**14 - 1.1121566425128e+73*cos(theta)**12 + 5.41315179984105e+71*cos(theta)**10 - 1.68809307687351e+70*cos(theta)**8 + 3.09741848967616e+68*cos(theta)**6 - 2.89478363521137e+66*cos(theta)**4 + 1.03385129828977e+64*cos(theta)**2 - 5.90434779148928e+60)*cos(34*phi)

#@torch.jit.script
def Yl68_m35(theta, phi):
    return 1.3827127910757e-63*(1.0 - cos(theta)**2)**17.5*(5.75684056872572e+78*cos(theta)**33 - 2.25156431132384e+79*cos(theta)**31 + 3.93600528107362e+79*cos(theta)**29 - 4.06620392904807e+79*cos(theta)**27 + 2.7659643005734e+79*cos(theta)**25 - 1.30675478767247e+79*cos(theta)**23 + 4.40811948374847e+78*cos(theta)**21 - 1.07515109359719e+78*cos(theta)**19 + 1.89928550625123e+77*cos(theta)**17 - 2.41179111904918e+76*cos(theta)**15 + 2.16442792735183e+75*cos(theta)**13 - 1.33458797101536e+74*cos(theta)**11 + 5.41315179984105e+72*cos(theta)**9 - 1.35047446149881e+71*cos(theta)**7 + 1.8584510938057e+69*cos(theta)**5 - 1.15791345408455e+67*cos(theta)**3 + 2.06770259657955e+64*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl68_m36(theta, phi):
    return 2.36025181791098e-65*(1.0 - cos(theta)**2)**18*(1.89975738767949e+80*cos(theta)**32 - 6.97984936510389e+80*cos(theta)**30 + 1.14144153151135e+81*cos(theta)**28 - 1.09787506084298e+81*cos(theta)**26 + 6.91491075143349e+80*cos(theta)**24 - 3.00553601164668e+80*cos(theta)**22 + 9.25705091587178e+79*cos(theta)**20 - 2.04278707783466e+79*cos(theta)**18 + 3.22878536062709e+78*cos(theta)**16 - 3.61768667857377e+77*cos(theta)**14 + 2.81375630555738e+76*cos(theta)**12 - 1.46804676811689e+75*cos(theta)**10 + 4.87183661985694e+73*cos(theta)**8 - 9.45332123049165e+71*cos(theta)**6 + 9.29225546902849e+69*cos(theta)**4 - 3.47374036225364e+67*cos(theta)**2 + 2.06770259657955e+64)*cos(36*phi)

#@torch.jit.script
def Yl68_m37(theta, phi):
    return 4.07182122728887e-67*(1.0 - cos(theta)**2)**18.5*(6.07922364057436e+81*cos(theta)**31 - 2.09395480953117e+82*cos(theta)**29 + 3.19603628823178e+82*cos(theta)**27 - 2.85447515819175e+82*cos(theta)**25 + 1.65957858034404e+82*cos(theta)**23 - 6.6121792256227e+81*cos(theta)**21 + 1.85141018317436e+81*cos(theta)**19 - 3.67701674010238e+80*cos(theta)**17 + 5.16605657700335e+79*cos(theta)**15 - 5.06476135000328e+78*cos(theta)**13 + 3.37650756666885e+77*cos(theta)**11 - 1.46804676811689e+76*cos(theta)**9 + 3.89746929588556e+74*cos(theta)**7 - 5.67199273829499e+72*cos(theta)**5 + 3.71690218761139e+70*cos(theta)**3 - 6.94748072450728e+67*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl68_m38(theta, phi):
    return 7.10321438621669e-69*(1.0 - cos(theta)**2)**19*(1.88455932857805e+83*cos(theta)**30 - 6.07246894764039e+83*cos(theta)**28 + 8.62929797822582e+83*cos(theta)**26 - 7.13618789547936e+83*cos(theta)**24 + 3.81703073479129e+83*cos(theta)**22 - 1.38855763738077e+83*cos(theta)**20 + 3.51767934803128e+82*cos(theta)**18 - 6.25092845817405e+81*cos(theta)**16 + 7.74908486550502e+80*cos(theta)**14 - 6.58418975500426e+79*cos(theta)**12 + 3.71415832333574e+78*cos(theta)**10 - 1.3212420913052e+77*cos(theta)**8 + 2.72822850711989e+75*cos(theta)**6 - 2.83599636914749e+73*cos(theta)**4 + 1.11507065628342e+71*cos(theta)**2 - 6.94748072450728e+67)*cos(38*phi)

#@torch.jit.script
def Yl68_m39(theta, phi):
    return 1.25372534736348e-70*(1.0 - cos(theta)**2)**19.5*(5.65367798573415e+84*cos(theta)**29 - 1.70029130533931e+85*cos(theta)**27 + 2.24361747433871e+85*cos(theta)**25 - 1.71268509491505e+85*cos(theta)**23 + 8.39746761654083e+84*cos(theta)**21 - 2.77711527476153e+84*cos(theta)**19 + 6.3318228264563e+83*cos(theta)**17 - 1.00014855330785e+83*cos(theta)**15 + 1.0848718811707e+82*cos(theta)**13 - 7.90102770600512e+80*cos(theta)**11 + 3.71415832333574e+79*cos(theta)**9 - 1.05699367304416e+78*cos(theta)**7 + 1.63693710427193e+76*cos(theta)**5 - 1.134398547659e+74*cos(theta)**3 + 2.23014131256684e+71*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl68_m40(theta, phi):
    return 2.24022443358709e-72*(1.0 - cos(theta)**2)**20*(1.6395666158629e+86*cos(theta)**28 - 4.59078652441613e+86*cos(theta)**26 + 5.60904368584678e+86*cos(theta)**24 - 3.93917571830461e+86*cos(theta)**22 + 1.76346819947357e+86*cos(theta)**20 - 5.27651902204692e+85*cos(theta)**18 + 1.07640988049757e+85*cos(theta)**16 - 1.50022282996177e+84*cos(theta)**14 + 1.41033344552191e+83*cos(theta)**12 - 8.69113047660563e+81*cos(theta)**10 + 3.34274249100216e+80*cos(theta)**8 - 7.39895571130914e+78*cos(theta)**6 + 8.18468552135967e+76*cos(theta)**4 - 3.40319564297699e+74*cos(theta)**2 + 2.23014131256684e+71)*cos(40*phi)

#@torch.jit.script
def Yl68_m41(theta, phi):
    return 4.05507849190289e-74*(1.0 - cos(theta)**2)**20.5*(4.59078652441613e+87*cos(theta)**27 - 1.19360449634819e+88*cos(theta)**25 + 1.34617048460323e+88*cos(theta)**23 - 8.66618658027014e+87*cos(theta)**21 + 3.52693639894715e+87*cos(theta)**19 - 9.49773423968445e+86*cos(theta)**17 + 1.72225580879611e+86*cos(theta)**15 - 2.10031196194648e+85*cos(theta)**13 + 1.6924001346263e+84*cos(theta)**11 - 8.69113047660563e+82*cos(theta)**9 + 2.67419399280173e+81*cos(theta)**7 - 4.43937342678548e+79*cos(theta)**5 + 3.27387420854387e+77*cos(theta)**3 - 6.80639128595399e+74*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl68_m42(theta, phi):
    return 7.44082414054722e-76*(1.0 - cos(theta)**2)**21*(1.23951236159236e+89*cos(theta)**26 - 2.98401124087049e+89*cos(theta)**24 + 3.09619211458742e+89*cos(theta)**22 - 1.81989918185673e+89*cos(theta)**20 + 6.70117915799958e+88*cos(theta)**18 - 1.61461482074636e+88*cos(theta)**16 + 2.58338371319417e+87*cos(theta)**14 - 2.73040555053042e+86*cos(theta)**12 + 1.86164014808893e+85*cos(theta)**10 - 7.82201742894506e+83*cos(theta)**8 + 1.87193579496121e+82*cos(theta)**6 - 2.21968671339274e+80*cos(theta)**4 + 9.8216226256316e+77*cos(theta)**2 - 6.80639128595399e+74)*cos(42*phi)

#@torch.jit.script
def Yl68_m43(theta, phi):
    return 1.38507368115804e-77*(1.0 - cos(theta)**2)**21.5*(3.22273214014013e+90*cos(theta)**25 - 7.16162697808917e+90*cos(theta)**23 + 6.81162265209233e+90*cos(theta)**21 - 3.63979836371346e+90*cos(theta)**19 + 1.20621224843993e+90*cos(theta)**17 - 2.58338371319417e+89*cos(theta)**15 + 3.61673719847184e+88*cos(theta)**13 - 3.27648666063651e+87*cos(theta)**11 + 1.86164014808893e+86*cos(theta)**9 - 6.25761394315605e+84*cos(theta)**7 + 1.12316147697673e+83*cos(theta)**5 - 8.87874685357097e+80*cos(theta)**3 + 1.96432452512632e+78*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl68_m44(theta, phi):
    return 2.61754321988924e-79*(1.0 - cos(theta)**2)**22*(8.05683035035031e+91*cos(theta)**24 - 1.64717420496051e+92*cos(theta)**22 + 1.43044075693939e+92*cos(theta)**20 - 6.91561689105557e+91*cos(theta)**18 + 2.05056082234787e+91*cos(theta)**16 - 3.87507556979126e+90*cos(theta)**14 + 4.70175835801339e+89*cos(theta)**12 - 3.60413532670016e+88*cos(theta)**10 + 1.67547613328003e+87*cos(theta)**8 - 4.38032976020924e+85*cos(theta)**6 + 5.61580738488364e+83*cos(theta)**4 - 2.66362405607129e+81*cos(theta)**2 + 1.96432452512632e+78)*cos(44*phi)

#@torch.jit.script
def Yl68_m45(theta, phi):
    return 5.02630708722213e-81*(1.0 - cos(theta)**2)**22.5*(1.93363928408408e+93*cos(theta)**23 - 3.62378325091312e+93*cos(theta)**21 + 2.86088151387878e+93*cos(theta)**19 - 1.24481104039e+93*cos(theta)**17 + 3.2808973157566e+92*cos(theta)**15 - 5.42510579770776e+91*cos(theta)**13 + 5.64211002961607e+90*cos(theta)**11 - 3.60413532670016e+89*cos(theta)**9 + 1.34038090662403e+88*cos(theta)**7 - 2.62819785612554e+86*cos(theta)**5 + 2.24632295395345e+84*cos(theta)**3 - 5.32724811214258e+81*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl68_m46(theta, phi):
    return 9.81595762833013e-83*(1.0 - cos(theta)**2)**23*(4.44737035339337e+94*cos(theta)**22 - 7.60994482691755e+94*cos(theta)**20 + 5.43567487636968e+94*cos(theta)**18 - 2.116178768663e+94*cos(theta)**16 + 4.92134597363489e+93*cos(theta)**14 - 7.05263753702008e+92*cos(theta)**12 + 6.20632103257767e+91*cos(theta)**10 - 3.24372179403014e+90*cos(theta)**8 + 9.38266634636818e+88*cos(theta)**6 - 1.31409892806277e+87*cos(theta)**4 + 6.73896886186036e+84*cos(theta)**2 - 5.32724811214258e+81)*cos(46*phi)

#@torch.jit.script
def Yl68_m47(theta, phi):
    return 1.95151733974338e-84*(1.0 - cos(theta)**2)**23.5*(9.78421477746542e+95*cos(theta)**21 - 1.52198896538351e+96*cos(theta)**19 + 9.78421477746542e+95*cos(theta)**17 - 3.38588602986081e+95*cos(theta)**15 + 6.88988436308885e+94*cos(theta)**13 - 8.4631650444241e+93*cos(theta)**11 + 6.20632103257767e+92*cos(theta)**9 - 2.59497743522412e+91*cos(theta)**7 + 5.62959980782091e+89*cos(theta)**5 - 5.25639571225108e+87*cos(theta)**3 + 1.34779377237207e+85*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl68_m48(theta, phi):
    return 3.95397366551868e-86*(1.0 - cos(theta)**2)**24*(2.05468510326774e+97*cos(theta)**20 - 2.89177903422867e+97*cos(theta)**18 + 1.66331651216912e+97*cos(theta)**16 - 5.07882904479121e+96*cos(theta)**14 + 8.95684967201551e+95*cos(theta)**12 - 9.30948154886651e+94*cos(theta)**10 + 5.58568892931991e+93*cos(theta)**8 - 1.81648420465688e+92*cos(theta)**6 + 2.81479990391046e+90*cos(theta)**4 - 1.57691871367533e+88*cos(theta)**2 + 1.34779377237207e+85)*cos(48*phi)

#@torch.jit.script
def Yl68_m49(theta, phi):
    return 8.17383456958882e-88*(1.0 - cos(theta)**2)**24.5*(4.10937020653548e+98*cos(theta)**19 - 5.2052022616116e+98*cos(theta)**17 + 2.66130641947059e+98*cos(theta)**15 - 7.1103606627077e+97*cos(theta)**13 + 1.07482196064186e+97*cos(theta)**11 - 9.30948154886651e+95*cos(theta)**9 + 4.46855114345593e+94*cos(theta)**7 - 1.08989052279413e+93*cos(theta)**5 + 1.12591996156418e+91*cos(theta)**3 - 3.15383742735065e+88*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl68_m50(theta, phi):
    return 1.72626728289121e-89*(1.0 - cos(theta)**2)**25*(7.80780339241741e+99*cos(theta)**18 - 8.84884384473973e+99*cos(theta)**16 + 3.99195962920589e+99*cos(theta)**14 - 9.24346886152e+98*cos(theta)**12 + 1.18230415670605e+98*cos(theta)**10 - 8.37853339397986e+96*cos(theta)**8 + 3.12798580041915e+95*cos(theta)**6 - 5.44945261397064e+93*cos(theta)**4 + 3.37775988469255e+91*cos(theta)**2 - 3.15383742735065e+88)*cos(50*phi)

#@torch.jit.script
def Yl68_m51(theta, phi):
    return 3.72990960205454e-91*(1.0 - cos(theta)**2)**25.5*(1.40540461063513e+101*cos(theta)**17 - 1.41581501515836e+101*cos(theta)**15 + 5.58874348088825e+100*cos(theta)**13 - 1.1092162633824e+100*cos(theta)**11 + 1.18230415670605e+99*cos(theta)**9 - 6.70282671518389e+97*cos(theta)**7 + 1.87679148025149e+96*cos(theta)**5 - 2.17978104558826e+94*cos(theta)**3 + 6.75551976938509e+91*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl68_m52(theta, phi):
    return 8.25815866324608e-93*(1.0 - cos(theta)**2)**26*(2.38918783807973e+102*cos(theta)**16 - 2.12372252273753e+102*cos(theta)**14 + 7.26536652515472e+101*cos(theta)**12 - 1.22013788972064e+101*cos(theta)**10 + 1.06407374103544e+100*cos(theta)**8 - 4.69197870062872e+98*cos(theta)**6 + 9.38395740125744e+96*cos(theta)**4 - 6.53934313676477e+94*cos(theta)**2 + 6.75551976938509e+91)*cos(52*phi)

#@torch.jit.script
def Yl68_m53(theta, phi):
    return 1.87685424164684e-94*(1.0 - cos(theta)**2)**26.5*(3.82270054092756e+103*cos(theta)**15 - 2.97321153183255e+103*cos(theta)**13 + 8.71843983018567e+102*cos(theta)**11 - 1.22013788972064e+102*cos(theta)**9 + 8.51258992828354e+100*cos(theta)**7 - 2.81518722037723e+99*cos(theta)**5 + 3.75358296050298e+97*cos(theta)**3 - 1.30786862735295e+95*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl68_m54(theta, phi):
    return 4.38737747599552e-96*(1.0 - cos(theta)**2)**27*(5.73405081139134e+104*cos(theta)**14 - 3.86517499138231e+104*cos(theta)**12 + 9.59028381320424e+103*cos(theta)**10 - 1.09812410074858e+103*cos(theta)**8 + 5.95881294979848e+101*cos(theta)**6 - 1.40759361018862e+100*cos(theta)**4 + 1.12607488815089e+98*cos(theta)**2 - 1.30786862735295e+95)*cos(54*phi)

#@torch.jit.script
def Yl68_m55(theta, phi):
    return 1.05727613113712e-97*(1.0 - cos(theta)**2)**27.5*(8.02767113594788e+105*cos(theta)**13 - 4.63820998965878e+105*cos(theta)**11 + 9.59028381320424e+104*cos(theta)**9 - 8.78499280598861e+103*cos(theta)**7 + 3.57528776987909e+102*cos(theta)**5 - 5.63037444075447e+100*cos(theta)**3 + 2.25214977630179e+98*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl68_m56(theta, phi):
    return 2.63333377271339e-99*(1.0 - cos(theta)**2)**28*(1.04359724767322e+107*cos(theta)**12 - 5.10203098862465e+106*cos(theta)**10 + 8.63125543188381e+105*cos(theta)**8 - 6.14949496419203e+104*cos(theta)**6 + 1.78764388493954e+103*cos(theta)**4 - 1.68911233222634e+101*cos(theta)**2 + 2.25214977630179e+98)*cos(56*phi)

#@torch.jit.script
def Yl68_m57(theta, phi):
    return 6.79923856448301e-101*(1.0 - cos(theta)**2)**28.5*(1.25231669720787e+108*cos(theta)**11 - 5.10203098862465e+107*cos(theta)**9 + 6.90500434550705e+106*cos(theta)**7 - 3.68969697851522e+105*cos(theta)**5 + 7.15057553975817e+103*cos(theta)**3 - 3.37822466445268e+101*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl68_m58(theta, phi):
    return 1.82632752438246e-102*(1.0 - cos(theta)**2)**29*(1.37754836692866e+109*cos(theta)**10 - 4.59182788976219e+108*cos(theta)**8 + 4.83350304185493e+107*cos(theta)**6 - 1.84484848925761e+106*cos(theta)**4 + 2.14517266192745e+104*cos(theta)**2 - 3.37822466445268e+101)*cos(58*phi)

#@torch.jit.script
def Yl68_m59(theta, phi):
    return 5.12479861430099e-104*(1.0 - cos(theta)**2)**29.5*(1.37754836692866e+110*cos(theta)**9 - 3.67346231180975e+109*cos(theta)**7 + 2.90010182511296e+108*cos(theta)**5 - 7.37939395703043e+106*cos(theta)**3 + 4.2903453238549e+104*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl68_m60(theta, phi):
    return 1.50990827182819e-105*(1.0 - cos(theta)**2)**30*(1.23979353023579e+111*cos(theta)**8 - 2.57142361826683e+110*cos(theta)**6 + 1.45005091255648e+109*cos(theta)**4 - 2.21381818710913e+107*cos(theta)**2 + 4.2903453238549e+104)*cos(60*phi)

#@torch.jit.script
def Yl68_m61(theta, phi):
    return 4.70013915072667e-107*(1.0 - cos(theta)**2)**30.5*(9.91834824188633e+111*cos(theta)**7 - 1.54285417096009e+111*cos(theta)**5 + 5.80020365022592e+109*cos(theta)**3 - 4.42763637421826e+107*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl68_m62(theta, phi):
    return 1.55808095672644e-108*(1.0 - cos(theta)**2)**31*(6.94284376932043e+112*cos(theta)**6 - 7.71427085480048e+111*cos(theta)**4 + 1.74006109506778e+110*cos(theta)**2 - 4.42763637421826e+107)*cos(62*phi)

#@torch.jit.script
def Yl68_m63(theta, phi):
    return 5.55749072438024e-110*(1.0 - cos(theta)**2)**31.5*(4.16570626159226e+113*cos(theta)**5 - 3.08570834192019e+112*cos(theta)**3 + 3.48012219013555e+110*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl68_m64(theta, phi):
    return 2.16325033055874e-111*(1.0 - cos(theta)**2)**32*(2.08285313079613e+114*cos(theta)**4 - 9.25712502576057e+112*cos(theta)**2 + 3.48012219013555e+110)*cos(64*phi)

#@torch.jit.script
def Yl68_m65(theta, phi):
    return 9.37887964101915e-113*(1.0 - cos(theta)**2)**32.5*(8.33141252318451e+114*cos(theta)**3 - 1.85142500515211e+113*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl68_m66(theta, phi):
    return 4.6777600020732e-114*(1.0 - cos(theta)**2)**33*(2.49942375695535e+115*cos(theta)**2 - 1.85142500515211e+113)*cos(66*phi)

#@torch.jit.script
def Yl68_m67(theta, phi):
    return 14.2306895079291*(1.0 - cos(theta)**2)**33.5*cos(67*phi)*cos(theta)

#@torch.jit.script
def Yl68_m68(theta, phi):
    return 1.22027155810609*(1.0 - cos(theta)**2)**34*cos(68*phi)

#@torch.jit.script
def Yl69_m_minus_69(theta, phi):
    return 1.22468485120279*(1.0 - cos(theta)**2)**34.5*sin(69*phi)

#@torch.jit.script
def Yl69_m_minus_68(theta, phi):
    return 14.3867894923659*(1.0 - cos(theta)**2)**34*sin(68*phi)*cos(theta)

#@torch.jit.script
def Yl69_m_minus_67(theta, phi):
    return 3.47735247384222e-116*(1.0 - cos(theta)**2)**33.5*(3.42421054702884e+117*cos(theta)**2 - 2.49942375695535e+115)*sin(67*phi)

#@torch.jit.script
def Yl69_m_minus_66(theta, phi):
    return 7.02390769639901e-115*(1.0 - cos(theta)**2)**33*(1.14140351567628e+117*cos(theta)**3 - 2.49942375695535e+115*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl69_m_minus_65(theta, phi):
    return 1.63220865200709e-113*(1.0 - cos(theta)**2)**32.5*(2.8535087891907e+116*cos(theta)**4 - 1.24971187847768e+115*cos(theta)**2 + 4.62856251288029e+112)*sin(65*phi)

#@torch.jit.script
def Yl69_m_minus_64(theta, phi):
    return 4.22486734237911e-112*(1.0 - cos(theta)**2)**32*(5.70701757838139e+115*cos(theta)**5 - 4.16570626159226e+114*cos(theta)**3 + 4.62856251288029e+112*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl69_m_minus_63(theta, phi):
    return 1.19347828804884e-110*(1.0 - cos(theta)**2)**31.5*(9.51169596396899e+114*cos(theta)**6 - 1.04142656539806e+114*cos(theta)**4 + 2.31428125644014e+112*cos(theta)**2 - 5.80020365022592e+109)*sin(63*phi)

#@torch.jit.script
def Yl69_m_minus_62(theta, phi):
    return 3.6278599088397e-109*(1.0 - cos(theta)**2)**31*(1.35881370913843e+114*cos(theta)**7 - 2.08285313079613e+113*cos(theta)**5 + 7.71427085480048e+111*cos(theta)**3 - 5.80020365022592e+109*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl69_m_minus_61(theta, phi):
    return 1.17444085245015e-107*(1.0 - cos(theta)**2)**30.5*(1.69851713642303e+113*cos(theta)**8 - 3.47142188466021e+112*cos(theta)**6 + 1.92856771370012e+111*cos(theta)**4 - 2.90010182511296e+109*cos(theta)**2 + 5.53454546777283e+106)*sin(61*phi)

#@torch.jit.script
def Yl69_m_minus_60(theta, phi):
    return 4.01720579458844e-106*(1.0 - cos(theta)**2)**30*(1.88724126269226e+112*cos(theta)**9 - 4.95917412094316e+111*cos(theta)**7 + 3.85713542740024e+110*cos(theta)**5 - 9.66700608370987e+108*cos(theta)**3 + 5.53454546777283e+106*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl69_m_minus_59(theta, phi):
    return 1.4428425309415e-104*(1.0 - cos(theta)**2)**29.5*(1.88724126269226e+111*cos(theta)**10 - 6.19896765117895e+110*cos(theta)**8 + 6.42855904566706e+109*cos(theta)**6 - 2.41675152092747e+108*cos(theta)**4 + 2.76727273388641e+106*cos(theta)**2 - 4.2903453238549e+103)*sin(59*phi)

#@torch.jit.script
def Yl69_m_minus_58(theta, phi):
    return 5.41402507685722e-103*(1.0 - cos(theta)**2)**29*(1.71567387517478e+110*cos(theta)**11 - 6.88774183464328e+109*cos(theta)**9 + 9.18365577952438e+108*cos(theta)**7 - 4.83350304185493e+107*cos(theta)**5 + 9.22424244628804e+105*cos(theta)**3 - 4.2903453238549e+103*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl69_m_minus_57(theta, phi):
    return 2.11355107153923e-101*(1.0 - cos(theta)**2)**28.5*(1.42972822931232e+109*cos(theta)**12 - 6.88774183464328e+108*cos(theta)**10 + 1.14795697244055e+108*cos(theta)**8 - 8.05583840309156e+106*cos(theta)**6 + 2.30606061157201e+105*cos(theta)**4 - 2.14517266192745e+103*cos(theta)**2 + 2.81518722037723e+100)*sin(57*phi)

#@torch.jit.script
def Yl69_m_minus_56(theta, phi):
    return 8.55400884978709e-100*(1.0 - cos(theta)**2)**28*(1.09979094562486e+108*cos(theta)**13 - 6.26158348603935e+107*cos(theta)**11 + 1.27550774715616e+107*cos(theta)**9 - 1.15083405758451e+106*cos(theta)**7 + 4.61212122314402e+104*cos(theta)**5 - 7.15057553975817e+102*cos(theta)**3 + 2.81518722037723e+100*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl69_m_minus_55(theta, phi):
    return 3.57839863561779e-98*(1.0 - cos(theta)**2)**27.5*(7.85564961160614e+106*cos(theta)**14 - 5.21798623836612e+106*cos(theta)**12 + 1.27550774715616e+106*cos(theta)**10 - 1.43854257198064e+105*cos(theta)**8 + 7.68686870524004e+103*cos(theta)**6 - 1.78764388493954e+102*cos(theta)**4 + 1.40759361018862e+100*cos(theta)**2 - 1.60867841164413e+97)*sin(55*phi)

#@torch.jit.script
def Yl69_m_minus_54(theta, phi):
    return 1.54328164764011e-96*(1.0 - cos(theta)**2)**27*(5.23709974107076e+105*cos(theta)**15 - 4.01383556797394e+105*cos(theta)**13 + 1.15955249741469e+105*cos(theta)**11 - 1.59838063553404e+104*cos(theta)**9 + 1.09812410074858e+103*cos(theta)**7 - 3.57528776987909e+101*cos(theta)**5 + 4.69197870062872e+99*cos(theta)**3 - 1.60867841164413e+97*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl69_m_minus_53(theta, phi):
    return 6.84632858112973e-95*(1.0 - cos(theta)**2)**26.5*(3.27318733816923e+104*cos(theta)**16 - 2.86702540569567e+104*cos(theta)**14 + 9.66293747845578e+103*cos(theta)**12 - 1.59838063553404e+103*cos(theta)**10 + 1.37265512593572e+102*cos(theta)**8 - 5.95881294979848e+100*cos(theta)**6 + 1.17299467515718e+99*cos(theta)**4 - 8.04339205822067e+96*cos(theta)**2 + 8.17417892095596e+93)*sin(53*phi)

#@torch.jit.script
def Yl69_m_minus_52(theta, phi):
    return 3.11789951721678e-93*(1.0 - cos(theta)**2)**26*(1.92540431657013e+103*cos(theta)**17 - 1.91135027046378e+103*cos(theta)**15 + 7.43302882958137e+102*cos(theta)**13 - 1.45307330503094e+102*cos(theta)**11 + 1.5251723621508e+101*cos(theta)**9 - 8.51258992828354e+99*cos(theta)**7 + 2.34598935031436e+98*cos(theta)**5 - 2.68113068607356e+96*cos(theta)**3 + 8.17417892095596e+93*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl69_m_minus_51(theta, phi):
    return 1.45509400851028e-91*(1.0 - cos(theta)**2)**25.5*(1.06966906476118e+102*cos(theta)**18 - 1.19459391903986e+102*cos(theta)**16 + 5.30930630684384e+101*cos(theta)**14 - 1.21089442085912e+101*cos(theta)**12 + 1.5251723621508e+100*cos(theta)**10 - 1.06407374103544e+99*cos(theta)**8 + 3.90998225052394e+97*cos(theta)**6 - 6.70282671518389e+95*cos(theta)**4 + 4.08708946047798e+93*cos(theta)**2 - 3.75306653854727e+90)*sin(51*phi)

#@torch.jit.script
def Yl69_m_minus_50(theta, phi):
    return 6.94797866131853e-90*(1.0 - cos(theta)**2)**25*(5.6298371829536e+100*cos(theta)**19 - 7.02702305317567e+100*cos(theta)**17 + 3.53953753789589e+100*cos(theta)**15 - 9.31457246814708e+99*cos(theta)**13 + 1.386520329228e+99*cos(theta)**11 - 1.18230415670605e+98*cos(theta)**9 + 5.58568892931991e+96*cos(theta)**7 - 1.34056534303678e+95*cos(theta)**5 + 1.36236315349266e+93*cos(theta)**3 - 3.75306653854727e+90*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl69_m_minus_49(theta, phi):
    return 3.38958832010567e-88*(1.0 - cos(theta)**2)**24.5*(2.8149185914768e+99*cos(theta)**20 - 3.9039016962087e+99*cos(theta)**18 + 2.21221096118493e+99*cos(theta)**16 - 6.65326604867649e+98*cos(theta)**14 + 1.15543360769e+98*cos(theta)**12 - 1.18230415670605e+97*cos(theta)**10 + 6.98211116164988e+95*cos(theta)**8 - 2.23427557172796e+94*cos(theta)**6 + 3.40590788373165e+92*cos(theta)**4 - 1.87653326927364e+90*cos(theta)**2 + 1.57691871367533e+87)*sin(49*phi)

#@torch.jit.script
def Yl69_m_minus_48(theta, phi):
    return 1.68732058755698e-86*(1.0 - cos(theta)**2)**24*(1.34043742451276e+98*cos(theta)**21 - 2.05468510326774e+98*cos(theta)**19 + 1.3013005654029e+98*cos(theta)**17 - 4.43551069911766e+97*cos(theta)**15 + 8.88795082838462e+96*cos(theta)**13 - 1.07482196064186e+96*cos(theta)**11 + 7.75790129072209e+94*cos(theta)**9 - 3.19182224532566e+93*cos(theta)**7 + 6.8118157674633e+91*cos(theta)**5 - 6.25511089757879e+89*cos(theta)**3 + 1.57691871367533e+87*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl69_m_minus_47(theta, phi):
    return 8.56055411150962e-85*(1.0 - cos(theta)**2)**23.5*(6.09289738414892e+96*cos(theta)**22 - 1.02734255163387e+97*cos(theta)**20 + 7.22944758557167e+96*cos(theta)**18 - 2.77219418694854e+96*cos(theta)**16 + 6.34853630598901e+95*cos(theta)**14 - 8.95684967201551e+94*cos(theta)**12 + 7.75790129072209e+93*cos(theta)**10 - 3.98977780665708e+92*cos(theta)**8 + 1.13530262791055e+91*cos(theta)**6 - 1.5637777243947e+89*cos(theta)**4 + 7.88459356837663e+86*cos(theta)**2 - 6.12633532896397e+83)*sin(47*phi)

#@torch.jit.script
def Yl69_m_minus_46(theta, phi):
    return 4.42175615909734e-83*(1.0 - cos(theta)**2)**23*(2.64908581919518e+95*cos(theta)**23 - 4.89210738873271e+95*cos(theta)**21 + 3.80497241345878e+95*cos(theta)**19 - 1.6307024629109e+95*cos(theta)**17 + 4.23235753732601e+94*cos(theta)**15 - 6.88988436308885e+93*cos(theta)**13 + 7.05263753702008e+92*cos(theta)**11 - 4.4330864518412e+91*cos(theta)**9 + 1.62186089701507e+90*cos(theta)**7 - 3.12755544878939e+88*cos(theta)**5 + 2.62819785612554e+86*cos(theta)**3 - 6.12633532896397e+83*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl69_m_minus_45(theta, phi):
    return 2.32300064537706e-81*(1.0 - cos(theta)**2)**22.5*(1.10378575799799e+94*cos(theta)**24 - 2.22368517669669e+94*cos(theta)**22 + 1.90248620672939e+94*cos(theta)**20 - 9.0594581272828e+93*cos(theta)**18 + 2.64522346082876e+93*cos(theta)**16 - 4.92134597363489e+92*cos(theta)**14 + 5.87719794751674e+91*cos(theta)**12 - 4.4330864518412e+90*cos(theta)**10 + 2.02732612126884e+89*cos(theta)**8 - 5.21259241464899e+87*cos(theta)**6 + 6.57049464031385e+85*cos(theta)**4 - 3.06316766448198e+83*cos(theta)**2 + 2.21968671339274e+80)*sin(45*phi)

#@torch.jit.script
def Yl69_m_minus_44(theta, phi):
    return 1.2401429835105e-79*(1.0 - cos(theta)**2)**22*(4.41514303199197e+92*cos(theta)**25 - 9.66819642042038e+92*cos(theta)**23 + 9.0594581272828e+92*cos(theta)**21 - 4.76813585646463e+92*cos(theta)**19 + 1.5560138004875e+92*cos(theta)**17 - 3.2808973157566e+91*cos(theta)**15 + 4.5209214980898e+90*cos(theta)**13 - 4.03007859258291e+89*cos(theta)**11 + 2.2525845791876e+88*cos(theta)**9 - 7.4465605923557e+86*cos(theta)**7 + 1.31409892806277e+85*cos(theta)**5 - 1.02105588816066e+83*cos(theta)**3 + 2.21968671339274e+80*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl69_m_minus_43(theta, phi):
    return 6.72198681361313e-78*(1.0 - cos(theta)**2)**21.5*(1.69813193538153e+91*cos(theta)**26 - 4.02841517517516e+91*cos(theta)**24 + 4.11793551240127e+91*cos(theta)**22 - 2.38406792823232e+91*cos(theta)**20 + 8.64452111381946e+90*cos(theta)**18 - 2.05056082234787e+90*cos(theta)**16 + 3.22922964149271e+89*cos(theta)**14 - 3.35839882715242e+88*cos(theta)**12 + 2.2525845791876e+87*cos(theta)**10 - 9.30820074044463e+85*cos(theta)**8 + 2.19016488010462e+84*cos(theta)**6 - 2.55263972040165e+82*cos(theta)**4 + 1.10984335669637e+80*cos(theta)**2 - 7.55509432740892e+76)*sin(43*phi)

#@torch.jit.script
def Yl69_m_minus_42(theta, phi):
    return 3.69648160726526e-76*(1.0 - cos(theta)**2)**21*(6.2893775384501e+89*cos(theta)**27 - 1.61136607007006e+90*cos(theta)**25 + 1.79040674452229e+90*cos(theta)**23 - 1.13527044201539e+90*cos(theta)**21 + 4.54974795464182e+89*cos(theta)**19 - 1.20621224843993e+89*cos(theta)**17 + 2.15281976099514e+88*cos(theta)**15 - 2.58338371319417e+87*cos(theta)**13 + 2.04780416289782e+86*cos(theta)**11 - 1.03424452671607e+85*cos(theta)**9 + 3.12880697157803e+83*cos(theta)**7 - 5.10527944080331e+81*cos(theta)**5 + 3.69947785565457e+79*cos(theta)**3 - 7.55509432740892e+76*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl69_m_minus_41(theta, phi):
    return 2.06076777575783e-74*(1.0 - cos(theta)**2)**20.5*(2.24620626373218e+88*cos(theta)**28 - 6.19756180796178e+88*cos(theta)**26 + 7.46002810217622e+88*cos(theta)**24 - 5.16032019097904e+88*cos(theta)**22 + 2.27487397732091e+88*cos(theta)**20 - 6.70117915799958e+87*cos(theta)**18 + 1.34551235062196e+87*cos(theta)**16 - 1.84527408085298e+86*cos(theta)**14 + 1.70650346908152e+85*cos(theta)**12 - 1.03424452671607e+84*cos(theta)**10 + 3.91100871447253e+82*cos(theta)**8 - 8.50879906800551e+80*cos(theta)**6 + 9.24869463913642e+78*cos(theta)**4 - 3.77754716370446e+76*cos(theta)**2 + 2.43085403069785e+73)*sin(41*phi)

#@torch.jit.script
def Yl69_m_minus_40(theta, phi):
    return 1.16392339110742e-72*(1.0 - cos(theta)**2)**20*(7.74553884045579e+86*cos(theta)**29 - 2.29539326220807e+87*cos(theta)**27 + 2.98401124087049e+87*cos(theta)**25 - 2.24361747433871e+87*cos(theta)**23 + 1.08327332253377e+87*cos(theta)**21 - 3.52693639894715e+86*cos(theta)**19 + 7.91477853307038e+85*cos(theta)**17 - 1.23018272056865e+85*cos(theta)**15 + 1.31269497621655e+84*cos(theta)**13 - 9.40222297014609e+82*cos(theta)**11 + 4.34556523830281e+81*cos(theta)**9 - 1.21554272400079e+80*cos(theta)**7 + 1.84973892782728e+78*cos(theta)**5 - 1.25918238790149e+76*cos(theta)**3 + 2.43085403069785e+73*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl69_m_minus_39(theta, phi):
    return 6.65576948924773e-71*(1.0 - cos(theta)**2)**19.5*(2.58184628015193e+85*cos(theta)**30 - 8.19783307931452e+85*cos(theta)**28 + 1.14769663110403e+86*cos(theta)**26 - 9.34840614307797e+85*cos(theta)**24 + 4.92396964788076e+85*cos(theta)**22 - 1.76346819947357e+85*cos(theta)**20 + 4.3970991850391e+84*cos(theta)**18 - 7.68864200355408e+83*cos(theta)**16 + 9.37639268726107e+82*cos(theta)**14 - 7.83518580845507e+81*cos(theta)**12 + 4.34556523830281e+80*cos(theta)**10 - 1.51942840500098e+79*cos(theta)**8 + 3.08289821304547e+77*cos(theta)**6 - 3.14795596975372e+75*cos(theta)**4 + 1.21542701534893e+73*cos(theta)**2 - 7.43380437522279e+69)*sin(39*phi)

#@torch.jit.script
def Yl69_m_minus_38(theta, phi):
    return 3.85115498999865e-69*(1.0 - cos(theta)**2)**19*(8.32853638758687e+83*cos(theta)**31 - 2.82683899286708e+84*cos(theta)**29 + 4.25072826334827e+84*cos(theta)**27 - 3.73936245723119e+84*cos(theta)**25 + 2.14085636864381e+84*cos(theta)**23 - 8.39746761654083e+83*cos(theta)**21 + 2.31426272896795e+83*cos(theta)**19 - 4.52273059032593e+82*cos(theta)**17 + 6.25092845817405e+81*cos(theta)**15 - 6.0270660065039e+80*cos(theta)**13 + 3.95051385300256e+79*cos(theta)**11 - 1.68825378333443e+78*cos(theta)**9 + 4.40414030435068e+76*cos(theta)**7 - 6.29591193950744e+74*cos(theta)**5 + 4.05142338449642e+72*cos(theta)**3 - 7.43380437522279e+69*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl69_m_minus_37(theta, phi):
    return 2.25350162298453e-67*(1.0 - cos(theta)**2)**18.5*(2.6026676211209e+82*cos(theta)**32 - 9.42279664289026e+82*cos(theta)**30 + 1.5181172369101e+83*cos(theta)**28 - 1.4382163297043e+83*cos(theta)**26 + 8.9202348693492e+82*cos(theta)**24 - 3.81703073479129e+82*cos(theta)**22 + 1.15713136448397e+82*cos(theta)**20 - 2.51262810573663e+81*cos(theta)**18 + 3.90683028635878e+80*cos(theta)**16 - 4.30504714750279e+79*cos(theta)**14 + 3.29209487750213e+78*cos(theta)**12 - 1.68825378333443e+77*cos(theta)**10 + 5.50517538043835e+75*cos(theta)**8 - 1.04931865658457e+74*cos(theta)**6 + 1.0128558461241e+72*cos(theta)**4 - 3.71690218761139e+69*cos(theta)**2 + 2.17108772640852e+66)*sin(37*phi)

#@torch.jit.script
def Yl69_m_minus_36(theta, phi):
    return 1.3328085735637e-65*(1.0 - cos(theta)**2)**18*(7.88687157915424e+80*cos(theta)**33 - 3.03961182028718e+81*cos(theta)**31 + 5.23488702382792e+81*cos(theta)**29 - 5.32672714705297e+81*cos(theta)**27 + 3.56809394773968e+81*cos(theta)**25 - 1.65957858034404e+81*cos(theta)**23 + 5.51014935468559e+80*cos(theta)**21 - 1.32243584512454e+80*cos(theta)**19 + 2.29813546256399e+79*cos(theta)**17 - 2.87003143166853e+78*cos(theta)**15 + 2.53238067500164e+77*cos(theta)**13 - 1.53477616666766e+76*cos(theta)**11 + 6.11686153382039e+74*cos(theta)**9 - 1.49902665226368e+73*cos(theta)**7 + 2.02571169224821e+71*cos(theta)**5 - 1.23896739587046e+69*cos(theta)**3 + 2.17108772640852e+66*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl69_m_minus_35(theta, phi):
    return 7.96346151917664e-64*(1.0 - cos(theta)**2)**17.5*(2.31966811151595e+79*cos(theta)**34 - 9.49878693839744e+79*cos(theta)**32 + 1.74496234127597e+80*cos(theta)**30 - 1.90240255251892e+80*cos(theta)**28 + 1.37234382605372e+80*cos(theta)**26 - 6.91491075143349e+79*cos(theta)**24 + 2.5046133430389e+79*cos(theta)**22 - 6.6121792256227e+78*cos(theta)**20 + 1.27674192364666e+78*cos(theta)**18 - 1.79376964479283e+77*cos(theta)**16 + 1.80884333928689e+76*cos(theta)**14 - 1.27898013888972e+75*cos(theta)**12 + 6.11686153382039e+73*cos(theta)**10 - 1.87378331532959e+72*cos(theta)**8 + 3.37618615374702e+70*cos(theta)**6 - 3.09741848967616e+68*cos(theta)**4 + 1.08554386320426e+66*cos(theta)**2 - 6.08147822523396e+62)*sin(35*phi)

#@torch.jit.script
def Yl69_m_minus_34(theta, phi):
    return 4.80454845430205e-62*(1.0 - cos(theta)**2)**17*(6.62762317575986e+77*cos(theta)**35 - 2.87842028436286e+78*cos(theta)**33 + 5.62891077830959e+78*cos(theta)**31 - 6.56000880178937e+78*cos(theta)**29 + 5.08275491131009e+78*cos(theta)**27 - 2.7659643005734e+78*cos(theta)**25 + 1.08896232306039e+78*cos(theta)**23 - 3.14865677410605e+77*cos(theta)**21 + 6.71969433498242e+76*cos(theta)**19 - 1.05515861458402e+76*cos(theta)**17 + 1.20589555952459e+75*cos(theta)**15 - 9.83830876069013e+73*cos(theta)**13 + 5.56078321256399e+72*cos(theta)**11 - 2.08198146147733e+71*cos(theta)**9 + 4.82312307678145e+69*cos(theta)**7 - 6.19483697935232e+67*cos(theta)**5 + 3.61847954401421e+65*cos(theta)**3 - 6.08147822523396e+62*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl69_m_minus_33(theta, phi):
    return 2.92565047691658e-60*(1.0 - cos(theta)**2)**16.5*(1.84100643771107e+76*cos(theta)**36 - 8.46594201283194e+76*cos(theta)**34 + 1.75903461822175e+77*cos(theta)**32 - 2.18666960059646e+77*cos(theta)**30 + 1.81526961118217e+77*cos(theta)**28 - 1.06383242329746e+77*cos(theta)**26 + 4.53734301275163e+76*cos(theta)**24 - 1.43120762459366e+76*cos(theta)**22 + 3.35984716749121e+75*cos(theta)**20 - 5.86199230324454e+74*cos(theta)**18 + 7.53684724702869e+73*cos(theta)**16 - 7.02736340049295e+72*cos(theta)**14 + 4.63398601046999e+71*cos(theta)**12 - 2.08198146147733e+70*cos(theta)**10 + 6.02890384597682e+68*cos(theta)**8 - 1.03247282989205e+67*cos(theta)**6 + 9.04619886003552e+64*cos(theta)**4 - 3.04073911261698e+62*cos(theta)**2 + 1.64009660874702e+59)*sin(33*phi)

#@torch.jit.script
def Yl69_m_minus_32(theta, phi):
    return 1.79731164551872e-58*(1.0 - cos(theta)**2)**16*(4.97569307489479e+74*cos(theta)**37 - 2.41884057509484e+75*cos(theta)**35 + 5.3304079340053e+75*cos(theta)**33 - 7.05377290514987e+75*cos(theta)**31 + 6.25955038338681e+75*cos(theta)**29 - 3.94012008628689e+75*cos(theta)**27 + 1.81493720510065e+75*cos(theta)**25 - 6.22264184605939e+74*cos(theta)**23 + 1.59992722261486e+74*cos(theta)**21 - 3.08525910697081e+73*cos(theta)**19 + 4.4334395570757e+72*cos(theta)**17 - 4.68490893366197e+71*cos(theta)**15 + 3.56460462343845e+70*cos(theta)**13 - 1.89271041952484e+69*cos(theta)**11 + 6.69878205108535e+67*cos(theta)**9 - 1.47496118556008e+66*cos(theta)**7 + 1.8092397720071e+64*cos(theta)**5 - 1.01357970420566e+62*cos(theta)**3 + 1.64009660874702e+59*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl69_m_minus_31(theta, phi):
    return 1.11346321367111e-56*(1.0 - cos(theta)**2)**15.5*(1.309392914446e+73*cos(theta)**38 - 6.71900159748567e+73*cos(theta)**36 + 1.56776703941332e+74*cos(theta)**34 - 2.20430403285933e+74*cos(theta)**32 + 2.08651679446227e+74*cos(theta)**30 - 1.40718574510246e+74*cos(theta)**28 + 6.98052771192559e+73*cos(theta)**26 - 2.59276743585808e+73*cos(theta)**24 + 7.27239646643119e+72*cos(theta)**22 - 1.5426295534854e+72*cos(theta)**20 + 2.46302197615317e+71*cos(theta)**18 - 2.92806808353873e+70*cos(theta)**16 + 2.5461461595989e+69*cos(theta)**14 - 1.57725868293737e+68*cos(theta)**12 + 6.69878205108535e+66*cos(theta)**10 - 1.8437014819501e+65*cos(theta)**8 + 3.01539962001184e+63*cos(theta)**6 - 2.53394926051415e+61*cos(theta)**4 + 8.20048304373512e+58*cos(theta)**2 - 4.27331060121684e+55)*sin(31*phi)

#@torch.jit.script
def Yl69_m_minus_30(theta, phi):
    return 6.95357554066631e-55*(1.0 - cos(theta)**2)**15*(3.35741772934871e+71*cos(theta)**39 - 1.81594637769883e+72*cos(theta)**37 + 4.47933439832378e+72*cos(theta)**35 - 6.67970919048283e+72*cos(theta)**33 + 6.73069933697506e+72*cos(theta)**31 - 4.85236463828435e+72*cos(theta)**29 + 2.58538063404652e+72*cos(theta)**27 - 1.03710697434323e+72*cos(theta)**25 + 3.161911507144e+71*cos(theta)**23 - 7.34585501659716e+70*cos(theta)**21 + 1.29632735587009e+70*cos(theta)**19 - 1.7223929903169e+69*cos(theta)**17 + 1.69743077306593e+68*cos(theta)**15 - 1.21327590995182e+67*cos(theta)**13 + 6.08980186462304e+65*cos(theta)**11 - 2.04855720216677e+64*cos(theta)**9 + 4.30771374287406e+62*cos(theta)**7 - 5.0678985210283e+60*cos(theta)**5 + 2.73349434791171e+58*cos(theta)**3 - 4.27331060121684e+55*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl69_m_minus_29(theta, phi):
    return 4.37578293208222e-53*(1.0 - cos(theta)**2)**14.5*(8.39354432337178e+69*cos(theta)**40 - 4.77880625710218e+70*cos(theta)**38 + 1.24425955508994e+71*cos(theta)**36 - 1.96462035014201e+71*cos(theta)**34 + 2.10334354280471e+71*cos(theta)**32 - 1.61745487942812e+71*cos(theta)**30 + 9.23350226445184e+70*cos(theta)**28 - 3.9888729782432e+70*cos(theta)**26 + 1.31746312797667e+70*cos(theta)**24 - 3.33902500754417e+69*cos(theta)**22 + 6.48163677935044e+68*cos(theta)**20 - 9.568849946205e+67*cos(theta)**18 + 1.06089423316621e+67*cos(theta)**16 - 8.66625649965587e+65*cos(theta)**14 + 5.07483488718587e+64*cos(theta)**12 - 2.04855720216677e+63*cos(theta)**10 + 5.38464217859257e+61*cos(theta)**8 - 8.44649753504717e+59*cos(theta)**6 + 6.83373586977926e+57*cos(theta)**4 - 2.13665530060842e+55*cos(theta)**2 + 1.07911883869112e+52)*sin(29*phi)

#@torch.jit.script
def Yl69_m_minus_28(theta, phi):
    return 2.77370798116249e-51*(1.0 - cos(theta)**2)**14*(2.0472059325297e+68*cos(theta)**41 - 1.22533493771851e+69*cos(theta)**39 + 3.36286366240524e+69*cos(theta)**37 - 5.61320100040574e+69*cos(theta)**35 + 6.37376831152942e+69*cos(theta)**33 - 5.21759638525199e+69*cos(theta)**31 + 3.18396629808684e+69*cos(theta)**29 - 1.47736036231229e+69*cos(theta)**27 + 5.26985251190666e+68*cos(theta)**25 - 1.45175000328007e+68*cos(theta)**23 + 3.08649370445259e+67*cos(theta)**21 - 5.0362368137921e+66*cos(theta)**19 + 6.24055431274239e+65*cos(theta)**17 - 5.77750433310391e+64*cos(theta)**15 + 3.90371914398913e+63*cos(theta)**13 - 1.86232472924252e+62*cos(theta)**11 + 5.98293575399175e+60*cos(theta)**9 - 1.20664250500674e+59*cos(theta)**7 + 1.36674717395585e+57*cos(theta)**5 - 7.1221843353614e+54*cos(theta)**3 + 1.07911883869112e+52*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl69_m_minus_27(theta, phi):
    return 1.7703993786841e-49*(1.0 - cos(theta)**2)**13.5*(4.87429983935643e+66*cos(theta)**42 - 3.06333734429627e+67*cos(theta)**40 + 8.84964121685589e+67*cos(theta)**38 - 1.5592225001127e+68*cos(theta)**36 + 1.87463773868512e+68*cos(theta)**34 - 1.63049887039125e+68*cos(theta)**32 + 1.06132209936228e+68*cos(theta)**30 - 5.2762870082582e+67*cos(theta)**28 + 2.02686635073333e+67*cos(theta)**26 - 6.0489583470003e+66*cos(theta)**24 + 1.40295168384209e+66*cos(theta)**22 - 2.51811840689605e+65*cos(theta)**20 + 3.46697461819022e+64*cos(theta)**18 - 3.61094020818995e+63*cos(theta)**16 + 2.78837081713509e+62*cos(theta)**14 - 1.55193727436877e+61*cos(theta)**12 + 5.98293575399175e+59*cos(theta)**10 - 1.50830313125842e+58*cos(theta)**8 + 2.27791195659309e+56*cos(theta)**6 - 1.78054608384035e+54*cos(theta)**4 + 5.39559419345561e+51*cos(theta)**2 - 2.64879440032185e+48)*sin(27*phi)

#@torch.jit.script
def Yl69_m_minus_26(theta, phi):
    return 1.13747298988002e-47*(1.0 - cos(theta)**2)**13*(1.13355810217591e+65*cos(theta)**43 - 7.47155449828359e+65*cos(theta)**41 + 2.26913877355279e+66*cos(theta)**39 - 4.21411486516947e+66*cos(theta)**37 + 5.35610782481463e+66*cos(theta)**35 - 4.94090566785226e+66*cos(theta)**33 + 3.4236196753622e+66*cos(theta)**31 - 1.81940931319248e+66*cos(theta)**29 + 7.50691241012345e+65*cos(theta)**27 - 2.41958333880012e+65*cos(theta)**25 + 6.0997899297482e+64*cos(theta)**23 - 1.19910400328383e+64*cos(theta)**21 + 1.82472348325801e+63*cos(theta)**19 - 2.12408247540585e+62*cos(theta)**17 + 1.85891387809006e+61*cos(theta)**15 - 1.19379790336059e+60*cos(theta)**13 + 5.43903250362886e+58*cos(theta)**11 - 1.67589236806491e+57*cos(theta)**9 + 3.25415993799013e+55*cos(theta)**7 - 3.5610921676807e+53*cos(theta)**5 + 1.79853139781854e+51*cos(theta)**3 - 2.64879440032185e+48*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl69_m_minus_25(theta, phi):
    return 7.35409496492504e-46*(1.0 - cos(theta)**2)**12.5*(2.57626841403617e+63*cos(theta)**44 - 1.77894154721038e+64*cos(theta)**42 + 5.67284693388198e+64*cos(theta)**40 - 1.10897759609723e+65*cos(theta)**38 + 1.48780772911518e+65*cos(theta)**36 - 1.45320754936831e+65*cos(theta)**34 + 1.06988114855069e+65*cos(theta)**32 - 6.0646977106416e+64*cos(theta)**30 + 2.68104014647266e+64*cos(theta)**28 - 9.30608976461584e+63*cos(theta)**26 + 2.54157913739508e+63*cos(theta)**24 - 5.45047274219925e+62*cos(theta)**22 + 9.12361741629004e+61*cos(theta)**20 - 1.18004581966992e+61*cos(theta)**18 + 1.16182117380629e+60*cos(theta)**16 - 8.52712788114708e+58*cos(theta)**14 + 4.53252708635738e+57*cos(theta)**12 - 1.67589236806491e+56*cos(theta)**10 + 4.06769992248766e+54*cos(theta)**8 - 5.93515361280117e+52*cos(theta)**6 + 4.49632849454634e+50*cos(theta)**4 - 1.32439720016092e+48*cos(theta)**2 + 6.33682870890395e+44)*sin(25*phi)

#@torch.jit.script
def Yl69_m_minus_24(theta, phi):
    return 4.78298938892577e-44*(1.0 - cos(theta)**2)**12*(5.72504092008038e+61*cos(theta)**45 - 4.13707336560553e+62*cos(theta)**43 + 1.38362120338585e+63*cos(theta)**41 - 2.8435322976852e+63*cos(theta)**39 + 4.02110197058156e+63*cos(theta)**37 - 4.15202156962375e+63*cos(theta)**35 + 3.24206408651723e+63*cos(theta)**33 - 1.95635410020697e+63*cos(theta)**31 + 9.24496602231952e+62*cos(theta)**29 - 3.44669991282068e+62*cos(theta)**27 + 1.01663165495803e+62*cos(theta)**25 - 2.36977075747793e+61*cos(theta)**23 + 4.34457972204288e+60*cos(theta)**21 - 6.21076747194693e+59*cos(theta)**19 + 6.83424219886052e+58*cos(theta)**17 - 5.68475192076472e+57*cos(theta)**15 + 3.48655929719799e+56*cos(theta)**13 - 1.52353851642265e+55*cos(theta)**11 + 4.51966658054184e+53*cos(theta)**9 - 8.47879087543024e+51*cos(theta)**7 + 8.99265698909268e+49*cos(theta)**5 - 4.41465733386975e+47*cos(theta)**3 + 6.33682870890395e+44*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl69_m_minus_23(theta, phi):
    return 3.12838220973394e-42*(1.0 - cos(theta)**2)**11.5*(1.24457411306095e+60*cos(theta)**46 - 9.40243946728529e+60*cos(theta)**44 + 3.29433619853774e+61*cos(theta)**42 - 7.10883074421301e+61*cos(theta)**40 + 1.05818472910041e+62*cos(theta)**38 - 1.15333932489549e+62*cos(theta)**36 + 9.53548260740362e+61*cos(theta)**34 - 6.11360656314678e+61*cos(theta)**32 + 3.08165534077317e+61*cos(theta)**30 - 1.23096425457882e+61*cos(theta)**28 + 3.91012174983859e+60*cos(theta)**26 - 9.87404482282472e+59*cos(theta)**24 + 1.97480896456494e+59*cos(theta)**22 - 3.10538373597347e+58*cos(theta)**20 + 3.79680122158918e+57*cos(theta)**18 - 3.55296995047795e+56*cos(theta)**16 + 2.49039949799856e+55*cos(theta)**14 - 1.26961543035221e+54*cos(theta)**12 + 4.51966658054184e+52*cos(theta)**10 - 1.05984885942878e+51*cos(theta)**8 + 1.49877616484878e+49*cos(theta)**6 - 1.10366433346744e+47*cos(theta)**4 + 3.16841435445197e+44*cos(theta)**2 - 1.48125963274987e+41)*sin(23*phi)

#@torch.jit.script
def Yl69_m_minus_22(theta, phi):
    return 2.05713432186081e-40*(1.0 - cos(theta)**2)**11*(2.64803002778926e+58*cos(theta)**47 - 2.08943099273007e+59*cos(theta)**45 + 7.66124697334357e+59*cos(theta)**43 - 1.73386115712512e+60*cos(theta)**41 + 2.71329417718054e+60*cos(theta)**39 - 3.11713331052834e+60*cos(theta)**37 + 2.72442360211532e+60*cos(theta)**35 - 1.85260804943842e+60*cos(theta)**33 + 9.94082367991346e+59*cos(theta)**31 - 4.24470432613385e+59*cos(theta)**29 + 1.44819324068096e+59*cos(theta)**27 - 3.94961792912989e+58*cos(theta)**25 + 8.58612593289106e+57*cos(theta)**23 - 1.47875415998737e+57*cos(theta)**21 + 1.99831643241536e+56*cos(theta)**19 - 2.08998232381056e+55*cos(theta)**17 + 1.66026633199904e+54*cos(theta)**15 - 9.76627254117083e+52*cos(theta)**13 + 4.10878780049258e+51*cos(theta)**11 - 1.17760984380976e+50*cos(theta)**9 + 2.14110880692683e+48*cos(theta)**7 - 2.20732866693487e+46*cos(theta)**5 + 1.05613811815066e+44*cos(theta)**3 - 1.48125963274987e+41*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl69_m_minus_21(theta, phi):
    return 1.35957748834704e-38*(1.0 - cos(theta)**2)**10.5*(5.51672922456096e+56*cos(theta)**48 - 4.54224128854362e+57*cos(theta)**46 + 1.74119249394172e+58*cos(theta)**44 - 4.12824085029791e+58*cos(theta)**42 + 6.78323544295135e+58*cos(theta)**40 - 8.20298239612721e+58*cos(theta)**38 + 7.56784333920922e+58*cos(theta)**36 - 5.44884720423064e+58*cos(theta)**34 + 3.10650739997296e+58*cos(theta)**32 - 1.41490144204462e+58*cos(theta)**30 + 5.17211871671771e+57*cos(theta)**28 - 1.51908381889611e+57*cos(theta)**26 + 3.57755247203794e+56*cos(theta)**24 - 6.72160981812439e+55*cos(theta)**22 + 9.99158216207679e+54*cos(theta)**20 - 1.16110129100587e+54*cos(theta)**18 + 1.0376664574994e+53*cos(theta)**16 - 6.97590895797916e+51*cos(theta)**14 + 3.42398983374382e+50*cos(theta)**12 - 1.17760984380976e+49*cos(theta)**10 + 2.67638600865854e+47*cos(theta)**8 - 3.67888111155812e+45*cos(theta)**6 + 2.64034529537664e+43*cos(theta)**4 - 7.40629816374935e+40*cos(theta)**2 + 3.3911621628889e+37)*sin(21*phi)

#@torch.jit.script
def Yl69_m_minus_20(theta, phi):
    return 9.02865918920212e-37*(1.0 - cos(theta)**2)**10*(1.12586310705326e+55*cos(theta)**49 - 9.66434316711409e+55*cos(theta)**47 + 3.86931665320382e+56*cos(theta)**45 - 9.6005601169719e+56*cos(theta)**43 + 1.65444766901252e+57*cos(theta)**41 - 2.1033288195198e+57*cos(theta)**39 + 2.04536306465114e+57*cos(theta)**37 - 1.55681348692304e+57*cos(theta)**35 + 9.41365878779684e+56*cos(theta)**33 - 4.56419820014392e+56*cos(theta)**31 + 1.78348921266128e+56*cos(theta)**29 - 5.62623636628189e+55*cos(theta)**27 + 1.43102098881518e+55*cos(theta)**25 - 2.92243905135843e+54*cos(theta)**23 + 4.75789626765561e+53*cos(theta)**21 - 6.11105942634666e+52*cos(theta)**19 + 6.10392033823177e+51*cos(theta)**17 - 4.65060597198611e+50*cos(theta)**15 + 2.63383833364909e+49*cos(theta)**13 - 1.07055440346341e+48*cos(theta)**11 + 2.97376223184282e+46*cos(theta)**9 - 5.25554444508303e+44*cos(theta)**7 + 5.28069059075329e+42*cos(theta)**5 - 2.46876605458312e+40*cos(theta)**3 + 3.3911621628889e+37*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl69_m_minus_19(theta, phi):
    return 6.02286689259109e-35*(1.0 - cos(theta)**2)**9.5*(2.25172621410651e+53*cos(theta)**50 - 2.0134048264821e+54*cos(theta)**48 + 8.41155794174744e+54*cos(theta)**46 - 2.18194548112998e+55*cos(theta)**44 + 3.93916111669648e+55*cos(theta)**42 - 5.25832204879949e+55*cos(theta)**40 + 5.3825343806609e+55*cos(theta)**38 - 4.32448190811956e+55*cos(theta)**36 + 2.76872317288142e+55*cos(theta)**34 - 1.42631193754498e+55*cos(theta)**32 + 5.94496404220427e+54*cos(theta)**30 - 2.00937013081496e+54*cos(theta)**28 + 5.50392688005837e+53*cos(theta)**26 - 1.21768293806601e+53*cos(theta)**24 + 2.16268012166164e+52*cos(theta)**22 - 3.05552971317333e+51*cos(theta)**20 + 3.39106685457321e+50*cos(theta)**18 - 2.90662873249132e+49*cos(theta)**16 + 1.88131309546364e+48*cos(theta)**14 - 8.92128669552845e+46*cos(theta)**12 + 2.97376223184282e+45*cos(theta)**10 - 6.56943055635379e+43*cos(theta)**8 + 8.80115098458881e+41*cos(theta)**6 - 6.17191513645779e+39*cos(theta)**4 + 1.69558108144445e+37*cos(theta)**2 - 7.62058913008741e+33)*sin(19*phi)

#@torch.jit.script
def Yl69_m_minus_18(theta, phi):
    return 4.03487132532308e-33*(1.0 - cos(theta)**2)**9*(4.41514943942454e+51*cos(theta)**51 - 4.10898944180021e+52*cos(theta)**49 + 1.7896931790952e+53*cos(theta)**47 - 4.84876773584439e+53*cos(theta)**45 + 9.16083980627089e+53*cos(theta)**43 - 1.28251757287792e+54*cos(theta)**41 + 1.38013702068228e+54*cos(theta)**39 - 1.16877889408637e+54*cos(theta)**37 + 7.91063763680406e+53*cos(theta)**35 - 4.32215738649992e+53*cos(theta)**33 + 1.91773033619492e+53*cos(theta)**31 - 6.92886252005159e+52*cos(theta)**29 + 2.03849143705866e+52*cos(theta)**27 - 4.87073175226405e+51*cos(theta)**25 + 9.4029570507028e+50*cos(theta)**23 - 1.45501414913016e+50*cos(theta)**21 + 1.78477202872274e+49*cos(theta)**19 - 1.70978160734783e+48*cos(theta)**17 + 1.25420873030909e+47*cos(theta)**15 - 6.86252822732958e+45*cos(theta)**13 + 2.7034202107662e+44*cos(theta)**11 - 7.29936728483755e+42*cos(theta)**9 + 1.25730728351269e+41*cos(theta)**7 - 1.23438302729156e+39*cos(theta)**5 + 5.65193693814816e+36*cos(theta)**3 - 7.62058913008741e+33*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl69_m_minus_17(theta, phi):
    return 2.71388216826562e-31*(1.0 - cos(theta)**2)**8.5*(8.49067199889334e+49*cos(theta)**52 - 8.21797888360041e+50*cos(theta)**50 + 3.72852745644834e+51*cos(theta)**48 - 1.05407994257487e+52*cos(theta)**46 + 2.08200904687975e+52*cos(theta)**44 - 3.05361326875696e+52*cos(theta)**42 + 3.4503425517057e+52*cos(theta)**40 - 3.07573393180623e+52*cos(theta)**38 + 2.19739934355668e+52*cos(theta)**36 - 1.27122276073527e+52*cos(theta)**34 + 5.99290730060914e+51*cos(theta)**32 - 2.3096208400172e+51*cos(theta)**30 + 7.28032656092378e+50*cos(theta)**28 - 1.8733583662554e+50*cos(theta)**26 + 3.91789877112616e+49*cos(theta)**24 - 6.61370067786435e+48*cos(theta)**22 + 8.9238601436137e+47*cos(theta)**20 - 9.49878670748797e+46*cos(theta)**18 + 7.83880456443182e+45*cos(theta)**16 - 4.90180587666398e+44*cos(theta)**14 + 2.2528501756385e+43*cos(theta)**12 - 7.29936728483755e+41*cos(theta)**10 + 1.57163410439086e+40*cos(theta)**8 - 2.05730504548593e+38*cos(theta)**6 + 1.41298423453704e+36*cos(theta)**4 - 3.8102945650437e+33*cos(theta)**2 + 1.68448035589907e+30)*sin(17*phi)

#@torch.jit.script
def Yl69_m_minus_16(theta, phi):
    return 1.83222222934563e-29*(1.0 - cos(theta)**2)**8*(1.60201358469686e+48*cos(theta)**53 - 1.6113684085491e+49*cos(theta)**51 + 7.60923970703742e+49*cos(theta)**49 - 2.24272328207419e+50*cos(theta)**47 + 4.62668677084388e+50*cos(theta)**45 - 7.10142620641154e+50*cos(theta)**43 + 8.41546963830659e+50*cos(theta)**41 - 7.88649726104161e+50*cos(theta)**39 + 5.9389171447478e+50*cos(theta)**37 - 3.63206503067221e+50*cos(theta)**35 + 1.8160325153361e+50*cos(theta)**33 - 7.45038980650709e+49*cos(theta)**31 + 2.5104574348013e+49*cos(theta)**29 - 6.93836431946446e+48*cos(theta)**27 + 1.56715950845047e+48*cos(theta)**25 - 2.87552203385407e+47*cos(theta)**23 + 4.24945721124462e+46*cos(theta)**21 - 4.99936142499367e+45*cos(theta)**19 + 4.61106150848931e+44*cos(theta)**17 - 3.26787058444266e+43*cos(theta)**15 + 1.73296167356807e+42*cos(theta)**13 - 6.63578844076141e+40*cos(theta)**11 + 1.74626011598984e+39*cos(theta)**9 - 2.93900720783704e+37*cos(theta)**7 + 2.82596846907408e+35*cos(theta)**5 - 1.2700981883479e+33*cos(theta)**3 + 1.68448035589907e+30*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl69_m_minus_15(theta, phi):
    return 1.24132210914335e-27*(1.0 - cos(theta)**2)**7.5*(2.9666918235127e+46*cos(theta)**54 - 3.09878540105596e+47*cos(theta)**52 + 1.52184794140748e+48*cos(theta)**50 - 4.67234017098789e+48*cos(theta)**48 + 1.00580147192258e+49*cos(theta)**46 - 1.61396050145717e+49*cos(theta)**44 + 2.00368324721586e+49*cos(theta)**42 - 1.9716243152604e+49*cos(theta)**40 + 1.56287293282837e+49*cos(theta)**38 - 1.0089069529645e+49*cos(theta)**36 + 5.34127210392971e+48*cos(theta)**34 - 2.32824681453347e+48*cos(theta)**32 + 8.36819144933767e+47*cos(theta)**30 - 2.47798725695159e+47*cos(theta)**28 + 6.02753657096333e+46*cos(theta)**26 - 1.19813418077253e+46*cos(theta)**24 + 1.93157145965664e+45*cos(theta)**22 - 2.49968071249683e+44*cos(theta)**20 + 2.56170083804961e+43*cos(theta)**18 - 2.04241911527666e+42*cos(theta)**16 + 1.23782976683434e+41*cos(theta)**14 - 5.5298237006345e+39*cos(theta)**12 + 1.74626011598984e+38*cos(theta)**10 - 3.67375900979631e+36*cos(theta)**8 + 4.7099474484568e+34*cos(theta)**6 - 3.17524547086975e+32*cos(theta)**4 + 8.42240177949537e+29*cos(theta)**2 - 3.66989184291737e+26)*sin(15*phi)

#@torch.jit.script
def Yl69_m_minus_14(theta, phi):
    return 8.43733860488851e-26*(1.0 - cos(theta)**2)**7*(5.39398513365945e+44*cos(theta)**55 - 5.84676490765276e+45*cos(theta)**53 + 2.98401557138722e+46*cos(theta)**51 - 9.53538810405692e+46*cos(theta)**49 + 2.14000313175018e+47*cos(theta)**47 - 3.58657889212704e+47*cos(theta)**45 + 4.65972848189734e+47*cos(theta)**43 - 4.80883979331805e+47*cos(theta)**41 + 4.00736649443171e+47*cos(theta)**39 - 2.72677554855271e+47*cos(theta)**37 + 1.52607774397992e+47*cos(theta)**35 - 7.05529337737414e+46*cos(theta)**33 + 2.69941659656054e+46*cos(theta)**31 - 8.54478364466066e+45*cos(theta)**29 + 2.23242095220864e+45*cos(theta)**27 - 4.79253672309011e+44*cos(theta)**25 + 8.39813678111585e+43*cos(theta)**23 - 1.19032414880802e+43*cos(theta)**21 + 1.34826359897348e+42*cos(theta)**19 - 1.20142300898627e+41*cos(theta)**17 + 8.25219844556226e+39*cos(theta)**15 - 4.25371053894962e+38*cos(theta)**13 + 1.5875091963544e+37*cos(theta)**11 - 4.08195445532923e+35*cos(theta)**9 + 6.72849635493829e+33*cos(theta)**7 - 6.35049094173951e+31*cos(theta)**5 + 2.80746725983179e+29*cos(theta)**3 - 3.66989184291737e+26*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl69_m_minus_13(theta, phi):
    return 5.75226040218542e-24*(1.0 - cos(theta)**2)**6.5*(9.63211631010616e+42*cos(theta)**56 - 1.08273424215792e+44*cos(theta)**54 + 5.73849148343697e+44*cos(theta)**52 - 1.90707762081138e+45*cos(theta)**50 + 4.45833985781287e+45*cos(theta)**48 - 7.79691063505879e+45*cos(theta)**46 + 1.05902920043121e+46*cos(theta)**44 - 1.14496185555192e+46*cos(theta)**42 + 1.00184162360793e+46*cos(theta)**40 - 7.17572512777028e+45*cos(theta)**38 + 4.23910484438866e+45*cos(theta)**36 - 2.07508628746298e+45*cos(theta)**34 + 8.43567686425169e+44*cos(theta)**32 - 2.84826121488689e+44*cos(theta)**30 + 7.97293197217372e+43*cos(theta)**28 - 1.84328335503466e+43*cos(theta)**26 + 3.49922365879827e+42*cos(theta)**24 - 5.41056431276371e+41*cos(theta)**22 + 6.74131799486741e+40*cos(theta)**20 - 6.67457227214595e+39*cos(theta)**18 + 5.15762402847641e+38*cos(theta)**16 - 3.0383646706783e+37*cos(theta)**14 + 1.32292433029534e+36*cos(theta)**12 - 4.08195445532923e+34*cos(theta)**10 + 8.41062044367286e+32*cos(theta)**8 - 1.05841515695658e+31*cos(theta)**6 + 7.01866814957947e+28*cos(theta)**4 - 1.83494592145869e+26*cos(theta)**2 + 7.89563649508901e+22)*sin(13*phi)

#@torch.jit.script
def Yl69_m_minus_12(theta, phi):
    return 3.93262822752531e-22*(1.0 - cos(theta)**2)**6*(1.68984496668529e+41*cos(theta)**57 - 1.9686077130144e+42*cos(theta)**55 + 1.08273424215792e+43*cos(theta)**53 - 3.73936788394389e+43*cos(theta)**51 + 9.09865277104668e+43*cos(theta)**49 - 1.65891715639549e+44*cos(theta)**47 + 2.35339822318047e+44*cos(theta)**45 - 2.66270198965562e+44*cos(theta)**43 + 2.44351615514129e+44*cos(theta)**41 - 1.8399295199411e+44*cos(theta)**39 + 1.14570401199694e+44*cos(theta)**37 - 5.92881796417995e+43*cos(theta)**35 + 2.55626571643991e+43*cos(theta)**33 - 9.18793940286092e+42*cos(theta)**31 + 2.74928688695645e+42*cos(theta)**29 - 6.82697538901725e+41*cos(theta)**27 + 1.39968946351931e+41*cos(theta)**25 - 2.352419266419e+40*cos(theta)**23 + 3.21015142612734e+39*cos(theta)**21 - 3.51293277481366e+38*cos(theta)**19 + 3.03389648733907e+37*cos(theta)**17 - 2.02557644711887e+36*cos(theta)**15 + 1.01763410022718e+35*cos(theta)**13 - 3.71086768666293e+33*cos(theta)**11 + 9.34513382630318e+31*cos(theta)**9 - 1.51202165279512e+30*cos(theta)**7 + 1.40373362991589e+28*cos(theta)**5 - 6.11648640486229e+25*cos(theta)**3 + 7.89563649508901e+22*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl69_m_minus_11(theta, phi):
    return 2.69550038614936e-20*(1.0 - cos(theta)**2)**5.5*(2.91352580462981e+39*cos(theta)**58 - 3.51537091609714e+40*cos(theta)**56 + 2.00506341140355e+41*cos(theta)**54 - 7.19109208450748e+41*cos(theta)**52 + 1.81973055420934e+42*cos(theta)**50 - 3.45607740915726e+42*cos(theta)**48 + 5.1160830938706e+42*cos(theta)**46 - 6.05159543103551e+42*cos(theta)**44 + 5.81789560747926e+42*cos(theta)**42 - 4.59982379985275e+42*cos(theta)**40 + 3.01501055788667e+42*cos(theta)**38 - 1.64689387893887e+42*cos(theta)**36 + 7.51842857776443e+41*cos(theta)**34 - 2.87123106339404e+41*cos(theta)**32 + 9.16428962318818e+40*cos(theta)**30 - 2.43820549607759e+40*cos(theta)**28 + 5.3834210135358e+39*cos(theta)**26 - 9.80174694341252e+38*cos(theta)**24 + 1.45915973914879e+38*cos(theta)**22 - 1.75646638740683e+37*cos(theta)**20 + 1.6854980485217e+36*cos(theta)**18 - 1.26598527944929e+35*cos(theta)**16 + 7.26881500162273e+33*cos(theta)**14 - 3.09238973888578e+32*cos(theta)**12 + 9.34513382630318e+30*cos(theta)**10 - 1.8900270659939e+29*cos(theta)**8 + 2.33955604985982e+27*cos(theta)**6 - 1.52912160121557e+25*cos(theta)**4 + 3.9478182475445e+22*cos(theta)**2 - 1.68063782356088e+19)*sin(11*phi)

#@torch.jit.script
def Yl69_m_minus_10(theta, phi):
    return 1.85186957979692e-18*(1.0 - cos(theta)**2)**5*(4.93817932988104e+37*cos(theta)**59 - 6.16731739666165e+38*cos(theta)**57 + 3.64556983891555e+39*cos(theta)**55 - 1.35680982726556e+40*cos(theta)**53 + 3.56809912590066e+40*cos(theta)**51 - 7.05321920236176e+40*cos(theta)**49 + 1.08852831784481e+41*cos(theta)**47 - 1.34479898467456e+41*cos(theta)**45 + 1.35299897848355e+41*cos(theta)**43 - 1.12190824386652e+41*cos(theta)**41 + 7.73079630227352e+40*cos(theta)**39 - 4.45106453767263e+40*cos(theta)**37 + 2.14812245078984e+40*cos(theta)**35 - 8.70070019210315e+39*cos(theta)**33 + 2.95622245909296e+39*cos(theta)**31 - 8.40760515888824e+38*cos(theta)**29 + 1.99385963464289e+38*cos(theta)**27 - 3.92069877736501e+37*cos(theta)**25 + 6.34417277890778e+36*cos(theta)**23 - 8.36412565431823e+35*cos(theta)**21 + 8.87104236064055e+34*cos(theta)**19 - 7.44697223205466e+33*cos(theta)**17 + 4.84587666774848e+32*cos(theta)**15 - 2.37876133760445e+31*cos(theta)**13 + 8.49557620573016e+29*cos(theta)**11 - 2.10003007332656e+28*cos(theta)**9 + 3.34222292837118e+26*cos(theta)**7 - 3.05824320243114e+24*cos(theta)**5 + 1.31593941584817e+22*cos(theta)**3 - 1.68063782356088e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl69_m_minus_9(theta, phi):
    return 1.27496883327931e-16*(1.0 - cos(theta)**2)**4.5*(8.23029888313506e+35*cos(theta)**60 - 1.06333058563132e+37*cos(theta)**58 + 6.50994614092063e+37*cos(theta)**56 - 2.51261079123252e+38*cos(theta)**54 + 6.8617290882705e+38*cos(theta)**52 - 1.41064384047235e+39*cos(theta)**50 + 2.26776732884335e+39*cos(theta)**48 - 2.92347605364034e+39*cos(theta)**46 + 3.0749976783717e+39*cos(theta)**44 - 2.6712101044441e+39*cos(theta)**42 + 1.93269907556838e+39*cos(theta)**40 - 1.17133277307175e+39*cos(theta)**38 + 5.96700680774954e+38*cos(theta)**36 - 2.55902946826563e+38*cos(theta)**34 + 9.2381951846655e+37*cos(theta)**32 - 2.80253505296275e+37*cos(theta)**30 + 7.12092726658174e+36*cos(theta)**28 - 1.50796106821731e+36*cos(theta)**26 + 2.64340532454491e+35*cos(theta)**24 - 3.80187529741738e+34*cos(theta)**22 + 4.43552118032027e+33*cos(theta)**20 - 4.13720679558592e+32*cos(theta)**18 + 3.0286729173428e+31*cos(theta)**16 - 1.69911524114603e+30*cos(theta)**14 + 7.07964683810847e+28*cos(theta)**12 - 2.10003007332656e+27*cos(theta)**10 + 4.17777866046397e+25*cos(theta)**8 - 5.09707200405191e+23*cos(theta)**6 + 3.28984853962042e+21*cos(theta)**4 - 8.4031891178044e+18*cos(theta)**2 + 3.5456494167951e+15)*sin(9*phi)

#@torch.jit.script
def Yl69_m_minus_8(theta, phi):
    return 8.7945128414917e-15*(1.0 - cos(theta)**2)**4*(1.34922932510411e+34*cos(theta)**61 - 1.80225522988359e+35*cos(theta)**59 + 1.1420958141966e+36*cos(theta)**57 - 4.5683832567864e+36*cos(theta)**55 + 1.29466586571141e+37*cos(theta)**53 - 2.76596831465167e+37*cos(theta)**51 + 4.62809658947622e+37*cos(theta)**49 - 6.22016181625604e+37*cos(theta)**47 + 6.83332817415933e+37*cos(theta)**45 - 6.21211652196303e+37*cos(theta)**43 + 4.71390018431312e+37*cos(theta)**41 - 3.00341736685063e+37*cos(theta)**39 + 1.61270454263501e+37*cos(theta)**37 - 7.31151276647323e+36*cos(theta)**35 + 2.79945308626227e+36*cos(theta)**33 - 9.04043565471854e+35*cos(theta)**31 + 2.45549216089026e+35*cos(theta)**29 - 5.58504099339745e+34*cos(theta)**27 + 1.05736212981796e+34*cos(theta)**25 - 1.65298925974669e+33*cos(theta)**23 + 2.11215294300965e+32*cos(theta)**21 - 2.17747726083469e+31*cos(theta)**19 + 1.7815723043193e+30*cos(theta)**17 - 1.13274349409735e+29*cos(theta)**15 + 5.44588218316036e+27*cos(theta)**13 - 1.90911824847869e+26*cos(theta)**11 + 4.64197628940441e+24*cos(theta)**9 - 7.28153143435986e+22*cos(theta)**7 + 6.57969707924084e+20*cos(theta)**5 - 2.80106303926813e+18*cos(theta)**3 + 3.5456494167951e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl69_m_minus_7(theta, phi):
    return 6.07649289897455e-13*(1.0 - cos(theta)**2)**3.5*(2.17617633081308e+32*cos(theta)**62 - 3.00375871647265e+33*cos(theta)**60 + 1.96913071413207e+34*cos(theta)**58 - 8.15782724426144e+34*cos(theta)**56 + 2.39752938094706e+35*cos(theta)**54 - 5.3191698358686e+35*cos(theta)**52 + 9.25619317895245e+35*cos(theta)**50 - 1.29586704505334e+36*cos(theta)**48 + 1.48550612481725e+36*cos(theta)**46 - 1.41184466408251e+36*cos(theta)**44 + 1.12235718674122e+36*cos(theta)**42 - 7.50854341712657e+35*cos(theta)**40 + 4.24395932272372e+35*cos(theta)**38 - 2.03097576846479e+35*cos(theta)**36 + 8.23368554783022e+34*cos(theta)**34 - 2.82513614209954e+34*cos(theta)**32 + 8.18497386963419e+33*cos(theta)**30 - 1.99465749764195e+33*cos(theta)**28 + 4.06677742237678e+32*cos(theta)**26 - 6.88745524894452e+31*cos(theta)**24 + 9.60069519549843e+30*cos(theta)**22 - 1.08873863041735e+30*cos(theta)**20 + 9.89762391288498e+28*cos(theta)**18 - 7.07964683810847e+27*cos(theta)**16 + 3.88991584511454e+26*cos(theta)**14 - 1.59093187373224e+25*cos(theta)**12 + 4.64197628940441e+23*cos(theta)**10 - 9.10191429294983e+21*cos(theta)**8 + 1.09661617987347e+20*cos(theta)**6 - 7.00265759817033e+17*cos(theta)**4 + 1.77282470839755e+15*cos(theta)**2 - 742699919730.855)*sin(7*phi)

#@torch.jit.script
def Yl69_m_minus_6(theta, phi):
    return 4.2046520828098e-11*(1.0 - cos(theta)**2)**3*(3.45424814414774e+30*cos(theta)**63 - 4.92419461716828e+31*cos(theta)**61 + 3.33750968496961e+32*cos(theta)**59 - 1.43119776215113e+33*cos(theta)**57 + 4.35914432899466e+33*cos(theta)**55 - 1.00361695016389e+34*cos(theta)**53 + 1.81493983901028e+34*cos(theta)**51 - 2.64462662255784e+34*cos(theta)**49 + 3.1606513293984e+34*cos(theta)**47 - 3.13743258685002e+34*cos(theta)**45 + 2.61013299242144e+34*cos(theta)**43 - 1.8313520529577e+34*cos(theta)**41 + 1.08819469813429e+34*cos(theta)**39 - 5.48912369855348e+33*cos(theta)**37 + 2.35248158509435e+33*cos(theta)**35 - 8.56101861242286e+32*cos(theta)**33 + 2.6403141514949e+32*cos(theta)**31 - 6.8781293022136e+31*cos(theta)**29 + 1.50621386013955e+31*cos(theta)**27 - 2.75498209957781e+30*cos(theta)**25 + 4.17421530239062e+29*cos(theta)**23 - 5.18446966865403e+28*cos(theta)**21 + 5.20927574362367e+27*cos(theta)**19 - 4.1644981400638e+26*cos(theta)**17 + 2.59327723007636e+25*cos(theta)**15 - 1.2237937490248e+24*cos(theta)**13 + 4.2199784449131e+22*cos(theta)**11 - 1.01132381032776e+21*cos(theta)**9 + 1.56659454267639e+19*cos(theta)**7 - 1.40053151963407e+17*cos(theta)**5 + 590941569465851.0*cos(theta)**3 - 742699919730.855*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl69_m_minus_5(theta, phi):
    return 2.91306841423075e-9*(1.0 - cos(theta)**2)**2.5*(5.39726272523085e+28*cos(theta)**64 - 7.94224938252948e+29*cos(theta)**62 + 5.56251614161602e+30*cos(theta)**60 - 2.46758234853643e+31*cos(theta)**58 + 7.78418630177618e+31*cos(theta)**56 - 1.8585499077109e+32*cos(theta)**54 + 3.49026892117362e+32*cos(theta)**52 - 5.28925324511568e+32*cos(theta)**50 + 6.58469026957999e+32*cos(theta)**48 - 6.82050562358699e+32*cos(theta)**46 + 5.93212043732146e+32*cos(theta)**44 - 4.36036203085167e+32*cos(theta)**42 + 2.72048674533572e+32*cos(theta)**40 - 1.44450623646144e+32*cos(theta)**38 + 6.53467106970652e+31*cos(theta)**36 - 2.51794665071261e+31*cos(theta)**34 + 8.25098172342156e+30*cos(theta)**32 - 2.29270976740453e+30*cos(theta)**30 + 5.3793352147841e+29*cos(theta)**28 - 1.05960849983762e+29*cos(theta)**26 + 1.73925637599609e+28*cos(theta)**24 - 2.35657712211547e+27*cos(theta)**22 + 2.60463787181184e+26*cos(theta)**20 - 2.31361007781322e+25*cos(theta)**18 + 1.62079826879773e+24*cos(theta)**16 - 8.74138392160572e+22*cos(theta)**14 + 3.51664870409425e+21*cos(theta)**12 - 1.01132381032776e+20*cos(theta)**10 + 1.95824317834549e+18*cos(theta)**8 - 2.33421919939011e+16*cos(theta)**6 + 147735392366463.0*cos(theta)**4 - 371349959865.428*cos(theta)**2 + 154729149.943928)*sin(5*phi)

#@torch.jit.script
def Yl69_m_minus_4(theta, phi):
    return 2.02033423196773e-7*(1.0 - cos(theta)**2)**2*(8.30348111573977e+26*cos(theta)**65 - 1.26067450516341e+28*cos(theta)**63 + 9.118878920682e+28*cos(theta)**61 - 4.18234296362107e+29*cos(theta)**59 + 1.36564671960986e+30*cos(theta)**57 - 3.37918165038346e+30*cos(theta)**55 + 6.58541305881816e+30*cos(theta)**53 - 1.03710847943445e+31*cos(theta)**51 + 1.34381434073061e+31*cos(theta)**49 - 1.45117140927383e+31*cos(theta)**47 + 1.31824898607143e+31*cos(theta)**45 - 1.01403768159341e+31*cos(theta)**43 + 6.63533352520906e+30*cos(theta)**41 - 3.70386214477293e+30*cos(theta)**39 + 1.7661273161369e+30*cos(theta)**37 - 7.1941332877503e+29*cos(theta)**35 + 2.50029749194593e+29*cos(theta)**33 - 7.39583795936947e+28*cos(theta)**31 + 1.85494317751176e+28*cos(theta)**29 - 3.92447592532451e+27*cos(theta)**27 + 6.95702550398437e+26*cos(theta)**25 - 1.02459874874586e+26*cos(theta)**23 + 1.24030374848183e+25*cos(theta)**21 - 1.21768951463854e+24*cos(theta)**19 + 9.53410746351604e+22*cos(theta)**17 - 5.82758928107048e+21*cos(theta)**15 + 2.70511438776481e+20*cos(theta)**13 - 9.19385282116145e+18*cos(theta)**11 + 2.17582575371721e+17*cos(theta)**9 - 3.33459885627159e+15*cos(theta)**7 + 29547078473292.5*cos(theta)**5 - 123783319955.143*cos(theta)**3 + 154729149.943928*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl69_m_minus_3(theta, phi):
    return 1.40235065051115e-5*(1.0 - cos(theta)**2)**1.5*(1.25810319935451e+25*cos(theta)**66 - 1.96980391431783e+26*cos(theta)**64 + 1.47078692269064e+27*cos(theta)**62 - 6.97057160603511e+27*cos(theta)**60 + 2.35456330967217e+28*cos(theta)**58 - 6.03425294711332e+28*cos(theta)**56 + 1.21952093681818e+29*cos(theta)**54 - 1.99443938352778e+29*cos(theta)**52 + 2.68762868146122e+29*cos(theta)**50 - 3.02327376932047e+29*cos(theta)**48 + 2.86575866537268e+29*cos(theta)**46 - 2.30463109453048e+29*cos(theta)**44 + 1.57984131552597e+29*cos(theta)**42 - 9.25965536193232e+28*cos(theta)**40 + 4.64770346351815e+28*cos(theta)**38 - 1.99837035770842e+28*cos(theta)**36 + 7.35381615278214e+27*cos(theta)**34 - 2.31119936230296e+27*cos(theta)**32 + 6.1831439250392e+26*cos(theta)**30 - 1.40159854475876e+26*cos(theta)**28 + 2.67577903999399e+25*cos(theta)**26 - 4.26916145310774e+24*cos(theta)**24 + 5.63774431128103e+23*cos(theta)**22 - 6.0884475731927e+22*cos(theta)**20 + 5.29672636862002e+21*cos(theta)**18 - 3.64224330066905e+20*cos(theta)**16 + 1.93222456268915e+19*cos(theta)**14 - 7.66154401763454e+17*cos(theta)**12 + 2.17582575371721e+16*cos(theta)**10 - 416824857033948.0*cos(theta)**8 + 4924513078882.09*cos(theta)**6 - 30945829988.7856*cos(theta)**4 + 77364574.9719641*cos(theta)**2 - 32114.8090377601)*sin(3*phi)

#@torch.jit.script
def Yl69_m_minus_2(theta, phi):
    return 0.000974002944650333*(1.0 - cos(theta)**2)*(1.87776596918584e+23*cos(theta)**67 - 3.03046756048897e+24*cos(theta)**65 + 2.33458241696928e+25*cos(theta)**63 - 1.14271665672707e+26*cos(theta)**61 + 3.99078527063079e+26*cos(theta)**59 - 1.05864086791462e+27*cos(theta)**57 + 2.21731079421487e+27*cos(theta)**55 - 3.76309317646752e+27*cos(theta)**53 + 5.26986015972789e+27*cos(theta)**51 - 6.16994646800097e+27*cos(theta)**49 + 6.09735886249507e+27*cos(theta)**47 - 5.12140243228996e+27*cos(theta)**45 + 3.67404957099062e+27*cos(theta)**43 - 2.25845252730057e+27*cos(theta)**41 + 1.19171883679953e+27*cos(theta)**39 - 5.4010009667795e+26*cos(theta)**37 + 2.10109032936633e+26*cos(theta)**35 - 7.00363443122109e+25*cos(theta)**33 + 1.99456255646426e+25*cos(theta)**31 - 4.8330984302026e+24*cos(theta)**29 + 9.91029274071847e+23*cos(theta)**27 - 1.70766458124309e+23*cos(theta)**25 + 2.45119317881784e+22*cos(theta)**23 - 2.89926074913938e+21*cos(theta)**21 + 2.78775072032633e+20*cos(theta)**19 - 2.14249605921709e+19*cos(theta)**17 + 1.28814970845943e+18*cos(theta)**15 - 5.89349539818041e+16*cos(theta)**13 + 1.97802341247019e+15*cos(theta)**11 - 46313873003772.0*cos(theta)**9 + 703501868411.727*cos(theta)**7 - 6189165997.75713*cos(theta)**5 + 25788191.6573214*cos(theta)**3 - 32114.8090377601*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl69_m_minus_1(theta, phi):
    return 0.06767743658202*(1.0 - cos(theta)**2)**0.5*(2.76142054292035e+21*cos(theta)**68 - 4.59161751589237e+22*cos(theta)**66 + 3.6477850265145e+23*cos(theta)**64 - 1.84309138181785e+24*cos(theta)**62 + 6.65130878438465e+24*cos(theta)**60 - 1.82524287571486e+25*cos(theta)**58 + 3.95948356109798e+25*cos(theta)**56 - 6.96869106753244e+25*cos(theta)**54 + 1.01343464610152e+26*cos(theta)**52 - 1.23398929360019e+26*cos(theta)**50 + 1.27028309635314e+26*cos(theta)**48 - 1.11334835484564e+26*cos(theta)**46 + 8.35011266134232e+25*cos(theta)**44 - 5.3772679221442e+25*cos(theta)**42 + 2.97929709199882e+25*cos(theta)**40 - 1.42131604388934e+25*cos(theta)**38 + 5.83636202601757e+24*cos(theta)**36 - 2.05989247977091e+24*cos(theta)**34 + 6.23300798895081e+23*cos(theta)**32 - 1.61103281006753e+23*cos(theta)**30 + 3.53939026454231e+22*cos(theta)**28 - 6.56794069708882e+21*cos(theta)**26 + 1.0213304911741e+21*cos(theta)**24 - 1.31784579506335e+20*cos(theta)**22 + 1.39387536016316e+19*cos(theta)**20 - 1.19027558845394e+18*cos(theta)**18 + 8.05093567787146e+16*cos(theta)**16 - 4.20963957012887e+15*cos(theta)**14 + 164835284372516.0*cos(theta)**12 - 4631387300377.2*cos(theta)**10 + 87937733551.4659*cos(theta)**8 - 1031527666.29285*cos(theta)**6 + 6447047.91433034*cos(theta)**4 - 16057.4045188801*cos(theta)**2 + 6.65178314783764)*sin(phi)

#@torch.jit.script
def Yl69_m0(theta, phi):
    return 4.18153562767418e+20*cos(theta)**69 - 7.16049823541871e+21*cos(theta)**67 + 5.86365244389288e+22*cos(theta)**65 - 3.05674112363338e+23*cos(theta)**63 + 1.13927775085038e+24*cos(theta)**61 - 3.23236943264526e+24*cos(theta)**59 + 7.25798438222578e+24*cos(theta)**57 - 1.32385635131798e+25*cos(theta)**55 + 1.99789296921464e+25*cos(theta)**53 - 2.52809597022752e+25*cos(theta)**51 + 2.7086742538152e+25*cos(theta)**49 - 2.47505899183114e+25*cos(theta)**47 + 1.93879621026773e+25*cos(theta)**45 - 1.30660874619813e+25*cos(theta)**43 + 7.59245622790804e+24*cos(theta)**41 - 3.80783737424134e+24*cos(theta)**39 + 1.64813521864067e+24*cos(theta)**37 - 6.14934484938201e+23*cos(theta)**35 + 1.97349524562152e+23*cos(theta)**33 - 5.42994001921919e+22*cos(theta)**31 + 1.27521318633178e+22*cos(theta)**29 - 2.54166202086746e+21*cos(theta)**27 + 4.26853286758124e+20*cos(theta)**25 - 5.98672211441969e+19*cos(theta)**23 + 6.93516801716201e+18*cos(theta)**21 - 6.54555183642257e+17*cos(theta)**19 + 4.94822884185791e+16*cos(theta)**17 - 2.93228375813802e+15*cos(theta)**15 + 132482699915874.0*cos(theta)**13 - 4399170112149.09*cos(theta)**11 + 102090445640.591*cos(theta)**9 - 1539696708.44628*cos(theta)**7 + 13472346.1989049*cos(theta)**5 - 55925.0568655248*cos(theta)**3 + 69.5008991700805*cos(theta)

#@torch.jit.script
def Yl69_m1(theta, phi):
    return 0.06767743658202*(1.0 - cos(theta)**2)**0.5*(2.76142054292035e+21*cos(theta)**68 - 4.59161751589237e+22*cos(theta)**66 + 3.6477850265145e+23*cos(theta)**64 - 1.84309138181785e+24*cos(theta)**62 + 6.65130878438465e+24*cos(theta)**60 - 1.82524287571486e+25*cos(theta)**58 + 3.95948356109798e+25*cos(theta)**56 - 6.96869106753244e+25*cos(theta)**54 + 1.01343464610152e+26*cos(theta)**52 - 1.23398929360019e+26*cos(theta)**50 + 1.27028309635314e+26*cos(theta)**48 - 1.11334835484564e+26*cos(theta)**46 + 8.35011266134232e+25*cos(theta)**44 - 5.3772679221442e+25*cos(theta)**42 + 2.97929709199882e+25*cos(theta)**40 - 1.42131604388934e+25*cos(theta)**38 + 5.83636202601757e+24*cos(theta)**36 - 2.05989247977091e+24*cos(theta)**34 + 6.23300798895081e+23*cos(theta)**32 - 1.61103281006753e+23*cos(theta)**30 + 3.53939026454231e+22*cos(theta)**28 - 6.56794069708882e+21*cos(theta)**26 + 1.0213304911741e+21*cos(theta)**24 - 1.31784579506335e+20*cos(theta)**22 + 1.39387536016316e+19*cos(theta)**20 - 1.19027558845394e+18*cos(theta)**18 + 8.05093567787146e+16*cos(theta)**16 - 4.20963957012887e+15*cos(theta)**14 + 164835284372516.0*cos(theta)**12 - 4631387300377.2*cos(theta)**10 + 87937733551.4659*cos(theta)**8 - 1031527666.29285*cos(theta)**6 + 6447047.91433034*cos(theta)**4 - 16057.4045188801*cos(theta)**2 + 6.65178314783764)*cos(phi)

#@torch.jit.script
def Yl69_m2(theta, phi):
    return 0.000974002944650333*(1.0 - cos(theta)**2)*(1.87776596918584e+23*cos(theta)**67 - 3.03046756048897e+24*cos(theta)**65 + 2.33458241696928e+25*cos(theta)**63 - 1.14271665672707e+26*cos(theta)**61 + 3.99078527063079e+26*cos(theta)**59 - 1.05864086791462e+27*cos(theta)**57 + 2.21731079421487e+27*cos(theta)**55 - 3.76309317646752e+27*cos(theta)**53 + 5.26986015972789e+27*cos(theta)**51 - 6.16994646800097e+27*cos(theta)**49 + 6.09735886249507e+27*cos(theta)**47 - 5.12140243228996e+27*cos(theta)**45 + 3.67404957099062e+27*cos(theta)**43 - 2.25845252730057e+27*cos(theta)**41 + 1.19171883679953e+27*cos(theta)**39 - 5.4010009667795e+26*cos(theta)**37 + 2.10109032936633e+26*cos(theta)**35 - 7.00363443122109e+25*cos(theta)**33 + 1.99456255646426e+25*cos(theta)**31 - 4.8330984302026e+24*cos(theta)**29 + 9.91029274071847e+23*cos(theta)**27 - 1.70766458124309e+23*cos(theta)**25 + 2.45119317881784e+22*cos(theta)**23 - 2.89926074913938e+21*cos(theta)**21 + 2.78775072032633e+20*cos(theta)**19 - 2.14249605921709e+19*cos(theta)**17 + 1.28814970845943e+18*cos(theta)**15 - 5.89349539818041e+16*cos(theta)**13 + 1.97802341247019e+15*cos(theta)**11 - 46313873003772.0*cos(theta)**9 + 703501868411.727*cos(theta)**7 - 6189165997.75713*cos(theta)**5 + 25788191.6573214*cos(theta)**3 - 32114.8090377601*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl69_m3(theta, phi):
    return 1.40235065051115e-5*(1.0 - cos(theta)**2)**1.5*(1.25810319935451e+25*cos(theta)**66 - 1.96980391431783e+26*cos(theta)**64 + 1.47078692269064e+27*cos(theta)**62 - 6.97057160603511e+27*cos(theta)**60 + 2.35456330967217e+28*cos(theta)**58 - 6.03425294711332e+28*cos(theta)**56 + 1.21952093681818e+29*cos(theta)**54 - 1.99443938352778e+29*cos(theta)**52 + 2.68762868146122e+29*cos(theta)**50 - 3.02327376932047e+29*cos(theta)**48 + 2.86575866537268e+29*cos(theta)**46 - 2.30463109453048e+29*cos(theta)**44 + 1.57984131552597e+29*cos(theta)**42 - 9.25965536193232e+28*cos(theta)**40 + 4.64770346351815e+28*cos(theta)**38 - 1.99837035770842e+28*cos(theta)**36 + 7.35381615278214e+27*cos(theta)**34 - 2.31119936230296e+27*cos(theta)**32 + 6.1831439250392e+26*cos(theta)**30 - 1.40159854475876e+26*cos(theta)**28 + 2.67577903999399e+25*cos(theta)**26 - 4.26916145310774e+24*cos(theta)**24 + 5.63774431128103e+23*cos(theta)**22 - 6.0884475731927e+22*cos(theta)**20 + 5.29672636862002e+21*cos(theta)**18 - 3.64224330066905e+20*cos(theta)**16 + 1.93222456268915e+19*cos(theta)**14 - 7.66154401763454e+17*cos(theta)**12 + 2.17582575371721e+16*cos(theta)**10 - 416824857033948.0*cos(theta)**8 + 4924513078882.09*cos(theta)**6 - 30945829988.7856*cos(theta)**4 + 77364574.9719641*cos(theta)**2 - 32114.8090377601)*cos(3*phi)

#@torch.jit.script
def Yl69_m4(theta, phi):
    return 2.02033423196773e-7*(1.0 - cos(theta)**2)**2*(8.30348111573977e+26*cos(theta)**65 - 1.26067450516341e+28*cos(theta)**63 + 9.118878920682e+28*cos(theta)**61 - 4.18234296362107e+29*cos(theta)**59 + 1.36564671960986e+30*cos(theta)**57 - 3.37918165038346e+30*cos(theta)**55 + 6.58541305881816e+30*cos(theta)**53 - 1.03710847943445e+31*cos(theta)**51 + 1.34381434073061e+31*cos(theta)**49 - 1.45117140927383e+31*cos(theta)**47 + 1.31824898607143e+31*cos(theta)**45 - 1.01403768159341e+31*cos(theta)**43 + 6.63533352520906e+30*cos(theta)**41 - 3.70386214477293e+30*cos(theta)**39 + 1.7661273161369e+30*cos(theta)**37 - 7.1941332877503e+29*cos(theta)**35 + 2.50029749194593e+29*cos(theta)**33 - 7.39583795936947e+28*cos(theta)**31 + 1.85494317751176e+28*cos(theta)**29 - 3.92447592532451e+27*cos(theta)**27 + 6.95702550398437e+26*cos(theta)**25 - 1.02459874874586e+26*cos(theta)**23 + 1.24030374848183e+25*cos(theta)**21 - 1.21768951463854e+24*cos(theta)**19 + 9.53410746351604e+22*cos(theta)**17 - 5.82758928107048e+21*cos(theta)**15 + 2.70511438776481e+20*cos(theta)**13 - 9.19385282116145e+18*cos(theta)**11 + 2.17582575371721e+17*cos(theta)**9 - 3.33459885627159e+15*cos(theta)**7 + 29547078473292.5*cos(theta)**5 - 123783319955.143*cos(theta)**3 + 154729149.943928*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl69_m5(theta, phi):
    return 2.91306841423075e-9*(1.0 - cos(theta)**2)**2.5*(5.39726272523085e+28*cos(theta)**64 - 7.94224938252948e+29*cos(theta)**62 + 5.56251614161602e+30*cos(theta)**60 - 2.46758234853643e+31*cos(theta)**58 + 7.78418630177618e+31*cos(theta)**56 - 1.8585499077109e+32*cos(theta)**54 + 3.49026892117362e+32*cos(theta)**52 - 5.28925324511568e+32*cos(theta)**50 + 6.58469026957999e+32*cos(theta)**48 - 6.82050562358699e+32*cos(theta)**46 + 5.93212043732146e+32*cos(theta)**44 - 4.36036203085167e+32*cos(theta)**42 + 2.72048674533572e+32*cos(theta)**40 - 1.44450623646144e+32*cos(theta)**38 + 6.53467106970652e+31*cos(theta)**36 - 2.51794665071261e+31*cos(theta)**34 + 8.25098172342156e+30*cos(theta)**32 - 2.29270976740453e+30*cos(theta)**30 + 5.3793352147841e+29*cos(theta)**28 - 1.05960849983762e+29*cos(theta)**26 + 1.73925637599609e+28*cos(theta)**24 - 2.35657712211547e+27*cos(theta)**22 + 2.60463787181184e+26*cos(theta)**20 - 2.31361007781322e+25*cos(theta)**18 + 1.62079826879773e+24*cos(theta)**16 - 8.74138392160572e+22*cos(theta)**14 + 3.51664870409425e+21*cos(theta)**12 - 1.01132381032776e+20*cos(theta)**10 + 1.95824317834549e+18*cos(theta)**8 - 2.33421919939011e+16*cos(theta)**6 + 147735392366463.0*cos(theta)**4 - 371349959865.428*cos(theta)**2 + 154729149.943928)*cos(5*phi)

#@torch.jit.script
def Yl69_m6(theta, phi):
    return 4.2046520828098e-11*(1.0 - cos(theta)**2)**3*(3.45424814414774e+30*cos(theta)**63 - 4.92419461716828e+31*cos(theta)**61 + 3.33750968496961e+32*cos(theta)**59 - 1.43119776215113e+33*cos(theta)**57 + 4.35914432899466e+33*cos(theta)**55 - 1.00361695016389e+34*cos(theta)**53 + 1.81493983901028e+34*cos(theta)**51 - 2.64462662255784e+34*cos(theta)**49 + 3.1606513293984e+34*cos(theta)**47 - 3.13743258685002e+34*cos(theta)**45 + 2.61013299242144e+34*cos(theta)**43 - 1.8313520529577e+34*cos(theta)**41 + 1.08819469813429e+34*cos(theta)**39 - 5.48912369855348e+33*cos(theta)**37 + 2.35248158509435e+33*cos(theta)**35 - 8.56101861242286e+32*cos(theta)**33 + 2.6403141514949e+32*cos(theta)**31 - 6.8781293022136e+31*cos(theta)**29 + 1.50621386013955e+31*cos(theta)**27 - 2.75498209957781e+30*cos(theta)**25 + 4.17421530239062e+29*cos(theta)**23 - 5.18446966865403e+28*cos(theta)**21 + 5.20927574362367e+27*cos(theta)**19 - 4.1644981400638e+26*cos(theta)**17 + 2.59327723007636e+25*cos(theta)**15 - 1.2237937490248e+24*cos(theta)**13 + 4.2199784449131e+22*cos(theta)**11 - 1.01132381032776e+21*cos(theta)**9 + 1.56659454267639e+19*cos(theta)**7 - 1.40053151963407e+17*cos(theta)**5 + 590941569465851.0*cos(theta)**3 - 742699919730.855*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl69_m7(theta, phi):
    return 6.07649289897455e-13*(1.0 - cos(theta)**2)**3.5*(2.17617633081308e+32*cos(theta)**62 - 3.00375871647265e+33*cos(theta)**60 + 1.96913071413207e+34*cos(theta)**58 - 8.15782724426144e+34*cos(theta)**56 + 2.39752938094706e+35*cos(theta)**54 - 5.3191698358686e+35*cos(theta)**52 + 9.25619317895245e+35*cos(theta)**50 - 1.29586704505334e+36*cos(theta)**48 + 1.48550612481725e+36*cos(theta)**46 - 1.41184466408251e+36*cos(theta)**44 + 1.12235718674122e+36*cos(theta)**42 - 7.50854341712657e+35*cos(theta)**40 + 4.24395932272372e+35*cos(theta)**38 - 2.03097576846479e+35*cos(theta)**36 + 8.23368554783022e+34*cos(theta)**34 - 2.82513614209954e+34*cos(theta)**32 + 8.18497386963419e+33*cos(theta)**30 - 1.99465749764195e+33*cos(theta)**28 + 4.06677742237678e+32*cos(theta)**26 - 6.88745524894452e+31*cos(theta)**24 + 9.60069519549843e+30*cos(theta)**22 - 1.08873863041735e+30*cos(theta)**20 + 9.89762391288498e+28*cos(theta)**18 - 7.07964683810847e+27*cos(theta)**16 + 3.88991584511454e+26*cos(theta)**14 - 1.59093187373224e+25*cos(theta)**12 + 4.64197628940441e+23*cos(theta)**10 - 9.10191429294983e+21*cos(theta)**8 + 1.09661617987347e+20*cos(theta)**6 - 7.00265759817033e+17*cos(theta)**4 + 1.77282470839755e+15*cos(theta)**2 - 742699919730.855)*cos(7*phi)

#@torch.jit.script
def Yl69_m8(theta, phi):
    return 8.7945128414917e-15*(1.0 - cos(theta)**2)**4*(1.34922932510411e+34*cos(theta)**61 - 1.80225522988359e+35*cos(theta)**59 + 1.1420958141966e+36*cos(theta)**57 - 4.5683832567864e+36*cos(theta)**55 + 1.29466586571141e+37*cos(theta)**53 - 2.76596831465167e+37*cos(theta)**51 + 4.62809658947622e+37*cos(theta)**49 - 6.22016181625604e+37*cos(theta)**47 + 6.83332817415933e+37*cos(theta)**45 - 6.21211652196303e+37*cos(theta)**43 + 4.71390018431312e+37*cos(theta)**41 - 3.00341736685063e+37*cos(theta)**39 + 1.61270454263501e+37*cos(theta)**37 - 7.31151276647323e+36*cos(theta)**35 + 2.79945308626227e+36*cos(theta)**33 - 9.04043565471854e+35*cos(theta)**31 + 2.45549216089026e+35*cos(theta)**29 - 5.58504099339745e+34*cos(theta)**27 + 1.05736212981796e+34*cos(theta)**25 - 1.65298925974669e+33*cos(theta)**23 + 2.11215294300965e+32*cos(theta)**21 - 2.17747726083469e+31*cos(theta)**19 + 1.7815723043193e+30*cos(theta)**17 - 1.13274349409735e+29*cos(theta)**15 + 5.44588218316036e+27*cos(theta)**13 - 1.90911824847869e+26*cos(theta)**11 + 4.64197628940441e+24*cos(theta)**9 - 7.28153143435986e+22*cos(theta)**7 + 6.57969707924084e+20*cos(theta)**5 - 2.80106303926813e+18*cos(theta)**3 + 3.5456494167951e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl69_m9(theta, phi):
    return 1.27496883327931e-16*(1.0 - cos(theta)**2)**4.5*(8.23029888313506e+35*cos(theta)**60 - 1.06333058563132e+37*cos(theta)**58 + 6.50994614092063e+37*cos(theta)**56 - 2.51261079123252e+38*cos(theta)**54 + 6.8617290882705e+38*cos(theta)**52 - 1.41064384047235e+39*cos(theta)**50 + 2.26776732884335e+39*cos(theta)**48 - 2.92347605364034e+39*cos(theta)**46 + 3.0749976783717e+39*cos(theta)**44 - 2.6712101044441e+39*cos(theta)**42 + 1.93269907556838e+39*cos(theta)**40 - 1.17133277307175e+39*cos(theta)**38 + 5.96700680774954e+38*cos(theta)**36 - 2.55902946826563e+38*cos(theta)**34 + 9.2381951846655e+37*cos(theta)**32 - 2.80253505296275e+37*cos(theta)**30 + 7.12092726658174e+36*cos(theta)**28 - 1.50796106821731e+36*cos(theta)**26 + 2.64340532454491e+35*cos(theta)**24 - 3.80187529741738e+34*cos(theta)**22 + 4.43552118032027e+33*cos(theta)**20 - 4.13720679558592e+32*cos(theta)**18 + 3.0286729173428e+31*cos(theta)**16 - 1.69911524114603e+30*cos(theta)**14 + 7.07964683810847e+28*cos(theta)**12 - 2.10003007332656e+27*cos(theta)**10 + 4.17777866046397e+25*cos(theta)**8 - 5.09707200405191e+23*cos(theta)**6 + 3.28984853962042e+21*cos(theta)**4 - 8.4031891178044e+18*cos(theta)**2 + 3.5456494167951e+15)*cos(9*phi)

#@torch.jit.script
def Yl69_m10(theta, phi):
    return 1.85186957979692e-18*(1.0 - cos(theta)**2)**5*(4.93817932988104e+37*cos(theta)**59 - 6.16731739666165e+38*cos(theta)**57 + 3.64556983891555e+39*cos(theta)**55 - 1.35680982726556e+40*cos(theta)**53 + 3.56809912590066e+40*cos(theta)**51 - 7.05321920236176e+40*cos(theta)**49 + 1.08852831784481e+41*cos(theta)**47 - 1.34479898467456e+41*cos(theta)**45 + 1.35299897848355e+41*cos(theta)**43 - 1.12190824386652e+41*cos(theta)**41 + 7.73079630227352e+40*cos(theta)**39 - 4.45106453767263e+40*cos(theta)**37 + 2.14812245078984e+40*cos(theta)**35 - 8.70070019210315e+39*cos(theta)**33 + 2.95622245909296e+39*cos(theta)**31 - 8.40760515888824e+38*cos(theta)**29 + 1.99385963464289e+38*cos(theta)**27 - 3.92069877736501e+37*cos(theta)**25 + 6.34417277890778e+36*cos(theta)**23 - 8.36412565431823e+35*cos(theta)**21 + 8.87104236064055e+34*cos(theta)**19 - 7.44697223205466e+33*cos(theta)**17 + 4.84587666774848e+32*cos(theta)**15 - 2.37876133760445e+31*cos(theta)**13 + 8.49557620573016e+29*cos(theta)**11 - 2.10003007332656e+28*cos(theta)**9 + 3.34222292837118e+26*cos(theta)**7 - 3.05824320243114e+24*cos(theta)**5 + 1.31593941584817e+22*cos(theta)**3 - 1.68063782356088e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl69_m11(theta, phi):
    return 2.69550038614936e-20*(1.0 - cos(theta)**2)**5.5*(2.91352580462981e+39*cos(theta)**58 - 3.51537091609714e+40*cos(theta)**56 + 2.00506341140355e+41*cos(theta)**54 - 7.19109208450748e+41*cos(theta)**52 + 1.81973055420934e+42*cos(theta)**50 - 3.45607740915726e+42*cos(theta)**48 + 5.1160830938706e+42*cos(theta)**46 - 6.05159543103551e+42*cos(theta)**44 + 5.81789560747926e+42*cos(theta)**42 - 4.59982379985275e+42*cos(theta)**40 + 3.01501055788667e+42*cos(theta)**38 - 1.64689387893887e+42*cos(theta)**36 + 7.51842857776443e+41*cos(theta)**34 - 2.87123106339404e+41*cos(theta)**32 + 9.16428962318818e+40*cos(theta)**30 - 2.43820549607759e+40*cos(theta)**28 + 5.3834210135358e+39*cos(theta)**26 - 9.80174694341252e+38*cos(theta)**24 + 1.45915973914879e+38*cos(theta)**22 - 1.75646638740683e+37*cos(theta)**20 + 1.6854980485217e+36*cos(theta)**18 - 1.26598527944929e+35*cos(theta)**16 + 7.26881500162273e+33*cos(theta)**14 - 3.09238973888578e+32*cos(theta)**12 + 9.34513382630318e+30*cos(theta)**10 - 1.8900270659939e+29*cos(theta)**8 + 2.33955604985982e+27*cos(theta)**6 - 1.52912160121557e+25*cos(theta)**4 + 3.9478182475445e+22*cos(theta)**2 - 1.68063782356088e+19)*cos(11*phi)

#@torch.jit.script
def Yl69_m12(theta, phi):
    return 3.93262822752531e-22*(1.0 - cos(theta)**2)**6*(1.68984496668529e+41*cos(theta)**57 - 1.9686077130144e+42*cos(theta)**55 + 1.08273424215792e+43*cos(theta)**53 - 3.73936788394389e+43*cos(theta)**51 + 9.09865277104668e+43*cos(theta)**49 - 1.65891715639549e+44*cos(theta)**47 + 2.35339822318047e+44*cos(theta)**45 - 2.66270198965562e+44*cos(theta)**43 + 2.44351615514129e+44*cos(theta)**41 - 1.8399295199411e+44*cos(theta)**39 + 1.14570401199694e+44*cos(theta)**37 - 5.92881796417995e+43*cos(theta)**35 + 2.55626571643991e+43*cos(theta)**33 - 9.18793940286092e+42*cos(theta)**31 + 2.74928688695645e+42*cos(theta)**29 - 6.82697538901725e+41*cos(theta)**27 + 1.39968946351931e+41*cos(theta)**25 - 2.352419266419e+40*cos(theta)**23 + 3.21015142612734e+39*cos(theta)**21 - 3.51293277481366e+38*cos(theta)**19 + 3.03389648733907e+37*cos(theta)**17 - 2.02557644711887e+36*cos(theta)**15 + 1.01763410022718e+35*cos(theta)**13 - 3.71086768666293e+33*cos(theta)**11 + 9.34513382630318e+31*cos(theta)**9 - 1.51202165279512e+30*cos(theta)**7 + 1.40373362991589e+28*cos(theta)**5 - 6.11648640486229e+25*cos(theta)**3 + 7.89563649508901e+22*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl69_m13(theta, phi):
    return 5.75226040218542e-24*(1.0 - cos(theta)**2)**6.5*(9.63211631010616e+42*cos(theta)**56 - 1.08273424215792e+44*cos(theta)**54 + 5.73849148343697e+44*cos(theta)**52 - 1.90707762081138e+45*cos(theta)**50 + 4.45833985781287e+45*cos(theta)**48 - 7.79691063505879e+45*cos(theta)**46 + 1.05902920043121e+46*cos(theta)**44 - 1.14496185555192e+46*cos(theta)**42 + 1.00184162360793e+46*cos(theta)**40 - 7.17572512777028e+45*cos(theta)**38 + 4.23910484438866e+45*cos(theta)**36 - 2.07508628746298e+45*cos(theta)**34 + 8.43567686425169e+44*cos(theta)**32 - 2.84826121488689e+44*cos(theta)**30 + 7.97293197217372e+43*cos(theta)**28 - 1.84328335503466e+43*cos(theta)**26 + 3.49922365879827e+42*cos(theta)**24 - 5.41056431276371e+41*cos(theta)**22 + 6.74131799486741e+40*cos(theta)**20 - 6.67457227214595e+39*cos(theta)**18 + 5.15762402847641e+38*cos(theta)**16 - 3.0383646706783e+37*cos(theta)**14 + 1.32292433029534e+36*cos(theta)**12 - 4.08195445532923e+34*cos(theta)**10 + 8.41062044367286e+32*cos(theta)**8 - 1.05841515695658e+31*cos(theta)**6 + 7.01866814957947e+28*cos(theta)**4 - 1.83494592145869e+26*cos(theta)**2 + 7.89563649508901e+22)*cos(13*phi)

#@torch.jit.script
def Yl69_m14(theta, phi):
    return 8.43733860488851e-26*(1.0 - cos(theta)**2)**7*(5.39398513365945e+44*cos(theta)**55 - 5.84676490765276e+45*cos(theta)**53 + 2.98401557138722e+46*cos(theta)**51 - 9.53538810405692e+46*cos(theta)**49 + 2.14000313175018e+47*cos(theta)**47 - 3.58657889212704e+47*cos(theta)**45 + 4.65972848189734e+47*cos(theta)**43 - 4.80883979331805e+47*cos(theta)**41 + 4.00736649443171e+47*cos(theta)**39 - 2.72677554855271e+47*cos(theta)**37 + 1.52607774397992e+47*cos(theta)**35 - 7.05529337737414e+46*cos(theta)**33 + 2.69941659656054e+46*cos(theta)**31 - 8.54478364466066e+45*cos(theta)**29 + 2.23242095220864e+45*cos(theta)**27 - 4.79253672309011e+44*cos(theta)**25 + 8.39813678111585e+43*cos(theta)**23 - 1.19032414880802e+43*cos(theta)**21 + 1.34826359897348e+42*cos(theta)**19 - 1.20142300898627e+41*cos(theta)**17 + 8.25219844556226e+39*cos(theta)**15 - 4.25371053894962e+38*cos(theta)**13 + 1.5875091963544e+37*cos(theta)**11 - 4.08195445532923e+35*cos(theta)**9 + 6.72849635493829e+33*cos(theta)**7 - 6.35049094173951e+31*cos(theta)**5 + 2.80746725983179e+29*cos(theta)**3 - 3.66989184291737e+26*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl69_m15(theta, phi):
    return 1.24132210914335e-27*(1.0 - cos(theta)**2)**7.5*(2.9666918235127e+46*cos(theta)**54 - 3.09878540105596e+47*cos(theta)**52 + 1.52184794140748e+48*cos(theta)**50 - 4.67234017098789e+48*cos(theta)**48 + 1.00580147192258e+49*cos(theta)**46 - 1.61396050145717e+49*cos(theta)**44 + 2.00368324721586e+49*cos(theta)**42 - 1.9716243152604e+49*cos(theta)**40 + 1.56287293282837e+49*cos(theta)**38 - 1.0089069529645e+49*cos(theta)**36 + 5.34127210392971e+48*cos(theta)**34 - 2.32824681453347e+48*cos(theta)**32 + 8.36819144933767e+47*cos(theta)**30 - 2.47798725695159e+47*cos(theta)**28 + 6.02753657096333e+46*cos(theta)**26 - 1.19813418077253e+46*cos(theta)**24 + 1.93157145965664e+45*cos(theta)**22 - 2.49968071249683e+44*cos(theta)**20 + 2.56170083804961e+43*cos(theta)**18 - 2.04241911527666e+42*cos(theta)**16 + 1.23782976683434e+41*cos(theta)**14 - 5.5298237006345e+39*cos(theta)**12 + 1.74626011598984e+38*cos(theta)**10 - 3.67375900979631e+36*cos(theta)**8 + 4.7099474484568e+34*cos(theta)**6 - 3.17524547086975e+32*cos(theta)**4 + 8.42240177949537e+29*cos(theta)**2 - 3.66989184291737e+26)*cos(15*phi)

#@torch.jit.script
def Yl69_m16(theta, phi):
    return 1.83222222934563e-29*(1.0 - cos(theta)**2)**8*(1.60201358469686e+48*cos(theta)**53 - 1.6113684085491e+49*cos(theta)**51 + 7.60923970703742e+49*cos(theta)**49 - 2.24272328207419e+50*cos(theta)**47 + 4.62668677084388e+50*cos(theta)**45 - 7.10142620641154e+50*cos(theta)**43 + 8.41546963830659e+50*cos(theta)**41 - 7.88649726104161e+50*cos(theta)**39 + 5.9389171447478e+50*cos(theta)**37 - 3.63206503067221e+50*cos(theta)**35 + 1.8160325153361e+50*cos(theta)**33 - 7.45038980650709e+49*cos(theta)**31 + 2.5104574348013e+49*cos(theta)**29 - 6.93836431946446e+48*cos(theta)**27 + 1.56715950845047e+48*cos(theta)**25 - 2.87552203385407e+47*cos(theta)**23 + 4.24945721124462e+46*cos(theta)**21 - 4.99936142499367e+45*cos(theta)**19 + 4.61106150848931e+44*cos(theta)**17 - 3.26787058444266e+43*cos(theta)**15 + 1.73296167356807e+42*cos(theta)**13 - 6.63578844076141e+40*cos(theta)**11 + 1.74626011598984e+39*cos(theta)**9 - 2.93900720783704e+37*cos(theta)**7 + 2.82596846907408e+35*cos(theta)**5 - 1.2700981883479e+33*cos(theta)**3 + 1.68448035589907e+30*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl69_m17(theta, phi):
    return 2.71388216826562e-31*(1.0 - cos(theta)**2)**8.5*(8.49067199889334e+49*cos(theta)**52 - 8.21797888360041e+50*cos(theta)**50 + 3.72852745644834e+51*cos(theta)**48 - 1.05407994257487e+52*cos(theta)**46 + 2.08200904687975e+52*cos(theta)**44 - 3.05361326875696e+52*cos(theta)**42 + 3.4503425517057e+52*cos(theta)**40 - 3.07573393180623e+52*cos(theta)**38 + 2.19739934355668e+52*cos(theta)**36 - 1.27122276073527e+52*cos(theta)**34 + 5.99290730060914e+51*cos(theta)**32 - 2.3096208400172e+51*cos(theta)**30 + 7.28032656092378e+50*cos(theta)**28 - 1.8733583662554e+50*cos(theta)**26 + 3.91789877112616e+49*cos(theta)**24 - 6.61370067786435e+48*cos(theta)**22 + 8.9238601436137e+47*cos(theta)**20 - 9.49878670748797e+46*cos(theta)**18 + 7.83880456443182e+45*cos(theta)**16 - 4.90180587666398e+44*cos(theta)**14 + 2.2528501756385e+43*cos(theta)**12 - 7.29936728483755e+41*cos(theta)**10 + 1.57163410439086e+40*cos(theta)**8 - 2.05730504548593e+38*cos(theta)**6 + 1.41298423453704e+36*cos(theta)**4 - 3.8102945650437e+33*cos(theta)**2 + 1.68448035589907e+30)*cos(17*phi)

#@torch.jit.script
def Yl69_m18(theta, phi):
    return 4.03487132532308e-33*(1.0 - cos(theta)**2)**9*(4.41514943942454e+51*cos(theta)**51 - 4.10898944180021e+52*cos(theta)**49 + 1.7896931790952e+53*cos(theta)**47 - 4.84876773584439e+53*cos(theta)**45 + 9.16083980627089e+53*cos(theta)**43 - 1.28251757287792e+54*cos(theta)**41 + 1.38013702068228e+54*cos(theta)**39 - 1.16877889408637e+54*cos(theta)**37 + 7.91063763680406e+53*cos(theta)**35 - 4.32215738649992e+53*cos(theta)**33 + 1.91773033619492e+53*cos(theta)**31 - 6.92886252005159e+52*cos(theta)**29 + 2.03849143705866e+52*cos(theta)**27 - 4.87073175226405e+51*cos(theta)**25 + 9.4029570507028e+50*cos(theta)**23 - 1.45501414913016e+50*cos(theta)**21 + 1.78477202872274e+49*cos(theta)**19 - 1.70978160734783e+48*cos(theta)**17 + 1.25420873030909e+47*cos(theta)**15 - 6.86252822732958e+45*cos(theta)**13 + 2.7034202107662e+44*cos(theta)**11 - 7.29936728483755e+42*cos(theta)**9 + 1.25730728351269e+41*cos(theta)**7 - 1.23438302729156e+39*cos(theta)**5 + 5.65193693814816e+36*cos(theta)**3 - 7.62058913008741e+33*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl69_m19(theta, phi):
    return 6.02286689259109e-35*(1.0 - cos(theta)**2)**9.5*(2.25172621410651e+53*cos(theta)**50 - 2.0134048264821e+54*cos(theta)**48 + 8.41155794174744e+54*cos(theta)**46 - 2.18194548112998e+55*cos(theta)**44 + 3.93916111669648e+55*cos(theta)**42 - 5.25832204879949e+55*cos(theta)**40 + 5.3825343806609e+55*cos(theta)**38 - 4.32448190811956e+55*cos(theta)**36 + 2.76872317288142e+55*cos(theta)**34 - 1.42631193754498e+55*cos(theta)**32 + 5.94496404220427e+54*cos(theta)**30 - 2.00937013081496e+54*cos(theta)**28 + 5.50392688005837e+53*cos(theta)**26 - 1.21768293806601e+53*cos(theta)**24 + 2.16268012166164e+52*cos(theta)**22 - 3.05552971317333e+51*cos(theta)**20 + 3.39106685457321e+50*cos(theta)**18 - 2.90662873249132e+49*cos(theta)**16 + 1.88131309546364e+48*cos(theta)**14 - 8.92128669552845e+46*cos(theta)**12 + 2.97376223184282e+45*cos(theta)**10 - 6.56943055635379e+43*cos(theta)**8 + 8.80115098458881e+41*cos(theta)**6 - 6.17191513645779e+39*cos(theta)**4 + 1.69558108144445e+37*cos(theta)**2 - 7.62058913008741e+33)*cos(19*phi)

#@torch.jit.script
def Yl69_m20(theta, phi):
    return 9.02865918920212e-37*(1.0 - cos(theta)**2)**10*(1.12586310705326e+55*cos(theta)**49 - 9.66434316711409e+55*cos(theta)**47 + 3.86931665320382e+56*cos(theta)**45 - 9.6005601169719e+56*cos(theta)**43 + 1.65444766901252e+57*cos(theta)**41 - 2.1033288195198e+57*cos(theta)**39 + 2.04536306465114e+57*cos(theta)**37 - 1.55681348692304e+57*cos(theta)**35 + 9.41365878779684e+56*cos(theta)**33 - 4.56419820014392e+56*cos(theta)**31 + 1.78348921266128e+56*cos(theta)**29 - 5.62623636628189e+55*cos(theta)**27 + 1.43102098881518e+55*cos(theta)**25 - 2.92243905135843e+54*cos(theta)**23 + 4.75789626765561e+53*cos(theta)**21 - 6.11105942634666e+52*cos(theta)**19 + 6.10392033823177e+51*cos(theta)**17 - 4.65060597198611e+50*cos(theta)**15 + 2.63383833364909e+49*cos(theta)**13 - 1.07055440346341e+48*cos(theta)**11 + 2.97376223184282e+46*cos(theta)**9 - 5.25554444508303e+44*cos(theta)**7 + 5.28069059075329e+42*cos(theta)**5 - 2.46876605458312e+40*cos(theta)**3 + 3.3911621628889e+37*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl69_m21(theta, phi):
    return 1.35957748834704e-38*(1.0 - cos(theta)**2)**10.5*(5.51672922456096e+56*cos(theta)**48 - 4.54224128854362e+57*cos(theta)**46 + 1.74119249394172e+58*cos(theta)**44 - 4.12824085029791e+58*cos(theta)**42 + 6.78323544295135e+58*cos(theta)**40 - 8.20298239612721e+58*cos(theta)**38 + 7.56784333920922e+58*cos(theta)**36 - 5.44884720423064e+58*cos(theta)**34 + 3.10650739997296e+58*cos(theta)**32 - 1.41490144204462e+58*cos(theta)**30 + 5.17211871671771e+57*cos(theta)**28 - 1.51908381889611e+57*cos(theta)**26 + 3.57755247203794e+56*cos(theta)**24 - 6.72160981812439e+55*cos(theta)**22 + 9.99158216207679e+54*cos(theta)**20 - 1.16110129100587e+54*cos(theta)**18 + 1.0376664574994e+53*cos(theta)**16 - 6.97590895797916e+51*cos(theta)**14 + 3.42398983374382e+50*cos(theta)**12 - 1.17760984380976e+49*cos(theta)**10 + 2.67638600865854e+47*cos(theta)**8 - 3.67888111155812e+45*cos(theta)**6 + 2.64034529537664e+43*cos(theta)**4 - 7.40629816374935e+40*cos(theta)**2 + 3.3911621628889e+37)*cos(21*phi)

#@torch.jit.script
def Yl69_m22(theta, phi):
    return 2.05713432186081e-40*(1.0 - cos(theta)**2)**11*(2.64803002778926e+58*cos(theta)**47 - 2.08943099273007e+59*cos(theta)**45 + 7.66124697334357e+59*cos(theta)**43 - 1.73386115712512e+60*cos(theta)**41 + 2.71329417718054e+60*cos(theta)**39 - 3.11713331052834e+60*cos(theta)**37 + 2.72442360211532e+60*cos(theta)**35 - 1.85260804943842e+60*cos(theta)**33 + 9.94082367991346e+59*cos(theta)**31 - 4.24470432613385e+59*cos(theta)**29 + 1.44819324068096e+59*cos(theta)**27 - 3.94961792912989e+58*cos(theta)**25 + 8.58612593289106e+57*cos(theta)**23 - 1.47875415998737e+57*cos(theta)**21 + 1.99831643241536e+56*cos(theta)**19 - 2.08998232381056e+55*cos(theta)**17 + 1.66026633199904e+54*cos(theta)**15 - 9.76627254117083e+52*cos(theta)**13 + 4.10878780049258e+51*cos(theta)**11 - 1.17760984380976e+50*cos(theta)**9 + 2.14110880692683e+48*cos(theta)**7 - 2.20732866693487e+46*cos(theta)**5 + 1.05613811815066e+44*cos(theta)**3 - 1.48125963274987e+41*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl69_m23(theta, phi):
    return 3.12838220973394e-42*(1.0 - cos(theta)**2)**11.5*(1.24457411306095e+60*cos(theta)**46 - 9.40243946728529e+60*cos(theta)**44 + 3.29433619853774e+61*cos(theta)**42 - 7.10883074421301e+61*cos(theta)**40 + 1.05818472910041e+62*cos(theta)**38 - 1.15333932489549e+62*cos(theta)**36 + 9.53548260740362e+61*cos(theta)**34 - 6.11360656314678e+61*cos(theta)**32 + 3.08165534077317e+61*cos(theta)**30 - 1.23096425457882e+61*cos(theta)**28 + 3.91012174983859e+60*cos(theta)**26 - 9.87404482282472e+59*cos(theta)**24 + 1.97480896456494e+59*cos(theta)**22 - 3.10538373597347e+58*cos(theta)**20 + 3.79680122158918e+57*cos(theta)**18 - 3.55296995047795e+56*cos(theta)**16 + 2.49039949799856e+55*cos(theta)**14 - 1.26961543035221e+54*cos(theta)**12 + 4.51966658054184e+52*cos(theta)**10 - 1.05984885942878e+51*cos(theta)**8 + 1.49877616484878e+49*cos(theta)**6 - 1.10366433346744e+47*cos(theta)**4 + 3.16841435445197e+44*cos(theta)**2 - 1.48125963274987e+41)*cos(23*phi)

#@torch.jit.script
def Yl69_m24(theta, phi):
    return 4.78298938892577e-44*(1.0 - cos(theta)**2)**12*(5.72504092008038e+61*cos(theta)**45 - 4.13707336560553e+62*cos(theta)**43 + 1.38362120338585e+63*cos(theta)**41 - 2.8435322976852e+63*cos(theta)**39 + 4.02110197058156e+63*cos(theta)**37 - 4.15202156962375e+63*cos(theta)**35 + 3.24206408651723e+63*cos(theta)**33 - 1.95635410020697e+63*cos(theta)**31 + 9.24496602231952e+62*cos(theta)**29 - 3.44669991282068e+62*cos(theta)**27 + 1.01663165495803e+62*cos(theta)**25 - 2.36977075747793e+61*cos(theta)**23 + 4.34457972204288e+60*cos(theta)**21 - 6.21076747194693e+59*cos(theta)**19 + 6.83424219886052e+58*cos(theta)**17 - 5.68475192076472e+57*cos(theta)**15 + 3.48655929719799e+56*cos(theta)**13 - 1.52353851642265e+55*cos(theta)**11 + 4.51966658054184e+53*cos(theta)**9 - 8.47879087543024e+51*cos(theta)**7 + 8.99265698909268e+49*cos(theta)**5 - 4.41465733386975e+47*cos(theta)**3 + 6.33682870890395e+44*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl69_m25(theta, phi):
    return 7.35409496492504e-46*(1.0 - cos(theta)**2)**12.5*(2.57626841403617e+63*cos(theta)**44 - 1.77894154721038e+64*cos(theta)**42 + 5.67284693388198e+64*cos(theta)**40 - 1.10897759609723e+65*cos(theta)**38 + 1.48780772911518e+65*cos(theta)**36 - 1.45320754936831e+65*cos(theta)**34 + 1.06988114855069e+65*cos(theta)**32 - 6.0646977106416e+64*cos(theta)**30 + 2.68104014647266e+64*cos(theta)**28 - 9.30608976461584e+63*cos(theta)**26 + 2.54157913739508e+63*cos(theta)**24 - 5.45047274219925e+62*cos(theta)**22 + 9.12361741629004e+61*cos(theta)**20 - 1.18004581966992e+61*cos(theta)**18 + 1.16182117380629e+60*cos(theta)**16 - 8.52712788114708e+58*cos(theta)**14 + 4.53252708635738e+57*cos(theta)**12 - 1.67589236806491e+56*cos(theta)**10 + 4.06769992248766e+54*cos(theta)**8 - 5.93515361280117e+52*cos(theta)**6 + 4.49632849454634e+50*cos(theta)**4 - 1.32439720016092e+48*cos(theta)**2 + 6.33682870890395e+44)*cos(25*phi)

#@torch.jit.script
def Yl69_m26(theta, phi):
    return 1.13747298988002e-47*(1.0 - cos(theta)**2)**13*(1.13355810217591e+65*cos(theta)**43 - 7.47155449828359e+65*cos(theta)**41 + 2.26913877355279e+66*cos(theta)**39 - 4.21411486516947e+66*cos(theta)**37 + 5.35610782481463e+66*cos(theta)**35 - 4.94090566785226e+66*cos(theta)**33 + 3.4236196753622e+66*cos(theta)**31 - 1.81940931319248e+66*cos(theta)**29 + 7.50691241012345e+65*cos(theta)**27 - 2.41958333880012e+65*cos(theta)**25 + 6.0997899297482e+64*cos(theta)**23 - 1.19910400328383e+64*cos(theta)**21 + 1.82472348325801e+63*cos(theta)**19 - 2.12408247540585e+62*cos(theta)**17 + 1.85891387809006e+61*cos(theta)**15 - 1.19379790336059e+60*cos(theta)**13 + 5.43903250362886e+58*cos(theta)**11 - 1.67589236806491e+57*cos(theta)**9 + 3.25415993799013e+55*cos(theta)**7 - 3.5610921676807e+53*cos(theta)**5 + 1.79853139781854e+51*cos(theta)**3 - 2.64879440032185e+48*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl69_m27(theta, phi):
    return 1.7703993786841e-49*(1.0 - cos(theta)**2)**13.5*(4.87429983935643e+66*cos(theta)**42 - 3.06333734429627e+67*cos(theta)**40 + 8.84964121685589e+67*cos(theta)**38 - 1.5592225001127e+68*cos(theta)**36 + 1.87463773868512e+68*cos(theta)**34 - 1.63049887039125e+68*cos(theta)**32 + 1.06132209936228e+68*cos(theta)**30 - 5.2762870082582e+67*cos(theta)**28 + 2.02686635073333e+67*cos(theta)**26 - 6.0489583470003e+66*cos(theta)**24 + 1.40295168384209e+66*cos(theta)**22 - 2.51811840689605e+65*cos(theta)**20 + 3.46697461819022e+64*cos(theta)**18 - 3.61094020818995e+63*cos(theta)**16 + 2.78837081713509e+62*cos(theta)**14 - 1.55193727436877e+61*cos(theta)**12 + 5.98293575399175e+59*cos(theta)**10 - 1.50830313125842e+58*cos(theta)**8 + 2.27791195659309e+56*cos(theta)**6 - 1.78054608384035e+54*cos(theta)**4 + 5.39559419345561e+51*cos(theta)**2 - 2.64879440032185e+48)*cos(27*phi)

#@torch.jit.script
def Yl69_m28(theta, phi):
    return 2.77370798116249e-51*(1.0 - cos(theta)**2)**14*(2.0472059325297e+68*cos(theta)**41 - 1.22533493771851e+69*cos(theta)**39 + 3.36286366240524e+69*cos(theta)**37 - 5.61320100040574e+69*cos(theta)**35 + 6.37376831152942e+69*cos(theta)**33 - 5.21759638525199e+69*cos(theta)**31 + 3.18396629808684e+69*cos(theta)**29 - 1.47736036231229e+69*cos(theta)**27 + 5.26985251190666e+68*cos(theta)**25 - 1.45175000328007e+68*cos(theta)**23 + 3.08649370445259e+67*cos(theta)**21 - 5.0362368137921e+66*cos(theta)**19 + 6.24055431274239e+65*cos(theta)**17 - 5.77750433310391e+64*cos(theta)**15 + 3.90371914398913e+63*cos(theta)**13 - 1.86232472924252e+62*cos(theta)**11 + 5.98293575399175e+60*cos(theta)**9 - 1.20664250500674e+59*cos(theta)**7 + 1.36674717395585e+57*cos(theta)**5 - 7.1221843353614e+54*cos(theta)**3 + 1.07911883869112e+52*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl69_m29(theta, phi):
    return 4.37578293208222e-53*(1.0 - cos(theta)**2)**14.5*(8.39354432337178e+69*cos(theta)**40 - 4.77880625710218e+70*cos(theta)**38 + 1.24425955508994e+71*cos(theta)**36 - 1.96462035014201e+71*cos(theta)**34 + 2.10334354280471e+71*cos(theta)**32 - 1.61745487942812e+71*cos(theta)**30 + 9.23350226445184e+70*cos(theta)**28 - 3.9888729782432e+70*cos(theta)**26 + 1.31746312797667e+70*cos(theta)**24 - 3.33902500754417e+69*cos(theta)**22 + 6.48163677935044e+68*cos(theta)**20 - 9.568849946205e+67*cos(theta)**18 + 1.06089423316621e+67*cos(theta)**16 - 8.66625649965587e+65*cos(theta)**14 + 5.07483488718587e+64*cos(theta)**12 - 2.04855720216677e+63*cos(theta)**10 + 5.38464217859257e+61*cos(theta)**8 - 8.44649753504717e+59*cos(theta)**6 + 6.83373586977926e+57*cos(theta)**4 - 2.13665530060842e+55*cos(theta)**2 + 1.07911883869112e+52)*cos(29*phi)

#@torch.jit.script
def Yl69_m30(theta, phi):
    return 6.95357554066631e-55*(1.0 - cos(theta)**2)**15*(3.35741772934871e+71*cos(theta)**39 - 1.81594637769883e+72*cos(theta)**37 + 4.47933439832378e+72*cos(theta)**35 - 6.67970919048283e+72*cos(theta)**33 + 6.73069933697506e+72*cos(theta)**31 - 4.85236463828435e+72*cos(theta)**29 + 2.58538063404652e+72*cos(theta)**27 - 1.03710697434323e+72*cos(theta)**25 + 3.161911507144e+71*cos(theta)**23 - 7.34585501659716e+70*cos(theta)**21 + 1.29632735587009e+70*cos(theta)**19 - 1.7223929903169e+69*cos(theta)**17 + 1.69743077306593e+68*cos(theta)**15 - 1.21327590995182e+67*cos(theta)**13 + 6.08980186462304e+65*cos(theta)**11 - 2.04855720216677e+64*cos(theta)**9 + 4.30771374287406e+62*cos(theta)**7 - 5.0678985210283e+60*cos(theta)**5 + 2.73349434791171e+58*cos(theta)**3 - 4.27331060121684e+55*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl69_m31(theta, phi):
    return 1.11346321367111e-56*(1.0 - cos(theta)**2)**15.5*(1.309392914446e+73*cos(theta)**38 - 6.71900159748567e+73*cos(theta)**36 + 1.56776703941332e+74*cos(theta)**34 - 2.20430403285933e+74*cos(theta)**32 + 2.08651679446227e+74*cos(theta)**30 - 1.40718574510246e+74*cos(theta)**28 + 6.98052771192559e+73*cos(theta)**26 - 2.59276743585808e+73*cos(theta)**24 + 7.27239646643119e+72*cos(theta)**22 - 1.5426295534854e+72*cos(theta)**20 + 2.46302197615317e+71*cos(theta)**18 - 2.92806808353873e+70*cos(theta)**16 + 2.5461461595989e+69*cos(theta)**14 - 1.57725868293737e+68*cos(theta)**12 + 6.69878205108535e+66*cos(theta)**10 - 1.8437014819501e+65*cos(theta)**8 + 3.01539962001184e+63*cos(theta)**6 - 2.53394926051415e+61*cos(theta)**4 + 8.20048304373512e+58*cos(theta)**2 - 4.27331060121684e+55)*cos(31*phi)

#@torch.jit.script
def Yl69_m32(theta, phi):
    return 1.79731164551872e-58*(1.0 - cos(theta)**2)**16*(4.97569307489479e+74*cos(theta)**37 - 2.41884057509484e+75*cos(theta)**35 + 5.3304079340053e+75*cos(theta)**33 - 7.05377290514987e+75*cos(theta)**31 + 6.25955038338681e+75*cos(theta)**29 - 3.94012008628689e+75*cos(theta)**27 + 1.81493720510065e+75*cos(theta)**25 - 6.22264184605939e+74*cos(theta)**23 + 1.59992722261486e+74*cos(theta)**21 - 3.08525910697081e+73*cos(theta)**19 + 4.4334395570757e+72*cos(theta)**17 - 4.68490893366197e+71*cos(theta)**15 + 3.56460462343845e+70*cos(theta)**13 - 1.89271041952484e+69*cos(theta)**11 + 6.69878205108535e+67*cos(theta)**9 - 1.47496118556008e+66*cos(theta)**7 + 1.8092397720071e+64*cos(theta)**5 - 1.01357970420566e+62*cos(theta)**3 + 1.64009660874702e+59*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl69_m33(theta, phi):
    return 2.92565047691658e-60*(1.0 - cos(theta)**2)**16.5*(1.84100643771107e+76*cos(theta)**36 - 8.46594201283194e+76*cos(theta)**34 + 1.75903461822175e+77*cos(theta)**32 - 2.18666960059646e+77*cos(theta)**30 + 1.81526961118217e+77*cos(theta)**28 - 1.06383242329746e+77*cos(theta)**26 + 4.53734301275163e+76*cos(theta)**24 - 1.43120762459366e+76*cos(theta)**22 + 3.35984716749121e+75*cos(theta)**20 - 5.86199230324454e+74*cos(theta)**18 + 7.53684724702869e+73*cos(theta)**16 - 7.02736340049295e+72*cos(theta)**14 + 4.63398601046999e+71*cos(theta)**12 - 2.08198146147733e+70*cos(theta)**10 + 6.02890384597682e+68*cos(theta)**8 - 1.03247282989205e+67*cos(theta)**6 + 9.04619886003552e+64*cos(theta)**4 - 3.04073911261698e+62*cos(theta)**2 + 1.64009660874702e+59)*cos(33*phi)

#@torch.jit.script
def Yl69_m34(theta, phi):
    return 4.80454845430205e-62*(1.0 - cos(theta)**2)**17*(6.62762317575986e+77*cos(theta)**35 - 2.87842028436286e+78*cos(theta)**33 + 5.62891077830959e+78*cos(theta)**31 - 6.56000880178937e+78*cos(theta)**29 + 5.08275491131009e+78*cos(theta)**27 - 2.7659643005734e+78*cos(theta)**25 + 1.08896232306039e+78*cos(theta)**23 - 3.14865677410605e+77*cos(theta)**21 + 6.71969433498242e+76*cos(theta)**19 - 1.05515861458402e+76*cos(theta)**17 + 1.20589555952459e+75*cos(theta)**15 - 9.83830876069013e+73*cos(theta)**13 + 5.56078321256399e+72*cos(theta)**11 - 2.08198146147733e+71*cos(theta)**9 + 4.82312307678145e+69*cos(theta)**7 - 6.19483697935232e+67*cos(theta)**5 + 3.61847954401421e+65*cos(theta)**3 - 6.08147822523396e+62*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl69_m35(theta, phi):
    return 7.96346151917664e-64*(1.0 - cos(theta)**2)**17.5*(2.31966811151595e+79*cos(theta)**34 - 9.49878693839744e+79*cos(theta)**32 + 1.74496234127597e+80*cos(theta)**30 - 1.90240255251892e+80*cos(theta)**28 + 1.37234382605372e+80*cos(theta)**26 - 6.91491075143349e+79*cos(theta)**24 + 2.5046133430389e+79*cos(theta)**22 - 6.6121792256227e+78*cos(theta)**20 + 1.27674192364666e+78*cos(theta)**18 - 1.79376964479283e+77*cos(theta)**16 + 1.80884333928689e+76*cos(theta)**14 - 1.27898013888972e+75*cos(theta)**12 + 6.11686153382039e+73*cos(theta)**10 - 1.87378331532959e+72*cos(theta)**8 + 3.37618615374702e+70*cos(theta)**6 - 3.09741848967616e+68*cos(theta)**4 + 1.08554386320426e+66*cos(theta)**2 - 6.08147822523396e+62)*cos(35*phi)

#@torch.jit.script
def Yl69_m36(theta, phi):
    return 1.3328085735637e-65*(1.0 - cos(theta)**2)**18*(7.88687157915424e+80*cos(theta)**33 - 3.03961182028718e+81*cos(theta)**31 + 5.23488702382792e+81*cos(theta)**29 - 5.32672714705297e+81*cos(theta)**27 + 3.56809394773968e+81*cos(theta)**25 - 1.65957858034404e+81*cos(theta)**23 + 5.51014935468559e+80*cos(theta)**21 - 1.32243584512454e+80*cos(theta)**19 + 2.29813546256399e+79*cos(theta)**17 - 2.87003143166853e+78*cos(theta)**15 + 2.53238067500164e+77*cos(theta)**13 - 1.53477616666766e+76*cos(theta)**11 + 6.11686153382039e+74*cos(theta)**9 - 1.49902665226368e+73*cos(theta)**7 + 2.02571169224821e+71*cos(theta)**5 - 1.23896739587046e+69*cos(theta)**3 + 2.17108772640852e+66*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl69_m37(theta, phi):
    return 2.25350162298453e-67*(1.0 - cos(theta)**2)**18.5*(2.6026676211209e+82*cos(theta)**32 - 9.42279664289026e+82*cos(theta)**30 + 1.5181172369101e+83*cos(theta)**28 - 1.4382163297043e+83*cos(theta)**26 + 8.9202348693492e+82*cos(theta)**24 - 3.81703073479129e+82*cos(theta)**22 + 1.15713136448397e+82*cos(theta)**20 - 2.51262810573663e+81*cos(theta)**18 + 3.90683028635878e+80*cos(theta)**16 - 4.30504714750279e+79*cos(theta)**14 + 3.29209487750213e+78*cos(theta)**12 - 1.68825378333443e+77*cos(theta)**10 + 5.50517538043835e+75*cos(theta)**8 - 1.04931865658457e+74*cos(theta)**6 + 1.0128558461241e+72*cos(theta)**4 - 3.71690218761139e+69*cos(theta)**2 + 2.17108772640852e+66)*cos(37*phi)

#@torch.jit.script
def Yl69_m38(theta, phi):
    return 3.85115498999865e-69*(1.0 - cos(theta)**2)**19*(8.32853638758687e+83*cos(theta)**31 - 2.82683899286708e+84*cos(theta)**29 + 4.25072826334827e+84*cos(theta)**27 - 3.73936245723119e+84*cos(theta)**25 + 2.14085636864381e+84*cos(theta)**23 - 8.39746761654083e+83*cos(theta)**21 + 2.31426272896795e+83*cos(theta)**19 - 4.52273059032593e+82*cos(theta)**17 + 6.25092845817405e+81*cos(theta)**15 - 6.0270660065039e+80*cos(theta)**13 + 3.95051385300256e+79*cos(theta)**11 - 1.68825378333443e+78*cos(theta)**9 + 4.40414030435068e+76*cos(theta)**7 - 6.29591193950744e+74*cos(theta)**5 + 4.05142338449642e+72*cos(theta)**3 - 7.43380437522279e+69*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl69_m39(theta, phi):
    return 6.65576948924773e-71*(1.0 - cos(theta)**2)**19.5*(2.58184628015193e+85*cos(theta)**30 - 8.19783307931452e+85*cos(theta)**28 + 1.14769663110403e+86*cos(theta)**26 - 9.34840614307797e+85*cos(theta)**24 + 4.92396964788076e+85*cos(theta)**22 - 1.76346819947357e+85*cos(theta)**20 + 4.3970991850391e+84*cos(theta)**18 - 7.68864200355408e+83*cos(theta)**16 + 9.37639268726107e+82*cos(theta)**14 - 7.83518580845507e+81*cos(theta)**12 + 4.34556523830281e+80*cos(theta)**10 - 1.51942840500098e+79*cos(theta)**8 + 3.08289821304547e+77*cos(theta)**6 - 3.14795596975372e+75*cos(theta)**4 + 1.21542701534893e+73*cos(theta)**2 - 7.43380437522279e+69)*cos(39*phi)

#@torch.jit.script
def Yl69_m40(theta, phi):
    return 1.16392339110742e-72*(1.0 - cos(theta)**2)**20*(7.74553884045579e+86*cos(theta)**29 - 2.29539326220807e+87*cos(theta)**27 + 2.98401124087049e+87*cos(theta)**25 - 2.24361747433871e+87*cos(theta)**23 + 1.08327332253377e+87*cos(theta)**21 - 3.52693639894715e+86*cos(theta)**19 + 7.91477853307038e+85*cos(theta)**17 - 1.23018272056865e+85*cos(theta)**15 + 1.31269497621655e+84*cos(theta)**13 - 9.40222297014609e+82*cos(theta)**11 + 4.34556523830281e+81*cos(theta)**9 - 1.21554272400079e+80*cos(theta)**7 + 1.84973892782728e+78*cos(theta)**5 - 1.25918238790149e+76*cos(theta)**3 + 2.43085403069785e+73*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl69_m41(theta, phi):
    return 2.06076777575783e-74*(1.0 - cos(theta)**2)**20.5*(2.24620626373218e+88*cos(theta)**28 - 6.19756180796178e+88*cos(theta)**26 + 7.46002810217622e+88*cos(theta)**24 - 5.16032019097904e+88*cos(theta)**22 + 2.27487397732091e+88*cos(theta)**20 - 6.70117915799958e+87*cos(theta)**18 + 1.34551235062196e+87*cos(theta)**16 - 1.84527408085298e+86*cos(theta)**14 + 1.70650346908152e+85*cos(theta)**12 - 1.03424452671607e+84*cos(theta)**10 + 3.91100871447253e+82*cos(theta)**8 - 8.50879906800551e+80*cos(theta)**6 + 9.24869463913642e+78*cos(theta)**4 - 3.77754716370446e+76*cos(theta)**2 + 2.43085403069785e+73)*cos(41*phi)

#@torch.jit.script
def Yl69_m42(theta, phi):
    return 3.69648160726526e-76*(1.0 - cos(theta)**2)**21*(6.2893775384501e+89*cos(theta)**27 - 1.61136607007006e+90*cos(theta)**25 + 1.79040674452229e+90*cos(theta)**23 - 1.13527044201539e+90*cos(theta)**21 + 4.54974795464182e+89*cos(theta)**19 - 1.20621224843993e+89*cos(theta)**17 + 2.15281976099514e+88*cos(theta)**15 - 2.58338371319417e+87*cos(theta)**13 + 2.04780416289782e+86*cos(theta)**11 - 1.03424452671607e+85*cos(theta)**9 + 3.12880697157803e+83*cos(theta)**7 - 5.10527944080331e+81*cos(theta)**5 + 3.69947785565457e+79*cos(theta)**3 - 7.55509432740892e+76*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl69_m43(theta, phi):
    return 6.72198681361313e-78*(1.0 - cos(theta)**2)**21.5*(1.69813193538153e+91*cos(theta)**26 - 4.02841517517516e+91*cos(theta)**24 + 4.11793551240127e+91*cos(theta)**22 - 2.38406792823232e+91*cos(theta)**20 + 8.64452111381946e+90*cos(theta)**18 - 2.05056082234787e+90*cos(theta)**16 + 3.22922964149271e+89*cos(theta)**14 - 3.35839882715242e+88*cos(theta)**12 + 2.2525845791876e+87*cos(theta)**10 - 9.30820074044463e+85*cos(theta)**8 + 2.19016488010462e+84*cos(theta)**6 - 2.55263972040165e+82*cos(theta)**4 + 1.10984335669637e+80*cos(theta)**2 - 7.55509432740892e+76)*cos(43*phi)

#@torch.jit.script
def Yl69_m44(theta, phi):
    return 1.2401429835105e-79*(1.0 - cos(theta)**2)**22*(4.41514303199197e+92*cos(theta)**25 - 9.66819642042038e+92*cos(theta)**23 + 9.0594581272828e+92*cos(theta)**21 - 4.76813585646463e+92*cos(theta)**19 + 1.5560138004875e+92*cos(theta)**17 - 3.2808973157566e+91*cos(theta)**15 + 4.5209214980898e+90*cos(theta)**13 - 4.03007859258291e+89*cos(theta)**11 + 2.2525845791876e+88*cos(theta)**9 - 7.4465605923557e+86*cos(theta)**7 + 1.31409892806277e+85*cos(theta)**5 - 1.02105588816066e+83*cos(theta)**3 + 2.21968671339274e+80*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl69_m45(theta, phi):
    return 2.32300064537706e-81*(1.0 - cos(theta)**2)**22.5*(1.10378575799799e+94*cos(theta)**24 - 2.22368517669669e+94*cos(theta)**22 + 1.90248620672939e+94*cos(theta)**20 - 9.0594581272828e+93*cos(theta)**18 + 2.64522346082876e+93*cos(theta)**16 - 4.92134597363489e+92*cos(theta)**14 + 5.87719794751674e+91*cos(theta)**12 - 4.4330864518412e+90*cos(theta)**10 + 2.02732612126884e+89*cos(theta)**8 - 5.21259241464899e+87*cos(theta)**6 + 6.57049464031385e+85*cos(theta)**4 - 3.06316766448198e+83*cos(theta)**2 + 2.21968671339274e+80)*cos(45*phi)

#@torch.jit.script
def Yl69_m46(theta, phi):
    return 4.42175615909734e-83*(1.0 - cos(theta)**2)**23*(2.64908581919518e+95*cos(theta)**23 - 4.89210738873271e+95*cos(theta)**21 + 3.80497241345878e+95*cos(theta)**19 - 1.6307024629109e+95*cos(theta)**17 + 4.23235753732601e+94*cos(theta)**15 - 6.88988436308885e+93*cos(theta)**13 + 7.05263753702008e+92*cos(theta)**11 - 4.4330864518412e+91*cos(theta)**9 + 1.62186089701507e+90*cos(theta)**7 - 3.12755544878939e+88*cos(theta)**5 + 2.62819785612554e+86*cos(theta)**3 - 6.12633532896397e+83*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl69_m47(theta, phi):
    return 8.56055411150962e-85*(1.0 - cos(theta)**2)**23.5*(6.09289738414892e+96*cos(theta)**22 - 1.02734255163387e+97*cos(theta)**20 + 7.22944758557167e+96*cos(theta)**18 - 2.77219418694854e+96*cos(theta)**16 + 6.34853630598901e+95*cos(theta)**14 - 8.95684967201551e+94*cos(theta)**12 + 7.75790129072209e+93*cos(theta)**10 - 3.98977780665708e+92*cos(theta)**8 + 1.13530262791055e+91*cos(theta)**6 - 1.5637777243947e+89*cos(theta)**4 + 7.88459356837663e+86*cos(theta)**2 - 6.12633532896397e+83)*cos(47*phi)

#@torch.jit.script
def Yl69_m48(theta, phi):
    return 1.68732058755698e-86*(1.0 - cos(theta)**2)**24*(1.34043742451276e+98*cos(theta)**21 - 2.05468510326774e+98*cos(theta)**19 + 1.3013005654029e+98*cos(theta)**17 - 4.43551069911766e+97*cos(theta)**15 + 8.88795082838462e+96*cos(theta)**13 - 1.07482196064186e+96*cos(theta)**11 + 7.75790129072209e+94*cos(theta)**9 - 3.19182224532566e+93*cos(theta)**7 + 6.8118157674633e+91*cos(theta)**5 - 6.25511089757879e+89*cos(theta)**3 + 1.57691871367533e+87*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl69_m49(theta, phi):
    return 3.38958832010567e-88*(1.0 - cos(theta)**2)**24.5*(2.8149185914768e+99*cos(theta)**20 - 3.9039016962087e+99*cos(theta)**18 + 2.21221096118493e+99*cos(theta)**16 - 6.65326604867649e+98*cos(theta)**14 + 1.15543360769e+98*cos(theta)**12 - 1.18230415670605e+97*cos(theta)**10 + 6.98211116164988e+95*cos(theta)**8 - 2.23427557172796e+94*cos(theta)**6 + 3.40590788373165e+92*cos(theta)**4 - 1.87653326927364e+90*cos(theta)**2 + 1.57691871367533e+87)*cos(49*phi)

#@torch.jit.script
def Yl69_m50(theta, phi):
    return 6.94797866131853e-90*(1.0 - cos(theta)**2)**25*(5.6298371829536e+100*cos(theta)**19 - 7.02702305317567e+100*cos(theta)**17 + 3.53953753789589e+100*cos(theta)**15 - 9.31457246814708e+99*cos(theta)**13 + 1.386520329228e+99*cos(theta)**11 - 1.18230415670605e+98*cos(theta)**9 + 5.58568892931991e+96*cos(theta)**7 - 1.34056534303678e+95*cos(theta)**5 + 1.36236315349266e+93*cos(theta)**3 - 3.75306653854727e+90*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl69_m51(theta, phi):
    return 1.45509400851028e-91*(1.0 - cos(theta)**2)**25.5*(1.06966906476118e+102*cos(theta)**18 - 1.19459391903986e+102*cos(theta)**16 + 5.30930630684384e+101*cos(theta)**14 - 1.21089442085912e+101*cos(theta)**12 + 1.5251723621508e+100*cos(theta)**10 - 1.06407374103544e+99*cos(theta)**8 + 3.90998225052394e+97*cos(theta)**6 - 6.70282671518389e+95*cos(theta)**4 + 4.08708946047798e+93*cos(theta)**2 - 3.75306653854727e+90)*cos(51*phi)

#@torch.jit.script
def Yl69_m52(theta, phi):
    return 3.11789951721678e-93*(1.0 - cos(theta)**2)**26*(1.92540431657013e+103*cos(theta)**17 - 1.91135027046378e+103*cos(theta)**15 + 7.43302882958137e+102*cos(theta)**13 - 1.45307330503094e+102*cos(theta)**11 + 1.5251723621508e+101*cos(theta)**9 - 8.51258992828354e+99*cos(theta)**7 + 2.34598935031436e+98*cos(theta)**5 - 2.68113068607356e+96*cos(theta)**3 + 8.17417892095596e+93*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl69_m53(theta, phi):
    return 6.84632858112973e-95*(1.0 - cos(theta)**2)**26.5*(3.27318733816923e+104*cos(theta)**16 - 2.86702540569567e+104*cos(theta)**14 + 9.66293747845578e+103*cos(theta)**12 - 1.59838063553404e+103*cos(theta)**10 + 1.37265512593572e+102*cos(theta)**8 - 5.95881294979848e+100*cos(theta)**6 + 1.17299467515718e+99*cos(theta)**4 - 8.04339205822067e+96*cos(theta)**2 + 8.17417892095596e+93)*cos(53*phi)

#@torch.jit.script
def Yl69_m54(theta, phi):
    return 1.54328164764011e-96*(1.0 - cos(theta)**2)**27*(5.23709974107076e+105*cos(theta)**15 - 4.01383556797394e+105*cos(theta)**13 + 1.15955249741469e+105*cos(theta)**11 - 1.59838063553404e+104*cos(theta)**9 + 1.09812410074858e+103*cos(theta)**7 - 3.57528776987909e+101*cos(theta)**5 + 4.69197870062872e+99*cos(theta)**3 - 1.60867841164413e+97*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl69_m55(theta, phi):
    return 3.57839863561779e-98*(1.0 - cos(theta)**2)**27.5*(7.85564961160614e+106*cos(theta)**14 - 5.21798623836612e+106*cos(theta)**12 + 1.27550774715616e+106*cos(theta)**10 - 1.43854257198064e+105*cos(theta)**8 + 7.68686870524004e+103*cos(theta)**6 - 1.78764388493954e+102*cos(theta)**4 + 1.40759361018862e+100*cos(theta)**2 - 1.60867841164413e+97)*cos(55*phi)

#@torch.jit.script
def Yl69_m56(theta, phi):
    return 8.55400884978709e-100*(1.0 - cos(theta)**2)**28*(1.09979094562486e+108*cos(theta)**13 - 6.26158348603935e+107*cos(theta)**11 + 1.27550774715616e+107*cos(theta)**9 - 1.15083405758451e+106*cos(theta)**7 + 4.61212122314402e+104*cos(theta)**5 - 7.15057553975817e+102*cos(theta)**3 + 2.81518722037723e+100*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl69_m57(theta, phi):
    return 2.11355107153923e-101*(1.0 - cos(theta)**2)**28.5*(1.42972822931232e+109*cos(theta)**12 - 6.88774183464328e+108*cos(theta)**10 + 1.14795697244055e+108*cos(theta)**8 - 8.05583840309156e+106*cos(theta)**6 + 2.30606061157201e+105*cos(theta)**4 - 2.14517266192745e+103*cos(theta)**2 + 2.81518722037723e+100)*cos(57*phi)

#@torch.jit.script
def Yl69_m58(theta, phi):
    return 5.41402507685722e-103*(1.0 - cos(theta)**2)**29*(1.71567387517478e+110*cos(theta)**11 - 6.88774183464328e+109*cos(theta)**9 + 9.18365577952438e+108*cos(theta)**7 - 4.83350304185493e+107*cos(theta)**5 + 9.22424244628804e+105*cos(theta)**3 - 4.2903453238549e+103*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl69_m59(theta, phi):
    return 1.4428425309415e-104*(1.0 - cos(theta)**2)**29.5*(1.88724126269226e+111*cos(theta)**10 - 6.19896765117895e+110*cos(theta)**8 + 6.42855904566706e+109*cos(theta)**6 - 2.41675152092747e+108*cos(theta)**4 + 2.76727273388641e+106*cos(theta)**2 - 4.2903453238549e+103)*cos(59*phi)

#@torch.jit.script
def Yl69_m60(theta, phi):
    return 4.01720579458844e-106*(1.0 - cos(theta)**2)**30*(1.88724126269226e+112*cos(theta)**9 - 4.95917412094316e+111*cos(theta)**7 + 3.85713542740024e+110*cos(theta)**5 - 9.66700608370987e+108*cos(theta)**3 + 5.53454546777283e+106*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl69_m61(theta, phi):
    return 1.17444085245015e-107*(1.0 - cos(theta)**2)**30.5*(1.69851713642303e+113*cos(theta)**8 - 3.47142188466021e+112*cos(theta)**6 + 1.92856771370012e+111*cos(theta)**4 - 2.90010182511296e+109*cos(theta)**2 + 5.53454546777283e+106)*cos(61*phi)

#@torch.jit.script
def Yl69_m62(theta, phi):
    return 3.6278599088397e-109*(1.0 - cos(theta)**2)**31*(1.35881370913843e+114*cos(theta)**7 - 2.08285313079613e+113*cos(theta)**5 + 7.71427085480048e+111*cos(theta)**3 - 5.80020365022592e+109*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl69_m63(theta, phi):
    return 1.19347828804884e-110*(1.0 - cos(theta)**2)**31.5*(9.51169596396899e+114*cos(theta)**6 - 1.04142656539806e+114*cos(theta)**4 + 2.31428125644014e+112*cos(theta)**2 - 5.80020365022592e+109)*cos(63*phi)

#@torch.jit.script
def Yl69_m64(theta, phi):
    return 4.22486734237911e-112*(1.0 - cos(theta)**2)**32*(5.70701757838139e+115*cos(theta)**5 - 4.16570626159226e+114*cos(theta)**3 + 4.62856251288029e+112*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl69_m65(theta, phi):
    return 1.63220865200709e-113*(1.0 - cos(theta)**2)**32.5*(2.8535087891907e+116*cos(theta)**4 - 1.24971187847768e+115*cos(theta)**2 + 4.62856251288029e+112)*cos(65*phi)

#@torch.jit.script
def Yl69_m66(theta, phi):
    return 7.02390769639901e-115*(1.0 - cos(theta)**2)**33*(1.14140351567628e+117*cos(theta)**3 - 2.49942375695535e+115*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl69_m67(theta, phi):
    return 3.47735247384222e-116*(1.0 - cos(theta)**2)**33.5*(3.42421054702884e+117*cos(theta)**2 - 2.49942375695535e+115)*cos(67*phi)

#@torch.jit.script
def Yl69_m68(theta, phi):
    return 14.3867894923659*(1.0 - cos(theta)**2)**34*cos(68*phi)*cos(theta)

#@torch.jit.script
def Yl69_m69(theta, phi):
    return 1.22468485120279*(1.0 - cos(theta)**2)**34.5*cos(69*phi)

#@torch.jit.script
def Yl70_m_minus_70(theta, phi):
    return 1.22905094295194*(1.0 - cos(theta)**2)**35*sin(70*phi)

#@torch.jit.script
def Yl70_m_minus_69(theta, phi):
    return 14.542326871995*(1.0 - cos(theta)**2)**34.5*sin(69*phi)*cos(theta)

#@torch.jit.script
def Yl70_m_minus_68(theta, phi):
    return 2.54712960481231e-118*(1.0 - cos(theta)**2)**34*(4.75965266037008e+119*cos(theta)**2 - 3.42421054702884e+117)*sin(68*phi)

#@torch.jit.script
def Yl70_m_minus_67(theta, phi):
    return 5.18264204688737e-117*(1.0 - cos(theta)**2)**33.5*(1.58655088679003e+119*cos(theta)**3 - 3.42421054702884e+117*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl70_m_minus_66(theta, phi):
    return 1.21322539806989e-115*(1.0 - cos(theta)**2)**33*(3.96637721697507e+118*cos(theta)**4 - 1.71210527351442e+117*cos(theta)**2 + 6.24855939238839e+114)*sin(66*phi)

#@torch.jit.script
def Yl70_m_minus_65(theta, phi):
    return 3.16370477326006e-114*(1.0 - cos(theta)**2)**32.5*(7.93275443395014e+117*cos(theta)**5 - 5.70701757838139e+116*cos(theta)**3 + 6.24855939238839e+114*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl70_m_minus_64(theta, phi):
    return 9.00406163506351e-113*(1.0 - cos(theta)**2)**32*(1.32212573899169e+117*cos(theta)**6 - 1.42675439459535e+116*cos(theta)**4 + 3.12427969619419e+114*cos(theta)**2 - 7.71427085480048e+111)*sin(64*phi)

#@torch.jit.script
def Yl70_m_minus_63(theta, phi):
    return 2.75765465786572e-111*(1.0 - cos(theta)**2)**31.5*(1.88875105570241e+116*cos(theta)**7 - 2.8535087891907e+115*cos(theta)**5 + 1.04142656539806e+114*cos(theta)**3 - 7.71427085480048e+111*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl70_m_minus_62(theta, phi):
    return 8.99519727500161e-110*(1.0 - cos(theta)**2)**31*(2.36093881962802e+115*cos(theta)**8 - 4.75584798198449e+114*cos(theta)**6 + 2.60356641349516e+113*cos(theta)**4 - 3.85713542740024e+111*cos(theta)**2 + 7.2502545627824e+108)*sin(62*phi)

#@torch.jit.script
def Yl70_m_minus_61(theta, phi):
    return 3.10040845585289e-108*(1.0 - cos(theta)**2)**30.5*(2.62326535514224e+114*cos(theta)**9 - 6.79406854569213e+113*cos(theta)**7 + 5.20713282699032e+112*cos(theta)**5 - 1.28571180913341e+111*cos(theta)**3 + 7.2502545627824e+108*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl70_m_minus_60(theta, phi):
    return 1.12215942258632e-106*(1.0 - cos(theta)**2)**30*(2.62326535514224e+113*cos(theta)**10 - 8.49258568211517e+112*cos(theta)**8 + 8.67855471165054e+111*cos(theta)**6 - 3.21427952283353e+110*cos(theta)**4 + 3.6251272813912e+108*cos(theta)**2 - 5.53454546777283e+105)*sin(60*phi)

#@torch.jit.script
def Yl70_m_minus_59(theta, phi):
    return 4.24348409997014e-105*(1.0 - cos(theta)**2)**29.5*(2.38478668649295e+112*cos(theta)**11 - 9.4362063134613e+111*cos(theta)**9 + 1.23979353023579e+111*cos(theta)**7 - 6.42855904566706e+109*cos(theta)**5 + 1.20837576046373e+108*cos(theta)**3 - 5.53454546777283e+105*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl70_m_minus_58(theta, phi):
    return 1.66958316686443e-103*(1.0 - cos(theta)**2)**29*(1.98732223874412e+111*cos(theta)**12 - 9.4362063134613e+110*cos(theta)**10 + 1.54974191279474e+110*cos(theta)**8 - 1.07142650761118e+109*cos(theta)**6 + 3.02093940115933e+107*cos(theta)**4 - 2.76727273388641e+105*cos(theta)**2 + 3.57528776987909e+102)*sin(58*phi)

#@torch.jit.script
def Yl70_m_minus_57(theta, phi):
    return 6.81058971792623e-102*(1.0 - cos(theta)**2)**28.5*(1.52870941441855e+110*cos(theta)**13 - 8.5783693758739e+109*cos(theta)**11 + 1.72193545866082e+109*cos(theta)**9 - 1.5306092965874e+108*cos(theta)**7 + 6.04187880231867e+106*cos(theta)**5 - 9.22424244628804e+104*cos(theta)**3 + 3.57528776987909e+102*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl70_m_minus_56(theta, phi):
    return 2.87177623153215e-100*(1.0 - cos(theta)**2)**28*(1.09193529601325e+109*cos(theta)**14 - 7.14864114656159e+108*cos(theta)**12 + 1.72193545866082e+108*cos(theta)**10 - 1.91326162073424e+107*cos(theta)**8 + 1.00697980038644e+106*cos(theta)**6 - 2.30606061157201e+104*cos(theta)**4 + 1.78764388493954e+102*cos(theta)**2 - 2.01084801455517e+99)*sin(56*phi)

#@torch.jit.script
def Yl70_m_minus_55(theta, phi):
    return 1.24847973905654e-98*(1.0 - cos(theta)**2)**27.5*(7.27956864008836e+107*cos(theta)**15 - 5.4989547281243e+107*cos(theta)**13 + 1.56539587150984e+107*cos(theta)**11 - 2.12584624526027e+106*cos(theta)**9 + 1.43854257198064e+105*cos(theta)**7 - 4.61212122314402e+103*cos(theta)**5 + 5.95881294979848e+101*cos(theta)**3 - 2.01084801455517e+99*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl70_m_minus_54(theta, phi):
    return 5.58337113012323e-97*(1.0 - cos(theta)**2)**27*(4.54973040005522e+106*cos(theta)**16 - 3.92782480580307e+106*cos(theta)**14 + 1.30449655959153e+106*cos(theta)**12 - 2.12584624526027e+105*cos(theta)**10 + 1.79817821497579e+104*cos(theta)**8 - 7.68686870524004e+102*cos(theta)**6 + 1.48970323744962e+101*cos(theta)**4 - 1.00542400727758e+99*cos(theta)**2 + 1.00542400727758e+96)*sin(54*phi)

#@torch.jit.script
def Yl70_m_minus_53(theta, phi):
    return 2.5634910168844e-95*(1.0 - cos(theta)**2)**26.5*(2.67631200003248e+105*cos(theta)**17 - 2.61854987053538e+105*cos(theta)**15 + 1.00345889199349e+105*cos(theta)**13 - 1.93258749569116e+104*cos(theta)**11 + 1.99797579441755e+103*cos(theta)**9 - 1.09812410074858e+102*cos(theta)**7 + 2.97940647489924e+100*cos(theta)**5 - 3.35141335759194e+98*cos(theta)**3 + 1.00542400727758e+96*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl70_m_minus_52(theta, phi):
    return 1.20620356626626e-93*(1.0 - cos(theta)**2)**26*(1.48684000001805e+104*cos(theta)**18 - 1.63659366908461e+104*cos(theta)**16 + 7.16756351423918e+103*cos(theta)**14 - 1.61048957974263e+103*cos(theta)**12 + 1.99797579441755e+102*cos(theta)**10 - 1.37265512593572e+101*cos(theta)**8 + 4.9656774581654e+99*cos(theta)**6 - 8.37853339397986e+97*cos(theta)**4 + 5.02712003638792e+95*cos(theta)**2 - 4.5412105116422e+92)*sin(52*phi)

#@torch.jit.script
def Yl70_m_minus_51(theta, phi):
    return 5.80734094599917e-92*(1.0 - cos(theta)**2)**25.5*(7.82547368430551e+102*cos(theta)**19 - 9.62702158285066e+102*cos(theta)**17 + 4.77837567615945e+102*cos(theta)**15 - 1.23883813826356e+102*cos(theta)**13 + 1.81634163128868e+101*cos(theta)**11 - 1.5251723621508e+100*cos(theta)**9 + 7.09382494023628e+98*cos(theta)**7 - 1.67570667879597e+97*cos(theta)**5 + 1.67570667879597e+95*cos(theta)**3 - 4.5412105116422e+92*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl70_m_minus_50(theta, phi):
    return 2.85683400722986e-90*(1.0 - cos(theta)**2)**25*(3.91273684215275e+101*cos(theta)**20 - 5.34834532380592e+101*cos(theta)**18 + 2.98648479759966e+101*cos(theta)**16 - 8.84884384473973e+100*cos(theta)**14 + 1.5136180260739e+100*cos(theta)**12 - 1.5251723621508e+99*cos(theta)**10 + 8.86728117529535e+97*cos(theta)**8 - 2.79284446465995e+96*cos(theta)**6 + 4.18926669698993e+94*cos(theta)**4 - 2.2706052558211e+92*cos(theta)**2 + 1.87653326927364e+89)*sin(50*phi)

#@torch.jit.script
def Yl70_m_minus_49(theta, phi):
    return 1.43411928977543e-88*(1.0 - cos(theta)**2)**24.5*(1.86320802007274e+100*cos(theta)**21 - 2.8149185914768e+100*cos(theta)**19 + 1.75675576329392e+100*cos(theta)**17 - 5.89922922982649e+99*cos(theta)**15 + 1.16432155851839e+99*cos(theta)**13 - 1.386520329228e+98*cos(theta)**11 + 9.85253463921706e+96*cos(theta)**9 - 3.98977780665708e+95*cos(theta)**7 + 8.37853339397986e+93*cos(theta)**5 - 7.56868418607034e+91*cos(theta)**3 + 1.87653326927364e+89*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl70_m_minus_48(theta, phi):
    return 7.33787143759487e-87*(1.0 - cos(theta)**2)**24*(8.469127363967e+98*cos(theta)**22 - 1.4074592957384e+99*cos(theta)**20 + 9.75975424052176e+98*cos(theta)**18 - 3.68701826864155e+98*cos(theta)**16 + 8.31658256084561e+97*cos(theta)**14 - 1.15543360769e+97*cos(theta)**12 + 9.85253463921706e+95*cos(theta)**10 - 4.98722225832135e+94*cos(theta)**8 + 1.39642223232998e+93*cos(theta)**6 - 1.89217104651758e+91*cos(theta)**4 + 9.38266634636818e+88*cos(theta)**2 - 7.16781233488784e+85)*sin(48*phi)

#@torch.jit.script
def Yl70_m_minus_47(theta, phi):
    return 3.822742281856e-85*(1.0 - cos(theta)**2)**23.5*(3.68222928868131e+97*cos(theta)**23 - 6.70218712256381e+97*cos(theta)**21 + 5.13671275816935e+97*cos(theta)**19 - 2.1688342756715e+97*cos(theta)**17 + 5.54438837389707e+96*cos(theta)**15 - 8.88795082838462e+95*cos(theta)**13 + 8.95684967201551e+94*cos(theta)**11 - 5.5413580648015e+93*cos(theta)**9 + 1.99488890332854e+92*cos(theta)**7 - 3.78434209303517e+90*cos(theta)**5 + 3.12755544878939e+88*cos(theta)**3 - 7.16781233488784e+85*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl70_m_minus_46(theta, phi):
    return 2.02569274121716e-83*(1.0 - cos(theta)**2)**23*(1.53426220361721e+96*cos(theta)**24 - 3.04644869207446e+96*cos(theta)**22 + 2.56835637908467e+96*cos(theta)**20 - 1.20490793092861e+96*cos(theta)**18 + 3.46524273368567e+95*cos(theta)**16 - 6.34853630598901e+94*cos(theta)**14 + 7.46404139334626e+93*cos(theta)**12 - 5.5413580648015e+92*cos(theta)**10 + 2.49361112916067e+91*cos(theta)**8 - 6.30723682172528e+89*cos(theta)**6 + 7.81888862197349e+87*cos(theta)**4 - 3.58390616744392e+85*cos(theta)**2 + 2.55263972040165e+82)*sin(46*phi)

#@torch.jit.script
def Yl70_m_minus_45(theta, phi):
    return 1.09086892600705e-81*(1.0 - cos(theta)**2)**22.5*(6.13704881446884e+94*cos(theta)**25 - 1.32454290959759e+95*cos(theta)**23 + 1.22302684718318e+95*cos(theta)**21 - 6.34162068909796e+94*cos(theta)**19 + 2.03837807863863e+94*cos(theta)**17 - 4.23235753732601e+93*cos(theta)**15 + 5.74157030257404e+92*cos(theta)**13 - 5.03759824072863e+91*cos(theta)**11 + 2.77067903240075e+90*cos(theta)**9 - 9.0103383167504e+88*cos(theta)**7 + 1.5637777243947e+87*cos(theta)**5 - 1.19463538914797e+85*cos(theta)**3 + 2.55263972040165e+82*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl70_m_minus_44(theta, phi):
    return 5.96496864287317e-80*(1.0 - cos(theta)**2)**22*(2.36040339018032e+93*cos(theta)**26 - 5.51892878998997e+93*cos(theta)**24 + 5.55921294174172e+93*cos(theta)**22 - 3.17081034454898e+93*cos(theta)**20 + 1.13243226591035e+93*cos(theta)**18 - 2.64522346082876e+92*cos(theta)**16 + 4.10112164469575e+91*cos(theta)**14 - 4.19799853394053e+90*cos(theta)**12 + 2.77067903240075e+89*cos(theta)**10 - 1.1262922895938e+88*cos(theta)**8 + 2.6062962073245e+86*cos(theta)**6 - 2.98658847286993e+84*cos(theta)**4 + 1.27631986020083e+82*cos(theta)**2 - 8.53725658997208e+78)*sin(44*phi)

#@torch.jit.script
def Yl70_m_minus_43(theta, phi):
    return 3.30934826064584e-78*(1.0 - cos(theta)**2)**21.5*(8.74223477844564e+91*cos(theta)**27 - 2.20757151599599e+92*cos(theta)**25 + 2.41704910510509e+92*cos(theta)**23 - 1.50990968788047e+92*cos(theta)**21 + 5.96016982058079e+91*cos(theta)**19 - 1.5560138004875e+91*cos(theta)**17 + 2.73408109646383e+90*cos(theta)**15 - 3.22922964149271e+89*cos(theta)**13 + 2.51879912036432e+88*cos(theta)**11 - 1.25143587732644e+87*cos(theta)**9 + 3.72328029617785e+85*cos(theta)**7 - 5.97317694573987e+83*cos(theta)**5 + 4.25439953400276e+81*cos(theta)**3 - 8.53725658997208e+78*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl70_m_minus_42(theta, phi):
    return 1.86149001125438e-76*(1.0 - cos(theta)**2)**21*(3.12222670658773e+90*cos(theta)**28 - 8.49065967690764e+90*cos(theta)**26 + 1.00710379379379e+91*cos(theta)**24 - 6.86322585400212e+90*cos(theta)**22 + 2.98008491029039e+90*cos(theta)**20 - 8.64452111381946e+89*cos(theta)**18 + 1.70880068528989e+89*cos(theta)**16 - 2.30659260106622e+88*cos(theta)**14 + 2.09899926697026e+87*cos(theta)**12 - 1.25143587732644e+86*cos(theta)**10 + 4.65410037022231e+84*cos(theta)**8 - 9.95529490956645e+82*cos(theta)**6 + 1.06359988350069e+81*cos(theta)**4 - 4.26862829498604e+78*cos(theta)**2 + 2.69824797407462e+75)*sin(42*phi)

#@torch.jit.script
def Yl70_m_minus_41(theta, phi):
    return 1.06088600525106e-74*(1.0 - cos(theta)**2)**20.5*(1.07662989882336e+89*cos(theta)**29 - 3.14468876922505e+89*cos(theta)**27 + 4.02841517517516e+89*cos(theta)**25 - 2.98401124087049e+89*cos(theta)**23 + 1.41908805251924e+89*cos(theta)**21 - 4.54974795464182e+88*cos(theta)**19 + 1.00517687369994e+88*cos(theta)**17 - 1.53772840071082e+87*cos(theta)**15 + 1.61461482074636e+86*cos(theta)**13 - 1.13766897938768e+85*cos(theta)**11 + 5.17122263358035e+83*cos(theta)**9 - 1.42218498708092e+82*cos(theta)**7 + 2.12719976700138e+80*cos(theta)**5 - 1.42287609832868e+78*cos(theta)**3 + 2.69824797407462e+75*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl70_m_minus_40(theta, phi):
    return 6.1219649269969e-73*(1.0 - cos(theta)**2)**20*(3.58876632941118e+87*cos(theta)**30 - 1.12310313186609e+88*cos(theta)**28 + 1.54939045199045e+88*cos(theta)**26 - 1.24333801702937e+88*cos(theta)**24 + 6.4504002387238e+87*cos(theta)**22 - 2.27487397732091e+87*cos(theta)**20 + 5.58431596499965e+86*cos(theta)**18 - 9.6108025044426e+85*cos(theta)**16 + 1.15329630053311e+85*cos(theta)**14 - 9.48057482823064e+83*cos(theta)**12 + 5.17122263358035e+82*cos(theta)**10 - 1.77773123385115e+81*cos(theta)**8 + 3.5453329450023e+79*cos(theta)**6 - 3.5571902458217e+77*cos(theta)**4 + 1.34912398703731e+75*cos(theta)**2 - 8.10284676899284e+71)*sin(40*phi)

#@torch.jit.script
def Yl70_m_minus_39(theta, phi):
    return 3.57493398645019e-71*(1.0 - cos(theta)**2)**19.5*(1.15766655787458e+86*cos(theta)**31 - 3.8727694202279e+86*cos(theta)**29 + 5.73848315552017e+86*cos(theta)**27 - 4.97335206811748e+86*cos(theta)**25 + 2.80452184292339e+86*cos(theta)**23 - 1.08327332253377e+86*cos(theta)**21 + 2.93911366578929e+85*cos(theta)**19 - 5.65341323790741e+84*cos(theta)**17 + 7.68864200355408e+83*cos(theta)**15 - 7.29274986786972e+82*cos(theta)**13 + 4.70111148507304e+81*cos(theta)**11 - 1.97525692650128e+80*cos(theta)**9 + 5.06476135000328e+78*cos(theta)**7 - 7.1143804916434e+76*cos(theta)**5 + 4.49707995679103e+74*cos(theta)**3 - 8.10284676899284e+71*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl70_m_minus_38(theta, phi):
    return 2.11133071047807e-69*(1.0 - cos(theta)**2)**19*(3.61770799335805e+84*cos(theta)**32 - 1.29092314007597e+85*cos(theta)**30 + 2.04945826982863e+85*cos(theta)**28 - 1.91282771850672e+85*cos(theta)**26 + 1.16855076788475e+85*cos(theta)**24 - 4.92396964788076e+84*cos(theta)**22 + 1.46955683289465e+84*cos(theta)**20 - 3.14078513217078e+83*cos(theta)**18 + 4.8054012522213e+82*cos(theta)**16 - 5.20910704847837e+81*cos(theta)**14 + 3.91759290422754e+80*cos(theta)**12 - 1.97525692650128e+79*cos(theta)**10 + 6.3309516875041e+77*cos(theta)**8 - 1.18573008194057e+76*cos(theta)**6 + 1.12426998919776e+74*cos(theta)**4 - 4.05142338449642e+71*cos(theta)**2 + 2.32306386725712e+68)*sin(38*phi)

#@torch.jit.script
def Yl70_m_minus_37(theta, phi):
    return 1.26044851950185e-67*(1.0 - cos(theta)**2)**18.5*(1.09627514950244e+83*cos(theta)**33 - 4.16426819379344e+83*cos(theta)**31 + 7.06709748216769e+83*cos(theta)**29 - 7.08454710558045e+83*cos(theta)**27 + 4.67420307153898e+83*cos(theta)**25 - 2.14085636864381e+83*cos(theta)**23 + 6.99788968045069e+82*cos(theta)**21 - 1.65304480640568e+82*cos(theta)**19 + 2.82670661895371e+81*cos(theta)**17 - 3.47273803231892e+80*cos(theta)**15 + 3.01353300325195e+79*cos(theta)**13 - 1.79568811500116e+78*cos(theta)**11 + 7.03439076389344e+76*cos(theta)**9 - 1.69390011705795e+75*cos(theta)**7 + 2.24853997839551e+73*cos(theta)**5 - 1.35047446149881e+71*cos(theta)**3 + 2.32306386725712e+68*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl70_m_minus_36(theta, phi):
    return 7.60250054324482e-66*(1.0 - cos(theta)**2)**18*(3.22433867500717e+81*cos(theta)**34 - 1.30133381056045e+82*cos(theta)**32 + 2.35569916072256e+82*cos(theta)**30 - 2.53019539485016e+82*cos(theta)**28 + 1.79777041213038e+82*cos(theta)**26 - 8.9202348693492e+81*cos(theta)**24 + 3.18085894565941e+81*cos(theta)**22 - 8.26522403202838e+80*cos(theta)**20 + 1.57039256608539e+80*cos(theta)**18 - 2.17046127019932e+79*cos(theta)**16 + 2.15252357375139e+78*cos(theta)**14 - 1.49640676250097e+77*cos(theta)**12 + 7.03439076389344e+75*cos(theta)**10 - 2.11737514632244e+74*cos(theta)**8 + 3.74756663065919e+72*cos(theta)**6 - 3.37618615374702e+70*cos(theta)**4 + 1.16153193362856e+68*cos(theta)**2 - 6.38555213649566e+64)*sin(36*phi)

#@torch.jit.script
def Yl70_m_minus_35(theta, phi):
    return 4.63066554430613e-64*(1.0 - cos(theta)**2)**17.5*(9.21239621430621e+79*cos(theta)**35 - 3.94343578957712e+80*cos(theta)**33 + 7.59902955071795e+80*cos(theta)**31 - 8.72481170637987e+80*cos(theta)**29 + 6.65840893381621e+80*cos(theta)**27 - 3.56809394773968e+80*cos(theta)**25 + 1.3829821502867e+80*cos(theta)**23 - 3.93582096763256e+79*cos(theta)**21 + 8.26522403202838e+78*cos(theta)**19 - 1.27674192364666e+78*cos(theta)**17 + 1.43501571583426e+77*cos(theta)**15 - 1.15108212500075e+76*cos(theta)**13 + 6.39490069444858e+74*cos(theta)**11 - 2.35263905146938e+73*cos(theta)**9 + 5.35366661522741e+71*cos(theta)**7 - 6.75237230749403e+69*cos(theta)**5 + 3.8717731120952e+67*cos(theta)**3 - 6.38555213649566e+64*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl70_m_minus_34(theta, phi):
    return 2.84701211076783e-62*(1.0 - cos(theta)**2)**17*(2.55899894841839e+78*cos(theta)**36 - 1.15983405575798e+79*cos(theta)**34 + 2.37469673459936e+79*cos(theta)**32 - 2.90827056879329e+79*cos(theta)**30 + 2.37800319064865e+79*cos(theta)**28 - 1.37234382605372e+79*cos(theta)**26 + 5.76242562619458e+78*cos(theta)**24 - 1.78900953074207e+78*cos(theta)**22 + 4.13261201601419e+77*cos(theta)**20 - 7.09301068692589e+76*cos(theta)**18 + 8.96884822396414e+75*cos(theta)**16 - 8.22201517857675e+74*cos(theta)**14 + 5.32908391204049e+73*cos(theta)**12 - 2.35263905146938e+72*cos(theta)**10 + 6.69208326903426e+70*cos(theta)**8 - 1.12539538458234e+69*cos(theta)**6 + 9.67943278023801e+66*cos(theta)**4 - 3.19277606824783e+64*cos(theta)**2 + 1.68929950700943e+61)*sin(34*phi)

#@torch.jit.script
def Yl70_m_minus_33(theta, phi):
    return 1.7660656608883e-60*(1.0 - cos(theta)**2)**16.5*(6.91621337410376e+76*cos(theta)**37 - 3.31381158787993e+77*cos(theta)**35 + 7.19605071090715e+77*cos(theta)**33 - 9.38151796384932e+77*cos(theta)**31 + 8.20001100223672e+77*cos(theta)**29 - 5.08275491131009e+77*cos(theta)**27 + 2.30497025047783e+77*cos(theta)**25 - 7.77830230757423e+76*cos(theta)**23 + 1.96791048381628e+76*cos(theta)**21 - 3.73316351943468e+75*cos(theta)**19 + 5.27579307292008e+74*cos(theta)**17 - 5.4813434523845e+73*cos(theta)**15 + 4.09929531695422e+72*cos(theta)**13 - 2.13876277406307e+71*cos(theta)**11 + 7.43564807670474e+69*cos(theta)**9 - 1.60770769226048e+68*cos(theta)**7 + 1.9358865560476e+66*cos(theta)**5 - 1.06425868941594e+64*cos(theta)**3 + 1.68929950700943e+61*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl70_m_minus_32(theta, phi):
    return 1.10488545620251e-58*(1.0 - cos(theta)**2)**16*(1.82005615107994e+75*cos(theta)**38 - 9.20503218855536e+75*cos(theta)**36 + 2.11648550320799e+76*cos(theta)**34 - 2.93172436370291e+76*cos(theta)**32 + 2.73333700074557e+76*cos(theta)**30 - 1.81526961118217e+76*cos(theta)**28 + 8.8652701941455e+75*cos(theta)**26 - 3.2409592948226e+75*cos(theta)**24 + 8.94504765371037e+74*cos(theta)**22 - 1.86658175971734e+74*cos(theta)**20 + 2.93099615162227e+73*cos(theta)**18 - 3.42583965774031e+72*cos(theta)**16 + 2.92806808353873e+71*cos(theta)**14 - 1.78230231171923e+70*cos(theta)**12 + 7.43564807670474e+68*cos(theta)**10 - 2.0096346153256e+67*cos(theta)**8 + 3.22647759341267e+65*cos(theta)**6 - 2.66064672353986e+63*cos(theta)**4 + 8.44649753504717e+60*cos(theta)**2 - 4.31604370722901e+57)*sin(32*phi)

#@torch.jit.script
def Yl70_m_minus_31(theta, phi):
    return 6.96866594416903e-57*(1.0 - cos(theta)**2)**15.5*(4.66681064379471e+73*cos(theta)**39 - 2.4878465374474e+74*cos(theta)**37 + 6.0471014377371e+74*cos(theta)**35 - 8.88401322334216e+74*cos(theta)**33 + 8.81721613143733e+74*cos(theta)**31 - 6.25955038338681e+74*cos(theta)**29 + 3.28343340523907e+74*cos(theta)**27 - 1.29638371792904e+74*cos(theta)**25 + 3.88915115378712e+73*cos(theta)**23 - 8.88848457008257e+72*cos(theta)**21 + 1.5426295534854e+72*cos(theta)**19 - 2.01519979867077e+71*cos(theta)**17 + 1.95204538902582e+70*cos(theta)**15 - 1.37100177824556e+69*cos(theta)**13 + 6.75968006973158e+67*cos(theta)**11 - 2.23292735036178e+66*cos(theta)**9 + 4.60925370487524e+64*cos(theta)**7 - 5.32129344707972e+62*cos(theta)**5 + 2.81549917834906e+60*cos(theta)**3 - 4.31604370722901e+57*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl70_m_minus_30(theta, phi):
    return 4.42935336553025e-55*(1.0 - cos(theta)**2)**15*(1.16670266094868e+72*cos(theta)**40 - 6.54696457222999e+72*cos(theta)**38 + 1.67975039937142e+73*cos(theta)**36 - 2.61294506568887e+73*cos(theta)**34 + 2.75538004107417e+73*cos(theta)**32 - 2.08651679446227e+73*cos(theta)**30 + 1.17265478758538e+73*cos(theta)**28 - 4.98609122280399e+72*cos(theta)**26 + 1.6204796474113e+72*cos(theta)**24 - 4.04022025912844e+71*cos(theta)**22 + 7.71314776742702e+70*cos(theta)**20 - 1.11955544370598e+70*cos(theta)**18 + 1.22002836814114e+69*cos(theta)**16 - 9.79286984461114e+67*cos(theta)**14 + 5.63306672477632e+66*cos(theta)**12 - 2.23292735036178e+65*cos(theta)**10 + 5.76156713109405e+63*cos(theta)**8 - 8.86882241179953e+61*cos(theta)**6 + 7.03874794587264e+59*cos(theta)**4 - 2.1580218536145e+57*cos(theta)**2 + 1.06832765030421e+54)*sin(30*phi)

#@torch.jit.script
def Yl70_m_minus_29(theta, phi):
    return 2.83616998909815e-53*(1.0 - cos(theta)**2)**14.5*(2.84561624621629e+70*cos(theta)**41 - 1.67870886467436e+71*cos(theta)**39 + 4.53986594424707e+71*cos(theta)**37 - 7.46555733053963e+71*cos(theta)**35 + 8.34963648810353e+71*cos(theta)**33 - 6.73069933697506e+71*cos(theta)**31 + 4.04363719857029e+71*cos(theta)**29 - 1.84670045289037e+71*cos(theta)**27 + 6.48191858964519e+70*cos(theta)**25 - 1.75661750396889e+70*cos(theta)**23 + 3.67292750829858e+69*cos(theta)**21 - 5.89239707213676e+68*cos(theta)**19 + 7.17663745965375e+67*cos(theta)**17 - 6.52857989640742e+66*cos(theta)**15 + 4.33312824982794e+65*cos(theta)**13 - 2.02993395487435e+64*cos(theta)**11 + 6.40174125677117e+62*cos(theta)**9 - 1.26697463025708e+61*cos(theta)**7 + 1.40774958917453e+59*cos(theta)**5 - 7.19340617871501e+56*cos(theta)**3 + 1.06832765030421e+54*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl70_m_minus_28(theta, phi):
    return 1.82883489525325e-51*(1.0 - cos(theta)**2)**14*(6.77527677670544e+68*cos(theta)**42 - 4.19677216168589e+69*cos(theta)**40 + 1.19470156427555e+70*cos(theta)**38 - 2.0737659251499e+70*cos(theta)**36 + 2.45577543767751e+70*cos(theta)**34 - 2.10334354280471e+70*cos(theta)**32 + 1.3478790661901e+70*cos(theta)**30 - 6.59535876032274e+69*cos(theta)**28 + 2.493045611402e+69*cos(theta)**26 - 7.31923959987036e+68*cos(theta)**24 + 1.66951250377208e+68*cos(theta)**22 - 2.94619853606838e+67*cos(theta)**20 + 3.98702081091875e+66*cos(theta)**18 - 4.08036243525464e+65*cos(theta)**16 + 3.09509160701995e+64*cos(theta)**14 - 1.69161162906196e+63*cos(theta)**12 + 6.40174125677117e+61*cos(theta)**10 - 1.58371828782134e+60*cos(theta)**8 + 2.34624931529088e+58*cos(theta)**6 - 1.79835154467875e+56*cos(theta)**4 + 5.34163825152105e+53*cos(theta)**2 - 2.56933056831219e+50)*sin(28*phi)

#@torch.jit.script
def Yl70_m_minus_27(theta, phi):
    return 1.187194197688e-49*(1.0 - cos(theta)**2)**13.5*(1.57564576202452e+67*cos(theta)**43 - 1.02360296626485e+68*cos(theta)**41 + 3.06333734429627e+68*cos(theta)**39 - 5.6047727706754e+68*cos(theta)**37 + 7.01650125050717e+68*cos(theta)**35 - 6.37376831152941e+68*cos(theta)**33 + 4.34799698770999e+68*cos(theta)**31 - 2.2742616414906e+68*cos(theta)**29 + 9.23350226445184e+67*cos(theta)**27 - 2.92769583994815e+67*cos(theta)**25 + 7.25875001640036e+66*cos(theta)**23 - 1.40295168384209e+66*cos(theta)**21 + 2.09843200574671e+65*cos(theta)**19 - 2.40021319720861e+64*cos(theta)**17 + 2.06339440467997e+63*cos(theta)**15 - 1.30123971466304e+62*cos(theta)**13 + 5.81976477888288e+60*cos(theta)**11 - 1.75968698646816e+59*cos(theta)**9 + 3.35178473612983e+57*cos(theta)**7 - 3.59670308935751e+55*cos(theta)**5 + 1.78054608384035e+53*cos(theta)**3 - 2.56933056831219e+50*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl70_m_minus_26(theta, phi):
    return 7.75593160683268e-48*(1.0 - cos(theta)**2)**13*(3.58101309551028e+65*cos(theta)**44 - 2.43714991967822e+66*cos(theta)**42 + 7.65834336074068e+66*cos(theta)**40 - 1.47494020280932e+67*cos(theta)**38 + 1.94902812514088e+67*cos(theta)**36 - 1.87463773868512e+67*cos(theta)**34 + 1.35874905865937e+67*cos(theta)**32 - 7.580872138302e+66*cos(theta)**30 + 3.29767938016137e+66*cos(theta)**28 - 1.12603686151852e+66*cos(theta)**26 + 3.02447917350015e+65*cos(theta)**24 - 6.37705310837312e+64*cos(theta)**22 + 1.04921600287336e+64*cos(theta)**20 - 1.33345177622701e+63*cos(theta)**18 + 1.28962150292498e+62*cos(theta)**16 - 9.29456939045031e+60*cos(theta)**14 + 4.8498039824024e+59*cos(theta)**12 - 1.75968698646816e+58*cos(theta)**10 + 4.18973092016229e+56*cos(theta)**8 - 5.99450514892918e+54*cos(theta)**6 + 4.45136520960088e+52*cos(theta)**4 - 1.2846652841561e+50*cos(theta)**2 + 6.01998727345875e+46)*sin(26*phi)

#@torch.jit.script
def Yl70_m_minus_25(theta, phi):
    return 5.09771843463546e-46*(1.0 - cos(theta)**2)**12.5*(7.95780687891173e+63*cos(theta)**45 - 5.66779051087957e+64*cos(theta)**43 + 1.8678886245709e+65*cos(theta)**41 - 3.78189795592132e+65*cos(theta)**39 + 5.26764358146184e+65*cos(theta)**37 - 5.35610782481463e+65*cos(theta)**35 + 4.11742138987688e+65*cos(theta)**33 - 2.44544262525871e+65*cos(theta)**31 + 1.1371308207453e+65*cos(theta)**29 - 4.17050689451303e+64*cos(theta)**27 + 1.20979166940006e+64*cos(theta)**25 - 2.77263178624918e+63*cos(theta)**23 + 4.99626668034931e+62*cos(theta)**21 - 7.01816724330003e+61*cos(theta)**19 + 7.58600884073518e+60*cos(theta)**17 - 6.19637959363354e+59*cos(theta)**15 + 3.73061844800185e+58*cos(theta)**13 - 1.59971544224378e+57*cos(theta)**11 + 4.6552565779581e+55*cos(theta)**9 - 8.56357878418454e+53*cos(theta)**7 + 8.90273041920175e+51*cos(theta)**5 - 4.28221761385366e+49*cos(theta)**3 + 6.01998727345875e+46*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl70_m_minus_24(theta, phi):
    return 3.36989650069038e-44*(1.0 - cos(theta)**2)**12*(1.72995801715472e+62*cos(theta)**46 - 1.28813420701809e+63*cos(theta)**44 + 4.44735386802594e+63*cos(theta)**42 - 9.4547448898033e+63*cos(theta)**40 + 1.38622199512154e+64*cos(theta)**38 - 1.48780772911518e+64*cos(theta)**36 + 1.21100629114026e+64*cos(theta)**34 - 7.64200820393347e+63*cos(theta)**32 + 3.790436069151e+63*cos(theta)**30 - 1.48946674804037e+63*cos(theta)**28 + 4.65304488230792e+62*cos(theta)**26 - 1.15526324427049e+62*cos(theta)**24 + 2.27103030924969e+61*cos(theta)**22 - 3.50908362165002e+60*cos(theta)**20 + 4.21444935596399e+59*cos(theta)**18 - 3.87273724602096e+58*cos(theta)**16 + 2.66472746285846e+57*cos(theta)**14 - 1.33309620186982e+56*cos(theta)**12 + 4.6552565779581e+54*cos(theta)**10 - 1.07044734802307e+53*cos(theta)**8 + 1.48378840320029e+51*cos(theta)**6 - 1.07055440346341e+49*cos(theta)**4 + 3.00999363672937e+46*cos(theta)**2 - 1.37757145845738e+43)*sin(24*phi)

#@torch.jit.script
def Yl70_m_minus_23(theta, phi):
    return 2.23990406748289e-42*(1.0 - cos(theta)**2)**11.5*(3.68076173862707e+60*cos(theta)**47 - 2.86252046004019e+61*cos(theta)**45 + 1.03426834140138e+62*cos(theta)**43 - 2.30603533897642e+62*cos(theta)**41 + 3.5544153721065e+62*cos(theta)**39 - 4.02110197058156e+62*cos(theta)**37 + 3.46001797468646e+62*cos(theta)**35 - 2.31576006179802e+62*cos(theta)**33 + 1.22272131262936e+62*cos(theta)**31 - 5.13609223462195e+61*cos(theta)**29 + 1.72334995641034e+61*cos(theta)**27 - 4.62105297708197e+60*cos(theta)**25 + 9.87404482282472e+59*cos(theta)**23 - 1.67099220078572e+59*cos(theta)**21 + 2.21813123998105e+58*cos(theta)**19 - 2.27808073295351e+57*cos(theta)**17 + 1.77648497523897e+56*cos(theta)**15 - 1.02545861682294e+55*cos(theta)**13 + 4.23205143450736e+53*cos(theta)**11 - 1.18938594224785e+52*cos(theta)**9 + 2.11969771885756e+50*cos(theta)**7 - 2.14110880692683e+48*cos(theta)**5 + 1.00333121224312e+46*cos(theta)**3 - 1.37757145845738e+43*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl70_m_minus_22(theta, phi):
    return 1.49655096517071e-40*(1.0 - cos(theta)**2)**11*(7.66825362213973e+58*cos(theta)**48 - 6.22287056530476e+59*cos(theta)**46 + 2.35060986682132e+60*cos(theta)**44 - 5.49056033089623e+60*cos(theta)**42 + 8.88603843026626e+60*cos(theta)**40 - 1.05818472910041e+61*cos(theta)**38 + 9.61116104079571e+60*cos(theta)**36 - 6.8110590052883e+60*cos(theta)**34 + 3.82100410196674e+60*cos(theta)**32 - 1.71203074487398e+60*cos(theta)**30 + 6.15482127289408e+59*cos(theta)**28 - 1.77732806810845e+59*cos(theta)**26 + 4.11418534284363e+58*cos(theta)**24 - 7.59541909448056e+57*cos(theta)**22 + 1.10906561999052e+57*cos(theta)**20 - 1.26560040719639e+56*cos(theta)**18 + 1.11030310952436e+55*cos(theta)**16 - 7.32470440587812e+53*cos(theta)**14 + 3.52670952875613e+52*cos(theta)**12 - 1.18938594224785e+51*cos(theta)**10 + 2.64962214857195e+49*cos(theta)**8 - 3.56851467821138e+47*cos(theta)**6 + 2.50832803060781e+45*cos(theta)**4 - 6.8878572922869e+42*cos(theta)**2 + 3.0859575682289e+39)*sin(22*phi)

#@torch.jit.script
def Yl70_m_minus_21(theta, phi):
    return 1.00480888130137e-38*(1.0 - cos(theta)**2)**10.5*(1.56494971880403e+57*cos(theta)**49 - 1.32401501389463e+58*cos(theta)**47 + 5.22357748182516e+58*cos(theta)**45 - 1.27687449555726e+59*cos(theta)**43 + 2.16732644640641e+59*cos(theta)**41 - 2.71329417718054e+59*cos(theta)**39 + 2.59761109210695e+59*cos(theta)**37 - 1.9460168586538e+59*cos(theta)**35 + 1.15788003089901e+59*cos(theta)**33 - 5.52267982217414e+58*cos(theta)**31 + 2.12235216306692e+58*cos(theta)**29 - 6.58269654854982e+57*cos(theta)**27 + 1.64567413713745e+57*cos(theta)**25 - 3.30235612803502e+56*cos(theta)**23 + 5.28126485709773e+55*cos(theta)**21 - 6.66105477471786e+54*cos(theta)**19 + 6.53119476190799e+53*cos(theta)**17 - 4.88313627058542e+52*cos(theta)**15 + 2.71285348365856e+51*cos(theta)**13 - 1.08125994749805e+50*cos(theta)**11 + 2.94402460952439e+48*cos(theta)**9 - 5.09787811173054e+46*cos(theta)**7 + 5.01665606121562e+44*cos(theta)**5 - 2.2959524307623e+42*cos(theta)**3 + 3.0859575682289e+39*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl70_m_minus_20(theta, phi):
    return 6.77780645942075e-37*(1.0 - cos(theta)**2)**10*(3.12989943760805e+55*cos(theta)**50 - 2.75836461228048e+56*cos(theta)**48 + 1.13556032213591e+57*cos(theta)**46 - 2.90198748990287e+57*cos(theta)**44 + 5.16030106287239e+57*cos(theta)**42 - 6.78323544295135e+57*cos(theta)**40 + 6.83581866343934e+57*cos(theta)**38 - 5.40560238514944e+57*cos(theta)**36 + 3.40552950264415e+57*cos(theta)**34 - 1.72583744442942e+57*cos(theta)**32 + 7.07450721022308e+56*cos(theta)**30 - 2.35096305305351e+56*cos(theta)**28 + 6.32951591206713e+55*cos(theta)**26 - 1.37598172001459e+55*cos(theta)**24 + 2.40057493504442e+54*cos(theta)**22 - 3.33052738735893e+53*cos(theta)**20 + 3.62844153439333e+52*cos(theta)**18 - 3.05196016911589e+51*cos(theta)**16 + 1.93775248832755e+50*cos(theta)**14 - 9.01049956248373e+48*cos(theta)**12 + 2.94402460952439e+47*cos(theta)**10 - 6.37234763966318e+45*cos(theta)**8 + 8.36109343535937e+43*cos(theta)**6 - 5.73988107690575e+41*cos(theta)**4 + 1.54297878411445e+39*cos(theta)**2 - 6.78232432577779e+35)*sin(20*phi)

#@torch.jit.script
def Yl70_m_minus_19(theta, phi):
    return 4.59193261320621e-35*(1.0 - cos(theta)**2)**9.5*(6.1370577208001e+53*cos(theta)**51 - 5.62931553526628e+54*cos(theta)**49 + 2.41608579177852e+55*cos(theta)**47 - 6.44886108867304e+55*cos(theta)**45 + 1.20007001462149e+56*cos(theta)**43 - 1.65444766901252e+56*cos(theta)**41 + 1.7527740162665e+56*cos(theta)**39 - 1.46097361760796e+56*cos(theta)**37 + 9.730084293269e+55*cos(theta)**35 - 5.22981043766491e+55*cos(theta)**33 + 2.28209910007196e+55*cos(theta)**31 - 8.10676914846036e+54*cos(theta)**29 + 2.34426515261746e+54*cos(theta)**27 - 5.50392688005837e+53*cos(theta)**25 + 1.04372823262801e+53*cos(theta)**23 - 1.58596542255187e+52*cos(theta)**21 + 1.90970607073333e+51*cos(theta)**19 - 1.79527068771523e+50*cos(theta)**17 + 1.29183499221836e+49*cos(theta)**15 - 6.93115350960287e+47*cos(theta)**13 + 2.67638600865854e+46*cos(theta)**11 - 7.08038626629242e+44*cos(theta)**9 + 1.19444191933705e+43*cos(theta)**7 - 1.14797621538115e+41*cos(theta)**5 + 5.14326261371483e+38*cos(theta)**3 - 6.78232432577779e+35*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl70_m_minus_18(theta, phi):
    return 3.12386445344419e-33*(1.0 - cos(theta)**2)**9*(1.18020340784617e+52*cos(theta)**52 - 1.12586310705326e+53*cos(theta)**50 + 5.03351206620525e+53*cos(theta)**48 - 1.40192632362457e+54*cos(theta)**46 + 2.72743185141247e+54*cos(theta)**44 - 3.93916111669648e+54*cos(theta)**42 + 4.38193504066624e+54*cos(theta)**40 - 3.84466741475778e+54*cos(theta)**38 + 2.70280119257472e+54*cos(theta)**36 - 1.53817954048968e+54*cos(theta)**34 + 7.13155968772488e+53*cos(theta)**32 - 2.70225638282012e+53*cos(theta)**30 + 8.37237554506234e+52*cos(theta)**28 - 2.11689495386861e+52*cos(theta)**26 + 4.34886763595004e+51*cos(theta)**24 - 7.20893373887214e+50*cos(theta)**22 + 9.54853035366666e+49*cos(theta)**20 - 9.97372604286237e+48*cos(theta)**18 + 8.07396870136477e+47*cos(theta)**16 - 4.95082393543062e+46*cos(theta)**14 + 2.23032167388211e+45*cos(theta)**12 - 7.08038626629242e+43*cos(theta)**10 + 1.49305239917132e+42*cos(theta)**8 - 1.91329369230192e+40*cos(theta)**6 + 1.28581565342871e+38*cos(theta)**4 - 3.3911621628889e+35*cos(theta)**2 + 1.46549790963219e+32)*sin(18*phi)

#@torch.jit.script
def Yl70_m_minus_17(theta, phi):
    return 2.1333958805615e-31*(1.0 - cos(theta)**2)**8.5*(2.22679888272863e+50*cos(theta)**53 - 2.20757471971227e+51*cos(theta)**51 + 1.02724736045005e+52*cos(theta)**49 - 2.98282196515867e+52*cos(theta)**47 + 6.06095966980549e+52*cos(theta)**45 - 9.16083980627089e+52*cos(theta)**43 + 1.06876464406494e+53*cos(theta)**41 - 9.85812157630201e+52*cos(theta)**39 + 7.30486808803979e+52*cos(theta)**37 - 4.39479868711337e+52*cos(theta)**35 + 2.16107869324996e+52*cos(theta)**33 - 8.71695607361329e+51*cos(theta)**31 + 2.8870260500215e+51*cos(theta)**29 - 7.84035168099484e+50*cos(theta)**27 + 1.73954705438002e+50*cos(theta)**25 - 3.13431901690093e+49*cos(theta)**23 + 4.54691921603174e+48*cos(theta)**21 - 5.24932949624335e+47*cos(theta)**19 + 4.74939335374399e+46*cos(theta)**17 - 3.30054929028708e+45*cos(theta)**15 + 1.71563205683239e+44*cos(theta)**13 - 6.43671478753856e+42*cos(theta)**11 + 1.65894711019035e+41*cos(theta)**9 - 2.73327670328845e+39*cos(theta)**7 + 2.57163130685741e+37*cos(theta)**5 - 1.13038738762963e+35*cos(theta)**3 + 1.46549790963219e+32*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl70_m_minus_16(theta, phi):
    return 1.4622713074207e-29*(1.0 - cos(theta)**2)**8*(4.12370163468265e+48*cos(theta)**54 - 4.24533599944667e+49*cos(theta)**52 + 2.0544947209001e+50*cos(theta)**50 - 6.21421242741389e+50*cos(theta)**48 + 1.31759992821858e+51*cos(theta)**46 - 2.08200904687975e+51*cos(theta)**44 + 2.54467772396414e+51*cos(theta)**42 - 2.4645303940755e+51*cos(theta)**40 + 1.92233370737889e+51*cos(theta)**38 - 1.22077741308705e+51*cos(theta)**36 + 6.35611380367636e+50*cos(theta)**34 - 2.72404877300415e+50*cos(theta)**32 + 9.62342016673832e+49*cos(theta)**30 - 2.8001256003553e+49*cos(theta)**28 + 6.6905655937693e+48*cos(theta)**26 - 1.30596625704205e+48*cos(theta)**24 + 2.06678146183261e+47*cos(theta)**22 - 2.62466474812168e+46*cos(theta)**20 + 2.6385518631911e+45*cos(theta)**18 - 2.06284330642943e+44*cos(theta)**16 + 1.225451469166e+43*cos(theta)**14 - 5.36392898961547e+41*cos(theta)**12 + 1.65894711019035e+40*cos(theta)**10 - 3.41659587911056e+38*cos(theta)**8 + 4.28605217809569e+36*cos(theta)**6 - 2.82596846907408e+34*cos(theta)**4 + 7.32748954816097e+31*cos(theta)**2 - 3.11940806647977e+28)*sin(16*phi)

#@torch.jit.script
def Yl70_m_minus_15(theta, phi):
    return 1.00567702523587e-27*(1.0 - cos(theta)**2)**7.5*(7.49763933578663e+46*cos(theta)**55 - 8.01006792348428e+47*cos(theta)**53 + 4.02842102137275e+48*cos(theta)**51 - 1.26820661783957e+49*cos(theta)**49 + 2.80340410259273e+49*cos(theta)**47 - 4.62668677084388e+49*cos(theta)**45 + 5.91785517200962e+49*cos(theta)**43 - 6.01104974164757e+49*cos(theta)**41 + 4.92906078815101e+49*cos(theta)**39 - 3.29939841374878e+49*cos(theta)**37 + 1.8160325153361e+49*cos(theta)**35 - 8.25469325152774e+48*cos(theta)**33 + 3.10432908604462e+48*cos(theta)**31 - 9.65560551846655e+47*cos(theta)**29 + 2.47798725695159e+47*cos(theta)**27 - 5.22386502816822e+46*cos(theta)**25 + 8.98600635579396e+45*cos(theta)**23 - 1.24984035624842e+45*cos(theta)**21 + 1.38871150694269e+44*cos(theta)**19 - 1.21343723907613e+43*cos(theta)**17 + 8.16967646110664e+41*cos(theta)**15 - 4.12609922278113e+40*cos(theta)**13 + 1.50813373653668e+39*cos(theta)**11 - 3.79621764345618e+37*cos(theta)**9 + 6.12293168299384e+35*cos(theta)**7 - 5.65193693814816e+33*cos(theta)**5 + 2.44249651605366e+31*cos(theta)**3 - 3.11940806647977e+28*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl70_m_minus_14(theta, phi):
    return 6.93844268438917e-26*(1.0 - cos(theta)**2)**7*(1.33886416710476e+45*cos(theta)**56 - 1.48334591175635e+46*cos(theta)**54 + 7.74696350263991e+46*cos(theta)**52 - 2.53641323567914e+47*cos(theta)**50 + 5.84042521373486e+47*cos(theta)**48 - 1.00580147192258e+48*cos(theta)**46 + 1.34496708454764e+48*cos(theta)**44 - 1.4312023194399e+48*cos(theta)**42 + 1.23226519703775e+48*cos(theta)**40 - 8.68262740460204e+47*cos(theta)**38 + 5.04453476482251e+47*cos(theta)**36 - 2.42785095633169e+47*cos(theta)**34 + 9.70102839388944e+46*cos(theta)**32 - 3.21853517282218e+46*cos(theta)**30 + 8.84995448911283e+45*cos(theta)**28 - 2.00917885698778e+45*cos(theta)**26 + 3.74416931491415e+44*cos(theta)**24 - 5.6810925284019e+43*cos(theta)**22 + 6.94355753471343e+42*cos(theta)**20 - 6.74131799486741e+41*cos(theta)**18 + 5.10604778819165e+40*cos(theta)**16 - 2.94721373055795e+39*cos(theta)**14 + 1.25677811378057e+38*cos(theta)**12 - 3.79621764345618e+36*cos(theta)**10 + 7.6536646037423e+34*cos(theta)**8 - 9.4198948969136e+32*cos(theta)**6 + 6.10624129013414e+30*cos(theta)**4 - 1.55970403323988e+28*cos(theta)**2 + 6.55337829092388e+24)*sin(14*phi)

#@torch.jit.script
def Yl70_m_minus_13(theta, phi):
    return 4.80108147403523e-24*(1.0 - cos(theta)**2)**6.5*(2.34888450369255e+43*cos(theta)**57 - 2.69699256682972e+44*cos(theta)**55 + 1.46169122691319e+45*cos(theta)**53 - 4.97335928564537e+45*cos(theta)**51 + 1.19192351300711e+46*cos(theta)**49 - 2.14000313175018e+46*cos(theta)**47 + 2.9888157434392e+46*cos(theta)**45 - 3.32837748706953e+46*cos(theta)**43 + 3.00552487082378e+46*cos(theta)**41 - 2.22631471912873e+46*cos(theta)**39 + 1.36338777427635e+46*cos(theta)**37 - 6.93671701809054e+45*cos(theta)**35 + 2.93970557390589e+45*cos(theta)**33 - 1.03823715252328e+45*cos(theta)**31 + 3.05170844452166e+44*cos(theta)**29 - 7.4414031740288e+43*cos(theta)**27 + 1.49766772596566e+43*cos(theta)**25 - 2.47004022973995e+42*cos(theta)**23 + 3.30645596891116e+41*cos(theta)**21 - 3.54806210256179e+40*cos(theta)**19 + 3.00355752246568e+39*cos(theta)**17 - 1.9648091537053e+38*cos(theta)**15 + 9.66752395215823e+36*cos(theta)**13 - 3.45110694859653e+35*cos(theta)**11 + 8.50407178193589e+33*cos(theta)**9 - 1.34569927098766e+32*cos(theta)**7 + 1.22124825802683e+30*cos(theta)**5 - 5.19901344413294e+27*cos(theta)**3 + 6.55337829092388e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl70_m_minus_12(theta, phi):
    return 3.33113412074688e-22*(1.0 - cos(theta)**2)**6*(4.04980086843544e+41*cos(theta)**58 - 4.81605815505308e+42*cos(theta)**56 + 2.7068356053948e+43*cos(theta)**54 - 9.56415247239495e+43*cos(theta)**52 + 2.38384702601423e+44*cos(theta)**50 - 4.45833985781287e+44*cos(theta)**48 + 6.49742552921566e+44*cos(theta)**46 - 7.56449428879438e+44*cos(theta)**44 + 7.15601159719948e+44*cos(theta)**42 - 5.56578679782182e+44*cos(theta)**40 + 3.58786256388514e+44*cos(theta)**38 - 1.92686583835848e+44*cos(theta)**36 + 8.64619286442909e+43*cos(theta)**34 - 3.24449110163526e+43*cos(theta)**32 + 1.01723614817389e+43*cos(theta)**30 - 2.65764399072457e+42*cos(theta)**28 + 5.7602604844833e+41*cos(theta)**26 - 1.02918342905831e+41*cos(theta)**24 + 1.50293453132325e+40*cos(theta)**22 - 1.7740310512809e+39*cos(theta)**20 + 1.66864306803649e+38*cos(theta)**18 - 1.22800572106581e+37*cos(theta)**16 + 6.90537425154159e+35*cos(theta)**14 - 2.87592245716377e+34*cos(theta)**12 + 8.50407178193589e+32*cos(theta)**10 - 1.68212408873457e+31*cos(theta)**8 + 2.03541376337805e+29*cos(theta)**6 - 1.29975336103324e+27*cos(theta)**4 + 3.27668914546194e+24*cos(theta)**2 - 1.36131663708431e+21)*sin(12*phi)

#@torch.jit.script
def Yl70_m_minus_11(theta, phi):
    return 2.31699475653475e-20*(1.0 - cos(theta)**2)**5.5*(6.86406926853464e+39*cos(theta)**59 - 8.44922483342645e+40*cos(theta)**57 + 4.92151928253599e+41*cos(theta)**55 - 1.8045570702632e+42*cos(theta)**53 + 4.67420985492986e+42*cos(theta)**51 - 9.09865277104668e+42*cos(theta)**49 + 1.38243096366291e+43*cos(theta)**47 - 1.6809987308432e+43*cos(theta)**45 + 1.66418874353476e+43*cos(theta)**43 - 1.35750897507849e+43*cos(theta)**41 + 9.19964759970549e+42*cos(theta)**39 - 5.20774550907698e+42*cos(theta)**37 + 2.47034081840831e+42*cos(theta)**35 - 9.83179121707656e+41*cos(theta)**33 + 3.28140692959319e+41*cos(theta)**31 - 9.16428962318818e+40*cos(theta)**29 + 2.13342980906789e+40*cos(theta)**27 - 4.11673371623326e+39*cos(theta)**25 + 6.53449796227501e+38*cos(theta)**23 - 8.44776691086141e+37*cos(theta)**21 + 8.78233193703414e+36*cos(theta)**19 - 7.22356306509302e+35*cos(theta)**17 + 4.60358283436106e+34*cos(theta)**15 - 2.21224804397213e+33*cos(theta)**13 + 7.73097434721445e+31*cos(theta)**11 - 1.86902676526064e+30*cos(theta)**9 + 2.90773394768293e+28*cos(theta)**7 - 2.59950672206647e+26*cos(theta)**5 + 1.09222971515398e+24*cos(theta)**3 - 1.36131663708431e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl70_m_minus_10(theta, phi):
    return 1.61526277895562e-18*(1.0 - cos(theta)**2)**5*(1.14401154475577e+38*cos(theta)**60 - 1.45676290231491e+39*cos(theta)**58 + 8.78842729024284e+39*cos(theta)**56 - 3.34177235233925e+40*cos(theta)**54 + 8.98886510563435e+40*cos(theta)**52 - 1.81973055420933e+41*cos(theta)**50 + 2.88006450763105e+41*cos(theta)**48 - 3.65434506705043e+41*cos(theta)**46 + 3.78224714439719e+41*cos(theta)**44 - 3.23216422637736e+41*cos(theta)**42 + 2.29991189992637e+41*cos(theta)**40 - 1.37045934449394e+41*cos(theta)**38 + 6.86205782891198e+40*cos(theta)**36 - 2.89170329914016e+40*cos(theta)**34 + 1.02543966549787e+40*cos(theta)**32 - 3.05476320772939e+39*cos(theta)**30 + 7.61939217524247e+38*cos(theta)**28 - 1.58335912162818e+38*cos(theta)**26 + 2.72270748428126e+37*cos(theta)**24 - 3.83989405039155e+36*cos(theta)**22 + 4.39116596851707e+35*cos(theta)**20 - 4.01309059171834e+34*cos(theta)**18 + 2.87723927147566e+33*cos(theta)**16 - 1.58017717426581e+32*cos(theta)**14 + 6.44247862267871e+30*cos(theta)**12 - 1.86902676526064e+29*cos(theta)**10 + 3.63466743460366e+27*cos(theta)**8 - 4.33251120344412e+25*cos(theta)**6 + 2.73057428788495e+23*cos(theta)**4 - 6.80658318542156e+20*cos(theta)**2 + 2.80106303926813e+17)*sin(10*phi)

#@torch.jit.script
def Yl70_m_minus_9(theta, phi):
    return 1.12837406758519e-16*(1.0 - cos(theta)**2)**4.5*(1.87542876189471e+36*cos(theta)**61 - 2.46908966494052e+37*cos(theta)**59 + 1.54182934916541e+38*cos(theta)**57 - 6.07594973152592e+38*cos(theta)**55 + 1.69601228408195e+39*cos(theta)**53 - 3.56809912590066e+39*cos(theta)**51 + 5.8776826686348e+39*cos(theta)**49 - 7.77520227032005e+39*cos(theta)**47 + 8.40499365421598e+39*cos(theta)**45 - 7.51666099157527e+39*cos(theta)**43 + 5.60954121933262e+39*cos(theta)**41 - 3.51399831921524e+39*cos(theta)**39 + 1.85461022403026e+39*cos(theta)**37 - 8.26200942611475e+38*cos(theta)**35 + 3.10739292575112e+38*cos(theta)**33 - 9.85407486364321e+37*cos(theta)**31 + 2.62737661215258e+37*cos(theta)**29 - 5.86429304306732e+36*cos(theta)**27 + 1.0890829937125e+36*cos(theta)**25 - 1.66951915234415e+35*cos(theta)**23 + 2.09103141357956e+34*cos(theta)**21 - 2.11215294300965e+33*cos(theta)**19 + 1.69249368910333e+32*cos(theta)**17 - 1.05345144951054e+31*cos(theta)**15 + 4.95575278667593e+29*cos(theta)**13 - 1.69911524114603e+28*cos(theta)**11 + 4.03851937178184e+26*cos(theta)**9 - 6.18930171920588e+24*cos(theta)**7 + 5.4611485757699e+22*cos(theta)**5 - 2.26886106180719e+20*cos(theta)**3 + 2.80106303926813e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl70_m_minus_8(theta, phi):
    return 7.89700634562307e-15*(1.0 - cos(theta)**2)**4*(3.02488509983018e+34*cos(theta)**62 - 4.11514944156753e+35*cos(theta)**60 + 2.6583264640783e+36*cos(theta)**58 - 1.08499102348677e+37*cos(theta)**56 + 3.14076348904065e+37*cos(theta)**54 - 6.86172908827049e+37*cos(theta)**52 + 1.17553653372696e+38*cos(theta)**50 - 1.61983380631668e+38*cos(theta)**48 + 1.82717253352521e+38*cos(theta)**46 - 1.70833204353983e+38*cos(theta)**44 + 1.33560505222205e+38*cos(theta)**42 - 8.78499579803809e+37*cos(theta)**40 + 4.88055322113227e+37*cos(theta)**38 - 2.29500261836521e+37*cos(theta)**36 + 9.13939095809154e+36*cos(theta)**34 - 3.0793983948885e+36*cos(theta)**32 + 8.75792204050858e+35*cos(theta)**30 - 2.09439037252404e+35*cos(theta)**28 + 4.18878074504809e+34*cos(theta)**26 - 6.95632980143397e+33*cos(theta)**24 + 9.50468824354344e+32*cos(theta)**22 - 1.05607647150483e+32*cos(theta)**20 + 9.40274271724073e+30*cos(theta)**18 - 6.58407155944088e+29*cos(theta)**16 + 3.53982341905423e+28*cos(theta)**14 - 1.41592936762169e+27*cos(theta)**12 + 4.03851937178184e+25*cos(theta)**10 - 7.73662714900736e+23*cos(theta)**8 + 9.10191429294983e+21*cos(theta)**6 - 5.67215265451797e+19*cos(theta)**4 + 1.40053151963407e+17*cos(theta)**2 - 57187893819275.9)*sin(8*phi)

#@torch.jit.script
def Yl70_m_minus_7(theta, phi):
    return 5.53579581560677e-13*(1.0 - cos(theta)**2)**3.5*(4.80140492036536e+32*cos(theta)**63 - 6.74614662552054e+33*cos(theta)**61 + 4.50563807470897e+34*cos(theta)**59 - 1.903493023661e+35*cos(theta)**57 + 5.71047907098301e+35*cos(theta)**55 - 1.29466586571141e+36*cos(theta)**53 + 2.30497359554306e+36*cos(theta)**51 - 3.3057832781973e+36*cos(theta)**49 + 3.88760113516003e+36*cos(theta)**47 - 3.79629343008852e+36*cos(theta)**45 + 3.10605826098152e+36*cos(theta)**43 - 2.14268190196051e+36*cos(theta)**41 + 1.25142390285443e+36*cos(theta)**39 - 6.20270977936543e+35*cos(theta)**37 + 2.61125455945473e+35*cos(theta)**35 - 9.33151028754091e+34*cos(theta)**33 + 2.82513614209954e+34*cos(theta)**31 - 7.22203576732428e+33*cos(theta)**29 + 1.55140027594374e+33*cos(theta)**27 - 2.78253192057359e+32*cos(theta)**25 + 4.13247314936671e+31*cos(theta)**23 - 5.02893557859441e+30*cos(theta)**21 + 4.94881195644249e+29*cos(theta)**19 - 3.87298327025934e+28*cos(theta)**17 + 2.35988227936949e+27*cos(theta)**15 - 1.08917643663207e+26*cos(theta)**13 + 3.6713812470744e+24*cos(theta)**11 - 8.59625238778595e+22*cos(theta)**9 + 1.3002734704214e+21*cos(theta)**7 - 1.13443053090359e+19*cos(theta)**5 + 4.66843839878022e+16*cos(theta)**3 - 57187893819275.9*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl70_m_minus_6(theta, phi):
    return 3.8861128910259e-11*(1.0 - cos(theta)**2)**3*(7.50219518807088e+30*cos(theta)**64 - 1.08808816540654e+32*cos(theta)**62 + 7.50939679118163e+32*cos(theta)**60 - 3.28188452355345e+33*cos(theta)**58 + 1.01972840553268e+34*cos(theta)**56 - 2.39752938094706e+34*cos(theta)**54 + 4.4326415298905e+34*cos(theta)**52 - 6.6115665563946e+34*cos(theta)**50 + 8.09916903158339e+34*cos(theta)**48 - 8.25281180454026e+34*cos(theta)**46 + 7.05922332041253e+34*cos(theta)**44 - 5.10162357609645e+34*cos(theta)**42 + 3.12855975713607e+34*cos(theta)**40 - 1.63229204720143e+34*cos(theta)**38 + 7.25348488737424e+33*cos(theta)**36 - 2.74456184927674e+33*cos(theta)**34 + 8.82855044406107e+32*cos(theta)**32 - 2.40734525577476e+32*cos(theta)**30 + 5.54071527122763e+31*cos(theta)**28 - 1.070204584836e+31*cos(theta)**26 + 1.72186381223613e+30*cos(theta)**24 - 2.28587980845201e+29*cos(theta)**22 + 2.47440597822124e+28*cos(theta)**20 - 2.1516573723663e+27*cos(theta)**18 + 1.47492642460593e+26*cos(theta)**16 - 7.77983169022909e+24*cos(theta)**14 + 3.059484372562e+23*cos(theta)**12 - 8.59625238778595e+21*cos(theta)**10 + 1.62534183802676e+20*cos(theta)**8 - 1.89071755150599e+18*cos(theta)**6 + 1.16710959969506e+16*cos(theta)**4 - 28593946909637.9*cos(theta)**2 + 11604686245.7946)*sin(6*phi)

#@torch.jit.script
def Yl70_m_minus_5(theta, phi):
    return 2.73135963587515e-9*(1.0 - cos(theta)**2)**2.5*(1.15418387508783e+29*cos(theta)**65 - 1.72712407207387e+30*cos(theta)**63 + 1.23104865429207e+31*cos(theta)**61 - 5.56251614161602e+31*cos(theta)**59 + 1.78899720268891e+32*cos(theta)**57 - 4.35914432899466e+32*cos(theta)**55 + 8.36347458469906e+32*cos(theta)**53 - 1.29638559929306e+33*cos(theta)**51 + 1.65289163909865e+33*cos(theta)**49 - 1.75591740522133e+33*cos(theta)**47 + 1.56871629342501e+33*cos(theta)**45 - 1.18642408746429e+33*cos(theta)**43 + 7.63063355399042e+32*cos(theta)**41 - 4.18536422359341e+32*cos(theta)**39 + 1.96040132091196e+32*cos(theta)**37 - 7.84160528364783e+31*cos(theta)**35 + 2.67531831638214e+31*cos(theta)**33 - 7.76562985733794e+30*cos(theta)**31 + 1.91059147283711e+30*cos(theta)**29 - 3.96372068457776e+29*cos(theta)**27 + 6.88745524894452e+28*cos(theta)**25 - 9.93860786283481e+27*cos(theta)**23 + 1.17828856105774e+27*cos(theta)**21 - 1.13245124861384e+26*cos(theta)**19 + 8.67603779179959e+24*cos(theta)**17 - 5.18655446015272e+23*cos(theta)**15 + 2.35344951735538e+22*cos(theta)**13 - 7.81477489798723e+20*cos(theta)**11 + 1.80593537558528e+19*cos(theta)**9 - 2.70102507357998e+17*cos(theta)**7 + 2.33421919939011e+15*cos(theta)**5 - 9531315636545.98*cos(theta)**3 + 11604686245.7946*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl70_m_minus_4(theta, phi):
    return 1.92168184227816e-7*(1.0 - cos(theta)**2)**2*(1.74876344710277e+27*cos(theta)**66 - 2.69863136261542e+28*cos(theta)**64 + 1.98556234563237e+29*cos(theta)**62 - 9.2708602360267e+29*cos(theta)**60 + 3.08447793567054e+30*cos(theta)**58 - 7.78418630177618e+30*cos(theta)**56 + 1.54879158975908e+31*cos(theta)**54 - 2.49304922940973e+31*cos(theta)**52 + 3.3057832781973e+31*cos(theta)**50 - 3.65816126087777e+31*cos(theta)**48 + 3.41025281179349e+31*cos(theta)**46 - 2.69641838060066e+31*cos(theta)**44 + 1.81681751285486e+31*cos(theta)**42 - 1.04634105589835e+31*cos(theta)**40 + 5.15895084450515e+30*cos(theta)**38 - 2.17822368990217e+30*cos(theta)**36 + 7.86858328347689e+29*cos(theta)**34 - 2.42675933041811e+29*cos(theta)**32 + 6.36863824279037e+28*cos(theta)**30 - 1.41561453020634e+28*cos(theta)**28 + 2.64902124959405e+27*cos(theta)**26 - 4.1410866095145e+26*cos(theta)**24 + 5.35585709571698e+25*cos(theta)**22 - 5.66225624306921e+24*cos(theta)**20 + 4.82002099544422e+23*cos(theta)**18 - 3.24159653759545e+22*cos(theta)**16 + 1.68103536953956e+21*cos(theta)**14 - 6.51231241498936e+19*cos(theta)**12 + 1.80593537558528e+18*cos(theta)**10 - 3.37628134197498e+16*cos(theta)**8 + 389036533231685.0*cos(theta)**6 - 2382828909136.49*cos(theta)**4 + 5802343122.89731*cos(theta)**2 - 2344381.05975649)*sin(4*phi)

#@torch.jit.script
def Yl70_m_minus_3(theta, phi):
    return 1.35311512253704e-5*(1.0 - cos(theta)**2)**1.5*(2.61009469716831e+25*cos(theta)**67 - 4.15174055786988e+26*cos(theta)**65 + 3.15168626290852e+27*cos(theta)**63 - 1.519813153447e+28*cos(theta)**61 + 5.22792870452633e+28*cos(theta)**59 - 1.36564671960986e+29*cos(theta)**57 + 2.81598470865288e+29*cos(theta)**55 - 4.7038664705844e+29*cos(theta)**53 + 6.4819279964653e+29*cos(theta)**51 - 7.46563522628117e+29*cos(theta)**49 + 7.25585704636914e+29*cos(theta)**47 - 5.99204084577925e+29*cos(theta)**45 + 4.22515700663921e+29*cos(theta)**43 - 2.55205135584964e+29*cos(theta)**41 + 1.32280790884747e+29*cos(theta)**39 - 5.88709105378966e+28*cos(theta)**37 + 2.24816665242197e+28*cos(theta)**35 - 7.35381615278214e+27*cos(theta)**33 + 2.05439943315819e+27*cos(theta)**31 - 4.88142941450463e+26*cos(theta)**29 + 9.81118981331129e+25*cos(theta)**27 - 1.6564346438058e+25*cos(theta)**25 + 2.32863351987695e+24*cos(theta)**23 - 2.69631249669962e+23*cos(theta)**21 + 2.53685315549696e+22*cos(theta)**19 - 1.90682149270321e+21*cos(theta)**17 + 1.12069024635971e+20*cos(theta)**15 - 5.00947108845335e+18*cos(theta)**13 + 1.64175943235026e+17*cos(theta)**11 - 3.75142371330553e+15*cos(theta)**9 + 55576647604526.4*cos(theta)**7 - 476565781827.299*cos(theta)**5 + 1934114374.2991*cos(theta)**3 - 2344381.05975649*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl70_m_minus_2(theta, phi):
    return 0.000953346187643187*(1.0 - cos(theta)**2)*(3.83837455465928e+23*cos(theta)**68 - 6.29051599677255e+24*cos(theta)**66 + 4.92450978579457e+25*cos(theta)**64 - 2.45131153781774e+26*cos(theta)**62 + 8.71321450754389e+26*cos(theta)**60 - 2.35456330967217e+27*cos(theta)**58 + 5.02854412259443e+27*cos(theta)**56 - 8.71086383441555e+27*cos(theta)**54 + 1.24652461470487e+28*cos(theta)**52 - 1.49312704525623e+28*cos(theta)**50 + 1.51163688466024e+28*cos(theta)**48 - 1.3026175751694e+28*cos(theta)**46 + 9.60262956054367e+27*cos(theta)**44 - 6.07631275202295e+27*cos(theta)**42 + 3.30701977211869e+27*cos(theta)**40 - 1.54923448783938e+27*cos(theta)**38 + 6.2449073678388e+26*cos(theta)**36 - 2.16288710375945e+26*cos(theta)**34 + 6.41999822861933e+25*cos(theta)**32 - 1.62714313816821e+25*cos(theta)**30 + 3.50399636189689e+24*cos(theta)**28 - 6.37090247617616e+23*cos(theta)**26 + 9.70263966615395e+22*cos(theta)**24 - 1.22559658940892e+22*cos(theta)**22 + 1.26842657774848e+21*cos(theta)**20 - 1.059345273724e+20*cos(theta)**18 + 7.00431403974817e+18*cos(theta)**16 - 3.57819363460954e+17*cos(theta)**14 + 1.36813286029188e+16*cos(theta)**12 - 375142371330553.0*cos(theta)**10 + 6947080950565.8*cos(theta)**8 - 79427630304.5498*cos(theta)**6 + 483528593.574776*cos(theta)**4 - 1172190.52987824*cos(theta)**2 + 472.276603496472)*sin(2*phi)

#@torch.jit.script
def Yl70_m_minus_1(theta, phi):
    return 0.0671956915356721*(1.0 - cos(theta)**2)**0.5*(5.56286167341925e+21*cos(theta)**69 - 9.38882984592918e+22*cos(theta)**67 + 7.57616890122241e+23*cos(theta)**65 - 3.8909706949488e+24*cos(theta)**63 + 1.42839582090883e+25*cos(theta)**61 - 3.99078527063079e+25*cos(theta)**59 + 8.82200723262181e+25*cos(theta)**57 - 1.58379342443919e+26*cos(theta)**55 + 2.3519332352922e+26*cos(theta)**53 - 2.92770008873771e+26*cos(theta)**51 + 3.08497323400048e+26*cos(theta)**49 - 2.77152675567958e+26*cos(theta)**47 + 2.13391768012082e+26*cos(theta)**45 - 1.41309598884255e+26*cos(theta)**43 + 8.06590188321631e+25*cos(theta)**41 - 3.97239612266509e+25*cos(theta)**39 + 1.6878128021186e+25*cos(theta)**37 - 6.17967743931272e+24*cos(theta)**35 + 1.94545400867252e+24*cos(theta)**33 - 5.24884883280068e+23*cos(theta)**31 + 1.20827460755065e+23*cos(theta)**29 - 2.35959350969487e+22*cos(theta)**27 + 3.88105586646158e+21*cos(theta)**25 - 5.32868082351704e+20*cos(theta)**23 + 6.04012656070704e+19*cos(theta)**21 - 5.57550144065265e+18*cos(theta)**19 + 4.12018472926363e+17*cos(theta)**17 - 2.38546242307302e+16*cos(theta)**15 + 1.05240989253222e+15*cos(theta)**13 - 34103851939141.2*cos(theta)**11 + 771897883396.2*cos(theta)**9 - 11346804329.2214*cos(theta)**7 + 96705718.7149551*cos(theta)**5 - 390730.176626081*cos(theta)**3 + 472.276603496472*cos(theta))*sin(phi)

#@torch.jit.script
def Yl70_m0(theta, phi):
    return 8.3628579089726e+20*cos(theta)**70 - 1.45297135612725e+22*cos(theta)**68 + 1.20798129534959e+23*cos(theta)**66 - 6.39782686055525e+23*cos(theta)**64 + 2.42443965242094e+24*cos(theta)**62 - 6.999412798058e+24*cos(theta)**60 + 1.60064091118381e+25*cos(theta)**58 - 2.97621982698181e+25*cos(theta)**56 + 4.583378533552e+25*cos(theta)**54 - 5.92485517751843e+25*cos(theta)**52 + 6.4928578226359e+25*cos(theta)**50 - 6.07620384471274e+25*cos(theta)**48 + 4.88173642224784e+25*cos(theta)**46 - 3.37966367694082e+25*cos(theta)**44 + 2.02096197116688e+25*cos(theta)**42 - 1.04507402833315e+25*cos(theta)**40 + 4.67406962213219e+24*cos(theta)**38 - 1.80641613213795e+24*cos(theta)**36 + 6.0213871071265e+23*cos(theta)**34 - 1.72611045840468e+23*cos(theta)**32 + 4.23837023449863e+22*cos(theta)**30 - 8.86816282831603e+21*cos(theta)**28 + 1.57083671466891e+21*cos(theta)**26 - 2.33648481586909e+20*cos(theta)**24 + 2.88920165403167e+19*cos(theta)**22 - 2.93365091024754e+18*cos(theta)**20 + 2.40878856070455e+17*cos(theta)**18 - 1.56894274068879e+16*cos(theta)**16 + 791063566733843.0*cos(theta)**14 - 29907264051840.4*cos(theta)**12 + 812296060667.269*cos(theta)**10 - 14925815732.9633*cos(theta)**8 + 169611542.420037*cos(theta)**6 - 1027948.74193962*cos(theta)**4 + 2484.9687556961*cos(theta)**2 - 0.999987426839477

#@torch.jit.script
def Yl70_m1(theta, phi):
    return 0.0671956915356721*(1.0 - cos(theta)**2)**0.5*(5.56286167341925e+21*cos(theta)**69 - 9.38882984592918e+22*cos(theta)**67 + 7.57616890122241e+23*cos(theta)**65 - 3.8909706949488e+24*cos(theta)**63 + 1.42839582090883e+25*cos(theta)**61 - 3.99078527063079e+25*cos(theta)**59 + 8.82200723262181e+25*cos(theta)**57 - 1.58379342443919e+26*cos(theta)**55 + 2.3519332352922e+26*cos(theta)**53 - 2.92770008873771e+26*cos(theta)**51 + 3.08497323400048e+26*cos(theta)**49 - 2.77152675567958e+26*cos(theta)**47 + 2.13391768012082e+26*cos(theta)**45 - 1.41309598884255e+26*cos(theta)**43 + 8.06590188321631e+25*cos(theta)**41 - 3.97239612266509e+25*cos(theta)**39 + 1.6878128021186e+25*cos(theta)**37 - 6.17967743931272e+24*cos(theta)**35 + 1.94545400867252e+24*cos(theta)**33 - 5.24884883280068e+23*cos(theta)**31 + 1.20827460755065e+23*cos(theta)**29 - 2.35959350969487e+22*cos(theta)**27 + 3.88105586646158e+21*cos(theta)**25 - 5.32868082351704e+20*cos(theta)**23 + 6.04012656070704e+19*cos(theta)**21 - 5.57550144065265e+18*cos(theta)**19 + 4.12018472926363e+17*cos(theta)**17 - 2.38546242307302e+16*cos(theta)**15 + 1.05240989253222e+15*cos(theta)**13 - 34103851939141.2*cos(theta)**11 + 771897883396.2*cos(theta)**9 - 11346804329.2214*cos(theta)**7 + 96705718.7149551*cos(theta)**5 - 390730.176626081*cos(theta)**3 + 472.276603496472*cos(theta))*cos(phi)

#@torch.jit.script
def Yl70_m2(theta, phi):
    return 0.000953346187643187*(1.0 - cos(theta)**2)*(3.83837455465928e+23*cos(theta)**68 - 6.29051599677255e+24*cos(theta)**66 + 4.92450978579457e+25*cos(theta)**64 - 2.45131153781774e+26*cos(theta)**62 + 8.71321450754389e+26*cos(theta)**60 - 2.35456330967217e+27*cos(theta)**58 + 5.02854412259443e+27*cos(theta)**56 - 8.71086383441555e+27*cos(theta)**54 + 1.24652461470487e+28*cos(theta)**52 - 1.49312704525623e+28*cos(theta)**50 + 1.51163688466024e+28*cos(theta)**48 - 1.3026175751694e+28*cos(theta)**46 + 9.60262956054367e+27*cos(theta)**44 - 6.07631275202295e+27*cos(theta)**42 + 3.30701977211869e+27*cos(theta)**40 - 1.54923448783938e+27*cos(theta)**38 + 6.2449073678388e+26*cos(theta)**36 - 2.16288710375945e+26*cos(theta)**34 + 6.41999822861933e+25*cos(theta)**32 - 1.62714313816821e+25*cos(theta)**30 + 3.50399636189689e+24*cos(theta)**28 - 6.37090247617616e+23*cos(theta)**26 + 9.70263966615395e+22*cos(theta)**24 - 1.22559658940892e+22*cos(theta)**22 + 1.26842657774848e+21*cos(theta)**20 - 1.059345273724e+20*cos(theta)**18 + 7.00431403974817e+18*cos(theta)**16 - 3.57819363460954e+17*cos(theta)**14 + 1.36813286029188e+16*cos(theta)**12 - 375142371330553.0*cos(theta)**10 + 6947080950565.8*cos(theta)**8 - 79427630304.5498*cos(theta)**6 + 483528593.574776*cos(theta)**4 - 1172190.52987824*cos(theta)**2 + 472.276603496472)*cos(2*phi)

#@torch.jit.script
def Yl70_m3(theta, phi):
    return 1.35311512253704e-5*(1.0 - cos(theta)**2)**1.5*(2.61009469716831e+25*cos(theta)**67 - 4.15174055786988e+26*cos(theta)**65 + 3.15168626290852e+27*cos(theta)**63 - 1.519813153447e+28*cos(theta)**61 + 5.22792870452633e+28*cos(theta)**59 - 1.36564671960986e+29*cos(theta)**57 + 2.81598470865288e+29*cos(theta)**55 - 4.7038664705844e+29*cos(theta)**53 + 6.4819279964653e+29*cos(theta)**51 - 7.46563522628117e+29*cos(theta)**49 + 7.25585704636914e+29*cos(theta)**47 - 5.99204084577925e+29*cos(theta)**45 + 4.22515700663921e+29*cos(theta)**43 - 2.55205135584964e+29*cos(theta)**41 + 1.32280790884747e+29*cos(theta)**39 - 5.88709105378966e+28*cos(theta)**37 + 2.24816665242197e+28*cos(theta)**35 - 7.35381615278214e+27*cos(theta)**33 + 2.05439943315819e+27*cos(theta)**31 - 4.88142941450463e+26*cos(theta)**29 + 9.81118981331129e+25*cos(theta)**27 - 1.6564346438058e+25*cos(theta)**25 + 2.32863351987695e+24*cos(theta)**23 - 2.69631249669962e+23*cos(theta)**21 + 2.53685315549696e+22*cos(theta)**19 - 1.90682149270321e+21*cos(theta)**17 + 1.12069024635971e+20*cos(theta)**15 - 5.00947108845335e+18*cos(theta)**13 + 1.64175943235026e+17*cos(theta)**11 - 3.75142371330553e+15*cos(theta)**9 + 55576647604526.4*cos(theta)**7 - 476565781827.299*cos(theta)**5 + 1934114374.2991*cos(theta)**3 - 2344381.05975649*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl70_m4(theta, phi):
    return 1.92168184227816e-7*(1.0 - cos(theta)**2)**2*(1.74876344710277e+27*cos(theta)**66 - 2.69863136261542e+28*cos(theta)**64 + 1.98556234563237e+29*cos(theta)**62 - 9.2708602360267e+29*cos(theta)**60 + 3.08447793567054e+30*cos(theta)**58 - 7.78418630177618e+30*cos(theta)**56 + 1.54879158975908e+31*cos(theta)**54 - 2.49304922940973e+31*cos(theta)**52 + 3.3057832781973e+31*cos(theta)**50 - 3.65816126087777e+31*cos(theta)**48 + 3.41025281179349e+31*cos(theta)**46 - 2.69641838060066e+31*cos(theta)**44 + 1.81681751285486e+31*cos(theta)**42 - 1.04634105589835e+31*cos(theta)**40 + 5.15895084450515e+30*cos(theta)**38 - 2.17822368990217e+30*cos(theta)**36 + 7.86858328347689e+29*cos(theta)**34 - 2.42675933041811e+29*cos(theta)**32 + 6.36863824279037e+28*cos(theta)**30 - 1.41561453020634e+28*cos(theta)**28 + 2.64902124959405e+27*cos(theta)**26 - 4.1410866095145e+26*cos(theta)**24 + 5.35585709571698e+25*cos(theta)**22 - 5.66225624306921e+24*cos(theta)**20 + 4.82002099544422e+23*cos(theta)**18 - 3.24159653759545e+22*cos(theta)**16 + 1.68103536953956e+21*cos(theta)**14 - 6.51231241498936e+19*cos(theta)**12 + 1.80593537558528e+18*cos(theta)**10 - 3.37628134197498e+16*cos(theta)**8 + 389036533231685.0*cos(theta)**6 - 2382828909136.49*cos(theta)**4 + 5802343122.89731*cos(theta)**2 - 2344381.05975649)*cos(4*phi)

#@torch.jit.script
def Yl70_m5(theta, phi):
    return 2.73135963587515e-9*(1.0 - cos(theta)**2)**2.5*(1.15418387508783e+29*cos(theta)**65 - 1.72712407207387e+30*cos(theta)**63 + 1.23104865429207e+31*cos(theta)**61 - 5.56251614161602e+31*cos(theta)**59 + 1.78899720268891e+32*cos(theta)**57 - 4.35914432899466e+32*cos(theta)**55 + 8.36347458469906e+32*cos(theta)**53 - 1.29638559929306e+33*cos(theta)**51 + 1.65289163909865e+33*cos(theta)**49 - 1.75591740522133e+33*cos(theta)**47 + 1.56871629342501e+33*cos(theta)**45 - 1.18642408746429e+33*cos(theta)**43 + 7.63063355399042e+32*cos(theta)**41 - 4.18536422359341e+32*cos(theta)**39 + 1.96040132091196e+32*cos(theta)**37 - 7.84160528364783e+31*cos(theta)**35 + 2.67531831638214e+31*cos(theta)**33 - 7.76562985733794e+30*cos(theta)**31 + 1.91059147283711e+30*cos(theta)**29 - 3.96372068457776e+29*cos(theta)**27 + 6.88745524894452e+28*cos(theta)**25 - 9.93860786283481e+27*cos(theta)**23 + 1.17828856105774e+27*cos(theta)**21 - 1.13245124861384e+26*cos(theta)**19 + 8.67603779179959e+24*cos(theta)**17 - 5.18655446015272e+23*cos(theta)**15 + 2.35344951735538e+22*cos(theta)**13 - 7.81477489798723e+20*cos(theta)**11 + 1.80593537558528e+19*cos(theta)**9 - 2.70102507357998e+17*cos(theta)**7 + 2.33421919939011e+15*cos(theta)**5 - 9531315636545.98*cos(theta)**3 + 11604686245.7946*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl70_m6(theta, phi):
    return 3.8861128910259e-11*(1.0 - cos(theta)**2)**3*(7.50219518807088e+30*cos(theta)**64 - 1.08808816540654e+32*cos(theta)**62 + 7.50939679118163e+32*cos(theta)**60 - 3.28188452355345e+33*cos(theta)**58 + 1.01972840553268e+34*cos(theta)**56 - 2.39752938094706e+34*cos(theta)**54 + 4.4326415298905e+34*cos(theta)**52 - 6.6115665563946e+34*cos(theta)**50 + 8.09916903158339e+34*cos(theta)**48 - 8.25281180454026e+34*cos(theta)**46 + 7.05922332041253e+34*cos(theta)**44 - 5.10162357609645e+34*cos(theta)**42 + 3.12855975713607e+34*cos(theta)**40 - 1.63229204720143e+34*cos(theta)**38 + 7.25348488737424e+33*cos(theta)**36 - 2.74456184927674e+33*cos(theta)**34 + 8.82855044406107e+32*cos(theta)**32 - 2.40734525577476e+32*cos(theta)**30 + 5.54071527122763e+31*cos(theta)**28 - 1.070204584836e+31*cos(theta)**26 + 1.72186381223613e+30*cos(theta)**24 - 2.28587980845201e+29*cos(theta)**22 + 2.47440597822124e+28*cos(theta)**20 - 2.1516573723663e+27*cos(theta)**18 + 1.47492642460593e+26*cos(theta)**16 - 7.77983169022909e+24*cos(theta)**14 + 3.059484372562e+23*cos(theta)**12 - 8.59625238778595e+21*cos(theta)**10 + 1.62534183802676e+20*cos(theta)**8 - 1.89071755150599e+18*cos(theta)**6 + 1.16710959969506e+16*cos(theta)**4 - 28593946909637.9*cos(theta)**2 + 11604686245.7946)*cos(6*phi)

#@torch.jit.script
def Yl70_m7(theta, phi):
    return 5.53579581560677e-13*(1.0 - cos(theta)**2)**3.5*(4.80140492036536e+32*cos(theta)**63 - 6.74614662552054e+33*cos(theta)**61 + 4.50563807470897e+34*cos(theta)**59 - 1.903493023661e+35*cos(theta)**57 + 5.71047907098301e+35*cos(theta)**55 - 1.29466586571141e+36*cos(theta)**53 + 2.30497359554306e+36*cos(theta)**51 - 3.3057832781973e+36*cos(theta)**49 + 3.88760113516003e+36*cos(theta)**47 - 3.79629343008852e+36*cos(theta)**45 + 3.10605826098152e+36*cos(theta)**43 - 2.14268190196051e+36*cos(theta)**41 + 1.25142390285443e+36*cos(theta)**39 - 6.20270977936543e+35*cos(theta)**37 + 2.61125455945473e+35*cos(theta)**35 - 9.33151028754091e+34*cos(theta)**33 + 2.82513614209954e+34*cos(theta)**31 - 7.22203576732428e+33*cos(theta)**29 + 1.55140027594374e+33*cos(theta)**27 - 2.78253192057359e+32*cos(theta)**25 + 4.13247314936671e+31*cos(theta)**23 - 5.02893557859441e+30*cos(theta)**21 + 4.94881195644249e+29*cos(theta)**19 - 3.87298327025934e+28*cos(theta)**17 + 2.35988227936949e+27*cos(theta)**15 - 1.08917643663207e+26*cos(theta)**13 + 3.6713812470744e+24*cos(theta)**11 - 8.59625238778595e+22*cos(theta)**9 + 1.3002734704214e+21*cos(theta)**7 - 1.13443053090359e+19*cos(theta)**5 + 4.66843839878022e+16*cos(theta)**3 - 57187893819275.9*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl70_m8(theta, phi):
    return 7.89700634562307e-15*(1.0 - cos(theta)**2)**4*(3.02488509983018e+34*cos(theta)**62 - 4.11514944156753e+35*cos(theta)**60 + 2.6583264640783e+36*cos(theta)**58 - 1.08499102348677e+37*cos(theta)**56 + 3.14076348904065e+37*cos(theta)**54 - 6.86172908827049e+37*cos(theta)**52 + 1.17553653372696e+38*cos(theta)**50 - 1.61983380631668e+38*cos(theta)**48 + 1.82717253352521e+38*cos(theta)**46 - 1.70833204353983e+38*cos(theta)**44 + 1.33560505222205e+38*cos(theta)**42 - 8.78499579803809e+37*cos(theta)**40 + 4.88055322113227e+37*cos(theta)**38 - 2.29500261836521e+37*cos(theta)**36 + 9.13939095809154e+36*cos(theta)**34 - 3.0793983948885e+36*cos(theta)**32 + 8.75792204050858e+35*cos(theta)**30 - 2.09439037252404e+35*cos(theta)**28 + 4.18878074504809e+34*cos(theta)**26 - 6.95632980143397e+33*cos(theta)**24 + 9.50468824354344e+32*cos(theta)**22 - 1.05607647150483e+32*cos(theta)**20 + 9.40274271724073e+30*cos(theta)**18 - 6.58407155944088e+29*cos(theta)**16 + 3.53982341905423e+28*cos(theta)**14 - 1.41592936762169e+27*cos(theta)**12 + 4.03851937178184e+25*cos(theta)**10 - 7.73662714900736e+23*cos(theta)**8 + 9.10191429294983e+21*cos(theta)**6 - 5.67215265451797e+19*cos(theta)**4 + 1.40053151963407e+17*cos(theta)**2 - 57187893819275.9)*cos(8*phi)

#@torch.jit.script
def Yl70_m9(theta, phi):
    return 1.12837406758519e-16*(1.0 - cos(theta)**2)**4.5*(1.87542876189471e+36*cos(theta)**61 - 2.46908966494052e+37*cos(theta)**59 + 1.54182934916541e+38*cos(theta)**57 - 6.07594973152592e+38*cos(theta)**55 + 1.69601228408195e+39*cos(theta)**53 - 3.56809912590066e+39*cos(theta)**51 + 5.8776826686348e+39*cos(theta)**49 - 7.77520227032005e+39*cos(theta)**47 + 8.40499365421598e+39*cos(theta)**45 - 7.51666099157527e+39*cos(theta)**43 + 5.60954121933262e+39*cos(theta)**41 - 3.51399831921524e+39*cos(theta)**39 + 1.85461022403026e+39*cos(theta)**37 - 8.26200942611475e+38*cos(theta)**35 + 3.10739292575112e+38*cos(theta)**33 - 9.85407486364321e+37*cos(theta)**31 + 2.62737661215258e+37*cos(theta)**29 - 5.86429304306732e+36*cos(theta)**27 + 1.0890829937125e+36*cos(theta)**25 - 1.66951915234415e+35*cos(theta)**23 + 2.09103141357956e+34*cos(theta)**21 - 2.11215294300965e+33*cos(theta)**19 + 1.69249368910333e+32*cos(theta)**17 - 1.05345144951054e+31*cos(theta)**15 + 4.95575278667593e+29*cos(theta)**13 - 1.69911524114603e+28*cos(theta)**11 + 4.03851937178184e+26*cos(theta)**9 - 6.18930171920588e+24*cos(theta)**7 + 5.4611485757699e+22*cos(theta)**5 - 2.26886106180719e+20*cos(theta)**3 + 2.80106303926813e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl70_m10(theta, phi):
    return 1.61526277895562e-18*(1.0 - cos(theta)**2)**5*(1.14401154475577e+38*cos(theta)**60 - 1.45676290231491e+39*cos(theta)**58 + 8.78842729024284e+39*cos(theta)**56 - 3.34177235233925e+40*cos(theta)**54 + 8.98886510563435e+40*cos(theta)**52 - 1.81973055420933e+41*cos(theta)**50 + 2.88006450763105e+41*cos(theta)**48 - 3.65434506705043e+41*cos(theta)**46 + 3.78224714439719e+41*cos(theta)**44 - 3.23216422637736e+41*cos(theta)**42 + 2.29991189992637e+41*cos(theta)**40 - 1.37045934449394e+41*cos(theta)**38 + 6.86205782891198e+40*cos(theta)**36 - 2.89170329914016e+40*cos(theta)**34 + 1.02543966549787e+40*cos(theta)**32 - 3.05476320772939e+39*cos(theta)**30 + 7.61939217524247e+38*cos(theta)**28 - 1.58335912162818e+38*cos(theta)**26 + 2.72270748428126e+37*cos(theta)**24 - 3.83989405039155e+36*cos(theta)**22 + 4.39116596851707e+35*cos(theta)**20 - 4.01309059171834e+34*cos(theta)**18 + 2.87723927147566e+33*cos(theta)**16 - 1.58017717426581e+32*cos(theta)**14 + 6.44247862267871e+30*cos(theta)**12 - 1.86902676526064e+29*cos(theta)**10 + 3.63466743460366e+27*cos(theta)**8 - 4.33251120344412e+25*cos(theta)**6 + 2.73057428788495e+23*cos(theta)**4 - 6.80658318542156e+20*cos(theta)**2 + 2.80106303926813e+17)*cos(10*phi)

#@torch.jit.script
def Yl70_m11(theta, phi):
    return 2.31699475653475e-20*(1.0 - cos(theta)**2)**5.5*(6.86406926853464e+39*cos(theta)**59 - 8.44922483342645e+40*cos(theta)**57 + 4.92151928253599e+41*cos(theta)**55 - 1.8045570702632e+42*cos(theta)**53 + 4.67420985492986e+42*cos(theta)**51 - 9.09865277104668e+42*cos(theta)**49 + 1.38243096366291e+43*cos(theta)**47 - 1.6809987308432e+43*cos(theta)**45 + 1.66418874353476e+43*cos(theta)**43 - 1.35750897507849e+43*cos(theta)**41 + 9.19964759970549e+42*cos(theta)**39 - 5.20774550907698e+42*cos(theta)**37 + 2.47034081840831e+42*cos(theta)**35 - 9.83179121707656e+41*cos(theta)**33 + 3.28140692959319e+41*cos(theta)**31 - 9.16428962318818e+40*cos(theta)**29 + 2.13342980906789e+40*cos(theta)**27 - 4.11673371623326e+39*cos(theta)**25 + 6.53449796227501e+38*cos(theta)**23 - 8.44776691086141e+37*cos(theta)**21 + 8.78233193703414e+36*cos(theta)**19 - 7.22356306509302e+35*cos(theta)**17 + 4.60358283436106e+34*cos(theta)**15 - 2.21224804397213e+33*cos(theta)**13 + 7.73097434721445e+31*cos(theta)**11 - 1.86902676526064e+30*cos(theta)**9 + 2.90773394768293e+28*cos(theta)**7 - 2.59950672206647e+26*cos(theta)**5 + 1.09222971515398e+24*cos(theta)**3 - 1.36131663708431e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl70_m12(theta, phi):
    return 3.33113412074688e-22*(1.0 - cos(theta)**2)**6*(4.04980086843544e+41*cos(theta)**58 - 4.81605815505308e+42*cos(theta)**56 + 2.7068356053948e+43*cos(theta)**54 - 9.56415247239495e+43*cos(theta)**52 + 2.38384702601423e+44*cos(theta)**50 - 4.45833985781287e+44*cos(theta)**48 + 6.49742552921566e+44*cos(theta)**46 - 7.56449428879438e+44*cos(theta)**44 + 7.15601159719948e+44*cos(theta)**42 - 5.56578679782182e+44*cos(theta)**40 + 3.58786256388514e+44*cos(theta)**38 - 1.92686583835848e+44*cos(theta)**36 + 8.64619286442909e+43*cos(theta)**34 - 3.24449110163526e+43*cos(theta)**32 + 1.01723614817389e+43*cos(theta)**30 - 2.65764399072457e+42*cos(theta)**28 + 5.7602604844833e+41*cos(theta)**26 - 1.02918342905831e+41*cos(theta)**24 + 1.50293453132325e+40*cos(theta)**22 - 1.7740310512809e+39*cos(theta)**20 + 1.66864306803649e+38*cos(theta)**18 - 1.22800572106581e+37*cos(theta)**16 + 6.90537425154159e+35*cos(theta)**14 - 2.87592245716377e+34*cos(theta)**12 + 8.50407178193589e+32*cos(theta)**10 - 1.68212408873457e+31*cos(theta)**8 + 2.03541376337805e+29*cos(theta)**6 - 1.29975336103324e+27*cos(theta)**4 + 3.27668914546194e+24*cos(theta)**2 - 1.36131663708431e+21)*cos(12*phi)

#@torch.jit.script
def Yl70_m13(theta, phi):
    return 4.80108147403523e-24*(1.0 - cos(theta)**2)**6.5*(2.34888450369255e+43*cos(theta)**57 - 2.69699256682972e+44*cos(theta)**55 + 1.46169122691319e+45*cos(theta)**53 - 4.97335928564537e+45*cos(theta)**51 + 1.19192351300711e+46*cos(theta)**49 - 2.14000313175018e+46*cos(theta)**47 + 2.9888157434392e+46*cos(theta)**45 - 3.32837748706953e+46*cos(theta)**43 + 3.00552487082378e+46*cos(theta)**41 - 2.22631471912873e+46*cos(theta)**39 + 1.36338777427635e+46*cos(theta)**37 - 6.93671701809054e+45*cos(theta)**35 + 2.93970557390589e+45*cos(theta)**33 - 1.03823715252328e+45*cos(theta)**31 + 3.05170844452166e+44*cos(theta)**29 - 7.4414031740288e+43*cos(theta)**27 + 1.49766772596566e+43*cos(theta)**25 - 2.47004022973995e+42*cos(theta)**23 + 3.30645596891116e+41*cos(theta)**21 - 3.54806210256179e+40*cos(theta)**19 + 3.00355752246568e+39*cos(theta)**17 - 1.9648091537053e+38*cos(theta)**15 + 9.66752395215823e+36*cos(theta)**13 - 3.45110694859653e+35*cos(theta)**11 + 8.50407178193589e+33*cos(theta)**9 - 1.34569927098766e+32*cos(theta)**7 + 1.22124825802683e+30*cos(theta)**5 - 5.19901344413294e+27*cos(theta)**3 + 6.55337829092388e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl70_m14(theta, phi):
    return 6.93844268438917e-26*(1.0 - cos(theta)**2)**7*(1.33886416710476e+45*cos(theta)**56 - 1.48334591175635e+46*cos(theta)**54 + 7.74696350263991e+46*cos(theta)**52 - 2.53641323567914e+47*cos(theta)**50 + 5.84042521373486e+47*cos(theta)**48 - 1.00580147192258e+48*cos(theta)**46 + 1.34496708454764e+48*cos(theta)**44 - 1.4312023194399e+48*cos(theta)**42 + 1.23226519703775e+48*cos(theta)**40 - 8.68262740460204e+47*cos(theta)**38 + 5.04453476482251e+47*cos(theta)**36 - 2.42785095633169e+47*cos(theta)**34 + 9.70102839388944e+46*cos(theta)**32 - 3.21853517282218e+46*cos(theta)**30 + 8.84995448911283e+45*cos(theta)**28 - 2.00917885698778e+45*cos(theta)**26 + 3.74416931491415e+44*cos(theta)**24 - 5.6810925284019e+43*cos(theta)**22 + 6.94355753471343e+42*cos(theta)**20 - 6.74131799486741e+41*cos(theta)**18 + 5.10604778819165e+40*cos(theta)**16 - 2.94721373055795e+39*cos(theta)**14 + 1.25677811378057e+38*cos(theta)**12 - 3.79621764345618e+36*cos(theta)**10 + 7.6536646037423e+34*cos(theta)**8 - 9.4198948969136e+32*cos(theta)**6 + 6.10624129013414e+30*cos(theta)**4 - 1.55970403323988e+28*cos(theta)**2 + 6.55337829092388e+24)*cos(14*phi)

#@torch.jit.script
def Yl70_m15(theta, phi):
    return 1.00567702523587e-27*(1.0 - cos(theta)**2)**7.5*(7.49763933578663e+46*cos(theta)**55 - 8.01006792348428e+47*cos(theta)**53 + 4.02842102137275e+48*cos(theta)**51 - 1.26820661783957e+49*cos(theta)**49 + 2.80340410259273e+49*cos(theta)**47 - 4.62668677084388e+49*cos(theta)**45 + 5.91785517200962e+49*cos(theta)**43 - 6.01104974164757e+49*cos(theta)**41 + 4.92906078815101e+49*cos(theta)**39 - 3.29939841374878e+49*cos(theta)**37 + 1.8160325153361e+49*cos(theta)**35 - 8.25469325152774e+48*cos(theta)**33 + 3.10432908604462e+48*cos(theta)**31 - 9.65560551846655e+47*cos(theta)**29 + 2.47798725695159e+47*cos(theta)**27 - 5.22386502816822e+46*cos(theta)**25 + 8.98600635579396e+45*cos(theta)**23 - 1.24984035624842e+45*cos(theta)**21 + 1.38871150694269e+44*cos(theta)**19 - 1.21343723907613e+43*cos(theta)**17 + 8.16967646110664e+41*cos(theta)**15 - 4.12609922278113e+40*cos(theta)**13 + 1.50813373653668e+39*cos(theta)**11 - 3.79621764345618e+37*cos(theta)**9 + 6.12293168299384e+35*cos(theta)**7 - 5.65193693814816e+33*cos(theta)**5 + 2.44249651605366e+31*cos(theta)**3 - 3.11940806647977e+28*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl70_m16(theta, phi):
    return 1.4622713074207e-29*(1.0 - cos(theta)**2)**8*(4.12370163468265e+48*cos(theta)**54 - 4.24533599944667e+49*cos(theta)**52 + 2.0544947209001e+50*cos(theta)**50 - 6.21421242741389e+50*cos(theta)**48 + 1.31759992821858e+51*cos(theta)**46 - 2.08200904687975e+51*cos(theta)**44 + 2.54467772396414e+51*cos(theta)**42 - 2.4645303940755e+51*cos(theta)**40 + 1.92233370737889e+51*cos(theta)**38 - 1.22077741308705e+51*cos(theta)**36 + 6.35611380367636e+50*cos(theta)**34 - 2.72404877300415e+50*cos(theta)**32 + 9.62342016673832e+49*cos(theta)**30 - 2.8001256003553e+49*cos(theta)**28 + 6.6905655937693e+48*cos(theta)**26 - 1.30596625704205e+48*cos(theta)**24 + 2.06678146183261e+47*cos(theta)**22 - 2.62466474812168e+46*cos(theta)**20 + 2.6385518631911e+45*cos(theta)**18 - 2.06284330642943e+44*cos(theta)**16 + 1.225451469166e+43*cos(theta)**14 - 5.36392898961547e+41*cos(theta)**12 + 1.65894711019035e+40*cos(theta)**10 - 3.41659587911056e+38*cos(theta)**8 + 4.28605217809569e+36*cos(theta)**6 - 2.82596846907408e+34*cos(theta)**4 + 7.32748954816097e+31*cos(theta)**2 - 3.11940806647977e+28)*cos(16*phi)

#@torch.jit.script
def Yl70_m17(theta, phi):
    return 2.1333958805615e-31*(1.0 - cos(theta)**2)**8.5*(2.22679888272863e+50*cos(theta)**53 - 2.20757471971227e+51*cos(theta)**51 + 1.02724736045005e+52*cos(theta)**49 - 2.98282196515867e+52*cos(theta)**47 + 6.06095966980549e+52*cos(theta)**45 - 9.16083980627089e+52*cos(theta)**43 + 1.06876464406494e+53*cos(theta)**41 - 9.85812157630201e+52*cos(theta)**39 + 7.30486808803979e+52*cos(theta)**37 - 4.39479868711337e+52*cos(theta)**35 + 2.16107869324996e+52*cos(theta)**33 - 8.71695607361329e+51*cos(theta)**31 + 2.8870260500215e+51*cos(theta)**29 - 7.84035168099484e+50*cos(theta)**27 + 1.73954705438002e+50*cos(theta)**25 - 3.13431901690093e+49*cos(theta)**23 + 4.54691921603174e+48*cos(theta)**21 - 5.24932949624335e+47*cos(theta)**19 + 4.74939335374399e+46*cos(theta)**17 - 3.30054929028708e+45*cos(theta)**15 + 1.71563205683239e+44*cos(theta)**13 - 6.43671478753856e+42*cos(theta)**11 + 1.65894711019035e+41*cos(theta)**9 - 2.73327670328845e+39*cos(theta)**7 + 2.57163130685741e+37*cos(theta)**5 - 1.13038738762963e+35*cos(theta)**3 + 1.46549790963219e+32*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl70_m18(theta, phi):
    return 3.12386445344419e-33*(1.0 - cos(theta)**2)**9*(1.18020340784617e+52*cos(theta)**52 - 1.12586310705326e+53*cos(theta)**50 + 5.03351206620525e+53*cos(theta)**48 - 1.40192632362457e+54*cos(theta)**46 + 2.72743185141247e+54*cos(theta)**44 - 3.93916111669648e+54*cos(theta)**42 + 4.38193504066624e+54*cos(theta)**40 - 3.84466741475778e+54*cos(theta)**38 + 2.70280119257472e+54*cos(theta)**36 - 1.53817954048968e+54*cos(theta)**34 + 7.13155968772488e+53*cos(theta)**32 - 2.70225638282012e+53*cos(theta)**30 + 8.37237554506234e+52*cos(theta)**28 - 2.11689495386861e+52*cos(theta)**26 + 4.34886763595004e+51*cos(theta)**24 - 7.20893373887214e+50*cos(theta)**22 + 9.54853035366666e+49*cos(theta)**20 - 9.97372604286237e+48*cos(theta)**18 + 8.07396870136477e+47*cos(theta)**16 - 4.95082393543062e+46*cos(theta)**14 + 2.23032167388211e+45*cos(theta)**12 - 7.08038626629242e+43*cos(theta)**10 + 1.49305239917132e+42*cos(theta)**8 - 1.91329369230192e+40*cos(theta)**6 + 1.28581565342871e+38*cos(theta)**4 - 3.3911621628889e+35*cos(theta)**2 + 1.46549790963219e+32)*cos(18*phi)

#@torch.jit.script
def Yl70_m19(theta, phi):
    return 4.59193261320621e-35*(1.0 - cos(theta)**2)**9.5*(6.1370577208001e+53*cos(theta)**51 - 5.62931553526628e+54*cos(theta)**49 + 2.41608579177852e+55*cos(theta)**47 - 6.44886108867304e+55*cos(theta)**45 + 1.20007001462149e+56*cos(theta)**43 - 1.65444766901252e+56*cos(theta)**41 + 1.7527740162665e+56*cos(theta)**39 - 1.46097361760796e+56*cos(theta)**37 + 9.730084293269e+55*cos(theta)**35 - 5.22981043766491e+55*cos(theta)**33 + 2.28209910007196e+55*cos(theta)**31 - 8.10676914846036e+54*cos(theta)**29 + 2.34426515261746e+54*cos(theta)**27 - 5.50392688005837e+53*cos(theta)**25 + 1.04372823262801e+53*cos(theta)**23 - 1.58596542255187e+52*cos(theta)**21 + 1.90970607073333e+51*cos(theta)**19 - 1.79527068771523e+50*cos(theta)**17 + 1.29183499221836e+49*cos(theta)**15 - 6.93115350960287e+47*cos(theta)**13 + 2.67638600865854e+46*cos(theta)**11 - 7.08038626629242e+44*cos(theta)**9 + 1.19444191933705e+43*cos(theta)**7 - 1.14797621538115e+41*cos(theta)**5 + 5.14326261371483e+38*cos(theta)**3 - 6.78232432577779e+35*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl70_m20(theta, phi):
    return 6.77780645942075e-37*(1.0 - cos(theta)**2)**10*(3.12989943760805e+55*cos(theta)**50 - 2.75836461228048e+56*cos(theta)**48 + 1.13556032213591e+57*cos(theta)**46 - 2.90198748990287e+57*cos(theta)**44 + 5.16030106287239e+57*cos(theta)**42 - 6.78323544295135e+57*cos(theta)**40 + 6.83581866343934e+57*cos(theta)**38 - 5.40560238514944e+57*cos(theta)**36 + 3.40552950264415e+57*cos(theta)**34 - 1.72583744442942e+57*cos(theta)**32 + 7.07450721022308e+56*cos(theta)**30 - 2.35096305305351e+56*cos(theta)**28 + 6.32951591206713e+55*cos(theta)**26 - 1.37598172001459e+55*cos(theta)**24 + 2.40057493504442e+54*cos(theta)**22 - 3.33052738735893e+53*cos(theta)**20 + 3.62844153439333e+52*cos(theta)**18 - 3.05196016911589e+51*cos(theta)**16 + 1.93775248832755e+50*cos(theta)**14 - 9.01049956248373e+48*cos(theta)**12 + 2.94402460952439e+47*cos(theta)**10 - 6.37234763966318e+45*cos(theta)**8 + 8.36109343535937e+43*cos(theta)**6 - 5.73988107690575e+41*cos(theta)**4 + 1.54297878411445e+39*cos(theta)**2 - 6.78232432577779e+35)*cos(20*phi)

#@torch.jit.script
def Yl70_m21(theta, phi):
    return 1.00480888130137e-38*(1.0 - cos(theta)**2)**10.5*(1.56494971880403e+57*cos(theta)**49 - 1.32401501389463e+58*cos(theta)**47 + 5.22357748182516e+58*cos(theta)**45 - 1.27687449555726e+59*cos(theta)**43 + 2.16732644640641e+59*cos(theta)**41 - 2.71329417718054e+59*cos(theta)**39 + 2.59761109210695e+59*cos(theta)**37 - 1.9460168586538e+59*cos(theta)**35 + 1.15788003089901e+59*cos(theta)**33 - 5.52267982217414e+58*cos(theta)**31 + 2.12235216306692e+58*cos(theta)**29 - 6.58269654854982e+57*cos(theta)**27 + 1.64567413713745e+57*cos(theta)**25 - 3.30235612803502e+56*cos(theta)**23 + 5.28126485709773e+55*cos(theta)**21 - 6.66105477471786e+54*cos(theta)**19 + 6.53119476190799e+53*cos(theta)**17 - 4.88313627058542e+52*cos(theta)**15 + 2.71285348365856e+51*cos(theta)**13 - 1.08125994749805e+50*cos(theta)**11 + 2.94402460952439e+48*cos(theta)**9 - 5.09787811173054e+46*cos(theta)**7 + 5.01665606121562e+44*cos(theta)**5 - 2.2959524307623e+42*cos(theta)**3 + 3.0859575682289e+39*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl70_m22(theta, phi):
    return 1.49655096517071e-40*(1.0 - cos(theta)**2)**11*(7.66825362213973e+58*cos(theta)**48 - 6.22287056530476e+59*cos(theta)**46 + 2.35060986682132e+60*cos(theta)**44 - 5.49056033089623e+60*cos(theta)**42 + 8.88603843026626e+60*cos(theta)**40 - 1.05818472910041e+61*cos(theta)**38 + 9.61116104079571e+60*cos(theta)**36 - 6.8110590052883e+60*cos(theta)**34 + 3.82100410196674e+60*cos(theta)**32 - 1.71203074487398e+60*cos(theta)**30 + 6.15482127289408e+59*cos(theta)**28 - 1.77732806810845e+59*cos(theta)**26 + 4.11418534284363e+58*cos(theta)**24 - 7.59541909448056e+57*cos(theta)**22 + 1.10906561999052e+57*cos(theta)**20 - 1.26560040719639e+56*cos(theta)**18 + 1.11030310952436e+55*cos(theta)**16 - 7.32470440587812e+53*cos(theta)**14 + 3.52670952875613e+52*cos(theta)**12 - 1.18938594224785e+51*cos(theta)**10 + 2.64962214857195e+49*cos(theta)**8 - 3.56851467821138e+47*cos(theta)**6 + 2.50832803060781e+45*cos(theta)**4 - 6.8878572922869e+42*cos(theta)**2 + 3.0859575682289e+39)*cos(22*phi)

#@torch.jit.script
def Yl70_m23(theta, phi):
    return 2.23990406748289e-42*(1.0 - cos(theta)**2)**11.5*(3.68076173862707e+60*cos(theta)**47 - 2.86252046004019e+61*cos(theta)**45 + 1.03426834140138e+62*cos(theta)**43 - 2.30603533897642e+62*cos(theta)**41 + 3.5544153721065e+62*cos(theta)**39 - 4.02110197058156e+62*cos(theta)**37 + 3.46001797468646e+62*cos(theta)**35 - 2.31576006179802e+62*cos(theta)**33 + 1.22272131262936e+62*cos(theta)**31 - 5.13609223462195e+61*cos(theta)**29 + 1.72334995641034e+61*cos(theta)**27 - 4.62105297708197e+60*cos(theta)**25 + 9.87404482282472e+59*cos(theta)**23 - 1.67099220078572e+59*cos(theta)**21 + 2.21813123998105e+58*cos(theta)**19 - 2.27808073295351e+57*cos(theta)**17 + 1.77648497523897e+56*cos(theta)**15 - 1.02545861682294e+55*cos(theta)**13 + 4.23205143450736e+53*cos(theta)**11 - 1.18938594224785e+52*cos(theta)**9 + 2.11969771885756e+50*cos(theta)**7 - 2.14110880692683e+48*cos(theta)**5 + 1.00333121224312e+46*cos(theta)**3 - 1.37757145845738e+43*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl70_m24(theta, phi):
    return 3.36989650069038e-44*(1.0 - cos(theta)**2)**12*(1.72995801715472e+62*cos(theta)**46 - 1.28813420701809e+63*cos(theta)**44 + 4.44735386802594e+63*cos(theta)**42 - 9.4547448898033e+63*cos(theta)**40 + 1.38622199512154e+64*cos(theta)**38 - 1.48780772911518e+64*cos(theta)**36 + 1.21100629114026e+64*cos(theta)**34 - 7.64200820393347e+63*cos(theta)**32 + 3.790436069151e+63*cos(theta)**30 - 1.48946674804037e+63*cos(theta)**28 + 4.65304488230792e+62*cos(theta)**26 - 1.15526324427049e+62*cos(theta)**24 + 2.27103030924969e+61*cos(theta)**22 - 3.50908362165002e+60*cos(theta)**20 + 4.21444935596399e+59*cos(theta)**18 - 3.87273724602096e+58*cos(theta)**16 + 2.66472746285846e+57*cos(theta)**14 - 1.33309620186982e+56*cos(theta)**12 + 4.6552565779581e+54*cos(theta)**10 - 1.07044734802307e+53*cos(theta)**8 + 1.48378840320029e+51*cos(theta)**6 - 1.07055440346341e+49*cos(theta)**4 + 3.00999363672937e+46*cos(theta)**2 - 1.37757145845738e+43)*cos(24*phi)

#@torch.jit.script
def Yl70_m25(theta, phi):
    return 5.09771843463546e-46*(1.0 - cos(theta)**2)**12.5*(7.95780687891173e+63*cos(theta)**45 - 5.66779051087957e+64*cos(theta)**43 + 1.8678886245709e+65*cos(theta)**41 - 3.78189795592132e+65*cos(theta)**39 + 5.26764358146184e+65*cos(theta)**37 - 5.35610782481463e+65*cos(theta)**35 + 4.11742138987688e+65*cos(theta)**33 - 2.44544262525871e+65*cos(theta)**31 + 1.1371308207453e+65*cos(theta)**29 - 4.17050689451303e+64*cos(theta)**27 + 1.20979166940006e+64*cos(theta)**25 - 2.77263178624918e+63*cos(theta)**23 + 4.99626668034931e+62*cos(theta)**21 - 7.01816724330003e+61*cos(theta)**19 + 7.58600884073518e+60*cos(theta)**17 - 6.19637959363354e+59*cos(theta)**15 + 3.73061844800185e+58*cos(theta)**13 - 1.59971544224378e+57*cos(theta)**11 + 4.6552565779581e+55*cos(theta)**9 - 8.56357878418454e+53*cos(theta)**7 + 8.90273041920175e+51*cos(theta)**5 - 4.28221761385366e+49*cos(theta)**3 + 6.01998727345875e+46*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl70_m26(theta, phi):
    return 7.75593160683268e-48*(1.0 - cos(theta)**2)**13*(3.58101309551028e+65*cos(theta)**44 - 2.43714991967822e+66*cos(theta)**42 + 7.65834336074068e+66*cos(theta)**40 - 1.47494020280932e+67*cos(theta)**38 + 1.94902812514088e+67*cos(theta)**36 - 1.87463773868512e+67*cos(theta)**34 + 1.35874905865937e+67*cos(theta)**32 - 7.580872138302e+66*cos(theta)**30 + 3.29767938016137e+66*cos(theta)**28 - 1.12603686151852e+66*cos(theta)**26 + 3.02447917350015e+65*cos(theta)**24 - 6.37705310837312e+64*cos(theta)**22 + 1.04921600287336e+64*cos(theta)**20 - 1.33345177622701e+63*cos(theta)**18 + 1.28962150292498e+62*cos(theta)**16 - 9.29456939045031e+60*cos(theta)**14 + 4.8498039824024e+59*cos(theta)**12 - 1.75968698646816e+58*cos(theta)**10 + 4.18973092016229e+56*cos(theta)**8 - 5.99450514892918e+54*cos(theta)**6 + 4.45136520960088e+52*cos(theta)**4 - 1.2846652841561e+50*cos(theta)**2 + 6.01998727345875e+46)*cos(26*phi)

#@torch.jit.script
def Yl70_m27(theta, phi):
    return 1.187194197688e-49*(1.0 - cos(theta)**2)**13.5*(1.57564576202452e+67*cos(theta)**43 - 1.02360296626485e+68*cos(theta)**41 + 3.06333734429627e+68*cos(theta)**39 - 5.6047727706754e+68*cos(theta)**37 + 7.01650125050717e+68*cos(theta)**35 - 6.37376831152941e+68*cos(theta)**33 + 4.34799698770999e+68*cos(theta)**31 - 2.2742616414906e+68*cos(theta)**29 + 9.23350226445184e+67*cos(theta)**27 - 2.92769583994815e+67*cos(theta)**25 + 7.25875001640036e+66*cos(theta)**23 - 1.40295168384209e+66*cos(theta)**21 + 2.09843200574671e+65*cos(theta)**19 - 2.40021319720861e+64*cos(theta)**17 + 2.06339440467997e+63*cos(theta)**15 - 1.30123971466304e+62*cos(theta)**13 + 5.81976477888288e+60*cos(theta)**11 - 1.75968698646816e+59*cos(theta)**9 + 3.35178473612983e+57*cos(theta)**7 - 3.59670308935751e+55*cos(theta)**5 + 1.78054608384035e+53*cos(theta)**3 - 2.56933056831219e+50*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl70_m28(theta, phi):
    return 1.82883489525325e-51*(1.0 - cos(theta)**2)**14*(6.77527677670544e+68*cos(theta)**42 - 4.19677216168589e+69*cos(theta)**40 + 1.19470156427555e+70*cos(theta)**38 - 2.0737659251499e+70*cos(theta)**36 + 2.45577543767751e+70*cos(theta)**34 - 2.10334354280471e+70*cos(theta)**32 + 1.3478790661901e+70*cos(theta)**30 - 6.59535876032274e+69*cos(theta)**28 + 2.493045611402e+69*cos(theta)**26 - 7.31923959987036e+68*cos(theta)**24 + 1.66951250377208e+68*cos(theta)**22 - 2.94619853606838e+67*cos(theta)**20 + 3.98702081091875e+66*cos(theta)**18 - 4.08036243525464e+65*cos(theta)**16 + 3.09509160701995e+64*cos(theta)**14 - 1.69161162906196e+63*cos(theta)**12 + 6.40174125677117e+61*cos(theta)**10 - 1.58371828782134e+60*cos(theta)**8 + 2.34624931529088e+58*cos(theta)**6 - 1.79835154467875e+56*cos(theta)**4 + 5.34163825152105e+53*cos(theta)**2 - 2.56933056831219e+50)*cos(28*phi)

#@torch.jit.script
def Yl70_m29(theta, phi):
    return 2.83616998909815e-53*(1.0 - cos(theta)**2)**14.5*(2.84561624621629e+70*cos(theta)**41 - 1.67870886467436e+71*cos(theta)**39 + 4.53986594424707e+71*cos(theta)**37 - 7.46555733053963e+71*cos(theta)**35 + 8.34963648810353e+71*cos(theta)**33 - 6.73069933697506e+71*cos(theta)**31 + 4.04363719857029e+71*cos(theta)**29 - 1.84670045289037e+71*cos(theta)**27 + 6.48191858964519e+70*cos(theta)**25 - 1.75661750396889e+70*cos(theta)**23 + 3.67292750829858e+69*cos(theta)**21 - 5.89239707213676e+68*cos(theta)**19 + 7.17663745965375e+67*cos(theta)**17 - 6.52857989640742e+66*cos(theta)**15 + 4.33312824982794e+65*cos(theta)**13 - 2.02993395487435e+64*cos(theta)**11 + 6.40174125677117e+62*cos(theta)**9 - 1.26697463025708e+61*cos(theta)**7 + 1.40774958917453e+59*cos(theta)**5 - 7.19340617871501e+56*cos(theta)**3 + 1.06832765030421e+54*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl70_m30(theta, phi):
    return 4.42935336553025e-55*(1.0 - cos(theta)**2)**15*(1.16670266094868e+72*cos(theta)**40 - 6.54696457222999e+72*cos(theta)**38 + 1.67975039937142e+73*cos(theta)**36 - 2.61294506568887e+73*cos(theta)**34 + 2.75538004107417e+73*cos(theta)**32 - 2.08651679446227e+73*cos(theta)**30 + 1.17265478758538e+73*cos(theta)**28 - 4.98609122280399e+72*cos(theta)**26 + 1.6204796474113e+72*cos(theta)**24 - 4.04022025912844e+71*cos(theta)**22 + 7.71314776742702e+70*cos(theta)**20 - 1.11955544370598e+70*cos(theta)**18 + 1.22002836814114e+69*cos(theta)**16 - 9.79286984461114e+67*cos(theta)**14 + 5.63306672477632e+66*cos(theta)**12 - 2.23292735036178e+65*cos(theta)**10 + 5.76156713109405e+63*cos(theta)**8 - 8.86882241179953e+61*cos(theta)**6 + 7.03874794587264e+59*cos(theta)**4 - 2.1580218536145e+57*cos(theta)**2 + 1.06832765030421e+54)*cos(30*phi)

#@torch.jit.script
def Yl70_m31(theta, phi):
    return 6.96866594416903e-57*(1.0 - cos(theta)**2)**15.5*(4.66681064379471e+73*cos(theta)**39 - 2.4878465374474e+74*cos(theta)**37 + 6.0471014377371e+74*cos(theta)**35 - 8.88401322334216e+74*cos(theta)**33 + 8.81721613143733e+74*cos(theta)**31 - 6.25955038338681e+74*cos(theta)**29 + 3.28343340523907e+74*cos(theta)**27 - 1.29638371792904e+74*cos(theta)**25 + 3.88915115378712e+73*cos(theta)**23 - 8.88848457008257e+72*cos(theta)**21 + 1.5426295534854e+72*cos(theta)**19 - 2.01519979867077e+71*cos(theta)**17 + 1.95204538902582e+70*cos(theta)**15 - 1.37100177824556e+69*cos(theta)**13 + 6.75968006973158e+67*cos(theta)**11 - 2.23292735036178e+66*cos(theta)**9 + 4.60925370487524e+64*cos(theta)**7 - 5.32129344707972e+62*cos(theta)**5 + 2.81549917834906e+60*cos(theta)**3 - 4.31604370722901e+57*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl70_m32(theta, phi):
    return 1.10488545620251e-58*(1.0 - cos(theta)**2)**16*(1.82005615107994e+75*cos(theta)**38 - 9.20503218855536e+75*cos(theta)**36 + 2.11648550320799e+76*cos(theta)**34 - 2.93172436370291e+76*cos(theta)**32 + 2.73333700074557e+76*cos(theta)**30 - 1.81526961118217e+76*cos(theta)**28 + 8.8652701941455e+75*cos(theta)**26 - 3.2409592948226e+75*cos(theta)**24 + 8.94504765371037e+74*cos(theta)**22 - 1.86658175971734e+74*cos(theta)**20 + 2.93099615162227e+73*cos(theta)**18 - 3.42583965774031e+72*cos(theta)**16 + 2.92806808353873e+71*cos(theta)**14 - 1.78230231171923e+70*cos(theta)**12 + 7.43564807670474e+68*cos(theta)**10 - 2.0096346153256e+67*cos(theta)**8 + 3.22647759341267e+65*cos(theta)**6 - 2.66064672353986e+63*cos(theta)**4 + 8.44649753504717e+60*cos(theta)**2 - 4.31604370722901e+57)*cos(32*phi)

#@torch.jit.script
def Yl70_m33(theta, phi):
    return 1.7660656608883e-60*(1.0 - cos(theta)**2)**16.5*(6.91621337410376e+76*cos(theta)**37 - 3.31381158787993e+77*cos(theta)**35 + 7.19605071090715e+77*cos(theta)**33 - 9.38151796384932e+77*cos(theta)**31 + 8.20001100223672e+77*cos(theta)**29 - 5.08275491131009e+77*cos(theta)**27 + 2.30497025047783e+77*cos(theta)**25 - 7.77830230757423e+76*cos(theta)**23 + 1.96791048381628e+76*cos(theta)**21 - 3.73316351943468e+75*cos(theta)**19 + 5.27579307292008e+74*cos(theta)**17 - 5.4813434523845e+73*cos(theta)**15 + 4.09929531695422e+72*cos(theta)**13 - 2.13876277406307e+71*cos(theta)**11 + 7.43564807670474e+69*cos(theta)**9 - 1.60770769226048e+68*cos(theta)**7 + 1.9358865560476e+66*cos(theta)**5 - 1.06425868941594e+64*cos(theta)**3 + 1.68929950700943e+61*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl70_m34(theta, phi):
    return 2.84701211076783e-62*(1.0 - cos(theta)**2)**17*(2.55899894841839e+78*cos(theta)**36 - 1.15983405575798e+79*cos(theta)**34 + 2.37469673459936e+79*cos(theta)**32 - 2.90827056879329e+79*cos(theta)**30 + 2.37800319064865e+79*cos(theta)**28 - 1.37234382605372e+79*cos(theta)**26 + 5.76242562619458e+78*cos(theta)**24 - 1.78900953074207e+78*cos(theta)**22 + 4.13261201601419e+77*cos(theta)**20 - 7.09301068692589e+76*cos(theta)**18 + 8.96884822396414e+75*cos(theta)**16 - 8.22201517857675e+74*cos(theta)**14 + 5.32908391204049e+73*cos(theta)**12 - 2.35263905146938e+72*cos(theta)**10 + 6.69208326903426e+70*cos(theta)**8 - 1.12539538458234e+69*cos(theta)**6 + 9.67943278023801e+66*cos(theta)**4 - 3.19277606824783e+64*cos(theta)**2 + 1.68929950700943e+61)*cos(34*phi)

#@torch.jit.script
def Yl70_m35(theta, phi):
    return 4.63066554430613e-64*(1.0 - cos(theta)**2)**17.5*(9.21239621430621e+79*cos(theta)**35 - 3.94343578957712e+80*cos(theta)**33 + 7.59902955071795e+80*cos(theta)**31 - 8.72481170637987e+80*cos(theta)**29 + 6.65840893381621e+80*cos(theta)**27 - 3.56809394773968e+80*cos(theta)**25 + 1.3829821502867e+80*cos(theta)**23 - 3.93582096763256e+79*cos(theta)**21 + 8.26522403202838e+78*cos(theta)**19 - 1.27674192364666e+78*cos(theta)**17 + 1.43501571583426e+77*cos(theta)**15 - 1.15108212500075e+76*cos(theta)**13 + 6.39490069444858e+74*cos(theta)**11 - 2.35263905146938e+73*cos(theta)**9 + 5.35366661522741e+71*cos(theta)**7 - 6.75237230749403e+69*cos(theta)**5 + 3.8717731120952e+67*cos(theta)**3 - 6.38555213649566e+64*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl70_m36(theta, phi):
    return 7.60250054324482e-66*(1.0 - cos(theta)**2)**18*(3.22433867500717e+81*cos(theta)**34 - 1.30133381056045e+82*cos(theta)**32 + 2.35569916072256e+82*cos(theta)**30 - 2.53019539485016e+82*cos(theta)**28 + 1.79777041213038e+82*cos(theta)**26 - 8.9202348693492e+81*cos(theta)**24 + 3.18085894565941e+81*cos(theta)**22 - 8.26522403202838e+80*cos(theta)**20 + 1.57039256608539e+80*cos(theta)**18 - 2.17046127019932e+79*cos(theta)**16 + 2.15252357375139e+78*cos(theta)**14 - 1.49640676250097e+77*cos(theta)**12 + 7.03439076389344e+75*cos(theta)**10 - 2.11737514632244e+74*cos(theta)**8 + 3.74756663065919e+72*cos(theta)**6 - 3.37618615374702e+70*cos(theta)**4 + 1.16153193362856e+68*cos(theta)**2 - 6.38555213649566e+64)*cos(36*phi)

#@torch.jit.script
def Yl70_m37(theta, phi):
    return 1.26044851950185e-67*(1.0 - cos(theta)**2)**18.5*(1.09627514950244e+83*cos(theta)**33 - 4.16426819379344e+83*cos(theta)**31 + 7.06709748216769e+83*cos(theta)**29 - 7.08454710558045e+83*cos(theta)**27 + 4.67420307153898e+83*cos(theta)**25 - 2.14085636864381e+83*cos(theta)**23 + 6.99788968045069e+82*cos(theta)**21 - 1.65304480640568e+82*cos(theta)**19 + 2.82670661895371e+81*cos(theta)**17 - 3.47273803231892e+80*cos(theta)**15 + 3.01353300325195e+79*cos(theta)**13 - 1.79568811500116e+78*cos(theta)**11 + 7.03439076389344e+76*cos(theta)**9 - 1.69390011705795e+75*cos(theta)**7 + 2.24853997839551e+73*cos(theta)**5 - 1.35047446149881e+71*cos(theta)**3 + 2.32306386725712e+68*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl70_m38(theta, phi):
    return 2.11133071047807e-69*(1.0 - cos(theta)**2)**19*(3.61770799335805e+84*cos(theta)**32 - 1.29092314007597e+85*cos(theta)**30 + 2.04945826982863e+85*cos(theta)**28 - 1.91282771850672e+85*cos(theta)**26 + 1.16855076788475e+85*cos(theta)**24 - 4.92396964788076e+84*cos(theta)**22 + 1.46955683289465e+84*cos(theta)**20 - 3.14078513217078e+83*cos(theta)**18 + 4.8054012522213e+82*cos(theta)**16 - 5.20910704847837e+81*cos(theta)**14 + 3.91759290422754e+80*cos(theta)**12 - 1.97525692650128e+79*cos(theta)**10 + 6.3309516875041e+77*cos(theta)**8 - 1.18573008194057e+76*cos(theta)**6 + 1.12426998919776e+74*cos(theta)**4 - 4.05142338449642e+71*cos(theta)**2 + 2.32306386725712e+68)*cos(38*phi)

#@torch.jit.script
def Yl70_m39(theta, phi):
    return 3.57493398645019e-71*(1.0 - cos(theta)**2)**19.5*(1.15766655787458e+86*cos(theta)**31 - 3.8727694202279e+86*cos(theta)**29 + 5.73848315552017e+86*cos(theta)**27 - 4.97335206811748e+86*cos(theta)**25 + 2.80452184292339e+86*cos(theta)**23 - 1.08327332253377e+86*cos(theta)**21 + 2.93911366578929e+85*cos(theta)**19 - 5.65341323790741e+84*cos(theta)**17 + 7.68864200355408e+83*cos(theta)**15 - 7.29274986786972e+82*cos(theta)**13 + 4.70111148507304e+81*cos(theta)**11 - 1.97525692650128e+80*cos(theta)**9 + 5.06476135000328e+78*cos(theta)**7 - 7.1143804916434e+76*cos(theta)**5 + 4.49707995679103e+74*cos(theta)**3 - 8.10284676899284e+71*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl70_m40(theta, phi):
    return 6.1219649269969e-73*(1.0 - cos(theta)**2)**20*(3.58876632941118e+87*cos(theta)**30 - 1.12310313186609e+88*cos(theta)**28 + 1.54939045199045e+88*cos(theta)**26 - 1.24333801702937e+88*cos(theta)**24 + 6.4504002387238e+87*cos(theta)**22 - 2.27487397732091e+87*cos(theta)**20 + 5.58431596499965e+86*cos(theta)**18 - 9.6108025044426e+85*cos(theta)**16 + 1.15329630053311e+85*cos(theta)**14 - 9.48057482823064e+83*cos(theta)**12 + 5.17122263358035e+82*cos(theta)**10 - 1.77773123385115e+81*cos(theta)**8 + 3.5453329450023e+79*cos(theta)**6 - 3.5571902458217e+77*cos(theta)**4 + 1.34912398703731e+75*cos(theta)**2 - 8.10284676899284e+71)*cos(40*phi)

#@torch.jit.script
def Yl70_m41(theta, phi):
    return 1.06088600525106e-74*(1.0 - cos(theta)**2)**20.5*(1.07662989882336e+89*cos(theta)**29 - 3.14468876922505e+89*cos(theta)**27 + 4.02841517517516e+89*cos(theta)**25 - 2.98401124087049e+89*cos(theta)**23 + 1.41908805251924e+89*cos(theta)**21 - 4.54974795464182e+88*cos(theta)**19 + 1.00517687369994e+88*cos(theta)**17 - 1.53772840071082e+87*cos(theta)**15 + 1.61461482074636e+86*cos(theta)**13 - 1.13766897938768e+85*cos(theta)**11 + 5.17122263358035e+83*cos(theta)**9 - 1.42218498708092e+82*cos(theta)**7 + 2.12719976700138e+80*cos(theta)**5 - 1.42287609832868e+78*cos(theta)**3 + 2.69824797407462e+75*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl70_m42(theta, phi):
    return 1.86149001125438e-76*(1.0 - cos(theta)**2)**21*(3.12222670658773e+90*cos(theta)**28 - 8.49065967690764e+90*cos(theta)**26 + 1.00710379379379e+91*cos(theta)**24 - 6.86322585400212e+90*cos(theta)**22 + 2.98008491029039e+90*cos(theta)**20 - 8.64452111381946e+89*cos(theta)**18 + 1.70880068528989e+89*cos(theta)**16 - 2.30659260106622e+88*cos(theta)**14 + 2.09899926697026e+87*cos(theta)**12 - 1.25143587732644e+86*cos(theta)**10 + 4.65410037022231e+84*cos(theta)**8 - 9.95529490956645e+82*cos(theta)**6 + 1.06359988350069e+81*cos(theta)**4 - 4.26862829498604e+78*cos(theta)**2 + 2.69824797407462e+75)*cos(42*phi)

#@torch.jit.script
def Yl70_m43(theta, phi):
    return 3.30934826064584e-78*(1.0 - cos(theta)**2)**21.5*(8.74223477844564e+91*cos(theta)**27 - 2.20757151599599e+92*cos(theta)**25 + 2.41704910510509e+92*cos(theta)**23 - 1.50990968788047e+92*cos(theta)**21 + 5.96016982058079e+91*cos(theta)**19 - 1.5560138004875e+91*cos(theta)**17 + 2.73408109646383e+90*cos(theta)**15 - 3.22922964149271e+89*cos(theta)**13 + 2.51879912036432e+88*cos(theta)**11 - 1.25143587732644e+87*cos(theta)**9 + 3.72328029617785e+85*cos(theta)**7 - 5.97317694573987e+83*cos(theta)**5 + 4.25439953400276e+81*cos(theta)**3 - 8.53725658997208e+78*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl70_m44(theta, phi):
    return 5.96496864287317e-80*(1.0 - cos(theta)**2)**22*(2.36040339018032e+93*cos(theta)**26 - 5.51892878998997e+93*cos(theta)**24 + 5.55921294174172e+93*cos(theta)**22 - 3.17081034454898e+93*cos(theta)**20 + 1.13243226591035e+93*cos(theta)**18 - 2.64522346082876e+92*cos(theta)**16 + 4.10112164469575e+91*cos(theta)**14 - 4.19799853394053e+90*cos(theta)**12 + 2.77067903240075e+89*cos(theta)**10 - 1.1262922895938e+88*cos(theta)**8 + 2.6062962073245e+86*cos(theta)**6 - 2.98658847286993e+84*cos(theta)**4 + 1.27631986020083e+82*cos(theta)**2 - 8.53725658997208e+78)*cos(44*phi)

#@torch.jit.script
def Yl70_m45(theta, phi):
    return 1.09086892600705e-81*(1.0 - cos(theta)**2)**22.5*(6.13704881446884e+94*cos(theta)**25 - 1.32454290959759e+95*cos(theta)**23 + 1.22302684718318e+95*cos(theta)**21 - 6.34162068909796e+94*cos(theta)**19 + 2.03837807863863e+94*cos(theta)**17 - 4.23235753732601e+93*cos(theta)**15 + 5.74157030257404e+92*cos(theta)**13 - 5.03759824072863e+91*cos(theta)**11 + 2.77067903240075e+90*cos(theta)**9 - 9.0103383167504e+88*cos(theta)**7 + 1.5637777243947e+87*cos(theta)**5 - 1.19463538914797e+85*cos(theta)**3 + 2.55263972040165e+82*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl70_m46(theta, phi):
    return 2.02569274121716e-83*(1.0 - cos(theta)**2)**23*(1.53426220361721e+96*cos(theta)**24 - 3.04644869207446e+96*cos(theta)**22 + 2.56835637908467e+96*cos(theta)**20 - 1.20490793092861e+96*cos(theta)**18 + 3.46524273368567e+95*cos(theta)**16 - 6.34853630598901e+94*cos(theta)**14 + 7.46404139334626e+93*cos(theta)**12 - 5.5413580648015e+92*cos(theta)**10 + 2.49361112916067e+91*cos(theta)**8 - 6.30723682172528e+89*cos(theta)**6 + 7.81888862197349e+87*cos(theta)**4 - 3.58390616744392e+85*cos(theta)**2 + 2.55263972040165e+82)*cos(46*phi)

#@torch.jit.script
def Yl70_m47(theta, phi):
    return 3.822742281856e-85*(1.0 - cos(theta)**2)**23.5*(3.68222928868131e+97*cos(theta)**23 - 6.70218712256381e+97*cos(theta)**21 + 5.13671275816935e+97*cos(theta)**19 - 2.1688342756715e+97*cos(theta)**17 + 5.54438837389707e+96*cos(theta)**15 - 8.88795082838462e+95*cos(theta)**13 + 8.95684967201551e+94*cos(theta)**11 - 5.5413580648015e+93*cos(theta)**9 + 1.99488890332854e+92*cos(theta)**7 - 3.78434209303517e+90*cos(theta)**5 + 3.12755544878939e+88*cos(theta)**3 - 7.16781233488784e+85*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl70_m48(theta, phi):
    return 7.33787143759487e-87*(1.0 - cos(theta)**2)**24*(8.469127363967e+98*cos(theta)**22 - 1.4074592957384e+99*cos(theta)**20 + 9.75975424052176e+98*cos(theta)**18 - 3.68701826864155e+98*cos(theta)**16 + 8.31658256084561e+97*cos(theta)**14 - 1.15543360769e+97*cos(theta)**12 + 9.85253463921706e+95*cos(theta)**10 - 4.98722225832135e+94*cos(theta)**8 + 1.39642223232998e+93*cos(theta)**6 - 1.89217104651758e+91*cos(theta)**4 + 9.38266634636818e+88*cos(theta)**2 - 7.16781233488784e+85)*cos(48*phi)

#@torch.jit.script
def Yl70_m49(theta, phi):
    return 1.43411928977543e-88*(1.0 - cos(theta)**2)**24.5*(1.86320802007274e+100*cos(theta)**21 - 2.8149185914768e+100*cos(theta)**19 + 1.75675576329392e+100*cos(theta)**17 - 5.89922922982649e+99*cos(theta)**15 + 1.16432155851839e+99*cos(theta)**13 - 1.386520329228e+98*cos(theta)**11 + 9.85253463921706e+96*cos(theta)**9 - 3.98977780665708e+95*cos(theta)**7 + 8.37853339397986e+93*cos(theta)**5 - 7.56868418607034e+91*cos(theta)**3 + 1.87653326927364e+89*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl70_m50(theta, phi):
    return 2.85683400722986e-90*(1.0 - cos(theta)**2)**25*(3.91273684215275e+101*cos(theta)**20 - 5.34834532380592e+101*cos(theta)**18 + 2.98648479759966e+101*cos(theta)**16 - 8.84884384473973e+100*cos(theta)**14 + 1.5136180260739e+100*cos(theta)**12 - 1.5251723621508e+99*cos(theta)**10 + 8.86728117529535e+97*cos(theta)**8 - 2.79284446465995e+96*cos(theta)**6 + 4.18926669698993e+94*cos(theta)**4 - 2.2706052558211e+92*cos(theta)**2 + 1.87653326927364e+89)*cos(50*phi)

#@torch.jit.script
def Yl70_m51(theta, phi):
    return 5.80734094599917e-92*(1.0 - cos(theta)**2)**25.5*(7.82547368430551e+102*cos(theta)**19 - 9.62702158285066e+102*cos(theta)**17 + 4.77837567615945e+102*cos(theta)**15 - 1.23883813826356e+102*cos(theta)**13 + 1.81634163128868e+101*cos(theta)**11 - 1.5251723621508e+100*cos(theta)**9 + 7.09382494023628e+98*cos(theta)**7 - 1.67570667879597e+97*cos(theta)**5 + 1.67570667879597e+95*cos(theta)**3 - 4.5412105116422e+92*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl70_m52(theta, phi):
    return 1.20620356626626e-93*(1.0 - cos(theta)**2)**26*(1.48684000001805e+104*cos(theta)**18 - 1.63659366908461e+104*cos(theta)**16 + 7.16756351423918e+103*cos(theta)**14 - 1.61048957974263e+103*cos(theta)**12 + 1.99797579441755e+102*cos(theta)**10 - 1.37265512593572e+101*cos(theta)**8 + 4.9656774581654e+99*cos(theta)**6 - 8.37853339397986e+97*cos(theta)**4 + 5.02712003638792e+95*cos(theta)**2 - 4.5412105116422e+92)*cos(52*phi)

#@torch.jit.script
def Yl70_m53(theta, phi):
    return 2.5634910168844e-95*(1.0 - cos(theta)**2)**26.5*(2.67631200003248e+105*cos(theta)**17 - 2.61854987053538e+105*cos(theta)**15 + 1.00345889199349e+105*cos(theta)**13 - 1.93258749569116e+104*cos(theta)**11 + 1.99797579441755e+103*cos(theta)**9 - 1.09812410074858e+102*cos(theta)**7 + 2.97940647489924e+100*cos(theta)**5 - 3.35141335759194e+98*cos(theta)**3 + 1.00542400727758e+96*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl70_m54(theta, phi):
    return 5.58337113012323e-97*(1.0 - cos(theta)**2)**27*(4.54973040005522e+106*cos(theta)**16 - 3.92782480580307e+106*cos(theta)**14 + 1.30449655959153e+106*cos(theta)**12 - 2.12584624526027e+105*cos(theta)**10 + 1.79817821497579e+104*cos(theta)**8 - 7.68686870524004e+102*cos(theta)**6 + 1.48970323744962e+101*cos(theta)**4 - 1.00542400727758e+99*cos(theta)**2 + 1.00542400727758e+96)*cos(54*phi)

#@torch.jit.script
def Yl70_m55(theta, phi):
    return 1.24847973905654e-98*(1.0 - cos(theta)**2)**27.5*(7.27956864008836e+107*cos(theta)**15 - 5.4989547281243e+107*cos(theta)**13 + 1.56539587150984e+107*cos(theta)**11 - 2.12584624526027e+106*cos(theta)**9 + 1.43854257198064e+105*cos(theta)**7 - 4.61212122314402e+103*cos(theta)**5 + 5.95881294979848e+101*cos(theta)**3 - 2.01084801455517e+99*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl70_m56(theta, phi):
    return 2.87177623153215e-100*(1.0 - cos(theta)**2)**28*(1.09193529601325e+109*cos(theta)**14 - 7.14864114656159e+108*cos(theta)**12 + 1.72193545866082e+108*cos(theta)**10 - 1.91326162073424e+107*cos(theta)**8 + 1.00697980038644e+106*cos(theta)**6 - 2.30606061157201e+104*cos(theta)**4 + 1.78764388493954e+102*cos(theta)**2 - 2.01084801455517e+99)*cos(56*phi)

#@torch.jit.script
def Yl70_m57(theta, phi):
    return 6.81058971792623e-102*(1.0 - cos(theta)**2)**28.5*(1.52870941441855e+110*cos(theta)**13 - 8.5783693758739e+109*cos(theta)**11 + 1.72193545866082e+109*cos(theta)**9 - 1.5306092965874e+108*cos(theta)**7 + 6.04187880231867e+106*cos(theta)**5 - 9.22424244628804e+104*cos(theta)**3 + 3.57528776987909e+102*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl70_m58(theta, phi):
    return 1.66958316686443e-103*(1.0 - cos(theta)**2)**29*(1.98732223874412e+111*cos(theta)**12 - 9.4362063134613e+110*cos(theta)**10 + 1.54974191279474e+110*cos(theta)**8 - 1.07142650761118e+109*cos(theta)**6 + 3.02093940115933e+107*cos(theta)**4 - 2.76727273388641e+105*cos(theta)**2 + 3.57528776987909e+102)*cos(58*phi)

#@torch.jit.script
def Yl70_m59(theta, phi):
    return 4.24348409997014e-105*(1.0 - cos(theta)**2)**29.5*(2.38478668649295e+112*cos(theta)**11 - 9.4362063134613e+111*cos(theta)**9 + 1.23979353023579e+111*cos(theta)**7 - 6.42855904566706e+109*cos(theta)**5 + 1.20837576046373e+108*cos(theta)**3 - 5.53454546777283e+105*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl70_m60(theta, phi):
    return 1.12215942258632e-106*(1.0 - cos(theta)**2)**30*(2.62326535514224e+113*cos(theta)**10 - 8.49258568211517e+112*cos(theta)**8 + 8.67855471165054e+111*cos(theta)**6 - 3.21427952283353e+110*cos(theta)**4 + 3.6251272813912e+108*cos(theta)**2 - 5.53454546777283e+105)*cos(60*phi)

#@torch.jit.script
def Yl70_m61(theta, phi):
    return 3.10040845585289e-108*(1.0 - cos(theta)**2)**30.5*(2.62326535514224e+114*cos(theta)**9 - 6.79406854569213e+113*cos(theta)**7 + 5.20713282699032e+112*cos(theta)**5 - 1.28571180913341e+111*cos(theta)**3 + 7.2502545627824e+108*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl70_m62(theta, phi):
    return 8.99519727500161e-110*(1.0 - cos(theta)**2)**31*(2.36093881962802e+115*cos(theta)**8 - 4.75584798198449e+114*cos(theta)**6 + 2.60356641349516e+113*cos(theta)**4 - 3.85713542740024e+111*cos(theta)**2 + 7.2502545627824e+108)*cos(62*phi)

#@torch.jit.script
def Yl70_m63(theta, phi):
    return 2.75765465786572e-111*(1.0 - cos(theta)**2)**31.5*(1.88875105570241e+116*cos(theta)**7 - 2.8535087891907e+115*cos(theta)**5 + 1.04142656539806e+114*cos(theta)**3 - 7.71427085480048e+111*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl70_m64(theta, phi):
    return 9.00406163506351e-113*(1.0 - cos(theta)**2)**32*(1.32212573899169e+117*cos(theta)**6 - 1.42675439459535e+116*cos(theta)**4 + 3.12427969619419e+114*cos(theta)**2 - 7.71427085480048e+111)*cos(64*phi)

#@torch.jit.script
def Yl70_m65(theta, phi):
    return 3.16370477326006e-114*(1.0 - cos(theta)**2)**32.5*(7.93275443395014e+117*cos(theta)**5 - 5.70701757838139e+116*cos(theta)**3 + 6.24855939238839e+114*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl70_m66(theta, phi):
    return 1.21322539806989e-115*(1.0 - cos(theta)**2)**33*(3.96637721697507e+118*cos(theta)**4 - 1.71210527351442e+117*cos(theta)**2 + 6.24855939238839e+114)*cos(66*phi)

#@torch.jit.script
def Yl70_m67(theta, phi):
    return 5.18264204688737e-117*(1.0 - cos(theta)**2)**33.5*(1.58655088679003e+119*cos(theta)**3 - 3.42421054702884e+117*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl70_m68(theta, phi):
    return 2.54712960481231e-118*(1.0 - cos(theta)**2)**34*(4.75965266037008e+119*cos(theta)**2 - 3.42421054702884e+117)*cos(68*phi)

#@torch.jit.script
def Yl70_m69(theta, phi):
    return 14.542326871995*(1.0 - cos(theta)**2)**34.5*cos(69*phi)*cos(theta)

#@torch.jit.script
def Yl70_m70(theta, phi):
    return 1.22905094295194*(1.0 - cos(theta)**2)**35*cos(70*phi)

#@torch.jit.script
def Yl71_m_minus_71(theta, phi):
    return 1.23337099473571*(1.0 - cos(theta)**2)**35.5*sin(71*phi)

#@torch.jit.script
def Yl71_m_minus_70(theta, phi):
    return 14.697311642374*(1.0 - cos(theta)**2)**35*sin(70*phi)*cos(theta)

#@torch.jit.script
def Yl71_m_minus_69(theta, phi):
    return 1.83881521262701e-120*(1.0 - cos(theta)**2)**34.5*(6.71111025112181e+121*cos(theta)**2 - 4.75965266037008e+119)*sin(69*phi)

#@torch.jit.script
def Yl71_m_minus_68(theta, phi):
    return 3.76844979029729e-119*(1.0 - cos(theta)**2)**34*(2.23703675037394e+121*cos(theta)**3 - 4.75965266037008e+119*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl71_m_minus_67(theta, phi):
    return 8.88587355583423e-118*(1.0 - cos(theta)**2)**33.5*(5.59259187593484e+120*cos(theta)**4 - 2.37982633018504e+119*cos(theta)**2 + 8.56052636757209e+116)*sin(67*phi)

#@torch.jit.script
def Yl71_m_minus_66(theta, phi):
    return 2.33412803219294e-116*(1.0 - cos(theta)**2)**33*(1.11851837518697e+120*cos(theta)**5 - 7.93275443395013e+118*cos(theta)**3 + 8.56052636757209e+116*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl71_m_minus_65(theta, phi):
    return 6.69207166525422e-115*(1.0 - cos(theta)**2)**32.5*(1.86419729197828e+119*cos(theta)**6 - 1.98318860848753e+118*cos(theta)**4 + 4.28026318378604e+116*cos(theta)**2 - 1.04142656539806e+114)*sin(65*phi)

#@torch.jit.script
def Yl71_m_minus_64(theta, phi):
    return 2.06480506732716e-113*(1.0 - cos(theta)**2)**32*(2.6631389885404e+118*cos(theta)**7 - 3.96637721697507e+117*cos(theta)**5 + 1.42675439459535e+116*cos(theta)**3 - 1.04142656539806e+114*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl71_m_minus_63(theta, phi):
    return 6.78564187335636e-112*(1.0 - cos(theta)**2)**31.5*(3.3289237356755e+117*cos(theta)**8 - 6.61062869495845e+116*cos(theta)**6 + 3.56688598648837e+115*cos(theta)**4 - 5.20713282699032e+113*cos(theta)**2 + 9.64283856850059e+110)*sin(63*phi)

#@torch.jit.script
def Yl71_m_minus_62(theta, phi):
    return 2.35648450820151e-110*(1.0 - cos(theta)**2)**31*(3.69880415075056e+116*cos(theta)**9 - 9.44375527851207e+115*cos(theta)**7 + 7.13377197297674e+114*cos(theta)**5 - 1.73571094233011e+113*cos(theta)**3 + 9.64283856850059e+110*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl71_m_minus_61(theta, phi):
    return 8.59390224853277e-109*(1.0 - cos(theta)**2)**30.5*(3.69880415075056e+115*cos(theta)**10 - 1.18046940981401e+115*cos(theta)**8 + 1.18896199549612e+114*cos(theta)**6 - 4.33927735582527e+112*cos(theta)**4 + 4.8214192842503e+110*cos(theta)**2 - 7.2502545627824e+107)*sin(61*phi)

#@torch.jit.script
def Yl71_m_minus_60(theta, phi):
    return 3.27471657254262e-107*(1.0 - cos(theta)**2)**30*(3.36254922795505e+114*cos(theta)**11 - 1.31163267757112e+114*cos(theta)**9 + 1.69851713642303e+113*cos(theta)**7 - 8.67855471165054e+111*cos(theta)**5 + 1.60713976141677e+110*cos(theta)**3 - 7.2502545627824e+107*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl71_m_minus_59(theta, phi):
    return 1.29837453329626e-105*(1.0 - cos(theta)**2)**29.5*(2.80212435662921e+113*cos(theta)**12 - 1.31163267757112e+113*cos(theta)**10 + 2.12314642052879e+112*cos(theta)**8 - 1.44642578527509e+111*cos(theta)**6 + 4.01784940354191e+109*cos(theta)**4 - 3.6251272813912e+107*cos(theta)**2 + 4.61212122314402e+104)*sin(59*phi)

#@torch.jit.script
def Yl71_m_minus_58(theta, phi):
    return 5.33756701552661e-104*(1.0 - cos(theta)**2)**29*(2.15548027433016e+112*cos(theta)**13 - 1.19239334324647e+112*cos(theta)**11 + 2.35905157836532e+111*cos(theta)**9 - 2.06632255039298e+110*cos(theta)**7 + 8.03569880708383e+108*cos(theta)**5 - 1.20837576046373e+107*cos(theta)**3 + 4.61212122314402e+104*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl71_m_minus_57(theta, phi):
    return 2.26830898890119e-102*(1.0 - cos(theta)**2)**28.5*(1.53962876737869e+111*cos(theta)**14 - 9.93661119372061e+110*cos(theta)**12 + 2.35905157836532e+110*cos(theta)**10 - 2.58290318799123e+109*cos(theta)**8 + 1.33928313451397e+108*cos(theta)**6 - 3.02093940115933e+106*cos(theta)**4 + 2.30606061157201e+104*cos(theta)**2 - 2.55377697848506e+101)*sin(57*phi)

#@torch.jit.script
def Yl71_m_minus_56(theta, phi):
    return 9.93923200490332e-101*(1.0 - cos(theta)**2)**28*(1.02641917825246e+110*cos(theta)**15 - 7.64354707209277e+109*cos(theta)**13 + 2.14459234396848e+109*cos(theta)**11 - 2.86989243110137e+108*cos(theta)**9 + 1.91326162073424e+107*cos(theta)**7 - 6.04187880231867e+105*cos(theta)**5 + 7.68686870524004e+103*cos(theta)**3 - 2.55377697848506e+101*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl71_m_minus_55(theta, phi):
    return 4.48037824681915e-99*(1.0 - cos(theta)**2)**27.5*(6.41511986407786e+108*cos(theta)**16 - 5.45967648006627e+108*cos(theta)**14 + 1.7871602866404e+108*cos(theta)**12 - 2.86989243110137e+107*cos(theta)**10 + 2.39157702591781e+106*cos(theta)**8 - 1.00697980038644e+105*cos(theta)**6 + 1.92171717631001e+103*cos(theta)**4 - 1.27688848924253e+101*cos(theta)**2 + 1.25678000909698e+98)*sin(55*phi)

#@torch.jit.script
def Yl71_m_minus_54(theta, phi):
    return 2.07359727383235e-97*(1.0 - cos(theta)**2)**27*(3.7735999200458e+107*cos(theta)**17 - 3.63978432004418e+107*cos(theta)**15 + 1.37473868203107e+107*cos(theta)**13 - 2.60899311918306e+106*cos(theta)**11 + 2.65730780657534e+105*cos(theta)**9 - 1.43854257198064e+104*cos(theta)**7 + 3.84343435262002e+102*cos(theta)**5 - 4.25629496414177e+100*cos(theta)**3 + 1.25678000909698e+98*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl71_m_minus_53(theta, phi):
    return 9.83593550283913e-96*(1.0 - cos(theta)**2)**26.5*(2.09644440002545e+106*cos(theta)**18 - 2.27486520002761e+106*cos(theta)**16 + 9.81956201450768e+105*cos(theta)**14 - 2.17416093265255e+105*cos(theta)**12 + 2.65730780657534e+104*cos(theta)**10 - 1.79817821497579e+103*cos(theta)**8 + 6.40572392103336e+101*cos(theta)**6 - 1.06407374103544e+100*cos(theta)**4 + 6.2839000454849e+97*cos(theta)**2 - 5.58568892931991e+94)*sin(53*phi)

#@torch.jit.script
def Yl71_m_minus_52(theta, phi):
    return 4.77422975694428e-94*(1.0 - cos(theta)**2)**26*(1.10339178948708e+105*cos(theta)**19 - 1.33815600001624e+105*cos(theta)**17 + 6.54637467633845e+104*cos(theta)**15 - 1.67243148665581e+104*cos(theta)**13 + 2.41573436961395e+103*cos(theta)**11 - 1.99797579441755e+102*cos(theta)**9 + 9.15103417290481e+100*cos(theta)**7 - 2.12814748207088e+99*cos(theta)**5 + 2.09463334849497e+97*cos(theta)**3 - 5.58568892931991e+94*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl71_m_minus_51(theta, phi):
    return 2.36794095448655e-92*(1.0 - cos(theta)**2)**25.5*(5.51695894743538e+103*cos(theta)**20 - 7.43420000009023e+103*cos(theta)**18 + 4.09148417271153e+103*cos(theta)**16 - 1.19459391903986e+103*cos(theta)**14 + 2.01311197467829e+102*cos(theta)**12 - 1.99797579441755e+101*cos(theta)**10 + 1.1438792716131e+100*cos(theta)**8 - 3.54691247011814e+98*cos(theta)**6 + 5.23658337123741e+96*cos(theta)**4 - 2.79284446465995e+94*cos(theta)**2 + 2.2706052558211e+91)*sin(51*phi)

#@torch.jit.script
def Yl71_m_minus_50(theta, phi):
    return 1.19856179900749e-90*(1.0 - cos(theta)**2)**25*(2.62712330830256e+102*cos(theta)**21 - 3.91273684215275e+102*cos(theta)**19 + 2.40675539571267e+102*cos(theta)**17 - 7.96395946026575e+101*cos(theta)**15 + 1.54854767282945e+101*cos(theta)**13 - 1.81634163128868e+100*cos(theta)**11 + 1.270976968459e+99*cos(theta)**9 - 5.06701781445449e+97*cos(theta)**7 + 1.04731667424748e+96*cos(theta)**5 - 9.30948154886651e+93*cos(theta)**3 + 2.2706052558211e+91*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl71_m_minus_49(theta, phi):
    return 6.18392846630575e-89*(1.0 - cos(theta)**2)**24.5*(1.19414695831935e+101*cos(theta)**22 - 1.95636842107638e+101*cos(theta)**20 + 1.33708633095148e+101*cos(theta)**18 - 4.9774746626661e+100*cos(theta)**16 + 1.10610548059247e+100*cos(theta)**14 - 1.5136180260739e+99*cos(theta)**12 + 1.270976968459e+98*cos(theta)**10 - 6.33377226806811e+96*cos(theta)**8 + 1.74552779041247e+95*cos(theta)**6 - 2.32737038721663e+93*cos(theta)**4 + 1.13530262791055e+91*cos(theta)**2 - 8.52969667851653e+87)*sin(49*phi)

#@torch.jit.script
def Yl71_m_minus_48(theta, phi):
    return 3.24877023999585e-87*(1.0 - cos(theta)**2)**24*(5.19194329704064e+99*cos(theta)**23 - 9.3160401003637e+99*cos(theta)**21 + 7.037296478692e+99*cos(theta)**19 - 2.92792627215653e+99*cos(theta)**17 + 7.37403653728311e+98*cos(theta)**15 - 1.16432155851839e+98*cos(theta)**13 + 1.15543360769e+97*cos(theta)**11 - 7.0375247422979e+95*cos(theta)**9 + 2.49361112916067e+94*cos(theta)**7 - 4.65474077443326e+92*cos(theta)**5 + 3.78434209303517e+90*cos(theta)**3 - 8.52969667851653e+87*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl71_m_minus_47(theta, phi):
    return 1.73619339517346e-85*(1.0 - cos(theta)**2)**23.5*(2.16330970710027e+98*cos(theta)**24 - 4.2345636819835e+98*cos(theta)**22 + 3.518648239346e+98*cos(theta)**20 - 1.62662570675363e+98*cos(theta)**18 + 4.60877283580194e+97*cos(theta)**16 - 8.31658256084561e+96*cos(theta)**14 + 9.62861339741667e+95*cos(theta)**12 - 7.0375247422979e+94*cos(theta)**10 + 3.11701391145084e+93*cos(theta)**8 - 7.75790129072209e+91*cos(theta)**6 + 9.46085523258792e+89*cos(theta)**4 - 4.26484833925827e+87*cos(theta)**2 + 2.98658847286993e+84)*sin(47*phi)

#@torch.jit.script
def Yl71_m_minus_46(theta, phi):
    return 9.42994387102045e-84*(1.0 - cos(theta)**2)**23*(8.65323882840107e+96*cos(theta)**25 - 1.84111464434065e+97*cos(theta)**23 + 1.67554678064095e+97*cos(theta)**21 - 8.56118793028224e+96*cos(theta)**19 + 2.71104284458938e+96*cos(theta)**17 - 5.54438837389707e+95*cos(theta)**15 + 7.40662569032052e+94*cos(theta)**13 - 6.39774976572536e+93*cos(theta)**11 + 3.46334879050093e+92*cos(theta)**9 - 1.1082716129603e+91*cos(theta)**7 + 1.89217104651758e+89*cos(theta)**5 - 1.42161611308609e+87*cos(theta)**3 + 2.98658847286993e+84*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl71_m_minus_45(theta, phi):
    return 5.20102226077753e-82*(1.0 - cos(theta)**2)**22.5*(3.32816878015426e+95*cos(theta)**26 - 7.67131101808605e+95*cos(theta)**24 + 7.61612173018615e+95*cos(theta)**22 - 4.28059396514112e+95*cos(theta)**20 + 1.50613491366077e+95*cos(theta)**18 - 3.46524273368567e+94*cos(theta)**16 + 5.29044692165751e+93*cos(theta)**14 - 5.33145813810447e+92*cos(theta)**12 + 3.46334879050093e+91*cos(theta)**10 - 1.38533951620037e+90*cos(theta)**8 + 3.15361841086264e+88*cos(theta)**6 - 3.55404028271522e+86*cos(theta)**4 + 1.49329423643497e+84*cos(theta)**2 - 9.8178450784679e+80)*sin(45*phi)

#@torch.jit.script
def Yl71_m_minus_44(theta, phi):
    return 2.9107143653895e-80*(1.0 - cos(theta)**2)**22*(1.23265510376084e+94*cos(theta)**27 - 3.06852440723442e+94*cos(theta)**25 + 3.31135727399398e+94*cos(theta)**23 - 2.03837807863863e+94*cos(theta)**21 + 7.92702586137245e+93*cos(theta)**19 - 2.03837807863863e+93*cos(theta)**17 + 3.52696461443834e+92*cos(theta)**15 - 4.10112164469575e+91*cos(theta)**13 + 3.1484989004554e+90*cos(theta)**11 - 1.53926612911153e+89*cos(theta)**9 + 4.5051691583752e+87*cos(theta)**7 - 7.10808056543044e+85*cos(theta)**5 + 4.97764745478322e+83*cos(theta)**3 - 9.8178450784679e+80*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl71_m_minus_43(theta, phi):
    return 1.65168614259395e-78*(1.0 - cos(theta)**2)**21.5*(4.4023396562887e+92*cos(theta)**28 - 1.18020169509016e+93*cos(theta)**26 + 1.37973219749749e+93*cos(theta)**24 - 9.26535490290286e+92*cos(theta)**22 + 3.96351293068622e+92*cos(theta)**20 - 1.13243226591035e+92*cos(theta)**18 + 2.20435288402396e+91*cos(theta)**16 - 2.9293726033541e+90*cos(theta)**14 + 2.62374908371283e+89*cos(theta)**12 - 1.53926612911153e+88*cos(theta)**10 + 5.631461447969e+86*cos(theta)**8 - 1.18468009423841e+85*cos(theta)**6 + 1.24441186369581e+83*cos(theta)**4 - 4.90892253923395e+80*cos(theta)**2 + 3.04902021070432e+77)*sin(43*phi)

#@torch.jit.script
def Yl71_m_minus_42(theta, phi):
    return 9.49683625092251e-77*(1.0 - cos(theta)**2)**21*(1.51804815734093e+91*cos(theta)**29 - 4.37111738922282e+91*cos(theta)**27 + 5.51892878998997e+91*cos(theta)**25 - 4.02841517517516e+91*cos(theta)**23 + 1.88738710985058e+91*cos(theta)**21 - 5.96016982058079e+90*cos(theta)**19 + 1.29667816707292e+90*cos(theta)**17 - 1.95291506890274e+89*cos(theta)**15 + 2.01826852593295e+88*cos(theta)**13 - 1.39933284464684e+87*cos(theta)**11 + 6.25717938663222e+85*cos(theta)**9 - 1.6924001346263e+84*cos(theta)**7 + 2.48882372739161e+82*cos(theta)**5 - 1.63630751307798e+80*cos(theta)**3 + 3.04902021070432e+77*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl71_m_minus_41(theta, phi):
    return 5.529410066666e-75*(1.0 - cos(theta)**2)**20.5*(5.06016052446977e+89*cos(theta)**30 - 1.56111335329386e+90*cos(theta)**28 + 2.12266491922691e+90*cos(theta)**26 - 1.67850632298965e+90*cos(theta)**24 + 8.57903231750265e+89*cos(theta)**22 - 2.98008491029039e+89*cos(theta)**20 + 7.20376759484955e+88*cos(theta)**18 - 1.22057191806421e+88*cos(theta)**16 + 1.44162037566639e+87*cos(theta)**14 - 1.16611070387237e+86*cos(theta)**12 + 6.25717938663222e+84*cos(theta)**10 - 2.11550016828287e+83*cos(theta)**8 + 4.14803954565269e+81*cos(theta)**6 - 4.09076878269496e+79*cos(theta)**4 + 1.52451010535216e+77*cos(theta)**2 - 8.99415991358205e+73)*sin(41*phi)

#@torch.jit.script
def Yl71_m_minus_40(theta, phi):
    return 3.25813186319286e-73*(1.0 - cos(theta)**2)**20*(1.63230984660315e+88*cos(theta)**31 - 5.38314949411678e+88*cos(theta)**29 + 7.86172192306263e+88*cos(theta)**27 - 6.7140252919586e+88*cos(theta)**25 + 3.73001405108811e+88*cos(theta)**23 - 1.41908805251924e+88*cos(theta)**21 + 3.79145662886819e+87*cos(theta)**19 - 7.17983481214241e+86*cos(theta)**17 + 9.6108025044426e+85*cos(theta)**15 - 8.97008233747976e+84*cos(theta)**13 + 5.68834489693838e+83*cos(theta)**11 - 2.35055574253652e+82*cos(theta)**9 + 5.92577077950384e+80*cos(theta)**7 - 8.18153756538991e+78*cos(theta)**5 + 5.08170035117386e+76*cos(theta)**3 - 8.99415991358205e+73*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl71_m_minus_39(theta, phi):
    return 1.94180285665687e-71*(1.0 - cos(theta)**2)**19.5*(5.10096827063485e+86*cos(theta)**32 - 1.79438316470559e+87*cos(theta)**30 + 2.80775782966522e+87*cos(theta)**28 - 2.58231741998407e+87*cos(theta)**26 + 1.55417252128671e+87*cos(theta)**24 - 6.4504002387238e+86*cos(theta)**22 + 1.89572831443409e+86*cos(theta)**20 - 3.9887971178569e+85*cos(theta)**18 + 6.00675156527662e+84*cos(theta)**16 - 6.4072016696284e+83*cos(theta)**14 + 4.74028741411532e+82*cos(theta)**12 - 2.35055574253652e+81*cos(theta)**10 + 7.4072134743798e+79*cos(theta)**8 - 1.36358959423165e+78*cos(theta)**6 + 1.27042508779346e+76*cos(theta)**4 - 4.49707995679103e+73*cos(theta)**2 + 2.53213961531026e+70)*sin(39*phi)

#@torch.jit.script
def Yl71_m_minus_38(theta, phi):
    return 1.16992614950083e-69*(1.0 - cos(theta)**2)**19*(1.54574796079844e+85*cos(theta)**33 - 5.78833278937288e+85*cos(theta)**31 + 9.68192355056974e+85*cos(theta)**29 - 9.56413859253361e+85*cos(theta)**27 + 6.21669008514685e+85*cos(theta)**25 - 2.80452184292339e+85*cos(theta)**23 + 9.02727768778139e+84*cos(theta)**21 - 2.09936690413521e+84*cos(theta)**19 + 3.53338327369213e+83*cos(theta)**17 - 4.27146777975227e+82*cos(theta)**15 + 3.64637493393486e+81*cos(theta)**13 - 2.13686885685138e+80*cos(theta)**11 + 8.23023719375533e+78*cos(theta)**9 - 1.94798513461665e+77*cos(theta)**7 + 2.54085017558693e+75*cos(theta)**5 - 1.49902665226368e+73*cos(theta)**3 + 2.53213961531026e+70*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl71_m_minus_37(theta, phi):
    return 7.12215064831495e-68*(1.0 - cos(theta)**2)**18.5*(4.54631753176011e+83*cos(theta)**34 - 1.80885399667902e+84*cos(theta)**32 + 3.22730785018991e+84*cos(theta)**30 - 3.41576378304772e+84*cos(theta)**28 + 2.3910346481334e+84*cos(theta)**26 - 1.16855076788475e+84*cos(theta)**24 + 4.10330803990063e+83*cos(theta)**22 - 1.0496834520676e+83*cos(theta)**20 + 1.96299070760674e+82*cos(theta)**18 - 2.66966736234517e+81*cos(theta)**16 + 2.60455352423919e+80*cos(theta)**14 - 1.78072404737615e+79*cos(theta)**12 + 8.23023719375533e+77*cos(theta)**10 - 2.43498141827081e+76*cos(theta)**8 + 4.23475029264488e+74*cos(theta)**6 - 3.74756663065919e+72*cos(theta)**4 + 1.26606980765513e+70*cos(theta)**2 - 6.83254078605036e+66)*sin(37*phi)

#@torch.jit.script
def Yl71_m_minus_36(theta, phi):
    return 4.37881962246183e-66*(1.0 - cos(theta)**2)**18*(1.29894786621718e+82*cos(theta)**35 - 5.48137574751219e+82*cos(theta)**33 + 1.04106704844836e+83*cos(theta)**31 - 1.17784958036128e+83*cos(theta)**29 + 8.85568388197557e+82*cos(theta)**27 - 4.67420307153898e+82*cos(theta)**25 + 1.78404697386984e+82*cos(theta)**23 - 4.99849262889335e+81*cos(theta)**21 + 1.03315300400355e+81*cos(theta)**19 - 1.57039256608539e+80*cos(theta)**17 + 1.73636901615946e+79*cos(theta)**15 - 1.36978772875089e+78*cos(theta)**13 + 7.48203381250485e+76*cos(theta)**11 - 2.70553490918979e+75*cos(theta)**9 + 6.04964327520698e+73*cos(theta)**7 - 7.49513326131838e+71*cos(theta)**5 + 4.22023269218377e+69*cos(theta)**3 - 6.83254078605036e+66*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl71_m_minus_35(theta, phi):
    return 2.71769174252509e-64*(1.0 - cos(theta)**2)**17.5*(3.60818851726993e+80*cos(theta)**36 - 1.61216933750359e+81*cos(theta)**34 + 3.25333452640112e+81*cos(theta)**32 - 3.92616526787094e+81*cos(theta)**30 + 3.1627442435627e+81*cos(theta)**28 - 1.79777041213038e+81*cos(theta)**26 + 7.433529057791e+80*cos(theta)**24 - 2.27204210404243e+80*cos(theta)**22 + 5.16576502001774e+79*cos(theta)**20 - 8.72440314491884e+78*cos(theta)**18 + 1.08523063509966e+78*cos(theta)**16 - 9.78419806250634e+76*cos(theta)**14 + 6.23502817708737e+75*cos(theta)**12 - 2.70553490918979e+74*cos(theta)**10 + 7.56205409400872e+72*cos(theta)**8 - 1.2491888768864e+71*cos(theta)**6 + 1.05505817304594e+69*cos(theta)**4 - 3.41627039302518e+66*cos(theta)**2 + 1.77376448235991e+63)*sin(35*phi)

#@torch.jit.script
def Yl71_m_minus_34(theta, phi):
    return 1.70197818592895e-62*(1.0 - cos(theta)**2)**17*(9.7518608574863e+78*cos(theta)**37 - 4.6061981071531e+79*cos(theta)**35 + 9.85858947394279e+79*cos(theta)**33 - 1.26650492511966e+80*cos(theta)**31 + 1.09060146329748e+80*cos(theta)**29 - 6.65840893381621e+79*cos(theta)**27 + 2.9734116231164e+79*cos(theta)**25 - 9.87844393061927e+78*cos(theta)**23 + 2.45988810477035e+78*cos(theta)**21 - 4.59179112890465e+77*cos(theta)**19 + 6.3837096182333e+76*cos(theta)**17 - 6.52279870833756e+75*cos(theta)**15 + 4.79617552083644e+74*cos(theta)**13 - 2.45957719017253e+73*cos(theta)**11 + 8.40228232667635e+71*cos(theta)**9 - 1.78455553840914e+70*cos(theta)**7 + 2.11011634609189e+68*cos(theta)**5 - 1.13875679767506e+66*cos(theta)**3 + 1.77376448235991e+63*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl71_m_minus_33(theta, phi):
    return 1.07507914518226e-60*(1.0 - cos(theta)**2)**16.5*(2.56627917302271e+77*cos(theta)**38 - 1.2794994742092e+78*cos(theta)**36 + 2.89958513939494e+78*cos(theta)**34 - 3.95782789099893e+78*cos(theta)**32 + 3.63533821099161e+78*cos(theta)**30 - 2.37800319064865e+78*cos(theta)**28 + 1.14361985504477e+78*cos(theta)**26 - 4.1160183044247e+77*cos(theta)**24 + 1.1181309567138e+77*cos(theta)**22 - 2.29589556445233e+76*cos(theta)**20 + 3.54650534346294e+75*cos(theta)**18 - 4.07674919271097e+74*cos(theta)**16 + 3.42583965774031e+73*cos(theta)**14 - 2.04964765847711e+72*cos(theta)**12 + 8.40228232667635e+70*cos(theta)**10 - 2.23069442301142e+69*cos(theta)**8 + 3.51686057681981e+67*cos(theta)**6 - 2.84689199418765e+65*cos(theta)**4 + 8.86882241179953e+62*cos(theta)**2 - 4.44552501844588e+59)*sin(33*phi)

#@torch.jit.script
def Yl71_m_minus_32(theta, phi):
    return 6.84682788089054e-59*(1.0 - cos(theta)**2)**16*(6.58020300775054e+75*cos(theta)**39 - 3.45810668705188e+76*cos(theta)**37 + 8.28452896969983e+76*cos(theta)**35 - 1.19934178515119e+77*cos(theta)**33 + 1.17268974548117e+77*cos(theta)**31 - 8.20001100223672e+76*cos(theta)**29 + 4.23562909275841e+76*cos(theta)**27 - 1.64640732176988e+76*cos(theta)**25 + 4.86143894223389e+75*cos(theta)**23 - 1.09328360212016e+75*cos(theta)**21 + 1.86658175971734e+74*cos(theta)**19 - 2.39808776041822e+73*cos(theta)**17 + 2.28389310516021e+72*cos(theta)**15 - 1.57665204498239e+71*cos(theta)**13 + 7.63843847879669e+69*cos(theta)**11 - 2.47854935890158e+68*cos(theta)**9 + 5.02408653831401e+66*cos(theta)**7 - 5.6937839883753e+64*cos(theta)**5 + 2.95627413726651e+62*cos(theta)**3 - 4.44552501844588e+59*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl71_m_minus_31(theta, phi):
    return 4.39478889556512e-57*(1.0 - cos(theta)**2)**15.5*(1.64505075193764e+74*cos(theta)**40 - 9.10028075539968e+74*cos(theta)**38 + 2.30125804713884e+75*cos(theta)**36 - 3.52747583867998e+75*cos(theta)**34 + 3.66465545462864e+75*cos(theta)**32 - 2.73333700074557e+75*cos(theta)**30 + 1.51272467598515e+75*cos(theta)**28 - 6.33233585296107e+74*cos(theta)**26 + 2.02559955926412e+74*cos(theta)**24 - 4.96947091872798e+73*cos(theta)**22 + 9.3329087985867e+72*cos(theta)**20 - 1.33227097801012e+72*cos(theta)**18 + 1.42743319072513e+71*cos(theta)**16 - 1.12618003213028e+70*cos(theta)**14 + 6.36536539899724e+68*cos(theta)**12 - 2.47854935890158e+67*cos(theta)**10 + 6.28010817289252e+65*cos(theta)**8 - 9.4896399806255e+63*cos(theta)**6 + 7.39068534316627e+61*cos(theta)**4 - 2.22276250922294e+59*cos(theta)**2 + 1.07901092680725e+56)*sin(31*phi)

#@torch.jit.script
def Yl71_m_minus_30(theta, phi):
    return 2.84203899663231e-55*(1.0 - cos(theta)**2)**15*(4.01231890716496e+72*cos(theta)**41 - 2.33340532189735e+73*cos(theta)**39 + 6.21961634361849e+73*cos(theta)**37 - 1.00785023962285e+74*cos(theta)**35 + 1.11050165291777e+74*cos(theta)**33 - 8.81721613143733e+73*cos(theta)**31 + 5.21629198615567e+73*cos(theta)**29 - 2.34530957517077e+73*cos(theta)**27 + 8.10239823705649e+72*cos(theta)**25 - 2.16063952988173e+72*cos(theta)**23 + 4.44424228504128e+71*cos(theta)**21 - 7.01195251584275e+70*cos(theta)**19 + 8.39666582779489e+69*cos(theta)**17 - 7.50786688086854e+68*cos(theta)**15 + 4.89643492230557e+67*cos(theta)**13 - 2.25322668991053e+66*cos(theta)**11 + 6.97789796988057e+64*cos(theta)**9 - 1.35566285437507e+63*cos(theta)**7 + 1.47813706863325e+61*cos(theta)**5 - 7.40920836407647e+58*cos(theta)**3 + 1.07901092680725e+56*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl71_m_minus_29(theta, phi):
    return 1.85103812934372e-53*(1.0 - cos(theta)**2)**14.5*(9.55314025515468e+70*cos(theta)**42 - 5.83351330474339e+71*cos(theta)**40 + 1.6367411430575e+72*cos(theta)**38 - 2.79958399895236e+72*cos(theta)**36 + 3.26618133211109e+72*cos(theta)**34 - 2.75538004107417e+72*cos(theta)**32 + 1.73876399538522e+72*cos(theta)**30 - 8.37610562560988e+71*cos(theta)**28 + 3.1163070142525e+71*cos(theta)**26 - 9.00266470784055e+70*cos(theta)**24 + 2.02011012956422e+70*cos(theta)**22 - 3.50597625792137e+69*cos(theta)**20 + 4.66481434877494e+68*cos(theta)**18 - 4.69241680054284e+67*cos(theta)**16 + 3.49745351593255e+66*cos(theta)**14 - 1.87768890825877e+65*cos(theta)**12 + 6.97789796988057e+63*cos(theta)**10 - 1.69457856796884e+62*cos(theta)**8 + 2.46356178105542e+60*cos(theta)**6 - 1.85230209101912e+58*cos(theta)**4 + 5.39505463403626e+55*cos(theta)**2 - 2.54363726262907e+52)*sin(29*phi)

#@torch.jit.script
def Yl71_m_minus_28(theta, phi):
    return 1.21380687393104e-51*(1.0 - cos(theta)**2)**14*(2.22166052445458e+69*cos(theta)**43 - 1.42280812310814e+70*cos(theta)**41 + 4.19677216168589e+70*cos(theta)**39 - 7.56644324041179e+70*cos(theta)**37 + 9.33194666317454e+70*cos(theta)**35 - 8.34963648810353e+70*cos(theta)**33 + 5.60891611414588e+70*cos(theta)**31 - 2.88831228469306e+70*cos(theta)**29 + 1.15418778305648e+70*cos(theta)**27 - 3.60106588313622e+69*cos(theta)**25 + 8.78308751984444e+68*cos(theta)**23 - 1.66951250377208e+68*cos(theta)**21 + 2.45516544672365e+67*cos(theta)**19 - 2.7602451767899e+66*cos(theta)**17 + 2.33163567728837e+65*cos(theta)**15 - 1.44437608327598e+64*cos(theta)**13 + 6.34354360898234e+62*cos(theta)**11 - 1.88286507552093e+61*cos(theta)**9 + 3.51937397293632e+59*cos(theta)**7 - 3.70460418203823e+57*cos(theta)**5 + 1.79835154467875e+55*cos(theta)**3 - 2.54363726262907e+52*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl71_m_minus_27(theta, phi):
    return 8.01112536794487e-50*(1.0 - cos(theta)**2)**13.5*(5.04922846466949e+67*cos(theta)**44 - 3.38763838835272e+68*cos(theta)**42 + 1.04919304042147e+69*cos(theta)**40 - 1.99116927379258e+69*cos(theta)**38 + 2.59220740643737e+69*cos(theta)**36 - 2.45577543767751e+69*cos(theta)**34 + 1.75278628567059e+69*cos(theta)**32 - 9.62770761564355e+68*cos(theta)**30 + 4.12209922520171e+68*cos(theta)**28 - 1.38502533966778e+68*cos(theta)**26 + 3.65961979993518e+67*cos(theta)**24 - 7.58869319896401e+66*cos(theta)**22 + 1.22758272336183e+66*cos(theta)**20 - 1.53346954266106e+65*cos(theta)**18 + 1.45727229830523e+64*cos(theta)**16 - 1.03169720233998e+63*cos(theta)**14 + 5.28628634081862e+61*cos(theta)**12 - 1.88286507552093e+60*cos(theta)**10 + 4.3992174661704e+58*cos(theta)**8 - 6.17434030339705e+56*cos(theta)**6 + 4.49587886169688e+54*cos(theta)**4 - 1.27181863131454e+52*cos(theta)**2 + 5.83938765525499e+48)*sin(27*phi)

#@torch.jit.script
def Yl71_m_minus_26(theta, phi):
    return 5.32001458461065e-48*(1.0 - cos(theta)**2)**13*(1.12205076992655e+66*cos(theta)**45 - 7.87822881012261e+66*cos(theta)**43 + 2.55900741566213e+67*cos(theta)**41 - 5.10556224049378e+67*cos(theta)**39 + 7.00596596334425e+67*cos(theta)**37 - 7.01650125050717e+67*cos(theta)**35 + 5.31147359294118e+67*cos(theta)**33 - 3.10571213407856e+67*cos(theta)**31 + 1.42141352593163e+67*cos(theta)**29 - 5.12972348025102e+66*cos(theta)**27 + 1.46384791997407e+66*cos(theta)**25 - 3.29943182563653e+65*cos(theta)**23 + 5.84563201600869e+64*cos(theta)**21 - 8.07089232979504e+63*cos(theta)**19 + 8.57218999003076e+62*cos(theta)**17 - 6.87798134893323e+61*cos(theta)**15 + 4.06637410832201e+60*cos(theta)**13 - 1.71169552320085e+59*cos(theta)**11 + 4.888019406856e+57*cos(theta)**9 - 8.82048614771008e+55*cos(theta)**7 + 8.99175772339377e+53*cos(theta)**5 - 4.23939543771512e+51*cos(theta)**3 + 5.83938765525499e+48*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl71_m_minus_25(theta, phi):
    return 3.55367417211057e-46*(1.0 - cos(theta)**2)**12.5*(2.43924080418816e+64*cos(theta)**46 - 1.79050654775514e+65*cos(theta)**44 + 6.09287479919554e+65*cos(theta)**42 - 1.27639056012345e+66*cos(theta)**40 + 1.84367525351164e+66*cos(theta)**38 - 1.94902812514088e+66*cos(theta)**36 + 1.56219811557094e+66*cos(theta)**34 - 9.70535041899551e+65*cos(theta)**32 + 4.73804508643875e+65*cos(theta)**30 - 1.83204410008965e+65*cos(theta)**28 + 5.63018430759259e+64*cos(theta)**26 - 1.37476326068189e+64*cos(theta)**24 + 2.65710546182213e+63*cos(theta)**22 - 4.03544616489752e+62*cos(theta)**20 + 4.76232777223931e+61*cos(theta)**18 - 4.29873834308327e+60*cos(theta)**16 + 2.90455293451572e+59*cos(theta)**14 - 1.42641293600071e+58*cos(theta)**12 + 4.888019406856e+56*cos(theta)**10 - 1.10256076846376e+55*cos(theta)**8 + 1.49862628723229e+53*cos(theta)**6 - 1.05984885942878e+51*cos(theta)**4 + 2.91969382762749e+48*cos(theta)**2 - 1.30869288553451e+45)*sin(25*phi)

#@torch.jit.script
def Yl71_m_minus_24(theta, phi):
    return 2.38705349224361e-44*(1.0 - cos(theta)**2)**12*(5.18987405146417e+62*cos(theta)**47 - 3.97890343945586e+63*cos(theta)**45 + 1.41694762771989e+64*cos(theta)**43 - 3.11314770761816e+64*cos(theta)**41 + 4.72737244490165e+64*cos(theta)**39 - 5.26764358146184e+64*cos(theta)**37 + 4.46342318734553e+64*cos(theta)**35 - 2.94101527848349e+64*cos(theta)**33 + 1.52840164078669e+64*cos(theta)**31 - 6.317393448585e+63*cos(theta)**29 + 2.08525344725651e+63*cos(theta)**27 - 5.49905304272754e+62*cos(theta)**25 + 1.15526324427049e+62*cos(theta)**23 - 1.92164103090358e+61*cos(theta)**21 + 2.50648830117858e+60*cos(theta)**19 - 2.52866961357839e+59*cos(theta)**17 + 1.93636862301048e+58*cos(theta)**15 - 1.09724072000054e+57*cos(theta)**13 + 4.44365400623273e+55*cos(theta)**11 - 1.22506752051529e+54*cos(theta)**9 + 2.14089469604614e+52*cos(theta)**7 - 2.11969771885756e+50*cos(theta)**5 + 9.73231275875831e+47*cos(theta)**3 - 1.30869288553451e+45*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl71_m_minus_23(theta, phi):
    return 1.61192404130082e-42*(1.0 - cos(theta)**2)**11.5*(1.0812237607217e+61*cos(theta)**48 - 8.64979008577362e+61*cos(theta)**46 + 3.22033551754521e+62*cos(theta)**44 - 7.41225644670991e+62*cos(theta)**42 + 1.18184311122541e+63*cos(theta)**40 - 1.38622199512154e+63*cos(theta)**38 + 1.23983977426265e+63*cos(theta)**36 - 8.65004493671614e+62*cos(theta)**34 + 4.77625512745842e+62*cos(theta)**32 - 2.105797816195e+62*cos(theta)**30 + 7.44733374020183e+61*cos(theta)**28 - 2.11502040104906e+61*cos(theta)**26 + 4.81359685112705e+60*cos(theta)**24 - 8.73473195865264e+59*cos(theta)**22 + 1.25324415058929e+59*cos(theta)**20 - 1.404816451988e+58*cos(theta)**18 + 1.21023038938155e+57*cos(theta)**16 - 7.83743371428959e+55*cos(theta)**14 + 3.70304500519394e+54*cos(theta)**12 - 1.22506752051529e+53*cos(theta)**10 + 2.67611837005767e+51*cos(theta)**8 - 3.53282953142927e+49*cos(theta)**6 + 2.43307818968958e+47*cos(theta)**4 - 6.54346442767255e+44*cos(theta)**2 + 2.86994053845287e+41)*sin(23*phi)

#@torch.jit.script
def Yl71_m_minus_22(theta, phi):
    return 1.09397283893788e-40*(1.0 - cos(theta)**2)**11*(2.20657910351368e+59*cos(theta)**49 - 1.84038086931354e+60*cos(theta)**47 + 7.15630115010047e+60*cos(theta)**45 - 1.7237805690023e+61*cos(theta)**43 + 2.88254417372052e+61*cos(theta)**41 - 3.55441537210651e+61*cos(theta)**39 + 3.35091830881796e+61*cos(theta)**37 - 2.47144141049033e+61*cos(theta)**35 + 1.44735003862376e+61*cos(theta)**33 - 6.7928961812742e+60*cos(theta)**31 + 2.56804611731098e+60*cos(theta)**29 - 7.83340889277428e+59*cos(theta)**27 + 1.92543874045082e+59*cos(theta)**25 - 3.79770954724028e+58*cos(theta)**23 + 5.96782928852044e+57*cos(theta)**21 - 7.39377079993683e+56*cos(theta)**19 + 7.11900229047971e+55*cos(theta)**17 - 5.2249558095264e+54*cos(theta)**15 + 2.84849615784149e+53*cos(theta)**13 - 1.11369774592299e+52*cos(theta)**11 + 2.97346485561963e+50*cos(theta)**9 - 5.04689933061324e+48*cos(theta)**7 + 4.86615637937915e+46*cos(theta)**5 - 2.18115480922418e+44*cos(theta)**3 + 2.86994053845287e+41*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl71_m_minus_21(theta, phi):
    return 7.45990017450111e-39*(1.0 - cos(theta)**2)**10.5*(4.41315820702735e+57*cos(theta)**50 - 3.83412681106987e+58*cos(theta)**48 + 1.55571764132619e+59*cos(theta)**46 - 3.91768311136887e+59*cos(theta)**44 + 6.86320041362028e+59*cos(theta)**42 - 8.88603843026626e+59*cos(theta)**40 + 8.81820607583675e+59*cos(theta)**38 - 6.86511502913979e+59*cos(theta)**36 + 4.25691187830519e+59*cos(theta)**34 - 2.12278005664819e+59*cos(theta)**32 + 8.56015372436992e+58*cos(theta)**30 - 2.79764603313367e+58*cos(theta)**28 + 7.40553361711854e+57*cos(theta)**26 - 1.58237897801678e+57*cos(theta)**24 + 2.7126496766002e+56*cos(theta)**22 - 3.69688539996841e+55*cos(theta)**20 + 3.95500127248873e+54*cos(theta)**18 - 3.265597380954e+53*cos(theta)**16 + 2.03464011274392e+52*cos(theta)**14 - 9.28081454935825e+50*cos(theta)**12 + 2.97346485561963e+49*cos(theta)**10 - 6.30862416326655e+47*cos(theta)**8 + 8.11026063229859e+45*cos(theta)**6 - 5.45288702306046e+43*cos(theta)**4 + 1.43497026922644e+41*cos(theta)**2 - 6.17191513645779e+37)*sin(21*phi)

#@torch.jit.script
def Yl71_m_minus_20(theta, phi):
    return 5.10989548815476e-37*(1.0 - cos(theta)**2)**10*(8.65325138632815e+55*cos(theta)**51 - 7.82474859402013e+56*cos(theta)**49 + 3.31003753473657e+57*cos(theta)**47 - 8.70596246970861e+57*cos(theta)**45 + 1.59609311944658e+58*cos(theta)**43 - 2.16732644640641e+58*cos(theta)**41 + 2.26107848098378e+58*cos(theta)**39 - 1.85543649436211e+58*cos(theta)**37 + 1.21626053665862e+58*cos(theta)**35 - 6.43266683832784e+57*cos(theta)**33 + 2.76133991108707e+57*cos(theta)**31 - 9.64705528666783e+56*cos(theta)**29 + 2.74279022856242e+56*cos(theta)**27 - 6.32951591206713e+55*cos(theta)**25 + 1.17941290286965e+55*cos(theta)**23 - 1.76042161903258e+54*cos(theta)**21 + 2.08157961709933e+53*cos(theta)**19 - 1.92093963585529e+52*cos(theta)**17 + 1.35642674182928e+51*cos(theta)**15 - 7.13908811489096e+49*cos(theta)**13 + 2.70314986874512e+48*cos(theta)**11 - 7.0095824036295e+46*cos(theta)**9 + 1.15860866175694e+45*cos(theta)**7 - 1.09057740461209e+43*cos(theta)**5 + 4.78323423075479e+40*cos(theta)**3 - 6.17191513645779e+37*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl71_m_minus_19(theta, phi):
    return 3.51507329866901e-35*(1.0 - cos(theta)**2)**9.5*(1.66408680506311e+54*cos(theta)**52 - 1.56494971880403e+55*cos(theta)**50 + 6.8959115307012e+55*cos(theta)**48 - 1.89260053689318e+56*cos(theta)**46 + 3.62748436237859e+56*cos(theta)**44 - 5.16030106287239e+56*cos(theta)**42 + 5.65269620245945e+56*cos(theta)**40 - 4.88272761674239e+56*cos(theta)**38 + 3.3785014907184e+56*cos(theta)**36 - 1.89196083480231e+56*cos(theta)**34 + 8.6291872221471e+55*cos(theta)**32 - 3.21568509555594e+55*cos(theta)**30 + 9.79567938772294e+54*cos(theta)**28 - 2.4344291969489e+54*cos(theta)**26 + 4.91422042862355e+53*cos(theta)**24 - 8.00191645014808e+52*cos(theta)**22 + 1.04078980854967e+52*cos(theta)**20 - 1.06718868658627e+51*cos(theta)**18 + 8.47766713643301e+49*cos(theta)**16 - 5.09934865349354e+48*cos(theta)**14 + 2.25262489062093e+47*cos(theta)**12 - 7.0095824036295e+45*cos(theta)**10 + 1.44826082719618e+44*cos(theta)**8 - 1.81762900768682e+42*cos(theta)**6 + 1.1958085576887e+40*cos(theta)**4 - 3.0859575682289e+37*cos(theta)**2 + 1.30429313957265e+34)*sin(19*phi)

#@torch.jit.script
def Yl71_m_minus_18(theta, phi):
    return 2.42769193282891e-33*(1.0 - cos(theta)**2)**9*(3.13978642464737e+52*cos(theta)**53 - 3.06852886040005e+53*cos(theta)**51 + 1.40732888381657e+54*cos(theta)**49 - 4.0268096529642e+54*cos(theta)**47 + 8.0610763608413e+54*cos(theta)**45 - 1.20007001462149e+55*cos(theta)**43 + 1.37870639084377e+55*cos(theta)**41 - 1.25198144019036e+55*cos(theta)**39 + 9.13108511004974e+54*cos(theta)**37 - 5.40560238514944e+54*cos(theta)**35 + 2.61490521883245e+54*cos(theta)**33 - 1.03731777275998e+54*cos(theta)**31 + 3.37782047852515e+53*cos(theta)**29 - 9.01640443314406e+52*cos(theta)**27 + 1.96568817144942e+52*cos(theta)**25 - 3.47909410876003e+51*cos(theta)**23 + 4.9561419454746e+50*cos(theta)**21 - 5.61678256098039e+49*cos(theta)**19 + 4.98686302143118e+48*cos(theta)**17 - 3.39956576899569e+47*cos(theta)**15 + 1.73278837740072e+46*cos(theta)**13 - 6.37234763966318e+44*cos(theta)**11 + 1.60917869688464e+43*cos(theta)**9 - 2.59661286812403e+41*cos(theta)**7 + 2.39161711537739e+39*cos(theta)**5 - 1.02865252274297e+37*cos(theta)**3 + 1.30429313957265e+34*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl71_m_minus_17(theta, phi):
    return 1.68300520225555e-31*(1.0 - cos(theta)**2)**8.5*(5.81441930490253e+50*cos(theta)**54 - 5.90101703923087e+51*cos(theta)**52 + 2.81465776763314e+52*cos(theta)**50 - 8.38918677700875e+52*cos(theta)**48 + 1.75240790453072e+53*cos(theta)**46 - 2.72743185141247e+53*cos(theta)**44 + 3.28263426391374e+53*cos(theta)**42 - 3.12995360047589e+53*cos(theta)**40 + 2.40291713422362e+53*cos(theta)**38 - 1.50155621809707e+53*cos(theta)**36 + 7.6908977024484e+52*cos(theta)**34 - 3.24161803987494e+52*cos(theta)**32 + 1.12594015950838e+52*cos(theta)**30 - 3.22014444040859e+51*cos(theta)**28 + 7.56033912095931e+50*cos(theta)**26 - 1.44962254531668e+50*cos(theta)**24 + 2.25279179339754e+49*cos(theta)**22 - 2.80839128049019e+48*cos(theta)**20 + 2.77047945635066e+47*cos(theta)**18 - 2.12472860562231e+46*cos(theta)**16 + 1.23770598385766e+45*cos(theta)**14 - 5.31028969971931e+43*cos(theta)**12 + 1.60917869688464e+42*cos(theta)**10 - 3.24576608515504e+40*cos(theta)**8 + 3.98602852562899e+38*cos(theta)**6 - 2.57163130685741e+36*cos(theta)**4 + 6.52146569786326e+33*cos(theta)**2 - 2.7138850178374e+30)*sin(17*phi)

#@torch.jit.script
def Yl71_m_minus_16(theta, phi):
    return 1.17086854566878e-29*(1.0 - cos(theta)**2)**8*(1.05716714634592e+49*cos(theta)**55 - 1.11339944136432e+50*cos(theta)**53 + 5.51893679928067e+50*cos(theta)**51 - 1.71207893408342e+51*cos(theta)**49 + 3.72852745644834e+51*cos(theta)**47 - 6.06095966980549e+51*cos(theta)**45 + 7.63403317189241e+51*cos(theta)**43 - 7.63403317189241e+51*cos(theta)**41 + 6.16132598518876e+51*cos(theta)**39 - 4.05826004891099e+51*cos(theta)**37 + 2.19739934355668e+51*cos(theta)**35 - 9.82308496931801e+50*cos(theta)**33 + 3.63206503067221e+50*cos(theta)**31 - 1.11039463462365e+50*cos(theta)**29 + 2.8001256003553e+49*cos(theta)**27 - 5.79849018126672e+48*cos(theta)**25 + 9.79474692781541e+47*cos(theta)**23 - 1.33732918118581e+47*cos(theta)**21 + 1.45814708228982e+46*cos(theta)**19 - 1.24984035624842e+45*cos(theta)**17 + 8.25137322571771e+43*cos(theta)**15 - 4.08483823055332e+42*cos(theta)**13 + 1.46288972444058e+41*cos(theta)**11 - 3.60640676128337e+39*cos(theta)**9 + 5.69432646518427e+37*cos(theta)**7 - 5.14326261371483e+35*cos(theta)**5 + 2.17382189928775e+33*cos(theta)**3 - 2.7138850178374e+30*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl71_m_minus_15(theta, phi):
    return 8.17262889945722e-28*(1.0 - cos(theta)**2)**7.5*(1.88779847561771e+47*cos(theta)**56 - 2.06185081734132e+48*cos(theta)**54 + 1.06133399986167e+49*cos(theta)**52 - 3.42415786816684e+49*cos(theta)**50 + 7.76776553426737e+49*cos(theta)**48 - 1.31759992821858e+50*cos(theta)**46 + 1.73500753906646e+50*cos(theta)**44 - 1.81762694568867e+50*cos(theta)**42 + 1.54033149629719e+50*cos(theta)**40 - 1.06796317076605e+50*cos(theta)**38 + 6.10388706543523e+49*cos(theta)**36 - 2.88914263803471e+49*cos(theta)**34 + 1.13502032208506e+49*cos(theta)**32 - 3.70131544874551e+48*cos(theta)**30 + 1.00004485726975e+48*cos(theta)**28 - 2.23018853125643e+47*cos(theta)**26 + 4.08114455325642e+46*cos(theta)**24 - 6.07876900539003e+45*cos(theta)**22 + 7.2907354114491e+44*cos(theta)**20 - 6.94355753471343e+43*cos(theta)**18 + 5.15710826607357e+42*cos(theta)**16 - 2.91774159325237e+41*cos(theta)**14 + 1.21907477036715e+40*cos(theta)**12 - 3.60640676128337e+38*cos(theta)**10 + 7.11790808148034e+36*cos(theta)**8 - 8.57210435619138e+34*cos(theta)**6 + 5.43455474821939e+32*cos(theta)**4 - 1.3569425089187e+30*cos(theta)**2 + 5.5703715472853e+26)*sin(15*phi)

#@torch.jit.script
def Yl71_m_minus_14(theta, phi):
    return 5.72200762892404e-26*(1.0 - cos(theta)**2)**7*(3.3119271502065e+45*cos(theta)**57 - 3.74881966789332e+46*cos(theta)**55 + 2.00251698087107e+47*cos(theta)**53 - 6.71403503562125e+47*cos(theta)**51 + 1.58525827229946e+48*cos(theta)**49 - 2.80340410259273e+48*cos(theta)**47 + 3.85557230903657e+48*cos(theta)**45 - 4.2270394085783e+48*cos(theta)**43 + 3.75690608852973e+48*cos(theta)**41 - 2.73836710452834e+48*cos(theta)**39 + 1.64969920687439e+48*cos(theta)**37 - 8.25469325152774e+47*cos(theta)**35 + 3.43945552146989e+47*cos(theta)**33 - 1.19397272540178e+47*cos(theta)**31 + 3.44843054230948e+46*cos(theta)**29 - 8.25995752317197e+45*cos(theta)**27 + 1.63245782130257e+45*cos(theta)**25 - 2.64294304582175e+44*cos(theta)**23 + 3.47177876735671e+43*cos(theta)**21 - 3.65450396563865e+42*cos(theta)**19 + 3.03359309769033e+41*cos(theta)**17 - 1.94516106216825e+40*cos(theta)**15 + 9.37749823359348e+38*cos(theta)**13 - 3.2785516011667e+37*cos(theta)**11 + 7.90878675720038e+35*cos(theta)**9 - 1.22458633659877e+34*cos(theta)**7 + 1.08691094964388e+32*cos(theta)**5 - 4.52314169639566e+29*cos(theta)**3 + 5.5703715472853e+26*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl71_m_minus_13(theta, phi):
    return 4.0176480748809e-24*(1.0 - cos(theta)**2)**6.5*(5.71021922449397e+43*cos(theta)**58 - 6.69432083552378e+44*cos(theta)**56 + 3.70836477939087e+45*cos(theta)**54 - 1.29116058377332e+46*cos(theta)**52 + 3.17051654459892e+46*cos(theta)**50 - 5.84042521373486e+46*cos(theta)**48 + 8.3816789326882e+46*cos(theta)**46 - 9.60690774676886e+46*cos(theta)**44 + 8.94501449649936e+46*cos(theta)**42 - 6.84591776132084e+46*cos(theta)**40 + 4.34131370230102e+46*cos(theta)**38 - 2.29297034764659e+46*cos(theta)**36 + 1.0116045651382e+46*cos(theta)**34 - 3.73116476688055e+45*cos(theta)**32 + 1.14947684743649e+45*cos(theta)**30 - 2.94998482970428e+44*cos(theta)**28 + 6.2786839280868e+43*cos(theta)**26 - 1.1012262690924e+43*cos(theta)**24 + 1.57808125788942e+42*cos(theta)**22 - 1.82725198281932e+41*cos(theta)**20 + 1.68532949871685e+40*cos(theta)**18 - 1.21572566385515e+39*cos(theta)**16 + 6.69821302399534e+37*cos(theta)**14 - 2.73212633430559e+36*cos(theta)**12 + 7.90878675720038e+34*cos(theta)**10 - 1.53073292074846e+33*cos(theta)**8 + 1.81151824940646e+31*cos(theta)**6 - 1.13078542409892e+29*cos(theta)**4 + 2.78518577364265e+26*cos(theta)**2 - 1.12989280877998e+23)*sin(13*phi)

#@torch.jit.script
def Yl71_m_minus_12(theta, phi):
    return 2.82837858925591e-22*(1.0 - cos(theta)**2)**6*(9.67833766863384e+41*cos(theta)**59 - 1.17444225184628e+43*cos(theta)**57 + 6.74248141707431e+43*cos(theta)**55 - 2.43615204485532e+44*cos(theta)**53 + 6.21669910705671e+44*cos(theta)**51 - 1.19192351300711e+45*cos(theta)**49 + 1.78333594312515e+45*cos(theta)**47 - 2.13486838817086e+45*cos(theta)**45 + 2.08023592941846e+45*cos(theta)**43 - 1.66973603934655e+45*cos(theta)**41 + 1.11315735956436e+45*cos(theta)**39 - 6.19721715580161e+44*cos(theta)**37 + 2.89029875753772e+44*cos(theta)**35 - 1.1306559899638e+44*cos(theta)**33 + 3.7079898304403e+43*cos(theta)**31 - 1.01723614817389e+43*cos(theta)**29 + 2.325438491884e+42*cos(theta)**27 - 4.40490507636959e+41*cos(theta)**25 + 6.86122286038876e+40*cos(theta)**23 - 8.70119991818725e+39*cos(theta)**21 + 8.87015525640448e+38*cos(theta)**19 - 7.15132743444209e+37*cos(theta)**17 + 4.46547534933023e+36*cos(theta)**15 - 2.10163564177353e+35*cos(theta)**13 + 7.18980614290944e+33*cos(theta)**11 - 1.70081435638718e+32*cos(theta)**9 + 2.5878832134378e+30*cos(theta)**7 - 2.26157084819783e+28*cos(theta)**5 + 9.28395257880883e+25*cos(theta)**3 - 1.12989280877998e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl71_m_minus_11(theta, phi):
    return 1.99596174091397e-20*(1.0 - cos(theta)**2)**5.5*(1.61305627810564e+40*cos(theta)**60 - 2.02490043421772e+41*cos(theta)**58 + 1.20401453876327e+42*cos(theta)**56 - 4.51139267565799e+42*cos(theta)**54 + 1.19551905904937e+43*cos(theta)**52 - 2.38384702601423e+43*cos(theta)**50 + 3.71528321484406e+43*cos(theta)**48 - 4.64101823515404e+43*cos(theta)**46 + 4.72780893049649e+43*cos(theta)**44 - 3.97556199844416e+43*cos(theta)**42 + 2.78289339891091e+43*cos(theta)**40 - 1.63084661994779e+43*cos(theta)**38 + 8.02860765982701e+42*cos(theta)**36 - 3.32545879401119e+42*cos(theta)**34 + 1.15874682201259e+42*cos(theta)**32 - 3.39078716057963e+41*cos(theta)**30 + 8.30513747101429e+40*cos(theta)**28 - 1.69419426014215e+40*cos(theta)**26 + 2.85884285849532e+39*cos(theta)**24 - 3.9550908719033e+38*cos(theta)**22 + 4.43507762820224e+37*cos(theta)**20 - 3.97295968580116e+36*cos(theta)**18 + 2.79092209333139e+35*cos(theta)**16 - 1.50116831555252e+34*cos(theta)**14 + 5.9915051190912e+32*cos(theta)**12 - 1.70081435638718e+31*cos(theta)**10 + 3.23485401679725e+29*cos(theta)**8 - 3.76928474699638e+27*cos(theta)**6 + 2.32098814470221e+25*cos(theta)**4 - 5.6494640438999e+22*cos(theta)**2 + 2.26886106180719e+19)*sin(11*phi)

#@torch.jit.script
def Yl71_m_minus_10(theta, phi):
    return 1.41164032538405e-18*(1.0 - cos(theta)**2)**5*(2.64435455427154e+38*cos(theta)**61 - 3.43203463426732e+39*cos(theta)**59 + 2.11230620835661e+40*cos(theta)**57 - 8.20253213755999e+40*cos(theta)**55 + 2.255696337829e+41*cos(theta)**53 - 4.67420985492986e+41*cos(theta)**51 + 7.5822106425389e+41*cos(theta)**49 - 9.87450688330647e+41*cos(theta)**47 + 1.050624206777e+42*cos(theta)**45 - 9.24549301963758e+41*cos(theta)**43 + 6.78754487539247e+41*cos(theta)**41 - 4.18165799986613e+41*cos(theta)**39 + 2.16989396211541e+41*cos(theta)**37 - 9.50131084003197e+40*cos(theta)**35 + 3.51135400609877e+40*cos(theta)**33 - 1.0938023098644e+40*cos(theta)**31 + 2.86384050724631e+39*cos(theta)**29 - 6.27479355608203e+38*cos(theta)**27 + 1.14353714339813e+38*cos(theta)**25 - 1.71960472691448e+37*cos(theta)**23 + 2.11194172771535e+36*cos(theta)**21 - 2.09103141357956e+35*cos(theta)**19 + 1.64171887843023e+34*cos(theta)**17 - 1.00077887703501e+33*cos(theta)**15 + 4.60885009160861e+31*cos(theta)**13 - 1.54619486944289e+30*cos(theta)**11 + 3.59428224088584e+28*cos(theta)**9 - 5.38469249570912e+26*cos(theta)**7 + 4.64197628940441e+24*cos(theta)**5 - 1.88315468129997e+22*cos(theta)**3 + 2.26886106180719e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl71_m_minus_9(theta, phi):
    return 1.0003740333612e-16*(1.0 - cos(theta)**2)**4.5*(4.26508799076055e+36*cos(theta)**62 - 5.72005772377887e+37*cos(theta)**60 + 3.64190725578726e+38*cos(theta)**58 - 1.46473788170714e+39*cos(theta)**56 + 4.17721544042407e+39*cos(theta)**54 - 8.98886510563435e+39*cos(theta)**52 + 1.51644212850778e+40*cos(theta)**50 - 2.05718893402218e+40*cos(theta)**48 + 2.28396566690652e+40*cos(theta)**46 - 2.10124841355399e+40*cos(theta)**44 + 1.61608211318868e+40*cos(theta)**42 - 1.04541449996653e+40*cos(theta)**40 + 5.71024726872476e+39*cos(theta)**38 - 2.63925301111999e+39*cos(theta)**36 + 1.03275117826434e+39*cos(theta)**34 - 3.41813221832624e+38*cos(theta)**32 + 9.54613502415435e+37*cos(theta)**30 - 2.24099769860073e+37*cos(theta)**28 + 4.39821978230049e+36*cos(theta)**26 - 7.16501969547699e+35*cos(theta)**24 + 9.59973512597888e+34*cos(theta)**22 - 1.04551570678978e+34*cos(theta)**20 + 9.12066043572351e+32*cos(theta)**18 - 6.25486798146883e+31*cos(theta)**16 + 3.29203577972044e+30*cos(theta)**14 - 1.28849572453574e+29*cos(theta)**12 + 3.59428224088584e+27*cos(theta)**10 - 6.7308656196364e+25*cos(theta)**8 + 7.73662714900736e+23*cos(theta)**6 - 4.70788670324991e+21*cos(theta)**4 + 1.13443053090359e+19*cos(theta)**2 - 4.51784361172279e+15)*sin(9*phi)

#@torch.jit.script
def Yl71_m_minus_8(theta, phi):
    return 7.1019511131672e-15*(1.0 - cos(theta)**2)**4*(6.76998093771516e+34*cos(theta)**63 - 9.37714380947355e+35*cos(theta)**61 + 6.1727241623513e+36*cos(theta)**59 - 2.56971558194235e+37*cos(theta)**57 + 7.5949371644074e+37*cos(theta)**55 - 1.69601228408195e+38*cos(theta)**53 + 2.97341593825055e+38*cos(theta)**51 - 4.19834476331057e+38*cos(theta)**49 + 4.85950141895003e+38*cos(theta)**47 - 4.66944091900888e+38*cos(theta)**45 + 3.75833049578763e+38*cos(theta)**43 - 2.54979146333301e+38*cos(theta)**41 + 1.46416596633968e+38*cos(theta)**39 - 7.13311624627025e+37*cos(theta)**37 + 2.95071765218384e+37*cos(theta)**35 - 1.03579764191704e+37*cos(theta)**33 + 3.0793983948885e+36*cos(theta)**31 - 7.72757827103698e+35*cos(theta)**29 + 1.62897028974092e+35*cos(theta)**27 - 2.8660078781908e+34*cos(theta)**25 + 4.17379788086038e+33*cos(theta)**23 - 4.97864622280847e+32*cos(theta)**21 + 4.80034759774921e+31*cos(theta)**19 - 3.67933410674637e+30*cos(theta)**17 + 2.19469051981363e+29*cos(theta)**15 - 9.91150557335186e+27*cos(theta)**13 + 3.26752930989622e+26*cos(theta)**11 - 7.47873957737378e+24*cos(theta)**9 + 1.10523244985819e+23*cos(theta)**7 - 9.41577340649983e+20*cos(theta)**5 + 3.78143510301198e+18*cos(theta)**3 - 4.51784361172279e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl71_m_minus_7(theta, phi):
    return 5.04988177888807e-13*(1.0 - cos(theta)**2)**3.5*(1.05780952151799e+33*cos(theta)**64 - 1.51244254991509e+34*cos(theta)**62 + 1.02878736039188e+35*cos(theta)**60 - 4.43054410679716e+35*cos(theta)**58 + 1.35623877935846e+36*cos(theta)**56 - 3.14076348904065e+36*cos(theta)**54 + 5.71810757355875e+36*cos(theta)**52 - 8.39668952662115e+36*cos(theta)**50 + 1.01239612894792e+37*cos(theta)**48 - 1.01509585195845e+37*cos(theta)**46 + 8.54166021769917e+36*cos(theta)**44 - 6.07093205555478e+36*cos(theta)**42 + 3.66041491584921e+36*cos(theta)**40 - 1.87713585428164e+36*cos(theta)**38 + 8.19643792273289e+35*cos(theta)**36 - 3.04646365269718e+35*cos(theta)**34 + 9.62311998402657e+34*cos(theta)**32 - 2.57585942367899e+34*cos(theta)**30 + 5.81775103478901e+33*cos(theta)**28 - 1.10231072238108e+33*cos(theta)**26 + 1.73908245035849e+32*cos(theta)**24 - 2.26302101036749e+31*cos(theta)**22 + 2.40017379887461e+30*cos(theta)**20 - 2.04407450374798e+29*cos(theta)**18 + 1.37168157488352e+28*cos(theta)**16 - 7.07964683810847e+26*cos(theta)**14 + 2.72294109158018e+25*cos(theta)**12 - 7.47873957737378e+23*cos(theta)**10 + 1.38154056232274e+22*cos(theta)**8 - 1.56929556774997e+20*cos(theta)**6 + 9.45358775752995e+17*cos(theta)**4 - 2.2589218058614e+15*cos(theta)**2 + 893560840926.185)*sin(7*phi)

#@torch.jit.script
def Yl71_m_minus_6(theta, phi):
    return 3.59571441194071e-11*(1.0 - cos(theta)**2)**3*(1.62739926387384e+31*cos(theta)**65 - 2.40070246018268e+32*cos(theta)**63 + 1.68653665638014e+33*cos(theta)**61 - 7.50939679118163e+33*cos(theta)**59 + 2.37936627957625e+34*cos(theta)**57 - 5.710479070983e+34*cos(theta)**55 + 1.07888822142618e+35*cos(theta)**53 - 1.64640971110219e+35*cos(theta)**51 + 2.06611454887331e+35*cos(theta)**49 - 2.15977840842224e+35*cos(theta)**47 + 1.89814671504426e+35*cos(theta)**45 - 1.41184466408251e+35*cos(theta)**43 + 8.92784125816879e+34*cos(theta)**41 - 4.81316885713242e+34*cos(theta)**39 + 2.21525349263051e+34*cos(theta)**37 - 8.70418186484909e+33*cos(theta)**35 + 2.91609696485654e+33*cos(theta)**33 - 8.3092239473516e+32*cos(theta)**31 + 2.00612104647897e+32*cos(theta)**29 - 4.08263230511509e+31*cos(theta)**27 + 6.95632980143397e+30*cos(theta)**25 - 9.83922178420646e+29*cos(theta)**23 + 1.142939904226e+29*cos(theta)**21 - 1.07582868618315e+28*cos(theta)**19 + 8.06871514637362e+26*cos(theta)**17 - 4.71976455873898e+25*cos(theta)**15 + 2.09457007044629e+24*cos(theta)**13 - 6.79885416124889e+22*cos(theta)**11 + 1.53504506924749e+21*cos(theta)**9 - 2.24185081107139e+19*cos(theta)**7 + 1.89071755150599e+17*cos(theta)**5 - 752973935287132.0*cos(theta)**3 + 893560840926.185*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl71_m_minus_5(theta, phi):
    return 2.56331820022474e-9*(1.0 - cos(theta)**2)**2.5*(2.4657564604149e+29*cos(theta)**66 - 3.75109759403544e+30*cos(theta)**64 + 2.72022041351635e+31*cos(theta)**62 - 1.2515661318636e+32*cos(theta)**60 + 4.10235565444181e+32*cos(theta)**58 - 1.01972840553268e+33*cos(theta)**56 + 1.99794115078922e+33*cos(theta)**54 - 3.16617252135036e+33*cos(theta)**52 + 4.13222909774663e+33*cos(theta)**50 - 4.49953835087966e+33*cos(theta)**48 + 4.12640590227013e+33*cos(theta)**46 - 3.20873787291479e+33*cos(theta)**44 + 2.12567649004019e+33*cos(theta)**42 - 1.2032922142831e+33*cos(theta)**40 + 5.82961445429082e+32*cos(theta)**38 - 2.41782829579141e+32*cos(theta)**36 + 8.57675577898981e+31*cos(theta)**34 - 2.59663248354737e+31*cos(theta)**32 + 6.68707015492989e+30*cos(theta)**30 - 1.45808296611253e+30*cos(theta)**28 + 2.67551146208999e+29*cos(theta)**26 - 4.09967574341936e+28*cos(theta)**24 + 5.19518138284547e+27*cos(theta)**22 - 5.37914343091575e+26*cos(theta)**20 + 4.48261952576312e+25*cos(theta)**18 - 2.94985284921186e+24*cos(theta)**16 + 1.49612147889021e+23*cos(theta)**14 - 5.66571180104074e+21*cos(theta)**12 + 1.53504506924749e+20*cos(theta)**10 - 2.80231351383923e+18*cos(theta)**8 + 3.15119591917665e+16*cos(theta)**6 - 188243483821783.0*cos(theta)**4 + 446780420463.093*cos(theta)**2 - 175828579.481737)*sin(5*phi)

#@torch.jit.script
def Yl71_m_minus_4(theta, phi):
    return 1.82913903779927e-7*(1.0 - cos(theta)**2)**2*(3.68023352300732e+27*cos(theta)**67 - 5.77091937543914e+28*cos(theta)**65 + 4.31781018018468e+29*cos(theta)**63 - 2.05174775715345e+30*cos(theta)**61 + 6.95314517702002e+30*cos(theta)**59 - 1.78899720268891e+31*cos(theta)**57 + 3.63262027416222e+31*cos(theta)**55 - 5.97391041764218e+31*cos(theta)**53 + 8.10240999558162e+31*cos(theta)**51 - 9.18273132832584e+31*cos(theta)**49 + 8.77958702610666e+31*cos(theta)**47 - 7.13052860647731e+31*cos(theta)**45 + 4.94343369776788e+31*cos(theta)**43 - 2.93485905922709e+31*cos(theta)**41 + 1.49477293699765e+31*cos(theta)**39 - 6.53467106970652e+30*cos(theta)**37 + 2.45050165113995e+30*cos(theta)**35 - 7.86858328347689e+29*cos(theta)**33 + 2.15711940481609e+29*cos(theta)**31 - 5.02787229693977e+28*cos(theta)**29 + 9.9093017114444e+27*cos(theta)**27 - 1.63987029736774e+27*cos(theta)**25 + 2.25877451428064e+26*cos(theta)**23 - 2.56149687186464e+25*cos(theta)**21 + 2.35927343461217e+24*cos(theta)**19 - 1.73520755835992e+23*cos(theta)**17 + 9.97414319260139e+21*cos(theta)**15 - 4.35823984695442e+20*cos(theta)**13 + 1.39549551749772e+19*cos(theta)**11 - 3.11368168204359e+17*cos(theta)**9 + 4.50170845596664e+15*cos(theta)**7 - 37648696764356.6*cos(theta)**5 + 148926806821.031*cos(theta)**3 - 175828579.481737*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl71_m_minus_3(theta, phi):
    return 1.30626655242972e-5*(1.0 - cos(theta)**2)**1.5*(5.41210812206959e+25*cos(theta)**68 - 8.74381723551385e+26*cos(theta)**66 + 6.74657840653856e+27*cos(theta)**64 - 3.30927057605395e+28*cos(theta)**62 + 1.15885752950334e+29*cos(theta)**60 - 3.08447793567054e+29*cos(theta)**58 + 6.48682191814682e+29*cos(theta)**56 - 1.10627970697077e+30*cos(theta)**54 + 1.55815576838108e+30*cos(theta)**52 - 1.83654626566517e+30*cos(theta)**50 + 1.82908063043889e+30*cos(theta)**48 - 1.55011491445159e+30*cos(theta)**46 + 1.12350765858361e+30*cos(theta)**44 - 6.98775966482639e+29*cos(theta)**42 + 3.73693234249411e+29*cos(theta)**40 - 1.71965028150172e+29*cos(theta)**38 + 6.80694903094429e+28*cos(theta)**36 - 2.31428920102262e+28*cos(theta)**34 + 6.7409981400503e+27*cos(theta)**32 - 1.67595743231326e+27*cos(theta)**30 + 3.53903632551586e+26*cos(theta)**28 - 6.3071934514144e+25*cos(theta)**26 + 9.41156047616933e+24*cos(theta)**24 - 1.16431675993847e+24*cos(theta)**22 + 1.17963671730609e+23*cos(theta)**20 - 9.64004199088844e+21*cos(theta)**18 + 6.23383949537587e+20*cos(theta)**16 - 3.1130284621103e+19*cos(theta)**14 + 1.1629129312481e+18*cos(theta)**12 - 3.11368168204359e+16*cos(theta)**10 + 562713556995830.0*cos(theta)**8 - 6274782794059.44*cos(theta)**6 + 37231701705.2577*cos(theta)**4 - 87914289.7408683*cos(theta)**2 + 34476.1920552425)*sin(3*phi)

#@torch.jit.script
def Yl71_m_minus_2(theta, phi):
    return 0.000933409489689217*(1.0 - cos(theta)**2)*(7.84363495952114e+23*cos(theta)**69 - 1.30504734858416e+25*cos(theta)**67 + 1.03793513946747e+26*cos(theta)**65 - 5.25281043818087e+26*cos(theta)**63 + 1.89976644180875e+27*cos(theta)**61 - 5.22792870452633e+27*cos(theta)**59 + 1.13803893300821e+28*cos(theta)**57 - 2.01141764903777e+28*cos(theta)**55 + 2.93991654411525e+28*cos(theta)**53 - 3.60107110914739e+28*cos(theta)**51 + 3.73281761314059e+28*cos(theta)**49 - 3.2981168392587e+28*cos(theta)**47 + 2.49668368574135e+28*cos(theta)**45 - 1.62506038716893e+28*cos(theta)**43 + 9.11446912803443e+27*cos(theta)**41 - 4.40935969615825e+27*cos(theta)**39 + 1.83971595430927e+27*cos(theta)**37 - 6.61225486006461e+26*cos(theta)**35 + 2.04272670910615e+26*cos(theta)**33 - 5.4063142977847e+25*cos(theta)**31 + 1.22035735362616e+25*cos(theta)**29 - 2.33599757459793e+24*cos(theta)**27 + 3.76462419046773e+23*cos(theta)**25 - 5.06224678234119e+22*cos(theta)**23 + 5.61731770145755e+21*cos(theta)**21 - 5.07370631099391e+20*cos(theta)**19 + 3.66696440904463e+19*cos(theta)**17 - 2.07535230807353e+18*cos(theta)**15 + 8.94548408652384e+16*cos(theta)**13 - 2.83061971094872e+15*cos(theta)**11 + 62523728555092.2*cos(theta)**9 - 896397542008.491*cos(theta)**7 + 7446340341.05155*cos(theta)**5 - 29304763.2469561*cos(theta)**3 + 34476.1920552425*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl71_m_minus_1(theta, phi):
    return 0.0667240903835191*(1.0 - cos(theta)**2)**0.5*(1.12051927993159e+22*cos(theta)**70 - 1.91918727732964e+23*cos(theta)**68 + 1.57262899919314e+24*cos(theta)**66 - 8.20751630965762e+24*cos(theta)**64 + 3.06413942227218e+25*cos(theta)**62 - 8.71321450754389e+25*cos(theta)**60 + 1.96213609139347e+26*cos(theta)**58 - 3.59181723042459e+26*cos(theta)**56 + 5.44428989650972e+26*cos(theta)**54 - 6.92513674836036e+26*cos(theta)**52 + 7.46563522628117e+26*cos(theta)**50 - 6.87107674845562e+26*cos(theta)**48 + 5.42757322987251e+26*cos(theta)**46 - 3.69331906174756e+26*cos(theta)**44 + 2.17011169715105e+26*cos(theta)**42 - 1.10233992403956e+26*cos(theta)**40 + 4.84135777449808e+25*cos(theta)**38 - 1.83673746112906e+25*cos(theta)**36 + 6.00801973266515e+24*cos(theta)**34 - 1.68947321805772e+24*cos(theta)**32 + 4.06785784542053e+23*cos(theta)**30 - 8.34284848070688e+22*cos(theta)**28 + 1.44793238094913e+22*cos(theta)**26 - 2.10926949264216e+21*cos(theta)**24 + 2.55332622793525e+20*cos(theta)**22 - 2.53685315549696e+19*cos(theta)**20 + 2.03720244946924e+18*cos(theta)**18 - 1.29709519254596e+17*cos(theta)**16 + 6.38963149037417e+15*cos(theta)**14 - 235884975912393.0*cos(theta)**12 + 6252372855509.22*cos(theta)**10 - 112049692751.061*cos(theta)**8 + 1241056723.50859*cos(theta)**6 - 7326190.81173902*cos(theta)**4 + 17238.0960276212*cos(theta)**2 - 6.74680862137817)*sin(phi)

#@torch.jit.script
def Yl71_m0(theta, phi):
    return 1.6725301070792e+21*cos(theta)**71 - 2.94768603978143e+22*cos(theta)**69 + 2.48750771558533e+23*cos(theta)**67 - 1.33817020904116e+24*cos(theta)**65 + 5.15443339778818e+24*cos(theta)**63 - 1.5137757031399e+25*cos(theta)**61 + 3.52443961418068e+25*cos(theta)**59 - 6.67809100760037e+25*cos(theta)**57 + 1.04903870552463e+26*cos(theta)**55 - 1.38473109129251e+26*cos(theta)**53 + 1.55134914130169e+26*cos(theta)**51 - 1.48607825331303e+26*cos(theta)**49 + 1.2238291497872e+26*cos(theta)**47 - 8.69795733675193e+25*cos(theta)**45 + 5.34843339340647e+25*cos(theta)**43 - 2.84934239188557e+25*cos(theta)**41 + 1.31557475301023e+25*cos(theta)**39 - 5.26087907167069e+24*cos(theta)**37 + 1.81918248272725e+24*cos(theta)**35 - 5.42563196602864e+23*cos(theta)**33 + 1.3906474165355e+23*cos(theta)**31 - 3.04880268123058e+22*cos(theta)**29 + 5.68325935986967e+21*cos(theta)**27 - 8.94138966971875e+20*cos(theta)**25 + 1.17649864075247e+20*cos(theta)**23 - 1.28023292950699e+19*cos(theta)**21 + 1.13630141672218e+18*cos(theta)**19 - 8.0860400440904e+16*cos(theta)**17 + 4.51437375203733e+15*cos(theta)**15 - 192295839336276.0*cos(theta)**13 + 6023725087642.38*cos(theta)**11 - 131941409725.341*cos(theta)**9 + 1878912480.26593*cos(theta)**7 - 15528202.3162473*cos(theta)**5 + 60894.9110441072*cos(theta)**3 - 71.5008740243921*cos(theta)

#@torch.jit.script
def Yl71_m1(theta, phi):
    return 0.0667240903835191*(1.0 - cos(theta)**2)**0.5*(1.12051927993159e+22*cos(theta)**70 - 1.91918727732964e+23*cos(theta)**68 + 1.57262899919314e+24*cos(theta)**66 - 8.20751630965762e+24*cos(theta)**64 + 3.06413942227218e+25*cos(theta)**62 - 8.71321450754389e+25*cos(theta)**60 + 1.96213609139347e+26*cos(theta)**58 - 3.59181723042459e+26*cos(theta)**56 + 5.44428989650972e+26*cos(theta)**54 - 6.92513674836036e+26*cos(theta)**52 + 7.46563522628117e+26*cos(theta)**50 - 6.87107674845562e+26*cos(theta)**48 + 5.42757322987251e+26*cos(theta)**46 - 3.69331906174756e+26*cos(theta)**44 + 2.17011169715105e+26*cos(theta)**42 - 1.10233992403956e+26*cos(theta)**40 + 4.84135777449808e+25*cos(theta)**38 - 1.83673746112906e+25*cos(theta)**36 + 6.00801973266515e+24*cos(theta)**34 - 1.68947321805772e+24*cos(theta)**32 + 4.06785784542053e+23*cos(theta)**30 - 8.34284848070688e+22*cos(theta)**28 + 1.44793238094913e+22*cos(theta)**26 - 2.10926949264216e+21*cos(theta)**24 + 2.55332622793525e+20*cos(theta)**22 - 2.53685315549696e+19*cos(theta)**20 + 2.03720244946924e+18*cos(theta)**18 - 1.29709519254596e+17*cos(theta)**16 + 6.38963149037417e+15*cos(theta)**14 - 235884975912393.0*cos(theta)**12 + 6252372855509.22*cos(theta)**10 - 112049692751.061*cos(theta)**8 + 1241056723.50859*cos(theta)**6 - 7326190.81173902*cos(theta)**4 + 17238.0960276212*cos(theta)**2 - 6.74680862137817)*cos(phi)

#@torch.jit.script
def Yl71_m2(theta, phi):
    return 0.000933409489689217*(1.0 - cos(theta)**2)*(7.84363495952114e+23*cos(theta)**69 - 1.30504734858416e+25*cos(theta)**67 + 1.03793513946747e+26*cos(theta)**65 - 5.25281043818087e+26*cos(theta)**63 + 1.89976644180875e+27*cos(theta)**61 - 5.22792870452633e+27*cos(theta)**59 + 1.13803893300821e+28*cos(theta)**57 - 2.01141764903777e+28*cos(theta)**55 + 2.93991654411525e+28*cos(theta)**53 - 3.60107110914739e+28*cos(theta)**51 + 3.73281761314059e+28*cos(theta)**49 - 3.2981168392587e+28*cos(theta)**47 + 2.49668368574135e+28*cos(theta)**45 - 1.62506038716893e+28*cos(theta)**43 + 9.11446912803443e+27*cos(theta)**41 - 4.40935969615825e+27*cos(theta)**39 + 1.83971595430927e+27*cos(theta)**37 - 6.61225486006461e+26*cos(theta)**35 + 2.04272670910615e+26*cos(theta)**33 - 5.4063142977847e+25*cos(theta)**31 + 1.22035735362616e+25*cos(theta)**29 - 2.33599757459793e+24*cos(theta)**27 + 3.76462419046773e+23*cos(theta)**25 - 5.06224678234119e+22*cos(theta)**23 + 5.61731770145755e+21*cos(theta)**21 - 5.07370631099391e+20*cos(theta)**19 + 3.66696440904463e+19*cos(theta)**17 - 2.07535230807353e+18*cos(theta)**15 + 8.94548408652384e+16*cos(theta)**13 - 2.83061971094872e+15*cos(theta)**11 + 62523728555092.2*cos(theta)**9 - 896397542008.491*cos(theta)**7 + 7446340341.05155*cos(theta)**5 - 29304763.2469561*cos(theta)**3 + 34476.1920552425*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl71_m3(theta, phi):
    return 1.30626655242972e-5*(1.0 - cos(theta)**2)**1.5*(5.41210812206959e+25*cos(theta)**68 - 8.74381723551385e+26*cos(theta)**66 + 6.74657840653856e+27*cos(theta)**64 - 3.30927057605395e+28*cos(theta)**62 + 1.15885752950334e+29*cos(theta)**60 - 3.08447793567054e+29*cos(theta)**58 + 6.48682191814682e+29*cos(theta)**56 - 1.10627970697077e+30*cos(theta)**54 + 1.55815576838108e+30*cos(theta)**52 - 1.83654626566517e+30*cos(theta)**50 + 1.82908063043889e+30*cos(theta)**48 - 1.55011491445159e+30*cos(theta)**46 + 1.12350765858361e+30*cos(theta)**44 - 6.98775966482639e+29*cos(theta)**42 + 3.73693234249411e+29*cos(theta)**40 - 1.71965028150172e+29*cos(theta)**38 + 6.80694903094429e+28*cos(theta)**36 - 2.31428920102262e+28*cos(theta)**34 + 6.7409981400503e+27*cos(theta)**32 - 1.67595743231326e+27*cos(theta)**30 + 3.53903632551586e+26*cos(theta)**28 - 6.3071934514144e+25*cos(theta)**26 + 9.41156047616933e+24*cos(theta)**24 - 1.16431675993847e+24*cos(theta)**22 + 1.17963671730609e+23*cos(theta)**20 - 9.64004199088844e+21*cos(theta)**18 + 6.23383949537587e+20*cos(theta)**16 - 3.1130284621103e+19*cos(theta)**14 + 1.1629129312481e+18*cos(theta)**12 - 3.11368168204359e+16*cos(theta)**10 + 562713556995830.0*cos(theta)**8 - 6274782794059.44*cos(theta)**6 + 37231701705.2577*cos(theta)**4 - 87914289.7408683*cos(theta)**2 + 34476.1920552425)*cos(3*phi)

#@torch.jit.script
def Yl71_m4(theta, phi):
    return 1.82913903779927e-7*(1.0 - cos(theta)**2)**2*(3.68023352300732e+27*cos(theta)**67 - 5.77091937543914e+28*cos(theta)**65 + 4.31781018018468e+29*cos(theta)**63 - 2.05174775715345e+30*cos(theta)**61 + 6.95314517702002e+30*cos(theta)**59 - 1.78899720268891e+31*cos(theta)**57 + 3.63262027416222e+31*cos(theta)**55 - 5.97391041764218e+31*cos(theta)**53 + 8.10240999558162e+31*cos(theta)**51 - 9.18273132832584e+31*cos(theta)**49 + 8.77958702610666e+31*cos(theta)**47 - 7.13052860647731e+31*cos(theta)**45 + 4.94343369776788e+31*cos(theta)**43 - 2.93485905922709e+31*cos(theta)**41 + 1.49477293699765e+31*cos(theta)**39 - 6.53467106970652e+30*cos(theta)**37 + 2.45050165113995e+30*cos(theta)**35 - 7.86858328347689e+29*cos(theta)**33 + 2.15711940481609e+29*cos(theta)**31 - 5.02787229693977e+28*cos(theta)**29 + 9.9093017114444e+27*cos(theta)**27 - 1.63987029736774e+27*cos(theta)**25 + 2.25877451428064e+26*cos(theta)**23 - 2.56149687186464e+25*cos(theta)**21 + 2.35927343461217e+24*cos(theta)**19 - 1.73520755835992e+23*cos(theta)**17 + 9.97414319260139e+21*cos(theta)**15 - 4.35823984695442e+20*cos(theta)**13 + 1.39549551749772e+19*cos(theta)**11 - 3.11368168204359e+17*cos(theta)**9 + 4.50170845596664e+15*cos(theta)**7 - 37648696764356.6*cos(theta)**5 + 148926806821.031*cos(theta)**3 - 175828579.481737*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl71_m5(theta, phi):
    return 2.56331820022474e-9*(1.0 - cos(theta)**2)**2.5*(2.4657564604149e+29*cos(theta)**66 - 3.75109759403544e+30*cos(theta)**64 + 2.72022041351635e+31*cos(theta)**62 - 1.2515661318636e+32*cos(theta)**60 + 4.10235565444181e+32*cos(theta)**58 - 1.01972840553268e+33*cos(theta)**56 + 1.99794115078922e+33*cos(theta)**54 - 3.16617252135036e+33*cos(theta)**52 + 4.13222909774663e+33*cos(theta)**50 - 4.49953835087966e+33*cos(theta)**48 + 4.12640590227013e+33*cos(theta)**46 - 3.20873787291479e+33*cos(theta)**44 + 2.12567649004019e+33*cos(theta)**42 - 1.2032922142831e+33*cos(theta)**40 + 5.82961445429082e+32*cos(theta)**38 - 2.41782829579141e+32*cos(theta)**36 + 8.57675577898981e+31*cos(theta)**34 - 2.59663248354737e+31*cos(theta)**32 + 6.68707015492989e+30*cos(theta)**30 - 1.45808296611253e+30*cos(theta)**28 + 2.67551146208999e+29*cos(theta)**26 - 4.09967574341936e+28*cos(theta)**24 + 5.19518138284547e+27*cos(theta)**22 - 5.37914343091575e+26*cos(theta)**20 + 4.48261952576312e+25*cos(theta)**18 - 2.94985284921186e+24*cos(theta)**16 + 1.49612147889021e+23*cos(theta)**14 - 5.66571180104074e+21*cos(theta)**12 + 1.53504506924749e+20*cos(theta)**10 - 2.80231351383923e+18*cos(theta)**8 + 3.15119591917665e+16*cos(theta)**6 - 188243483821783.0*cos(theta)**4 + 446780420463.093*cos(theta)**2 - 175828579.481737)*cos(5*phi)

#@torch.jit.script
def Yl71_m6(theta, phi):
    return 3.59571441194071e-11*(1.0 - cos(theta)**2)**3*(1.62739926387384e+31*cos(theta)**65 - 2.40070246018268e+32*cos(theta)**63 + 1.68653665638014e+33*cos(theta)**61 - 7.50939679118163e+33*cos(theta)**59 + 2.37936627957625e+34*cos(theta)**57 - 5.710479070983e+34*cos(theta)**55 + 1.07888822142618e+35*cos(theta)**53 - 1.64640971110219e+35*cos(theta)**51 + 2.06611454887331e+35*cos(theta)**49 - 2.15977840842224e+35*cos(theta)**47 + 1.89814671504426e+35*cos(theta)**45 - 1.41184466408251e+35*cos(theta)**43 + 8.92784125816879e+34*cos(theta)**41 - 4.81316885713242e+34*cos(theta)**39 + 2.21525349263051e+34*cos(theta)**37 - 8.70418186484909e+33*cos(theta)**35 + 2.91609696485654e+33*cos(theta)**33 - 8.3092239473516e+32*cos(theta)**31 + 2.00612104647897e+32*cos(theta)**29 - 4.08263230511509e+31*cos(theta)**27 + 6.95632980143397e+30*cos(theta)**25 - 9.83922178420646e+29*cos(theta)**23 + 1.142939904226e+29*cos(theta)**21 - 1.07582868618315e+28*cos(theta)**19 + 8.06871514637362e+26*cos(theta)**17 - 4.71976455873898e+25*cos(theta)**15 + 2.09457007044629e+24*cos(theta)**13 - 6.79885416124889e+22*cos(theta)**11 + 1.53504506924749e+21*cos(theta)**9 - 2.24185081107139e+19*cos(theta)**7 + 1.89071755150599e+17*cos(theta)**5 - 752973935287132.0*cos(theta)**3 + 893560840926.185*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl71_m7(theta, phi):
    return 5.04988177888807e-13*(1.0 - cos(theta)**2)**3.5*(1.05780952151799e+33*cos(theta)**64 - 1.51244254991509e+34*cos(theta)**62 + 1.02878736039188e+35*cos(theta)**60 - 4.43054410679716e+35*cos(theta)**58 + 1.35623877935846e+36*cos(theta)**56 - 3.14076348904065e+36*cos(theta)**54 + 5.71810757355875e+36*cos(theta)**52 - 8.39668952662115e+36*cos(theta)**50 + 1.01239612894792e+37*cos(theta)**48 - 1.01509585195845e+37*cos(theta)**46 + 8.54166021769917e+36*cos(theta)**44 - 6.07093205555478e+36*cos(theta)**42 + 3.66041491584921e+36*cos(theta)**40 - 1.87713585428164e+36*cos(theta)**38 + 8.19643792273289e+35*cos(theta)**36 - 3.04646365269718e+35*cos(theta)**34 + 9.62311998402657e+34*cos(theta)**32 - 2.57585942367899e+34*cos(theta)**30 + 5.81775103478901e+33*cos(theta)**28 - 1.10231072238108e+33*cos(theta)**26 + 1.73908245035849e+32*cos(theta)**24 - 2.26302101036749e+31*cos(theta)**22 + 2.40017379887461e+30*cos(theta)**20 - 2.04407450374798e+29*cos(theta)**18 + 1.37168157488352e+28*cos(theta)**16 - 7.07964683810847e+26*cos(theta)**14 + 2.72294109158018e+25*cos(theta)**12 - 7.47873957737378e+23*cos(theta)**10 + 1.38154056232274e+22*cos(theta)**8 - 1.56929556774997e+20*cos(theta)**6 + 9.45358775752995e+17*cos(theta)**4 - 2.2589218058614e+15*cos(theta)**2 + 893560840926.185)*cos(7*phi)

#@torch.jit.script
def Yl71_m8(theta, phi):
    return 7.1019511131672e-15*(1.0 - cos(theta)**2)**4*(6.76998093771516e+34*cos(theta)**63 - 9.37714380947355e+35*cos(theta)**61 + 6.1727241623513e+36*cos(theta)**59 - 2.56971558194235e+37*cos(theta)**57 + 7.5949371644074e+37*cos(theta)**55 - 1.69601228408195e+38*cos(theta)**53 + 2.97341593825055e+38*cos(theta)**51 - 4.19834476331057e+38*cos(theta)**49 + 4.85950141895003e+38*cos(theta)**47 - 4.66944091900888e+38*cos(theta)**45 + 3.75833049578763e+38*cos(theta)**43 - 2.54979146333301e+38*cos(theta)**41 + 1.46416596633968e+38*cos(theta)**39 - 7.13311624627025e+37*cos(theta)**37 + 2.95071765218384e+37*cos(theta)**35 - 1.03579764191704e+37*cos(theta)**33 + 3.0793983948885e+36*cos(theta)**31 - 7.72757827103698e+35*cos(theta)**29 + 1.62897028974092e+35*cos(theta)**27 - 2.8660078781908e+34*cos(theta)**25 + 4.17379788086038e+33*cos(theta)**23 - 4.97864622280847e+32*cos(theta)**21 + 4.80034759774921e+31*cos(theta)**19 - 3.67933410674637e+30*cos(theta)**17 + 2.19469051981363e+29*cos(theta)**15 - 9.91150557335186e+27*cos(theta)**13 + 3.26752930989622e+26*cos(theta)**11 - 7.47873957737378e+24*cos(theta)**9 + 1.10523244985819e+23*cos(theta)**7 - 9.41577340649983e+20*cos(theta)**5 + 3.78143510301198e+18*cos(theta)**3 - 4.51784361172279e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl71_m9(theta, phi):
    return 1.0003740333612e-16*(1.0 - cos(theta)**2)**4.5*(4.26508799076055e+36*cos(theta)**62 - 5.72005772377887e+37*cos(theta)**60 + 3.64190725578726e+38*cos(theta)**58 - 1.46473788170714e+39*cos(theta)**56 + 4.17721544042407e+39*cos(theta)**54 - 8.98886510563435e+39*cos(theta)**52 + 1.51644212850778e+40*cos(theta)**50 - 2.05718893402218e+40*cos(theta)**48 + 2.28396566690652e+40*cos(theta)**46 - 2.10124841355399e+40*cos(theta)**44 + 1.61608211318868e+40*cos(theta)**42 - 1.04541449996653e+40*cos(theta)**40 + 5.71024726872476e+39*cos(theta)**38 - 2.63925301111999e+39*cos(theta)**36 + 1.03275117826434e+39*cos(theta)**34 - 3.41813221832624e+38*cos(theta)**32 + 9.54613502415435e+37*cos(theta)**30 - 2.24099769860073e+37*cos(theta)**28 + 4.39821978230049e+36*cos(theta)**26 - 7.16501969547699e+35*cos(theta)**24 + 9.59973512597888e+34*cos(theta)**22 - 1.04551570678978e+34*cos(theta)**20 + 9.12066043572351e+32*cos(theta)**18 - 6.25486798146883e+31*cos(theta)**16 + 3.29203577972044e+30*cos(theta)**14 - 1.28849572453574e+29*cos(theta)**12 + 3.59428224088584e+27*cos(theta)**10 - 6.7308656196364e+25*cos(theta)**8 + 7.73662714900736e+23*cos(theta)**6 - 4.70788670324991e+21*cos(theta)**4 + 1.13443053090359e+19*cos(theta)**2 - 4.51784361172279e+15)*cos(9*phi)

#@torch.jit.script
def Yl71_m10(theta, phi):
    return 1.41164032538405e-18*(1.0 - cos(theta)**2)**5*(2.64435455427154e+38*cos(theta)**61 - 3.43203463426732e+39*cos(theta)**59 + 2.11230620835661e+40*cos(theta)**57 - 8.20253213755999e+40*cos(theta)**55 + 2.255696337829e+41*cos(theta)**53 - 4.67420985492986e+41*cos(theta)**51 + 7.5822106425389e+41*cos(theta)**49 - 9.87450688330647e+41*cos(theta)**47 + 1.050624206777e+42*cos(theta)**45 - 9.24549301963758e+41*cos(theta)**43 + 6.78754487539247e+41*cos(theta)**41 - 4.18165799986613e+41*cos(theta)**39 + 2.16989396211541e+41*cos(theta)**37 - 9.50131084003197e+40*cos(theta)**35 + 3.51135400609877e+40*cos(theta)**33 - 1.0938023098644e+40*cos(theta)**31 + 2.86384050724631e+39*cos(theta)**29 - 6.27479355608203e+38*cos(theta)**27 + 1.14353714339813e+38*cos(theta)**25 - 1.71960472691448e+37*cos(theta)**23 + 2.11194172771535e+36*cos(theta)**21 - 2.09103141357956e+35*cos(theta)**19 + 1.64171887843023e+34*cos(theta)**17 - 1.00077887703501e+33*cos(theta)**15 + 4.60885009160861e+31*cos(theta)**13 - 1.54619486944289e+30*cos(theta)**11 + 3.59428224088584e+28*cos(theta)**9 - 5.38469249570912e+26*cos(theta)**7 + 4.64197628940441e+24*cos(theta)**5 - 1.88315468129997e+22*cos(theta)**3 + 2.26886106180719e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl71_m11(theta, phi):
    return 1.99596174091397e-20*(1.0 - cos(theta)**2)**5.5*(1.61305627810564e+40*cos(theta)**60 - 2.02490043421772e+41*cos(theta)**58 + 1.20401453876327e+42*cos(theta)**56 - 4.51139267565799e+42*cos(theta)**54 + 1.19551905904937e+43*cos(theta)**52 - 2.38384702601423e+43*cos(theta)**50 + 3.71528321484406e+43*cos(theta)**48 - 4.64101823515404e+43*cos(theta)**46 + 4.72780893049649e+43*cos(theta)**44 - 3.97556199844416e+43*cos(theta)**42 + 2.78289339891091e+43*cos(theta)**40 - 1.63084661994779e+43*cos(theta)**38 + 8.02860765982701e+42*cos(theta)**36 - 3.32545879401119e+42*cos(theta)**34 + 1.15874682201259e+42*cos(theta)**32 - 3.39078716057963e+41*cos(theta)**30 + 8.30513747101429e+40*cos(theta)**28 - 1.69419426014215e+40*cos(theta)**26 + 2.85884285849532e+39*cos(theta)**24 - 3.9550908719033e+38*cos(theta)**22 + 4.43507762820224e+37*cos(theta)**20 - 3.97295968580116e+36*cos(theta)**18 + 2.79092209333139e+35*cos(theta)**16 - 1.50116831555252e+34*cos(theta)**14 + 5.9915051190912e+32*cos(theta)**12 - 1.70081435638718e+31*cos(theta)**10 + 3.23485401679725e+29*cos(theta)**8 - 3.76928474699638e+27*cos(theta)**6 + 2.32098814470221e+25*cos(theta)**4 - 5.6494640438999e+22*cos(theta)**2 + 2.26886106180719e+19)*cos(11*phi)

#@torch.jit.script
def Yl71_m12(theta, phi):
    return 2.82837858925591e-22*(1.0 - cos(theta)**2)**6*(9.67833766863384e+41*cos(theta)**59 - 1.17444225184628e+43*cos(theta)**57 + 6.74248141707431e+43*cos(theta)**55 - 2.43615204485532e+44*cos(theta)**53 + 6.21669910705671e+44*cos(theta)**51 - 1.19192351300711e+45*cos(theta)**49 + 1.78333594312515e+45*cos(theta)**47 - 2.13486838817086e+45*cos(theta)**45 + 2.08023592941846e+45*cos(theta)**43 - 1.66973603934655e+45*cos(theta)**41 + 1.11315735956436e+45*cos(theta)**39 - 6.19721715580161e+44*cos(theta)**37 + 2.89029875753772e+44*cos(theta)**35 - 1.1306559899638e+44*cos(theta)**33 + 3.7079898304403e+43*cos(theta)**31 - 1.01723614817389e+43*cos(theta)**29 + 2.325438491884e+42*cos(theta)**27 - 4.40490507636959e+41*cos(theta)**25 + 6.86122286038876e+40*cos(theta)**23 - 8.70119991818725e+39*cos(theta)**21 + 8.87015525640448e+38*cos(theta)**19 - 7.15132743444209e+37*cos(theta)**17 + 4.46547534933023e+36*cos(theta)**15 - 2.10163564177353e+35*cos(theta)**13 + 7.18980614290944e+33*cos(theta)**11 - 1.70081435638718e+32*cos(theta)**9 + 2.5878832134378e+30*cos(theta)**7 - 2.26157084819783e+28*cos(theta)**5 + 9.28395257880883e+25*cos(theta)**3 - 1.12989280877998e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl71_m13(theta, phi):
    return 4.0176480748809e-24*(1.0 - cos(theta)**2)**6.5*(5.71021922449397e+43*cos(theta)**58 - 6.69432083552378e+44*cos(theta)**56 + 3.70836477939087e+45*cos(theta)**54 - 1.29116058377332e+46*cos(theta)**52 + 3.17051654459892e+46*cos(theta)**50 - 5.84042521373486e+46*cos(theta)**48 + 8.3816789326882e+46*cos(theta)**46 - 9.60690774676886e+46*cos(theta)**44 + 8.94501449649936e+46*cos(theta)**42 - 6.84591776132084e+46*cos(theta)**40 + 4.34131370230102e+46*cos(theta)**38 - 2.29297034764659e+46*cos(theta)**36 + 1.0116045651382e+46*cos(theta)**34 - 3.73116476688055e+45*cos(theta)**32 + 1.14947684743649e+45*cos(theta)**30 - 2.94998482970428e+44*cos(theta)**28 + 6.2786839280868e+43*cos(theta)**26 - 1.1012262690924e+43*cos(theta)**24 + 1.57808125788942e+42*cos(theta)**22 - 1.82725198281932e+41*cos(theta)**20 + 1.68532949871685e+40*cos(theta)**18 - 1.21572566385515e+39*cos(theta)**16 + 6.69821302399534e+37*cos(theta)**14 - 2.73212633430559e+36*cos(theta)**12 + 7.90878675720038e+34*cos(theta)**10 - 1.53073292074846e+33*cos(theta)**8 + 1.81151824940646e+31*cos(theta)**6 - 1.13078542409892e+29*cos(theta)**4 + 2.78518577364265e+26*cos(theta)**2 - 1.12989280877998e+23)*cos(13*phi)

#@torch.jit.script
def Yl71_m14(theta, phi):
    return 5.72200762892404e-26*(1.0 - cos(theta)**2)**7*(3.3119271502065e+45*cos(theta)**57 - 3.74881966789332e+46*cos(theta)**55 + 2.00251698087107e+47*cos(theta)**53 - 6.71403503562125e+47*cos(theta)**51 + 1.58525827229946e+48*cos(theta)**49 - 2.80340410259273e+48*cos(theta)**47 + 3.85557230903657e+48*cos(theta)**45 - 4.2270394085783e+48*cos(theta)**43 + 3.75690608852973e+48*cos(theta)**41 - 2.73836710452834e+48*cos(theta)**39 + 1.64969920687439e+48*cos(theta)**37 - 8.25469325152774e+47*cos(theta)**35 + 3.43945552146989e+47*cos(theta)**33 - 1.19397272540178e+47*cos(theta)**31 + 3.44843054230948e+46*cos(theta)**29 - 8.25995752317197e+45*cos(theta)**27 + 1.63245782130257e+45*cos(theta)**25 - 2.64294304582175e+44*cos(theta)**23 + 3.47177876735671e+43*cos(theta)**21 - 3.65450396563865e+42*cos(theta)**19 + 3.03359309769033e+41*cos(theta)**17 - 1.94516106216825e+40*cos(theta)**15 + 9.37749823359348e+38*cos(theta)**13 - 3.2785516011667e+37*cos(theta)**11 + 7.90878675720038e+35*cos(theta)**9 - 1.22458633659877e+34*cos(theta)**7 + 1.08691094964388e+32*cos(theta)**5 - 4.52314169639566e+29*cos(theta)**3 + 5.5703715472853e+26*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl71_m15(theta, phi):
    return 8.17262889945722e-28*(1.0 - cos(theta)**2)**7.5*(1.88779847561771e+47*cos(theta)**56 - 2.06185081734132e+48*cos(theta)**54 + 1.06133399986167e+49*cos(theta)**52 - 3.42415786816684e+49*cos(theta)**50 + 7.76776553426737e+49*cos(theta)**48 - 1.31759992821858e+50*cos(theta)**46 + 1.73500753906646e+50*cos(theta)**44 - 1.81762694568867e+50*cos(theta)**42 + 1.54033149629719e+50*cos(theta)**40 - 1.06796317076605e+50*cos(theta)**38 + 6.10388706543523e+49*cos(theta)**36 - 2.88914263803471e+49*cos(theta)**34 + 1.13502032208506e+49*cos(theta)**32 - 3.70131544874551e+48*cos(theta)**30 + 1.00004485726975e+48*cos(theta)**28 - 2.23018853125643e+47*cos(theta)**26 + 4.08114455325642e+46*cos(theta)**24 - 6.07876900539003e+45*cos(theta)**22 + 7.2907354114491e+44*cos(theta)**20 - 6.94355753471343e+43*cos(theta)**18 + 5.15710826607357e+42*cos(theta)**16 - 2.91774159325237e+41*cos(theta)**14 + 1.21907477036715e+40*cos(theta)**12 - 3.60640676128337e+38*cos(theta)**10 + 7.11790808148034e+36*cos(theta)**8 - 8.57210435619138e+34*cos(theta)**6 + 5.43455474821939e+32*cos(theta)**4 - 1.3569425089187e+30*cos(theta)**2 + 5.5703715472853e+26)*cos(15*phi)

#@torch.jit.script
def Yl71_m16(theta, phi):
    return 1.17086854566878e-29*(1.0 - cos(theta)**2)**8*(1.05716714634592e+49*cos(theta)**55 - 1.11339944136432e+50*cos(theta)**53 + 5.51893679928067e+50*cos(theta)**51 - 1.71207893408342e+51*cos(theta)**49 + 3.72852745644834e+51*cos(theta)**47 - 6.06095966980549e+51*cos(theta)**45 + 7.63403317189241e+51*cos(theta)**43 - 7.63403317189241e+51*cos(theta)**41 + 6.16132598518876e+51*cos(theta)**39 - 4.05826004891099e+51*cos(theta)**37 + 2.19739934355668e+51*cos(theta)**35 - 9.82308496931801e+50*cos(theta)**33 + 3.63206503067221e+50*cos(theta)**31 - 1.11039463462365e+50*cos(theta)**29 + 2.8001256003553e+49*cos(theta)**27 - 5.79849018126672e+48*cos(theta)**25 + 9.79474692781541e+47*cos(theta)**23 - 1.33732918118581e+47*cos(theta)**21 + 1.45814708228982e+46*cos(theta)**19 - 1.24984035624842e+45*cos(theta)**17 + 8.25137322571771e+43*cos(theta)**15 - 4.08483823055332e+42*cos(theta)**13 + 1.46288972444058e+41*cos(theta)**11 - 3.60640676128337e+39*cos(theta)**9 + 5.69432646518427e+37*cos(theta)**7 - 5.14326261371483e+35*cos(theta)**5 + 2.17382189928775e+33*cos(theta)**3 - 2.7138850178374e+30*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl71_m17(theta, phi):
    return 1.68300520225555e-31*(1.0 - cos(theta)**2)**8.5*(5.81441930490253e+50*cos(theta)**54 - 5.90101703923087e+51*cos(theta)**52 + 2.81465776763314e+52*cos(theta)**50 - 8.38918677700875e+52*cos(theta)**48 + 1.75240790453072e+53*cos(theta)**46 - 2.72743185141247e+53*cos(theta)**44 + 3.28263426391374e+53*cos(theta)**42 - 3.12995360047589e+53*cos(theta)**40 + 2.40291713422362e+53*cos(theta)**38 - 1.50155621809707e+53*cos(theta)**36 + 7.6908977024484e+52*cos(theta)**34 - 3.24161803987494e+52*cos(theta)**32 + 1.12594015950838e+52*cos(theta)**30 - 3.22014444040859e+51*cos(theta)**28 + 7.56033912095931e+50*cos(theta)**26 - 1.44962254531668e+50*cos(theta)**24 + 2.25279179339754e+49*cos(theta)**22 - 2.80839128049019e+48*cos(theta)**20 + 2.77047945635066e+47*cos(theta)**18 - 2.12472860562231e+46*cos(theta)**16 + 1.23770598385766e+45*cos(theta)**14 - 5.31028969971931e+43*cos(theta)**12 + 1.60917869688464e+42*cos(theta)**10 - 3.24576608515504e+40*cos(theta)**8 + 3.98602852562899e+38*cos(theta)**6 - 2.57163130685741e+36*cos(theta)**4 + 6.52146569786326e+33*cos(theta)**2 - 2.7138850178374e+30)*cos(17*phi)

#@torch.jit.script
def Yl71_m18(theta, phi):
    return 2.42769193282891e-33*(1.0 - cos(theta)**2)**9*(3.13978642464737e+52*cos(theta)**53 - 3.06852886040005e+53*cos(theta)**51 + 1.40732888381657e+54*cos(theta)**49 - 4.0268096529642e+54*cos(theta)**47 + 8.0610763608413e+54*cos(theta)**45 - 1.20007001462149e+55*cos(theta)**43 + 1.37870639084377e+55*cos(theta)**41 - 1.25198144019036e+55*cos(theta)**39 + 9.13108511004974e+54*cos(theta)**37 - 5.40560238514944e+54*cos(theta)**35 + 2.61490521883245e+54*cos(theta)**33 - 1.03731777275998e+54*cos(theta)**31 + 3.37782047852515e+53*cos(theta)**29 - 9.01640443314406e+52*cos(theta)**27 + 1.96568817144942e+52*cos(theta)**25 - 3.47909410876003e+51*cos(theta)**23 + 4.9561419454746e+50*cos(theta)**21 - 5.61678256098039e+49*cos(theta)**19 + 4.98686302143118e+48*cos(theta)**17 - 3.39956576899569e+47*cos(theta)**15 + 1.73278837740072e+46*cos(theta)**13 - 6.37234763966318e+44*cos(theta)**11 + 1.60917869688464e+43*cos(theta)**9 - 2.59661286812403e+41*cos(theta)**7 + 2.39161711537739e+39*cos(theta)**5 - 1.02865252274297e+37*cos(theta)**3 + 1.30429313957265e+34*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl71_m19(theta, phi):
    return 3.51507329866901e-35*(1.0 - cos(theta)**2)**9.5*(1.66408680506311e+54*cos(theta)**52 - 1.56494971880403e+55*cos(theta)**50 + 6.8959115307012e+55*cos(theta)**48 - 1.89260053689318e+56*cos(theta)**46 + 3.62748436237859e+56*cos(theta)**44 - 5.16030106287239e+56*cos(theta)**42 + 5.65269620245945e+56*cos(theta)**40 - 4.88272761674239e+56*cos(theta)**38 + 3.3785014907184e+56*cos(theta)**36 - 1.89196083480231e+56*cos(theta)**34 + 8.6291872221471e+55*cos(theta)**32 - 3.21568509555594e+55*cos(theta)**30 + 9.79567938772294e+54*cos(theta)**28 - 2.4344291969489e+54*cos(theta)**26 + 4.91422042862355e+53*cos(theta)**24 - 8.00191645014808e+52*cos(theta)**22 + 1.04078980854967e+52*cos(theta)**20 - 1.06718868658627e+51*cos(theta)**18 + 8.47766713643301e+49*cos(theta)**16 - 5.09934865349354e+48*cos(theta)**14 + 2.25262489062093e+47*cos(theta)**12 - 7.0095824036295e+45*cos(theta)**10 + 1.44826082719618e+44*cos(theta)**8 - 1.81762900768682e+42*cos(theta)**6 + 1.1958085576887e+40*cos(theta)**4 - 3.0859575682289e+37*cos(theta)**2 + 1.30429313957265e+34)*cos(19*phi)

#@torch.jit.script
def Yl71_m20(theta, phi):
    return 5.10989548815476e-37*(1.0 - cos(theta)**2)**10*(8.65325138632815e+55*cos(theta)**51 - 7.82474859402013e+56*cos(theta)**49 + 3.31003753473657e+57*cos(theta)**47 - 8.70596246970861e+57*cos(theta)**45 + 1.59609311944658e+58*cos(theta)**43 - 2.16732644640641e+58*cos(theta)**41 + 2.26107848098378e+58*cos(theta)**39 - 1.85543649436211e+58*cos(theta)**37 + 1.21626053665862e+58*cos(theta)**35 - 6.43266683832784e+57*cos(theta)**33 + 2.76133991108707e+57*cos(theta)**31 - 9.64705528666783e+56*cos(theta)**29 + 2.74279022856242e+56*cos(theta)**27 - 6.32951591206713e+55*cos(theta)**25 + 1.17941290286965e+55*cos(theta)**23 - 1.76042161903258e+54*cos(theta)**21 + 2.08157961709933e+53*cos(theta)**19 - 1.92093963585529e+52*cos(theta)**17 + 1.35642674182928e+51*cos(theta)**15 - 7.13908811489096e+49*cos(theta)**13 + 2.70314986874512e+48*cos(theta)**11 - 7.0095824036295e+46*cos(theta)**9 + 1.15860866175694e+45*cos(theta)**7 - 1.09057740461209e+43*cos(theta)**5 + 4.78323423075479e+40*cos(theta)**3 - 6.17191513645779e+37*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl71_m21(theta, phi):
    return 7.45990017450111e-39*(1.0 - cos(theta)**2)**10.5*(4.41315820702735e+57*cos(theta)**50 - 3.83412681106987e+58*cos(theta)**48 + 1.55571764132619e+59*cos(theta)**46 - 3.91768311136887e+59*cos(theta)**44 + 6.86320041362028e+59*cos(theta)**42 - 8.88603843026626e+59*cos(theta)**40 + 8.81820607583675e+59*cos(theta)**38 - 6.86511502913979e+59*cos(theta)**36 + 4.25691187830519e+59*cos(theta)**34 - 2.12278005664819e+59*cos(theta)**32 + 8.56015372436992e+58*cos(theta)**30 - 2.79764603313367e+58*cos(theta)**28 + 7.40553361711854e+57*cos(theta)**26 - 1.58237897801678e+57*cos(theta)**24 + 2.7126496766002e+56*cos(theta)**22 - 3.69688539996841e+55*cos(theta)**20 + 3.95500127248873e+54*cos(theta)**18 - 3.265597380954e+53*cos(theta)**16 + 2.03464011274392e+52*cos(theta)**14 - 9.28081454935825e+50*cos(theta)**12 + 2.97346485561963e+49*cos(theta)**10 - 6.30862416326655e+47*cos(theta)**8 + 8.11026063229859e+45*cos(theta)**6 - 5.45288702306046e+43*cos(theta)**4 + 1.43497026922644e+41*cos(theta)**2 - 6.17191513645779e+37)*cos(21*phi)

#@torch.jit.script
def Yl71_m22(theta, phi):
    return 1.09397283893788e-40*(1.0 - cos(theta)**2)**11*(2.20657910351368e+59*cos(theta)**49 - 1.84038086931354e+60*cos(theta)**47 + 7.15630115010047e+60*cos(theta)**45 - 1.7237805690023e+61*cos(theta)**43 + 2.88254417372052e+61*cos(theta)**41 - 3.55441537210651e+61*cos(theta)**39 + 3.35091830881796e+61*cos(theta)**37 - 2.47144141049033e+61*cos(theta)**35 + 1.44735003862376e+61*cos(theta)**33 - 6.7928961812742e+60*cos(theta)**31 + 2.56804611731098e+60*cos(theta)**29 - 7.83340889277428e+59*cos(theta)**27 + 1.92543874045082e+59*cos(theta)**25 - 3.79770954724028e+58*cos(theta)**23 + 5.96782928852044e+57*cos(theta)**21 - 7.39377079993683e+56*cos(theta)**19 + 7.11900229047971e+55*cos(theta)**17 - 5.2249558095264e+54*cos(theta)**15 + 2.84849615784149e+53*cos(theta)**13 - 1.11369774592299e+52*cos(theta)**11 + 2.97346485561963e+50*cos(theta)**9 - 5.04689933061324e+48*cos(theta)**7 + 4.86615637937915e+46*cos(theta)**5 - 2.18115480922418e+44*cos(theta)**3 + 2.86994053845287e+41*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl71_m23(theta, phi):
    return 1.61192404130082e-42*(1.0 - cos(theta)**2)**11.5*(1.0812237607217e+61*cos(theta)**48 - 8.64979008577362e+61*cos(theta)**46 + 3.22033551754521e+62*cos(theta)**44 - 7.41225644670991e+62*cos(theta)**42 + 1.18184311122541e+63*cos(theta)**40 - 1.38622199512154e+63*cos(theta)**38 + 1.23983977426265e+63*cos(theta)**36 - 8.65004493671614e+62*cos(theta)**34 + 4.77625512745842e+62*cos(theta)**32 - 2.105797816195e+62*cos(theta)**30 + 7.44733374020183e+61*cos(theta)**28 - 2.11502040104906e+61*cos(theta)**26 + 4.81359685112705e+60*cos(theta)**24 - 8.73473195865264e+59*cos(theta)**22 + 1.25324415058929e+59*cos(theta)**20 - 1.404816451988e+58*cos(theta)**18 + 1.21023038938155e+57*cos(theta)**16 - 7.83743371428959e+55*cos(theta)**14 + 3.70304500519394e+54*cos(theta)**12 - 1.22506752051529e+53*cos(theta)**10 + 2.67611837005767e+51*cos(theta)**8 - 3.53282953142927e+49*cos(theta)**6 + 2.43307818968958e+47*cos(theta)**4 - 6.54346442767255e+44*cos(theta)**2 + 2.86994053845287e+41)*cos(23*phi)

#@torch.jit.script
def Yl71_m24(theta, phi):
    return 2.38705349224361e-44*(1.0 - cos(theta)**2)**12*(5.18987405146417e+62*cos(theta)**47 - 3.97890343945586e+63*cos(theta)**45 + 1.41694762771989e+64*cos(theta)**43 - 3.11314770761816e+64*cos(theta)**41 + 4.72737244490165e+64*cos(theta)**39 - 5.26764358146184e+64*cos(theta)**37 + 4.46342318734553e+64*cos(theta)**35 - 2.94101527848349e+64*cos(theta)**33 + 1.52840164078669e+64*cos(theta)**31 - 6.317393448585e+63*cos(theta)**29 + 2.08525344725651e+63*cos(theta)**27 - 5.49905304272754e+62*cos(theta)**25 + 1.15526324427049e+62*cos(theta)**23 - 1.92164103090358e+61*cos(theta)**21 + 2.50648830117858e+60*cos(theta)**19 - 2.52866961357839e+59*cos(theta)**17 + 1.93636862301048e+58*cos(theta)**15 - 1.09724072000054e+57*cos(theta)**13 + 4.44365400623273e+55*cos(theta)**11 - 1.22506752051529e+54*cos(theta)**9 + 2.14089469604614e+52*cos(theta)**7 - 2.11969771885756e+50*cos(theta)**5 + 9.73231275875831e+47*cos(theta)**3 - 1.30869288553451e+45*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl71_m25(theta, phi):
    return 3.55367417211057e-46*(1.0 - cos(theta)**2)**12.5*(2.43924080418816e+64*cos(theta)**46 - 1.79050654775514e+65*cos(theta)**44 + 6.09287479919554e+65*cos(theta)**42 - 1.27639056012345e+66*cos(theta)**40 + 1.84367525351164e+66*cos(theta)**38 - 1.94902812514088e+66*cos(theta)**36 + 1.56219811557094e+66*cos(theta)**34 - 9.70535041899551e+65*cos(theta)**32 + 4.73804508643875e+65*cos(theta)**30 - 1.83204410008965e+65*cos(theta)**28 + 5.63018430759259e+64*cos(theta)**26 - 1.37476326068189e+64*cos(theta)**24 + 2.65710546182213e+63*cos(theta)**22 - 4.03544616489752e+62*cos(theta)**20 + 4.76232777223931e+61*cos(theta)**18 - 4.29873834308327e+60*cos(theta)**16 + 2.90455293451572e+59*cos(theta)**14 - 1.42641293600071e+58*cos(theta)**12 + 4.888019406856e+56*cos(theta)**10 - 1.10256076846376e+55*cos(theta)**8 + 1.49862628723229e+53*cos(theta)**6 - 1.05984885942878e+51*cos(theta)**4 + 2.91969382762749e+48*cos(theta)**2 - 1.30869288553451e+45)*cos(25*phi)

#@torch.jit.script
def Yl71_m26(theta, phi):
    return 5.32001458461065e-48*(1.0 - cos(theta)**2)**13*(1.12205076992655e+66*cos(theta)**45 - 7.87822881012261e+66*cos(theta)**43 + 2.55900741566213e+67*cos(theta)**41 - 5.10556224049378e+67*cos(theta)**39 + 7.00596596334425e+67*cos(theta)**37 - 7.01650125050717e+67*cos(theta)**35 + 5.31147359294118e+67*cos(theta)**33 - 3.10571213407856e+67*cos(theta)**31 + 1.42141352593163e+67*cos(theta)**29 - 5.12972348025102e+66*cos(theta)**27 + 1.46384791997407e+66*cos(theta)**25 - 3.29943182563653e+65*cos(theta)**23 + 5.84563201600869e+64*cos(theta)**21 - 8.07089232979504e+63*cos(theta)**19 + 8.57218999003076e+62*cos(theta)**17 - 6.87798134893323e+61*cos(theta)**15 + 4.06637410832201e+60*cos(theta)**13 - 1.71169552320085e+59*cos(theta)**11 + 4.888019406856e+57*cos(theta)**9 - 8.82048614771008e+55*cos(theta)**7 + 8.99175772339377e+53*cos(theta)**5 - 4.23939543771512e+51*cos(theta)**3 + 5.83938765525499e+48*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl71_m27(theta, phi):
    return 8.01112536794487e-50*(1.0 - cos(theta)**2)**13.5*(5.04922846466949e+67*cos(theta)**44 - 3.38763838835272e+68*cos(theta)**42 + 1.04919304042147e+69*cos(theta)**40 - 1.99116927379258e+69*cos(theta)**38 + 2.59220740643737e+69*cos(theta)**36 - 2.45577543767751e+69*cos(theta)**34 + 1.75278628567059e+69*cos(theta)**32 - 9.62770761564355e+68*cos(theta)**30 + 4.12209922520171e+68*cos(theta)**28 - 1.38502533966778e+68*cos(theta)**26 + 3.65961979993518e+67*cos(theta)**24 - 7.58869319896401e+66*cos(theta)**22 + 1.22758272336183e+66*cos(theta)**20 - 1.53346954266106e+65*cos(theta)**18 + 1.45727229830523e+64*cos(theta)**16 - 1.03169720233998e+63*cos(theta)**14 + 5.28628634081862e+61*cos(theta)**12 - 1.88286507552093e+60*cos(theta)**10 + 4.3992174661704e+58*cos(theta)**8 - 6.17434030339705e+56*cos(theta)**6 + 4.49587886169688e+54*cos(theta)**4 - 1.27181863131454e+52*cos(theta)**2 + 5.83938765525499e+48)*cos(27*phi)

#@torch.jit.script
def Yl71_m28(theta, phi):
    return 1.21380687393104e-51*(1.0 - cos(theta)**2)**14*(2.22166052445458e+69*cos(theta)**43 - 1.42280812310814e+70*cos(theta)**41 + 4.19677216168589e+70*cos(theta)**39 - 7.56644324041179e+70*cos(theta)**37 + 9.33194666317454e+70*cos(theta)**35 - 8.34963648810353e+70*cos(theta)**33 + 5.60891611414588e+70*cos(theta)**31 - 2.88831228469306e+70*cos(theta)**29 + 1.15418778305648e+70*cos(theta)**27 - 3.60106588313622e+69*cos(theta)**25 + 8.78308751984444e+68*cos(theta)**23 - 1.66951250377208e+68*cos(theta)**21 + 2.45516544672365e+67*cos(theta)**19 - 2.7602451767899e+66*cos(theta)**17 + 2.33163567728837e+65*cos(theta)**15 - 1.44437608327598e+64*cos(theta)**13 + 6.34354360898234e+62*cos(theta)**11 - 1.88286507552093e+61*cos(theta)**9 + 3.51937397293632e+59*cos(theta)**7 - 3.70460418203823e+57*cos(theta)**5 + 1.79835154467875e+55*cos(theta)**3 - 2.54363726262907e+52*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl71_m29(theta, phi):
    return 1.85103812934372e-53*(1.0 - cos(theta)**2)**14.5*(9.55314025515468e+70*cos(theta)**42 - 5.83351330474339e+71*cos(theta)**40 + 1.6367411430575e+72*cos(theta)**38 - 2.79958399895236e+72*cos(theta)**36 + 3.26618133211109e+72*cos(theta)**34 - 2.75538004107417e+72*cos(theta)**32 + 1.73876399538522e+72*cos(theta)**30 - 8.37610562560988e+71*cos(theta)**28 + 3.1163070142525e+71*cos(theta)**26 - 9.00266470784055e+70*cos(theta)**24 + 2.02011012956422e+70*cos(theta)**22 - 3.50597625792137e+69*cos(theta)**20 + 4.66481434877494e+68*cos(theta)**18 - 4.69241680054284e+67*cos(theta)**16 + 3.49745351593255e+66*cos(theta)**14 - 1.87768890825877e+65*cos(theta)**12 + 6.97789796988057e+63*cos(theta)**10 - 1.69457856796884e+62*cos(theta)**8 + 2.46356178105542e+60*cos(theta)**6 - 1.85230209101912e+58*cos(theta)**4 + 5.39505463403626e+55*cos(theta)**2 - 2.54363726262907e+52)*cos(29*phi)

#@torch.jit.script
def Yl71_m30(theta, phi):
    return 2.84203899663231e-55*(1.0 - cos(theta)**2)**15*(4.01231890716496e+72*cos(theta)**41 - 2.33340532189735e+73*cos(theta)**39 + 6.21961634361849e+73*cos(theta)**37 - 1.00785023962285e+74*cos(theta)**35 + 1.11050165291777e+74*cos(theta)**33 - 8.81721613143733e+73*cos(theta)**31 + 5.21629198615567e+73*cos(theta)**29 - 2.34530957517077e+73*cos(theta)**27 + 8.10239823705649e+72*cos(theta)**25 - 2.16063952988173e+72*cos(theta)**23 + 4.44424228504128e+71*cos(theta)**21 - 7.01195251584275e+70*cos(theta)**19 + 8.39666582779489e+69*cos(theta)**17 - 7.50786688086854e+68*cos(theta)**15 + 4.89643492230557e+67*cos(theta)**13 - 2.25322668991053e+66*cos(theta)**11 + 6.97789796988057e+64*cos(theta)**9 - 1.35566285437507e+63*cos(theta)**7 + 1.47813706863325e+61*cos(theta)**5 - 7.40920836407647e+58*cos(theta)**3 + 1.07901092680725e+56*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl71_m31(theta, phi):
    return 4.39478889556512e-57*(1.0 - cos(theta)**2)**15.5*(1.64505075193764e+74*cos(theta)**40 - 9.10028075539968e+74*cos(theta)**38 + 2.30125804713884e+75*cos(theta)**36 - 3.52747583867998e+75*cos(theta)**34 + 3.66465545462864e+75*cos(theta)**32 - 2.73333700074557e+75*cos(theta)**30 + 1.51272467598515e+75*cos(theta)**28 - 6.33233585296107e+74*cos(theta)**26 + 2.02559955926412e+74*cos(theta)**24 - 4.96947091872798e+73*cos(theta)**22 + 9.3329087985867e+72*cos(theta)**20 - 1.33227097801012e+72*cos(theta)**18 + 1.42743319072513e+71*cos(theta)**16 - 1.12618003213028e+70*cos(theta)**14 + 6.36536539899724e+68*cos(theta)**12 - 2.47854935890158e+67*cos(theta)**10 + 6.28010817289252e+65*cos(theta)**8 - 9.4896399806255e+63*cos(theta)**6 + 7.39068534316627e+61*cos(theta)**4 - 2.22276250922294e+59*cos(theta)**2 + 1.07901092680725e+56)*cos(31*phi)

#@torch.jit.script
def Yl71_m32(theta, phi):
    return 6.84682788089054e-59*(1.0 - cos(theta)**2)**16*(6.58020300775054e+75*cos(theta)**39 - 3.45810668705188e+76*cos(theta)**37 + 8.28452896969983e+76*cos(theta)**35 - 1.19934178515119e+77*cos(theta)**33 + 1.17268974548117e+77*cos(theta)**31 - 8.20001100223672e+76*cos(theta)**29 + 4.23562909275841e+76*cos(theta)**27 - 1.64640732176988e+76*cos(theta)**25 + 4.86143894223389e+75*cos(theta)**23 - 1.09328360212016e+75*cos(theta)**21 + 1.86658175971734e+74*cos(theta)**19 - 2.39808776041822e+73*cos(theta)**17 + 2.28389310516021e+72*cos(theta)**15 - 1.57665204498239e+71*cos(theta)**13 + 7.63843847879669e+69*cos(theta)**11 - 2.47854935890158e+68*cos(theta)**9 + 5.02408653831401e+66*cos(theta)**7 - 5.6937839883753e+64*cos(theta)**5 + 2.95627413726651e+62*cos(theta)**3 - 4.44552501844588e+59*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl71_m33(theta, phi):
    return 1.07507914518226e-60*(1.0 - cos(theta)**2)**16.5*(2.56627917302271e+77*cos(theta)**38 - 1.2794994742092e+78*cos(theta)**36 + 2.89958513939494e+78*cos(theta)**34 - 3.95782789099893e+78*cos(theta)**32 + 3.63533821099161e+78*cos(theta)**30 - 2.37800319064865e+78*cos(theta)**28 + 1.14361985504477e+78*cos(theta)**26 - 4.1160183044247e+77*cos(theta)**24 + 1.1181309567138e+77*cos(theta)**22 - 2.29589556445233e+76*cos(theta)**20 + 3.54650534346294e+75*cos(theta)**18 - 4.07674919271097e+74*cos(theta)**16 + 3.42583965774031e+73*cos(theta)**14 - 2.04964765847711e+72*cos(theta)**12 + 8.40228232667635e+70*cos(theta)**10 - 2.23069442301142e+69*cos(theta)**8 + 3.51686057681981e+67*cos(theta)**6 - 2.84689199418765e+65*cos(theta)**4 + 8.86882241179953e+62*cos(theta)**2 - 4.44552501844588e+59)*cos(33*phi)

#@torch.jit.script
def Yl71_m34(theta, phi):
    return 1.70197818592895e-62*(1.0 - cos(theta)**2)**17*(9.7518608574863e+78*cos(theta)**37 - 4.6061981071531e+79*cos(theta)**35 + 9.85858947394279e+79*cos(theta)**33 - 1.26650492511966e+80*cos(theta)**31 + 1.09060146329748e+80*cos(theta)**29 - 6.65840893381621e+79*cos(theta)**27 + 2.9734116231164e+79*cos(theta)**25 - 9.87844393061927e+78*cos(theta)**23 + 2.45988810477035e+78*cos(theta)**21 - 4.59179112890465e+77*cos(theta)**19 + 6.3837096182333e+76*cos(theta)**17 - 6.52279870833756e+75*cos(theta)**15 + 4.79617552083644e+74*cos(theta)**13 - 2.45957719017253e+73*cos(theta)**11 + 8.40228232667635e+71*cos(theta)**9 - 1.78455553840914e+70*cos(theta)**7 + 2.11011634609189e+68*cos(theta)**5 - 1.13875679767506e+66*cos(theta)**3 + 1.77376448235991e+63*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl71_m35(theta, phi):
    return 2.71769174252509e-64*(1.0 - cos(theta)**2)**17.5*(3.60818851726993e+80*cos(theta)**36 - 1.61216933750359e+81*cos(theta)**34 + 3.25333452640112e+81*cos(theta)**32 - 3.92616526787094e+81*cos(theta)**30 + 3.1627442435627e+81*cos(theta)**28 - 1.79777041213038e+81*cos(theta)**26 + 7.433529057791e+80*cos(theta)**24 - 2.27204210404243e+80*cos(theta)**22 + 5.16576502001774e+79*cos(theta)**20 - 8.72440314491884e+78*cos(theta)**18 + 1.08523063509966e+78*cos(theta)**16 - 9.78419806250634e+76*cos(theta)**14 + 6.23502817708737e+75*cos(theta)**12 - 2.70553490918979e+74*cos(theta)**10 + 7.56205409400872e+72*cos(theta)**8 - 1.2491888768864e+71*cos(theta)**6 + 1.05505817304594e+69*cos(theta)**4 - 3.41627039302518e+66*cos(theta)**2 + 1.77376448235991e+63)*cos(35*phi)

#@torch.jit.script
def Yl71_m36(theta, phi):
    return 4.37881962246183e-66*(1.0 - cos(theta)**2)**18*(1.29894786621718e+82*cos(theta)**35 - 5.48137574751219e+82*cos(theta)**33 + 1.04106704844836e+83*cos(theta)**31 - 1.17784958036128e+83*cos(theta)**29 + 8.85568388197557e+82*cos(theta)**27 - 4.67420307153898e+82*cos(theta)**25 + 1.78404697386984e+82*cos(theta)**23 - 4.99849262889335e+81*cos(theta)**21 + 1.03315300400355e+81*cos(theta)**19 - 1.57039256608539e+80*cos(theta)**17 + 1.73636901615946e+79*cos(theta)**15 - 1.36978772875089e+78*cos(theta)**13 + 7.48203381250485e+76*cos(theta)**11 - 2.70553490918979e+75*cos(theta)**9 + 6.04964327520698e+73*cos(theta)**7 - 7.49513326131838e+71*cos(theta)**5 + 4.22023269218377e+69*cos(theta)**3 - 6.83254078605036e+66*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl71_m37(theta, phi):
    return 7.12215064831495e-68*(1.0 - cos(theta)**2)**18.5*(4.54631753176011e+83*cos(theta)**34 - 1.80885399667902e+84*cos(theta)**32 + 3.22730785018991e+84*cos(theta)**30 - 3.41576378304772e+84*cos(theta)**28 + 2.3910346481334e+84*cos(theta)**26 - 1.16855076788475e+84*cos(theta)**24 + 4.10330803990063e+83*cos(theta)**22 - 1.0496834520676e+83*cos(theta)**20 + 1.96299070760674e+82*cos(theta)**18 - 2.66966736234517e+81*cos(theta)**16 + 2.60455352423919e+80*cos(theta)**14 - 1.78072404737615e+79*cos(theta)**12 + 8.23023719375533e+77*cos(theta)**10 - 2.43498141827081e+76*cos(theta)**8 + 4.23475029264488e+74*cos(theta)**6 - 3.74756663065919e+72*cos(theta)**4 + 1.26606980765513e+70*cos(theta)**2 - 6.83254078605036e+66)*cos(37*phi)

#@torch.jit.script
def Yl71_m38(theta, phi):
    return 1.16992614950083e-69*(1.0 - cos(theta)**2)**19*(1.54574796079844e+85*cos(theta)**33 - 5.78833278937288e+85*cos(theta)**31 + 9.68192355056974e+85*cos(theta)**29 - 9.56413859253361e+85*cos(theta)**27 + 6.21669008514685e+85*cos(theta)**25 - 2.80452184292339e+85*cos(theta)**23 + 9.02727768778139e+84*cos(theta)**21 - 2.09936690413521e+84*cos(theta)**19 + 3.53338327369213e+83*cos(theta)**17 - 4.27146777975227e+82*cos(theta)**15 + 3.64637493393486e+81*cos(theta)**13 - 2.13686885685138e+80*cos(theta)**11 + 8.23023719375533e+78*cos(theta)**9 - 1.94798513461665e+77*cos(theta)**7 + 2.54085017558693e+75*cos(theta)**5 - 1.49902665226368e+73*cos(theta)**3 + 2.53213961531026e+70*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl71_m39(theta, phi):
    return 1.94180285665687e-71*(1.0 - cos(theta)**2)**19.5*(5.10096827063485e+86*cos(theta)**32 - 1.79438316470559e+87*cos(theta)**30 + 2.80775782966522e+87*cos(theta)**28 - 2.58231741998407e+87*cos(theta)**26 + 1.55417252128671e+87*cos(theta)**24 - 6.4504002387238e+86*cos(theta)**22 + 1.89572831443409e+86*cos(theta)**20 - 3.9887971178569e+85*cos(theta)**18 + 6.00675156527662e+84*cos(theta)**16 - 6.4072016696284e+83*cos(theta)**14 + 4.74028741411532e+82*cos(theta)**12 - 2.35055574253652e+81*cos(theta)**10 + 7.4072134743798e+79*cos(theta)**8 - 1.36358959423165e+78*cos(theta)**6 + 1.27042508779346e+76*cos(theta)**4 - 4.49707995679103e+73*cos(theta)**2 + 2.53213961531026e+70)*cos(39*phi)

#@torch.jit.script
def Yl71_m40(theta, phi):
    return 3.25813186319286e-73*(1.0 - cos(theta)**2)**20*(1.63230984660315e+88*cos(theta)**31 - 5.38314949411678e+88*cos(theta)**29 + 7.86172192306263e+88*cos(theta)**27 - 6.7140252919586e+88*cos(theta)**25 + 3.73001405108811e+88*cos(theta)**23 - 1.41908805251924e+88*cos(theta)**21 + 3.79145662886819e+87*cos(theta)**19 - 7.17983481214241e+86*cos(theta)**17 + 9.6108025044426e+85*cos(theta)**15 - 8.97008233747976e+84*cos(theta)**13 + 5.68834489693838e+83*cos(theta)**11 - 2.35055574253652e+82*cos(theta)**9 + 5.92577077950384e+80*cos(theta)**7 - 8.18153756538991e+78*cos(theta)**5 + 5.08170035117386e+76*cos(theta)**3 - 8.99415991358205e+73*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl71_m41(theta, phi):
    return 5.529410066666e-75*(1.0 - cos(theta)**2)**20.5*(5.06016052446977e+89*cos(theta)**30 - 1.56111335329386e+90*cos(theta)**28 + 2.12266491922691e+90*cos(theta)**26 - 1.67850632298965e+90*cos(theta)**24 + 8.57903231750265e+89*cos(theta)**22 - 2.98008491029039e+89*cos(theta)**20 + 7.20376759484955e+88*cos(theta)**18 - 1.22057191806421e+88*cos(theta)**16 + 1.44162037566639e+87*cos(theta)**14 - 1.16611070387237e+86*cos(theta)**12 + 6.25717938663222e+84*cos(theta)**10 - 2.11550016828287e+83*cos(theta)**8 + 4.14803954565269e+81*cos(theta)**6 - 4.09076878269496e+79*cos(theta)**4 + 1.52451010535216e+77*cos(theta)**2 - 8.99415991358205e+73)*cos(41*phi)

#@torch.jit.script
def Yl71_m42(theta, phi):
    return 9.49683625092251e-77*(1.0 - cos(theta)**2)**21*(1.51804815734093e+91*cos(theta)**29 - 4.37111738922282e+91*cos(theta)**27 + 5.51892878998997e+91*cos(theta)**25 - 4.02841517517516e+91*cos(theta)**23 + 1.88738710985058e+91*cos(theta)**21 - 5.96016982058079e+90*cos(theta)**19 + 1.29667816707292e+90*cos(theta)**17 - 1.95291506890274e+89*cos(theta)**15 + 2.01826852593295e+88*cos(theta)**13 - 1.39933284464684e+87*cos(theta)**11 + 6.25717938663222e+85*cos(theta)**9 - 1.6924001346263e+84*cos(theta)**7 + 2.48882372739161e+82*cos(theta)**5 - 1.63630751307798e+80*cos(theta)**3 + 3.04902021070432e+77*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl71_m43(theta, phi):
    return 1.65168614259395e-78*(1.0 - cos(theta)**2)**21.5*(4.4023396562887e+92*cos(theta)**28 - 1.18020169509016e+93*cos(theta)**26 + 1.37973219749749e+93*cos(theta)**24 - 9.26535490290286e+92*cos(theta)**22 + 3.96351293068622e+92*cos(theta)**20 - 1.13243226591035e+92*cos(theta)**18 + 2.20435288402396e+91*cos(theta)**16 - 2.9293726033541e+90*cos(theta)**14 + 2.62374908371283e+89*cos(theta)**12 - 1.53926612911153e+88*cos(theta)**10 + 5.631461447969e+86*cos(theta)**8 - 1.18468009423841e+85*cos(theta)**6 + 1.24441186369581e+83*cos(theta)**4 - 4.90892253923395e+80*cos(theta)**2 + 3.04902021070432e+77)*cos(43*phi)

#@torch.jit.script
def Yl71_m44(theta, phi):
    return 2.9107143653895e-80*(1.0 - cos(theta)**2)**22*(1.23265510376084e+94*cos(theta)**27 - 3.06852440723442e+94*cos(theta)**25 + 3.31135727399398e+94*cos(theta)**23 - 2.03837807863863e+94*cos(theta)**21 + 7.92702586137245e+93*cos(theta)**19 - 2.03837807863863e+93*cos(theta)**17 + 3.52696461443834e+92*cos(theta)**15 - 4.10112164469575e+91*cos(theta)**13 + 3.1484989004554e+90*cos(theta)**11 - 1.53926612911153e+89*cos(theta)**9 + 4.5051691583752e+87*cos(theta)**7 - 7.10808056543044e+85*cos(theta)**5 + 4.97764745478322e+83*cos(theta)**3 - 9.8178450784679e+80*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl71_m45(theta, phi):
    return 5.20102226077753e-82*(1.0 - cos(theta)**2)**22.5*(3.32816878015426e+95*cos(theta)**26 - 7.67131101808605e+95*cos(theta)**24 + 7.61612173018615e+95*cos(theta)**22 - 4.28059396514112e+95*cos(theta)**20 + 1.50613491366077e+95*cos(theta)**18 - 3.46524273368567e+94*cos(theta)**16 + 5.29044692165751e+93*cos(theta)**14 - 5.33145813810447e+92*cos(theta)**12 + 3.46334879050093e+91*cos(theta)**10 - 1.38533951620037e+90*cos(theta)**8 + 3.15361841086264e+88*cos(theta)**6 - 3.55404028271522e+86*cos(theta)**4 + 1.49329423643497e+84*cos(theta)**2 - 9.8178450784679e+80)*cos(45*phi)

#@torch.jit.script
def Yl71_m46(theta, phi):
    return 9.42994387102045e-84*(1.0 - cos(theta)**2)**23*(8.65323882840107e+96*cos(theta)**25 - 1.84111464434065e+97*cos(theta)**23 + 1.67554678064095e+97*cos(theta)**21 - 8.56118793028224e+96*cos(theta)**19 + 2.71104284458938e+96*cos(theta)**17 - 5.54438837389707e+95*cos(theta)**15 + 7.40662569032052e+94*cos(theta)**13 - 6.39774976572536e+93*cos(theta)**11 + 3.46334879050093e+92*cos(theta)**9 - 1.1082716129603e+91*cos(theta)**7 + 1.89217104651758e+89*cos(theta)**5 - 1.42161611308609e+87*cos(theta)**3 + 2.98658847286993e+84*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl71_m47(theta, phi):
    return 1.73619339517346e-85*(1.0 - cos(theta)**2)**23.5*(2.16330970710027e+98*cos(theta)**24 - 4.2345636819835e+98*cos(theta)**22 + 3.518648239346e+98*cos(theta)**20 - 1.62662570675363e+98*cos(theta)**18 + 4.60877283580194e+97*cos(theta)**16 - 8.31658256084561e+96*cos(theta)**14 + 9.62861339741667e+95*cos(theta)**12 - 7.0375247422979e+94*cos(theta)**10 + 3.11701391145084e+93*cos(theta)**8 - 7.75790129072209e+91*cos(theta)**6 + 9.46085523258792e+89*cos(theta)**4 - 4.26484833925827e+87*cos(theta)**2 + 2.98658847286993e+84)*cos(47*phi)

#@torch.jit.script
def Yl71_m48(theta, phi):
    return 3.24877023999585e-87*(1.0 - cos(theta)**2)**24*(5.19194329704064e+99*cos(theta)**23 - 9.3160401003637e+99*cos(theta)**21 + 7.037296478692e+99*cos(theta)**19 - 2.92792627215653e+99*cos(theta)**17 + 7.37403653728311e+98*cos(theta)**15 - 1.16432155851839e+98*cos(theta)**13 + 1.15543360769e+97*cos(theta)**11 - 7.0375247422979e+95*cos(theta)**9 + 2.49361112916067e+94*cos(theta)**7 - 4.65474077443326e+92*cos(theta)**5 + 3.78434209303517e+90*cos(theta)**3 - 8.52969667851653e+87*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl71_m49(theta, phi):
    return 6.18392846630575e-89*(1.0 - cos(theta)**2)**24.5*(1.19414695831935e+101*cos(theta)**22 - 1.95636842107638e+101*cos(theta)**20 + 1.33708633095148e+101*cos(theta)**18 - 4.9774746626661e+100*cos(theta)**16 + 1.10610548059247e+100*cos(theta)**14 - 1.5136180260739e+99*cos(theta)**12 + 1.270976968459e+98*cos(theta)**10 - 6.33377226806811e+96*cos(theta)**8 + 1.74552779041247e+95*cos(theta)**6 - 2.32737038721663e+93*cos(theta)**4 + 1.13530262791055e+91*cos(theta)**2 - 8.52969667851653e+87)*cos(49*phi)

#@torch.jit.script
def Yl71_m50(theta, phi):
    return 1.19856179900749e-90*(1.0 - cos(theta)**2)**25*(2.62712330830256e+102*cos(theta)**21 - 3.91273684215275e+102*cos(theta)**19 + 2.40675539571267e+102*cos(theta)**17 - 7.96395946026575e+101*cos(theta)**15 + 1.54854767282945e+101*cos(theta)**13 - 1.81634163128868e+100*cos(theta)**11 + 1.270976968459e+99*cos(theta)**9 - 5.06701781445449e+97*cos(theta)**7 + 1.04731667424748e+96*cos(theta)**5 - 9.30948154886651e+93*cos(theta)**3 + 2.2706052558211e+91*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl71_m51(theta, phi):
    return 2.36794095448655e-92*(1.0 - cos(theta)**2)**25.5*(5.51695894743538e+103*cos(theta)**20 - 7.43420000009023e+103*cos(theta)**18 + 4.09148417271153e+103*cos(theta)**16 - 1.19459391903986e+103*cos(theta)**14 + 2.01311197467829e+102*cos(theta)**12 - 1.99797579441755e+101*cos(theta)**10 + 1.1438792716131e+100*cos(theta)**8 - 3.54691247011814e+98*cos(theta)**6 + 5.23658337123741e+96*cos(theta)**4 - 2.79284446465995e+94*cos(theta)**2 + 2.2706052558211e+91)*cos(51*phi)

#@torch.jit.script
def Yl71_m52(theta, phi):
    return 4.77422975694428e-94*(1.0 - cos(theta)**2)**26*(1.10339178948708e+105*cos(theta)**19 - 1.33815600001624e+105*cos(theta)**17 + 6.54637467633845e+104*cos(theta)**15 - 1.67243148665581e+104*cos(theta)**13 + 2.41573436961395e+103*cos(theta)**11 - 1.99797579441755e+102*cos(theta)**9 + 9.15103417290481e+100*cos(theta)**7 - 2.12814748207088e+99*cos(theta)**5 + 2.09463334849497e+97*cos(theta)**3 - 5.58568892931991e+94*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl71_m53(theta, phi):
    return 9.83593550283913e-96*(1.0 - cos(theta)**2)**26.5*(2.09644440002545e+106*cos(theta)**18 - 2.27486520002761e+106*cos(theta)**16 + 9.81956201450768e+105*cos(theta)**14 - 2.17416093265255e+105*cos(theta)**12 + 2.65730780657534e+104*cos(theta)**10 - 1.79817821497579e+103*cos(theta)**8 + 6.40572392103336e+101*cos(theta)**6 - 1.06407374103544e+100*cos(theta)**4 + 6.2839000454849e+97*cos(theta)**2 - 5.58568892931991e+94)*cos(53*phi)

#@torch.jit.script
def Yl71_m54(theta, phi):
    return 2.07359727383235e-97*(1.0 - cos(theta)**2)**27*(3.7735999200458e+107*cos(theta)**17 - 3.63978432004418e+107*cos(theta)**15 + 1.37473868203107e+107*cos(theta)**13 - 2.60899311918306e+106*cos(theta)**11 + 2.65730780657534e+105*cos(theta)**9 - 1.43854257198064e+104*cos(theta)**7 + 3.84343435262002e+102*cos(theta)**5 - 4.25629496414177e+100*cos(theta)**3 + 1.25678000909698e+98*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl71_m55(theta, phi):
    return 4.48037824681915e-99*(1.0 - cos(theta)**2)**27.5*(6.41511986407786e+108*cos(theta)**16 - 5.45967648006627e+108*cos(theta)**14 + 1.7871602866404e+108*cos(theta)**12 - 2.86989243110137e+107*cos(theta)**10 + 2.39157702591781e+106*cos(theta)**8 - 1.00697980038644e+105*cos(theta)**6 + 1.92171717631001e+103*cos(theta)**4 - 1.27688848924253e+101*cos(theta)**2 + 1.25678000909698e+98)*cos(55*phi)

#@torch.jit.script
def Yl71_m56(theta, phi):
    return 9.93923200490332e-101*(1.0 - cos(theta)**2)**28*(1.02641917825246e+110*cos(theta)**15 - 7.64354707209277e+109*cos(theta)**13 + 2.14459234396848e+109*cos(theta)**11 - 2.86989243110137e+108*cos(theta)**9 + 1.91326162073424e+107*cos(theta)**7 - 6.04187880231867e+105*cos(theta)**5 + 7.68686870524004e+103*cos(theta)**3 - 2.55377697848506e+101*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl71_m57(theta, phi):
    return 2.26830898890119e-102*(1.0 - cos(theta)**2)**28.5*(1.53962876737869e+111*cos(theta)**14 - 9.93661119372061e+110*cos(theta)**12 + 2.35905157836532e+110*cos(theta)**10 - 2.58290318799123e+109*cos(theta)**8 + 1.33928313451397e+108*cos(theta)**6 - 3.02093940115933e+106*cos(theta)**4 + 2.30606061157201e+104*cos(theta)**2 - 2.55377697848506e+101)*cos(57*phi)

#@torch.jit.script
def Yl71_m58(theta, phi):
    return 5.33756701552661e-104*(1.0 - cos(theta)**2)**29*(2.15548027433016e+112*cos(theta)**13 - 1.19239334324647e+112*cos(theta)**11 + 2.35905157836532e+111*cos(theta)**9 - 2.06632255039298e+110*cos(theta)**7 + 8.03569880708383e+108*cos(theta)**5 - 1.20837576046373e+107*cos(theta)**3 + 4.61212122314402e+104*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl71_m59(theta, phi):
    return 1.29837453329626e-105*(1.0 - cos(theta)**2)**29.5*(2.80212435662921e+113*cos(theta)**12 - 1.31163267757112e+113*cos(theta)**10 + 2.12314642052879e+112*cos(theta)**8 - 1.44642578527509e+111*cos(theta)**6 + 4.01784940354191e+109*cos(theta)**4 - 3.6251272813912e+107*cos(theta)**2 + 4.61212122314402e+104)*cos(59*phi)

#@torch.jit.script
def Yl71_m60(theta, phi):
    return 3.27471657254262e-107*(1.0 - cos(theta)**2)**30*(3.36254922795505e+114*cos(theta)**11 - 1.31163267757112e+114*cos(theta)**9 + 1.69851713642303e+113*cos(theta)**7 - 8.67855471165054e+111*cos(theta)**5 + 1.60713976141677e+110*cos(theta)**3 - 7.2502545627824e+107*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl71_m61(theta, phi):
    return 8.59390224853277e-109*(1.0 - cos(theta)**2)**30.5*(3.69880415075056e+115*cos(theta)**10 - 1.18046940981401e+115*cos(theta)**8 + 1.18896199549612e+114*cos(theta)**6 - 4.33927735582527e+112*cos(theta)**4 + 4.8214192842503e+110*cos(theta)**2 - 7.2502545627824e+107)*cos(61*phi)

#@torch.jit.script
def Yl71_m62(theta, phi):
    return 2.35648450820151e-110*(1.0 - cos(theta)**2)**31*(3.69880415075056e+116*cos(theta)**9 - 9.44375527851207e+115*cos(theta)**7 + 7.13377197297674e+114*cos(theta)**5 - 1.73571094233011e+113*cos(theta)**3 + 9.64283856850059e+110*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl71_m63(theta, phi):
    return 6.78564187335636e-112*(1.0 - cos(theta)**2)**31.5*(3.3289237356755e+117*cos(theta)**8 - 6.61062869495845e+116*cos(theta)**6 + 3.56688598648837e+115*cos(theta)**4 - 5.20713282699032e+113*cos(theta)**2 + 9.64283856850059e+110)*cos(63*phi)

#@torch.jit.script
def Yl71_m64(theta, phi):
    return 2.06480506732716e-113*(1.0 - cos(theta)**2)**32*(2.6631389885404e+118*cos(theta)**7 - 3.96637721697507e+117*cos(theta)**5 + 1.42675439459535e+116*cos(theta)**3 - 1.04142656539806e+114*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl71_m65(theta, phi):
    return 6.69207166525422e-115*(1.0 - cos(theta)**2)**32.5*(1.86419729197828e+119*cos(theta)**6 - 1.98318860848753e+118*cos(theta)**4 + 4.28026318378604e+116*cos(theta)**2 - 1.04142656539806e+114)*cos(65*phi)

#@torch.jit.script
def Yl71_m66(theta, phi):
    return 2.33412803219294e-116*(1.0 - cos(theta)**2)**33*(1.11851837518697e+120*cos(theta)**5 - 7.93275443395013e+118*cos(theta)**3 + 8.56052636757209e+116*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl71_m67(theta, phi):
    return 8.88587355583423e-118*(1.0 - cos(theta)**2)**33.5*(5.59259187593484e+120*cos(theta)**4 - 2.37982633018504e+119*cos(theta)**2 + 8.56052636757209e+116)*cos(67*phi)

#@torch.jit.script
def Yl71_m68(theta, phi):
    return 3.76844979029729e-119*(1.0 - cos(theta)**2)**34*(2.23703675037394e+121*cos(theta)**3 - 4.75965266037008e+119*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl71_m69(theta, phi):
    return 1.83881521262701e-120*(1.0 - cos(theta)**2)**34.5*(6.71111025112181e+121*cos(theta)**2 - 4.75965266037008e+119)*cos(69*phi)

#@torch.jit.script
def Yl71_m70(theta, phi):
    return 14.697311642374*(1.0 - cos(theta)**2)**35*cos(70*phi)*cos(theta)

#@torch.jit.script
def Yl71_m71(theta, phi):
    return 1.23337099473571*(1.0 - cos(theta)**2)**35.5*cos(71*phi)

#@torch.jit.script
def Yl72_m_minus_72(theta, phi):
    return 1.2376461236541*(1.0 - cos(theta)**2)**36*sin(72*phi)

#@torch.jit.script
def Yl72_m_minus_71(theta, phi):
    return 14.8517534838492*(1.0 - cos(theta)**2)**35.5*sin(71*phi)*cos(theta)

#@torch.jit.script
def Yl72_m_minus_70(theta, phi):
    return 1.30858019143794e-122*(1.0 - cos(theta)**2)**35*(9.59688765910419e+123*cos(theta)**2 - 6.71111025112181e+121)*sin(70*phi)

#@torch.jit.script
def Yl72_m_minus_69(theta, phi):
    return 2.70087908285898e-121*(1.0 - cos(theta)**2)**34.5*(3.19896255303473e+123*cos(theta)**3 - 6.71111025112181e+121*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl72_m_minus_68(theta, phi):
    return 6.41423243311855e-120*(1.0 - cos(theta)**2)**34*(7.99740638258683e+122*cos(theta)**4 - 3.35555512556091e+121*cos(theta)**2 + 1.18991316509252e+119)*sin(68*phi)

#@torch.jit.script
def Yl72_m_minus_67(theta, phi):
    return 1.69704638693964e-118*(1.0 - cos(theta)**2)**33.5*(1.59948127651737e+122*cos(theta)**5 - 1.11851837518697e+121*cos(theta)**3 + 1.18991316509252e+119*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl72_m_minus_66(theta, phi):
    return 4.90091013025169e-117*(1.0 - cos(theta)**2)**33*(2.66580212752894e+121*cos(theta)**6 - 2.79629593796742e+120*cos(theta)**4 + 5.9495658254626e+118*cos(theta)**2 - 1.42675439459535e+116)*sin(66*phi)

#@torch.jit.script
def Yl72_m_minus_65(theta, phi):
    return 1.52322935965797e-115*(1.0 - cos(theta)**2)**32.5*(3.80828875361278e+120*cos(theta)**7 - 5.59259187593485e+119*cos(theta)**5 + 1.98318860848753e+118*cos(theta)**3 - 1.42675439459535e+116*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl72_m_minus_64(theta, phi):
    return 5.0427864713945e-114*(1.0 - cos(theta)**2)**32*(4.76036094201597e+119*cos(theta)**8 - 9.32098645989141e+118*cos(theta)**6 + 4.95797152121883e+117*cos(theta)**4 - 7.13377197297674e+115*cos(theta)**2 + 1.30178320674758e+113)*sin(64*phi)

#@torch.jit.script
def Yl72_m_minus_63(theta, phi):
    return 1.76425471984068e-112*(1.0 - cos(theta)**2)**31.5*(5.2892899355733e+118*cos(theta)**9 - 1.3315694942702e+118*cos(theta)**7 + 9.91594304243767e+116*cos(theta)**5 - 2.37792399099225e+115*cos(theta)**3 + 1.30178320674758e+113*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl72_m_minus_62(theta, phi):
    return 6.48228575985983e-111*(1.0 - cos(theta)**2)**31*(5.2892899355733e+117*cos(theta)**10 - 1.66446186783775e+117*cos(theta)**8 + 1.65265717373961e+116*cos(theta)**6 - 5.94480997748062e+114*cos(theta)**4 + 6.5089160337379e+112*cos(theta)**2 - 9.64283856850059e+109)*sin(62*phi)

#@torch.jit.script
def Yl72_m_minus_61(theta, phi):
    return 2.488725020231e-109*(1.0 - cos(theta)**2)**30.5*(4.80844539597573e+116*cos(theta)**11 - 1.84940207537528e+116*cos(theta)**9 + 2.36093881962802e+115*cos(theta)**7 - 1.18896199549612e+114*cos(theta)**5 + 2.16963867791263e+112*cos(theta)**3 - 9.64283856850059e+109*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl72_m_minus_60(theta, phi):
    return 9.94244866882035e-108*(1.0 - cos(theta)**2)**30*(4.00703782997977e+115*cos(theta)**12 - 1.84940207537528e+115*cos(theta)**10 + 2.95117352453502e+114*cos(theta)**8 - 1.98160332582687e+113*cos(theta)**6 + 5.42409669478158e+111*cos(theta)**4 - 4.8214192842503e+109*cos(theta)**2 + 6.04187880231867e+106)*sin(60*phi)

#@torch.jit.script
def Yl72_m_minus_59(theta, phi):
    return 4.11862260923638e-106*(1.0 - cos(theta)**2)**29.5*(3.08233679229213e+114*cos(theta)**13 - 1.68127461397753e+114*cos(theta)**11 + 3.2790816939278e+113*cos(theta)**9 - 2.83086189403839e+112*cos(theta)**7 + 1.08481933895632e+111*cos(theta)**5 - 1.60713976141677e+109*cos(theta)**3 + 6.04187880231867e+106*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl72_m_minus_58(theta, phi):
    return 1.76380944917166e-104*(1.0 - cos(theta)**2)**29*(2.20166913735152e+113*cos(theta)**14 - 1.40106217831461e+113*cos(theta)**12 + 3.2790816939278e+112*cos(theta)**10 - 3.53857736754799e+111*cos(theta)**8 + 1.80803223159386e+110*cos(theta)**6 - 4.01784940354191e+108*cos(theta)**4 + 3.02093940115933e+106*cos(theta)**2 - 3.29437230224573e+103)*sin(58*phi)

#@torch.jit.script
def Yl72_m_minus_57(theta, phi):
    return 7.78877163442675e-103*(1.0 - cos(theta)**2)**28.5*(1.46777942490102e+112*cos(theta)**15 - 1.07774013716508e+112*cos(theta)**13 + 2.98098335811618e+111*cos(theta)**11 - 3.93175263060887e+110*cos(theta)**9 + 2.58290318799123e+109*cos(theta)**7 - 8.03569880708383e+107*cos(theta)**5 + 1.00697980038644e+106*cos(theta)**3 - 3.29437230224573e+103*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl72_m_minus_56(theta, phi):
    return 3.53853761906228e-101*(1.0 - cos(theta)**2)**28*(9.17362140563135e+110*cos(theta)**16 - 7.69814383689344e+110*cos(theta)**14 + 2.48415279843015e+110*cos(theta)**12 - 3.93175263060887e+109*cos(theta)**10 + 3.22862898498904e+108*cos(theta)**8 - 1.33928313451397e+107*cos(theta)**6 + 2.51744950096611e+105*cos(theta)**4 - 1.64718615112286e+103*cos(theta)**2 + 1.59611061155316e+100)*sin(56*phi)

#@torch.jit.script
def Yl72_m_minus_55(theta, phi):
    return 1.65064341078821e-99*(1.0 - cos(theta)**2)**27.5*(5.3962478856655e+109*cos(theta)**17 - 5.13209589126229e+109*cos(theta)**15 + 1.91088676802319e+109*cos(theta)**13 - 3.57432057328079e+108*cos(theta)**11 + 3.58736553887671e+107*cos(theta)**9 - 1.91326162073424e+106*cos(theta)**7 + 5.03489900193222e+104*cos(theta)**5 - 5.49062050374288e+102*cos(theta)**3 + 1.59611061155316e+100*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl72_m_minus_54(theta, phi):
    return 7.89207812217828e-98*(1.0 - cos(theta)**2)**27*(2.99791549203639e+108*cos(theta)**18 - 3.20755993203893e+108*cos(theta)**16 + 1.36491912001657e+108*cos(theta)**14 - 2.97860047773399e+107*cos(theta)**12 + 3.58736553887671e+106*cos(theta)**10 - 2.39157702591781e+105*cos(theta)**8 + 8.39149833655371e+103*cos(theta)**6 - 1.37265512593572e+102*cos(theta)**4 + 7.98055305776582e+99*cos(theta)**2 - 6.98211116164988e+96)*sin(54*phi)

#@torch.jit.script
def Yl72_m_minus_53(theta, phi):
    return 3.86147696646292e-96*(1.0 - cos(theta)**2)**26.5*(1.57785025896652e+107*cos(theta)**19 - 1.8867999600229e+107*cos(theta)**17 + 9.09946080011045e+106*cos(theta)**15 - 2.29123113671846e+106*cos(theta)**13 + 3.26124139897883e+105*cos(theta)**11 - 2.65730780657534e+104*cos(theta)**9 + 1.19878547665053e+103*cos(theta)**7 - 2.74531025187144e+101*cos(theta)**5 + 2.66018435258861e+99*cos(theta)**3 - 6.98211116164988e+96*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl72_m_minus_52(theta, phi):
    return 1.93073848323146e-94*(1.0 - cos(theta)**2)**26*(7.8892512948326e+105*cos(theta)**20 - 1.04822220001272e+106*cos(theta)**18 + 5.68716300006903e+105*cos(theta)**16 - 1.63659366908461e+105*cos(theta)**14 + 2.71770116581569e+104*cos(theta)**12 - 2.65730780657534e+103*cos(theta)**10 + 1.49848184581316e+102*cos(theta)**8 - 4.5755170864524e+100*cos(theta)**6 + 6.65046088147151e+98*cos(theta)**4 - 3.49105558082494e+96*cos(theta)**2 + 2.79284446465995e+93)*sin(52*phi)

#@torch.jit.script
def Yl72_m_minus_51(theta, phi):
    return 9.85244327058163e-93*(1.0 - cos(theta)**2)**25.5*(3.75678633087267e+104*cos(theta)**21 - 5.51695894743538e+104*cos(theta)**19 + 3.34539000004061e+104*cos(theta)**17 - 1.09106244605641e+104*cos(theta)**15 + 2.09053935831976e+103*cos(theta)**13 - 2.41573436961395e+102*cos(theta)**11 + 1.66497982868129e+101*cos(theta)**9 - 6.53645298064629e+99*cos(theta)**7 + 1.3300921762943e+98*cos(theta)**5 - 1.16368519360831e+96*cos(theta)**3 + 2.79284446465995e+93*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl72_m_minus_50(theta, phi):
    return 5.12516485110946e-91*(1.0 - cos(theta)**2)**25*(1.70763015039667e+103*cos(theta)**22 - 2.75847947371769e+103*cos(theta)**20 + 1.85855000002256e+103*cos(theta)**18 - 6.81914028785255e+102*cos(theta)**16 + 1.49324239879983e+102*cos(theta)**14 - 2.01311197467829e+101*cos(theta)**12 + 1.66497982868129e+100*cos(theta)**10 - 8.17056622580786e+98*cos(theta)**8 + 2.21682029382384e+97*cos(theta)**6 - 2.90921298402079e+95*cos(theta)**4 + 1.39642223232998e+93*cos(theta)**2 - 1.0320932981005e+90)*sin(50*phi)

#@torch.jit.script
def Yl72_m_minus_49(theta, phi):
    return 2.71488646524013e-89*(1.0 - cos(theta)**2)**24.5*(7.42447891476812e+101*cos(theta)**23 - 1.31356165415128e+102*cos(theta)**21 + 9.78184210538189e+101*cos(theta)**19 - 4.01125899285444e+101*cos(theta)**17 + 9.95494932533219e+100*cos(theta)**15 - 1.54854767282945e+100*cos(theta)**13 + 1.5136180260739e+99*cos(theta)**11 - 9.07840691756429e+97*cos(theta)**9 + 3.16688613403405e+96*cos(theta)**7 - 5.81842596804157e+94*cos(theta)**5 + 4.65474077443326e+92*cos(theta)**3 - 1.0320932981005e+90*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl72_m_minus_48(theta, phi):
    return 1.46301904087385e-87*(1.0 - cos(theta)**2)**24*(3.09353288115338e+100*cos(theta)**24 - 5.97073479159674e+100*cos(theta)**22 + 4.89092105269094e+100*cos(theta)**20 - 2.22847721825247e+100*cos(theta)**18 + 6.22184332833262e+99*cos(theta)**16 - 1.10610548059247e+99*cos(theta)**14 + 1.26134835506158e+98*cos(theta)**12 - 9.07840691756429e+96*cos(theta)**10 + 3.95860766754257e+95*cos(theta)**8 - 9.69737661340262e+93*cos(theta)**6 + 1.16368519360831e+92*cos(theta)**4 - 5.1604664905025e+89*cos(theta)**2 + 3.55404028271522e+86)*sin(48*phi)

#@torch.jit.script
def Yl72_m_minus_47(theta, phi):
    return 8.01328530746178e-86*(1.0 - cos(theta)**2)**23.5*(1.23741315246135e+99*cos(theta)**25 - 2.59597164852032e+99*cos(theta)**23 + 2.32901002509093e+99*cos(theta)**21 - 1.17288274644867e+99*cos(theta)**19 + 3.65990784019566e+98*cos(theta)**17 - 7.37403653728311e+97*cos(theta)**15 + 9.70267965431988e+96*cos(theta)**13 - 8.25309719778572e+95*cos(theta)**11 + 4.39845296393619e+94*cos(theta)**9 - 1.38533951620037e+93*cos(theta)**7 + 2.32737038721663e+91*cos(theta)**5 - 1.72015549683417e+89*cos(theta)**3 + 3.55404028271522e+86*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl72_m_minus_46(theta, phi):
    return 4.45728865959693e-84*(1.0 - cos(theta)**2)**23*(4.75928135562059e+97*cos(theta)**26 - 1.08165485355013e+98*cos(theta)**24 + 1.05864092049588e+98*cos(theta)**22 - 5.86441373224334e+97*cos(theta)**20 + 2.03328213344203e+97*cos(theta)**18 - 4.60877283580194e+96*cos(theta)**16 + 6.93048546737134e+95*cos(theta)**14 - 6.87758099815477e+94*cos(theta)**12 + 4.39845296393619e+93*cos(theta)**10 - 1.73167439525047e+92*cos(theta)**8 + 3.87895064536105e+90*cos(theta)**6 - 4.30038874208542e+88*cos(theta)**4 + 1.77702014135761e+86*cos(theta)**2 - 1.14868787418074e+83)*sin(46*phi)

#@torch.jit.script
def Yl72_m_minus_45(theta, phi):
    return 2.51590157027613e-82*(1.0 - cos(theta)**2)**22.5*(1.762696798378e+96*cos(theta)**27 - 4.32661941420053e+96*cos(theta)**25 + 4.60278661085163e+96*cos(theta)**23 - 2.79257796773492e+96*cos(theta)**21 + 1.07014849128528e+96*cos(theta)**19 - 2.71104284458938e+95*cos(theta)**17 + 4.62032364491423e+94*cos(theta)**15 - 5.29044692165751e+93*cos(theta)**13 + 3.99859360357835e+92*cos(theta)**11 - 1.92408266138941e+91*cos(theta)**9 + 5.5413580648015e+89*cos(theta)**7 - 8.60077748417084e+87*cos(theta)**5 + 5.92340047119204e+85*cos(theta)**3 - 1.14868787418074e+83*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl72_m_minus_44(theta, phi):
    return 1.44001028087571e-80*(1.0 - cos(theta)**2)**22*(6.29534570849284e+94*cos(theta)**28 - 1.66408439007713e+95*cos(theta)**26 + 1.91782775452151e+95*cos(theta)**24 - 1.26935362169769e+95*cos(theta)**22 + 5.3507424564264e+94*cos(theta)**20 - 1.50613491366077e+94*cos(theta)**18 + 2.88770227807139e+93*cos(theta)**16 - 3.77889065832679e+92*cos(theta)**14 + 3.33216133631529e+91*cos(theta)**12 - 1.92408266138941e+90*cos(theta)**10 + 6.92669758100187e+88*cos(theta)**8 - 1.43346291402847e+87*cos(theta)**6 + 1.48085011779801e+85*cos(theta)**4 - 5.74343937090372e+82*cos(theta)**2 + 3.50637324230996e+79)*sin(44*phi)

#@torch.jit.script
def Yl72_m_minus_43(theta, phi):
    return 8.35205962907912e-79*(1.0 - cos(theta)**2)**21.5*(2.17080886499753e+93*cos(theta)**29 - 6.16327551880418e+93*cos(theta)**27 + 7.67131101808605e+93*cos(theta)**25 - 5.51892878998997e+93*cos(theta)**23 + 2.54797259829829e+93*cos(theta)**21 - 7.92702586137245e+92*cos(theta)**19 + 1.69864839886552e+92*cos(theta)**17 - 2.51926043888453e+91*cos(theta)**15 + 2.56320102793484e+90*cos(theta)**13 - 1.74916605580855e+89*cos(theta)**11 + 7.69633064555763e+87*cos(theta)**9 - 2.04780416289782e+86*cos(theta)**7 + 2.96170023559602e+84*cos(theta)**5 - 1.91447979030124e+82*cos(theta)**3 + 3.50637324230996e+79*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl72_m_minus_42(theta, phi):
    return 4.90572426013266e-77*(1.0 - cos(theta)**2)**21*(7.23602954999177e+91*cos(theta)**30 - 2.20116982814435e+92*cos(theta)**28 + 2.9505042377254e+92*cos(theta)**26 - 2.29955366249582e+92*cos(theta)**24 + 1.15816936286286e+92*cos(theta)**22 - 3.96351293068622e+91*cos(theta)**20 + 9.43693554925291e+90*cos(theta)**18 - 1.57453777430283e+90*cos(theta)**16 + 1.83085787709631e+89*cos(theta)**14 - 1.45763837984046e+88*cos(theta)**12 + 7.69633064555763e+86*cos(theta)**10 - 2.55975520362227e+85*cos(theta)**8 + 4.9361670593267e+83*cos(theta)**6 - 4.7861994757531e+81*cos(theta)**4 + 1.75318662115498e+79*cos(theta)**2 - 1.01634007023477e+76)*sin(42*phi)

#@torch.jit.script
def Yl72_m_minus_41(theta, phi):
    return 2.91632826076128e-75*(1.0 - cos(theta)**2)**20.5*(2.33420308064251e+90*cos(theta)**31 - 7.59024078670465e+90*cos(theta)**29 + 1.09277934730571e+91*cos(theta)**27 - 9.19821464998327e+90*cos(theta)**25 + 5.03551896896895e+90*cos(theta)**23 - 1.88738710985058e+90*cos(theta)**21 + 4.96680818381732e+89*cos(theta)**19 - 9.26198690766371e+88*cos(theta)**17 + 1.22057191806421e+88*cos(theta)**15 - 1.12126029218497e+87*cos(theta)**13 + 6.99666422323421e+85*cos(theta)**11 - 2.84417244846919e+84*cos(theta)**9 + 7.05166722760957e+82*cos(theta)**7 - 9.5723989515062e+80*cos(theta)**5 + 5.84395540384994e+78*cos(theta)**3 - 1.01634007023477e+76*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl72_m_minus_40(theta, phi):
    return 1.75368108322596e-73*(1.0 - cos(theta)**2)**20*(7.29438462700783e+88*cos(theta)**32 - 2.53008026223488e+89*cos(theta)**30 + 3.90278338323466e+89*cos(theta)**28 - 3.53777486537818e+89*cos(theta)**26 + 2.09813290373706e+89*cos(theta)**24 - 8.57903231750265e+88*cos(theta)**22 + 2.48340409190866e+88*cos(theta)**20 - 5.14554828203539e+87*cos(theta)**18 + 7.62857448790131e+86*cos(theta)**16 - 8.0090020870355e+85*cos(theta)**14 + 5.83055351936184e+84*cos(theta)**12 - 2.84417244846919e+83*cos(theta)**10 + 8.81458403451196e+81*cos(theta)**8 - 1.59539982525103e+80*cos(theta)**6 + 1.46098885096248e+78*cos(theta)**4 - 5.08170035117386e+75*cos(theta)**2 + 2.81067497299439e+72)*sin(40*phi)

#@torch.jit.script
def Yl72_m_minus_39(theta, phi):
    return 1.06614579560172e-71*(1.0 - cos(theta)**2)**19.5*(2.21041958394177e+87*cos(theta)**33 - 8.16154923301576e+87*cos(theta)**31 + 1.34578737352919e+88*cos(theta)**29 - 1.3102869871771e+88*cos(theta)**27 + 8.39253161494824e+87*cos(theta)**25 - 3.73001405108811e+87*cos(theta)**23 + 1.18257337709936e+87*cos(theta)**21 - 2.70818330633442e+86*cos(theta)**19 + 4.48739675758901e+85*cos(theta)**17 - 5.33933472469033e+84*cos(theta)**15 + 4.48504116873988e+83*cos(theta)**13 - 2.58561131679017e+82*cos(theta)**11 + 9.79398226056884e+80*cos(theta)**9 - 2.27914260750148e+79*cos(theta)**7 + 2.92197770192497e+77*cos(theta)**5 - 1.69390011705795e+75*cos(theta)**3 + 2.81067497299439e+72*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl72_m_minus_38(theta, phi):
    return 6.54964176129246e-70*(1.0 - cos(theta)**2)**19*(6.50123407041696e+85*cos(theta)**34 - 2.55048413531742e+86*cos(theta)**32 + 4.48595791176398e+86*cos(theta)**30 - 4.67959638277537e+86*cos(theta)**28 + 3.22789677498009e+86*cos(theta)**26 - 1.55417252128671e+86*cos(theta)**24 + 5.37533353226983e+85*cos(theta)**22 - 1.35409165316721e+85*cos(theta)**20 + 2.49299819866056e+84*cos(theta)**18 - 3.33708420293146e+83*cos(theta)**16 + 3.2036008348142e+82*cos(theta)**14 - 2.15467609732515e+81*cos(theta)**12 + 9.79398226056884e+79*cos(theta)**10 - 2.84892825937684e+78*cos(theta)**8 + 4.86996283654161e+76*cos(theta)**6 - 4.23475029264488e+74*cos(theta)**4 + 1.4053374864972e+72*cos(theta)**2 - 7.44746945679489e+68)*sin(38*phi)

#@torch.jit.script
def Yl72_m_minus_37(theta, phi):
    return 4.06394583778961e-68*(1.0 - cos(theta)**2)**18.5*(1.85749544869056e+84*cos(theta)**35 - 7.72873980399219e+84*cos(theta)**33 + 1.44708319734322e+85*cos(theta)**31 - 1.61365392509496e+85*cos(theta)**29 + 1.1955173240667e+85*cos(theta)**27 - 6.21669008514685e+84*cos(theta)**25 + 2.33710153576949e+84*cos(theta)**23 - 6.44805549127242e+83*cos(theta)**21 + 1.3121043150845e+83*cos(theta)**19 - 1.96299070760674e+82*cos(theta)**17 + 2.13573388987613e+81*cos(theta)**15 - 1.65744315178857e+80*cos(theta)**13 + 8.90362023688077e+78*cos(theta)**11 - 3.16547584375205e+77*cos(theta)**9 + 6.95708976648802e+75*cos(theta)**7 - 8.46950058528977e+73*cos(theta)**5 + 4.68445828832399e+71*cos(theta)**3 - 7.44746945679489e+68*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl72_m_minus_36(theta, phi):
    return 2.54573041092809e-66*(1.0 - cos(theta)**2)**18*(5.159709579696e+82*cos(theta)**36 - 2.27315876588006e+83*cos(theta)**34 + 4.52213499169756e+83*cos(theta)**32 - 5.37884641698319e+83*cos(theta)**30 + 4.26970472880965e+83*cos(theta)**28 - 2.3910346481334e+83*cos(theta)**26 + 9.73792306570621e+82*cos(theta)**24 - 2.93093431421474e+82*cos(theta)**22 + 6.56052157542253e+81*cos(theta)**20 - 1.09055039311486e+81*cos(theta)**18 + 1.33483368117258e+80*cos(theta)**16 - 1.18388796556327e+79*cos(theta)**14 + 7.41968353073397e+77*cos(theta)**12 - 3.16547584375205e+76*cos(theta)**10 + 8.69636220811003e+74*cos(theta)**8 - 1.41158343088163e+73*cos(theta)**6 + 1.171114572081e+71*cos(theta)**4 - 3.72373472839744e+68*cos(theta)**2 + 1.8979279961251e+65)*sin(36*phi)

#@torch.jit.script
def Yl72_m_minus_35(theta, phi):
    return 1.60925604945875e-64*(1.0 - cos(theta)**2)**17.5*(1.39451610262054e+81*cos(theta)**37 - 6.49473933108588e+81*cos(theta)**35 + 1.37034393687805e+82*cos(theta)**33 - 1.73511174741393e+82*cos(theta)**31 + 1.4723119754516e+82*cos(theta)**29 - 8.85568388197557e+81*cos(theta)**27 + 3.89516922628249e+81*cos(theta)**25 - 1.27431926704989e+81*cos(theta)**23 + 3.12405789305835e+80*cos(theta)**21 - 5.73973891113082e+79*cos(theta)**19 + 7.85196283042696e+78*cos(theta)**17 - 7.89258643708844e+77*cos(theta)**15 + 5.70744886979536e+76*cos(theta)**13 - 2.87770531250186e+75*cos(theta)**11 + 9.66262467567781e+73*cos(theta)**9 - 2.01654775840232e+72*cos(theta)**7 + 2.34222914416199e+70*cos(theta)**5 - 1.24124490946581e+68*cos(theta)**3 + 1.8979279961251e+65*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl72_m_minus_34(theta, phi):
    return 1.0261452462024e-62*(1.0 - cos(theta)**2)**17*(3.66977921742248e+79*cos(theta)**38 - 1.80409425863497e+80*cos(theta)**36 + 4.03042334375897e+80*cos(theta)**34 - 5.42222421066854e+80*cos(theta)**32 + 4.90770658483868e+80*cos(theta)**30 - 3.1627442435627e+80*cos(theta)**28 + 1.49814201010865e+80*cos(theta)**26 - 5.30966361270786e+79*cos(theta)**24 + 1.42002631502652e+79*cos(theta)**22 - 2.86986945556541e+78*cos(theta)**20 + 4.36220157245942e+77*cos(theta)**18 - 4.93286652318028e+76*cos(theta)**16 + 4.07674919271097e+75*cos(theta)**14 - 2.39808776041822e+74*cos(theta)**12 + 9.66262467567781e+72*cos(theta)**10 - 2.52068469800291e+71*cos(theta)**8 + 3.90371524026999e+69*cos(theta)**6 - 3.10311227366454e+67*cos(theta)**4 + 9.4896399806255e+64*cos(theta)**2 - 4.66780126936817e+61)*sin(34*phi)

#@torch.jit.script
def Yl72_m_minus_33(theta, phi):
    return 6.59772293302761e-61*(1.0 - cos(theta)**2)**16.5*(9.40969030108327e+77*cos(theta)**39 - 4.87593042874315e+78*cos(theta)**37 + 1.15154952678828e+79*cos(theta)**35 - 1.64309824565713e+79*cos(theta)**33 + 1.58313115639957e+79*cos(theta)**31 - 1.09060146329748e+79*cos(theta)**29 + 5.54867411151351e+78*cos(theta)**27 - 2.12386544508314e+78*cos(theta)**25 + 6.17402745663705e+77*cos(theta)**23 - 1.36660450265019e+77*cos(theta)**21 + 2.29589556445233e+76*cos(theta)**19 - 2.90168619010605e+75*cos(theta)**17 + 2.71783279514065e+74*cos(theta)**15 - 1.8446828926294e+73*cos(theta)**13 + 8.78420425061619e+71*cos(theta)**11 - 2.80076077555878e+70*cos(theta)**9 + 5.57673605752855e+68*cos(theta)**7 - 6.20622454732907e+66*cos(theta)**5 + 3.16321332687517e+64*cos(theta)**3 - 4.66780126936817e+61*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl72_m_minus_32(theta, phi):
    return 4.27581315288909e-59*(1.0 - cos(theta)**2)**16*(2.35242257527082e+76*cos(theta)**40 - 1.28313958651136e+77*cos(theta)**38 + 3.19874868552299e+77*cos(theta)**36 - 4.83264189899157e+77*cos(theta)**34 + 4.94728486374867e+77*cos(theta)**32 - 3.63533821099161e+77*cos(theta)**30 + 1.98166932554054e+77*cos(theta)**28 - 8.16871325031978e+76*cos(theta)**26 + 2.57251144026544e+76*cos(theta)**24 - 6.21183864840998e+75*cos(theta)**22 + 1.14794778222616e+75*cos(theta)**20 - 1.61204788339225e+74*cos(theta)**18 + 1.69864549696291e+73*cos(theta)**16 - 1.31763063759243e+72*cos(theta)**14 + 7.32017020884682e+70*cos(theta)**12 - 2.80076077555878e+69*cos(theta)**10 + 6.97092007191069e+67*cos(theta)**8 - 1.03437075788818e+66*cos(theta)**6 + 7.90803331718791e+63*cos(theta)**4 - 2.33390063468409e+61*cos(theta)**2 + 1.11138125461147e+58)*sin(32*phi)

#@torch.jit.script
def Yl72_m_minus_31(theta, phi):
    return 2.79207652289367e-57*(1.0 - cos(theta)**2)**15.5*(5.7376160372459e+74*cos(theta)**41 - 3.29010150387527e+75*cos(theta)**39 + 8.6452667176297e+75*cos(theta)**37 - 1.3807548282833e+76*cos(theta)**35 + 1.49917723143899e+76*cos(theta)**33 - 1.17268974548117e+76*cos(theta)**31 + 6.83334250186393e+75*cos(theta)**29 - 3.02544935197029e+75*cos(theta)**27 + 1.02900457610617e+75*cos(theta)**25 - 2.70079941235216e+74*cos(theta)**23 + 5.46641801060078e+73*cos(theta)**21 - 8.48446254416972e+72*cos(theta)**19 + 9.99203233507592e+71*cos(theta)**17 - 8.78420425061619e+70*cos(theta)**15 + 5.6309001606514e+69*cos(theta)**13 - 2.5461461595989e+68*cos(theta)**11 + 7.74546674656744e+66*cos(theta)**9 - 1.47767251126883e+65*cos(theta)**7 + 1.58160666343758e+63*cos(theta)**5 - 7.77966878228029e+60*cos(theta)**3 + 1.11138125461147e+58*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl72_m_minus_30(theta, phi):
    return 1.83641391319431e-55*(1.0 - cos(theta)**2)**15*(1.36609905648712e+73*cos(theta)**42 - 8.22525375968818e+73*cos(theta)**40 + 2.27507018884992e+74*cos(theta)**38 - 3.83543007856473e+74*cos(theta)**36 + 4.40934479834997e+74*cos(theta)**34 - 3.66465545462864e+74*cos(theta)**32 + 2.27778083395464e+74*cos(theta)**30 - 1.08051762570368e+74*cos(theta)**28 + 3.95770990810067e+73*cos(theta)**26 - 1.12533308848007e+73*cos(theta)**24 + 2.48473545936399e+72*cos(theta)**22 - 4.24223127208486e+71*cos(theta)**20 + 5.55112907504217e+70*cos(theta)**18 - 5.49012765663512e+69*cos(theta)**16 + 4.02207154332243e+68*cos(theta)**14 - 2.12178846633241e+67*cos(theta)**12 + 7.74546674656744e+65*cos(theta)**10 - 1.84709063908603e+64*cos(theta)**8 + 2.6360111057293e+62*cos(theta)**6 - 1.94491719557007e+60*cos(theta)**4 + 5.55690627305735e+57*cos(theta)**2 - 2.56907363525536e+54)*sin(30*phi)

#@torch.jit.script
def Yl72_m_minus_29(theta, phi):
    return 1.21619968926472e-53*(1.0 - cos(theta)**2)**14.5*(3.17697454997004e+71*cos(theta)**43 - 2.00615945358248e+72*cos(theta)**41 + 5.83351330474339e+72*cos(theta)**39 - 1.03660272393641e+73*cos(theta)**37 + 1.25981279952856e+73*cos(theta)**35 - 1.11050165291777e+73*cos(theta)**33 + 7.34768010953111e+72*cos(theta)**31 - 3.72592284725405e+72*cos(theta)**29 + 1.46581848448173e+72*cos(theta)**27 - 4.50133235392027e+71*cos(theta)**25 + 1.08031976494087e+71*cos(theta)**23 - 2.02011012956422e+70*cos(theta)**21 + 2.92164688160114e+69*cos(theta)**19 - 3.22948685684419e+68*cos(theta)**17 + 2.68138102888162e+67*cos(theta)**15 - 1.63214497410186e+66*cos(theta)**13 + 7.0413334059704e+64*cos(theta)**11 - 2.05232293231782e+63*cos(theta)**9 + 3.76573015104186e+61*cos(theta)**7 - 3.88983439114014e+59*cos(theta)**5 + 1.85230209101912e+57*cos(theta)**3 - 2.56907363525536e+54*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl72_m_minus_28(theta, phi):
    return 8.10759251839952e-52*(1.0 - cos(theta)**2)**14*(7.22039670447737e+69*cos(theta)**44 - 4.77657012757734e+70*cos(theta)**42 + 1.45837832618585e+71*cos(theta)**40 - 2.72790190509583e+71*cos(theta)**38 + 3.49947999869045e+71*cos(theta)**36 - 3.26618133211109e+71*cos(theta)**34 + 2.29615003422847e+71*cos(theta)**32 - 1.24197428241802e+71*cos(theta)**30 + 5.23506601600618e+70*cos(theta)**28 - 1.73128167458472e+70*cos(theta)**26 + 4.50133235392027e+69*cos(theta)**24 - 9.18231877074646e+68*cos(theta)**22 + 1.46082344080057e+68*cos(theta)**20 - 1.79415936491344e+67*cos(theta)**18 + 1.67586314305101e+66*cos(theta)**16 - 1.16581783864418e+65*cos(theta)**14 + 5.86777783830866e+63*cos(theta)**12 - 2.05232293231782e+62*cos(theta)**10 + 4.70716268880233e+60*cos(theta)**8 - 6.48305731856691e+58*cos(theta)**6 + 4.63075522754779e+56*cos(theta)**4 - 1.28453681762768e+54*cos(theta)**2 + 5.78099377870244e+50)*sin(28*phi)

#@torch.jit.script
def Yl72_m_minus_27(theta, phi):
    return 5.43873840150301e-50*(1.0 - cos(theta)**2)**13.5*(1.60453260099497e+68*cos(theta)**45 - 1.11083026222729e+69*cos(theta)**43 + 3.55702030777036e+69*cos(theta)**41 - 6.99462026947648e+69*cos(theta)**39 + 9.45805405051473e+69*cos(theta)**37 - 9.33194666317454e+69*cos(theta)**35 + 6.95803040675294e+69*cos(theta)**33 - 4.00636865296135e+69*cos(theta)**31 + 1.80519517793316e+69*cos(theta)**29 - 6.41215435031378e+68*cos(theta)**27 + 1.80053294156811e+68*cos(theta)**25 - 3.9923125090202e+67*cos(theta)**23 + 6.95630209905034e+66*cos(theta)**21 - 9.4429440258602e+65*cos(theta)**19 + 9.85801848853537e+64*cos(theta)**17 - 7.77211892429455e+63*cos(theta)**15 + 4.51367526023743e+62*cos(theta)**13 - 1.86574812028892e+61*cos(theta)**11 + 5.23018076533592e+59*cos(theta)**9 - 9.26151045509558e+57*cos(theta)**7 + 9.26151045509558e+55*cos(theta)**5 - 4.28178939209227e+53*cos(theta)**3 + 5.78099377870244e+50*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl72_m_minus_26(theta, phi):
    return 3.67024185267844e-48*(1.0 - cos(theta)**2)**13*(3.48811434998907e+66*cos(theta)**46 - 2.52461423233475e+67*cos(theta)**44 + 8.4690959708818e+67*cos(theta)**42 - 1.74865506736912e+68*cos(theta)**40 + 2.48896159224072e+68*cos(theta)**38 - 2.59220740643737e+68*cos(theta)**36 + 2.04647953139792e+68*cos(theta)**34 - 1.25199020405042e+68*cos(theta)**32 + 6.01731725977722e+67*cos(theta)**30 - 2.29005512511206e+67*cos(theta)**28 + 6.92512669833888e+66*cos(theta)**26 - 1.66346354542508e+66*cos(theta)**24 + 3.16195549956834e+65*cos(theta)**22 - 4.7214720129301e+64*cos(theta)**20 + 5.47667693807521e+63*cos(theta)**18 - 4.85757432768409e+62*cos(theta)**16 + 3.22405375731245e+61*cos(theta)**14 - 1.55479010024077e+60*cos(theta)**12 + 5.23018076533592e+58*cos(theta)**10 - 1.15768880688695e+57*cos(theta)**8 + 1.54358507584926e+55*cos(theta)**6 - 1.07044734802307e+53*cos(theta)**4 + 2.89049688935122e+50*cos(theta)**2 - 1.26943209896848e+47)*sin(26*phi)

#@torch.jit.script
def Yl72_m_minus_25(theta, phi):
    return 2.4909020501506e-46*(1.0 - cos(theta)**2)**12.5*(7.42151989359376e+64*cos(theta)**47 - 5.61025384963277e+65*cos(theta)**45 + 1.96955720253065e+66*cos(theta)**43 - 4.26501235943688e+66*cos(theta)**41 + 6.38195280061723e+66*cos(theta)**39 - 7.00596596334425e+66*cos(theta)**37 + 5.84708437542264e+66*cos(theta)**35 - 3.7939097092437e+66*cos(theta)**33 + 1.9410700837991e+66*cos(theta)**31 - 7.89674181073125e+65*cos(theta)**29 + 2.56486174012551e+65*cos(theta)**27 - 6.65385418170033e+64*cos(theta)**25 + 1.37476326068189e+64*cos(theta)**23 - 2.24832000615719e+63*cos(theta)**21 + 2.88246154635537e+62*cos(theta)**19 - 2.85739666334359e+61*cos(theta)**17 + 2.14936917154164e+60*cos(theta)**15 - 1.19599238480059e+59*cos(theta)**13 + 4.75470978666902e+57*cos(theta)**11 - 1.28632089654105e+56*cos(theta)**9 + 2.20512153692752e+54*cos(theta)**7 - 2.14089469604614e+52*cos(theta)**5 + 9.63498963117073e+49*cos(theta)**3 - 1.26943209896848e+47*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl72_m_minus_24(theta, phi):
    return 1.69966423499341e-44*(1.0 - cos(theta)**2)**12*(1.54614997783203e+63*cos(theta)**48 - 1.21962040209408e+64*cos(theta)**46 + 4.47626636938785e+64*cos(theta)**44 - 1.01547913319926e+65*cos(theta)**42 + 1.59548820015431e+65*cos(theta)**40 - 1.84367525351164e+65*cos(theta)**38 + 1.62419010428407e+65*cos(theta)**36 - 1.11585579683638e+65*cos(theta)**34 + 6.06584401187219e+64*cos(theta)**32 - 2.63224727024375e+64*cos(theta)**30 + 9.16022050044826e+63*cos(theta)**28 - 2.55917468526936e+63*cos(theta)**26 + 5.72818025284119e+62*cos(theta)**24 - 1.02196363916236e+62*cos(theta)**22 + 1.44123077317769e+61*cos(theta)**20 - 1.58744259074644e+60*cos(theta)**18 + 1.34335573221352e+59*cos(theta)**16 - 8.54280274857566e+57*cos(theta)**14 + 3.96225815555752e+56*cos(theta)**12 - 1.28632089654105e+55*cos(theta)**10 + 2.7564019211594e+53*cos(theta)**8 - 3.56815782674356e+51*cos(theta)**6 + 2.40874740779268e+49*cos(theta)**4 - 6.34716049484238e+46*cos(theta)**2 + 2.72644351153023e+43)*sin(24*phi)

#@torch.jit.script
def Yl72_m_minus_23(theta, phi):
    return 1.1657268307417e-42*(1.0 - cos(theta)**2)**11.5*(3.15540811802456e+61*cos(theta)**49 - 2.59493702573208e+62*cos(theta)**47 + 9.94725859863966e+62*cos(theta)**45 - 2.36157937953316e+63*cos(theta)**43 + 3.8914346345227e+63*cos(theta)**41 - 4.72737244490165e+63*cos(theta)**39 + 4.38970298455153e+63*cos(theta)**37 - 3.18815941953252e+63*cos(theta)**35 + 1.83813454905218e+63*cos(theta)**33 - 8.49112022659275e+62*cos(theta)**31 + 3.1586967242925e+62*cos(theta)**29 - 9.47842476025688e+61*cos(theta)**27 + 2.29127210113648e+61*cos(theta)**25 - 4.44332017027113e+60*cos(theta)**23 + 6.8630036817985e+59*cos(theta)**21 - 8.35496100392861e+58*cos(theta)**19 + 7.90209254243248e+57*cos(theta)**17 - 5.69520183238377e+56*cos(theta)**15 + 3.0478908888904e+55*cos(theta)**13 - 1.16938263321914e+54*cos(theta)**11 + 3.06266880128822e+52*cos(theta)**9 - 5.09736832391937e+50*cos(theta)**7 + 4.81749481558536e+48*cos(theta)**5 - 2.11572016494746e+46*cos(theta)**3 + 2.72644351153023e+43*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl72_m_minus_22(theta, phi):
    return 8.03421773328159e-41*(1.0 - cos(theta)**2)**11*(6.31081623604912e+59*cos(theta)**50 - 5.40611880360851e+60*cos(theta)**48 + 2.1624475214434e+61*cos(theta)**46 - 5.36722586257535e+61*cos(theta)**44 + 9.26532055838738e+61*cos(theta)**42 - 1.18184311122541e+62*cos(theta)**40 + 1.15518499593461e+62*cos(theta)**38 - 8.85599838759033e+61*cos(theta)**36 + 5.40627808544759e+61*cos(theta)**34 - 2.65347507081023e+61*cos(theta)**32 + 1.0528989080975e+61*cos(theta)**30 - 3.38515170009174e+60*cos(theta)**28 + 8.81258500437107e+59*cos(theta)**26 - 1.85138340427964e+59*cos(theta)**24 + 3.11954712809023e+58*cos(theta)**22 - 4.17748050196431e+57*cos(theta)**20 + 4.39005141246249e+56*cos(theta)**18 - 3.55950114523986e+55*cos(theta)**16 + 2.177064920636e+54*cos(theta)**14 - 9.74485527682616e+52*cos(theta)**12 + 3.06266880128822e+51*cos(theta)**10 - 6.37171040489921e+49*cos(theta)**8 + 8.0291580259756e+47*cos(theta)**6 - 5.28930041236865e+45*cos(theta)**4 + 1.36322175576512e+43*cos(theta)**2 - 5.73988107690575e+39)*sin(22*phi)

#@torch.jit.script
def Yl72_m_minus_21(theta, phi):
    return 5.56278931907556e-39*(1.0 - cos(theta)**2)**10.5*(1.23741494824492e+58*cos(theta)**51 - 1.10328955175684e+59*cos(theta)**49 + 4.60095217328384e+59*cos(theta)**47 - 1.19271685835008e+60*cos(theta)**45 + 2.15472571125288e+60*cos(theta)**43 - 2.88254417372052e+60*cos(theta)**41 + 2.96201281008875e+60*cos(theta)**39 - 2.39351307772712e+60*cos(theta)**37 + 1.54465088155645e+60*cos(theta)**35 - 8.0408335479098e+59*cos(theta)**33 + 3.3964480906371e+59*cos(theta)**31 - 1.16729368968681e+59*cos(theta)**29 + 3.26392037198928e+58*cos(theta)**27 - 7.40553361711854e+57*cos(theta)**25 + 1.3563248383001e+57*cos(theta)**23 - 1.98927642950681e+56*cos(theta)**21 + 2.31055337498026e+55*cos(theta)**19 - 2.09382420308227e+54*cos(theta)**17 + 1.45137661375733e+53*cos(theta)**15 - 7.49604252063551e+51*cos(theta)**13 + 2.78424436480747e+50*cos(theta)**11 - 7.07967822766579e+48*cos(theta)**9 + 1.14702257513937e+47*cos(theta)**7 - 1.05786008247373e+45*cos(theta)**5 + 4.54407251921705e+42*cos(theta)**3 - 5.73988107690575e+39*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl72_m_minus_20(theta, phi):
    return 3.86843904618807e-37*(1.0 - cos(theta)**2)**10*(2.37964413124024e+56*cos(theta)**52 - 2.20657910351368e+57*cos(theta)**50 + 9.58531702767466e+57*cos(theta)**48 - 2.59286273554365e+58*cos(theta)**46 + 4.89710388921109e+58*cos(theta)**44 - 6.86320041362028e+58*cos(theta)**42 + 7.40503202522188e+58*cos(theta)**40 - 6.29871862559768e+58*cos(theta)**38 + 4.29069689321237e+58*cos(theta)**36 - 2.36495104350288e+58*cos(theta)**34 + 1.06139002832409e+58*cos(theta)**32 - 3.89097896562269e+57*cos(theta)**30 + 1.16568584713903e+57*cos(theta)**28 - 2.84828216043021e+56*cos(theta)**26 + 5.65135349291708e+55*cos(theta)**24 - 9.04216558866733e+54*cos(theta)**22 + 1.15527668749013e+54*cos(theta)**20 - 1.16323566837904e+53*cos(theta)**18 + 9.07110383598332e+51*cos(theta)**16 - 5.35431608616822e+50*cos(theta)**14 + 2.32020363733956e+49*cos(theta)**12 - 7.07967822766579e+47*cos(theta)**10 + 1.43377821892422e+46*cos(theta)**8 - 1.76310013745622e+44*cos(theta)**6 + 1.13601812980426e+42*cos(theta)**4 - 2.86994053845287e+39*cos(theta)**2 + 1.18690675701111e+36)*sin(20*phi)

#@torch.jit.script
def Yl72_m_minus_19(theta, phi):
    return 2.70126758225203e-35*(1.0 - cos(theta)**2)**9.5*(4.48989458724574e+54*cos(theta)**53 - 4.32662569316407e+55*cos(theta)**51 + 1.95618714850503e+56*cos(theta)**49 - 5.51672922456096e+56*cos(theta)**47 + 1.08824530871358e+57*cos(theta)**45 - 1.59609311944658e+57*cos(theta)**43 + 1.80610537200534e+57*cos(theta)**41 - 1.61505605784556e+57*cos(theta)**39 + 1.15964780897632e+57*cos(theta)**37 - 6.75700298143681e+56*cos(theta)**35 + 3.21633341916392e+56*cos(theta)**33 - 1.25515450503958e+56*cos(theta)**31 + 4.01960636944493e+55*cos(theta)**29 - 1.05491931867786e+55*cos(theta)**27 + 2.26054139716683e+54*cos(theta)**25 - 3.93137634289884e+53*cos(theta)**23 + 5.5013175594768e+52*cos(theta)**21 - 6.12229299146862e+51*cos(theta)**19 + 5.33594343293137e+50*cos(theta)**17 - 3.56954405744548e+49*cos(theta)**15 + 1.78477202872274e+48*cos(theta)**13 - 6.43607111605981e+46*cos(theta)**11 + 1.59308690991579e+45*cos(theta)**9 - 2.51871448208031e+43*cos(theta)**7 + 2.27203625960852e+41*cos(theta)**5 - 9.56646846150958e+38*cos(theta)**3 + 1.18690675701111e+36*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl72_m_minus_18(theta, phi):
    return 1.89358664843331e-33*(1.0 - cos(theta)**2)**9*(8.31461960601062e+52*cos(theta)**54 - 8.32043402531553e+53*cos(theta)**52 + 3.91237429701007e+54*cos(theta)**50 - 1.1493185884502e+55*cos(theta)**48 + 2.36575067111647e+55*cos(theta)**46 - 3.62748436237859e+55*cos(theta)**44 + 4.30025088572699e+55*cos(theta)**42 - 4.0376401446139e+55*cos(theta)**40 + 3.05170476046399e+55*cos(theta)**38 - 1.87694527262133e+55*cos(theta)**36 + 9.45980417401153e+54*cos(theta)**34 - 3.92235782824868e+54*cos(theta)**32 + 1.33986878981498e+54*cos(theta)**30 - 3.76756899527805e+53*cos(theta)**28 + 8.6943899891032e+52*cos(theta)**26 - 1.63807347620785e+52*cos(theta)**24 + 2.50059889067127e+51*cos(theta)**22 - 3.06114649573431e+50*cos(theta)**20 + 2.9644130182952e+49*cos(theta)**18 - 2.23096503590342e+48*cos(theta)**16 + 1.27483716337339e+47*cos(theta)**14 - 5.36339259671651e+45*cos(theta)**12 + 1.59308690991579e+44*cos(theta)**10 - 3.14839310260038e+42*cos(theta)**8 + 3.78672709934754e+40*cos(theta)**6 - 2.39161711537739e+38*cos(theta)**4 + 5.93453378505557e+35*cos(theta)**2 - 2.41535766587528e+32)*sin(18*phi)

#@torch.jit.script
def Yl72_m_minus_17(theta, phi):
    return 1.33225629876043e-31*(1.0 - cos(theta)**2)**8.5*(1.51174901927466e+51*cos(theta)**55 - 1.56989321232368e+52*cos(theta)**53 + 7.67132215100013e+52*cos(theta)**51 - 2.34554813969428e+53*cos(theta)**49 + 5.03351206620525e+53*cos(theta)**47 - 8.0610763608413e+53*cos(theta)**45 + 1.00005834551791e+54*cos(theta)**43 - 9.84790279174121e+53*cos(theta)**41 + 7.82488400118972e+53*cos(theta)**39 - 5.07282506113874e+53*cos(theta)**37 + 2.70280119257472e+53*cos(theta)**35 - 1.18859328128748e+53*cos(theta)**33 + 4.32215738649993e+52*cos(theta)**31 - 1.29916172250967e+52*cos(theta)**29 + 3.22014444040859e+51*cos(theta)**27 - 6.5522939048314e+50*cos(theta)**25 + 1.08721690898751e+50*cos(theta)**23 - 1.45768880749253e+49*cos(theta)**21 + 1.56021737805011e+48*cos(theta)**19 - 1.31233237406084e+47*cos(theta)**17 + 8.49891442248924e+45*cos(theta)**15 - 4.12568661285885e+44*cos(theta)**13 + 1.44826082719618e+43*cos(theta)**11 - 3.49821455844487e+41*cos(theta)**9 + 5.40961014192506e+39*cos(theta)**7 - 4.78323423075479e+37*cos(theta)**5 + 1.97817792835186e+35*cos(theta)**3 - 2.41535766587528e+32*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl72_m_minus_16(theta, phi):
    return 9.40538979437044e-30*(1.0 - cos(theta)**2)**8*(2.69955182013332e+49*cos(theta)**56 - 2.90720965245127e+50*cos(theta)**54 + 1.47525425980772e+51*cos(theta)**52 - 4.69109627938857e+51*cos(theta)**50 + 1.04864834712609e+52*cos(theta)**48 - 1.75240790453072e+52*cos(theta)**46 + 2.27285987617706e+52*cos(theta)**44 - 2.34473875993838e+52*cos(theta)**42 + 1.95622100029743e+52*cos(theta)**40 - 1.33495396345756e+52*cos(theta)**38 + 7.50778109048534e+51*cos(theta)**36 - 3.495862592022e+51*cos(theta)**34 + 1.35067418328123e+51*cos(theta)**32 - 4.33053907503225e+50*cos(theta)**30 + 1.15005158586021e+50*cos(theta)**28 - 2.52011304031977e+49*cos(theta)**26 + 4.53007045411463e+48*cos(theta)**24 - 6.62585821587513e+47*cos(theta)**22 + 7.80108689025054e+46*cos(theta)**20 - 7.2907354114491e+45*cos(theta)**18 + 5.31182151405577e+44*cos(theta)**16 - 2.9469190091849e+43*cos(theta)**14 + 1.20688402266348e+42*cos(theta)**12 - 3.49821455844487e+40*cos(theta)**10 + 6.76201267740632e+38*cos(theta)**8 - 7.97205705125798e+36*cos(theta)**6 + 4.94544482087964e+34*cos(theta)**4 - 1.20767883293764e+32*cos(theta)**2 + 4.84622324613821e+28)*sin(16*phi)

#@torch.jit.script
def Yl72_m_minus_15(theta, phi):
    return 6.66124738795357e-28*(1.0 - cos(theta)**2)**7.5*(4.7360558247953e+47*cos(theta)**57 - 5.28583573172958e+48*cos(theta)**55 + 2.78349860341079e+49*cos(theta)**53 - 9.19822799880112e+49*cos(theta)**51 + 2.14009866760427e+50*cos(theta)**49 - 3.72852745644834e+50*cos(theta)**47 + 5.05079972483791e+50*cos(theta)**45 - 5.45288083706601e+50*cos(theta)**43 + 4.77127073243276e+50*cos(theta)**41 - 3.42295888066042e+50*cos(theta)**39 + 2.0291300244555e+50*cos(theta)**37 - 9.98817883434857e+49*cos(theta)**35 + 4.09295207054917e+49*cos(theta)**33 - 1.39694808872008e+49*cos(theta)**31 + 3.9656951236559e+48*cos(theta)**29 - 9.33375200118433e+47*cos(theta)**27 + 1.81202818164585e+47*cos(theta)**25 - 2.88080791994571e+46*cos(theta)**23 + 3.71480328107168e+45*cos(theta)**21 - 3.83722916392058e+44*cos(theta)**19 + 3.12460089062104e+43*cos(theta)**17 - 1.96461267278993e+42*cos(theta)**15 + 9.28372325125754e+40*cos(theta)**13 - 3.1801950531317e+39*cos(theta)**11 + 7.51334741934036e+37*cos(theta)**9 - 1.13886529303685e+36*cos(theta)**7 + 9.89088964175928e+33*cos(theta)**5 - 4.02559610979214e+31*cos(theta)**3 + 4.84622324613821e+28*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl72_m_minus_14(theta, phi):
    return 4.73183057377072e-26*(1.0 - cos(theta)**2)**7*(8.16561349102637e+45*cos(theta)**58 - 9.43899237808853e+46*cos(theta)**56 + 5.15462704335331e+47*cos(theta)**54 - 1.76888999976945e+48*cos(theta)**52 + 4.28019733520855e+48*cos(theta)**50 - 7.76776553426737e+48*cos(theta)**48 + 1.09799994018215e+49*cos(theta)**46 - 1.23929109933318e+49*cos(theta)**44 + 1.13601684105542e+49*cos(theta)**42 - 8.55739720165105e+48*cos(theta)**40 + 5.33981585383026e+48*cos(theta)**38 - 2.77449412065238e+48*cos(theta)**36 + 1.20380943251446e+48*cos(theta)**34 - 4.36546277725025e+47*cos(theta)**32 + 1.32189837455197e+47*cos(theta)**30 - 3.33348285756583e+46*cos(theta)**28 + 6.96933916017635e+45*cos(theta)**26 - 1.20033663331071e+45*cos(theta)**24 + 1.68854694594167e+44*cos(theta)**22 - 1.91861458196029e+43*cos(theta)**20 + 1.73588938367836e+42*cos(theta)**18 - 1.22788292049371e+41*cos(theta)**16 + 6.63123089375539e+39*cos(theta)**14 - 2.65016254427642e+38*cos(theta)**12 + 7.51334741934036e+36*cos(theta)**10 - 1.42358161629607e+35*cos(theta)**8 + 1.64848160695988e+33*cos(theta)**6 - 1.00639902744803e+31*cos(theta)**4 + 2.4231116230691e+28*cos(theta)**2 - 9.60408887462982e+24)*sin(14*phi)

#@torch.jit.script
def Yl72_m_minus_13(theta, phi):
    return 3.3705782770497e-24*(1.0 - cos(theta)**2)**6.5*(1.38400228661464e+44*cos(theta)**59 - 1.65596357510325e+45*cos(theta)**57 + 9.37204916973329e+45*cos(theta)**55 - 3.33752830145178e+46*cos(theta)**53 + 8.39254379452656e+46*cos(theta)**51 - 1.58525827229946e+47*cos(theta)**49 + 2.33617008549394e+47*cos(theta)**47 - 2.75398022074041e+47*cos(theta)**45 + 2.64189963036144e+47*cos(theta)**43 - 2.08717004918318e+47*cos(theta)**41 + 1.36918355226417e+47*cos(theta)**39 - 7.49863275851995e+46*cos(theta)**37 + 3.43945552146989e+46*cos(theta)**35 - 1.32286750825765e+46*cos(theta)**33 + 4.26418830500635e+45*cos(theta)**31 - 1.14947684743649e+45*cos(theta)**29 + 2.58123672599124e+44*cos(theta)**27 - 4.80134653324285e+43*cos(theta)**25 + 7.34150846061598e+42*cos(theta)**23 - 9.13625991409662e+41*cos(theta)**21 + 9.13625991409662e+40*cos(theta)**19 - 7.22284070878651e+39*cos(theta)**17 + 4.42082059583693e+38*cos(theta)**15 - 2.03858657252032e+37*cos(theta)**13 + 6.83031583576396e+35*cos(theta)**11 - 1.58175735144008e+34*cos(theta)**9 + 2.3549737242284e+32*cos(theta)**7 - 2.01279805489607e+30*cos(theta)**5 + 8.07703874356368e+27*cos(theta)**3 - 9.60408887462982e+24*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl72_m_minus_12(theta, phi):
    return 2.40707435283517e-22*(1.0 - cos(theta)**2)**6*(2.30667047769107e+42*cos(theta)**60 - 2.85510961224698e+43*cos(theta)**58 + 1.67358020888094e+44*cos(theta)**56 - 6.18060796565145e+44*cos(theta)**54 + 1.61395072971665e+45*cos(theta)**52 - 3.17051654459892e+45*cos(theta)**50 + 4.86702101144572e+45*cos(theta)**48 - 5.98691352334871e+45*cos(theta)**46 + 6.00431734173054e+45*cos(theta)**44 - 4.9694524980552e+45*cos(theta)**42 + 3.42295888066042e+45*cos(theta)**40 - 1.97332441013683e+45*cos(theta)**38 + 9.55404311519414e+44*cos(theta)**36 - 3.89078678899309e+44*cos(theta)**34 + 1.33255884531448e+44*cos(theta)**32 - 3.83158949145498e+43*cos(theta)**30 + 9.21870259282586e+42*cos(theta)**28 - 1.84667174355494e+42*cos(theta)**26 + 3.05896185858999e+41*cos(theta)**24 - 4.15284541549846e+40*cos(theta)**22 + 4.56812995704831e+39*cos(theta)**20 - 4.01268928265917e+38*cos(theta)**18 + 2.76301287239808e+37*cos(theta)**16 - 1.45613326608594e+36*cos(theta)**14 + 5.69192986313664e+34*cos(theta)**12 - 1.58175735144008e+33*cos(theta)**10 + 2.9437171552855e+31*cos(theta)**8 - 3.35466342482678e+29*cos(theta)**6 + 2.01925968589092e+27*cos(theta)**4 - 4.80204443731491e+24*cos(theta)**2 + 1.88315468129997e+21)*sin(12*phi)

#@torch.jit.script
def Yl72_m_minus_11(theta, phi):
    return 1.72303486792792e-20*(1.0 - cos(theta)**2)**5.5*(3.7814270126083e+40*cos(theta)**61 - 4.83916883431692e+41*cos(theta)**59 + 2.93610562961569e+42*cos(theta)**57 - 1.12374690284572e+43*cos(theta)**55 + 3.04519005606915e+43*cos(theta)**53 - 6.21669910705671e+43*cos(theta)**51 + 9.93269594172595e+43*cos(theta)**49 - 1.27381138794653e+44*cos(theta)**47 + 1.33429274260679e+44*cos(theta)**45 - 1.1556866274547e+44*cos(theta)**43 + 8.34868019673273e+43*cos(theta)**41 - 5.05980617983802e+43*cos(theta)**39 + 2.58217381491734e+43*cos(theta)**37 - 1.11165336828374e+43*cos(theta)**35 + 4.03805710701359e+42*cos(theta)**33 - 1.23599661014677e+42*cos(theta)**31 + 3.1788629630434e+41*cos(theta)**29 - 6.83952497612941e+40*cos(theta)**27 + 1.223584743436e+40*cos(theta)**25 - 1.8055849632602e+39*cos(theta)**23 + 2.17529997954681e+38*cos(theta)**21 - 2.11194172771535e+37*cos(theta)**19 + 1.62530168964593e+36*cos(theta)**17 - 9.70755510723963e+34*cos(theta)**15 + 4.37840758702818e+33*cos(theta)**13 - 1.43796122858189e+32*cos(theta)**11 + 3.27079683920611e+30*cos(theta)**9 - 4.79237632118112e+28*cos(theta)**7 + 4.03851937178184e+26*cos(theta)**5 - 1.60068147910497e+24*cos(theta)**3 + 1.88315468129997e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl72_m_minus_10(theta, phi):
    return 1.23602984418932e-18*(1.0 - cos(theta)**2)**5*(6.09907582678759e+38*cos(theta)**62 - 8.0652813905282e+39*cos(theta)**60 + 5.0622510855443e+40*cos(theta)**58 - 2.00669089793878e+41*cos(theta)**56 + 5.63924084457249e+41*cos(theta)**54 - 1.19551905904937e+42*cos(theta)**52 + 1.98653918834519e+42*cos(theta)**50 - 2.65377372488861e+42*cos(theta)**48 + 2.90063639697128e+42*cos(theta)**46 - 2.62656051694249e+42*cos(theta)**44 + 1.98778099922208e+42*cos(theta)**42 - 1.2649515449595e+42*cos(theta)**40 + 6.79519424978246e+41*cos(theta)**38 - 3.08792602301039e+41*cos(theta)**36 + 1.187663855004e+41*cos(theta)**34 - 3.86248940670865e+40*cos(theta)**32 + 1.05962098768113e+40*cos(theta)**30 - 2.44268749147479e+39*cos(theta)**28 + 4.70609516706152e+38*cos(theta)**26 - 7.52327068025084e+37*cos(theta)**24 + 9.88772717975824e+36*cos(theta)**22 - 1.05597086385768e+36*cos(theta)**20 + 9.02945383136627e+34*cos(theta)**18 - 6.06722194202477e+33*cos(theta)**16 + 3.12743399073442e+32*cos(theta)**14 - 1.19830102381824e+31*cos(theta)**12 + 3.27079683920611e+29*cos(theta)**10 - 5.9904704014764e+27*cos(theta)**8 + 6.7308656196364e+25*cos(theta)**6 - 4.00170369776243e+23*cos(theta)**4 + 9.41577340649983e+20*cos(theta)**2 - 3.65945332549546e+17)*sin(10*phi)

#@torch.jit.script
def Yl72_m_minus_9(theta, phi):
    return 8.88395106999359e-17*(1.0 - cos(theta)**2)**4.5*(9.68107274093268e+36*cos(theta)**63 - 1.32217727713577e+38*cos(theta)**61 + 8.5800865856683e+38*cos(theta)**59 - 3.52051034726102e+39*cos(theta)**57 + 1.025316517195e+40*cos(theta)**55 - 2.255696337829e+40*cos(theta)**53 + 3.89517487910822e+40*cos(theta)**51 - 5.41586474467064e+40*cos(theta)**49 + 6.17156680206654e+40*cos(theta)**47 - 5.8368011487611e+40*cos(theta)**45 + 4.62274650981879e+40*cos(theta)**43 - 3.08524767063294e+40*cos(theta)**41 + 1.74235749994422e+40*cos(theta)**39 - 8.34574600813619e+39*cos(theta)**37 + 3.39332530001142e+39*cos(theta)**35 - 1.17045133536626e+39*cos(theta)**33 + 3.41813221832624e+38*cos(theta)**31 - 8.42306031543031e+37*cos(theta)**29 + 1.74299821002279e+37*cos(theta)**27 - 3.00930827210033e+36*cos(theta)**25 + 4.29901181728619e+35*cos(theta)**23 - 5.02843268503655e+34*cos(theta)**21 + 4.75234412177172e+33*cos(theta)**19 - 3.56895408354398e+32*cos(theta)**17 + 2.08495599382294e+31*cos(theta)**15 - 9.21770018321723e+29*cos(theta)**13 + 2.97345167200556e+28*cos(theta)**11 - 6.65607822386266e+26*cos(theta)**9 + 9.61552231376629e+24*cos(theta)**7 - 8.00340739552485e+22*cos(theta)**5 + 3.13859113549994e+20*cos(theta)**3 - 3.65945332549546e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl72_m_minus_8(theta, phi):
    return 6.39644477039539e-15*(1.0 - cos(theta)**2)**4*(1.51266761577073e+35*cos(theta)**64 - 2.13254399538028e+36*cos(theta)**62 + 1.43001443094472e+37*cos(theta)**60 - 6.06984542631211e+37*cos(theta)**58 + 1.83092235213393e+38*cos(theta)**56 - 4.17721544042407e+38*cos(theta)**54 + 7.49072092136196e+38*cos(theta)**52 - 1.08317294893413e+39*cos(theta)**50 + 1.28574308376386e+39*cos(theta)**48 - 1.26886981494806e+39*cos(theta)**46 + 1.050624206777e+39*cos(theta)**44 - 7.34582778722128e+38*cos(theta)**42 + 4.35589374986055e+38*cos(theta)**40 - 2.19624894950952e+38*cos(theta)**38 + 9.42590361114282e+37*cos(theta)**36 - 3.44250392754781e+37*cos(theta)**34 + 1.06816631822695e+37*cos(theta)**32 - 2.8076867718101e+36*cos(theta)**30 + 6.22499360722424e+35*cos(theta)**28 - 1.15742625850013e+35*cos(theta)**26 + 1.79125492386925e+34*cos(theta)**24 - 2.28565122047116e+33*cos(theta)**22 + 2.37617206088586e+32*cos(theta)**20 - 1.98275226863554e+31*cos(theta)**18 + 1.30309749613934e+30*cos(theta)**16 - 6.58407155944088e+28*cos(theta)**14 + 2.47787639333796e+27*cos(theta)**12 - 6.65607822386266e+25*cos(theta)**10 + 1.20194028922079e+24*cos(theta)**8 - 1.33390123258748e+22*cos(theta)**6 + 7.84647783874985e+19*cos(theta)**4 - 1.82972666274773e+17*cos(theta)**2 + 70591306433168.6)*sin(8*phi)

#@torch.jit.script
def Yl72_m_minus_7(theta, phi):
    return 4.61254192006681e-13*(1.0 - cos(theta)**2)**3.5*(2.32718094733959e+33*cos(theta)**65 - 3.38499046885758e+34*cos(theta)**63 + 2.34428595236839e+35*cos(theta)**61 - 1.02878736039188e+36*cos(theta)**59 + 3.21214447742794e+36*cos(theta)**57 - 7.5949371644074e+36*cos(theta)**55 + 1.41334357006829e+37*cos(theta)**53 - 2.12386852732182e+37*cos(theta)**51 + 2.62396547706911e+37*cos(theta)**49 - 2.6997230105278e+37*cos(theta)**47 + 2.33472045950444e+37*cos(theta)**45 - 1.70833204353983e+37*cos(theta)**43 + 1.06241310972209e+37*cos(theta)**41 - 5.63140756284493e+36*cos(theta)**39 + 2.54754151652509e+36*cos(theta)**37 - 9.83572550727947e+35*cos(theta)**35 + 3.23686763099075e+35*cos(theta)**33 - 9.05705410261324e+34*cos(theta)**31 + 2.1465495197325e+34*cos(theta)**29 - 4.28676392037085e+33*cos(theta)**27 + 7.16501969547699e+32*cos(theta)**25 - 9.93761400204853e+31*cos(theta)**23 + 1.13151050518374e+31*cos(theta)**21 - 1.04355382559766e+30*cos(theta)**19 + 7.66527938905494e+28*cos(theta)**17 - 4.38938103962725e+27*cos(theta)**15 + 1.90605876410613e+26*cos(theta)**13 - 6.05098020351151e+24*cos(theta)**11 + 1.33548921024532e+23*cos(theta)**9 - 1.90557318941068e+21*cos(theta)**7 + 1.56929556774997e+19*cos(theta)**5 - 6.09908887582577e+16*cos(theta)**3 + 70591306433168.6*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl72_m_minus_6(theta, phi):
    return 3.33062578228543e-11*(1.0 - cos(theta)**2)**3*(3.52603173839331e+31*cos(theta)**66 - 5.28904760758997e+32*cos(theta)**64 + 3.78110637478772e+33*cos(theta)**62 - 1.71464560065314e+34*cos(theta)**60 + 5.53818013349645e+34*cos(theta)**58 - 1.35623877935846e+35*cos(theta)**56 + 2.61730290753388e+35*cos(theta)**54 - 4.08436255254196e+35*cos(theta)**52 + 5.24793095413822e+35*cos(theta)**50 - 5.62442293859958e+35*cos(theta)**48 + 5.07547925979226e+35*cos(theta)**46 - 3.88257282622689e+35*cos(theta)**44 + 2.52955502314782e+35*cos(theta)**42 - 1.40785189071123e+35*cos(theta)**40 + 6.70405662243444e+34*cos(theta)**38 - 2.7321459742443e+34*cos(theta)**36 + 9.52019891467869e+33*cos(theta)**34 - 2.83032940706664e+33*cos(theta)**32 + 7.15516506577499e+32*cos(theta)**30 - 1.53098711441816e+32*cos(theta)**28 + 2.75577680595269e+31*cos(theta)**26 - 4.14067250085355e+30*cos(theta)**24 + 5.14322956901701e+29*cos(theta)**22 - 5.21776912798827e+28*cos(theta)**20 + 4.25848854947497e+27*cos(theta)**18 - 2.74336314976703e+26*cos(theta)**16 + 1.36147054579009e+25*cos(theta)**14 - 5.04248350292626e+23*cos(theta)**12 + 1.33548921024532e+22*cos(theta)**10 - 2.38196648676335e+20*cos(theta)**8 + 2.61549261291662e+18*cos(theta)**6 - 1.52477221895644e+16*cos(theta)**4 + 35295653216584.3*cos(theta)**2 - 13538800620.0937)*sin(6*phi)

#@torch.jit.script
def Yl72_m_minus_5(theta, phi):
    return 2.40774529174265e-9*(1.0 - cos(theta)**2)**2.5*(5.26273393790047e+29*cos(theta)**67 - 8.13699631936918e+30*cos(theta)**65 + 6.0017561504567e+31*cos(theta)**63 - 2.81089442730023e+32*cos(theta)**61 + 9.38674598897703e+32*cos(theta)**59 - 2.37936627957625e+33*cos(theta)**57 + 4.7587325591525e+33*cos(theta)**55 - 7.70634443875842e+33*cos(theta)**53 + 1.02900606943887e+34*cos(theta)**51 - 1.14784141604073e+34*cos(theta)**49 + 1.07988920421112e+34*cos(theta)**47 - 8.62793961383754e+33*cos(theta)**45 + 5.88268610034378e+33*cos(theta)**43 - 3.43378509929569e+33*cos(theta)**41 + 1.71898887754729e+33*cos(theta)**39 - 7.38417830876837e+32*cos(theta)**37 + 2.72005683276534e+32*cos(theta)**35 - 8.57675577898981e+31*cos(theta)**33 + 2.30811776315322e+31*cos(theta)**31 - 5.27926591178676e+30*cos(theta)**29 + 1.02065807627877e+30*cos(theta)**27 - 1.65626900034142e+29*cos(theta)**25 + 2.23618676913783e+28*cos(theta)**23 - 2.4846519657087e+27*cos(theta)**21 + 2.24130976288156e+26*cos(theta)**19 - 1.61374302927472e+25*cos(theta)**17 + 9.07647030526727e+23*cos(theta)**15 - 3.87883346378943e+22*cos(theta)**13 + 1.21408110022302e+21*cos(theta)**11 - 2.64662942973705e+19*cos(theta)**9 + 3.73641801845231e+17*cos(theta)**7 - 3.04954443791289e+15*cos(theta)**5 + 11765217738861.4*cos(theta)**3 - 13538800620.0937*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl72_m_minus_4(theta, phi):
    return 1.74224955082683e-7*(1.0 - cos(theta)**2)**2*(7.73931461455951e+27*cos(theta)**68 - 1.23287823020745e+29*cos(theta)**66 + 9.3777439850886e+29*cos(theta)**64 - 4.53370068919391e+30*cos(theta)**62 + 1.56445766482951e+31*cos(theta)**60 - 4.10235565444181e+31*cos(theta)**58 + 8.49773671277233e+31*cos(theta)**56 - 1.4271008219923e+32*cos(theta)**54 + 1.97885782584397e+32*cos(theta)**52 - 2.29568283208146e+32*cos(theta)**50 + 2.24976917543983e+32*cos(theta)**48 - 1.87563904648642e+32*cos(theta)**46 + 1.33697411371449e+32*cos(theta)**44 - 8.17567880784688e+31*cos(theta)**42 + 4.29747219386823e+31*cos(theta)**40 - 1.94320481809694e+31*cos(theta)**38 + 7.55571342434817e+30*cos(theta)**36 - 2.52257522911465e+30*cos(theta)**34 + 7.21286800985382e+29*cos(theta)**32 - 1.75975530392892e+29*cos(theta)**30 + 3.64520741528133e+28*cos(theta)**28 - 6.37026538592854e+27*cos(theta)**26 + 9.31744487140763e+26*cos(theta)**24 - 1.12938725714032e+26*cos(theta)**22 + 1.12065488144078e+25*cos(theta)**20 - 8.96523905152625e+23*cos(theta)**18 + 5.67279394079204e+22*cos(theta)**16 - 2.77059533127816e+21*cos(theta)**14 + 1.01173425018585e+20*cos(theta)**12 - 2.64662942973705e+18*cos(theta)**10 + 4.67052252306539e+16*cos(theta)**8 - 508257406318814.0*cos(theta)**6 + 2941304434715.36*cos(theta)**4 - 6769400310.04686*cos(theta)**2 + 2585714.40414319)*sin(4*phi)

#@torch.jit.script
def Yl72_m_minus_3(theta, phi):
    return 1.2616581652784e-5*(1.0 - cos(theta)**2)**1.5*(1.12163979921152e+26*cos(theta)**69 - 1.84011676150366e+27*cos(theta)**67 + 1.44272984385978e+28*cos(theta)**65 - 7.1963503003078e+28*cos(theta)**63 + 2.56468469644181e+29*cos(theta)**61 - 6.95314517702002e+29*cos(theta)**59 + 1.49083100224076e+30*cos(theta)**57 - 2.59472876725873e+30*cos(theta)**55 + 3.73369401102636e+30*cos(theta)**53 - 4.50133888643424e+30*cos(theta)**51 + 4.59136566416292e+30*cos(theta)**49 - 3.99072137550303e+30*cos(theta)**47 + 2.97105358603221e+30*cos(theta)**45 - 1.90132065298765e+30*cos(theta)**43 + 1.04816394972396e+30*cos(theta)**41 - 4.98257645665882e+29*cos(theta)**39 + 2.04208470928329e+29*cos(theta)**37 - 7.20735779747043e+28*cos(theta)**35 + 2.18571757874358e+28*cos(theta)**33 - 5.67663001267393e+27*cos(theta)**31 + 1.25696807423494e+27*cos(theta)**29 - 2.3593575503439e+26*cos(theta)**27 + 3.72697794856305e+25*cos(theta)**25 - 4.91037937887095e+24*cos(theta)**23 + 5.33645181638467e+23*cos(theta)**21 - 4.71854686922434e+22*cos(theta)**19 + 3.33693761223061e+21*cos(theta)**17 - 1.84706355418544e+20*cos(theta)**15 + 7.78257115527574e+18*cos(theta)**13 - 2.40602675430641e+17*cos(theta)**11 + 5.18946947007266e+15*cos(theta)**9 - 72608200902687.8*cos(theta)**7 + 588260886943.072*cos(theta)**5 - 2256466770.01562*cos(theta)**3 + 2585714.40414319*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl72_m_minus_2(theta, phi):
    return 0.000914158189897769*(1.0 - cos(theta)**2)*(1.60234257030218e+24*cos(theta)**70 - 2.70605406103479e+25*cos(theta)**68 + 2.18595430887846e+26*cos(theta)**66 - 1.12442973442309e+27*cos(theta)**64 + 4.13658822006744e+27*cos(theta)**62 - 1.15885752950334e+28*cos(theta)**60 + 2.57039827972545e+28*cos(theta)**58 - 4.63344422724773e+28*cos(theta)**56 + 6.91424816856734e+28*cos(theta)**54 - 8.65642093545045e+28*cos(theta)**52 + 9.18273132832584e+28*cos(theta)**50 - 8.3140028656313e+28*cos(theta)**48 + 6.45881214354829e+28*cos(theta)**46 - 4.32118330224465e+28*cos(theta)**44 + 2.49562845172371e+28*cos(theta)**42 - 1.2456441141647e+28*cos(theta)**40 + 5.37390712969286e+27*cos(theta)**38 - 2.00204383263067e+27*cos(theta)**36 + 6.42858111395171e+26*cos(theta)**34 - 1.7739468789606e+26*cos(theta)**32 + 4.18989358078314e+25*cos(theta)**30 - 8.42627696551395e+24*cos(theta)**28 + 1.43345305713964e+24*cos(theta)**26 - 2.0459914078629e+23*cos(theta)**24 + 2.42565991653849e+22*cos(theta)**22 - 2.35927343461217e+21*cos(theta)**20 + 1.85385422901701e+20*cos(theta)**18 - 1.1544147213659e+19*cos(theta)**16 + 5.55897939662553e+17*cos(theta)**14 - 2.00502229525534e+16*cos(theta)**12 + 518946947007266.0*cos(theta)**10 - 9076025112835.97*cos(theta)**8 + 98043481157.1787*cos(theta)**6 - 564116692.503905*cos(theta)**4 + 1292857.20207159*cos(theta)**2 - 492.517029360607)*sin(2*phi)

#@torch.jit.script
def Yl72_m_minus_1(theta, phi):
    return 0.0662622820359346*(1.0 - cos(theta)**2)**0.5*(2.25682052155236e+22*cos(theta)**71 - 3.92181747976057e+23*cos(theta)**69 + 3.26261837146039e+24*cos(theta)**67 - 1.72989189911245e+25*cos(theta)**65 + 6.56601304772609e+25*cos(theta)**63 - 1.89976644180875e+26*cos(theta)**61 + 4.35660725377194e+26*cos(theta)**59 - 8.12884952148724e+26*cos(theta)**57 + 1.25713603064861e+27*cos(theta)**55 - 1.63328696895292e+27*cos(theta)**53 + 1.80053555457369e+27*cos(theta)**51 - 1.69673527870027e+27*cos(theta)**49 + 1.37421534969112e+27*cos(theta)**47 - 9.60262956054367e+26*cos(theta)**45 + 5.80378709703189e+26*cos(theta)**43 - 3.03815637601148e+26*cos(theta)**41 + 1.37792490504945e+26*cos(theta)**39 - 5.4109292773802e+25*cos(theta)**37 + 1.83673746112906e+25*cos(theta)**35 - 5.37559660291092e+24*cos(theta)**33 + 1.35157857444617e+24*cos(theta)**31 - 2.90561274672895e+23*cos(theta)**29 + 5.30908539681347e+22*cos(theta)**27 - 8.18396563145159e+21*cos(theta)**25 + 1.05463474632108e+21*cos(theta)**23 - 1.12346354029151e+20*cos(theta)**21 + 9.75712752114214e+18*cos(theta)**19 - 6.79067483156413e+17*cos(theta)**17 + 3.70598626441702e+16*cos(theta)**15 - 1.54232484250411e+15*cos(theta)**13 + 47176995182478.7*cos(theta)**11 - 1008447234759.55*cos(theta)**9 + 14006211593.8827*cos(theta)**7 - 112823338.500781*cos(theta)**5 + 430952.400690531*cos(theta)**3 - 492.517029360607*cos(theta))*sin(phi)

#@torch.jit.script
def Yl72_m0(theta, phi):
    return 3.34497955490531e+21*cos(theta)**72 - 5.9788585610755e+22*cos(theta)**70 + 5.12019270389977e+23*cos(theta)**68 - 2.79707409579944e+24*cos(theta)**66 + 1.09484013421347e+25*cos(theta)**64 - 3.26992253418422e+25*cos(theta)**62 + 7.74865101772226e+25*cos(theta)**60 - 1.49565019644148e+26*cos(theta)**58 + 2.39564900650947e+26*cos(theta)**56 - 3.22773356957531e+26*cos(theta)**54 + 3.69510939044982e+26*cos(theta)**52 - 3.62137106558496e+26*cos(theta)**50 + 3.05522007943635e+26*cos(theta)**48 - 2.2277234968353e+26*cos(theta)**46 + 1.40762748426406e+26*cos(theta)**44 - 7.7195107252974e+25*cos(theta)**42 + 3.67616080446961e+25*cos(theta)**40 - 1.51955772521796e+25*cos(theta)**38 + 5.44469460157099e+24*cos(theta)**36 - 1.68723935021629e+24*cos(theta)**34 + 4.50733940700639e+23*cos(theta)**32 - 1.033583146498e+23*cos(theta)**30 + 2.02344135340517e+22*cos(theta)**28 - 3.3590726024908e+21*cos(theta)**26 + 4.68942695794462e+20*cos(theta)**24 - 5.44960774902196e+19*cos(theta)**22 + 5.2062009512989e+18*cos(theta)**20 - 4.02595922159866e+17*cos(theta)**18 + 2.47179679335712e+16*cos(theta)**16 - 1.17564651289281e+15*cos(theta)**14 + 41954444185586.4*cos(theta)**12 - 1076173072774.47*cos(theta)**10 + 18683560291.2234*cos(theta)**8 - 200667314.21337*cos(theta)**6 + 1149736.33048149*cos(theta)**4 - 2627.96875538626*cos(theta)**2 + 0.999988110877574

#@torch.jit.script
def Yl72_m1(theta, phi):
    return 0.0662622820359346*(1.0 - cos(theta)**2)**0.5*(2.25682052155236e+22*cos(theta)**71 - 3.92181747976057e+23*cos(theta)**69 + 3.26261837146039e+24*cos(theta)**67 - 1.72989189911245e+25*cos(theta)**65 + 6.56601304772609e+25*cos(theta)**63 - 1.89976644180875e+26*cos(theta)**61 + 4.35660725377194e+26*cos(theta)**59 - 8.12884952148724e+26*cos(theta)**57 + 1.25713603064861e+27*cos(theta)**55 - 1.63328696895292e+27*cos(theta)**53 + 1.80053555457369e+27*cos(theta)**51 - 1.69673527870027e+27*cos(theta)**49 + 1.37421534969112e+27*cos(theta)**47 - 9.60262956054367e+26*cos(theta)**45 + 5.80378709703189e+26*cos(theta)**43 - 3.03815637601148e+26*cos(theta)**41 + 1.37792490504945e+26*cos(theta)**39 - 5.4109292773802e+25*cos(theta)**37 + 1.83673746112906e+25*cos(theta)**35 - 5.37559660291092e+24*cos(theta)**33 + 1.35157857444617e+24*cos(theta)**31 - 2.90561274672895e+23*cos(theta)**29 + 5.30908539681347e+22*cos(theta)**27 - 8.18396563145159e+21*cos(theta)**25 + 1.05463474632108e+21*cos(theta)**23 - 1.12346354029151e+20*cos(theta)**21 + 9.75712752114214e+18*cos(theta)**19 - 6.79067483156413e+17*cos(theta)**17 + 3.70598626441702e+16*cos(theta)**15 - 1.54232484250411e+15*cos(theta)**13 + 47176995182478.7*cos(theta)**11 - 1008447234759.55*cos(theta)**9 + 14006211593.8827*cos(theta)**7 - 112823338.500781*cos(theta)**5 + 430952.400690531*cos(theta)**3 - 492.517029360607*cos(theta))*cos(phi)

#@torch.jit.script
def Yl72_m2(theta, phi):
    return 0.000914158189897769*(1.0 - cos(theta)**2)*(1.60234257030218e+24*cos(theta)**70 - 2.70605406103479e+25*cos(theta)**68 + 2.18595430887846e+26*cos(theta)**66 - 1.12442973442309e+27*cos(theta)**64 + 4.13658822006744e+27*cos(theta)**62 - 1.15885752950334e+28*cos(theta)**60 + 2.57039827972545e+28*cos(theta)**58 - 4.63344422724773e+28*cos(theta)**56 + 6.91424816856734e+28*cos(theta)**54 - 8.65642093545045e+28*cos(theta)**52 + 9.18273132832584e+28*cos(theta)**50 - 8.3140028656313e+28*cos(theta)**48 + 6.45881214354829e+28*cos(theta)**46 - 4.32118330224465e+28*cos(theta)**44 + 2.49562845172371e+28*cos(theta)**42 - 1.2456441141647e+28*cos(theta)**40 + 5.37390712969286e+27*cos(theta)**38 - 2.00204383263067e+27*cos(theta)**36 + 6.42858111395171e+26*cos(theta)**34 - 1.7739468789606e+26*cos(theta)**32 + 4.18989358078314e+25*cos(theta)**30 - 8.42627696551395e+24*cos(theta)**28 + 1.43345305713964e+24*cos(theta)**26 - 2.0459914078629e+23*cos(theta)**24 + 2.42565991653849e+22*cos(theta)**22 - 2.35927343461217e+21*cos(theta)**20 + 1.85385422901701e+20*cos(theta)**18 - 1.1544147213659e+19*cos(theta)**16 + 5.55897939662553e+17*cos(theta)**14 - 2.00502229525534e+16*cos(theta)**12 + 518946947007266.0*cos(theta)**10 - 9076025112835.97*cos(theta)**8 + 98043481157.1787*cos(theta)**6 - 564116692.503905*cos(theta)**4 + 1292857.20207159*cos(theta)**2 - 492.517029360607)*cos(2*phi)

#@torch.jit.script
def Yl72_m3(theta, phi):
    return 1.2616581652784e-5*(1.0 - cos(theta)**2)**1.5*(1.12163979921152e+26*cos(theta)**69 - 1.84011676150366e+27*cos(theta)**67 + 1.44272984385978e+28*cos(theta)**65 - 7.1963503003078e+28*cos(theta)**63 + 2.56468469644181e+29*cos(theta)**61 - 6.95314517702002e+29*cos(theta)**59 + 1.49083100224076e+30*cos(theta)**57 - 2.59472876725873e+30*cos(theta)**55 + 3.73369401102636e+30*cos(theta)**53 - 4.50133888643424e+30*cos(theta)**51 + 4.59136566416292e+30*cos(theta)**49 - 3.99072137550303e+30*cos(theta)**47 + 2.97105358603221e+30*cos(theta)**45 - 1.90132065298765e+30*cos(theta)**43 + 1.04816394972396e+30*cos(theta)**41 - 4.98257645665882e+29*cos(theta)**39 + 2.04208470928329e+29*cos(theta)**37 - 7.20735779747043e+28*cos(theta)**35 + 2.18571757874358e+28*cos(theta)**33 - 5.67663001267393e+27*cos(theta)**31 + 1.25696807423494e+27*cos(theta)**29 - 2.3593575503439e+26*cos(theta)**27 + 3.72697794856305e+25*cos(theta)**25 - 4.91037937887095e+24*cos(theta)**23 + 5.33645181638467e+23*cos(theta)**21 - 4.71854686922434e+22*cos(theta)**19 + 3.33693761223061e+21*cos(theta)**17 - 1.84706355418544e+20*cos(theta)**15 + 7.78257115527574e+18*cos(theta)**13 - 2.40602675430641e+17*cos(theta)**11 + 5.18946947007266e+15*cos(theta)**9 - 72608200902687.8*cos(theta)**7 + 588260886943.072*cos(theta)**5 - 2256466770.01562*cos(theta)**3 + 2585714.40414319*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl72_m4(theta, phi):
    return 1.74224955082683e-7*(1.0 - cos(theta)**2)**2*(7.73931461455951e+27*cos(theta)**68 - 1.23287823020745e+29*cos(theta)**66 + 9.3777439850886e+29*cos(theta)**64 - 4.53370068919391e+30*cos(theta)**62 + 1.56445766482951e+31*cos(theta)**60 - 4.10235565444181e+31*cos(theta)**58 + 8.49773671277233e+31*cos(theta)**56 - 1.4271008219923e+32*cos(theta)**54 + 1.97885782584397e+32*cos(theta)**52 - 2.29568283208146e+32*cos(theta)**50 + 2.24976917543983e+32*cos(theta)**48 - 1.87563904648642e+32*cos(theta)**46 + 1.33697411371449e+32*cos(theta)**44 - 8.17567880784688e+31*cos(theta)**42 + 4.29747219386823e+31*cos(theta)**40 - 1.94320481809694e+31*cos(theta)**38 + 7.55571342434817e+30*cos(theta)**36 - 2.52257522911465e+30*cos(theta)**34 + 7.21286800985382e+29*cos(theta)**32 - 1.75975530392892e+29*cos(theta)**30 + 3.64520741528133e+28*cos(theta)**28 - 6.37026538592854e+27*cos(theta)**26 + 9.31744487140763e+26*cos(theta)**24 - 1.12938725714032e+26*cos(theta)**22 + 1.12065488144078e+25*cos(theta)**20 - 8.96523905152625e+23*cos(theta)**18 + 5.67279394079204e+22*cos(theta)**16 - 2.77059533127816e+21*cos(theta)**14 + 1.01173425018585e+20*cos(theta)**12 - 2.64662942973705e+18*cos(theta)**10 + 4.67052252306539e+16*cos(theta)**8 - 508257406318814.0*cos(theta)**6 + 2941304434715.36*cos(theta)**4 - 6769400310.04686*cos(theta)**2 + 2585714.40414319)*cos(4*phi)

#@torch.jit.script
def Yl72_m5(theta, phi):
    return 2.40774529174265e-9*(1.0 - cos(theta)**2)**2.5*(5.26273393790047e+29*cos(theta)**67 - 8.13699631936918e+30*cos(theta)**65 + 6.0017561504567e+31*cos(theta)**63 - 2.81089442730023e+32*cos(theta)**61 + 9.38674598897703e+32*cos(theta)**59 - 2.37936627957625e+33*cos(theta)**57 + 4.7587325591525e+33*cos(theta)**55 - 7.70634443875842e+33*cos(theta)**53 + 1.02900606943887e+34*cos(theta)**51 - 1.14784141604073e+34*cos(theta)**49 + 1.07988920421112e+34*cos(theta)**47 - 8.62793961383754e+33*cos(theta)**45 + 5.88268610034378e+33*cos(theta)**43 - 3.43378509929569e+33*cos(theta)**41 + 1.71898887754729e+33*cos(theta)**39 - 7.38417830876837e+32*cos(theta)**37 + 2.72005683276534e+32*cos(theta)**35 - 8.57675577898981e+31*cos(theta)**33 + 2.30811776315322e+31*cos(theta)**31 - 5.27926591178676e+30*cos(theta)**29 + 1.02065807627877e+30*cos(theta)**27 - 1.65626900034142e+29*cos(theta)**25 + 2.23618676913783e+28*cos(theta)**23 - 2.4846519657087e+27*cos(theta)**21 + 2.24130976288156e+26*cos(theta)**19 - 1.61374302927472e+25*cos(theta)**17 + 9.07647030526727e+23*cos(theta)**15 - 3.87883346378943e+22*cos(theta)**13 + 1.21408110022302e+21*cos(theta)**11 - 2.64662942973705e+19*cos(theta)**9 + 3.73641801845231e+17*cos(theta)**7 - 3.04954443791289e+15*cos(theta)**5 + 11765217738861.4*cos(theta)**3 - 13538800620.0937*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl72_m6(theta, phi):
    return 3.33062578228543e-11*(1.0 - cos(theta)**2)**3*(3.52603173839331e+31*cos(theta)**66 - 5.28904760758997e+32*cos(theta)**64 + 3.78110637478772e+33*cos(theta)**62 - 1.71464560065314e+34*cos(theta)**60 + 5.53818013349645e+34*cos(theta)**58 - 1.35623877935846e+35*cos(theta)**56 + 2.61730290753388e+35*cos(theta)**54 - 4.08436255254196e+35*cos(theta)**52 + 5.24793095413822e+35*cos(theta)**50 - 5.62442293859958e+35*cos(theta)**48 + 5.07547925979226e+35*cos(theta)**46 - 3.88257282622689e+35*cos(theta)**44 + 2.52955502314782e+35*cos(theta)**42 - 1.40785189071123e+35*cos(theta)**40 + 6.70405662243444e+34*cos(theta)**38 - 2.7321459742443e+34*cos(theta)**36 + 9.52019891467869e+33*cos(theta)**34 - 2.83032940706664e+33*cos(theta)**32 + 7.15516506577499e+32*cos(theta)**30 - 1.53098711441816e+32*cos(theta)**28 + 2.75577680595269e+31*cos(theta)**26 - 4.14067250085355e+30*cos(theta)**24 + 5.14322956901701e+29*cos(theta)**22 - 5.21776912798827e+28*cos(theta)**20 + 4.25848854947497e+27*cos(theta)**18 - 2.74336314976703e+26*cos(theta)**16 + 1.36147054579009e+25*cos(theta)**14 - 5.04248350292626e+23*cos(theta)**12 + 1.33548921024532e+22*cos(theta)**10 - 2.38196648676335e+20*cos(theta)**8 + 2.61549261291662e+18*cos(theta)**6 - 1.52477221895644e+16*cos(theta)**4 + 35295653216584.3*cos(theta)**2 - 13538800620.0937)*cos(6*phi)

#@torch.jit.script
def Yl72_m7(theta, phi):
    return 4.61254192006681e-13*(1.0 - cos(theta)**2)**3.5*(2.32718094733959e+33*cos(theta)**65 - 3.38499046885758e+34*cos(theta)**63 + 2.34428595236839e+35*cos(theta)**61 - 1.02878736039188e+36*cos(theta)**59 + 3.21214447742794e+36*cos(theta)**57 - 7.5949371644074e+36*cos(theta)**55 + 1.41334357006829e+37*cos(theta)**53 - 2.12386852732182e+37*cos(theta)**51 + 2.62396547706911e+37*cos(theta)**49 - 2.6997230105278e+37*cos(theta)**47 + 2.33472045950444e+37*cos(theta)**45 - 1.70833204353983e+37*cos(theta)**43 + 1.06241310972209e+37*cos(theta)**41 - 5.63140756284493e+36*cos(theta)**39 + 2.54754151652509e+36*cos(theta)**37 - 9.83572550727947e+35*cos(theta)**35 + 3.23686763099075e+35*cos(theta)**33 - 9.05705410261324e+34*cos(theta)**31 + 2.1465495197325e+34*cos(theta)**29 - 4.28676392037085e+33*cos(theta)**27 + 7.16501969547699e+32*cos(theta)**25 - 9.93761400204853e+31*cos(theta)**23 + 1.13151050518374e+31*cos(theta)**21 - 1.04355382559766e+30*cos(theta)**19 + 7.66527938905494e+28*cos(theta)**17 - 4.38938103962725e+27*cos(theta)**15 + 1.90605876410613e+26*cos(theta)**13 - 6.05098020351151e+24*cos(theta)**11 + 1.33548921024532e+23*cos(theta)**9 - 1.90557318941068e+21*cos(theta)**7 + 1.56929556774997e+19*cos(theta)**5 - 6.09908887582577e+16*cos(theta)**3 + 70591306433168.6*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl72_m8(theta, phi):
    return 6.39644477039539e-15*(1.0 - cos(theta)**2)**4*(1.51266761577073e+35*cos(theta)**64 - 2.13254399538028e+36*cos(theta)**62 + 1.43001443094472e+37*cos(theta)**60 - 6.06984542631211e+37*cos(theta)**58 + 1.83092235213393e+38*cos(theta)**56 - 4.17721544042407e+38*cos(theta)**54 + 7.49072092136196e+38*cos(theta)**52 - 1.08317294893413e+39*cos(theta)**50 + 1.28574308376386e+39*cos(theta)**48 - 1.26886981494806e+39*cos(theta)**46 + 1.050624206777e+39*cos(theta)**44 - 7.34582778722128e+38*cos(theta)**42 + 4.35589374986055e+38*cos(theta)**40 - 2.19624894950952e+38*cos(theta)**38 + 9.42590361114282e+37*cos(theta)**36 - 3.44250392754781e+37*cos(theta)**34 + 1.06816631822695e+37*cos(theta)**32 - 2.8076867718101e+36*cos(theta)**30 + 6.22499360722424e+35*cos(theta)**28 - 1.15742625850013e+35*cos(theta)**26 + 1.79125492386925e+34*cos(theta)**24 - 2.28565122047116e+33*cos(theta)**22 + 2.37617206088586e+32*cos(theta)**20 - 1.98275226863554e+31*cos(theta)**18 + 1.30309749613934e+30*cos(theta)**16 - 6.58407155944088e+28*cos(theta)**14 + 2.47787639333796e+27*cos(theta)**12 - 6.65607822386266e+25*cos(theta)**10 + 1.20194028922079e+24*cos(theta)**8 - 1.33390123258748e+22*cos(theta)**6 + 7.84647783874985e+19*cos(theta)**4 - 1.82972666274773e+17*cos(theta)**2 + 70591306433168.6)*cos(8*phi)

#@torch.jit.script
def Yl72_m9(theta, phi):
    return 8.88395106999359e-17*(1.0 - cos(theta)**2)**4.5*(9.68107274093268e+36*cos(theta)**63 - 1.32217727713577e+38*cos(theta)**61 + 8.5800865856683e+38*cos(theta)**59 - 3.52051034726102e+39*cos(theta)**57 + 1.025316517195e+40*cos(theta)**55 - 2.255696337829e+40*cos(theta)**53 + 3.89517487910822e+40*cos(theta)**51 - 5.41586474467064e+40*cos(theta)**49 + 6.17156680206654e+40*cos(theta)**47 - 5.8368011487611e+40*cos(theta)**45 + 4.62274650981879e+40*cos(theta)**43 - 3.08524767063294e+40*cos(theta)**41 + 1.74235749994422e+40*cos(theta)**39 - 8.34574600813619e+39*cos(theta)**37 + 3.39332530001142e+39*cos(theta)**35 - 1.17045133536626e+39*cos(theta)**33 + 3.41813221832624e+38*cos(theta)**31 - 8.42306031543031e+37*cos(theta)**29 + 1.74299821002279e+37*cos(theta)**27 - 3.00930827210033e+36*cos(theta)**25 + 4.29901181728619e+35*cos(theta)**23 - 5.02843268503655e+34*cos(theta)**21 + 4.75234412177172e+33*cos(theta)**19 - 3.56895408354398e+32*cos(theta)**17 + 2.08495599382294e+31*cos(theta)**15 - 9.21770018321723e+29*cos(theta)**13 + 2.97345167200556e+28*cos(theta)**11 - 6.65607822386266e+26*cos(theta)**9 + 9.61552231376629e+24*cos(theta)**7 - 8.00340739552485e+22*cos(theta)**5 + 3.13859113549994e+20*cos(theta)**3 - 3.65945332549546e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl72_m10(theta, phi):
    return 1.23602984418932e-18*(1.0 - cos(theta)**2)**5*(6.09907582678759e+38*cos(theta)**62 - 8.0652813905282e+39*cos(theta)**60 + 5.0622510855443e+40*cos(theta)**58 - 2.00669089793878e+41*cos(theta)**56 + 5.63924084457249e+41*cos(theta)**54 - 1.19551905904937e+42*cos(theta)**52 + 1.98653918834519e+42*cos(theta)**50 - 2.65377372488861e+42*cos(theta)**48 + 2.90063639697128e+42*cos(theta)**46 - 2.62656051694249e+42*cos(theta)**44 + 1.98778099922208e+42*cos(theta)**42 - 1.2649515449595e+42*cos(theta)**40 + 6.79519424978246e+41*cos(theta)**38 - 3.08792602301039e+41*cos(theta)**36 + 1.187663855004e+41*cos(theta)**34 - 3.86248940670865e+40*cos(theta)**32 + 1.05962098768113e+40*cos(theta)**30 - 2.44268749147479e+39*cos(theta)**28 + 4.70609516706152e+38*cos(theta)**26 - 7.52327068025084e+37*cos(theta)**24 + 9.88772717975824e+36*cos(theta)**22 - 1.05597086385768e+36*cos(theta)**20 + 9.02945383136627e+34*cos(theta)**18 - 6.06722194202477e+33*cos(theta)**16 + 3.12743399073442e+32*cos(theta)**14 - 1.19830102381824e+31*cos(theta)**12 + 3.27079683920611e+29*cos(theta)**10 - 5.9904704014764e+27*cos(theta)**8 + 6.7308656196364e+25*cos(theta)**6 - 4.00170369776243e+23*cos(theta)**4 + 9.41577340649983e+20*cos(theta)**2 - 3.65945332549546e+17)*cos(10*phi)

#@torch.jit.script
def Yl72_m11(theta, phi):
    return 1.72303486792792e-20*(1.0 - cos(theta)**2)**5.5*(3.7814270126083e+40*cos(theta)**61 - 4.83916883431692e+41*cos(theta)**59 + 2.93610562961569e+42*cos(theta)**57 - 1.12374690284572e+43*cos(theta)**55 + 3.04519005606915e+43*cos(theta)**53 - 6.21669910705671e+43*cos(theta)**51 + 9.93269594172595e+43*cos(theta)**49 - 1.27381138794653e+44*cos(theta)**47 + 1.33429274260679e+44*cos(theta)**45 - 1.1556866274547e+44*cos(theta)**43 + 8.34868019673273e+43*cos(theta)**41 - 5.05980617983802e+43*cos(theta)**39 + 2.58217381491734e+43*cos(theta)**37 - 1.11165336828374e+43*cos(theta)**35 + 4.03805710701359e+42*cos(theta)**33 - 1.23599661014677e+42*cos(theta)**31 + 3.1788629630434e+41*cos(theta)**29 - 6.83952497612941e+40*cos(theta)**27 + 1.223584743436e+40*cos(theta)**25 - 1.8055849632602e+39*cos(theta)**23 + 2.17529997954681e+38*cos(theta)**21 - 2.11194172771535e+37*cos(theta)**19 + 1.62530168964593e+36*cos(theta)**17 - 9.70755510723963e+34*cos(theta)**15 + 4.37840758702818e+33*cos(theta)**13 - 1.43796122858189e+32*cos(theta)**11 + 3.27079683920611e+30*cos(theta)**9 - 4.79237632118112e+28*cos(theta)**7 + 4.03851937178184e+26*cos(theta)**5 - 1.60068147910497e+24*cos(theta)**3 + 1.88315468129997e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl72_m12(theta, phi):
    return 2.40707435283517e-22*(1.0 - cos(theta)**2)**6*(2.30667047769107e+42*cos(theta)**60 - 2.85510961224698e+43*cos(theta)**58 + 1.67358020888094e+44*cos(theta)**56 - 6.18060796565145e+44*cos(theta)**54 + 1.61395072971665e+45*cos(theta)**52 - 3.17051654459892e+45*cos(theta)**50 + 4.86702101144572e+45*cos(theta)**48 - 5.98691352334871e+45*cos(theta)**46 + 6.00431734173054e+45*cos(theta)**44 - 4.9694524980552e+45*cos(theta)**42 + 3.42295888066042e+45*cos(theta)**40 - 1.97332441013683e+45*cos(theta)**38 + 9.55404311519414e+44*cos(theta)**36 - 3.89078678899309e+44*cos(theta)**34 + 1.33255884531448e+44*cos(theta)**32 - 3.83158949145498e+43*cos(theta)**30 + 9.21870259282586e+42*cos(theta)**28 - 1.84667174355494e+42*cos(theta)**26 + 3.05896185858999e+41*cos(theta)**24 - 4.15284541549846e+40*cos(theta)**22 + 4.56812995704831e+39*cos(theta)**20 - 4.01268928265917e+38*cos(theta)**18 + 2.76301287239808e+37*cos(theta)**16 - 1.45613326608594e+36*cos(theta)**14 + 5.69192986313664e+34*cos(theta)**12 - 1.58175735144008e+33*cos(theta)**10 + 2.9437171552855e+31*cos(theta)**8 - 3.35466342482678e+29*cos(theta)**6 + 2.01925968589092e+27*cos(theta)**4 - 4.80204443731491e+24*cos(theta)**2 + 1.88315468129997e+21)*cos(12*phi)

#@torch.jit.script
def Yl72_m13(theta, phi):
    return 3.3705782770497e-24*(1.0 - cos(theta)**2)**6.5*(1.38400228661464e+44*cos(theta)**59 - 1.65596357510325e+45*cos(theta)**57 + 9.37204916973329e+45*cos(theta)**55 - 3.33752830145178e+46*cos(theta)**53 + 8.39254379452656e+46*cos(theta)**51 - 1.58525827229946e+47*cos(theta)**49 + 2.33617008549394e+47*cos(theta)**47 - 2.75398022074041e+47*cos(theta)**45 + 2.64189963036144e+47*cos(theta)**43 - 2.08717004918318e+47*cos(theta)**41 + 1.36918355226417e+47*cos(theta)**39 - 7.49863275851995e+46*cos(theta)**37 + 3.43945552146989e+46*cos(theta)**35 - 1.32286750825765e+46*cos(theta)**33 + 4.26418830500635e+45*cos(theta)**31 - 1.14947684743649e+45*cos(theta)**29 + 2.58123672599124e+44*cos(theta)**27 - 4.80134653324285e+43*cos(theta)**25 + 7.34150846061598e+42*cos(theta)**23 - 9.13625991409662e+41*cos(theta)**21 + 9.13625991409662e+40*cos(theta)**19 - 7.22284070878651e+39*cos(theta)**17 + 4.42082059583693e+38*cos(theta)**15 - 2.03858657252032e+37*cos(theta)**13 + 6.83031583576396e+35*cos(theta)**11 - 1.58175735144008e+34*cos(theta)**9 + 2.3549737242284e+32*cos(theta)**7 - 2.01279805489607e+30*cos(theta)**5 + 8.07703874356368e+27*cos(theta)**3 - 9.60408887462982e+24*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl72_m14(theta, phi):
    return 4.73183057377072e-26*(1.0 - cos(theta)**2)**7*(8.16561349102637e+45*cos(theta)**58 - 9.43899237808853e+46*cos(theta)**56 + 5.15462704335331e+47*cos(theta)**54 - 1.76888999976945e+48*cos(theta)**52 + 4.28019733520855e+48*cos(theta)**50 - 7.76776553426737e+48*cos(theta)**48 + 1.09799994018215e+49*cos(theta)**46 - 1.23929109933318e+49*cos(theta)**44 + 1.13601684105542e+49*cos(theta)**42 - 8.55739720165105e+48*cos(theta)**40 + 5.33981585383026e+48*cos(theta)**38 - 2.77449412065238e+48*cos(theta)**36 + 1.20380943251446e+48*cos(theta)**34 - 4.36546277725025e+47*cos(theta)**32 + 1.32189837455197e+47*cos(theta)**30 - 3.33348285756583e+46*cos(theta)**28 + 6.96933916017635e+45*cos(theta)**26 - 1.20033663331071e+45*cos(theta)**24 + 1.68854694594167e+44*cos(theta)**22 - 1.91861458196029e+43*cos(theta)**20 + 1.73588938367836e+42*cos(theta)**18 - 1.22788292049371e+41*cos(theta)**16 + 6.63123089375539e+39*cos(theta)**14 - 2.65016254427642e+38*cos(theta)**12 + 7.51334741934036e+36*cos(theta)**10 - 1.42358161629607e+35*cos(theta)**8 + 1.64848160695988e+33*cos(theta)**6 - 1.00639902744803e+31*cos(theta)**4 + 2.4231116230691e+28*cos(theta)**2 - 9.60408887462982e+24)*cos(14*phi)

#@torch.jit.script
def Yl72_m15(theta, phi):
    return 6.66124738795357e-28*(1.0 - cos(theta)**2)**7.5*(4.7360558247953e+47*cos(theta)**57 - 5.28583573172958e+48*cos(theta)**55 + 2.78349860341079e+49*cos(theta)**53 - 9.19822799880112e+49*cos(theta)**51 + 2.14009866760427e+50*cos(theta)**49 - 3.72852745644834e+50*cos(theta)**47 + 5.05079972483791e+50*cos(theta)**45 - 5.45288083706601e+50*cos(theta)**43 + 4.77127073243276e+50*cos(theta)**41 - 3.42295888066042e+50*cos(theta)**39 + 2.0291300244555e+50*cos(theta)**37 - 9.98817883434857e+49*cos(theta)**35 + 4.09295207054917e+49*cos(theta)**33 - 1.39694808872008e+49*cos(theta)**31 + 3.9656951236559e+48*cos(theta)**29 - 9.33375200118433e+47*cos(theta)**27 + 1.81202818164585e+47*cos(theta)**25 - 2.88080791994571e+46*cos(theta)**23 + 3.71480328107168e+45*cos(theta)**21 - 3.83722916392058e+44*cos(theta)**19 + 3.12460089062104e+43*cos(theta)**17 - 1.96461267278993e+42*cos(theta)**15 + 9.28372325125754e+40*cos(theta)**13 - 3.1801950531317e+39*cos(theta)**11 + 7.51334741934036e+37*cos(theta)**9 - 1.13886529303685e+36*cos(theta)**7 + 9.89088964175928e+33*cos(theta)**5 - 4.02559610979214e+31*cos(theta)**3 + 4.84622324613821e+28*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl72_m16(theta, phi):
    return 9.40538979437044e-30*(1.0 - cos(theta)**2)**8*(2.69955182013332e+49*cos(theta)**56 - 2.90720965245127e+50*cos(theta)**54 + 1.47525425980772e+51*cos(theta)**52 - 4.69109627938857e+51*cos(theta)**50 + 1.04864834712609e+52*cos(theta)**48 - 1.75240790453072e+52*cos(theta)**46 + 2.27285987617706e+52*cos(theta)**44 - 2.34473875993838e+52*cos(theta)**42 + 1.95622100029743e+52*cos(theta)**40 - 1.33495396345756e+52*cos(theta)**38 + 7.50778109048534e+51*cos(theta)**36 - 3.495862592022e+51*cos(theta)**34 + 1.35067418328123e+51*cos(theta)**32 - 4.33053907503225e+50*cos(theta)**30 + 1.15005158586021e+50*cos(theta)**28 - 2.52011304031977e+49*cos(theta)**26 + 4.53007045411463e+48*cos(theta)**24 - 6.62585821587513e+47*cos(theta)**22 + 7.80108689025054e+46*cos(theta)**20 - 7.2907354114491e+45*cos(theta)**18 + 5.31182151405577e+44*cos(theta)**16 - 2.9469190091849e+43*cos(theta)**14 + 1.20688402266348e+42*cos(theta)**12 - 3.49821455844487e+40*cos(theta)**10 + 6.76201267740632e+38*cos(theta)**8 - 7.97205705125798e+36*cos(theta)**6 + 4.94544482087964e+34*cos(theta)**4 - 1.20767883293764e+32*cos(theta)**2 + 4.84622324613821e+28)*cos(16*phi)

#@torch.jit.script
def Yl72_m17(theta, phi):
    return 1.33225629876043e-31*(1.0 - cos(theta)**2)**8.5*(1.51174901927466e+51*cos(theta)**55 - 1.56989321232368e+52*cos(theta)**53 + 7.67132215100013e+52*cos(theta)**51 - 2.34554813969428e+53*cos(theta)**49 + 5.03351206620525e+53*cos(theta)**47 - 8.0610763608413e+53*cos(theta)**45 + 1.00005834551791e+54*cos(theta)**43 - 9.84790279174121e+53*cos(theta)**41 + 7.82488400118972e+53*cos(theta)**39 - 5.07282506113874e+53*cos(theta)**37 + 2.70280119257472e+53*cos(theta)**35 - 1.18859328128748e+53*cos(theta)**33 + 4.32215738649993e+52*cos(theta)**31 - 1.29916172250967e+52*cos(theta)**29 + 3.22014444040859e+51*cos(theta)**27 - 6.5522939048314e+50*cos(theta)**25 + 1.08721690898751e+50*cos(theta)**23 - 1.45768880749253e+49*cos(theta)**21 + 1.56021737805011e+48*cos(theta)**19 - 1.31233237406084e+47*cos(theta)**17 + 8.49891442248924e+45*cos(theta)**15 - 4.12568661285885e+44*cos(theta)**13 + 1.44826082719618e+43*cos(theta)**11 - 3.49821455844487e+41*cos(theta)**9 + 5.40961014192506e+39*cos(theta)**7 - 4.78323423075479e+37*cos(theta)**5 + 1.97817792835186e+35*cos(theta)**3 - 2.41535766587528e+32*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl72_m18(theta, phi):
    return 1.89358664843331e-33*(1.0 - cos(theta)**2)**9*(8.31461960601062e+52*cos(theta)**54 - 8.32043402531553e+53*cos(theta)**52 + 3.91237429701007e+54*cos(theta)**50 - 1.1493185884502e+55*cos(theta)**48 + 2.36575067111647e+55*cos(theta)**46 - 3.62748436237859e+55*cos(theta)**44 + 4.30025088572699e+55*cos(theta)**42 - 4.0376401446139e+55*cos(theta)**40 + 3.05170476046399e+55*cos(theta)**38 - 1.87694527262133e+55*cos(theta)**36 + 9.45980417401153e+54*cos(theta)**34 - 3.92235782824868e+54*cos(theta)**32 + 1.33986878981498e+54*cos(theta)**30 - 3.76756899527805e+53*cos(theta)**28 + 8.6943899891032e+52*cos(theta)**26 - 1.63807347620785e+52*cos(theta)**24 + 2.50059889067127e+51*cos(theta)**22 - 3.06114649573431e+50*cos(theta)**20 + 2.9644130182952e+49*cos(theta)**18 - 2.23096503590342e+48*cos(theta)**16 + 1.27483716337339e+47*cos(theta)**14 - 5.36339259671651e+45*cos(theta)**12 + 1.59308690991579e+44*cos(theta)**10 - 3.14839310260038e+42*cos(theta)**8 + 3.78672709934754e+40*cos(theta)**6 - 2.39161711537739e+38*cos(theta)**4 + 5.93453378505557e+35*cos(theta)**2 - 2.41535766587528e+32)*cos(18*phi)

#@torch.jit.script
def Yl72_m19(theta, phi):
    return 2.70126758225203e-35*(1.0 - cos(theta)**2)**9.5*(4.48989458724574e+54*cos(theta)**53 - 4.32662569316407e+55*cos(theta)**51 + 1.95618714850503e+56*cos(theta)**49 - 5.51672922456096e+56*cos(theta)**47 + 1.08824530871358e+57*cos(theta)**45 - 1.59609311944658e+57*cos(theta)**43 + 1.80610537200534e+57*cos(theta)**41 - 1.61505605784556e+57*cos(theta)**39 + 1.15964780897632e+57*cos(theta)**37 - 6.75700298143681e+56*cos(theta)**35 + 3.21633341916392e+56*cos(theta)**33 - 1.25515450503958e+56*cos(theta)**31 + 4.01960636944493e+55*cos(theta)**29 - 1.05491931867786e+55*cos(theta)**27 + 2.26054139716683e+54*cos(theta)**25 - 3.93137634289884e+53*cos(theta)**23 + 5.5013175594768e+52*cos(theta)**21 - 6.12229299146862e+51*cos(theta)**19 + 5.33594343293137e+50*cos(theta)**17 - 3.56954405744548e+49*cos(theta)**15 + 1.78477202872274e+48*cos(theta)**13 - 6.43607111605981e+46*cos(theta)**11 + 1.59308690991579e+45*cos(theta)**9 - 2.51871448208031e+43*cos(theta)**7 + 2.27203625960852e+41*cos(theta)**5 - 9.56646846150958e+38*cos(theta)**3 + 1.18690675701111e+36*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl72_m20(theta, phi):
    return 3.86843904618807e-37*(1.0 - cos(theta)**2)**10*(2.37964413124024e+56*cos(theta)**52 - 2.20657910351368e+57*cos(theta)**50 + 9.58531702767466e+57*cos(theta)**48 - 2.59286273554365e+58*cos(theta)**46 + 4.89710388921109e+58*cos(theta)**44 - 6.86320041362028e+58*cos(theta)**42 + 7.40503202522188e+58*cos(theta)**40 - 6.29871862559768e+58*cos(theta)**38 + 4.29069689321237e+58*cos(theta)**36 - 2.36495104350288e+58*cos(theta)**34 + 1.06139002832409e+58*cos(theta)**32 - 3.89097896562269e+57*cos(theta)**30 + 1.16568584713903e+57*cos(theta)**28 - 2.84828216043021e+56*cos(theta)**26 + 5.65135349291708e+55*cos(theta)**24 - 9.04216558866733e+54*cos(theta)**22 + 1.15527668749013e+54*cos(theta)**20 - 1.16323566837904e+53*cos(theta)**18 + 9.07110383598332e+51*cos(theta)**16 - 5.35431608616822e+50*cos(theta)**14 + 2.32020363733956e+49*cos(theta)**12 - 7.07967822766579e+47*cos(theta)**10 + 1.43377821892422e+46*cos(theta)**8 - 1.76310013745622e+44*cos(theta)**6 + 1.13601812980426e+42*cos(theta)**4 - 2.86994053845287e+39*cos(theta)**2 + 1.18690675701111e+36)*cos(20*phi)

#@torch.jit.script
def Yl72_m21(theta, phi):
    return 5.56278931907556e-39*(1.0 - cos(theta)**2)**10.5*(1.23741494824492e+58*cos(theta)**51 - 1.10328955175684e+59*cos(theta)**49 + 4.60095217328384e+59*cos(theta)**47 - 1.19271685835008e+60*cos(theta)**45 + 2.15472571125288e+60*cos(theta)**43 - 2.88254417372052e+60*cos(theta)**41 + 2.96201281008875e+60*cos(theta)**39 - 2.39351307772712e+60*cos(theta)**37 + 1.54465088155645e+60*cos(theta)**35 - 8.0408335479098e+59*cos(theta)**33 + 3.3964480906371e+59*cos(theta)**31 - 1.16729368968681e+59*cos(theta)**29 + 3.26392037198928e+58*cos(theta)**27 - 7.40553361711854e+57*cos(theta)**25 + 1.3563248383001e+57*cos(theta)**23 - 1.98927642950681e+56*cos(theta)**21 + 2.31055337498026e+55*cos(theta)**19 - 2.09382420308227e+54*cos(theta)**17 + 1.45137661375733e+53*cos(theta)**15 - 7.49604252063551e+51*cos(theta)**13 + 2.78424436480747e+50*cos(theta)**11 - 7.07967822766579e+48*cos(theta)**9 + 1.14702257513937e+47*cos(theta)**7 - 1.05786008247373e+45*cos(theta)**5 + 4.54407251921705e+42*cos(theta)**3 - 5.73988107690575e+39*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl72_m22(theta, phi):
    return 8.03421773328159e-41*(1.0 - cos(theta)**2)**11*(6.31081623604912e+59*cos(theta)**50 - 5.40611880360851e+60*cos(theta)**48 + 2.1624475214434e+61*cos(theta)**46 - 5.36722586257535e+61*cos(theta)**44 + 9.26532055838738e+61*cos(theta)**42 - 1.18184311122541e+62*cos(theta)**40 + 1.15518499593461e+62*cos(theta)**38 - 8.85599838759033e+61*cos(theta)**36 + 5.40627808544759e+61*cos(theta)**34 - 2.65347507081023e+61*cos(theta)**32 + 1.0528989080975e+61*cos(theta)**30 - 3.38515170009174e+60*cos(theta)**28 + 8.81258500437107e+59*cos(theta)**26 - 1.85138340427964e+59*cos(theta)**24 + 3.11954712809023e+58*cos(theta)**22 - 4.17748050196431e+57*cos(theta)**20 + 4.39005141246249e+56*cos(theta)**18 - 3.55950114523986e+55*cos(theta)**16 + 2.177064920636e+54*cos(theta)**14 - 9.74485527682616e+52*cos(theta)**12 + 3.06266880128822e+51*cos(theta)**10 - 6.37171040489921e+49*cos(theta)**8 + 8.0291580259756e+47*cos(theta)**6 - 5.28930041236865e+45*cos(theta)**4 + 1.36322175576512e+43*cos(theta)**2 - 5.73988107690575e+39)*cos(22*phi)

#@torch.jit.script
def Yl72_m23(theta, phi):
    return 1.1657268307417e-42*(1.0 - cos(theta)**2)**11.5*(3.15540811802456e+61*cos(theta)**49 - 2.59493702573208e+62*cos(theta)**47 + 9.94725859863966e+62*cos(theta)**45 - 2.36157937953316e+63*cos(theta)**43 + 3.8914346345227e+63*cos(theta)**41 - 4.72737244490165e+63*cos(theta)**39 + 4.38970298455153e+63*cos(theta)**37 - 3.18815941953252e+63*cos(theta)**35 + 1.83813454905218e+63*cos(theta)**33 - 8.49112022659275e+62*cos(theta)**31 + 3.1586967242925e+62*cos(theta)**29 - 9.47842476025688e+61*cos(theta)**27 + 2.29127210113648e+61*cos(theta)**25 - 4.44332017027113e+60*cos(theta)**23 + 6.8630036817985e+59*cos(theta)**21 - 8.35496100392861e+58*cos(theta)**19 + 7.90209254243248e+57*cos(theta)**17 - 5.69520183238377e+56*cos(theta)**15 + 3.0478908888904e+55*cos(theta)**13 - 1.16938263321914e+54*cos(theta)**11 + 3.06266880128822e+52*cos(theta)**9 - 5.09736832391937e+50*cos(theta)**7 + 4.81749481558536e+48*cos(theta)**5 - 2.11572016494746e+46*cos(theta)**3 + 2.72644351153023e+43*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl72_m24(theta, phi):
    return 1.69966423499341e-44*(1.0 - cos(theta)**2)**12*(1.54614997783203e+63*cos(theta)**48 - 1.21962040209408e+64*cos(theta)**46 + 4.47626636938785e+64*cos(theta)**44 - 1.01547913319926e+65*cos(theta)**42 + 1.59548820015431e+65*cos(theta)**40 - 1.84367525351164e+65*cos(theta)**38 + 1.62419010428407e+65*cos(theta)**36 - 1.11585579683638e+65*cos(theta)**34 + 6.06584401187219e+64*cos(theta)**32 - 2.63224727024375e+64*cos(theta)**30 + 9.16022050044826e+63*cos(theta)**28 - 2.55917468526936e+63*cos(theta)**26 + 5.72818025284119e+62*cos(theta)**24 - 1.02196363916236e+62*cos(theta)**22 + 1.44123077317769e+61*cos(theta)**20 - 1.58744259074644e+60*cos(theta)**18 + 1.34335573221352e+59*cos(theta)**16 - 8.54280274857566e+57*cos(theta)**14 + 3.96225815555752e+56*cos(theta)**12 - 1.28632089654105e+55*cos(theta)**10 + 2.7564019211594e+53*cos(theta)**8 - 3.56815782674356e+51*cos(theta)**6 + 2.40874740779268e+49*cos(theta)**4 - 6.34716049484238e+46*cos(theta)**2 + 2.72644351153023e+43)*cos(24*phi)

#@torch.jit.script
def Yl72_m25(theta, phi):
    return 2.4909020501506e-46*(1.0 - cos(theta)**2)**12.5*(7.42151989359376e+64*cos(theta)**47 - 5.61025384963277e+65*cos(theta)**45 + 1.96955720253065e+66*cos(theta)**43 - 4.26501235943688e+66*cos(theta)**41 + 6.38195280061723e+66*cos(theta)**39 - 7.00596596334425e+66*cos(theta)**37 + 5.84708437542264e+66*cos(theta)**35 - 3.7939097092437e+66*cos(theta)**33 + 1.9410700837991e+66*cos(theta)**31 - 7.89674181073125e+65*cos(theta)**29 + 2.56486174012551e+65*cos(theta)**27 - 6.65385418170033e+64*cos(theta)**25 + 1.37476326068189e+64*cos(theta)**23 - 2.24832000615719e+63*cos(theta)**21 + 2.88246154635537e+62*cos(theta)**19 - 2.85739666334359e+61*cos(theta)**17 + 2.14936917154164e+60*cos(theta)**15 - 1.19599238480059e+59*cos(theta)**13 + 4.75470978666902e+57*cos(theta)**11 - 1.28632089654105e+56*cos(theta)**9 + 2.20512153692752e+54*cos(theta)**7 - 2.14089469604614e+52*cos(theta)**5 + 9.63498963117073e+49*cos(theta)**3 - 1.26943209896848e+47*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl72_m26(theta, phi):
    return 3.67024185267844e-48*(1.0 - cos(theta)**2)**13*(3.48811434998907e+66*cos(theta)**46 - 2.52461423233475e+67*cos(theta)**44 + 8.4690959708818e+67*cos(theta)**42 - 1.74865506736912e+68*cos(theta)**40 + 2.48896159224072e+68*cos(theta)**38 - 2.59220740643737e+68*cos(theta)**36 + 2.04647953139792e+68*cos(theta)**34 - 1.25199020405042e+68*cos(theta)**32 + 6.01731725977722e+67*cos(theta)**30 - 2.29005512511206e+67*cos(theta)**28 + 6.92512669833888e+66*cos(theta)**26 - 1.66346354542508e+66*cos(theta)**24 + 3.16195549956834e+65*cos(theta)**22 - 4.7214720129301e+64*cos(theta)**20 + 5.47667693807521e+63*cos(theta)**18 - 4.85757432768409e+62*cos(theta)**16 + 3.22405375731245e+61*cos(theta)**14 - 1.55479010024077e+60*cos(theta)**12 + 5.23018076533592e+58*cos(theta)**10 - 1.15768880688695e+57*cos(theta)**8 + 1.54358507584926e+55*cos(theta)**6 - 1.07044734802307e+53*cos(theta)**4 + 2.89049688935122e+50*cos(theta)**2 - 1.26943209896848e+47)*cos(26*phi)

#@torch.jit.script
def Yl72_m27(theta, phi):
    return 5.43873840150301e-50*(1.0 - cos(theta)**2)**13.5*(1.60453260099497e+68*cos(theta)**45 - 1.11083026222729e+69*cos(theta)**43 + 3.55702030777036e+69*cos(theta)**41 - 6.99462026947648e+69*cos(theta)**39 + 9.45805405051473e+69*cos(theta)**37 - 9.33194666317454e+69*cos(theta)**35 + 6.95803040675294e+69*cos(theta)**33 - 4.00636865296135e+69*cos(theta)**31 + 1.80519517793316e+69*cos(theta)**29 - 6.41215435031378e+68*cos(theta)**27 + 1.80053294156811e+68*cos(theta)**25 - 3.9923125090202e+67*cos(theta)**23 + 6.95630209905034e+66*cos(theta)**21 - 9.4429440258602e+65*cos(theta)**19 + 9.85801848853537e+64*cos(theta)**17 - 7.77211892429455e+63*cos(theta)**15 + 4.51367526023743e+62*cos(theta)**13 - 1.86574812028892e+61*cos(theta)**11 + 5.23018076533592e+59*cos(theta)**9 - 9.26151045509558e+57*cos(theta)**7 + 9.26151045509558e+55*cos(theta)**5 - 4.28178939209227e+53*cos(theta)**3 + 5.78099377870244e+50*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl72_m28(theta, phi):
    return 8.10759251839952e-52*(1.0 - cos(theta)**2)**14*(7.22039670447737e+69*cos(theta)**44 - 4.77657012757734e+70*cos(theta)**42 + 1.45837832618585e+71*cos(theta)**40 - 2.72790190509583e+71*cos(theta)**38 + 3.49947999869045e+71*cos(theta)**36 - 3.26618133211109e+71*cos(theta)**34 + 2.29615003422847e+71*cos(theta)**32 - 1.24197428241802e+71*cos(theta)**30 + 5.23506601600618e+70*cos(theta)**28 - 1.73128167458472e+70*cos(theta)**26 + 4.50133235392027e+69*cos(theta)**24 - 9.18231877074646e+68*cos(theta)**22 + 1.46082344080057e+68*cos(theta)**20 - 1.79415936491344e+67*cos(theta)**18 + 1.67586314305101e+66*cos(theta)**16 - 1.16581783864418e+65*cos(theta)**14 + 5.86777783830866e+63*cos(theta)**12 - 2.05232293231782e+62*cos(theta)**10 + 4.70716268880233e+60*cos(theta)**8 - 6.48305731856691e+58*cos(theta)**6 + 4.63075522754779e+56*cos(theta)**4 - 1.28453681762768e+54*cos(theta)**2 + 5.78099377870244e+50)*cos(28*phi)

#@torch.jit.script
def Yl72_m29(theta, phi):
    return 1.21619968926472e-53*(1.0 - cos(theta)**2)**14.5*(3.17697454997004e+71*cos(theta)**43 - 2.00615945358248e+72*cos(theta)**41 + 5.83351330474339e+72*cos(theta)**39 - 1.03660272393641e+73*cos(theta)**37 + 1.25981279952856e+73*cos(theta)**35 - 1.11050165291777e+73*cos(theta)**33 + 7.34768010953111e+72*cos(theta)**31 - 3.72592284725405e+72*cos(theta)**29 + 1.46581848448173e+72*cos(theta)**27 - 4.50133235392027e+71*cos(theta)**25 + 1.08031976494087e+71*cos(theta)**23 - 2.02011012956422e+70*cos(theta)**21 + 2.92164688160114e+69*cos(theta)**19 - 3.22948685684419e+68*cos(theta)**17 + 2.68138102888162e+67*cos(theta)**15 - 1.63214497410186e+66*cos(theta)**13 + 7.0413334059704e+64*cos(theta)**11 - 2.05232293231782e+63*cos(theta)**9 + 3.76573015104186e+61*cos(theta)**7 - 3.88983439114014e+59*cos(theta)**5 + 1.85230209101912e+57*cos(theta)**3 - 2.56907363525536e+54*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl72_m30(theta, phi):
    return 1.83641391319431e-55*(1.0 - cos(theta)**2)**15*(1.36609905648712e+73*cos(theta)**42 - 8.22525375968818e+73*cos(theta)**40 + 2.27507018884992e+74*cos(theta)**38 - 3.83543007856473e+74*cos(theta)**36 + 4.40934479834997e+74*cos(theta)**34 - 3.66465545462864e+74*cos(theta)**32 + 2.27778083395464e+74*cos(theta)**30 - 1.08051762570368e+74*cos(theta)**28 + 3.95770990810067e+73*cos(theta)**26 - 1.12533308848007e+73*cos(theta)**24 + 2.48473545936399e+72*cos(theta)**22 - 4.24223127208486e+71*cos(theta)**20 + 5.55112907504217e+70*cos(theta)**18 - 5.49012765663512e+69*cos(theta)**16 + 4.02207154332243e+68*cos(theta)**14 - 2.12178846633241e+67*cos(theta)**12 + 7.74546674656744e+65*cos(theta)**10 - 1.84709063908603e+64*cos(theta)**8 + 2.6360111057293e+62*cos(theta)**6 - 1.94491719557007e+60*cos(theta)**4 + 5.55690627305735e+57*cos(theta)**2 - 2.56907363525536e+54)*cos(30*phi)

#@torch.jit.script
def Yl72_m31(theta, phi):
    return 2.79207652289367e-57*(1.0 - cos(theta)**2)**15.5*(5.7376160372459e+74*cos(theta)**41 - 3.29010150387527e+75*cos(theta)**39 + 8.6452667176297e+75*cos(theta)**37 - 1.3807548282833e+76*cos(theta)**35 + 1.49917723143899e+76*cos(theta)**33 - 1.17268974548117e+76*cos(theta)**31 + 6.83334250186393e+75*cos(theta)**29 - 3.02544935197029e+75*cos(theta)**27 + 1.02900457610617e+75*cos(theta)**25 - 2.70079941235216e+74*cos(theta)**23 + 5.46641801060078e+73*cos(theta)**21 - 8.48446254416972e+72*cos(theta)**19 + 9.99203233507592e+71*cos(theta)**17 - 8.78420425061619e+70*cos(theta)**15 + 5.6309001606514e+69*cos(theta)**13 - 2.5461461595989e+68*cos(theta)**11 + 7.74546674656744e+66*cos(theta)**9 - 1.47767251126883e+65*cos(theta)**7 + 1.58160666343758e+63*cos(theta)**5 - 7.77966878228029e+60*cos(theta)**3 + 1.11138125461147e+58*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl72_m32(theta, phi):
    return 4.27581315288909e-59*(1.0 - cos(theta)**2)**16*(2.35242257527082e+76*cos(theta)**40 - 1.28313958651136e+77*cos(theta)**38 + 3.19874868552299e+77*cos(theta)**36 - 4.83264189899157e+77*cos(theta)**34 + 4.94728486374867e+77*cos(theta)**32 - 3.63533821099161e+77*cos(theta)**30 + 1.98166932554054e+77*cos(theta)**28 - 8.16871325031978e+76*cos(theta)**26 + 2.57251144026544e+76*cos(theta)**24 - 6.21183864840998e+75*cos(theta)**22 + 1.14794778222616e+75*cos(theta)**20 - 1.61204788339225e+74*cos(theta)**18 + 1.69864549696291e+73*cos(theta)**16 - 1.31763063759243e+72*cos(theta)**14 + 7.32017020884682e+70*cos(theta)**12 - 2.80076077555878e+69*cos(theta)**10 + 6.97092007191069e+67*cos(theta)**8 - 1.03437075788818e+66*cos(theta)**6 + 7.90803331718791e+63*cos(theta)**4 - 2.33390063468409e+61*cos(theta)**2 + 1.11138125461147e+58)*cos(32*phi)

#@torch.jit.script
def Yl72_m33(theta, phi):
    return 6.59772293302761e-61*(1.0 - cos(theta)**2)**16.5*(9.40969030108327e+77*cos(theta)**39 - 4.87593042874315e+78*cos(theta)**37 + 1.15154952678828e+79*cos(theta)**35 - 1.64309824565713e+79*cos(theta)**33 + 1.58313115639957e+79*cos(theta)**31 - 1.09060146329748e+79*cos(theta)**29 + 5.54867411151351e+78*cos(theta)**27 - 2.12386544508314e+78*cos(theta)**25 + 6.17402745663705e+77*cos(theta)**23 - 1.36660450265019e+77*cos(theta)**21 + 2.29589556445233e+76*cos(theta)**19 - 2.90168619010605e+75*cos(theta)**17 + 2.71783279514065e+74*cos(theta)**15 - 1.8446828926294e+73*cos(theta)**13 + 8.78420425061619e+71*cos(theta)**11 - 2.80076077555878e+70*cos(theta)**9 + 5.57673605752855e+68*cos(theta)**7 - 6.20622454732907e+66*cos(theta)**5 + 3.16321332687517e+64*cos(theta)**3 - 4.66780126936817e+61*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl72_m34(theta, phi):
    return 1.0261452462024e-62*(1.0 - cos(theta)**2)**17*(3.66977921742248e+79*cos(theta)**38 - 1.80409425863497e+80*cos(theta)**36 + 4.03042334375897e+80*cos(theta)**34 - 5.42222421066854e+80*cos(theta)**32 + 4.90770658483868e+80*cos(theta)**30 - 3.1627442435627e+80*cos(theta)**28 + 1.49814201010865e+80*cos(theta)**26 - 5.30966361270786e+79*cos(theta)**24 + 1.42002631502652e+79*cos(theta)**22 - 2.86986945556541e+78*cos(theta)**20 + 4.36220157245942e+77*cos(theta)**18 - 4.93286652318028e+76*cos(theta)**16 + 4.07674919271097e+75*cos(theta)**14 - 2.39808776041822e+74*cos(theta)**12 + 9.66262467567781e+72*cos(theta)**10 - 2.52068469800291e+71*cos(theta)**8 + 3.90371524026999e+69*cos(theta)**6 - 3.10311227366454e+67*cos(theta)**4 + 9.4896399806255e+64*cos(theta)**2 - 4.66780126936817e+61)*cos(34*phi)

#@torch.jit.script
def Yl72_m35(theta, phi):
    return 1.60925604945875e-64*(1.0 - cos(theta)**2)**17.5*(1.39451610262054e+81*cos(theta)**37 - 6.49473933108588e+81*cos(theta)**35 + 1.37034393687805e+82*cos(theta)**33 - 1.73511174741393e+82*cos(theta)**31 + 1.4723119754516e+82*cos(theta)**29 - 8.85568388197557e+81*cos(theta)**27 + 3.89516922628249e+81*cos(theta)**25 - 1.27431926704989e+81*cos(theta)**23 + 3.12405789305835e+80*cos(theta)**21 - 5.73973891113082e+79*cos(theta)**19 + 7.85196283042696e+78*cos(theta)**17 - 7.89258643708844e+77*cos(theta)**15 + 5.70744886979536e+76*cos(theta)**13 - 2.87770531250186e+75*cos(theta)**11 + 9.66262467567781e+73*cos(theta)**9 - 2.01654775840232e+72*cos(theta)**7 + 2.34222914416199e+70*cos(theta)**5 - 1.24124490946581e+68*cos(theta)**3 + 1.8979279961251e+65*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl72_m36(theta, phi):
    return 2.54573041092809e-66*(1.0 - cos(theta)**2)**18*(5.159709579696e+82*cos(theta)**36 - 2.27315876588006e+83*cos(theta)**34 + 4.52213499169756e+83*cos(theta)**32 - 5.37884641698319e+83*cos(theta)**30 + 4.26970472880965e+83*cos(theta)**28 - 2.3910346481334e+83*cos(theta)**26 + 9.73792306570621e+82*cos(theta)**24 - 2.93093431421474e+82*cos(theta)**22 + 6.56052157542253e+81*cos(theta)**20 - 1.09055039311486e+81*cos(theta)**18 + 1.33483368117258e+80*cos(theta)**16 - 1.18388796556327e+79*cos(theta)**14 + 7.41968353073397e+77*cos(theta)**12 - 3.16547584375205e+76*cos(theta)**10 + 8.69636220811003e+74*cos(theta)**8 - 1.41158343088163e+73*cos(theta)**6 + 1.171114572081e+71*cos(theta)**4 - 3.72373472839744e+68*cos(theta)**2 + 1.8979279961251e+65)*cos(36*phi)

#@torch.jit.script
def Yl72_m37(theta, phi):
    return 4.06394583778961e-68*(1.0 - cos(theta)**2)**18.5*(1.85749544869056e+84*cos(theta)**35 - 7.72873980399219e+84*cos(theta)**33 + 1.44708319734322e+85*cos(theta)**31 - 1.61365392509496e+85*cos(theta)**29 + 1.1955173240667e+85*cos(theta)**27 - 6.21669008514685e+84*cos(theta)**25 + 2.33710153576949e+84*cos(theta)**23 - 6.44805549127242e+83*cos(theta)**21 + 1.3121043150845e+83*cos(theta)**19 - 1.96299070760674e+82*cos(theta)**17 + 2.13573388987613e+81*cos(theta)**15 - 1.65744315178857e+80*cos(theta)**13 + 8.90362023688077e+78*cos(theta)**11 - 3.16547584375205e+77*cos(theta)**9 + 6.95708976648802e+75*cos(theta)**7 - 8.46950058528977e+73*cos(theta)**5 + 4.68445828832399e+71*cos(theta)**3 - 7.44746945679489e+68*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl72_m38(theta, phi):
    return 6.54964176129246e-70*(1.0 - cos(theta)**2)**19*(6.50123407041696e+85*cos(theta)**34 - 2.55048413531742e+86*cos(theta)**32 + 4.48595791176398e+86*cos(theta)**30 - 4.67959638277537e+86*cos(theta)**28 + 3.22789677498009e+86*cos(theta)**26 - 1.55417252128671e+86*cos(theta)**24 + 5.37533353226983e+85*cos(theta)**22 - 1.35409165316721e+85*cos(theta)**20 + 2.49299819866056e+84*cos(theta)**18 - 3.33708420293146e+83*cos(theta)**16 + 3.2036008348142e+82*cos(theta)**14 - 2.15467609732515e+81*cos(theta)**12 + 9.79398226056884e+79*cos(theta)**10 - 2.84892825937684e+78*cos(theta)**8 + 4.86996283654161e+76*cos(theta)**6 - 4.23475029264488e+74*cos(theta)**4 + 1.4053374864972e+72*cos(theta)**2 - 7.44746945679489e+68)*cos(38*phi)

#@torch.jit.script
def Yl72_m39(theta, phi):
    return 1.06614579560172e-71*(1.0 - cos(theta)**2)**19.5*(2.21041958394177e+87*cos(theta)**33 - 8.16154923301576e+87*cos(theta)**31 + 1.34578737352919e+88*cos(theta)**29 - 1.3102869871771e+88*cos(theta)**27 + 8.39253161494824e+87*cos(theta)**25 - 3.73001405108811e+87*cos(theta)**23 + 1.18257337709936e+87*cos(theta)**21 - 2.70818330633442e+86*cos(theta)**19 + 4.48739675758901e+85*cos(theta)**17 - 5.33933472469033e+84*cos(theta)**15 + 4.48504116873988e+83*cos(theta)**13 - 2.58561131679017e+82*cos(theta)**11 + 9.79398226056884e+80*cos(theta)**9 - 2.27914260750148e+79*cos(theta)**7 + 2.92197770192497e+77*cos(theta)**5 - 1.69390011705795e+75*cos(theta)**3 + 2.81067497299439e+72*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl72_m40(theta, phi):
    return 1.75368108322596e-73*(1.0 - cos(theta)**2)**20*(7.29438462700783e+88*cos(theta)**32 - 2.53008026223488e+89*cos(theta)**30 + 3.90278338323466e+89*cos(theta)**28 - 3.53777486537818e+89*cos(theta)**26 + 2.09813290373706e+89*cos(theta)**24 - 8.57903231750265e+88*cos(theta)**22 + 2.48340409190866e+88*cos(theta)**20 - 5.14554828203539e+87*cos(theta)**18 + 7.62857448790131e+86*cos(theta)**16 - 8.0090020870355e+85*cos(theta)**14 + 5.83055351936184e+84*cos(theta)**12 - 2.84417244846919e+83*cos(theta)**10 + 8.81458403451196e+81*cos(theta)**8 - 1.59539982525103e+80*cos(theta)**6 + 1.46098885096248e+78*cos(theta)**4 - 5.08170035117386e+75*cos(theta)**2 + 2.81067497299439e+72)*cos(40*phi)

#@torch.jit.script
def Yl72_m41(theta, phi):
    return 2.91632826076128e-75*(1.0 - cos(theta)**2)**20.5*(2.33420308064251e+90*cos(theta)**31 - 7.59024078670465e+90*cos(theta)**29 + 1.09277934730571e+91*cos(theta)**27 - 9.19821464998327e+90*cos(theta)**25 + 5.03551896896895e+90*cos(theta)**23 - 1.88738710985058e+90*cos(theta)**21 + 4.96680818381732e+89*cos(theta)**19 - 9.26198690766371e+88*cos(theta)**17 + 1.22057191806421e+88*cos(theta)**15 - 1.12126029218497e+87*cos(theta)**13 + 6.99666422323421e+85*cos(theta)**11 - 2.84417244846919e+84*cos(theta)**9 + 7.05166722760957e+82*cos(theta)**7 - 9.5723989515062e+80*cos(theta)**5 + 5.84395540384994e+78*cos(theta)**3 - 1.01634007023477e+76*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl72_m42(theta, phi):
    return 4.90572426013266e-77*(1.0 - cos(theta)**2)**21*(7.23602954999177e+91*cos(theta)**30 - 2.20116982814435e+92*cos(theta)**28 + 2.9505042377254e+92*cos(theta)**26 - 2.29955366249582e+92*cos(theta)**24 + 1.15816936286286e+92*cos(theta)**22 - 3.96351293068622e+91*cos(theta)**20 + 9.43693554925291e+90*cos(theta)**18 - 1.57453777430283e+90*cos(theta)**16 + 1.83085787709631e+89*cos(theta)**14 - 1.45763837984046e+88*cos(theta)**12 + 7.69633064555763e+86*cos(theta)**10 - 2.55975520362227e+85*cos(theta)**8 + 4.9361670593267e+83*cos(theta)**6 - 4.7861994757531e+81*cos(theta)**4 + 1.75318662115498e+79*cos(theta)**2 - 1.01634007023477e+76)*cos(42*phi)

#@torch.jit.script
def Yl72_m43(theta, phi):
    return 8.35205962907912e-79*(1.0 - cos(theta)**2)**21.5*(2.17080886499753e+93*cos(theta)**29 - 6.16327551880418e+93*cos(theta)**27 + 7.67131101808605e+93*cos(theta)**25 - 5.51892878998997e+93*cos(theta)**23 + 2.54797259829829e+93*cos(theta)**21 - 7.92702586137245e+92*cos(theta)**19 + 1.69864839886552e+92*cos(theta)**17 - 2.51926043888453e+91*cos(theta)**15 + 2.56320102793484e+90*cos(theta)**13 - 1.74916605580855e+89*cos(theta)**11 + 7.69633064555763e+87*cos(theta)**9 - 2.04780416289782e+86*cos(theta)**7 + 2.96170023559602e+84*cos(theta)**5 - 1.91447979030124e+82*cos(theta)**3 + 3.50637324230996e+79*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl72_m44(theta, phi):
    return 1.44001028087571e-80*(1.0 - cos(theta)**2)**22*(6.29534570849284e+94*cos(theta)**28 - 1.66408439007713e+95*cos(theta)**26 + 1.91782775452151e+95*cos(theta)**24 - 1.26935362169769e+95*cos(theta)**22 + 5.3507424564264e+94*cos(theta)**20 - 1.50613491366077e+94*cos(theta)**18 + 2.88770227807139e+93*cos(theta)**16 - 3.77889065832679e+92*cos(theta)**14 + 3.33216133631529e+91*cos(theta)**12 - 1.92408266138941e+90*cos(theta)**10 + 6.92669758100187e+88*cos(theta)**8 - 1.43346291402847e+87*cos(theta)**6 + 1.48085011779801e+85*cos(theta)**4 - 5.74343937090372e+82*cos(theta)**2 + 3.50637324230996e+79)*cos(44*phi)

#@torch.jit.script
def Yl72_m45(theta, phi):
    return 2.51590157027613e-82*(1.0 - cos(theta)**2)**22.5*(1.762696798378e+96*cos(theta)**27 - 4.32661941420053e+96*cos(theta)**25 + 4.60278661085163e+96*cos(theta)**23 - 2.79257796773492e+96*cos(theta)**21 + 1.07014849128528e+96*cos(theta)**19 - 2.71104284458938e+95*cos(theta)**17 + 4.62032364491423e+94*cos(theta)**15 - 5.29044692165751e+93*cos(theta)**13 + 3.99859360357835e+92*cos(theta)**11 - 1.92408266138941e+91*cos(theta)**9 + 5.5413580648015e+89*cos(theta)**7 - 8.60077748417084e+87*cos(theta)**5 + 5.92340047119204e+85*cos(theta)**3 - 1.14868787418074e+83*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl72_m46(theta, phi):
    return 4.45728865959693e-84*(1.0 - cos(theta)**2)**23*(4.75928135562059e+97*cos(theta)**26 - 1.08165485355013e+98*cos(theta)**24 + 1.05864092049588e+98*cos(theta)**22 - 5.86441373224334e+97*cos(theta)**20 + 2.03328213344203e+97*cos(theta)**18 - 4.60877283580194e+96*cos(theta)**16 + 6.93048546737134e+95*cos(theta)**14 - 6.87758099815477e+94*cos(theta)**12 + 4.39845296393619e+93*cos(theta)**10 - 1.73167439525047e+92*cos(theta)**8 + 3.87895064536105e+90*cos(theta)**6 - 4.30038874208542e+88*cos(theta)**4 + 1.77702014135761e+86*cos(theta)**2 - 1.14868787418074e+83)*cos(46*phi)

#@torch.jit.script
def Yl72_m47(theta, phi):
    return 8.01328530746178e-86*(1.0 - cos(theta)**2)**23.5*(1.23741315246135e+99*cos(theta)**25 - 2.59597164852032e+99*cos(theta)**23 + 2.32901002509093e+99*cos(theta)**21 - 1.17288274644867e+99*cos(theta)**19 + 3.65990784019566e+98*cos(theta)**17 - 7.37403653728311e+97*cos(theta)**15 + 9.70267965431988e+96*cos(theta)**13 - 8.25309719778572e+95*cos(theta)**11 + 4.39845296393619e+94*cos(theta)**9 - 1.38533951620037e+93*cos(theta)**7 + 2.32737038721663e+91*cos(theta)**5 - 1.72015549683417e+89*cos(theta)**3 + 3.55404028271522e+86*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl72_m48(theta, phi):
    return 1.46301904087385e-87*(1.0 - cos(theta)**2)**24*(3.09353288115338e+100*cos(theta)**24 - 5.97073479159674e+100*cos(theta)**22 + 4.89092105269094e+100*cos(theta)**20 - 2.22847721825247e+100*cos(theta)**18 + 6.22184332833262e+99*cos(theta)**16 - 1.10610548059247e+99*cos(theta)**14 + 1.26134835506158e+98*cos(theta)**12 - 9.07840691756429e+96*cos(theta)**10 + 3.95860766754257e+95*cos(theta)**8 - 9.69737661340262e+93*cos(theta)**6 + 1.16368519360831e+92*cos(theta)**4 - 5.1604664905025e+89*cos(theta)**2 + 3.55404028271522e+86)*cos(48*phi)

#@torch.jit.script
def Yl72_m49(theta, phi):
    return 2.71488646524013e-89*(1.0 - cos(theta)**2)**24.5*(7.42447891476812e+101*cos(theta)**23 - 1.31356165415128e+102*cos(theta)**21 + 9.78184210538189e+101*cos(theta)**19 - 4.01125899285444e+101*cos(theta)**17 + 9.95494932533219e+100*cos(theta)**15 - 1.54854767282945e+100*cos(theta)**13 + 1.5136180260739e+99*cos(theta)**11 - 9.07840691756429e+97*cos(theta)**9 + 3.16688613403405e+96*cos(theta)**7 - 5.81842596804157e+94*cos(theta)**5 + 4.65474077443326e+92*cos(theta)**3 - 1.0320932981005e+90*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl72_m50(theta, phi):
    return 5.12516485110946e-91*(1.0 - cos(theta)**2)**25*(1.70763015039667e+103*cos(theta)**22 - 2.75847947371769e+103*cos(theta)**20 + 1.85855000002256e+103*cos(theta)**18 - 6.81914028785255e+102*cos(theta)**16 + 1.49324239879983e+102*cos(theta)**14 - 2.01311197467829e+101*cos(theta)**12 + 1.66497982868129e+100*cos(theta)**10 - 8.17056622580786e+98*cos(theta)**8 + 2.21682029382384e+97*cos(theta)**6 - 2.90921298402079e+95*cos(theta)**4 + 1.39642223232998e+93*cos(theta)**2 - 1.0320932981005e+90)*cos(50*phi)

#@torch.jit.script
def Yl72_m51(theta, phi):
    return 9.85244327058163e-93*(1.0 - cos(theta)**2)**25.5*(3.75678633087267e+104*cos(theta)**21 - 5.51695894743538e+104*cos(theta)**19 + 3.34539000004061e+104*cos(theta)**17 - 1.09106244605641e+104*cos(theta)**15 + 2.09053935831976e+103*cos(theta)**13 - 2.41573436961395e+102*cos(theta)**11 + 1.66497982868129e+101*cos(theta)**9 - 6.53645298064629e+99*cos(theta)**7 + 1.3300921762943e+98*cos(theta)**5 - 1.16368519360831e+96*cos(theta)**3 + 2.79284446465995e+93*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl72_m52(theta, phi):
    return 1.93073848323146e-94*(1.0 - cos(theta)**2)**26*(7.8892512948326e+105*cos(theta)**20 - 1.04822220001272e+106*cos(theta)**18 + 5.68716300006903e+105*cos(theta)**16 - 1.63659366908461e+105*cos(theta)**14 + 2.71770116581569e+104*cos(theta)**12 - 2.65730780657534e+103*cos(theta)**10 + 1.49848184581316e+102*cos(theta)**8 - 4.5755170864524e+100*cos(theta)**6 + 6.65046088147151e+98*cos(theta)**4 - 3.49105558082494e+96*cos(theta)**2 + 2.79284446465995e+93)*cos(52*phi)

#@torch.jit.script
def Yl72_m53(theta, phi):
    return 3.86147696646292e-96*(1.0 - cos(theta)**2)**26.5*(1.57785025896652e+107*cos(theta)**19 - 1.8867999600229e+107*cos(theta)**17 + 9.09946080011045e+106*cos(theta)**15 - 2.29123113671846e+106*cos(theta)**13 + 3.26124139897883e+105*cos(theta)**11 - 2.65730780657534e+104*cos(theta)**9 + 1.19878547665053e+103*cos(theta)**7 - 2.74531025187144e+101*cos(theta)**5 + 2.66018435258861e+99*cos(theta)**3 - 6.98211116164988e+96*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl72_m54(theta, phi):
    return 7.89207812217828e-98*(1.0 - cos(theta)**2)**27*(2.99791549203639e+108*cos(theta)**18 - 3.20755993203893e+108*cos(theta)**16 + 1.36491912001657e+108*cos(theta)**14 - 2.97860047773399e+107*cos(theta)**12 + 3.58736553887671e+106*cos(theta)**10 - 2.39157702591781e+105*cos(theta)**8 + 8.39149833655371e+103*cos(theta)**6 - 1.37265512593572e+102*cos(theta)**4 + 7.98055305776582e+99*cos(theta)**2 - 6.98211116164988e+96)*cos(54*phi)

#@torch.jit.script
def Yl72_m55(theta, phi):
    return 1.65064341078821e-99*(1.0 - cos(theta)**2)**27.5*(5.3962478856655e+109*cos(theta)**17 - 5.13209589126229e+109*cos(theta)**15 + 1.91088676802319e+109*cos(theta)**13 - 3.57432057328079e+108*cos(theta)**11 + 3.58736553887671e+107*cos(theta)**9 - 1.91326162073424e+106*cos(theta)**7 + 5.03489900193222e+104*cos(theta)**5 - 5.49062050374288e+102*cos(theta)**3 + 1.59611061155316e+100*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl72_m56(theta, phi):
    return 3.53853761906228e-101*(1.0 - cos(theta)**2)**28*(9.17362140563135e+110*cos(theta)**16 - 7.69814383689344e+110*cos(theta)**14 + 2.48415279843015e+110*cos(theta)**12 - 3.93175263060887e+109*cos(theta)**10 + 3.22862898498904e+108*cos(theta)**8 - 1.33928313451397e+107*cos(theta)**6 + 2.51744950096611e+105*cos(theta)**4 - 1.64718615112286e+103*cos(theta)**2 + 1.59611061155316e+100)*cos(56*phi)

#@torch.jit.script
def Yl72_m57(theta, phi):
    return 7.78877163442675e-103*(1.0 - cos(theta)**2)**28.5*(1.46777942490102e+112*cos(theta)**15 - 1.07774013716508e+112*cos(theta)**13 + 2.98098335811618e+111*cos(theta)**11 - 3.93175263060887e+110*cos(theta)**9 + 2.58290318799123e+109*cos(theta)**7 - 8.03569880708383e+107*cos(theta)**5 + 1.00697980038644e+106*cos(theta)**3 - 3.29437230224573e+103*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl72_m58(theta, phi):
    return 1.76380944917166e-104*(1.0 - cos(theta)**2)**29*(2.20166913735152e+113*cos(theta)**14 - 1.40106217831461e+113*cos(theta)**12 + 3.2790816939278e+112*cos(theta)**10 - 3.53857736754799e+111*cos(theta)**8 + 1.80803223159386e+110*cos(theta)**6 - 4.01784940354191e+108*cos(theta)**4 + 3.02093940115933e+106*cos(theta)**2 - 3.29437230224573e+103)*cos(58*phi)

#@torch.jit.script
def Yl72_m59(theta, phi):
    return 4.11862260923638e-106*(1.0 - cos(theta)**2)**29.5*(3.08233679229213e+114*cos(theta)**13 - 1.68127461397753e+114*cos(theta)**11 + 3.2790816939278e+113*cos(theta)**9 - 2.83086189403839e+112*cos(theta)**7 + 1.08481933895632e+111*cos(theta)**5 - 1.60713976141677e+109*cos(theta)**3 + 6.04187880231867e+106*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl72_m60(theta, phi):
    return 9.94244866882035e-108*(1.0 - cos(theta)**2)**30*(4.00703782997977e+115*cos(theta)**12 - 1.84940207537528e+115*cos(theta)**10 + 2.95117352453502e+114*cos(theta)**8 - 1.98160332582687e+113*cos(theta)**6 + 5.42409669478158e+111*cos(theta)**4 - 4.8214192842503e+109*cos(theta)**2 + 6.04187880231867e+106)*cos(60*phi)

#@torch.jit.script
def Yl72_m61(theta, phi):
    return 2.488725020231e-109*(1.0 - cos(theta)**2)**30.5*(4.80844539597573e+116*cos(theta)**11 - 1.84940207537528e+116*cos(theta)**9 + 2.36093881962802e+115*cos(theta)**7 - 1.18896199549612e+114*cos(theta)**5 + 2.16963867791263e+112*cos(theta)**3 - 9.64283856850059e+109*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl72_m62(theta, phi):
    return 6.48228575985983e-111*(1.0 - cos(theta)**2)**31*(5.2892899355733e+117*cos(theta)**10 - 1.66446186783775e+117*cos(theta)**8 + 1.65265717373961e+116*cos(theta)**6 - 5.94480997748062e+114*cos(theta)**4 + 6.5089160337379e+112*cos(theta)**2 - 9.64283856850059e+109)*cos(62*phi)

#@torch.jit.script
def Yl72_m63(theta, phi):
    return 1.76425471984068e-112*(1.0 - cos(theta)**2)**31.5*(5.2892899355733e+118*cos(theta)**9 - 1.3315694942702e+118*cos(theta)**7 + 9.91594304243767e+116*cos(theta)**5 - 2.37792399099225e+115*cos(theta)**3 + 1.30178320674758e+113*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl72_m64(theta, phi):
    return 5.0427864713945e-114*(1.0 - cos(theta)**2)**32*(4.76036094201597e+119*cos(theta)**8 - 9.32098645989141e+118*cos(theta)**6 + 4.95797152121883e+117*cos(theta)**4 - 7.13377197297674e+115*cos(theta)**2 + 1.30178320674758e+113)*cos(64*phi)

#@torch.jit.script
def Yl72_m65(theta, phi):
    return 1.52322935965797e-115*(1.0 - cos(theta)**2)**32.5*(3.80828875361278e+120*cos(theta)**7 - 5.59259187593485e+119*cos(theta)**5 + 1.98318860848753e+118*cos(theta)**3 - 1.42675439459535e+116*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl72_m66(theta, phi):
    return 4.90091013025169e-117*(1.0 - cos(theta)**2)**33*(2.66580212752894e+121*cos(theta)**6 - 2.79629593796742e+120*cos(theta)**4 + 5.9495658254626e+118*cos(theta)**2 - 1.42675439459535e+116)*cos(66*phi)

#@torch.jit.script
def Yl72_m67(theta, phi):
    return 1.69704638693964e-118*(1.0 - cos(theta)**2)**33.5*(1.59948127651737e+122*cos(theta)**5 - 1.11851837518697e+121*cos(theta)**3 + 1.18991316509252e+119*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl72_m68(theta, phi):
    return 6.41423243311855e-120*(1.0 - cos(theta)**2)**34*(7.99740638258683e+122*cos(theta)**4 - 3.35555512556091e+121*cos(theta)**2 + 1.18991316509252e+119)*cos(68*phi)

#@torch.jit.script
def Yl72_m69(theta, phi):
    return 2.70087908285898e-121*(1.0 - cos(theta)**2)**34.5*(3.19896255303473e+123*cos(theta)**3 - 6.71111025112181e+121*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl72_m70(theta, phi):
    return 1.30858019143794e-122*(1.0 - cos(theta)**2)**35*(9.59688765910419e+123*cos(theta)**2 - 6.71111025112181e+121)*cos(70*phi)

#@torch.jit.script
def Yl72_m71(theta, phi):
    return 14.8517534838492*(1.0 - cos(theta)**2)**35.5*cos(71*phi)*cos(theta)

#@torch.jit.script
def Yl72_m72(theta, phi):
    return 1.2376461236541*(1.0 - cos(theta)**2)**36*cos(72*phi)

#@torch.jit.script
def Yl73_m_minus_73(theta, phi):
    return 1.24187740479589*(1.0 - cos(theta)**2)**36.5*sin(73*phi)

#@torch.jit.script
def Yl73_m_minus_72(theta, phi):
    return 15.005661775717*(1.0 - cos(theta)**2)**36*sin(72*phi)*cos(theta)

#@torch.jit.script
def Yl73_m_minus_71(theta, phi):
    return 9.18175591389851e-125*(1.0 - cos(theta)**2)**35.5*(1.39154871057011e+126*cos(theta)**2 - 9.59688765910419e+123)*sin(71*phi)

#@torch.jit.script
def Yl73_m_minus_70(theta, phi):
    return 1.90839212946819e-123*(1.0 - cos(theta)**2)**35*(4.63849570190036e+125*cos(theta)**3 - 9.59688765910419e+123*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl73_m_minus_69(theta, phi):
    return 4.56421013685262e-122*(1.0 - cos(theta)**2)**34.5*(1.15962392547509e+125*cos(theta)**4 - 4.7984438295521e+123*cos(theta)**2 + 1.67777756278045e+121)*sin(69*phi)

#@torch.jit.script
def Yl73_m_minus_68(theta, phi):
    return 1.21617145432201e-120*(1.0 - cos(theta)**2)**34*(2.31924785095018e+124*cos(theta)**5 - 1.59948127651737e+123*cos(theta)**3 + 1.67777756278045e+121*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl73_m_minus_67(theta, phi):
    return 3.53736591736893e-119*(1.0 - cos(theta)**2)**33.5*(3.86541308491697e+123*cos(theta)**6 - 3.99870319129341e+122*cos(theta)**4 + 8.38888781390227e+120*cos(theta)**2 - 1.98318860848753e+118)*sin(67*phi)

#@torch.jit.script
def Yl73_m_minus_66(theta, phi):
    return 1.1073706913539e-117*(1.0 - cos(theta)**2)**33*(5.52201869273852e+122*cos(theta)**7 - 7.99740638258683e+121*cos(theta)**5 + 2.79629593796742e+120*cos(theta)**3 - 1.98318860848753e+118*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl73_m_minus_65(theta, phi):
    return 3.69271183692067e-116*(1.0 - cos(theta)**2)**32.5*(6.90252336592316e+121*cos(theta)**8 - 1.33290106376447e+121*cos(theta)**6 + 6.99073984491856e+119*cos(theta)**4 - 9.91594304243767e+117*cos(theta)**2 + 1.78344299324419e+115)*sin(65*phi)

#@torch.jit.script
def Yl73_m_minus_64(theta, phi):
    return 1.30138625789899e-114*(1.0 - cos(theta)**2)**32*(7.66947040658128e+120*cos(theta)**9 - 1.90414437680639e+120*cos(theta)**7 + 1.39814796898371e+119*cos(theta)**5 - 3.30531434747922e+117*cos(theta)**3 + 1.78344299324419e+115*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl73_m_minus_63(theta, phi):
    return 4.81688746326942e-113*(1.0 - cos(theta)**2)**31.5*(7.66947040658128e+119*cos(theta)**10 - 2.38018047100798e+119*cos(theta)**8 + 2.33024661497285e+118*cos(theta)**6 - 8.26328586869806e+116*cos(theta)**4 + 8.91721496622093e+114*cos(theta)**2 - 1.30178320674758e+112)*sin(63*phi)

#@torch.jit.script
def Yl73_m_minus_62(theta, phi):
    return 1.86308340208827e-111*(1.0 - cos(theta)**2)**31*(6.9722458241648e+118*cos(theta)**11 - 2.64464496778665e+118*cos(theta)**9 + 3.3289237356755e+117*cos(theta)**7 - 1.65265717373961e+116*cos(theta)**5 + 2.97240498874031e+114*cos(theta)**3 - 1.30178320674758e+112*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl73_m_minus_61(theta, phi):
    return 7.49876604267769e-110*(1.0 - cos(theta)**2)**30.5*(5.81020485347067e+117*cos(theta)**12 - 2.64464496778665e+117*cos(theta)**10 + 4.16115466959438e+116*cos(theta)**8 - 2.75442862289935e+115*cos(theta)**6 + 7.43101247185077e+113*cos(theta)**4 - 6.5089160337379e+111*cos(theta)**2 + 8.03569880708383e+108)*sin(61*phi)

#@torch.jit.script
def Yl73_m_minus_60(theta, phi):
    return 3.12978049306378e-108*(1.0 - cos(theta)**2)**30*(4.46938834882359e+116*cos(theta)**13 - 2.40422269798786e+116*cos(theta)**11 + 4.6235051884382e+115*cos(theta)**9 - 3.93489803271336e+114*cos(theta)**7 + 1.48620249437015e+113*cos(theta)**5 - 2.16963867791263e+111*cos(theta)**3 + 8.03569880708383e+108*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl73_m_minus_59(theta, phi):
    return 1.3505283888363e-106*(1.0 - cos(theta)**2)**29.5*(3.19242024915971e+115*cos(theta)**14 - 2.00351891498989e+115*cos(theta)**12 + 4.6235051884382e+114*cos(theta)**10 - 4.9186225408917e+113*cos(theta)**8 + 2.47700415728359e+112*cos(theta)**6 - 5.42409669478158e+110*cos(theta)**4 + 4.01784940354191e+108*cos(theta)**2 - 4.31562771594191e+105)*sin(59*phi)

#@torch.jit.script
def Yl73_m_minus_58(theta, phi):
    return 6.00947195644053e-105*(1.0 - cos(theta)**2)**29*(2.12828016610647e+114*cos(theta)**15 - 1.54116839614607e+114*cos(theta)**13 + 4.20318653494382e+113*cos(theta)**11 - 5.46513615654633e+112*cos(theta)**9 + 3.53857736754799e+111*cos(theta)**7 - 1.08481933895632e+110*cos(theta)**5 + 1.33928313451397e+108*cos(theta)**3 - 4.31562771594191e+105*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl73_m_minus_57(theta, phi):
    return 2.75126201400801e-103*(1.0 - cos(theta)**2)**28.5*(1.33017510381655e+113*cos(theta)**16 - 1.10083456867576e+113*cos(theta)**14 + 3.50265544578651e+112*cos(theta)**12 - 5.46513615654633e+111*cos(theta)**10 + 4.42322170943498e+110*cos(theta)**8 - 1.80803223159386e+109*cos(theta)**6 + 3.34820783628493e+107*cos(theta)**4 - 2.15781385797095e+105*cos(theta)**2 + 2.05898268890358e+102)*sin(57*phi)

#@torch.jit.script
def Yl73_m_minus_56(theta, phi):
    return 1.29338580091513e-101*(1.0 - cos(theta)**2)**28*(7.82455943421497e+111*cos(theta)**17 - 7.33889712450508e+111*cos(theta)**15 + 2.6943503429127e+111*cos(theta)**13 - 4.9683055968603e+110*cos(theta)**11 + 4.91469078826109e+109*cos(theta)**9 - 2.58290318799123e+108*cos(theta)**7 + 6.69641567256986e+106*cos(theta)**5 - 7.19271285990318e+104*cos(theta)**3 + 2.05898268890358e+102*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl73_m_minus_55(theta, phi):
    return 6.23245564707892e-100*(1.0 - cos(theta)**2)**27.5*(4.34697746345276e+110*cos(theta)**18 - 4.58681070281567e+110*cos(theta)**16 + 1.92453595922336e+110*cos(theta)**14 - 4.14025466405025e+109*cos(theta)**12 + 4.91469078826109e+108*cos(theta)**10 - 3.22862898498904e+107*cos(theta)**8 + 1.11606927876164e+106*cos(theta)**6 - 1.79817821497579e+104*cos(theta)**4 + 1.02949134445179e+102*cos(theta)**2 - 8.86728117529535e+98)*sin(55*phi)

#@torch.jit.script
def Yl73_m_minus_54(theta, phi):
    return 3.07355494909891e-98*(1.0 - cos(theta)**2)**27*(2.28788287550145e+109*cos(theta)**19 - 2.69812394283275e+109*cos(theta)**17 + 1.28302397281557e+109*cos(theta)**15 - 3.18481128003866e+108*cos(theta)**13 + 4.46790071660099e+107*cos(theta)**11 - 3.58736553887671e+106*cos(theta)**9 + 1.5943846839452e+105*cos(theta)**7 - 3.59635642995159e+103*cos(theta)**5 + 3.4316378148393e+101*cos(theta)**3 - 8.86728117529535e+98*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl73_m_minus_53(theta, phi):
    return 1.54902290699109e-96*(1.0 - cos(theta)**2)**26.5*(1.14394143775073e+108*cos(theta)**20 - 1.49895774601819e+108*cos(theta)**18 + 8.01889983009733e+107*cos(theta)**16 - 2.27486520002761e+107*cos(theta)**14 + 3.72325059716749e+106*cos(theta)**12 - 3.58736553887671e+105*cos(theta)**10 + 1.99298085493151e+104*cos(theta)**8 - 5.99392738325265e+102*cos(theta)**6 + 8.57909453709825e+100*cos(theta)**4 - 4.43364058764768e+98*cos(theta)**2 + 3.49105558082494e+95)*sin(53*phi)

#@torch.jit.script
def Yl73_m_minus_52(theta, phi):
    return 7.96806301622279e-95*(1.0 - cos(theta)**2)**26*(5.44734017976537e+106*cos(theta)**21 - 7.8892512948326e+106*cos(theta)**19 + 4.71699990005725e+106*cos(theta)**17 - 1.51657680001841e+106*cos(theta)**15 + 2.86403892089807e+105*cos(theta)**13 - 3.26124139897883e+104*cos(theta)**11 + 2.21442317214612e+103*cos(theta)**9 - 8.56275340464664e+101*cos(theta)**7 + 1.71581890741965e+100*cos(theta)**5 - 1.47788019588256e+98*cos(theta)**3 + 3.49105558082494e+95*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl73_m_minus_51(theta, phi):
    return 4.1784874970959e-93*(1.0 - cos(theta)**2)**25.5*(2.47606371807517e+105*cos(theta)**22 - 3.9446256474163e+105*cos(theta)**20 + 2.62055550003181e+105*cos(theta)**18 - 9.47860500011505e+104*cos(theta)**16 + 2.04574208635577e+104*cos(theta)**14 - 2.71770116581569e+103*cos(theta)**12 + 2.21442317214612e+102*cos(theta)**10 - 1.07034417558083e+101*cos(theta)**8 + 2.85969817903275e+99*cos(theta)**6 - 3.6947004897064e+97*cos(theta)**4 + 1.74552779041247e+95*cos(theta)**2 - 1.26947475666362e+92)*sin(51*phi)

#@torch.jit.script
def Yl73_m_minus_50(theta, phi):
    return 2.23148446423405e-91*(1.0 - cos(theta)**2)**25*(1.07654944264138e+104*cos(theta)**23 - 1.87839316543633e+104*cos(theta)**21 + 1.37923973685885e+104*cos(theta)**19 - 5.57565000006768e+103*cos(theta)**17 + 1.36382805757051e+103*cos(theta)**15 - 2.09053935831976e+102*cos(theta)**13 + 2.01311197467829e+101*cos(theta)**11 - 1.18927130620092e+100*cos(theta)**9 + 4.08528311290393e+98*cos(theta)**7 - 7.38940097941279e+96*cos(theta)**5 + 5.81842596804157e+94*cos(theta)**3 - 1.26947475666362e+92*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl73_m_minus_49(theta, phi):
    return 1.21241707520457e-89*(1.0 - cos(theta)**2)**24.5*(4.4856226776724e+102*cos(theta)**24 - 8.53815075198333e+102*cos(theta)**22 + 6.89619868429423e+102*cos(theta)**20 - 3.09758333337093e+102*cos(theta)**18 + 8.52392535981569e+101*cos(theta)**16 - 1.49324239879983e+101*cos(theta)**14 + 1.67759331223191e+100*cos(theta)**12 - 1.18927130620092e+99*cos(theta)**10 + 5.10660389112991e+97*cos(theta)**8 - 1.23156682990213e+96*cos(theta)**6 + 1.45460649201039e+94*cos(theta)**4 - 6.34737378331808e+91*cos(theta)**2 + 4.30038874208542e+88)*sin(49*phi)

#@torch.jit.script
def Yl73_m_minus_48(theta, phi):
    return 6.69579214951838e-88*(1.0 - cos(theta)**2)**24*(1.79424907106896e+101*cos(theta)**25 - 3.71223945738406e+101*cos(theta)**23 + 3.2839041353782e+101*cos(theta)**21 - 1.63030701756365e+101*cos(theta)**19 + 5.01407374106805e+100*cos(theta)**17 - 9.95494932533219e+99*cos(theta)**15 + 1.29045639402454e+99*cos(theta)**13 - 1.08115573290993e+98*cos(theta)**11 + 5.67400432347768e+96*cos(theta)**9 - 1.75938118557447e+95*cos(theta)**7 + 2.90921298402078e+93*cos(theta)**5 - 2.11579126110603e+91*cos(theta)**3 + 4.30038874208542e+88*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl73_m_minus_47(theta, phi):
    return 3.75561723122912e-86*(1.0 - cos(theta)**2)**23.5*(6.90095796564985e+99*cos(theta)**26 - 1.54676644057669e+100*cos(theta)**24 + 1.49268369789918e+100*cos(theta)**22 - 8.15153508781824e+99*cos(theta)**20 + 2.78559652281559e+99*cos(theta)**18 - 6.22184332833262e+98*cos(theta)**16 + 9.21754567160388e+97*cos(theta)**14 - 9.00963110758274e+96*cos(theta)**12 + 5.67400432347768e+95*cos(theta)**10 - 2.19922648196809e+94*cos(theta)**8 + 4.84868830670131e+92*cos(theta)**6 - 5.28947815276506e+90*cos(theta)**4 + 2.15019437104271e+88*cos(theta)**2 - 1.36693857027509e+85)*sin(47*phi)

#@torch.jit.script
def Yl73_m_minus_46(theta, phi):
    return 2.13773480468267e-84*(1.0 - cos(theta)**2)**23*(2.55591035764809e+98*cos(theta)**27 - 6.18706576230676e+98*cos(theta)**25 + 6.4899291213008e+98*cos(theta)**23 - 3.88168337515154e+98*cos(theta)**21 + 1.46610343306083e+98*cos(theta)**19 - 3.65990784019566e+97*cos(theta)**17 + 6.14503044773592e+96*cos(theta)**15 - 6.93048546737134e+95*cos(theta)**13 + 5.15818574861607e+94*cos(theta)**11 - 2.44358497996455e+93*cos(theta)**9 + 6.92669758100187e+91*cos(theta)**7 - 1.05789563055301e+90*cos(theta)**5 + 7.16731457014236e+87*cos(theta)**3 - 1.36693857027509e+85*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl73_m_minus_45(theta, phi):
    return 1.23397489589721e-82*(1.0 - cos(theta)**2)**22.5*(9.12825127731462e+96*cos(theta)**28 - 2.37964067781029e+97*cos(theta)**26 + 2.70413713387533e+97*cos(theta)**24 - 1.76440153415979e+97*cos(theta)**22 + 7.33051716530417e+96*cos(theta)**20 - 2.03328213344203e+96*cos(theta)**18 + 3.84064402983495e+95*cos(theta)**16 - 4.9503467624081e+94*cos(theta)**14 + 4.29848812384673e+93*cos(theta)**12 - 2.44358497996455e+92*cos(theta)**10 + 8.65837197625234e+90*cos(theta)**8 - 1.76315938425502e+89*cos(theta)**6 + 1.79182864253559e+87*cos(theta)**4 - 6.83469285137543e+84*cos(theta)**2 + 4.10245669350266e+81)*sin(45*phi)

#@torch.jit.script
def Yl73_m_minus_44(theta, phi):
    return 7.21848946633358e-81*(1.0 - cos(theta)**2)**22*(3.14767285424642e+95*cos(theta)**29 - 8.81348399188998e+95*cos(theta)**27 + 1.08165485355013e+96*cos(theta)**25 - 7.67131101808605e+95*cos(theta)**23 + 3.49072245966865e+95*cos(theta)**21 - 1.07014849128528e+95*cos(theta)**19 + 2.25920237049115e+94*cos(theta)**17 - 3.30023117493873e+93*cos(theta)**15 + 3.30652932603595e+92*cos(theta)**13 - 2.22144089087686e+91*cos(theta)**11 + 9.62041330694704e+89*cos(theta)**9 - 2.51879912036432e+88*cos(theta)**7 + 3.58365728507118e+86*cos(theta)**5 - 2.27823095045848e+84*cos(theta)**3 + 4.10245669350266e+81*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl73_m_minus_43(theta, phi):
    return 4.27661234525935e-79*(1.0 - cos(theta)**2)**21.5*(1.04922428474881e+94*cos(theta)**30 - 3.14767285424642e+94*cos(theta)**28 + 4.16021097519282e+94*cos(theta)**26 - 3.19637959086919e+94*cos(theta)**24 + 1.58669202712212e+94*cos(theta)**22 - 5.3507424564264e+93*cos(theta)**20 + 1.25511242805064e+93*cos(theta)**18 - 2.06264448433671e+92*cos(theta)**16 + 2.36180666145425e+91*cos(theta)**14 - 1.85120074239739e+90*cos(theta)**12 + 9.62041330694704e+88*cos(theta)**10 - 3.14849890045539e+87*cos(theta)**8 + 5.9727621417853e+85*cos(theta)**6 - 5.69557737614619e+83*cos(theta)**4 + 2.05122834675133e+81*cos(theta)**2 - 1.16879108076999e+78)*sin(43*phi)

#@torch.jit.script
def Yl73_m_minus_42(theta, phi):
    return 2.56454147350442e-77*(1.0 - cos(theta)**2)**21*(3.38459446693163e+92*cos(theta)**31 - 1.08540443249877e+93*cos(theta)**29 + 1.54081887970104e+93*cos(theta)**27 - 1.27855183634768e+93*cos(theta)**25 + 6.89866098748746e+92*cos(theta)**23 - 2.54797259829829e+92*cos(theta)**21 + 6.60585488447704e+91*cos(theta)**19 - 1.21332028490395e+91*cos(theta)**17 + 1.57453777430283e+90*cos(theta)**15 - 1.42400057107491e+89*cos(theta)**13 + 8.74583027904276e+87*cos(theta)**11 - 3.49833211161711e+86*cos(theta)**9 + 8.53251734540758e+84*cos(theta)**7 - 1.13911547522924e+83*cos(theta)**5 + 6.83742782250443e+80*cos(theta)**3 - 1.16879108076999e+78*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl73_m_minus_41(theta, phi):
    return 1.55572788517508e-75*(1.0 - cos(theta)**2)**20.5*(1.05768577091614e+91*cos(theta)**32 - 3.61801477499588e+91*cos(theta)**30 + 5.50292457036087e+91*cos(theta)**28 - 4.91750706287567e+91*cos(theta)**26 + 2.87444207811977e+91*cos(theta)**24 - 1.15816936286286e+91*cos(theta)**22 + 3.30292744223852e+90*cos(theta)**20 - 6.74066824946637e+89*cos(theta)**18 + 9.84086108939269e+88*cos(theta)**16 - 1.01714326505351e+88*cos(theta)**14 + 7.2881918992023e+86*cos(theta)**12 - 3.49833211161711e+85*cos(theta)**10 + 1.06656466817595e+84*cos(theta)**8 - 1.89852579204873e+82*cos(theta)**6 + 1.70935695562611e+80*cos(theta)**4 - 5.84395540384994e+77*cos(theta)**2 + 3.17606271948366e+74)*sin(41*phi)

#@torch.jit.script
def Yl73_m_minus_40(theta, phi):
    return 9.54207952634015e-74*(1.0 - cos(theta)**2)**20*(3.20510839671556e+89*cos(theta)**33 - 1.16710154032125e+90*cos(theta)**31 + 1.89756019667616e+90*cos(theta)**29 - 1.82129891217618e+90*cos(theta)**27 + 1.14977683124791e+90*cos(theta)**25 - 5.03551896896895e+89*cos(theta)**23 + 1.57282259154215e+89*cos(theta)**21 - 3.54772013129809e+88*cos(theta)**19 + 5.78874181728982e+87*cos(theta)**17 - 6.78095510035672e+86*cos(theta)**15 + 5.60630146092485e+85*cos(theta)**13 - 3.18030191965191e+84*cos(theta)**11 + 1.18507185352883e+83*cos(theta)**9 - 2.71217970292676e+81*cos(theta)**7 + 3.41871391125221e+79*cos(theta)**5 - 1.94798513461665e+77*cos(theta)**3 + 3.17606271948366e+74*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl73_m_minus_39(theta, phi):
    return 5.91455006100594e-72*(1.0 - cos(theta)**2)**19.5*(9.42678940210459e+87*cos(theta)**34 - 3.64719231350392e+88*cos(theta)**32 + 6.32520065558721e+88*cos(theta)**30 - 6.50463897205777e+88*cos(theta)**28 + 4.42221858172273e+88*cos(theta)**26 - 2.09813290373706e+88*cos(theta)**24 + 7.14919359791887e+87*cos(theta)**22 - 1.77386006564904e+87*cos(theta)**20 + 3.21596767627212e+86*cos(theta)**18 - 4.23809693772295e+85*cos(theta)**16 + 4.00450104351775e+84*cos(theta)**14 - 2.65025159970993e+83*cos(theta)**12 + 1.18507185352883e+82*cos(theta)**10 - 3.39022462865845e+80*cos(theta)**8 + 5.69785651875369e+78*cos(theta)**6 - 4.86996283654161e+76*cos(theta)**4 + 1.58803135974183e+74*cos(theta)**2 - 8.26669109704233e+70)*sin(39*phi)

#@torch.jit.script
def Yl73_m_minus_38(theta, phi):
    return 3.70309407796574e-70*(1.0 - cos(theta)**2)**19*(2.69336840060131e+86*cos(theta)**35 - 1.10520979197088e+87*cos(theta)**33 + 2.04038730825394e+87*cos(theta)**31 - 2.24297895588199e+87*cos(theta)**29 + 1.63785873397138e+87*cos(theta)**27 - 8.39253161494824e+86*cos(theta)**25 + 3.10834504257342e+86*cos(theta)**23 - 8.44695269356688e+85*cos(theta)**21 + 1.69261456645901e+85*cos(theta)**19 - 2.49299819866056e+84*cos(theta)**17 + 2.66966736234517e+83*cos(theta)**15 - 2.03865507669994e+82*cos(theta)**13 + 1.07733804866257e+81*cos(theta)**11 - 3.76691625406494e+79*cos(theta)**9 + 8.13979502679098e+77*cos(theta)**7 - 9.73992567308323e+75*cos(theta)**5 + 5.2934378658061e+73*cos(theta)**3 - 8.26669109704233e+70*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl73_m_minus_37(theta, phi):
    return 2.34087102118119e-68*(1.0 - cos(theta)**2)**18.5*(7.4815788905592e+84*cos(theta)**36 - 3.25061703520848e+85*cos(theta)**34 + 6.37621033829356e+85*cos(theta)**32 - 7.47659651960663e+85*cos(theta)**30 + 5.84949547846922e+85*cos(theta)**28 - 3.22789677498009e+85*cos(theta)**26 + 1.29514376773893e+85*cos(theta)**24 - 3.83952395162131e+84*cos(theta)**22 + 8.46307283229506e+83*cos(theta)**20 - 1.38499899925587e+83*cos(theta)**18 + 1.66854210146573e+82*cos(theta)**16 - 1.45618219764282e+81*cos(theta)**14 + 8.9778170721881e+79*cos(theta)**12 - 3.76691625406494e+78*cos(theta)**10 + 1.01747437834887e+77*cos(theta)**8 - 1.62332094551387e+75*cos(theta)**6 + 1.32335946645153e+73*cos(theta)**4 - 4.13334554852116e+70*cos(theta)**2 + 2.06874151577636e+67)*sin(37*phi)

#@torch.jit.script
def Yl73_m_minus_36(theta, phi):
    return 1.49339498964172e-66*(1.0 - cos(theta)**2)**18*(2.02204834879978e+83*cos(theta)**37 - 9.2874772434528e+83*cos(theta)**35 + 1.93218495099805e+84*cos(theta)**33 - 2.41180532890537e+84*cos(theta)**31 + 2.0170674063687e+84*cos(theta)**29 - 1.1955173240667e+84*cos(theta)**27 + 5.18057507095571e+83*cos(theta)**25 - 1.66935823983535e+83*cos(theta)**23 + 4.03003468204527e+82*cos(theta)**21 - 7.28946841713614e+81*cos(theta)**19 + 9.8149535380337e+80*cos(theta)**17 - 9.70788131761879e+79*cos(theta)**15 + 6.90601313245239e+78*cos(theta)**13 - 3.42446932187722e+77*cos(theta)**11 + 1.1305270870543e+76*cos(theta)**9 - 2.31902992216267e+74*cos(theta)**7 + 2.64671893290305e+72*cos(theta)**5 - 1.37778184950705e+70*cos(theta)**3 + 2.06874151577636e+67*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl73_m_minus_35(theta, phi):
    return 9.61124697469081e-65*(1.0 - cos(theta)**2)**17.5*(5.32117986526259e+81*cos(theta)**38 - 2.579854789848e+82*cos(theta)**36 + 5.68289691470014e+82*cos(theta)**34 - 7.53689165282927e+82*cos(theta)**32 + 6.72355802122899e+82*cos(theta)**30 - 4.26970472880965e+82*cos(theta)**28 + 1.9925288734445e+82*cos(theta)**26 - 6.9556593326473e+81*cos(theta)**24 + 1.83183394638421e+81*cos(theta)**22 - 3.64473420856807e+80*cos(theta)**20 + 5.45275196557428e+79*cos(theta)**18 - 6.06742582351174e+78*cos(theta)**16 + 4.93286652318028e+77*cos(theta)**14 - 2.85372443489768e+76*cos(theta)**12 + 1.1305270870543e+75*cos(theta)**10 - 2.89878740270334e+73*cos(theta)**8 + 4.41119822150509e+71*cos(theta)**6 - 3.44445462376764e+69*cos(theta)**4 + 1.03437075788818e+67*cos(theta)**2 - 4.99454735822395e+63)*sin(35*phi)

#@torch.jit.script
def Yl73_m_minus_34(theta, phi):
    return 6.23769188191126e-63*(1.0 - cos(theta)**2)**17*(1.36440509365707e+80*cos(theta)**39 - 6.97258051310271e+80*cos(theta)**37 + 1.62368483277147e+81*cos(theta)**35 - 2.28390656146341e+81*cos(theta)**33 + 2.16888968426741e+81*cos(theta)**31 - 1.4723119754516e+81*cos(theta)**29 + 7.37973656831297e+80*cos(theta)**27 - 2.78226373305892e+80*cos(theta)**25 + 7.96449541906179e+79*cos(theta)**23 - 1.73558771836575e+79*cos(theta)**21 + 2.86986945556541e+78*cos(theta)**19 - 3.56907401383044e+77*cos(theta)**17 + 3.28857768212018e+76*cos(theta)**15 - 2.19517264222899e+75*cos(theta)**13 + 1.02775189732209e+74*cos(theta)**11 - 3.2208748918926e+72*cos(theta)**9 + 6.30171174500727e+70*cos(theta)**7 - 6.88890924753527e+68*cos(theta)**5 + 3.44790252629393e+66*cos(theta)**3 - 4.99454735822395e+63*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl73_m_minus_33(theta, phi):
    return 4.08080462725762e-61*(1.0 - cos(theta)**2)**16.5*(3.41101273414269e+78*cos(theta)**40 - 1.83488960871124e+79*cos(theta)**38 + 4.51023564658741e+79*cos(theta)**36 - 6.71737223959828e+79*cos(theta)**34 + 6.77778026333567e+79*cos(theta)**32 - 4.90770658483868e+79*cos(theta)**30 + 2.63562020296892e+79*cos(theta)**28 - 1.07010143579189e+79*cos(theta)**26 + 3.31853975794241e+78*cos(theta)**24 - 7.88903508348067e+77*cos(theta)**22 + 1.4349347277827e+77*cos(theta)**20 - 1.98281889657246e+76*cos(theta)**18 + 2.05536105132512e+75*cos(theta)**16 - 1.56798045873499e+74*cos(theta)**14 + 8.56459914435078e+72*cos(theta)**12 - 3.2208748918926e+71*cos(theta)**10 + 7.87713968125908e+69*cos(theta)**8 - 1.14815154125588e+68*cos(theta)**6 + 8.61975631573483e+65*cos(theta)**4 - 2.49727367911197e+63*cos(theta)**2 + 1.16695031734204e+60)*sin(33*phi)

#@torch.jit.script
def Yl73_m_minus_32(theta, phi):
    return 2.69023775900592e-59*(1.0 - cos(theta)**2)**16*(8.31954325400655e+76*cos(theta)**41 - 4.70484515054164e+77*cos(theta)**39 + 1.21898260718579e+78*cos(theta)**37 - 1.91924921131379e+78*cos(theta)**35 + 2.05387280707142e+78*cos(theta)**33 - 1.58313115639957e+78*cos(theta)**31 + 9.08834552747903e+77*cos(theta)**29 - 3.96333865108108e+77*cos(theta)**27 + 1.32741590317696e+77*cos(theta)**25 - 3.43001525368725e+76*cos(theta)**23 + 6.83302251325097e+75*cos(theta)**21 - 1.04358889293288e+75*cos(theta)**19 + 1.20903591254419e+74*cos(theta)**17 - 1.04532030582333e+73*cos(theta)**15 + 6.58815318796214e+71*cos(theta)**13 - 2.92806808353873e+70*cos(theta)**11 + 8.7523774236212e+68*cos(theta)**9 - 1.6402164875084e+67*cos(theta)**7 + 1.72395126314697e+65*cos(theta)**5 - 8.32424559703991e+62*cos(theta)**3 + 1.16695031734204e+60*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl73_m_minus_31(theta, phi):
    return 1.78652854082763e-57*(1.0 - cos(theta)**2)**15.5*(1.98084363190632e+75*cos(theta)**42 - 1.17621128763541e+76*cos(theta)**40 + 3.20784896627839e+76*cos(theta)**38 - 5.33124780920498e+76*cos(theta)**36 + 6.04080237373946e+76*cos(theta)**34 - 4.94728486374867e+76*cos(theta)**32 + 3.02944850915968e+76*cos(theta)**30 - 1.41547808967181e+76*cos(theta)**28 + 5.10544578144986e+75*cos(theta)**26 - 1.42917302236969e+75*cos(theta)**24 + 3.10591932420499e+74*cos(theta)**22 - 5.21794446466438e+73*cos(theta)**20 + 6.71686618080103e+72*cos(theta)**18 - 6.53325191139579e+71*cos(theta)**16 + 4.70582370568724e+70*cos(theta)**14 - 2.44005673628227e+69*cos(theta)**12 + 8.7523774236212e+67*cos(theta)**10 - 2.0502706093855e+66*cos(theta)**8 + 2.87325210524494e+64*cos(theta)**6 - 2.08106139925998e+62*cos(theta)**4 + 5.83475158671022e+59*cos(theta)**2 - 2.64614584431302e+56)*sin(31*phi)

#@torch.jit.script
def Yl73_m_minus_30(theta, phi):
    return 1.19470548102875e-55*(1.0 - cos(theta)**2)**15*(4.60661309745656e+73*cos(theta)**43 - 2.86880801862295e+74*cos(theta)**41 + 8.22525375968818e+74*cos(theta)**39 - 1.44087778627162e+75*cos(theta)**37 + 1.72594353535413e+75*cos(theta)**35 - 1.49917723143899e+75*cos(theta)**33 + 9.77241454567638e+74*cos(theta)**31 - 4.88095892990281e+74*cos(theta)**29 + 1.89090584498143e+74*cos(theta)**27 - 5.71669208947875e+73*cos(theta)**25 + 1.35039970617608e+73*cos(theta)**23 - 2.48473545936399e+72*cos(theta)**21 + 3.53519272673738e+71*cos(theta)**19 - 3.84308935964458e+70*cos(theta)**17 + 3.1372158037915e+69*cos(theta)**15 - 1.87696672021713e+68*cos(theta)**13 + 7.95670674874655e+66*cos(theta)**11 - 2.27807845487278e+65*cos(theta)**9 + 4.10464586463563e+63*cos(theta)**7 - 4.16212279851995e+61*cos(theta)**5 + 1.94491719557007e+59*cos(theta)**3 - 2.64614584431302e+56*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl73_m_minus_29(theta, phi):
    return 8.04277291533547e-54*(1.0 - cos(theta)**2)**14.5*(1.04695752214922e+72*cos(theta)**44 - 6.83049528243559e+72*cos(theta)**42 + 2.05631343992204e+73*cos(theta)**40 - 3.7917836480832e+73*cos(theta)**38 + 4.79428759820592e+73*cos(theta)**36 - 4.40934479834997e+73*cos(theta)**34 + 3.05387954552387e+73*cos(theta)**32 - 1.6269863099676e+73*cos(theta)**30 + 6.75323516064797e+72*cos(theta)**28 - 2.19872772672259e+72*cos(theta)**26 + 5.62666544240034e+71*cos(theta)**24 - 1.12942520880181e+71*cos(theta)**22 + 1.76759636336869e+70*cos(theta)**20 - 2.13504964424699e+69*cos(theta)**18 + 1.96075987736968e+68*cos(theta)**16 - 1.34069051444081e+67*cos(theta)**14 + 6.63058895728879e+65*cos(theta)**12 - 2.27807845487278e+64*cos(theta)**10 + 5.13080733079454e+62*cos(theta)**8 - 6.93687133086659e+60*cos(theta)**6 + 4.86229298892518e+58*cos(theta)**4 - 1.32307292215651e+56*cos(theta)**2 + 5.83880371648946e+52)*sin(29*phi)

#@torch.jit.script
def Yl73_m_minus_28(theta, phi):
    return 5.44894155235245e-52*(1.0 - cos(theta)**2)**14*(2.32657227144271e+70*cos(theta)**45 - 1.58848727498502e+71*cos(theta)**43 + 5.01539863395621e+71*cos(theta)**41 - 9.72252217457231e+71*cos(theta)**39 + 1.29575340492052e+72*cos(theta)**37 - 1.25981279952856e+72*cos(theta)**35 + 9.25418044098142e+71*cos(theta)**33 - 5.24834293537936e+71*cos(theta)**31 + 2.32870177953378e+71*cos(theta)**29 - 8.1434360248985e+70*cos(theta)**27 + 2.25066617696014e+70*cos(theta)**25 - 4.91054438609484e+69*cos(theta)**23 + 8.41712553985092e+68*cos(theta)**21 - 1.12371033907736e+68*cos(theta)**19 + 1.15338816315864e+67*cos(theta)**17 - 8.93793676293873e+65*cos(theta)**15 + 5.1004530440683e+64*cos(theta)**13 - 2.0709804135207e+63*cos(theta)**11 + 5.70089703421615e+61*cos(theta)**9 - 9.90981618695227e+59*cos(theta)**7 + 9.72458597785036e+57*cos(theta)**5 - 4.41024307385504e+55*cos(theta)**3 + 5.83880371648946e+52*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl73_m_minus_27(theta, phi):
    return 3.7140842604102e-50*(1.0 - cos(theta)**2)**13.5*(5.05776580748415e+68*cos(theta)**46 - 3.61019835223869e+69*cos(theta)**44 + 1.19414253189433e+70*cos(theta)**42 - 2.43063054364308e+70*cos(theta)**40 + 3.40987738136979e+70*cos(theta)**38 - 3.49947999869045e+70*cos(theta)**36 + 2.72181777675924e+70*cos(theta)**34 - 1.64010716730605e+70*cos(theta)**32 + 7.76233926511261e+69*cos(theta)**30 - 2.90837000889232e+69*cos(theta)**28 + 8.6564083729236e+68*cos(theta)**26 - 2.04606016087285e+68*cos(theta)**24 + 3.82596615447769e+67*cos(theta)**22 - 5.61855169538682e+66*cos(theta)**20 + 6.40771201754799e+65*cos(theta)**18 - 5.58621047683671e+64*cos(theta)**16 + 3.64318074576307e+63*cos(theta)**14 - 1.72581701126725e+62*cos(theta)**12 + 5.70089703421615e+60*cos(theta)**10 - 1.23872702336903e+59*cos(theta)**8 + 1.62076432964173e+57*cos(theta)**6 - 1.10256076846376e+55*cos(theta)**4 + 2.91940185824473e+52*cos(theta)**2 - 1.25673777797879e+49)*sin(27*phi)

#@torch.jit.script
def Yl73_m_minus_26(theta, phi):
    return 2.54624788461583e-48*(1.0 - cos(theta)**2)**13*(1.0761203845711e+67*cos(theta)**47 - 8.02266300497486e+67*cos(theta)**45 + 2.77707565556822e+68*cos(theta)**43 - 5.92836717961726e+68*cos(theta)**41 + 8.7432753368456e+68*cos(theta)**39 - 9.45805405051473e+68*cos(theta)**37 + 7.77662221931211e+68*cos(theta)**35 - 4.97002171910925e+68*cos(theta)**33 + 2.50398040810084e+68*cos(theta)**31 - 1.00288620996287e+68*cos(theta)**29 + 3.20607717515689e+67*cos(theta)**27 - 8.18424064349141e+66*cos(theta)**25 + 1.66346354542508e+66*cos(theta)**23 - 2.67550080732706e+65*cos(theta)**21 + 3.37248000923578e+64*cos(theta)**19 - 3.28600616284512e+63*cos(theta)**17 + 2.42878716384205e+62*cos(theta)**15 - 1.32755154712866e+61*cos(theta)**13 + 5.18263366746923e+59*cos(theta)**11 - 1.37636335929893e+58*cos(theta)**9 + 2.3153776137739e+56*cos(theta)**7 - 2.20512153692752e+54*cos(theta)**5 + 9.73133952748243e+51*cos(theta)**3 - 1.25673777797879e+49*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl73_m_minus_25(theta, phi):
    return 1.75524965841487e-46*(1.0 - cos(theta)**2)**12.5*(2.24191746785645e+65*cos(theta)**48 - 1.74405717499453e+66*cos(theta)**46 + 6.31153558083686e+66*cos(theta)**44 - 1.41151599514697e+67*cos(theta)**42 + 2.1858188342114e+67*cos(theta)**40 - 2.48896159224072e+67*cos(theta)**38 + 2.16017283869781e+67*cos(theta)**36 - 1.46177109385566e+67*cos(theta)**34 + 7.82493877531513e+66*cos(theta)**32 - 3.34295403320956e+66*cos(theta)**30 + 1.14502756255603e+66*cos(theta)**28 - 3.14778486288131e+65*cos(theta)**26 + 6.93109810593784e+64*cos(theta)**24 - 1.21613673060321e+64*cos(theta)**22 + 1.68624000461789e+63*cos(theta)**20 - 1.8255589793584e+62*cos(theta)**18 + 1.51799197740128e+61*cos(theta)**16 - 9.48251105091898e+59*cos(theta)**14 + 4.31886138955769e+58*cos(theta)**12 - 1.37636335929893e+57*cos(theta)**10 + 2.89422201721737e+55*cos(theta)**8 - 3.67520256154587e+53*cos(theta)**6 + 2.43283488187061e+51*cos(theta)**4 - 6.28368888989395e+48*cos(theta)**2 + 2.64465020618432e+45)*sin(25*phi)

#@torch.jit.script
def Yl73_m_minus_24(theta, phi):
    return 1.21632595741771e-44*(1.0 - cos(theta)**2)**12*(4.57534177113561e+63*cos(theta)**49 - 3.71075994679688e+64*cos(theta)**47 + 1.40256346240819e+65*cos(theta)**45 - 3.28259533755109e+65*cos(theta)**43 + 5.3312654492961e+65*cos(theta)**41 - 6.38195280061723e+65*cos(theta)**39 + 5.83830496945354e+65*cos(theta)**37 - 4.1764888395876e+65*cos(theta)**35 + 2.37119356827731e+65*cos(theta)**33 - 1.07837226877728e+65*cos(theta)**31 + 3.94837090536563e+64*cos(theta)**29 - 1.1658462455116e+64*cos(theta)**27 + 2.77243924237514e+63*cos(theta)**25 - 5.28755100262264e+62*cos(theta)**23 + 8.02971430770425e+61*cos(theta)**21 - 9.6082051545179e+60*cos(theta)**19 + 8.9293645729487e+59*cos(theta)**17 - 6.32167403394599e+58*cos(theta)**15 + 3.32220106889053e+57*cos(theta)**13 - 1.25123941754448e+56*cos(theta)**11 + 3.21580224135263e+54*cos(theta)**9 - 5.25028937363695e+52*cos(theta)**7 + 4.86566976374122e+50*cos(theta)**5 - 2.09456296329798e+48*cos(theta)**3 + 2.64465020618432e+45*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl73_m_minus_23(theta, phi):
    return 8.47073010326583e-43*(1.0 - cos(theta)**2)**11.5*(9.15068354227122e+61*cos(theta)**50 - 7.73074988916017e+62*cos(theta)**48 + 3.0490510052352e+63*cos(theta)**46 - 7.46044394897974e+63*cos(theta)**44 + 1.26934891649907e+64*cos(theta)**42 - 1.59548820015431e+64*cos(theta)**40 + 1.53639604459304e+64*cos(theta)**38 - 1.16013578877433e+64*cos(theta)**36 + 6.97409873022739e+63*cos(theta)**34 - 3.369913339929e+63*cos(theta)**32 + 1.31612363512188e+63*cos(theta)**30 - 4.16373659111284e+62*cos(theta)**28 + 1.0663227855289e+62*cos(theta)**26 - 2.20314625109277e+61*cos(theta)**24 + 3.64987013986557e+60*cos(theta)**22 - 4.80410257725895e+59*cos(theta)**20 + 4.96075809608261e+58*cos(theta)**18 - 3.95104627121624e+57*cos(theta)**16 + 2.37300076349324e+56*cos(theta)**14 - 1.0426995146204e+55*cos(theta)**12 + 3.21580224135263e+53*cos(theta)**10 - 6.56286171704619e+51*cos(theta)**8 + 8.10944960623536e+49*cos(theta)**6 - 5.23640740824496e+47*cos(theta)**4 + 1.32232510309216e+45*cos(theta)**2 - 5.45288702306046e+41)*sin(23*phi)

#@torch.jit.script
def Yl73_m_minus_22(theta, phi):
    return 5.92709036956332e-41*(1.0 - cos(theta)**2)**11*(1.79425167495514e+60*cos(theta)**51 - 1.57770405901228e+61*cos(theta)**49 + 6.48734256433021e+61*cos(theta)**47 - 1.65787643310661e+62*cos(theta)**45 + 2.95197422441645e+62*cos(theta)**43 - 3.8914346345227e+62*cos(theta)**41 + 3.93947703741804e+62*cos(theta)**39 - 3.13550213182252e+62*cos(theta)**37 + 1.99259963720783e+62*cos(theta)**35 - 1.02118586058454e+62*cos(theta)**33 + 4.24556011329637e+61*cos(theta)**31 - 1.43577123831477e+61*cos(theta)**29 + 3.94934365010703e+60*cos(theta)**27 - 8.81258500437107e+59*cos(theta)**25 + 1.58690006081112e+59*cos(theta)**23 - 2.28766789393283e+58*cos(theta)**21 + 2.61092531372769e+57*cos(theta)**19 - 2.32414486542132e+56*cos(theta)**17 + 1.58200050899549e+55*cos(theta)**15 - 8.02076549707999e+53*cos(theta)**13 + 2.92345658304785e+52*cos(theta)**11 - 7.29206857449577e+50*cos(theta)**9 + 1.15849280089077e+49*cos(theta)**7 - 1.04728148164899e+47*cos(theta)**5 + 4.40775034364054e+44*cos(theta)**3 - 5.45288702306046e+41*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl73_m_minus_21(theta, phi):
    return 4.16586338266047e-39*(1.0 - cos(theta)**2)**10.5*(3.45048399029835e+58*cos(theta)**52 - 3.15540811802456e+59*cos(theta)**50 + 1.35152970090213e+60*cos(theta)**48 - 3.60407920240567e+60*cos(theta)**46 + 6.70903232821919e+60*cos(theta)**44 - 9.26532055838738e+60*cos(theta)**42 + 9.84869259354511e+60*cos(theta)**40 - 8.25132139953296e+60*cos(theta)**38 + 5.53499899224396e+60*cos(theta)**36 - 3.00348782524866e+60*cos(theta)**34 + 1.32673753540512e+60*cos(theta)**32 - 4.78590412771591e+59*cos(theta)**30 + 1.41047987503823e+59*cos(theta)**28 - 3.38945577091195e+58*cos(theta)**26 + 6.61208358671299e+57*cos(theta)**24 - 1.03984904269674e+57*cos(theta)**22 + 1.30546265686385e+56*cos(theta)**20 - 1.29119159190073e+55*cos(theta)**18 + 9.88750318122182e+53*cos(theta)**16 - 5.72911821219999e+52*cos(theta)**14 + 2.43621381920654e+51*cos(theta)**12 - 7.29206857449577e+49*cos(theta)**10 + 1.44811600111346e+48*cos(theta)**8 - 1.74546913608165e+46*cos(theta)**6 + 1.10193758591013e+44*cos(theta)**4 - 2.72644351153023e+41*cos(theta)**2 + 1.10382328402034e+38)*sin(21*phi)

#@torch.jit.script
def Yl73_m_minus_20(theta, phi):
    return 2.940403188271e-37*(1.0 - cos(theta)**2)**10*(6.51034715150632e+56*cos(theta)**53 - 6.18707474122462e+57*cos(theta)**51 + 2.7582238793921e+58*cos(theta)**49 - 7.66825362213973e+58*cos(theta)**47 + 1.4908960729376e+59*cos(theta)**45 - 2.15472571125288e+59*cos(theta)**43 + 2.4021201447671e+59*cos(theta)**41 - 2.11572343577768e+59*cos(theta)**39 + 1.49594567357945e+59*cos(theta)**37 - 8.58139378642474e+58*cos(theta)**35 + 4.0204167739549e+58*cos(theta)**33 - 1.54384004119868e+58*cos(theta)**31 + 4.86372370702837e+57*cos(theta)**29 - 1.25535398922665e+57*cos(theta)**27 + 2.64483343468519e+56*cos(theta)**25 - 4.52108279433366e+55*cos(theta)**23 + 6.21648884220879e+54*cos(theta)**21 - 6.79574522053017e+53*cos(theta)**19 + 5.81617834189519e+52*cos(theta)**17 - 3.81941214146666e+51*cos(theta)**15 + 1.87401063015888e+50*cos(theta)**13 - 6.62915324954161e+48*cos(theta)**11 + 1.60901777901495e+47*cos(theta)**9 - 2.4935273372595e+45*cos(theta)**7 + 2.20387517182027e+43*cos(theta)**5 - 9.0881450384341e+40*cos(theta)**3 + 1.10382328402034e+38*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl73_m_minus_19(theta, phi):
    return 2.08374820714938e-35*(1.0 - cos(theta)**2)**9.5*(1.20561984287154e+55*cos(theta)**54 - 1.18982206562012e+56*cos(theta)**52 + 5.51644775878419e+56*cos(theta)**50 - 1.59755283794578e+57*cos(theta)**48 + 3.24107841942956e+57*cos(theta)**46 - 4.89710388921109e+57*cos(theta)**44 + 5.7193336780169e+57*cos(theta)**42 - 5.2893085894442e+57*cos(theta)**40 + 3.93669914099855e+57*cos(theta)**38 - 2.3837204962291e+57*cos(theta)**36 + 1.18247552175144e+57*cos(theta)**34 - 4.82450012874588e+56*cos(theta)**32 + 1.62124123567612e+56*cos(theta)**30 - 4.48340710438088e+55*cos(theta)**28 + 1.01724362872507e+55*cos(theta)**26 - 1.88378449763903e+54*cos(theta)**24 + 2.82567674645854e+53*cos(theta)**22 - 3.39787261026508e+52*cos(theta)**20 + 3.23121018994177e+51*cos(theta)**18 - 2.38713258841666e+50*cos(theta)**16 + 1.33857902154205e+49*cos(theta)**14 - 5.524294374618e+47*cos(theta)**12 + 1.60901777901495e+46*cos(theta)**10 - 3.11690917157438e+44*cos(theta)**8 + 3.67312528636712e+42*cos(theta)**6 - 2.27203625960853e+40*cos(theta)**4 + 5.51911642010168e+37*cos(theta)**2 - 2.19797547594651e+34)*sin(19*phi)

#@torch.jit.script
def Yl73_m_minus_18(theta, phi):
    return 1.48224671864839e-33*(1.0 - cos(theta)**2)**9*(2.19203607794826e+53*cos(theta)**55 - 2.24494729362287e+54*cos(theta)**53 + 1.08165642329102e+55*cos(theta)**51 - 3.26031191417506e+55*cos(theta)**49 + 6.8959115307012e+55*cos(theta)**47 - 1.08824530871358e+56*cos(theta)**45 + 1.33007759953881e+56*cos(theta)**43 - 1.2900752657181e+56*cos(theta)**41 + 1.00941003615347e+56*cos(theta)**39 - 6.4424878276462e+55*cos(theta)**37 + 3.3785014907184e+55*cos(theta)**35 - 1.4619697359836e+55*cos(theta)**33 + 5.22981043766491e+54*cos(theta)**31 - 1.54600244978651e+54*cos(theta)**29 + 3.76756899527805e+53*cos(theta)**27 - 7.53513799055611e+52*cos(theta)**25 + 1.22855510715589e+52*cos(theta)**23 - 1.61803457631671e+51*cos(theta)**21 + 1.70063694207462e+50*cos(theta)**19 - 1.4041956402451e+49*cos(theta)**17 + 8.9238601436137e+47*cos(theta)**15 - 4.24945721124462e+46*cos(theta)**13 + 1.46274343546814e+45*cos(theta)**11 - 3.46323241286042e+43*cos(theta)**9 + 5.24732183766731e+41*cos(theta)**7 - 4.54407251921705e+39*cos(theta)**5 + 1.83970547336723e+37*cos(theta)**3 - 2.19797547594651e+34*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl73_m_minus_17(theta, phi):
    return 1.05812069192858e-31*(1.0 - cos(theta)**2)**8.5*(3.91435013919331e+51*cos(theta)**56 - 4.15730980300531e+52*cos(theta)**54 + 2.08010850632888e+53*cos(theta)**52 - 6.52062382835011e+53*cos(theta)**50 + 1.43664823556275e+54*cos(theta)**48 - 2.36575067111647e+54*cos(theta)**46 + 3.02290363531549e+54*cos(theta)**44 - 3.07160777551928e+54*cos(theta)**42 + 2.52352509038368e+54*cos(theta)**40 - 1.69539153359111e+54*cos(theta)**38 + 9.38472636310667e+53*cos(theta)**36 - 4.29991098818706e+53*cos(theta)**34 + 1.63431576177028e+53*cos(theta)**32 - 5.15334149928837e+52*cos(theta)**30 + 1.34556035545645e+52*cos(theta)**28 - 2.89812999636773e+51*cos(theta)**26 + 5.11897961314953e+50*cos(theta)**24 - 7.3547026196214e+49*cos(theta)**22 + 8.50318471037309e+48*cos(theta)**20 - 7.80108689025054e+47*cos(theta)**18 + 5.57741258975856e+46*cos(theta)**16 - 3.03532657946044e+45*cos(theta)**14 + 1.21895286289012e+44*cos(theta)**12 - 3.46323241286042e+42*cos(theta)**10 + 6.55915229708413e+40*cos(theta)**8 - 7.57345419869508e+38*cos(theta)**6 + 4.59926368341807e+36*cos(theta)**4 - 1.09898773797325e+34*cos(theta)**2 + 4.313138689063e+30)*sin(17*phi)

#@torch.jit.script
def Yl73_m_minus_16(theta, phi):
    return 7.57868558212204e-30*(1.0 - cos(theta)**2)**8*(6.86728094595318e+49*cos(theta)**57 - 7.55874509637329e+50*cos(theta)**55 + 3.92473303080921e+51*cos(theta)**53 - 1.27855369183336e+52*cos(theta)**51 + 2.93193517461786e+52*cos(theta)**49 - 5.03351206620525e+52*cos(theta)**47 + 6.71756363403442e+52*cos(theta)**45 - 7.14327389655647e+52*cos(theta)**43 + 6.15493924483826e+52*cos(theta)**41 - 4.34715777843873e+52*cos(theta)**39 + 2.53641253056937e+52*cos(theta)**37 - 1.22854599662487e+52*cos(theta)**35 + 4.9524720053645e+51*cos(theta)**33 - 1.66236822557689e+51*cos(theta)**31 + 4.63986329467741e+50*cos(theta)**29 - 1.0733814801362e+50*cos(theta)**27 + 2.04759184525981e+49*cos(theta)**25 - 3.19769679113974e+48*cos(theta)**23 + 4.04913557636814e+47*cos(theta)**21 - 4.10583520539502e+46*cos(theta)**19 + 3.2808309351521e+45*cos(theta)**17 - 2.02355105297363e+44*cos(theta)**15 + 9.37656048377012e+42*cos(theta)**13 - 3.14839310260038e+41*cos(theta)**11 + 7.28794699676015e+39*cos(theta)**9 - 1.08192202838501e+38*cos(theta)**7 + 9.19852736683613e+35*cos(theta)**5 - 3.66329245991085e+33*cos(theta)**3 + 4.313138689063e+30*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl73_m_minus_15(theta, phi):
    return 5.44506276123659e-28*(1.0 - cos(theta)**2)**7.5*(1.18401395619882e+48*cos(theta)**58 - 1.34977591006666e+49*cos(theta)**56 + 7.26802413112817e+49*cos(theta)**54 - 2.45875709967953e+50*cos(theta)**52 + 5.86387034923571e+50*cos(theta)**50 - 1.04864834712609e+51*cos(theta)**48 + 1.46033992044226e+51*cos(theta)**46 - 1.62347134012647e+51*cos(theta)**44 + 1.46546172496149e+51*cos(theta)**42 - 1.08678944460968e+51*cos(theta)**40 + 6.67476981728782e+50*cos(theta)**38 - 3.41262776840243e+50*cos(theta)**36 + 1.4566094133425e+50*cos(theta)**34 - 5.19490070492779e+49*cos(theta)**32 + 1.5466210982258e+49*cos(theta)**30 - 3.83350528620071e+48*cos(theta)**28 + 7.87535325099928e+47*cos(theta)**26 - 1.33237366297489e+47*cos(theta)**24 + 1.84051617107643e+46*cos(theta)**22 - 2.05291760269751e+45*cos(theta)**20 + 1.82268385286227e+44*cos(theta)**18 - 1.26471940810852e+43*cos(theta)**16 + 6.69754320269294e+41*cos(theta)**14 - 2.62366091883365e+40*cos(theta)**12 + 7.28794699676015e+38*cos(theta)**10 - 1.35240253548126e+37*cos(theta)**8 + 1.53308789447269e+35*cos(theta)**6 - 9.15823114977711e+32*cos(theta)**4 + 2.1565693445315e+30*cos(theta)**2 - 8.35555732092795e+26)*sin(15*phi)

#@torch.jit.script
def Yl73_m_minus_14(theta, phi):
    return 3.92346905679142e-26*(1.0 - cos(theta)**2)**7*(2.00680331559123e+46*cos(theta)**59 - 2.36802791239765e+47*cos(theta)**57 + 1.32145893293239e+48*cos(theta)**55 - 4.63916433901798e+48*cos(theta)**53 + 1.14977849985014e+49*cos(theta)**51 - 2.14009866760427e+49*cos(theta)**49 + 3.10710621370695e+49*cos(theta)**47 - 3.60771408916993e+49*cos(theta)**45 + 3.40805052316625e+49*cos(theta)**43 - 2.65070596246264e+49*cos(theta)**41 + 1.71147944033021e+49*cos(theta)**39 - 9.22331829297953e+48*cos(theta)**37 + 4.16174118097857e+48*cos(theta)**35 - 1.5742123348266e+48*cos(theta)**33 + 4.98910031685743e+47*cos(theta)**31 - 1.32189837455197e+47*cos(theta)**29 + 2.9167975003701e+46*cos(theta)**27 - 5.32949465189956e+45*cos(theta)**25 + 8.00224422207141e+44*cos(theta)**23 - 9.77579810808338e+43*cos(theta)**21 + 9.59307290980145e+42*cos(theta)**19 - 7.4395259300501e+41*cos(theta)**17 + 4.46502880179529e+40*cos(theta)**15 - 2.01820070679512e+39*cos(theta)**13 + 6.62540636069105e+37*cos(theta)**11 - 1.50266948386807e+36*cos(theta)**9 + 2.19012556353241e+34*cos(theta)**7 - 1.83164622995542e+32*cos(theta)**5 + 7.18856448177168e+29*cos(theta)**3 - 8.35555732092795e+26*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl73_m_minus_13(theta, phi):
    return 2.83468942345913e-24*(1.0 - cos(theta)**2)**6.5*(3.34467219265205e+44*cos(theta)**60 - 4.08280674551319e+45*cos(theta)**58 + 2.35974809452213e+46*cos(theta)**56 - 8.59104507225552e+46*cos(theta)**54 + 2.21111249971181e+47*cos(theta)**52 - 4.28019733520855e+47*cos(theta)**50 + 6.4731379452228e+47*cos(theta)**48 - 7.84285671558681e+47*cos(theta)**46 + 7.7455693708324e+47*cos(theta)**44 - 6.3112046725301e+47*cos(theta)**42 + 4.27869860082553e+47*cos(theta)**40 - 2.4271890244683e+47*cos(theta)**38 + 1.15603921693849e+47*cos(theta)**36 - 4.63003627890178e+46*cos(theta)**34 + 1.55909384901795e+46*cos(theta)**32 - 4.40632791517323e+45*cos(theta)**30 + 1.04171339298932e+45*cos(theta)**28 - 2.04980563534599e+44*cos(theta)**26 + 3.33426842586309e+43*cos(theta)**24 - 4.44354459458335e+42*cos(theta)**22 + 4.79653645490072e+41*cos(theta)**20 - 4.13306996113895e+40*cos(theta)**18 + 2.79064300112206e+39*cos(theta)**16 - 1.44157193342508e+38*cos(theta)**14 + 5.52117196724254e+36*cos(theta)**12 - 1.50266948386807e+35*cos(theta)**10 + 2.73765695441552e+33*cos(theta)**8 - 3.05274371659237e+31*cos(theta)**6 + 1.79714112044292e+29*cos(theta)**4 - 4.17777866046397e+26*cos(theta)**2 + 1.60068147910497e+23)*sin(13*phi)

#@torch.jit.script
def Yl73_m_minus_12(theta, phi):
    return 2.05314502197758e-22*(1.0 - cos(theta)**2)**6*(5.48306916828204e+42*cos(theta)**61 - 6.9200114330732e+43*cos(theta)**59 + 4.13990893775813e+44*cos(theta)**57 - 1.56200819495555e+45*cos(theta)**55 + 4.17191037681473e+45*cos(theta)**53 - 8.39254379452656e+45*cos(theta)**51 + 1.32104856024955e+46*cos(theta)**49 - 1.66869291820996e+46*cos(theta)**47 + 1.72123763796275e+46*cos(theta)**45 - 1.46772201686747e+46*cos(theta)**43 + 1.04358502459159e+46*cos(theta)**41 - 6.22356160120076e+45*cos(theta)**39 + 3.12443031604998e+45*cos(theta)**37 - 1.32286750825765e+45*cos(theta)**35 + 4.7245268152059e+44*cos(theta)**33 - 1.42139610166878e+44*cos(theta)**31 + 3.59211514823904e+43*cos(theta)**29 - 7.59187272350365e+42*cos(theta)**27 + 1.33370737034524e+42*cos(theta)**25 - 1.93197591068842e+41*cos(theta)**23 + 2.28406497852415e+40*cos(theta)**21 - 2.17529997954681e+39*cos(theta)**19 + 1.64155470654239e+38*cos(theta)**17 - 9.61047955616723e+36*cos(theta)**15 + 4.24705535941734e+35*cos(theta)**13 - 1.36606316715279e+34*cos(theta)**11 + 3.04184106046168e+32*cos(theta)**9 - 4.36106245227482e+30*cos(theta)**7 + 3.59428224088584e+28*cos(theta)**5 - 1.39259288682132e+26*cos(theta)**3 + 1.60068147910497e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl73_m_minus_11(theta, phi):
    return 1.4904758171906e-20*(1.0 - cos(theta)**2)**5.5*(8.843659948842e+40*cos(theta)**62 - 1.15333523884553e+42*cos(theta)**60 + 7.13777403061746e+42*cos(theta)**58 - 2.78930034813491e+43*cos(theta)**56 + 7.72575995706431e+43*cos(theta)**54 - 1.61395072971665e+44*cos(theta)**52 + 2.6420971204991e+44*cos(theta)**50 - 3.47644357960408e+44*cos(theta)**48 + 3.74182095209295e+44*cos(theta)**46 - 3.33573185651697e+44*cos(theta)**44 + 2.4847262490276e+44*cos(theta)**42 - 1.55589040030019e+44*cos(theta)**40 + 8.22218504223678e+43*cos(theta)**38 - 3.67463196738236e+43*cos(theta)**36 + 1.38956671035468e+43*cos(theta)**34 - 4.44186281771494e+42*cos(theta)**32 + 1.19737171607968e+42*cos(theta)**30 - 2.71138311553702e+41*cos(theta)**28 + 5.12964373209706e+40*cos(theta)**26 - 8.0498996278684e+39*cos(theta)**24 + 1.03821135387462e+39*cos(theta)**22 - 1.08764998977341e+38*cos(theta)**20 + 9.11974836967993e+36*cos(theta)**18 - 6.00654972260452e+35*cos(theta)**16 + 3.03361097101238e+34*cos(theta)**14 - 1.13838597262733e+33*cos(theta)**12 + 3.04184106046168e+31*cos(theta)**10 - 5.45132806534352e+29*cos(theta)**8 + 5.9904704014764e+27*cos(theta)**6 - 3.48148221705331e+25*cos(theta)**4 + 8.00340739552485e+22*cos(theta)**2 - 3.03734626016123e+19)*sin(11*phi)

#@torch.jit.script
def Yl73_m_minus_10(theta, phi):
    return 1.08426353398728e-18*(1.0 - cos(theta)**2)**5*(1.40375554743524e+39*cos(theta)**63 - 1.89071350630415e+40*cos(theta)**61 + 1.20979220857923e+41*cos(theta)**59 - 4.89350938269282e+41*cos(theta)**57 + 1.40468362855715e+42*cos(theta)**55 - 3.04519005606915e+42*cos(theta)**53 + 5.18058258921393e+42*cos(theta)**51 - 7.09478281551854e+42*cos(theta)**49 + 7.96132117466584e+42*cos(theta)**47 - 7.41273745892659e+42*cos(theta)**45 + 5.77843313727349e+42*cos(theta)**43 - 3.79485463487851e+42*cos(theta)**41 + 2.10825257493251e+42*cos(theta)**39 - 9.93143774968206e+41*cos(theta)**37 + 3.97019060101336e+41*cos(theta)**35 - 1.3460190356712e+41*cos(theta)**33 + 3.86248940670865e+40*cos(theta)**31 - 9.34959695012765e+39*cos(theta)**29 + 1.89986804892484e+39*cos(theta)**27 - 3.21995985114736e+38*cos(theta)**25 + 4.5139624081505e+37*cos(theta)**23 - 5.17928566558765e+36*cos(theta)**21 + 4.79986756298944e+35*cos(theta)**19 - 3.53326454270854e+34*cos(theta)**17 + 2.02240731400826e+33*cos(theta)**15 - 8.75681517405636e+31*cos(theta)**13 + 2.76531005496517e+30*cos(theta)**11 - 6.05703118371502e+28*cos(theta)**9 + 8.55781485925199e+26*cos(theta)**7 - 6.96296443410662e+24*cos(theta)**5 + 2.66780246517495e+22*cos(theta)**3 - 3.03734626016123e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl73_m_minus_9(theta, phi):
    return 7.90248872694352e-17*(1.0 - cos(theta)**2)**4.5*(2.19336804286756e+37*cos(theta)**64 - 3.04953791339379e+38*cos(theta)**62 + 2.01632034763205e+39*cos(theta)**60 - 8.43708514257383e+39*cos(theta)**58 + 2.50836362242348e+40*cos(theta)**56 - 5.63924084457249e+40*cos(theta)**54 + 9.9626588254114e+40*cos(theta)**52 - 1.41895656310371e+41*cos(theta)**50 + 1.65860857805538e+41*cos(theta)**48 - 1.61146466498404e+41*cos(theta)**46 + 1.31328025847125e+41*cos(theta)**44 - 9.03536817828218e+40*cos(theta)**42 + 5.27063143733127e+40*cos(theta)**40 - 2.61353624991633e+40*cos(theta)**38 + 1.10283072250371e+40*cos(theta)**36 - 3.95887951667999e+39*cos(theta)**34 + 1.20702793959645e+39*cos(theta)**32 - 3.11653231670922e+38*cos(theta)**30 + 6.78524303187442e+37*cos(theta)**28 - 1.23844609659514e+37*cos(theta)**26 + 1.88081767006271e+36*cos(theta)**24 - 2.3542207570853e+35*cos(theta)**22 + 2.39993378149472e+34*cos(theta)**20 - 1.96292474594919e+33*cos(theta)**18 + 1.26400457125516e+32*cos(theta)**16 - 6.25486798146883e+30*cos(theta)**14 + 2.30442504580431e+29*cos(theta)**12 - 6.05703118371502e+27*cos(theta)**10 + 1.0697268574065e+26*cos(theta)**8 - 1.1604940723511e+24*cos(theta)**6 + 6.66950616293738e+21*cos(theta)**4 - 1.51867313008062e+19*cos(theta)**2 + 5.71789582108666e+15)*sin(9*phi)

#@torch.jit.script
def Yl73_m_minus_8(theta, phi):
    return 5.76935801162982e-15*(1.0 - cos(theta)**2)**4*(3.3744123736424e+35*cos(theta)**65 - 4.84053637046634e+36*cos(theta)**63 + 3.30544319283943e+37*cos(theta)**61 - 1.43001443094472e+38*cos(theta)**59 + 4.40063793407628e+38*cos(theta)**57 - 1.025316517195e+39*cos(theta)**55 + 1.87974694819083e+39*cos(theta)**53 - 2.78226777079158e+39*cos(theta)**51 + 3.38491546541915e+39*cos(theta)**49 - 3.4286482233703e+39*cos(theta)**47 + 2.91840057438055e+39*cos(theta)**45 - 2.10124841355399e+39*cos(theta)**43 + 1.28551986276372e+39*cos(theta)**41 - 6.70137499978547e+38*cos(theta)**39 + 2.98062357433435e+38*cos(theta)**37 - 1.13110843333714e+38*cos(theta)**35 + 3.65766042301955e+37*cos(theta)**33 - 1.00533300539007e+37*cos(theta)**31 + 2.33973897650842e+36*cos(theta)**29 - 4.58683739479681e+35*cos(theta)**27 + 7.52327068025084e+34*cos(theta)**25 - 1.023574242211e+34*cos(theta)**23 + 1.14282561023558e+33*cos(theta)**21 - 1.03311828734168e+32*cos(theta)**19 + 7.43532100738329e+30*cos(theta)**17 - 4.16991198764589e+29*cos(theta)**15 + 1.7726346506187e+28*cos(theta)**13 - 5.50639198519548e+26*cos(theta)**11 + 1.18858539711833e+25*cos(theta)**9 - 1.65784867478729e+23*cos(theta)**7 + 1.33390123258748e+21*cos(theta)**5 - 5.06224376693539e+18*cos(theta)**3 + 5.71789582108666e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl73_m_minus_7(theta, phi):
    return 4.21834374509173e-13*(1.0 - cos(theta)**2)**3.5*(5.1127460206703e+33*cos(theta)**66 - 7.56333807885366e+34*cos(theta)**64 + 5.33135998845069e+35*cos(theta)**62 - 2.38335738490786e+36*cos(theta)**60 + 7.58730678289014e+36*cos(theta)**58 - 1.83092235213393e+37*cos(theta)**56 + 3.48101286702006e+37*cos(theta)**54 - 5.35051494382997e+37*cos(theta)**52 + 6.7698309308383e+37*cos(theta)**50 - 7.14301713202146e+37*cos(theta)**48 + 6.34434907474032e+37*cos(theta)**46 - 4.77556457625908e+37*cos(theta)**44 + 3.06076157800887e+37*cos(theta)**42 - 1.67534374994637e+37*cos(theta)**40 + 7.8437462482483e+36*cos(theta)**38 - 3.14196787038094e+36*cos(theta)**36 + 1.07578247735869e+36*cos(theta)**34 - 3.14166564184397e+35*cos(theta)**32 + 7.79912992169473e+34*cos(theta)**30 - 1.63815621242743e+34*cos(theta)**28 + 2.89356564625032e+33*cos(theta)**26 - 4.26489267587916e+32*cos(theta)**24 + 5.19466186470718e+31*cos(theta)**22 - 5.16559143670839e+30*cos(theta)**20 + 4.13073389299072e+29*cos(theta)**18 - 2.60619499227868e+28*cos(theta)**16 + 1.26616760758478e+27*cos(theta)**14 - 4.5886599876629e+25*cos(theta)**12 + 1.18858539711833e+24*cos(theta)**10 - 2.07231084348411e+22*cos(theta)**8 + 2.22316872097913e+20*cos(theta)**6 - 1.26556094173385e+18*cos(theta)**4 + 2.85894791054333e+15*cos(theta)**2 - 1069565248987.4)*sin(7*phi)

#@torch.jit.script
def Yl73_m_minus_6(theta, phi):
    return 3.08833470306255e-11*(1.0 - cos(theta)**2)**3*(7.63096420995568e+31*cos(theta)**67 - 1.16359047366979e+33*cos(theta)**65 + 8.46247617214395e+33*cos(theta)**63 - 3.90714325394731e+34*cos(theta)**61 + 1.28598420048985e+35*cos(theta)**59 - 3.21214447742794e+35*cos(theta)**57 + 6.32911430367283e+35*cos(theta)**55 - 1.00953112147735e+36*cos(theta)**53 + 1.32741782957614e+36*cos(theta)**51 - 1.45775859837173e+36*cos(theta)**49 + 1.3498615052639e+36*cos(theta)**47 - 1.06123657250202e+36*cos(theta)**45 + 7.11805018141597e+35*cos(theta)**43 - 4.08620426816187e+35*cos(theta)**41 + 2.01121698673033e+35*cos(theta)**39 - 8.49180505508363e+34*cos(theta)**37 + 3.07366422102483e+34*cos(theta)**35 - 9.52019891467869e+33*cos(theta)**33 + 2.51584836183701e+33*cos(theta)**31 - 5.64881452561183e+32*cos(theta)**29 + 1.07169098009271e+32*cos(theta)**27 - 1.70595707035166e+31*cos(theta)**25 + 2.25854863682921e+30*cos(theta)**23 - 2.45980544605162e+29*cos(theta)**21 + 2.17407046999511e+28*cos(theta)**19 - 1.53305587781099e+27*cos(theta)**17 + 8.44111738389856e+25*cos(theta)**15 - 3.52973845204838e+24*cos(theta)**13 + 1.08053217919848e+23*cos(theta)**11 - 2.30256760387124e+21*cos(theta)**9 + 3.17595531568447e+19*cos(theta)**7 - 2.5311218834677e+17*cos(theta)**5 + 952982636847777.0*cos(theta)**3 - 1069565248987.4*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl73_m_minus_5(theta, phi):
    return 2.26356183859179e-9*(1.0 - cos(theta)**2)**2.5*(1.12220061911113e+30*cos(theta)**68 - 1.76301586919666e+31*cos(theta)**66 + 1.32226190189749e+32*cos(theta)**64 - 6.30184395797954e+32*cos(theta)**62 + 2.14330700081642e+33*cos(theta)**60 - 5.53818013349645e+33*cos(theta)**58 + 1.13019898279872e+34*cos(theta)**56 - 1.86950207680991e+34*cos(theta)**54 + 2.55272659533873e+34*cos(theta)**52 - 2.91551719674345e+34*cos(theta)**50 + 2.81221146929979e+34*cos(theta)**48 - 2.3070360271783e+34*cos(theta)**46 + 1.61773867759454e+34*cos(theta)**44 - 9.72905778133779e+33*cos(theta)**42 + 5.02804246682583e+33*cos(theta)**40 - 2.23468554081148e+33*cos(theta)**38 + 8.53795616951343e+32*cos(theta)**36 - 2.80005850431726e+32*cos(theta)**34 + 7.86202613074066e+31*cos(theta)**32 - 1.88293817520394e+31*cos(theta)**30 + 3.8274677860454e+30*cos(theta)**28 - 6.5613733475064e+29*cos(theta)**26 + 9.41061932012171e+28*cos(theta)**24 - 1.11809338456892e+28*cos(theta)**22 + 1.08703523499756e+27*cos(theta)**20 - 8.51697709894993e+25*cos(theta)**18 + 5.2756983649366e+24*cos(theta)**16 - 2.52124175146313e+23*cos(theta)**14 + 9.00443482665403e+21*cos(theta)**12 - 2.30256760387124e+20*cos(theta)**10 + 3.96994414460558e+18*cos(theta)**8 - 4.21853647244616e+16*cos(theta)**6 + 238245659211944.0*cos(theta)**4 - 534782624493.702*cos(theta)**2 + 199100009.119025)*sin(5*phi)

#@torch.jit.script
def Yl73_m_minus_4(theta, phi):
    return 1.66059685188635e-7*(1.0 - cos(theta)**2)**2*(1.62637770885671e+28*cos(theta)**69 - 2.63136696895023e+29*cos(theta)**67 + 2.0342490798423e+30*cos(theta)**65 - 1.00029269174278e+31*cos(theta)**63 + 3.51361803412528e+31*cos(theta)**61 - 9.38674598897703e+31*cos(theta)**59 + 1.98280523298021e+32*cos(theta)**57 - 3.39909468510893e+32*cos(theta)**55 + 4.81646527422401e+32*cos(theta)**53 - 5.71670038577148e+32*cos(theta)**51 + 5.73920708020365e+32*cos(theta)**49 - 4.90858729186872e+32*cos(theta)**47 + 3.59497483909898e+32*cos(theta)**45 - 2.2625715770553e+32*cos(theta)**43 + 1.22635182117703e+32*cos(theta)**41 - 5.72996292515764e+31*cos(theta)**39 + 2.30755572149012e+31*cos(theta)**37 - 8.00016715519218e+30*cos(theta)**35 + 2.3824321608305e+30*cos(theta)**33 - 6.07399411356111e+29*cos(theta)**31 + 1.31981647794669e+29*cos(theta)**29 - 2.43013827685422e+28*cos(theta)**27 + 3.76424772804868e+27*cos(theta)**25 - 4.86127558508224e+26*cos(theta)**23 + 5.17635826189313e+25*cos(theta)**21 - 4.48261952576312e+24*cos(theta)**19 + 3.10335197937447e+23*cos(theta)**17 - 1.68082783430875e+22*cos(theta)**15 + 6.92648832819541e+20*cos(theta)**13 - 2.09324327624658e+19*cos(theta)**11 + 4.41104904956176e+17*cos(theta)**9 - 6.02648067492308e+15*cos(theta)**7 + 47649131842388.8*cos(theta)**5 - 178260874831.234*cos(theta)**3 + 199100009.119025*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl73_m_minus_3(theta, phi):
    return 1.21915407005133e-5*(1.0 - cos(theta)**2)**1.5*(2.32339672693816e+26*cos(theta)**70 - 3.86965730727976e+27*cos(theta)**68 + 3.08219557551863e+28*cos(theta)**66 - 1.5629573308481e+29*cos(theta)**64 + 5.66712586149239e+29*cos(theta)**62 - 1.56445766482951e+30*cos(theta)**60 + 3.41862971203484e+30*cos(theta)**58 - 6.06981193769452e+30*cos(theta)**56 + 8.91938013745187e+30*cos(theta)**54 - 1.09936545880221e+31*cos(theta)**52 + 1.14784141604073e+31*cos(theta)**50 - 1.02262235247265e+31*cos(theta)**48 + 7.81516269369342e+30*cos(theta)**46 - 5.14220812967113e+30*cos(theta)**44 + 2.91988528851674e+30*cos(theta)**42 - 1.43249073128941e+30*cos(theta)**40 + 6.07251505655294e+29*cos(theta)**38 - 2.22226865422005e+29*cos(theta)**36 + 7.00715341420736e+28*cos(theta)**34 - 1.89812316048785e+28*cos(theta)**32 + 4.3993882598223e+27*cos(theta)**30 - 8.67906527447936e+26*cos(theta)**28 + 1.44778758771103e+26*cos(theta)**26 - 2.02553149378427e+25*cos(theta)**24 + 2.35289011904233e+24*cos(theta)**22 - 2.24130976288156e+23*cos(theta)**20 + 1.72408443298582e+22*cos(theta)**18 - 1.05051739644297e+21*cos(theta)**16 + 4.94749166299672e+19*cos(theta)**14 - 1.74436939687215e+18*cos(theta)**12 + 4.41104904956176e+16*cos(theta)**10 - 753310084365385.0*cos(theta)**8 + 7941521973731.47*cos(theta)**6 - 44565218707.8085*cos(theta)**4 + 99550004.5595126*cos(theta)**2 - 36938.7772020455)*sin(3*phi)

#@torch.jit.script
def Yl73_m_minus_2(theta, phi):
    return 0.000895559743659608*(1.0 - cos(theta)**2)*(3.27238975625092e+24*cos(theta)**71 - 5.60819899605762e+25*cos(theta)**69 + 4.60029190375915e+26*cos(theta)**67 - 2.40454973976631e+27*cos(theta)**65 + 8.99543787538475e+27*cos(theta)**63 - 2.56468469644181e+28*cos(theta)**61 + 5.79428764751669e+28*cos(theta)**59 - 1.06487928731483e+29*cos(theta)**57 + 1.6217054795367e+29*cos(theta)**55 - 2.0742744505702e+29*cos(theta)**53 + 2.25066944321712e+29*cos(theta)**51 - 2.08698439280133e+29*cos(theta)**49 + 1.66280057312626e+29*cos(theta)**47 - 1.1427129177047e+29*cos(theta)**45 + 6.79043090352731e+28*cos(theta)**43 - 3.4938798324132e+28*cos(theta)**41 + 1.55705514270588e+28*cos(theta)**39 - 6.00613149789202e+27*cos(theta)**37 + 2.00204383263067e+27*cos(theta)**35 - 5.75188836511469e+26*cos(theta)**33 + 1.41915750316848e+26*cos(theta)**31 - 2.99278112913082e+25*cos(theta)**29 + 5.3621762507816e+24*cos(theta)**27 - 8.10212597513707e+23*cos(theta)**25 + 1.02299570393145e+23*cos(theta)**23 - 1.06729036327693e+22*cos(theta)**21 + 9.07412859466219e+20*cos(theta)**19 - 6.17951409672336e+19*cos(theta)**17 + 3.29832777533115e+18*cos(theta)**15 - 1.34182261297858e+17*cos(theta)**13 + 4.01004459051069e+15*cos(theta)**11 - 83701120485042.8*cos(theta)**9 + 1134503139104.5*cos(theta)**7 - 8913043741.5617*cos(theta)**5 + 33183334.8531709*cos(theta)**3 - 36938.7772020455*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl73_m_minus_1(theta, phi):
    return 0.0658099321843123*(1.0 - cos(theta)**2)**0.5*(4.54498577257073e+22*cos(theta)**72 - 8.01171285151088e+23*cos(theta)**70 + 6.76513515258699e+24*cos(theta)**68 - 3.6432571814641e+25*cos(theta)**66 + 1.40553716802887e+26*cos(theta)**64 - 4.13658822006744e+26*cos(theta)**62 + 9.65714607919448e+26*cos(theta)**60 - 1.83599877123246e+27*cos(theta)**58 + 2.89590264202983e+27*cos(theta)**56 - 3.84124898253741e+27*cos(theta)**54 + 4.32821046772523e+27*cos(theta)**52 - 4.17396878560265e+27*cos(theta)**50 + 3.46416786067971e+27*cos(theta)**48 - 2.48415851674934e+27*cos(theta)**46 + 1.54327975080166e+27*cos(theta)**44 - 8.31876150574571e+26*cos(theta)**42 + 3.8926378567647e+26*cos(theta)**40 - 1.5805609204979e+26*cos(theta)**38 + 5.56123286841854e+25*cos(theta)**36 - 1.69173187209255e+25*cos(theta)**34 + 4.43486719740151e+24*cos(theta)**32 - 9.97593709710272e+23*cos(theta)**30 + 1.91506294670772e+23*cos(theta)**28 - 3.11620229812964e+22*cos(theta)**26 + 4.26248209971437e+21*cos(theta)**24 - 4.85131983307697e+20*cos(theta)**22 + 4.5370642973311e+19*cos(theta)**20 - 3.43306338706853e+18*cos(theta)**18 + 2.06145485958197e+17*cos(theta)**16 - 9.58444723556126e+15*cos(theta)**14 + 334170382542557.0*cos(theta)**12 - 8370112048504.28*cos(theta)**10 + 141812892388.062*cos(theta)**8 - 1485507290.26028*cos(theta)**6 + 8295833.71329272*cos(theta)**4 - 18469.3886010228*cos(theta)**2 + 6.84051429667509)*sin(phi)

#@torch.jit.script
def Yl73_m0(theta, phi):
    return 6.68980218455322e+21*cos(theta)**73 - 1.21246897524178e+23*cos(theta)**71 + 1.05349139981672e+24*cos(theta)**69 - 5.84276790536651e+24*cos(theta)**67 + 2.32344601416643e+25*cos(theta)**65 - 7.05513534228639e+25*cos(theta)**63 + 1.70107152141794e+26*cos(theta)**61 - 3.34367441911368e+26*cos(theta)**59 + 5.4589951632667e+26*cos(theta)**57 - 7.50435510815991e+26*cos(theta)**55 + 8.77477742962005e+26*cos(theta)**53 - 8.7939223985574e+26*cos(theta)**51 + 7.59637605566442e+26*cos(theta)**49 - 5.67917243576692e+26*cos(theta)**47 + 3.6849852359328e+26*cos(theta)**45 - 2.07870962026978e+26*cos(theta)**43 + 1.02014934081718e+26*cos(theta)**41 - 4.35461977860535e+25*cos(theta)**39 + 1.61500162960289e+25*cos(theta)**37 - 5.19358322218987e+24*cos(theta)**35 + 1.4440102884126e+24*cos(theta)**33 - 3.45776613279753e+23*cos(theta)**31 + 7.09559246138946e+22*cos(theta)**29 - 1.24012507073789e+22*cos(theta)**27 + 1.83200294540825e+21*cos(theta)**25 - 2.26639539638134e+20*cos(theta)**23 + 2.32144953556469e+19*cos(theta)**21 - 1.9414751193492e+18*cos(theta)**19 + 1.30295229752242e+17*cos(theta)**17 - 6.86561458593761e+15*cos(theta)**15 + 276202885641168.0*cos(theta)**13 - 8176024698296.44*cos(theta)**11 + 169307740363.819*cos(theta)**9 - 2280238927.45885*cos(theta)**7 + 17827631.2273402*cos(theta)**5 - 66150.7652220415*cos(theta)**3 + 73.5008502467128*cos(theta)

#@torch.jit.script
def Yl73_m1(theta, phi):
    return 0.0658099321843123*(1.0 - cos(theta)**2)**0.5*(4.54498577257073e+22*cos(theta)**72 - 8.01171285151088e+23*cos(theta)**70 + 6.76513515258699e+24*cos(theta)**68 - 3.6432571814641e+25*cos(theta)**66 + 1.40553716802887e+26*cos(theta)**64 - 4.13658822006744e+26*cos(theta)**62 + 9.65714607919448e+26*cos(theta)**60 - 1.83599877123246e+27*cos(theta)**58 + 2.89590264202983e+27*cos(theta)**56 - 3.84124898253741e+27*cos(theta)**54 + 4.32821046772523e+27*cos(theta)**52 - 4.17396878560265e+27*cos(theta)**50 + 3.46416786067971e+27*cos(theta)**48 - 2.48415851674934e+27*cos(theta)**46 + 1.54327975080166e+27*cos(theta)**44 - 8.31876150574571e+26*cos(theta)**42 + 3.8926378567647e+26*cos(theta)**40 - 1.5805609204979e+26*cos(theta)**38 + 5.56123286841854e+25*cos(theta)**36 - 1.69173187209255e+25*cos(theta)**34 + 4.43486719740151e+24*cos(theta)**32 - 9.97593709710272e+23*cos(theta)**30 + 1.91506294670772e+23*cos(theta)**28 - 3.11620229812964e+22*cos(theta)**26 + 4.26248209971437e+21*cos(theta)**24 - 4.85131983307697e+20*cos(theta)**22 + 4.5370642973311e+19*cos(theta)**20 - 3.43306338706853e+18*cos(theta)**18 + 2.06145485958197e+17*cos(theta)**16 - 9.58444723556126e+15*cos(theta)**14 + 334170382542557.0*cos(theta)**12 - 8370112048504.28*cos(theta)**10 + 141812892388.062*cos(theta)**8 - 1485507290.26028*cos(theta)**6 + 8295833.71329272*cos(theta)**4 - 18469.3886010228*cos(theta)**2 + 6.84051429667509)*cos(phi)

#@torch.jit.script
def Yl73_m2(theta, phi):
    return 0.000895559743659608*(1.0 - cos(theta)**2)*(3.27238975625092e+24*cos(theta)**71 - 5.60819899605762e+25*cos(theta)**69 + 4.60029190375915e+26*cos(theta)**67 - 2.40454973976631e+27*cos(theta)**65 + 8.99543787538475e+27*cos(theta)**63 - 2.56468469644181e+28*cos(theta)**61 + 5.79428764751669e+28*cos(theta)**59 - 1.06487928731483e+29*cos(theta)**57 + 1.6217054795367e+29*cos(theta)**55 - 2.0742744505702e+29*cos(theta)**53 + 2.25066944321712e+29*cos(theta)**51 - 2.08698439280133e+29*cos(theta)**49 + 1.66280057312626e+29*cos(theta)**47 - 1.1427129177047e+29*cos(theta)**45 + 6.79043090352731e+28*cos(theta)**43 - 3.4938798324132e+28*cos(theta)**41 + 1.55705514270588e+28*cos(theta)**39 - 6.00613149789202e+27*cos(theta)**37 + 2.00204383263067e+27*cos(theta)**35 - 5.75188836511469e+26*cos(theta)**33 + 1.41915750316848e+26*cos(theta)**31 - 2.99278112913082e+25*cos(theta)**29 + 5.3621762507816e+24*cos(theta)**27 - 8.10212597513707e+23*cos(theta)**25 + 1.02299570393145e+23*cos(theta)**23 - 1.06729036327693e+22*cos(theta)**21 + 9.07412859466219e+20*cos(theta)**19 - 6.17951409672336e+19*cos(theta)**17 + 3.29832777533115e+18*cos(theta)**15 - 1.34182261297858e+17*cos(theta)**13 + 4.01004459051069e+15*cos(theta)**11 - 83701120485042.8*cos(theta)**9 + 1134503139104.5*cos(theta)**7 - 8913043741.5617*cos(theta)**5 + 33183334.8531709*cos(theta)**3 - 36938.7772020455*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl73_m3(theta, phi):
    return 1.21915407005133e-5*(1.0 - cos(theta)**2)**1.5*(2.32339672693816e+26*cos(theta)**70 - 3.86965730727976e+27*cos(theta)**68 + 3.08219557551863e+28*cos(theta)**66 - 1.5629573308481e+29*cos(theta)**64 + 5.66712586149239e+29*cos(theta)**62 - 1.56445766482951e+30*cos(theta)**60 + 3.41862971203484e+30*cos(theta)**58 - 6.06981193769452e+30*cos(theta)**56 + 8.91938013745187e+30*cos(theta)**54 - 1.09936545880221e+31*cos(theta)**52 + 1.14784141604073e+31*cos(theta)**50 - 1.02262235247265e+31*cos(theta)**48 + 7.81516269369342e+30*cos(theta)**46 - 5.14220812967113e+30*cos(theta)**44 + 2.91988528851674e+30*cos(theta)**42 - 1.43249073128941e+30*cos(theta)**40 + 6.07251505655294e+29*cos(theta)**38 - 2.22226865422005e+29*cos(theta)**36 + 7.00715341420736e+28*cos(theta)**34 - 1.89812316048785e+28*cos(theta)**32 + 4.3993882598223e+27*cos(theta)**30 - 8.67906527447936e+26*cos(theta)**28 + 1.44778758771103e+26*cos(theta)**26 - 2.02553149378427e+25*cos(theta)**24 + 2.35289011904233e+24*cos(theta)**22 - 2.24130976288156e+23*cos(theta)**20 + 1.72408443298582e+22*cos(theta)**18 - 1.05051739644297e+21*cos(theta)**16 + 4.94749166299672e+19*cos(theta)**14 - 1.74436939687215e+18*cos(theta)**12 + 4.41104904956176e+16*cos(theta)**10 - 753310084365385.0*cos(theta)**8 + 7941521973731.47*cos(theta)**6 - 44565218707.8085*cos(theta)**4 + 99550004.5595126*cos(theta)**2 - 36938.7772020455)*cos(3*phi)

#@torch.jit.script
def Yl73_m4(theta, phi):
    return 1.66059685188635e-7*(1.0 - cos(theta)**2)**2*(1.62637770885671e+28*cos(theta)**69 - 2.63136696895023e+29*cos(theta)**67 + 2.0342490798423e+30*cos(theta)**65 - 1.00029269174278e+31*cos(theta)**63 + 3.51361803412528e+31*cos(theta)**61 - 9.38674598897703e+31*cos(theta)**59 + 1.98280523298021e+32*cos(theta)**57 - 3.39909468510893e+32*cos(theta)**55 + 4.81646527422401e+32*cos(theta)**53 - 5.71670038577148e+32*cos(theta)**51 + 5.73920708020365e+32*cos(theta)**49 - 4.90858729186872e+32*cos(theta)**47 + 3.59497483909898e+32*cos(theta)**45 - 2.2625715770553e+32*cos(theta)**43 + 1.22635182117703e+32*cos(theta)**41 - 5.72996292515764e+31*cos(theta)**39 + 2.30755572149012e+31*cos(theta)**37 - 8.00016715519218e+30*cos(theta)**35 + 2.3824321608305e+30*cos(theta)**33 - 6.07399411356111e+29*cos(theta)**31 + 1.31981647794669e+29*cos(theta)**29 - 2.43013827685422e+28*cos(theta)**27 + 3.76424772804868e+27*cos(theta)**25 - 4.86127558508224e+26*cos(theta)**23 + 5.17635826189313e+25*cos(theta)**21 - 4.48261952576312e+24*cos(theta)**19 + 3.10335197937447e+23*cos(theta)**17 - 1.68082783430875e+22*cos(theta)**15 + 6.92648832819541e+20*cos(theta)**13 - 2.09324327624658e+19*cos(theta)**11 + 4.41104904956176e+17*cos(theta)**9 - 6.02648067492308e+15*cos(theta)**7 + 47649131842388.8*cos(theta)**5 - 178260874831.234*cos(theta)**3 + 199100009.119025*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl73_m5(theta, phi):
    return 2.26356183859179e-9*(1.0 - cos(theta)**2)**2.5*(1.12220061911113e+30*cos(theta)**68 - 1.76301586919666e+31*cos(theta)**66 + 1.32226190189749e+32*cos(theta)**64 - 6.30184395797954e+32*cos(theta)**62 + 2.14330700081642e+33*cos(theta)**60 - 5.53818013349645e+33*cos(theta)**58 + 1.13019898279872e+34*cos(theta)**56 - 1.86950207680991e+34*cos(theta)**54 + 2.55272659533873e+34*cos(theta)**52 - 2.91551719674345e+34*cos(theta)**50 + 2.81221146929979e+34*cos(theta)**48 - 2.3070360271783e+34*cos(theta)**46 + 1.61773867759454e+34*cos(theta)**44 - 9.72905778133779e+33*cos(theta)**42 + 5.02804246682583e+33*cos(theta)**40 - 2.23468554081148e+33*cos(theta)**38 + 8.53795616951343e+32*cos(theta)**36 - 2.80005850431726e+32*cos(theta)**34 + 7.86202613074066e+31*cos(theta)**32 - 1.88293817520394e+31*cos(theta)**30 + 3.8274677860454e+30*cos(theta)**28 - 6.5613733475064e+29*cos(theta)**26 + 9.41061932012171e+28*cos(theta)**24 - 1.11809338456892e+28*cos(theta)**22 + 1.08703523499756e+27*cos(theta)**20 - 8.51697709894993e+25*cos(theta)**18 + 5.2756983649366e+24*cos(theta)**16 - 2.52124175146313e+23*cos(theta)**14 + 9.00443482665403e+21*cos(theta)**12 - 2.30256760387124e+20*cos(theta)**10 + 3.96994414460558e+18*cos(theta)**8 - 4.21853647244616e+16*cos(theta)**6 + 238245659211944.0*cos(theta)**4 - 534782624493.702*cos(theta)**2 + 199100009.119025)*cos(5*phi)

#@torch.jit.script
def Yl73_m6(theta, phi):
    return 3.08833470306255e-11*(1.0 - cos(theta)**2)**3*(7.63096420995568e+31*cos(theta)**67 - 1.16359047366979e+33*cos(theta)**65 + 8.46247617214395e+33*cos(theta)**63 - 3.90714325394731e+34*cos(theta)**61 + 1.28598420048985e+35*cos(theta)**59 - 3.21214447742794e+35*cos(theta)**57 + 6.32911430367283e+35*cos(theta)**55 - 1.00953112147735e+36*cos(theta)**53 + 1.32741782957614e+36*cos(theta)**51 - 1.45775859837173e+36*cos(theta)**49 + 1.3498615052639e+36*cos(theta)**47 - 1.06123657250202e+36*cos(theta)**45 + 7.11805018141597e+35*cos(theta)**43 - 4.08620426816187e+35*cos(theta)**41 + 2.01121698673033e+35*cos(theta)**39 - 8.49180505508363e+34*cos(theta)**37 + 3.07366422102483e+34*cos(theta)**35 - 9.52019891467869e+33*cos(theta)**33 + 2.51584836183701e+33*cos(theta)**31 - 5.64881452561183e+32*cos(theta)**29 + 1.07169098009271e+32*cos(theta)**27 - 1.70595707035166e+31*cos(theta)**25 + 2.25854863682921e+30*cos(theta)**23 - 2.45980544605162e+29*cos(theta)**21 + 2.17407046999511e+28*cos(theta)**19 - 1.53305587781099e+27*cos(theta)**17 + 8.44111738389856e+25*cos(theta)**15 - 3.52973845204838e+24*cos(theta)**13 + 1.08053217919848e+23*cos(theta)**11 - 2.30256760387124e+21*cos(theta)**9 + 3.17595531568447e+19*cos(theta)**7 - 2.5311218834677e+17*cos(theta)**5 + 952982636847777.0*cos(theta)**3 - 1069565248987.4*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl73_m7(theta, phi):
    return 4.21834374509173e-13*(1.0 - cos(theta)**2)**3.5*(5.1127460206703e+33*cos(theta)**66 - 7.56333807885366e+34*cos(theta)**64 + 5.33135998845069e+35*cos(theta)**62 - 2.38335738490786e+36*cos(theta)**60 + 7.58730678289014e+36*cos(theta)**58 - 1.83092235213393e+37*cos(theta)**56 + 3.48101286702006e+37*cos(theta)**54 - 5.35051494382997e+37*cos(theta)**52 + 6.7698309308383e+37*cos(theta)**50 - 7.14301713202146e+37*cos(theta)**48 + 6.34434907474032e+37*cos(theta)**46 - 4.77556457625908e+37*cos(theta)**44 + 3.06076157800887e+37*cos(theta)**42 - 1.67534374994637e+37*cos(theta)**40 + 7.8437462482483e+36*cos(theta)**38 - 3.14196787038094e+36*cos(theta)**36 + 1.07578247735869e+36*cos(theta)**34 - 3.14166564184397e+35*cos(theta)**32 + 7.79912992169473e+34*cos(theta)**30 - 1.63815621242743e+34*cos(theta)**28 + 2.89356564625032e+33*cos(theta)**26 - 4.26489267587916e+32*cos(theta)**24 + 5.19466186470718e+31*cos(theta)**22 - 5.16559143670839e+30*cos(theta)**20 + 4.13073389299072e+29*cos(theta)**18 - 2.60619499227868e+28*cos(theta)**16 + 1.26616760758478e+27*cos(theta)**14 - 4.5886599876629e+25*cos(theta)**12 + 1.18858539711833e+24*cos(theta)**10 - 2.07231084348411e+22*cos(theta)**8 + 2.22316872097913e+20*cos(theta)**6 - 1.26556094173385e+18*cos(theta)**4 + 2.85894791054333e+15*cos(theta)**2 - 1069565248987.4)*cos(7*phi)

#@torch.jit.script
def Yl73_m8(theta, phi):
    return 5.76935801162982e-15*(1.0 - cos(theta)**2)**4*(3.3744123736424e+35*cos(theta)**65 - 4.84053637046634e+36*cos(theta)**63 + 3.30544319283943e+37*cos(theta)**61 - 1.43001443094472e+38*cos(theta)**59 + 4.40063793407628e+38*cos(theta)**57 - 1.025316517195e+39*cos(theta)**55 + 1.87974694819083e+39*cos(theta)**53 - 2.78226777079158e+39*cos(theta)**51 + 3.38491546541915e+39*cos(theta)**49 - 3.4286482233703e+39*cos(theta)**47 + 2.91840057438055e+39*cos(theta)**45 - 2.10124841355399e+39*cos(theta)**43 + 1.28551986276372e+39*cos(theta)**41 - 6.70137499978547e+38*cos(theta)**39 + 2.98062357433435e+38*cos(theta)**37 - 1.13110843333714e+38*cos(theta)**35 + 3.65766042301955e+37*cos(theta)**33 - 1.00533300539007e+37*cos(theta)**31 + 2.33973897650842e+36*cos(theta)**29 - 4.58683739479681e+35*cos(theta)**27 + 7.52327068025084e+34*cos(theta)**25 - 1.023574242211e+34*cos(theta)**23 + 1.14282561023558e+33*cos(theta)**21 - 1.03311828734168e+32*cos(theta)**19 + 7.43532100738329e+30*cos(theta)**17 - 4.16991198764589e+29*cos(theta)**15 + 1.7726346506187e+28*cos(theta)**13 - 5.50639198519548e+26*cos(theta)**11 + 1.18858539711833e+25*cos(theta)**9 - 1.65784867478729e+23*cos(theta)**7 + 1.33390123258748e+21*cos(theta)**5 - 5.06224376693539e+18*cos(theta)**3 + 5.71789582108666e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl73_m9(theta, phi):
    return 7.90248872694352e-17*(1.0 - cos(theta)**2)**4.5*(2.19336804286756e+37*cos(theta)**64 - 3.04953791339379e+38*cos(theta)**62 + 2.01632034763205e+39*cos(theta)**60 - 8.43708514257383e+39*cos(theta)**58 + 2.50836362242348e+40*cos(theta)**56 - 5.63924084457249e+40*cos(theta)**54 + 9.9626588254114e+40*cos(theta)**52 - 1.41895656310371e+41*cos(theta)**50 + 1.65860857805538e+41*cos(theta)**48 - 1.61146466498404e+41*cos(theta)**46 + 1.31328025847125e+41*cos(theta)**44 - 9.03536817828218e+40*cos(theta)**42 + 5.27063143733127e+40*cos(theta)**40 - 2.61353624991633e+40*cos(theta)**38 + 1.10283072250371e+40*cos(theta)**36 - 3.95887951667999e+39*cos(theta)**34 + 1.20702793959645e+39*cos(theta)**32 - 3.11653231670922e+38*cos(theta)**30 + 6.78524303187442e+37*cos(theta)**28 - 1.23844609659514e+37*cos(theta)**26 + 1.88081767006271e+36*cos(theta)**24 - 2.3542207570853e+35*cos(theta)**22 + 2.39993378149472e+34*cos(theta)**20 - 1.96292474594919e+33*cos(theta)**18 + 1.26400457125516e+32*cos(theta)**16 - 6.25486798146883e+30*cos(theta)**14 + 2.30442504580431e+29*cos(theta)**12 - 6.05703118371502e+27*cos(theta)**10 + 1.0697268574065e+26*cos(theta)**8 - 1.1604940723511e+24*cos(theta)**6 + 6.66950616293738e+21*cos(theta)**4 - 1.51867313008062e+19*cos(theta)**2 + 5.71789582108666e+15)*cos(9*phi)

#@torch.jit.script
def Yl73_m10(theta, phi):
    return 1.08426353398728e-18*(1.0 - cos(theta)**2)**5*(1.40375554743524e+39*cos(theta)**63 - 1.89071350630415e+40*cos(theta)**61 + 1.20979220857923e+41*cos(theta)**59 - 4.89350938269282e+41*cos(theta)**57 + 1.40468362855715e+42*cos(theta)**55 - 3.04519005606915e+42*cos(theta)**53 + 5.18058258921393e+42*cos(theta)**51 - 7.09478281551854e+42*cos(theta)**49 + 7.96132117466584e+42*cos(theta)**47 - 7.41273745892659e+42*cos(theta)**45 + 5.77843313727349e+42*cos(theta)**43 - 3.79485463487851e+42*cos(theta)**41 + 2.10825257493251e+42*cos(theta)**39 - 9.93143774968206e+41*cos(theta)**37 + 3.97019060101336e+41*cos(theta)**35 - 1.3460190356712e+41*cos(theta)**33 + 3.86248940670865e+40*cos(theta)**31 - 9.34959695012765e+39*cos(theta)**29 + 1.89986804892484e+39*cos(theta)**27 - 3.21995985114736e+38*cos(theta)**25 + 4.5139624081505e+37*cos(theta)**23 - 5.17928566558765e+36*cos(theta)**21 + 4.79986756298944e+35*cos(theta)**19 - 3.53326454270854e+34*cos(theta)**17 + 2.02240731400826e+33*cos(theta)**15 - 8.75681517405636e+31*cos(theta)**13 + 2.76531005496517e+30*cos(theta)**11 - 6.05703118371502e+28*cos(theta)**9 + 8.55781485925199e+26*cos(theta)**7 - 6.96296443410662e+24*cos(theta)**5 + 2.66780246517495e+22*cos(theta)**3 - 3.03734626016123e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl73_m11(theta, phi):
    return 1.4904758171906e-20*(1.0 - cos(theta)**2)**5.5*(8.843659948842e+40*cos(theta)**62 - 1.15333523884553e+42*cos(theta)**60 + 7.13777403061746e+42*cos(theta)**58 - 2.78930034813491e+43*cos(theta)**56 + 7.72575995706431e+43*cos(theta)**54 - 1.61395072971665e+44*cos(theta)**52 + 2.6420971204991e+44*cos(theta)**50 - 3.47644357960408e+44*cos(theta)**48 + 3.74182095209295e+44*cos(theta)**46 - 3.33573185651697e+44*cos(theta)**44 + 2.4847262490276e+44*cos(theta)**42 - 1.55589040030019e+44*cos(theta)**40 + 8.22218504223678e+43*cos(theta)**38 - 3.67463196738236e+43*cos(theta)**36 + 1.38956671035468e+43*cos(theta)**34 - 4.44186281771494e+42*cos(theta)**32 + 1.19737171607968e+42*cos(theta)**30 - 2.71138311553702e+41*cos(theta)**28 + 5.12964373209706e+40*cos(theta)**26 - 8.0498996278684e+39*cos(theta)**24 + 1.03821135387462e+39*cos(theta)**22 - 1.08764998977341e+38*cos(theta)**20 + 9.11974836967993e+36*cos(theta)**18 - 6.00654972260452e+35*cos(theta)**16 + 3.03361097101238e+34*cos(theta)**14 - 1.13838597262733e+33*cos(theta)**12 + 3.04184106046168e+31*cos(theta)**10 - 5.45132806534352e+29*cos(theta)**8 + 5.9904704014764e+27*cos(theta)**6 - 3.48148221705331e+25*cos(theta)**4 + 8.00340739552485e+22*cos(theta)**2 - 3.03734626016123e+19)*cos(11*phi)

#@torch.jit.script
def Yl73_m12(theta, phi):
    return 2.05314502197758e-22*(1.0 - cos(theta)**2)**6*(5.48306916828204e+42*cos(theta)**61 - 6.9200114330732e+43*cos(theta)**59 + 4.13990893775813e+44*cos(theta)**57 - 1.56200819495555e+45*cos(theta)**55 + 4.17191037681473e+45*cos(theta)**53 - 8.39254379452656e+45*cos(theta)**51 + 1.32104856024955e+46*cos(theta)**49 - 1.66869291820996e+46*cos(theta)**47 + 1.72123763796275e+46*cos(theta)**45 - 1.46772201686747e+46*cos(theta)**43 + 1.04358502459159e+46*cos(theta)**41 - 6.22356160120076e+45*cos(theta)**39 + 3.12443031604998e+45*cos(theta)**37 - 1.32286750825765e+45*cos(theta)**35 + 4.7245268152059e+44*cos(theta)**33 - 1.42139610166878e+44*cos(theta)**31 + 3.59211514823904e+43*cos(theta)**29 - 7.59187272350365e+42*cos(theta)**27 + 1.33370737034524e+42*cos(theta)**25 - 1.93197591068842e+41*cos(theta)**23 + 2.28406497852415e+40*cos(theta)**21 - 2.17529997954681e+39*cos(theta)**19 + 1.64155470654239e+38*cos(theta)**17 - 9.61047955616723e+36*cos(theta)**15 + 4.24705535941734e+35*cos(theta)**13 - 1.36606316715279e+34*cos(theta)**11 + 3.04184106046168e+32*cos(theta)**9 - 4.36106245227482e+30*cos(theta)**7 + 3.59428224088584e+28*cos(theta)**5 - 1.39259288682132e+26*cos(theta)**3 + 1.60068147910497e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl73_m13(theta, phi):
    return 2.83468942345913e-24*(1.0 - cos(theta)**2)**6.5*(3.34467219265205e+44*cos(theta)**60 - 4.08280674551319e+45*cos(theta)**58 + 2.35974809452213e+46*cos(theta)**56 - 8.59104507225552e+46*cos(theta)**54 + 2.21111249971181e+47*cos(theta)**52 - 4.28019733520855e+47*cos(theta)**50 + 6.4731379452228e+47*cos(theta)**48 - 7.84285671558681e+47*cos(theta)**46 + 7.7455693708324e+47*cos(theta)**44 - 6.3112046725301e+47*cos(theta)**42 + 4.27869860082553e+47*cos(theta)**40 - 2.4271890244683e+47*cos(theta)**38 + 1.15603921693849e+47*cos(theta)**36 - 4.63003627890178e+46*cos(theta)**34 + 1.55909384901795e+46*cos(theta)**32 - 4.40632791517323e+45*cos(theta)**30 + 1.04171339298932e+45*cos(theta)**28 - 2.04980563534599e+44*cos(theta)**26 + 3.33426842586309e+43*cos(theta)**24 - 4.44354459458335e+42*cos(theta)**22 + 4.79653645490072e+41*cos(theta)**20 - 4.13306996113895e+40*cos(theta)**18 + 2.79064300112206e+39*cos(theta)**16 - 1.44157193342508e+38*cos(theta)**14 + 5.52117196724254e+36*cos(theta)**12 - 1.50266948386807e+35*cos(theta)**10 + 2.73765695441552e+33*cos(theta)**8 - 3.05274371659237e+31*cos(theta)**6 + 1.79714112044292e+29*cos(theta)**4 - 4.17777866046397e+26*cos(theta)**2 + 1.60068147910497e+23)*cos(13*phi)

#@torch.jit.script
def Yl73_m14(theta, phi):
    return 3.92346905679142e-26*(1.0 - cos(theta)**2)**7*(2.00680331559123e+46*cos(theta)**59 - 2.36802791239765e+47*cos(theta)**57 + 1.32145893293239e+48*cos(theta)**55 - 4.63916433901798e+48*cos(theta)**53 + 1.14977849985014e+49*cos(theta)**51 - 2.14009866760427e+49*cos(theta)**49 + 3.10710621370695e+49*cos(theta)**47 - 3.60771408916993e+49*cos(theta)**45 + 3.40805052316625e+49*cos(theta)**43 - 2.65070596246264e+49*cos(theta)**41 + 1.71147944033021e+49*cos(theta)**39 - 9.22331829297953e+48*cos(theta)**37 + 4.16174118097857e+48*cos(theta)**35 - 1.5742123348266e+48*cos(theta)**33 + 4.98910031685743e+47*cos(theta)**31 - 1.32189837455197e+47*cos(theta)**29 + 2.9167975003701e+46*cos(theta)**27 - 5.32949465189956e+45*cos(theta)**25 + 8.00224422207141e+44*cos(theta)**23 - 9.77579810808338e+43*cos(theta)**21 + 9.59307290980145e+42*cos(theta)**19 - 7.4395259300501e+41*cos(theta)**17 + 4.46502880179529e+40*cos(theta)**15 - 2.01820070679512e+39*cos(theta)**13 + 6.62540636069105e+37*cos(theta)**11 - 1.50266948386807e+36*cos(theta)**9 + 2.19012556353241e+34*cos(theta)**7 - 1.83164622995542e+32*cos(theta)**5 + 7.18856448177168e+29*cos(theta)**3 - 8.35555732092795e+26*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl73_m15(theta, phi):
    return 5.44506276123659e-28*(1.0 - cos(theta)**2)**7.5*(1.18401395619882e+48*cos(theta)**58 - 1.34977591006666e+49*cos(theta)**56 + 7.26802413112817e+49*cos(theta)**54 - 2.45875709967953e+50*cos(theta)**52 + 5.86387034923571e+50*cos(theta)**50 - 1.04864834712609e+51*cos(theta)**48 + 1.46033992044226e+51*cos(theta)**46 - 1.62347134012647e+51*cos(theta)**44 + 1.46546172496149e+51*cos(theta)**42 - 1.08678944460968e+51*cos(theta)**40 + 6.67476981728782e+50*cos(theta)**38 - 3.41262776840243e+50*cos(theta)**36 + 1.4566094133425e+50*cos(theta)**34 - 5.19490070492779e+49*cos(theta)**32 + 1.5466210982258e+49*cos(theta)**30 - 3.83350528620071e+48*cos(theta)**28 + 7.87535325099928e+47*cos(theta)**26 - 1.33237366297489e+47*cos(theta)**24 + 1.84051617107643e+46*cos(theta)**22 - 2.05291760269751e+45*cos(theta)**20 + 1.82268385286227e+44*cos(theta)**18 - 1.26471940810852e+43*cos(theta)**16 + 6.69754320269294e+41*cos(theta)**14 - 2.62366091883365e+40*cos(theta)**12 + 7.28794699676015e+38*cos(theta)**10 - 1.35240253548126e+37*cos(theta)**8 + 1.53308789447269e+35*cos(theta)**6 - 9.15823114977711e+32*cos(theta)**4 + 2.1565693445315e+30*cos(theta)**2 - 8.35555732092795e+26)*cos(15*phi)

#@torch.jit.script
def Yl73_m16(theta, phi):
    return 7.57868558212204e-30*(1.0 - cos(theta)**2)**8*(6.86728094595318e+49*cos(theta)**57 - 7.55874509637329e+50*cos(theta)**55 + 3.92473303080921e+51*cos(theta)**53 - 1.27855369183336e+52*cos(theta)**51 + 2.93193517461786e+52*cos(theta)**49 - 5.03351206620525e+52*cos(theta)**47 + 6.71756363403442e+52*cos(theta)**45 - 7.14327389655647e+52*cos(theta)**43 + 6.15493924483826e+52*cos(theta)**41 - 4.34715777843873e+52*cos(theta)**39 + 2.53641253056937e+52*cos(theta)**37 - 1.22854599662487e+52*cos(theta)**35 + 4.9524720053645e+51*cos(theta)**33 - 1.66236822557689e+51*cos(theta)**31 + 4.63986329467741e+50*cos(theta)**29 - 1.0733814801362e+50*cos(theta)**27 + 2.04759184525981e+49*cos(theta)**25 - 3.19769679113974e+48*cos(theta)**23 + 4.04913557636814e+47*cos(theta)**21 - 4.10583520539502e+46*cos(theta)**19 + 3.2808309351521e+45*cos(theta)**17 - 2.02355105297363e+44*cos(theta)**15 + 9.37656048377012e+42*cos(theta)**13 - 3.14839310260038e+41*cos(theta)**11 + 7.28794699676015e+39*cos(theta)**9 - 1.08192202838501e+38*cos(theta)**7 + 9.19852736683613e+35*cos(theta)**5 - 3.66329245991085e+33*cos(theta)**3 + 4.313138689063e+30*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl73_m17(theta, phi):
    return 1.05812069192858e-31*(1.0 - cos(theta)**2)**8.5*(3.91435013919331e+51*cos(theta)**56 - 4.15730980300531e+52*cos(theta)**54 + 2.08010850632888e+53*cos(theta)**52 - 6.52062382835011e+53*cos(theta)**50 + 1.43664823556275e+54*cos(theta)**48 - 2.36575067111647e+54*cos(theta)**46 + 3.02290363531549e+54*cos(theta)**44 - 3.07160777551928e+54*cos(theta)**42 + 2.52352509038368e+54*cos(theta)**40 - 1.69539153359111e+54*cos(theta)**38 + 9.38472636310667e+53*cos(theta)**36 - 4.29991098818706e+53*cos(theta)**34 + 1.63431576177028e+53*cos(theta)**32 - 5.15334149928837e+52*cos(theta)**30 + 1.34556035545645e+52*cos(theta)**28 - 2.89812999636773e+51*cos(theta)**26 + 5.11897961314953e+50*cos(theta)**24 - 7.3547026196214e+49*cos(theta)**22 + 8.50318471037309e+48*cos(theta)**20 - 7.80108689025054e+47*cos(theta)**18 + 5.57741258975856e+46*cos(theta)**16 - 3.03532657946044e+45*cos(theta)**14 + 1.21895286289012e+44*cos(theta)**12 - 3.46323241286042e+42*cos(theta)**10 + 6.55915229708413e+40*cos(theta)**8 - 7.57345419869508e+38*cos(theta)**6 + 4.59926368341807e+36*cos(theta)**4 - 1.09898773797325e+34*cos(theta)**2 + 4.313138689063e+30)*cos(17*phi)

#@torch.jit.script
def Yl73_m18(theta, phi):
    return 1.48224671864839e-33*(1.0 - cos(theta)**2)**9*(2.19203607794826e+53*cos(theta)**55 - 2.24494729362287e+54*cos(theta)**53 + 1.08165642329102e+55*cos(theta)**51 - 3.26031191417506e+55*cos(theta)**49 + 6.8959115307012e+55*cos(theta)**47 - 1.08824530871358e+56*cos(theta)**45 + 1.33007759953881e+56*cos(theta)**43 - 1.2900752657181e+56*cos(theta)**41 + 1.00941003615347e+56*cos(theta)**39 - 6.4424878276462e+55*cos(theta)**37 + 3.3785014907184e+55*cos(theta)**35 - 1.4619697359836e+55*cos(theta)**33 + 5.22981043766491e+54*cos(theta)**31 - 1.54600244978651e+54*cos(theta)**29 + 3.76756899527805e+53*cos(theta)**27 - 7.53513799055611e+52*cos(theta)**25 + 1.22855510715589e+52*cos(theta)**23 - 1.61803457631671e+51*cos(theta)**21 + 1.70063694207462e+50*cos(theta)**19 - 1.4041956402451e+49*cos(theta)**17 + 8.9238601436137e+47*cos(theta)**15 - 4.24945721124462e+46*cos(theta)**13 + 1.46274343546814e+45*cos(theta)**11 - 3.46323241286042e+43*cos(theta)**9 + 5.24732183766731e+41*cos(theta)**7 - 4.54407251921705e+39*cos(theta)**5 + 1.83970547336723e+37*cos(theta)**3 - 2.19797547594651e+34*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl73_m19(theta, phi):
    return 2.08374820714938e-35*(1.0 - cos(theta)**2)**9.5*(1.20561984287154e+55*cos(theta)**54 - 1.18982206562012e+56*cos(theta)**52 + 5.51644775878419e+56*cos(theta)**50 - 1.59755283794578e+57*cos(theta)**48 + 3.24107841942956e+57*cos(theta)**46 - 4.89710388921109e+57*cos(theta)**44 + 5.7193336780169e+57*cos(theta)**42 - 5.2893085894442e+57*cos(theta)**40 + 3.93669914099855e+57*cos(theta)**38 - 2.3837204962291e+57*cos(theta)**36 + 1.18247552175144e+57*cos(theta)**34 - 4.82450012874588e+56*cos(theta)**32 + 1.62124123567612e+56*cos(theta)**30 - 4.48340710438088e+55*cos(theta)**28 + 1.01724362872507e+55*cos(theta)**26 - 1.88378449763903e+54*cos(theta)**24 + 2.82567674645854e+53*cos(theta)**22 - 3.39787261026508e+52*cos(theta)**20 + 3.23121018994177e+51*cos(theta)**18 - 2.38713258841666e+50*cos(theta)**16 + 1.33857902154205e+49*cos(theta)**14 - 5.524294374618e+47*cos(theta)**12 + 1.60901777901495e+46*cos(theta)**10 - 3.11690917157438e+44*cos(theta)**8 + 3.67312528636712e+42*cos(theta)**6 - 2.27203625960853e+40*cos(theta)**4 + 5.51911642010168e+37*cos(theta)**2 - 2.19797547594651e+34)*cos(19*phi)

#@torch.jit.script
def Yl73_m20(theta, phi):
    return 2.940403188271e-37*(1.0 - cos(theta)**2)**10*(6.51034715150632e+56*cos(theta)**53 - 6.18707474122462e+57*cos(theta)**51 + 2.7582238793921e+58*cos(theta)**49 - 7.66825362213973e+58*cos(theta)**47 + 1.4908960729376e+59*cos(theta)**45 - 2.15472571125288e+59*cos(theta)**43 + 2.4021201447671e+59*cos(theta)**41 - 2.11572343577768e+59*cos(theta)**39 + 1.49594567357945e+59*cos(theta)**37 - 8.58139378642474e+58*cos(theta)**35 + 4.0204167739549e+58*cos(theta)**33 - 1.54384004119868e+58*cos(theta)**31 + 4.86372370702837e+57*cos(theta)**29 - 1.25535398922665e+57*cos(theta)**27 + 2.64483343468519e+56*cos(theta)**25 - 4.52108279433366e+55*cos(theta)**23 + 6.21648884220879e+54*cos(theta)**21 - 6.79574522053017e+53*cos(theta)**19 + 5.81617834189519e+52*cos(theta)**17 - 3.81941214146666e+51*cos(theta)**15 + 1.87401063015888e+50*cos(theta)**13 - 6.62915324954161e+48*cos(theta)**11 + 1.60901777901495e+47*cos(theta)**9 - 2.4935273372595e+45*cos(theta)**7 + 2.20387517182027e+43*cos(theta)**5 - 9.0881450384341e+40*cos(theta)**3 + 1.10382328402034e+38*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl73_m21(theta, phi):
    return 4.16586338266047e-39*(1.0 - cos(theta)**2)**10.5*(3.45048399029835e+58*cos(theta)**52 - 3.15540811802456e+59*cos(theta)**50 + 1.35152970090213e+60*cos(theta)**48 - 3.60407920240567e+60*cos(theta)**46 + 6.70903232821919e+60*cos(theta)**44 - 9.26532055838738e+60*cos(theta)**42 + 9.84869259354511e+60*cos(theta)**40 - 8.25132139953296e+60*cos(theta)**38 + 5.53499899224396e+60*cos(theta)**36 - 3.00348782524866e+60*cos(theta)**34 + 1.32673753540512e+60*cos(theta)**32 - 4.78590412771591e+59*cos(theta)**30 + 1.41047987503823e+59*cos(theta)**28 - 3.38945577091195e+58*cos(theta)**26 + 6.61208358671299e+57*cos(theta)**24 - 1.03984904269674e+57*cos(theta)**22 + 1.30546265686385e+56*cos(theta)**20 - 1.29119159190073e+55*cos(theta)**18 + 9.88750318122182e+53*cos(theta)**16 - 5.72911821219999e+52*cos(theta)**14 + 2.43621381920654e+51*cos(theta)**12 - 7.29206857449577e+49*cos(theta)**10 + 1.44811600111346e+48*cos(theta)**8 - 1.74546913608165e+46*cos(theta)**6 + 1.10193758591013e+44*cos(theta)**4 - 2.72644351153023e+41*cos(theta)**2 + 1.10382328402034e+38)*cos(21*phi)

#@torch.jit.script
def Yl73_m22(theta, phi):
    return 5.92709036956332e-41*(1.0 - cos(theta)**2)**11*(1.79425167495514e+60*cos(theta)**51 - 1.57770405901228e+61*cos(theta)**49 + 6.48734256433021e+61*cos(theta)**47 - 1.65787643310661e+62*cos(theta)**45 + 2.95197422441645e+62*cos(theta)**43 - 3.8914346345227e+62*cos(theta)**41 + 3.93947703741804e+62*cos(theta)**39 - 3.13550213182252e+62*cos(theta)**37 + 1.99259963720783e+62*cos(theta)**35 - 1.02118586058454e+62*cos(theta)**33 + 4.24556011329637e+61*cos(theta)**31 - 1.43577123831477e+61*cos(theta)**29 + 3.94934365010703e+60*cos(theta)**27 - 8.81258500437107e+59*cos(theta)**25 + 1.58690006081112e+59*cos(theta)**23 - 2.28766789393283e+58*cos(theta)**21 + 2.61092531372769e+57*cos(theta)**19 - 2.32414486542132e+56*cos(theta)**17 + 1.58200050899549e+55*cos(theta)**15 - 8.02076549707999e+53*cos(theta)**13 + 2.92345658304785e+52*cos(theta)**11 - 7.29206857449577e+50*cos(theta)**9 + 1.15849280089077e+49*cos(theta)**7 - 1.04728148164899e+47*cos(theta)**5 + 4.40775034364054e+44*cos(theta)**3 - 5.45288702306046e+41*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl73_m23(theta, phi):
    return 8.47073010326583e-43*(1.0 - cos(theta)**2)**11.5*(9.15068354227122e+61*cos(theta)**50 - 7.73074988916017e+62*cos(theta)**48 + 3.0490510052352e+63*cos(theta)**46 - 7.46044394897974e+63*cos(theta)**44 + 1.26934891649907e+64*cos(theta)**42 - 1.59548820015431e+64*cos(theta)**40 + 1.53639604459304e+64*cos(theta)**38 - 1.16013578877433e+64*cos(theta)**36 + 6.97409873022739e+63*cos(theta)**34 - 3.369913339929e+63*cos(theta)**32 + 1.31612363512188e+63*cos(theta)**30 - 4.16373659111284e+62*cos(theta)**28 + 1.0663227855289e+62*cos(theta)**26 - 2.20314625109277e+61*cos(theta)**24 + 3.64987013986557e+60*cos(theta)**22 - 4.80410257725895e+59*cos(theta)**20 + 4.96075809608261e+58*cos(theta)**18 - 3.95104627121624e+57*cos(theta)**16 + 2.37300076349324e+56*cos(theta)**14 - 1.0426995146204e+55*cos(theta)**12 + 3.21580224135263e+53*cos(theta)**10 - 6.56286171704619e+51*cos(theta)**8 + 8.10944960623536e+49*cos(theta)**6 - 5.23640740824496e+47*cos(theta)**4 + 1.32232510309216e+45*cos(theta)**2 - 5.45288702306046e+41)*cos(23*phi)

#@torch.jit.script
def Yl73_m24(theta, phi):
    return 1.21632595741771e-44*(1.0 - cos(theta)**2)**12*(4.57534177113561e+63*cos(theta)**49 - 3.71075994679688e+64*cos(theta)**47 + 1.40256346240819e+65*cos(theta)**45 - 3.28259533755109e+65*cos(theta)**43 + 5.3312654492961e+65*cos(theta)**41 - 6.38195280061723e+65*cos(theta)**39 + 5.83830496945354e+65*cos(theta)**37 - 4.1764888395876e+65*cos(theta)**35 + 2.37119356827731e+65*cos(theta)**33 - 1.07837226877728e+65*cos(theta)**31 + 3.94837090536563e+64*cos(theta)**29 - 1.1658462455116e+64*cos(theta)**27 + 2.77243924237514e+63*cos(theta)**25 - 5.28755100262264e+62*cos(theta)**23 + 8.02971430770425e+61*cos(theta)**21 - 9.6082051545179e+60*cos(theta)**19 + 8.9293645729487e+59*cos(theta)**17 - 6.32167403394599e+58*cos(theta)**15 + 3.32220106889053e+57*cos(theta)**13 - 1.25123941754448e+56*cos(theta)**11 + 3.21580224135263e+54*cos(theta)**9 - 5.25028937363695e+52*cos(theta)**7 + 4.86566976374122e+50*cos(theta)**5 - 2.09456296329798e+48*cos(theta)**3 + 2.64465020618432e+45*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl73_m25(theta, phi):
    return 1.75524965841487e-46*(1.0 - cos(theta)**2)**12.5*(2.24191746785645e+65*cos(theta)**48 - 1.74405717499453e+66*cos(theta)**46 + 6.31153558083686e+66*cos(theta)**44 - 1.41151599514697e+67*cos(theta)**42 + 2.1858188342114e+67*cos(theta)**40 - 2.48896159224072e+67*cos(theta)**38 + 2.16017283869781e+67*cos(theta)**36 - 1.46177109385566e+67*cos(theta)**34 + 7.82493877531513e+66*cos(theta)**32 - 3.34295403320956e+66*cos(theta)**30 + 1.14502756255603e+66*cos(theta)**28 - 3.14778486288131e+65*cos(theta)**26 + 6.93109810593784e+64*cos(theta)**24 - 1.21613673060321e+64*cos(theta)**22 + 1.68624000461789e+63*cos(theta)**20 - 1.8255589793584e+62*cos(theta)**18 + 1.51799197740128e+61*cos(theta)**16 - 9.48251105091898e+59*cos(theta)**14 + 4.31886138955769e+58*cos(theta)**12 - 1.37636335929893e+57*cos(theta)**10 + 2.89422201721737e+55*cos(theta)**8 - 3.67520256154587e+53*cos(theta)**6 + 2.43283488187061e+51*cos(theta)**4 - 6.28368888989395e+48*cos(theta)**2 + 2.64465020618432e+45)*cos(25*phi)

#@torch.jit.script
def Yl73_m26(theta, phi):
    return 2.54624788461583e-48*(1.0 - cos(theta)**2)**13*(1.0761203845711e+67*cos(theta)**47 - 8.02266300497486e+67*cos(theta)**45 + 2.77707565556822e+68*cos(theta)**43 - 5.92836717961726e+68*cos(theta)**41 + 8.7432753368456e+68*cos(theta)**39 - 9.45805405051473e+68*cos(theta)**37 + 7.77662221931211e+68*cos(theta)**35 - 4.97002171910925e+68*cos(theta)**33 + 2.50398040810084e+68*cos(theta)**31 - 1.00288620996287e+68*cos(theta)**29 + 3.20607717515689e+67*cos(theta)**27 - 8.18424064349141e+66*cos(theta)**25 + 1.66346354542508e+66*cos(theta)**23 - 2.67550080732706e+65*cos(theta)**21 + 3.37248000923578e+64*cos(theta)**19 - 3.28600616284512e+63*cos(theta)**17 + 2.42878716384205e+62*cos(theta)**15 - 1.32755154712866e+61*cos(theta)**13 + 5.18263366746923e+59*cos(theta)**11 - 1.37636335929893e+58*cos(theta)**9 + 2.3153776137739e+56*cos(theta)**7 - 2.20512153692752e+54*cos(theta)**5 + 9.73133952748243e+51*cos(theta)**3 - 1.25673777797879e+49*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl73_m27(theta, phi):
    return 3.7140842604102e-50*(1.0 - cos(theta)**2)**13.5*(5.05776580748415e+68*cos(theta)**46 - 3.61019835223869e+69*cos(theta)**44 + 1.19414253189433e+70*cos(theta)**42 - 2.43063054364308e+70*cos(theta)**40 + 3.40987738136979e+70*cos(theta)**38 - 3.49947999869045e+70*cos(theta)**36 + 2.72181777675924e+70*cos(theta)**34 - 1.64010716730605e+70*cos(theta)**32 + 7.76233926511261e+69*cos(theta)**30 - 2.90837000889232e+69*cos(theta)**28 + 8.6564083729236e+68*cos(theta)**26 - 2.04606016087285e+68*cos(theta)**24 + 3.82596615447769e+67*cos(theta)**22 - 5.61855169538682e+66*cos(theta)**20 + 6.40771201754799e+65*cos(theta)**18 - 5.58621047683671e+64*cos(theta)**16 + 3.64318074576307e+63*cos(theta)**14 - 1.72581701126725e+62*cos(theta)**12 + 5.70089703421615e+60*cos(theta)**10 - 1.23872702336903e+59*cos(theta)**8 + 1.62076432964173e+57*cos(theta)**6 - 1.10256076846376e+55*cos(theta)**4 + 2.91940185824473e+52*cos(theta)**2 - 1.25673777797879e+49)*cos(27*phi)

#@torch.jit.script
def Yl73_m28(theta, phi):
    return 5.44894155235245e-52*(1.0 - cos(theta)**2)**14*(2.32657227144271e+70*cos(theta)**45 - 1.58848727498502e+71*cos(theta)**43 + 5.01539863395621e+71*cos(theta)**41 - 9.72252217457231e+71*cos(theta)**39 + 1.29575340492052e+72*cos(theta)**37 - 1.25981279952856e+72*cos(theta)**35 + 9.25418044098142e+71*cos(theta)**33 - 5.24834293537936e+71*cos(theta)**31 + 2.32870177953378e+71*cos(theta)**29 - 8.1434360248985e+70*cos(theta)**27 + 2.25066617696014e+70*cos(theta)**25 - 4.91054438609484e+69*cos(theta)**23 + 8.41712553985092e+68*cos(theta)**21 - 1.12371033907736e+68*cos(theta)**19 + 1.15338816315864e+67*cos(theta)**17 - 8.93793676293873e+65*cos(theta)**15 + 5.1004530440683e+64*cos(theta)**13 - 2.0709804135207e+63*cos(theta)**11 + 5.70089703421615e+61*cos(theta)**9 - 9.90981618695227e+59*cos(theta)**7 + 9.72458597785036e+57*cos(theta)**5 - 4.41024307385504e+55*cos(theta)**3 + 5.83880371648946e+52*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl73_m29(theta, phi):
    return 8.04277291533547e-54*(1.0 - cos(theta)**2)**14.5*(1.04695752214922e+72*cos(theta)**44 - 6.83049528243559e+72*cos(theta)**42 + 2.05631343992204e+73*cos(theta)**40 - 3.7917836480832e+73*cos(theta)**38 + 4.79428759820592e+73*cos(theta)**36 - 4.40934479834997e+73*cos(theta)**34 + 3.05387954552387e+73*cos(theta)**32 - 1.6269863099676e+73*cos(theta)**30 + 6.75323516064797e+72*cos(theta)**28 - 2.19872772672259e+72*cos(theta)**26 + 5.62666544240034e+71*cos(theta)**24 - 1.12942520880181e+71*cos(theta)**22 + 1.76759636336869e+70*cos(theta)**20 - 2.13504964424699e+69*cos(theta)**18 + 1.96075987736968e+68*cos(theta)**16 - 1.34069051444081e+67*cos(theta)**14 + 6.63058895728879e+65*cos(theta)**12 - 2.27807845487278e+64*cos(theta)**10 + 5.13080733079454e+62*cos(theta)**8 - 6.93687133086659e+60*cos(theta)**6 + 4.86229298892518e+58*cos(theta)**4 - 1.32307292215651e+56*cos(theta)**2 + 5.83880371648946e+52)*cos(29*phi)

#@torch.jit.script
def Yl73_m30(theta, phi):
    return 1.19470548102875e-55*(1.0 - cos(theta)**2)**15*(4.60661309745656e+73*cos(theta)**43 - 2.86880801862295e+74*cos(theta)**41 + 8.22525375968818e+74*cos(theta)**39 - 1.44087778627162e+75*cos(theta)**37 + 1.72594353535413e+75*cos(theta)**35 - 1.49917723143899e+75*cos(theta)**33 + 9.77241454567638e+74*cos(theta)**31 - 4.88095892990281e+74*cos(theta)**29 + 1.89090584498143e+74*cos(theta)**27 - 5.71669208947875e+73*cos(theta)**25 + 1.35039970617608e+73*cos(theta)**23 - 2.48473545936399e+72*cos(theta)**21 + 3.53519272673738e+71*cos(theta)**19 - 3.84308935964458e+70*cos(theta)**17 + 3.1372158037915e+69*cos(theta)**15 - 1.87696672021713e+68*cos(theta)**13 + 7.95670674874655e+66*cos(theta)**11 - 2.27807845487278e+65*cos(theta)**9 + 4.10464586463563e+63*cos(theta)**7 - 4.16212279851995e+61*cos(theta)**5 + 1.94491719557007e+59*cos(theta)**3 - 2.64614584431302e+56*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl73_m31(theta, phi):
    return 1.78652854082763e-57*(1.0 - cos(theta)**2)**15.5*(1.98084363190632e+75*cos(theta)**42 - 1.17621128763541e+76*cos(theta)**40 + 3.20784896627839e+76*cos(theta)**38 - 5.33124780920498e+76*cos(theta)**36 + 6.04080237373946e+76*cos(theta)**34 - 4.94728486374867e+76*cos(theta)**32 + 3.02944850915968e+76*cos(theta)**30 - 1.41547808967181e+76*cos(theta)**28 + 5.10544578144986e+75*cos(theta)**26 - 1.42917302236969e+75*cos(theta)**24 + 3.10591932420499e+74*cos(theta)**22 - 5.21794446466438e+73*cos(theta)**20 + 6.71686618080103e+72*cos(theta)**18 - 6.53325191139579e+71*cos(theta)**16 + 4.70582370568724e+70*cos(theta)**14 - 2.44005673628227e+69*cos(theta)**12 + 8.7523774236212e+67*cos(theta)**10 - 2.0502706093855e+66*cos(theta)**8 + 2.87325210524494e+64*cos(theta)**6 - 2.08106139925998e+62*cos(theta)**4 + 5.83475158671022e+59*cos(theta)**2 - 2.64614584431302e+56)*cos(31*phi)

#@torch.jit.script
def Yl73_m32(theta, phi):
    return 2.69023775900592e-59*(1.0 - cos(theta)**2)**16*(8.31954325400655e+76*cos(theta)**41 - 4.70484515054164e+77*cos(theta)**39 + 1.21898260718579e+78*cos(theta)**37 - 1.91924921131379e+78*cos(theta)**35 + 2.05387280707142e+78*cos(theta)**33 - 1.58313115639957e+78*cos(theta)**31 + 9.08834552747903e+77*cos(theta)**29 - 3.96333865108108e+77*cos(theta)**27 + 1.32741590317696e+77*cos(theta)**25 - 3.43001525368725e+76*cos(theta)**23 + 6.83302251325097e+75*cos(theta)**21 - 1.04358889293288e+75*cos(theta)**19 + 1.20903591254419e+74*cos(theta)**17 - 1.04532030582333e+73*cos(theta)**15 + 6.58815318796214e+71*cos(theta)**13 - 2.92806808353873e+70*cos(theta)**11 + 8.7523774236212e+68*cos(theta)**9 - 1.6402164875084e+67*cos(theta)**7 + 1.72395126314697e+65*cos(theta)**5 - 8.32424559703991e+62*cos(theta)**3 + 1.16695031734204e+60*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl73_m33(theta, phi):
    return 4.08080462725762e-61*(1.0 - cos(theta)**2)**16.5*(3.41101273414269e+78*cos(theta)**40 - 1.83488960871124e+79*cos(theta)**38 + 4.51023564658741e+79*cos(theta)**36 - 6.71737223959828e+79*cos(theta)**34 + 6.77778026333567e+79*cos(theta)**32 - 4.90770658483868e+79*cos(theta)**30 + 2.63562020296892e+79*cos(theta)**28 - 1.07010143579189e+79*cos(theta)**26 + 3.31853975794241e+78*cos(theta)**24 - 7.88903508348067e+77*cos(theta)**22 + 1.4349347277827e+77*cos(theta)**20 - 1.98281889657246e+76*cos(theta)**18 + 2.05536105132512e+75*cos(theta)**16 - 1.56798045873499e+74*cos(theta)**14 + 8.56459914435078e+72*cos(theta)**12 - 3.2208748918926e+71*cos(theta)**10 + 7.87713968125908e+69*cos(theta)**8 - 1.14815154125588e+68*cos(theta)**6 + 8.61975631573483e+65*cos(theta)**4 - 2.49727367911197e+63*cos(theta)**2 + 1.16695031734204e+60)*cos(33*phi)

#@torch.jit.script
def Yl73_m34(theta, phi):
    return 6.23769188191126e-63*(1.0 - cos(theta)**2)**17*(1.36440509365707e+80*cos(theta)**39 - 6.97258051310271e+80*cos(theta)**37 + 1.62368483277147e+81*cos(theta)**35 - 2.28390656146341e+81*cos(theta)**33 + 2.16888968426741e+81*cos(theta)**31 - 1.4723119754516e+81*cos(theta)**29 + 7.37973656831297e+80*cos(theta)**27 - 2.78226373305892e+80*cos(theta)**25 + 7.96449541906179e+79*cos(theta)**23 - 1.73558771836575e+79*cos(theta)**21 + 2.86986945556541e+78*cos(theta)**19 - 3.56907401383044e+77*cos(theta)**17 + 3.28857768212018e+76*cos(theta)**15 - 2.19517264222899e+75*cos(theta)**13 + 1.02775189732209e+74*cos(theta)**11 - 3.2208748918926e+72*cos(theta)**9 + 6.30171174500727e+70*cos(theta)**7 - 6.88890924753527e+68*cos(theta)**5 + 3.44790252629393e+66*cos(theta)**3 - 4.99454735822395e+63*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl73_m35(theta, phi):
    return 9.61124697469081e-65*(1.0 - cos(theta)**2)**17.5*(5.32117986526259e+81*cos(theta)**38 - 2.579854789848e+82*cos(theta)**36 + 5.68289691470014e+82*cos(theta)**34 - 7.53689165282927e+82*cos(theta)**32 + 6.72355802122899e+82*cos(theta)**30 - 4.26970472880965e+82*cos(theta)**28 + 1.9925288734445e+82*cos(theta)**26 - 6.9556593326473e+81*cos(theta)**24 + 1.83183394638421e+81*cos(theta)**22 - 3.64473420856807e+80*cos(theta)**20 + 5.45275196557428e+79*cos(theta)**18 - 6.06742582351174e+78*cos(theta)**16 + 4.93286652318028e+77*cos(theta)**14 - 2.85372443489768e+76*cos(theta)**12 + 1.1305270870543e+75*cos(theta)**10 - 2.89878740270334e+73*cos(theta)**8 + 4.41119822150509e+71*cos(theta)**6 - 3.44445462376764e+69*cos(theta)**4 + 1.03437075788818e+67*cos(theta)**2 - 4.99454735822395e+63)*cos(35*phi)

#@torch.jit.script
def Yl73_m36(theta, phi):
    return 1.49339498964172e-66*(1.0 - cos(theta)**2)**18*(2.02204834879978e+83*cos(theta)**37 - 9.2874772434528e+83*cos(theta)**35 + 1.93218495099805e+84*cos(theta)**33 - 2.41180532890537e+84*cos(theta)**31 + 2.0170674063687e+84*cos(theta)**29 - 1.1955173240667e+84*cos(theta)**27 + 5.18057507095571e+83*cos(theta)**25 - 1.66935823983535e+83*cos(theta)**23 + 4.03003468204527e+82*cos(theta)**21 - 7.28946841713614e+81*cos(theta)**19 + 9.8149535380337e+80*cos(theta)**17 - 9.70788131761879e+79*cos(theta)**15 + 6.90601313245239e+78*cos(theta)**13 - 3.42446932187722e+77*cos(theta)**11 + 1.1305270870543e+76*cos(theta)**9 - 2.31902992216267e+74*cos(theta)**7 + 2.64671893290305e+72*cos(theta)**5 - 1.37778184950705e+70*cos(theta)**3 + 2.06874151577636e+67*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl73_m37(theta, phi):
    return 2.34087102118119e-68*(1.0 - cos(theta)**2)**18.5*(7.4815788905592e+84*cos(theta)**36 - 3.25061703520848e+85*cos(theta)**34 + 6.37621033829356e+85*cos(theta)**32 - 7.47659651960663e+85*cos(theta)**30 + 5.84949547846922e+85*cos(theta)**28 - 3.22789677498009e+85*cos(theta)**26 + 1.29514376773893e+85*cos(theta)**24 - 3.83952395162131e+84*cos(theta)**22 + 8.46307283229506e+83*cos(theta)**20 - 1.38499899925587e+83*cos(theta)**18 + 1.66854210146573e+82*cos(theta)**16 - 1.45618219764282e+81*cos(theta)**14 + 8.9778170721881e+79*cos(theta)**12 - 3.76691625406494e+78*cos(theta)**10 + 1.01747437834887e+77*cos(theta)**8 - 1.62332094551387e+75*cos(theta)**6 + 1.32335946645153e+73*cos(theta)**4 - 4.13334554852116e+70*cos(theta)**2 + 2.06874151577636e+67)*cos(37*phi)

#@torch.jit.script
def Yl73_m38(theta, phi):
    return 3.70309407796574e-70*(1.0 - cos(theta)**2)**19*(2.69336840060131e+86*cos(theta)**35 - 1.10520979197088e+87*cos(theta)**33 + 2.04038730825394e+87*cos(theta)**31 - 2.24297895588199e+87*cos(theta)**29 + 1.63785873397138e+87*cos(theta)**27 - 8.39253161494824e+86*cos(theta)**25 + 3.10834504257342e+86*cos(theta)**23 - 8.44695269356688e+85*cos(theta)**21 + 1.69261456645901e+85*cos(theta)**19 - 2.49299819866056e+84*cos(theta)**17 + 2.66966736234517e+83*cos(theta)**15 - 2.03865507669994e+82*cos(theta)**13 + 1.07733804866257e+81*cos(theta)**11 - 3.76691625406494e+79*cos(theta)**9 + 8.13979502679098e+77*cos(theta)**7 - 9.73992567308323e+75*cos(theta)**5 + 5.2934378658061e+73*cos(theta)**3 - 8.26669109704233e+70*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl73_m39(theta, phi):
    return 5.91455006100594e-72*(1.0 - cos(theta)**2)**19.5*(9.42678940210459e+87*cos(theta)**34 - 3.64719231350392e+88*cos(theta)**32 + 6.32520065558721e+88*cos(theta)**30 - 6.50463897205777e+88*cos(theta)**28 + 4.42221858172273e+88*cos(theta)**26 - 2.09813290373706e+88*cos(theta)**24 + 7.14919359791887e+87*cos(theta)**22 - 1.77386006564904e+87*cos(theta)**20 + 3.21596767627212e+86*cos(theta)**18 - 4.23809693772295e+85*cos(theta)**16 + 4.00450104351775e+84*cos(theta)**14 - 2.65025159970993e+83*cos(theta)**12 + 1.18507185352883e+82*cos(theta)**10 - 3.39022462865845e+80*cos(theta)**8 + 5.69785651875369e+78*cos(theta)**6 - 4.86996283654161e+76*cos(theta)**4 + 1.58803135974183e+74*cos(theta)**2 - 8.26669109704233e+70)*cos(39*phi)

#@torch.jit.script
def Yl73_m40(theta, phi):
    return 9.54207952634015e-74*(1.0 - cos(theta)**2)**20*(3.20510839671556e+89*cos(theta)**33 - 1.16710154032125e+90*cos(theta)**31 + 1.89756019667616e+90*cos(theta)**29 - 1.82129891217618e+90*cos(theta)**27 + 1.14977683124791e+90*cos(theta)**25 - 5.03551896896895e+89*cos(theta)**23 + 1.57282259154215e+89*cos(theta)**21 - 3.54772013129809e+88*cos(theta)**19 + 5.78874181728982e+87*cos(theta)**17 - 6.78095510035672e+86*cos(theta)**15 + 5.60630146092485e+85*cos(theta)**13 - 3.18030191965191e+84*cos(theta)**11 + 1.18507185352883e+83*cos(theta)**9 - 2.71217970292676e+81*cos(theta)**7 + 3.41871391125221e+79*cos(theta)**5 - 1.94798513461665e+77*cos(theta)**3 + 3.17606271948366e+74*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl73_m41(theta, phi):
    return 1.55572788517508e-75*(1.0 - cos(theta)**2)**20.5*(1.05768577091614e+91*cos(theta)**32 - 3.61801477499588e+91*cos(theta)**30 + 5.50292457036087e+91*cos(theta)**28 - 4.91750706287567e+91*cos(theta)**26 + 2.87444207811977e+91*cos(theta)**24 - 1.15816936286286e+91*cos(theta)**22 + 3.30292744223852e+90*cos(theta)**20 - 6.74066824946637e+89*cos(theta)**18 + 9.84086108939269e+88*cos(theta)**16 - 1.01714326505351e+88*cos(theta)**14 + 7.2881918992023e+86*cos(theta)**12 - 3.49833211161711e+85*cos(theta)**10 + 1.06656466817595e+84*cos(theta)**8 - 1.89852579204873e+82*cos(theta)**6 + 1.70935695562611e+80*cos(theta)**4 - 5.84395540384994e+77*cos(theta)**2 + 3.17606271948366e+74)*cos(41*phi)

#@torch.jit.script
def Yl73_m42(theta, phi):
    return 2.56454147350442e-77*(1.0 - cos(theta)**2)**21*(3.38459446693163e+92*cos(theta)**31 - 1.08540443249877e+93*cos(theta)**29 + 1.54081887970104e+93*cos(theta)**27 - 1.27855183634768e+93*cos(theta)**25 + 6.89866098748746e+92*cos(theta)**23 - 2.54797259829829e+92*cos(theta)**21 + 6.60585488447704e+91*cos(theta)**19 - 1.21332028490395e+91*cos(theta)**17 + 1.57453777430283e+90*cos(theta)**15 - 1.42400057107491e+89*cos(theta)**13 + 8.74583027904276e+87*cos(theta)**11 - 3.49833211161711e+86*cos(theta)**9 + 8.53251734540758e+84*cos(theta)**7 - 1.13911547522924e+83*cos(theta)**5 + 6.83742782250443e+80*cos(theta)**3 - 1.16879108076999e+78*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl73_m43(theta, phi):
    return 4.27661234525935e-79*(1.0 - cos(theta)**2)**21.5*(1.04922428474881e+94*cos(theta)**30 - 3.14767285424642e+94*cos(theta)**28 + 4.16021097519282e+94*cos(theta)**26 - 3.19637959086919e+94*cos(theta)**24 + 1.58669202712212e+94*cos(theta)**22 - 5.3507424564264e+93*cos(theta)**20 + 1.25511242805064e+93*cos(theta)**18 - 2.06264448433671e+92*cos(theta)**16 + 2.36180666145425e+91*cos(theta)**14 - 1.85120074239739e+90*cos(theta)**12 + 9.62041330694704e+88*cos(theta)**10 - 3.14849890045539e+87*cos(theta)**8 + 5.9727621417853e+85*cos(theta)**6 - 5.69557737614619e+83*cos(theta)**4 + 2.05122834675133e+81*cos(theta)**2 - 1.16879108076999e+78)*cos(43*phi)

#@torch.jit.script
def Yl73_m44(theta, phi):
    return 7.21848946633358e-81*(1.0 - cos(theta)**2)**22*(3.14767285424642e+95*cos(theta)**29 - 8.81348399188998e+95*cos(theta)**27 + 1.08165485355013e+96*cos(theta)**25 - 7.67131101808605e+95*cos(theta)**23 + 3.49072245966865e+95*cos(theta)**21 - 1.07014849128528e+95*cos(theta)**19 + 2.25920237049115e+94*cos(theta)**17 - 3.30023117493873e+93*cos(theta)**15 + 3.30652932603595e+92*cos(theta)**13 - 2.22144089087686e+91*cos(theta)**11 + 9.62041330694704e+89*cos(theta)**9 - 2.51879912036432e+88*cos(theta)**7 + 3.58365728507118e+86*cos(theta)**5 - 2.27823095045848e+84*cos(theta)**3 + 4.10245669350266e+81*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl73_m45(theta, phi):
    return 1.23397489589721e-82*(1.0 - cos(theta)**2)**22.5*(9.12825127731462e+96*cos(theta)**28 - 2.37964067781029e+97*cos(theta)**26 + 2.70413713387533e+97*cos(theta)**24 - 1.76440153415979e+97*cos(theta)**22 + 7.33051716530417e+96*cos(theta)**20 - 2.03328213344203e+96*cos(theta)**18 + 3.84064402983495e+95*cos(theta)**16 - 4.9503467624081e+94*cos(theta)**14 + 4.29848812384673e+93*cos(theta)**12 - 2.44358497996455e+92*cos(theta)**10 + 8.65837197625234e+90*cos(theta)**8 - 1.76315938425502e+89*cos(theta)**6 + 1.79182864253559e+87*cos(theta)**4 - 6.83469285137543e+84*cos(theta)**2 + 4.10245669350266e+81)*cos(45*phi)

#@torch.jit.script
def Yl73_m46(theta, phi):
    return 2.13773480468267e-84*(1.0 - cos(theta)**2)**23*(2.55591035764809e+98*cos(theta)**27 - 6.18706576230676e+98*cos(theta)**25 + 6.4899291213008e+98*cos(theta)**23 - 3.88168337515154e+98*cos(theta)**21 + 1.46610343306083e+98*cos(theta)**19 - 3.65990784019566e+97*cos(theta)**17 + 6.14503044773592e+96*cos(theta)**15 - 6.93048546737134e+95*cos(theta)**13 + 5.15818574861607e+94*cos(theta)**11 - 2.44358497996455e+93*cos(theta)**9 + 6.92669758100187e+91*cos(theta)**7 - 1.05789563055301e+90*cos(theta)**5 + 7.16731457014236e+87*cos(theta)**3 - 1.36693857027509e+85*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl73_m47(theta, phi):
    return 3.75561723122912e-86*(1.0 - cos(theta)**2)**23.5*(6.90095796564985e+99*cos(theta)**26 - 1.54676644057669e+100*cos(theta)**24 + 1.49268369789918e+100*cos(theta)**22 - 8.15153508781824e+99*cos(theta)**20 + 2.78559652281559e+99*cos(theta)**18 - 6.22184332833262e+98*cos(theta)**16 + 9.21754567160388e+97*cos(theta)**14 - 9.00963110758274e+96*cos(theta)**12 + 5.67400432347768e+95*cos(theta)**10 - 2.19922648196809e+94*cos(theta)**8 + 4.84868830670131e+92*cos(theta)**6 - 5.28947815276506e+90*cos(theta)**4 + 2.15019437104271e+88*cos(theta)**2 - 1.36693857027509e+85)*cos(47*phi)

#@torch.jit.script
def Yl73_m48(theta, phi):
    return 6.69579214951838e-88*(1.0 - cos(theta)**2)**24*(1.79424907106896e+101*cos(theta)**25 - 3.71223945738406e+101*cos(theta)**23 + 3.2839041353782e+101*cos(theta)**21 - 1.63030701756365e+101*cos(theta)**19 + 5.01407374106805e+100*cos(theta)**17 - 9.95494932533219e+99*cos(theta)**15 + 1.29045639402454e+99*cos(theta)**13 - 1.08115573290993e+98*cos(theta)**11 + 5.67400432347768e+96*cos(theta)**9 - 1.75938118557447e+95*cos(theta)**7 + 2.90921298402078e+93*cos(theta)**5 - 2.11579126110603e+91*cos(theta)**3 + 4.30038874208542e+88*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl73_m49(theta, phi):
    return 1.21241707520457e-89*(1.0 - cos(theta)**2)**24.5*(4.4856226776724e+102*cos(theta)**24 - 8.53815075198333e+102*cos(theta)**22 + 6.89619868429423e+102*cos(theta)**20 - 3.09758333337093e+102*cos(theta)**18 + 8.52392535981569e+101*cos(theta)**16 - 1.49324239879983e+101*cos(theta)**14 + 1.67759331223191e+100*cos(theta)**12 - 1.18927130620092e+99*cos(theta)**10 + 5.10660389112991e+97*cos(theta)**8 - 1.23156682990213e+96*cos(theta)**6 + 1.45460649201039e+94*cos(theta)**4 - 6.34737378331808e+91*cos(theta)**2 + 4.30038874208542e+88)*cos(49*phi)

#@torch.jit.script
def Yl73_m50(theta, phi):
    return 2.23148446423405e-91*(1.0 - cos(theta)**2)**25*(1.07654944264138e+104*cos(theta)**23 - 1.87839316543633e+104*cos(theta)**21 + 1.37923973685885e+104*cos(theta)**19 - 5.57565000006768e+103*cos(theta)**17 + 1.36382805757051e+103*cos(theta)**15 - 2.09053935831976e+102*cos(theta)**13 + 2.01311197467829e+101*cos(theta)**11 - 1.18927130620092e+100*cos(theta)**9 + 4.08528311290393e+98*cos(theta)**7 - 7.38940097941279e+96*cos(theta)**5 + 5.81842596804157e+94*cos(theta)**3 - 1.26947475666362e+92*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl73_m51(theta, phi):
    return 4.1784874970959e-93*(1.0 - cos(theta)**2)**25.5*(2.47606371807517e+105*cos(theta)**22 - 3.9446256474163e+105*cos(theta)**20 + 2.62055550003181e+105*cos(theta)**18 - 9.47860500011505e+104*cos(theta)**16 + 2.04574208635577e+104*cos(theta)**14 - 2.71770116581569e+103*cos(theta)**12 + 2.21442317214612e+102*cos(theta)**10 - 1.07034417558083e+101*cos(theta)**8 + 2.85969817903275e+99*cos(theta)**6 - 3.6947004897064e+97*cos(theta)**4 + 1.74552779041247e+95*cos(theta)**2 - 1.26947475666362e+92)*cos(51*phi)

#@torch.jit.script
def Yl73_m52(theta, phi):
    return 7.96806301622279e-95*(1.0 - cos(theta)**2)**26*(5.44734017976537e+106*cos(theta)**21 - 7.8892512948326e+106*cos(theta)**19 + 4.71699990005725e+106*cos(theta)**17 - 1.51657680001841e+106*cos(theta)**15 + 2.86403892089807e+105*cos(theta)**13 - 3.26124139897883e+104*cos(theta)**11 + 2.21442317214612e+103*cos(theta)**9 - 8.56275340464664e+101*cos(theta)**7 + 1.71581890741965e+100*cos(theta)**5 - 1.47788019588256e+98*cos(theta)**3 + 3.49105558082494e+95*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl73_m53(theta, phi):
    return 1.54902290699109e-96*(1.0 - cos(theta)**2)**26.5*(1.14394143775073e+108*cos(theta)**20 - 1.49895774601819e+108*cos(theta)**18 + 8.01889983009733e+107*cos(theta)**16 - 2.27486520002761e+107*cos(theta)**14 + 3.72325059716749e+106*cos(theta)**12 - 3.58736553887671e+105*cos(theta)**10 + 1.99298085493151e+104*cos(theta)**8 - 5.99392738325265e+102*cos(theta)**6 + 8.57909453709825e+100*cos(theta)**4 - 4.43364058764768e+98*cos(theta)**2 + 3.49105558082494e+95)*cos(53*phi)

#@torch.jit.script
def Yl73_m54(theta, phi):
    return 3.07355494909891e-98*(1.0 - cos(theta)**2)**27*(2.28788287550145e+109*cos(theta)**19 - 2.69812394283275e+109*cos(theta)**17 + 1.28302397281557e+109*cos(theta)**15 - 3.18481128003866e+108*cos(theta)**13 + 4.46790071660099e+107*cos(theta)**11 - 3.58736553887671e+106*cos(theta)**9 + 1.5943846839452e+105*cos(theta)**7 - 3.59635642995159e+103*cos(theta)**5 + 3.4316378148393e+101*cos(theta)**3 - 8.86728117529535e+98*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl73_m55(theta, phi):
    return 6.23245564707892e-100*(1.0 - cos(theta)**2)**27.5*(4.34697746345276e+110*cos(theta)**18 - 4.58681070281567e+110*cos(theta)**16 + 1.92453595922336e+110*cos(theta)**14 - 4.14025466405025e+109*cos(theta)**12 + 4.91469078826109e+108*cos(theta)**10 - 3.22862898498904e+107*cos(theta)**8 + 1.11606927876164e+106*cos(theta)**6 - 1.79817821497579e+104*cos(theta)**4 + 1.02949134445179e+102*cos(theta)**2 - 8.86728117529535e+98)*cos(55*phi)

#@torch.jit.script
def Yl73_m56(theta, phi):
    return 1.29338580091513e-101*(1.0 - cos(theta)**2)**28*(7.82455943421497e+111*cos(theta)**17 - 7.33889712450508e+111*cos(theta)**15 + 2.6943503429127e+111*cos(theta)**13 - 4.9683055968603e+110*cos(theta)**11 + 4.91469078826109e+109*cos(theta)**9 - 2.58290318799123e+108*cos(theta)**7 + 6.69641567256986e+106*cos(theta)**5 - 7.19271285990318e+104*cos(theta)**3 + 2.05898268890358e+102*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl73_m57(theta, phi):
    return 2.75126201400801e-103*(1.0 - cos(theta)**2)**28.5*(1.33017510381655e+113*cos(theta)**16 - 1.10083456867576e+113*cos(theta)**14 + 3.50265544578651e+112*cos(theta)**12 - 5.46513615654633e+111*cos(theta)**10 + 4.42322170943498e+110*cos(theta)**8 - 1.80803223159386e+109*cos(theta)**6 + 3.34820783628493e+107*cos(theta)**4 - 2.15781385797095e+105*cos(theta)**2 + 2.05898268890358e+102)*cos(57*phi)

#@torch.jit.script
def Yl73_m58(theta, phi):
    return 6.00947195644053e-105*(1.0 - cos(theta)**2)**29*(2.12828016610647e+114*cos(theta)**15 - 1.54116839614607e+114*cos(theta)**13 + 4.20318653494382e+113*cos(theta)**11 - 5.46513615654633e+112*cos(theta)**9 + 3.53857736754799e+111*cos(theta)**7 - 1.08481933895632e+110*cos(theta)**5 + 1.33928313451397e+108*cos(theta)**3 - 4.31562771594191e+105*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl73_m59(theta, phi):
    return 1.3505283888363e-106*(1.0 - cos(theta)**2)**29.5*(3.19242024915971e+115*cos(theta)**14 - 2.00351891498989e+115*cos(theta)**12 + 4.6235051884382e+114*cos(theta)**10 - 4.9186225408917e+113*cos(theta)**8 + 2.47700415728359e+112*cos(theta)**6 - 5.42409669478158e+110*cos(theta)**4 + 4.01784940354191e+108*cos(theta)**2 - 4.31562771594191e+105)*cos(59*phi)

#@torch.jit.script
def Yl73_m60(theta, phi):
    return 3.12978049306378e-108*(1.0 - cos(theta)**2)**30*(4.46938834882359e+116*cos(theta)**13 - 2.40422269798786e+116*cos(theta)**11 + 4.6235051884382e+115*cos(theta)**9 - 3.93489803271336e+114*cos(theta)**7 + 1.48620249437015e+113*cos(theta)**5 - 2.16963867791263e+111*cos(theta)**3 + 8.03569880708383e+108*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl73_m61(theta, phi):
    return 7.49876604267769e-110*(1.0 - cos(theta)**2)**30.5*(5.81020485347067e+117*cos(theta)**12 - 2.64464496778665e+117*cos(theta)**10 + 4.16115466959438e+116*cos(theta)**8 - 2.75442862289935e+115*cos(theta)**6 + 7.43101247185077e+113*cos(theta)**4 - 6.5089160337379e+111*cos(theta)**2 + 8.03569880708383e+108)*cos(61*phi)

#@torch.jit.script
def Yl73_m62(theta, phi):
    return 1.86308340208827e-111*(1.0 - cos(theta)**2)**31*(6.9722458241648e+118*cos(theta)**11 - 2.64464496778665e+118*cos(theta)**9 + 3.3289237356755e+117*cos(theta)**7 - 1.65265717373961e+116*cos(theta)**5 + 2.97240498874031e+114*cos(theta)**3 - 1.30178320674758e+112*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl73_m63(theta, phi):
    return 4.81688746326942e-113*(1.0 - cos(theta)**2)**31.5*(7.66947040658128e+119*cos(theta)**10 - 2.38018047100798e+119*cos(theta)**8 + 2.33024661497285e+118*cos(theta)**6 - 8.26328586869806e+116*cos(theta)**4 + 8.91721496622093e+114*cos(theta)**2 - 1.30178320674758e+112)*cos(63*phi)

#@torch.jit.script
def Yl73_m64(theta, phi):
    return 1.30138625789899e-114*(1.0 - cos(theta)**2)**32*(7.66947040658128e+120*cos(theta)**9 - 1.90414437680639e+120*cos(theta)**7 + 1.39814796898371e+119*cos(theta)**5 - 3.30531434747922e+117*cos(theta)**3 + 1.78344299324419e+115*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl73_m65(theta, phi):
    return 3.69271183692067e-116*(1.0 - cos(theta)**2)**32.5*(6.90252336592316e+121*cos(theta)**8 - 1.33290106376447e+121*cos(theta)**6 + 6.99073984491856e+119*cos(theta)**4 - 9.91594304243767e+117*cos(theta)**2 + 1.78344299324419e+115)*cos(65*phi)

#@torch.jit.script
def Yl73_m66(theta, phi):
    return 1.1073706913539e-117*(1.0 - cos(theta)**2)**33*(5.52201869273852e+122*cos(theta)**7 - 7.99740638258683e+121*cos(theta)**5 + 2.79629593796742e+120*cos(theta)**3 - 1.98318860848753e+118*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl73_m67(theta, phi):
    return 3.53736591736893e-119*(1.0 - cos(theta)**2)**33.5*(3.86541308491697e+123*cos(theta)**6 - 3.99870319129341e+122*cos(theta)**4 + 8.38888781390227e+120*cos(theta)**2 - 1.98318860848753e+118)*cos(67*phi)

#@torch.jit.script
def Yl73_m68(theta, phi):
    return 1.21617145432201e-120*(1.0 - cos(theta)**2)**34*(2.31924785095018e+124*cos(theta)**5 - 1.59948127651737e+123*cos(theta)**3 + 1.67777756278045e+121*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl73_m69(theta, phi):
    return 4.56421013685262e-122*(1.0 - cos(theta)**2)**34.5*(1.15962392547509e+125*cos(theta)**4 - 4.7984438295521e+123*cos(theta)**2 + 1.67777756278045e+121)*cos(69*phi)

#@torch.jit.script
def Yl73_m70(theta, phi):
    return 1.90839212946819e-123*(1.0 - cos(theta)**2)**35*(4.63849570190036e+125*cos(theta)**3 - 9.59688765910419e+123*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl73_m71(theta, phi):
    return 9.18175591389851e-125*(1.0 - cos(theta)**2)**35.5*(1.39154871057011e+126*cos(theta)**2 - 9.59688765910419e+123)*cos(71*phi)

#@torch.jit.script
def Yl73_m72(theta, phi):
    return 15.005661775717*(1.0 - cos(theta)**2)**36*cos(72*phi)*cos(theta)

#@torch.jit.script
def Yl73_m73(theta, phi):
    return 1.24187740479589*(1.0 - cos(theta)**2)**36.5*cos(73*phi)

#@torch.jit.script
def Yl74_m_minus_74(theta, phi):
    return 1.24606587336403*(1.0 - cos(theta)**2)**37*sin(74*phi)

#@torch.jit.script
def Yl74_m_minus_73(theta, phi):
    return 15.159045609564*(1.0 - cos(theta)**2)**36.5*sin(73*phi)*cos(theta)

#@torch.jit.script
def Yl74_m_minus_72(theta, phi):
    return 6.35330611770864e-127*(1.0 - cos(theta)**2)**36*(2.04557660453806e+128*cos(theta)**2 - 1.39154871057011e+126)*sin(72*phi)

#@torch.jit.script
def Yl74_m_minus_71(theta, phi):
    return 1.32964846474125e-125*(1.0 - cos(theta)**2)**35.5*(6.81858868179353e+127*cos(theta)**3 - 1.39154871057011e+126*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl74_m_minus_70(theta, phi):
    return 3.20221754894554e-124*(1.0 - cos(theta)**2)**35*(1.70464717044838e+127*cos(theta)**4 - 6.95774355285054e+125*cos(theta)**2 + 2.39922191477605e+123)*sin(70*phi)

#@torch.jit.script
def Yl74_m_minus_69(theta, phi):
    return 8.59245134182199e-123*(1.0 - cos(theta)**2)**34.5*(3.40929434089676e+126*cos(theta)**5 - 2.31924785095018e+125*cos(theta)**3 + 2.39922191477605e+123*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl74_m_minus_68(theta, phi):
    return 2.51686965917654e-121*(1.0 - cos(theta)**2)**34*(5.68215723482794e+125*cos(theta)**6 - 5.79811962737545e+124*cos(theta)**4 + 1.19961095738802e+123*cos(theta)**2 - 2.79629593796742e+120)*sin(68*phi)

#@torch.jit.script
def Yl74_m_minus_67(theta, phi):
    return 7.93512765114446e-120*(1.0 - cos(theta)**2)**33.5*(8.11736747832563e+124*cos(theta)**7 - 1.15962392547509e+124*cos(theta)**5 + 3.99870319129341e+122*cos(theta)**3 - 2.79629593796742e+120*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl74_m_minus_66(theta, phi):
    return 2.66506906003338e-118*(1.0 - cos(theta)**2)**33*(1.0146709347907e+124*cos(theta)**8 - 1.93270654245848e+123*cos(theta)**6 + 9.99675797823354e+121*cos(theta)**4 - 1.39814796898371e+120*cos(theta)**2 + 2.47898576060942e+117)*sin(66*phi)

#@torch.jit.script
def Yl74_m_minus_65(theta, phi):
    return 9.46005671197665e-117*(1.0 - cos(theta)**2)**32.5*(1.12741214976745e+123*cos(theta)**9 - 2.76100934636926e+122*cos(theta)**7 + 1.99935159564671e+121*cos(theta)**5 - 4.6604932299457e+119*cos(theta)**3 + 2.47898576060942e+117*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl74_m_minus_64(theta, phi):
    return 3.52696491989079e-115*(1.0 - cos(theta)**2)**32*(1.12741214976745e+122*cos(theta)**10 - 3.45126168296158e+121*cos(theta)**8 + 3.33225265941118e+120*cos(theta)**6 - 1.16512330748643e+119*cos(theta)**4 + 1.23949288030471e+117*cos(theta)**2 - 1.78344299324418e+114)*sin(64*phi)

#@torch.jit.script
def Yl74_m_minus_63(theta, phi):
    return 1.37415912422983e-113*(1.0 - cos(theta)**2)**31.5*(1.02492013615223e+121*cos(theta)**11 - 3.83473520329064e+120*cos(theta)**9 + 4.76036094201597e+119*cos(theta)**7 - 2.33024661497285e+118*cos(theta)**5 + 4.13164293434903e+116*cos(theta)**3 - 1.78344299324418e+114*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl74_m_minus_62(theta, phi):
    return 5.57170266890608e-112*(1.0 - cos(theta)**2)**31*(8.54100113460188e+119*cos(theta)**12 - 3.83473520329064e+119*cos(theta)**10 + 5.95045117751996e+118*cos(theta)**8 - 3.88374435828809e+117*cos(theta)**6 + 1.03291073358726e+116*cos(theta)**4 - 8.91721496622092e+113*cos(theta)**2 + 1.08481933895632e+111)*sin(62*phi)

#@torch.jit.script
def Yl74_m_minus_61(theta, phi):
    return 2.34276681031359e-110*(1.0 - cos(theta)**2)**30.5*(6.57000087277068e+118*cos(theta)**13 - 3.4861229120824e+118*cos(theta)**11 + 6.61161241946662e+117*cos(theta)**9 - 5.54820622612584e+116*cos(theta)**7 + 2.06582146717451e+115*cos(theta)**5 - 2.97240498874031e+113*cos(theta)**3 + 1.08481933895632e+111*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl74_m_minus_60(theta, phi):
    return 1.01849749430168e-108*(1.0 - cos(theta)**2)**30*(4.69285776626477e+117*cos(theta)**14 - 2.90510242673533e+117*cos(theta)**12 + 6.61161241946662e+116*cos(theta)**10 - 6.9352577826573e+115*cos(theta)**8 + 3.44303577862419e+114*cos(theta)**6 - 7.43101247185077e+112*cos(theta)**4 + 5.42409669478158e+110*cos(theta)**2 - 5.73978486220273e+107)*sin(60*phi)

#@torch.jit.script
def Yl74_m_minus_59(theta, phi):
    return 4.56623221404321e-107*(1.0 - cos(theta)**2)**29.5*(3.12857184417651e+116*cos(theta)**15 - 2.2346941744118e+116*cos(theta)**13 + 6.01055674496966e+115*cos(theta)**11 - 7.70584198073033e+114*cos(theta)**9 + 4.9186225408917e+113*cos(theta)**7 - 1.48620249437015e+112*cos(theta)**5 + 1.80803223159386e+110*cos(theta)**3 - 5.73978486220273e+107*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl74_m_minus_58(theta, phi):
    return 2.10641435321022e-105*(1.0 - cos(theta)**2)**29*(1.95535740261032e+115*cos(theta)**16 - 1.59621012457985e+115*cos(theta)**14 + 5.00879728747472e+114*cos(theta)**12 - 7.70584198073033e+113*cos(theta)**10 + 6.14827817611463e+112*cos(theta)**8 - 2.47700415728359e+111*cos(theta)**6 + 4.52008057898465e+109*cos(theta)**4 - 2.86989243110137e+107*cos(theta)**2 + 2.69726732246369e+104)*sin(58*phi)

#@torch.jit.script
def Yl74_m_minus_57(theta, phi):
    return 9.97826955093323e-104*(1.0 - cos(theta)**2)**28.5*(1.1502102368296e+114*cos(theta)**17 - 1.06414008305324e+114*cos(theta)**15 + 3.85292099036517e+113*cos(theta)**13 - 7.00531089157303e+112*cos(theta)**11 + 6.83142019568292e+111*cos(theta)**9 - 3.53857736754799e+110*cos(theta)**7 + 9.04016115796931e+108*cos(theta)**5 - 9.56630810367122e+106*cos(theta)**3 + 2.69726732246369e+104*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl74_m_minus_56(theta, phi):
    return 4.84537207548491e-102*(1.0 - cos(theta)**2)**28*(6.39005687127556e+112*cos(theta)**18 - 6.65087551908273e+112*cos(theta)**16 + 2.7520864216894e+112*cos(theta)**14 - 5.83775907631086e+111*cos(theta)**12 + 6.83142019568292e+110*cos(theta)**10 - 4.42322170943498e+109*cos(theta)**8 + 1.50669352632822e+108*cos(theta)**6 - 2.39157702591781e+106*cos(theta)**4 + 1.34863366123185e+104*cos(theta)**2 - 1.1438792716131e+101)*sin(56*phi)

#@torch.jit.script
def Yl74_m_minus_55(theta, phi):
    return 2.40810604953822e-100*(1.0 - cos(theta)**2)**27.5*(3.36318782698714e+111*cos(theta)**19 - 3.91227971710749e+111*cos(theta)**17 + 1.83472428112627e+111*cos(theta)**15 - 4.49058390485451e+110*cos(theta)**13 + 6.21038199607538e+109*cos(theta)**11 - 4.91469078826109e+108*cos(theta)**9 + 2.15241932332603e+107*cos(theta)**7 - 4.78315405183561e+105*cos(theta)**5 + 4.49544553743949e+103*cos(theta)**3 - 1.1438792716131e+101*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl74_m_minus_54(theta, phi):
    return 1.22316617203969e-98*(1.0 - cos(theta)**2)**27*(1.68159391349357e+110*cos(theta)**20 - 2.17348873172638e+110*cos(theta)**18 + 1.14670267570392e+110*cos(theta)**16 - 3.20755993203893e+109*cos(theta)**14 + 5.17531833006282e+108*cos(theta)**12 - 4.91469078826109e+107*cos(theta)**10 + 2.69052415415753e+106*cos(theta)**8 - 7.97192341972602e+104*cos(theta)**6 + 1.12386138435987e+103*cos(theta)**4 - 5.7193963580655e+100*cos(theta)**2 + 4.43364058764768e+97)*sin(54*phi)

#@torch.jit.script
def Yl74_m_minus_53(theta, phi):
    return 6.34161823364269e-97*(1.0 - cos(theta)**2)**26.5*(8.00759006425509e+108*cos(theta)**21 - 1.14394143775073e+109*cos(theta)**19 + 6.74530985708187e+108*cos(theta)**17 - 2.13837328802595e+108*cos(theta)**15 + 3.98101410004832e+107*cos(theta)**13 - 4.46790071660099e+106*cos(theta)**11 + 2.98947128239726e+105*cos(theta)**9 - 1.138846202818e+104*cos(theta)**7 + 2.24772276871974e+102*cos(theta)**5 - 1.9064654526885e+100*cos(theta)**3 + 4.43364058764768e+97*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl74_m_minus_52(theta, phi):
    return 3.35207166344377e-95*(1.0 - cos(theta)**2)**26*(3.63981366557049e+107*cos(theta)**22 - 5.71970718875363e+107*cos(theta)**20 + 3.74739436504548e+107*cos(theta)**18 - 1.33648330501622e+107*cos(theta)**16 + 2.84358150003451e+106*cos(theta)**14 - 3.72325059716749e+105*cos(theta)**12 + 2.98947128239726e+104*cos(theta)**10 - 1.4235577535225e+103*cos(theta)**8 + 3.7462046145329e+101*cos(theta)**6 - 4.76616363172125e+99*cos(theta)**4 + 2.21682029382384e+97*cos(theta)**2 - 1.58684344582952e+94)*sin(52*phi)

#@torch.jit.script
def Yl74_m_minus_51(theta, phi):
    return 1.80452326385747e-93*(1.0 - cos(theta)**2)**25.5*(1.58252768068282e+106*cos(theta)**23 - 2.72367008988268e+106*cos(theta)**21 + 1.97231282370815e+106*cos(theta)**19 - 7.86166650009542e+105*cos(theta)**17 + 1.89572100002301e+105*cos(theta)**15 - 2.86403892089807e+104*cos(theta)**13 + 2.71770116581569e+103*cos(theta)**11 - 1.58173083724723e+102*cos(theta)**9 + 5.35172087790415e+100*cos(theta)**7 - 9.5323272634425e+98*cos(theta)**5 + 7.38940097941279e+96*cos(theta)**3 - 1.58684344582952e+94*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl74_m_minus_50(theta, phi):
    return 9.88378097157581e-92*(1.0 - cos(theta)**2)**25*(6.59386533617843e+104*cos(theta)**24 - 1.23803185903758e+105*cos(theta)**22 + 9.86156411854075e+104*cos(theta)**20 - 4.36759250005301e+104*cos(theta)**18 + 1.18482562501438e+104*cos(theta)**16 - 2.04574208635577e+103*cos(theta)**14 + 2.26475097151307e+102*cos(theta)**12 - 1.58173083724723e+101*cos(theta)**10 + 6.68965109738019e+99*cos(theta)**8 - 1.58872121057375e+98*cos(theta)**6 + 1.8473502448532e+96*cos(theta)**4 - 7.9342172291476e+93*cos(theta)**2 + 5.28947815276506e+90)*sin(50*phi)

#@torch.jit.script
def Yl74_m_minus_49(theta, phi):
    return 5.50305634635573e-90*(1.0 - cos(theta)**2)**24.5*(2.63754613447137e+103*cos(theta)**25 - 5.38274721320688e+103*cos(theta)**23 + 4.69598291359083e+103*cos(theta)**21 - 2.29873289476474e+103*cos(theta)**19 + 6.96956250008459e+102*cos(theta)**17 - 1.36382805757051e+102*cos(theta)**15 + 1.74211613193313e+101*cos(theta)**13 - 1.43793712477021e+100*cos(theta)**11 + 7.43294566375576e+98*cos(theta)**9 - 2.26960172939107e+97*cos(theta)**7 + 3.6947004897064e+95*cos(theta)**5 - 2.64473907638253e+93*cos(theta)**3 + 5.28947815276506e+90*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl74_m_minus_48(theta, phi):
    return 3.11202580364349e-88*(1.0 - cos(theta)**2)**24*(1.01444082095053e+102*cos(theta)**26 - 2.2428113388362e+102*cos(theta)**24 + 2.13453768799583e+102*cos(theta)**22 - 1.14936644738237e+102*cos(theta)**20 + 3.87197916671366e+101*cos(theta)**18 - 8.52392535981569e+100*cos(theta)**16 + 1.24436866566652e+100*cos(theta)**14 - 1.1982809373085e+99*cos(theta)**12 + 7.43294566375576e+97*cos(theta)**10 - 2.83700216173884e+96*cos(theta)**8 + 6.15783414951066e+94*cos(theta)**6 - 6.61184769095633e+92*cos(theta)**4 + 2.64473907638253e+90*cos(theta)**2 - 1.65399567003285e+87)*sin(48*phi)

#@torch.jit.script
def Yl74_m_minus_47(theta, phi):
    return 1.78609677679504e-86*(1.0 - cos(theta)**2)**23.5*(3.7571882257427e+100*cos(theta)**27 - 8.97124535534481e+100*cos(theta)**25 + 9.28059864346014e+100*cos(theta)**23 - 5.47317355896367e+100*cos(theta)**21 + 2.03788377195456e+100*cos(theta)**19 - 5.01407374106805e+99*cos(theta)**17 + 8.29579110444349e+98*cos(theta)**15 - 9.21754567160388e+97*cos(theta)**13 + 6.75722333068706e+96*cos(theta)**11 - 3.15222462415427e+95*cos(theta)**9 + 8.79690592787237e+93*cos(theta)**7 - 1.32236953819127e+92*cos(theta)**5 + 8.81579692127511e+89*cos(theta)**3 - 1.65399567003285e+87*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl74_m_minus_46(theta, phi):
    return 1.03962493555662e-84*(1.0 - cos(theta)**2)**23*(1.34185293776525e+99*cos(theta)**28 - 3.45047898282493e+99*cos(theta)**26 + 3.86691610144173e+99*cos(theta)**24 - 2.48780616316531e+99*cos(theta)**22 + 1.01894188597728e+99*cos(theta)**20 - 2.78559652281558e+98*cos(theta)**18 + 5.18486944027718e+97*cos(theta)**16 - 6.58396119400277e+96*cos(theta)**14 + 5.63101944223921e+95*cos(theta)**12 - 3.15222462415427e+94*cos(theta)**10 + 1.09961324098405e+93*cos(theta)**8 - 2.20394923031878e+91*cos(theta)**6 + 2.20394923031878e+89*cos(theta)**4 - 8.26997835016427e+86*cos(theta)**2 + 4.88192346526816e+83)*sin(46*phi)

#@torch.jit.script
def Yl74_m_minus_45(theta, phi):
    return 6.13290601841919e-83*(1.0 - cos(theta)**2)**22.5*(4.62707909574224e+97*cos(theta)**29 - 1.27795517882405e+98*cos(theta)**27 + 1.54676644057669e+98*cos(theta)**25 - 1.08165485355013e+98*cos(theta)**23 + 4.85210421893943e+97*cos(theta)**21 - 1.46610343306083e+97*cos(theta)**19 + 3.04992320016305e+96*cos(theta)**17 - 4.38930746266852e+95*cos(theta)**15 + 4.33155341710709e+94*cos(theta)**13 - 2.86565874923115e+93*cos(theta)**11 + 1.22179248998227e+92*cos(theta)**9 - 3.1484989004554e+90*cos(theta)**7 + 4.40789846063755e+88*cos(theta)**5 - 2.75665945005475e+86*cos(theta)**3 + 4.88192346526816e+83*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl74_m_minus_44(theta, phi):
    return 3.66437926999678e-81*(1.0 - cos(theta)**2)**22*(1.54235969858075e+96*cos(theta)**30 - 4.56412563865731e+96*cos(theta)**28 + 5.94910169452573e+96*cos(theta)**26 - 4.50689522312556e+96*cos(theta)**24 + 2.20550191769974e+96*cos(theta)**22 - 7.33051716530417e+95*cos(theta)**20 + 1.69440177786836e+95*cos(theta)**18 - 2.74331716416782e+94*cos(theta)**16 + 3.09396672650506e+93*cos(theta)**14 - 2.38804895769263e+92*cos(theta)**12 + 1.22179248998227e+91*cos(theta)**10 - 3.93562362556924e+89*cos(theta)**8 + 7.34649743439592e+87*cos(theta)**6 - 6.89164862513689e+85*cos(theta)**4 + 2.44096173263408e+83*cos(theta)**2 - 1.36748556450089e+80)*sin(44*phi)

#@torch.jit.script
def Yl74_m_minus_43(theta, phi):
    return 2.21626796076129e-79*(1.0 - cos(theta)**2)**21.5*(4.9753538663895e+94*cos(theta)**31 - 1.57383642712321e+95*cos(theta)**29 + 2.20337099797249e+95*cos(theta)**27 - 1.80275808925022e+95*cos(theta)**25 + 9.58913877260756e+94*cos(theta)**23 - 3.49072245966865e+94*cos(theta)**21 + 8.917904094044e+93*cos(theta)**19 - 1.61371597892225e+93*cos(theta)**17 + 2.06264448433671e+92*cos(theta)**15 - 1.83696073668664e+91*cos(theta)**13 + 1.11072044543843e+90*cos(theta)**11 - 4.37291513952138e+88*cos(theta)**9 + 1.04949963348513e+87*cos(theta)**7 - 1.37832972502738e+85*cos(theta)**5 + 8.13653910878027e+82*cos(theta)**3 - 1.36748556450089e+80*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl74_m_minus_42(theta, phi):
    return 1.35609522951268e-77*(1.0 - cos(theta)**2)**21*(1.55479808324672e+93*cos(theta)**32 - 5.24612142374403e+93*cos(theta)**30 + 7.86918213561605e+93*cos(theta)**28 - 6.9336849586547e+93*cos(theta)**26 + 3.99547448858649e+93*cos(theta)**24 - 1.58669202712212e+93*cos(theta)**22 + 4.458952047022e+92*cos(theta)**20 - 8.96508877179027e+91*cos(theta)**18 + 1.28915280271044e+91*cos(theta)**16 - 1.31211481191903e+90*cos(theta)**14 + 9.25600371198692e+88*cos(theta)**12 - 4.37291513952138e+87*cos(theta)**10 + 1.31187454185641e+86*cos(theta)**8 - 2.29721620837896e+84*cos(theta)**6 + 2.03413477719507e+82*cos(theta)**4 - 6.83742782250443e+79*cos(theta)**2 + 3.65247212740621e+76)*sin(42*phi)

#@torch.jit.script
def Yl74_m_minus_41(theta, phi):
    return 8.39027417390453e-76*(1.0 - cos(theta)**2)**20.5*(4.71150934317188e+91*cos(theta)**33 - 1.69229723346582e+92*cos(theta)**31 + 2.71351108124691e+92*cos(theta)**29 - 2.56803146616841e+92*cos(theta)**27 + 1.59818979543459e+92*cos(theta)**25 - 6.89866098748746e+91*cos(theta)**23 + 2.12331049858191e+91*cos(theta)**21 - 4.71846777462646e+90*cos(theta)**19 + 7.58325178064966e+89*cos(theta)**17 - 8.74743207946017e+88*cos(theta)**15 + 7.12000285537456e+87*cos(theta)**13 - 3.97537739956489e+86*cos(theta)**11 + 1.45763837984046e+85*cos(theta)**9 - 3.28173744054138e+83*cos(theta)**7 + 4.06826955439013e+81*cos(theta)**5 - 2.27914260750148e+79*cos(theta)**3 + 3.65247212740621e+76*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl74_m_minus_40(theta, phi):
    return 5.24643783713255e-74*(1.0 - cos(theta)**2)**20*(1.38573804210938e+90*cos(theta)**34 - 5.28842885458068e+90*cos(theta)**32 + 9.04503693748971e+90*cos(theta)**30 - 9.17154095060146e+90*cos(theta)**28 + 6.14688382859459e+90*cos(theta)**26 - 2.87444207811977e+90*cos(theta)**24 + 9.65141135719048e+89*cos(theta)**22 - 2.35923388731323e+89*cos(theta)**20 + 4.21291765591648e+88*cos(theta)**18 - 5.46714504966261e+87*cos(theta)**16 + 5.08571632526754e+86*cos(theta)**14 - 3.31281449963741e+85*cos(theta)**12 + 1.45763837984046e+84*cos(theta)**10 - 4.10217180067672e+82*cos(theta)**8 + 6.78044925731689e+80*cos(theta)**6 - 5.69785651875369e+78*cos(theta)**4 + 1.82623606370311e+76*cos(theta)**2 - 9.34136093965783e+72)*sin(40*phi)

#@torch.jit.script
def Yl74_m_minus_39(theta, phi):
    return 3.31398836473207e-72*(1.0 - cos(theta)**2)**19.5*(3.95925154888393e+88*cos(theta)**35 - 1.60255419835778e+89*cos(theta)**33 + 2.91775385080313e+89*cos(theta)**31 - 3.16260032779361e+89*cos(theta)**29 + 2.27662364022022e+89*cos(theta)**27 - 1.14977683124791e+89*cos(theta)**25 + 4.19626580747412e+88*cos(theta)**23 - 1.12344470824439e+88*cos(theta)**21 + 2.21732508206131e+87*cos(theta)**19 - 3.21596767627212e+86*cos(theta)**17 + 3.39047755017836e+85*cos(theta)**15 - 2.54831884587493e+84*cos(theta)**13 + 1.32512579985496e+83*cos(theta)**11 - 4.55796866741858e+81*cos(theta)**9 + 9.68635608188127e+79*cos(theta)**7 - 1.13957130375074e+78*cos(theta)**5 + 6.08745354567702e+75*cos(theta)**3 - 9.34136093965783e+72*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl74_m_minus_38(theta, phi):
    return 2.11369077232848e-70*(1.0 - cos(theta)**2)**19*(1.0997920969122e+87*cos(theta)**36 - 4.7133947010523e+87*cos(theta)**34 + 9.11798078375979e+87*cos(theta)**32 - 1.05420010926454e+88*cos(theta)**30 + 8.13079871507221e+87*cos(theta)**28 - 4.42221858172273e+87*cos(theta)**26 + 1.74844408644755e+87*cos(theta)**24 - 5.10656685565634e+86*cos(theta)**22 + 1.10866254103065e+86*cos(theta)**20 - 1.78664870904007e+85*cos(theta)**18 + 2.11904846886148e+84*cos(theta)**16 - 1.82022774705352e+83*cos(theta)**14 + 1.10427149987914e+82*cos(theta)**12 - 4.55796866741858e+80*cos(theta)**10 + 1.21079451023516e+79*cos(theta)**8 - 1.89928550625123e+77*cos(theta)**6 + 1.52186338641925e+75*cos(theta)**4 - 4.67068046982891e+72*cos(theta)**2 + 2.29630308251176e+69)*sin(38*phi)

#@torch.jit.script
def Yl74_m_minus_37(theta, phi):
    return 1.36066534806227e-68*(1.0 - cos(theta)**2)**18.5*(2.97241107273568e+85*cos(theta)**37 - 1.34668420030066e+86*cos(theta)**35 + 2.76302447992721e+86*cos(theta)**33 - 3.40064551375657e+86*cos(theta)**31 + 2.80372369485249e+86*cos(theta)**29 - 1.63785873397138e+86*cos(theta)**27 + 6.9937763457902e+85*cos(theta)**25 - 2.22024645898102e+85*cos(theta)**23 + 5.2793454334793e+84*cos(theta)**21 - 9.40341425810562e+83*cos(theta)**19 + 1.24649909933028e+83*cos(theta)**17 - 1.21348516470235e+82*cos(theta)**15 + 8.49439615291644e+80*cos(theta)**13 - 4.14360787947143e+79*cos(theta)**11 + 1.34532723359462e+78*cos(theta)**9 - 2.71326500893033e+76*cos(theta)**7 + 3.04372677283851e+74*cos(theta)**5 - 1.55689348994297e+72*cos(theta)**3 + 2.29630308251176e+69*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl74_m_minus_36(theta, phi):
    return 8.83699506561061e-67*(1.0 - cos(theta)**2)**18*(7.82213440193601e+83*cos(theta)**38 - 3.7407894452796e+84*cos(theta)**36 + 8.1265425880212e+84*cos(theta)**34 - 1.06270172304893e+85*cos(theta)**32 + 9.34574564950829e+84*cos(theta)**30 - 5.84949547846922e+84*cos(theta)**28 + 2.68991397915008e+84*cos(theta)**26 - 9.2510269124209e+83*cos(theta)**24 + 2.39970246976332e+83*cos(theta)**22 - 4.70170712905281e+82*cos(theta)**20 + 6.92499499627933e+81*cos(theta)**18 - 7.58428227938968e+80*cos(theta)**16 + 6.06742582351174e+79*cos(theta)**14 - 3.45300656622619e+78*cos(theta)**12 + 1.34532723359462e+77*cos(theta)**10 - 3.39158126116291e+75*cos(theta)**8 + 5.07287795473085e+73*cos(theta)**6 - 3.89223372485743e+71*cos(theta)**4 + 1.14815154125588e+69*cos(theta)**2 - 5.4440566204641e+65)*sin(36*phi)

#@torch.jit.script
def Yl74_m_minus_35(theta, phi):
    return 5.78806312057407e-65*(1.0 - cos(theta)**2)**17.5*(2.0056754876759e+82*cos(theta)**39 - 1.01102417439989e+83*cos(theta)**37 + 2.3218693108632e+83*cos(theta)**35 - 3.22030825166341e+83*cos(theta)**33 + 3.01475666113171e+83*cos(theta)**31 - 2.0170674063687e+83*cos(theta)**29 + 9.96264436722251e+82*cos(theta)**27 - 3.70041076496836e+82*cos(theta)**25 + 1.04334889989709e+82*cos(theta)**23 - 2.23890815669181e+81*cos(theta)**21 + 3.64473420856807e+80*cos(theta)**19 - 4.46134251728805e+79*cos(theta)**17 + 4.04495054900783e+78*cos(theta)**15 - 2.65615889709707e+77*cos(theta)**13 + 1.22302475781329e+76*cos(theta)**11 - 3.76842362351435e+74*cos(theta)**9 + 7.24696850675836e+72*cos(theta)**7 - 7.78446744971486e+70*cos(theta)**5 + 3.82717180418626e+68*cos(theta)**3 - 5.4440566204641e+65*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl74_m_minus_34(theta, phi):
    return 3.82187521563157e-63*(1.0 - cos(theta)**2)**17*(5.01418871918975e+80*cos(theta)**40 - 2.6605899326313e+81*cos(theta)**38 + 6.44963697462e+81*cos(theta)**36 - 9.47149485783357e+81*cos(theta)**34 + 9.42111456603658e+81*cos(theta)**32 - 6.72355802122899e+81*cos(theta)**30 + 3.55808727400804e+81*cos(theta)**28 - 1.42323490960322e+81*cos(theta)**26 + 4.34728708290456e+80*cos(theta)**24 - 1.01768552576901e+80*cos(theta)**22 + 1.82236710428403e+79*cos(theta)**20 - 2.47852362071558e+78*cos(theta)**18 + 2.52809409312989e+77*cos(theta)**16 - 1.89725635506934e+76*cos(theta)**14 + 1.01918729817774e+75*cos(theta)**12 - 3.76842362351435e+73*cos(theta)**10 + 9.05871063344794e+71*cos(theta)**8 - 1.29741124161914e+70*cos(theta)**6 + 9.56792951046566e+67*cos(theta)**4 - 2.72202831023205e+65*cos(theta)**2 + 1.24863683955599e+62)*sin(34*phi)

#@torch.jit.script
def Yl74_m_minus_33(theta, phi):
    return 2.5431987961142e-61*(1.0 - cos(theta)**2)**16.5*(1.22297285833896e+79*cos(theta)**41 - 6.82202546828537e+79*cos(theta)**39 + 1.74314512827568e+80*cos(theta)**37 - 2.70614138795245e+80*cos(theta)**35 + 2.85488320182927e+80*cos(theta)**33 - 2.16888968426741e+80*cos(theta)**31 + 1.22692664620967e+80*cos(theta)**29 - 5.27124040593784e+79*cos(theta)**27 + 1.73891483316182e+79*cos(theta)**25 - 4.42471967725655e+78*cos(theta)**23 + 8.67793859182874e+77*cos(theta)**21 - 1.3044861161661e+77*cos(theta)**19 + 1.48711417242935e+76*cos(theta)**17 - 1.26483757004622e+75*cos(theta)**15 + 7.83990229367495e+73*cos(theta)**13 - 3.42583965774031e+72*cos(theta)**11 + 1.00652340371644e+71*cos(theta)**9 - 1.85344463088449e+69*cos(theta)**7 + 1.91358590209313e+67*cos(theta)**5 - 9.0734277007735e+64*cos(theta)**3 + 1.24863683955599e+62*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl74_m_minus_32(theta, phi):
    return 1.70489188407376e-59*(1.0 - cos(theta)**2)**16*(2.91184013890229e+77*cos(theta)**42 - 1.70550636707134e+78*cos(theta)**40 + 4.5872240217781e+78*cos(theta)**38 - 7.51705941097902e+78*cos(theta)**36 + 8.39671529949785e+78*cos(theta)**34 - 6.77778026333567e+78*cos(theta)**32 + 4.08975548736556e+78*cos(theta)**30 - 1.88258585926351e+78*cos(theta)**28 + 6.68813397369932e+77*cos(theta)**26 - 1.8436331988569e+77*cos(theta)**24 + 3.94451754174034e+76*cos(theta)**22 - 6.52243058083048e+75*cos(theta)**20 + 8.26174540238527e+74*cos(theta)**18 - 7.90523481278891e+73*cos(theta)**16 + 5.59993020976782e+72*cos(theta)**14 - 2.85486638145026e+71*cos(theta)**12 + 1.00652340371644e+70*cos(theta)**10 - 2.31680578860561e+68*cos(theta)**8 + 3.18930983682189e+66*cos(theta)**6 - 2.26835692519338e+64*cos(theta)**4 + 6.24318419777993e+61*cos(theta)**2 - 2.77845313652867e+58)*sin(32*phi)

#@torch.jit.script
def Yl74_m_minus_31(theta, phi):
    return 1.15102300503607e-57*(1.0 - cos(theta)**2)**15.5*(6.77172125326115e+75*cos(theta)**43 - 4.15977162700328e+76*cos(theta)**41 + 1.17621128763541e+77*cos(theta)**39 - 2.03163767864298e+77*cos(theta)**37 + 2.39906151414224e+77*cos(theta)**35 - 2.05387280707142e+77*cos(theta)**33 + 1.31927596366631e+77*cos(theta)**31 - 6.49167537677074e+76*cos(theta)**29 + 2.47708665692568e+76*cos(theta)**27 - 7.37453279542758e+75*cos(theta)**25 + 1.71500762684362e+75*cos(theta)**23 - 3.10591932420499e+74*cos(theta)**21 + 4.34828705388698e+73*cos(theta)**19 - 4.65013812516994e+72*cos(theta)**17 + 3.73328680651188e+71*cos(theta)**15 - 2.19605106265405e+70*cos(theta)**13 + 9.15021276105853e+68*cos(theta)**11 - 2.57422865400624e+67*cos(theta)**9 + 4.55615690974555e+65*cos(theta)**7 - 4.53671385038675e+63*cos(theta)**5 + 2.08106139925998e+61*cos(theta)**3 - 2.77845313652867e+58*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl74_m_minus_30(theta, phi):
    return 7.82357034002052e-56*(1.0 - cos(theta)**2)**15*(1.53902755755935e+74*cos(theta)**44 - 9.90421815953161e+74*cos(theta)**42 + 2.94052821908852e+75*cos(theta)**40 - 5.34641494379731e+75*cos(theta)**38 + 6.66405976150623e+75*cos(theta)**36 - 6.04080237373946e+75*cos(theta)**34 + 4.12273738645722e+75*cos(theta)**32 - 2.16389179225691e+75*cos(theta)**30 + 8.84673806044884e+74*cos(theta)**28 - 2.83635876747215e+74*cos(theta)**26 + 7.14586511184843e+73*cos(theta)**24 - 1.41178151100227e+73*cos(theta)**22 + 2.17414352694349e+72*cos(theta)**20 - 2.58341006953886e+71*cos(theta)**18 + 2.33330425406992e+70*cos(theta)**16 - 1.56860790189575e+69*cos(theta)**14 + 7.62517730088211e+67*cos(theta)**12 - 2.57422865400624e+66*cos(theta)**10 + 5.69519613718194e+64*cos(theta)**8 - 7.56118975064458e+62*cos(theta)**6 + 5.20265349814994e+60*cos(theta)**4 - 1.38922656826434e+58*cos(theta)**2 + 6.01396782798414e+54)*sin(30*phi)

#@torch.jit.script
def Yl74_m_minus_29(theta, phi):
    return 5.35214558293554e-54*(1.0 - cos(theta)**2)**14.5*(3.42006123902078e+72*cos(theta)**45 - 2.30330654872828e+73*cos(theta)**43 + 7.17202004655737e+73*cos(theta)**41 - 1.3708756266147e+74*cos(theta)**39 + 1.80109723283952e+74*cos(theta)**37 - 1.72594353535413e+74*cos(theta)**35 + 1.24931435953249e+74*cos(theta)**33 - 6.98029610405455e+73*cos(theta)**31 + 3.05059933118926e+73*cos(theta)**29 - 1.05050324721191e+73*cos(theta)**27 + 2.85834604473937e+72*cos(theta)**25 - 6.13818048261855e+71*cos(theta)**23 + 1.03530644140166e+71*cos(theta)**21 - 1.35968951028361e+70*cos(theta)**19 + 1.37253191415878e+69*cos(theta)**17 - 1.04573860126383e+68*cos(theta)**15 + 5.86552100067854e+66*cos(theta)**13 - 2.3402078672784e+65*cos(theta)**11 + 6.32799570797993e+63*cos(theta)**9 - 1.0801699643778e+62*cos(theta)**7 + 1.04053069962999e+60*cos(theta)**5 - 4.63075522754779e+57*cos(theta)**3 + 6.01396782798414e+54*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl74_m_minus_28(theta, phi):
    return 3.68404941024624e-52*(1.0 - cos(theta)**2)**14*(7.4349157370017e+70*cos(theta)**46 - 5.23478761074609e+71*cos(theta)**44 + 1.7076238206089e+72*cos(theta)**42 - 3.42718906653674e+72*cos(theta)**40 + 4.739729560104e+72*cos(theta)**38 - 4.79428759820592e+72*cos(theta)**36 + 3.67445399862497e+72*cos(theta)**34 - 2.18134253251705e+72*cos(theta)**32 + 1.01686644372975e+72*cos(theta)**30 - 3.75179731147109e+71*cos(theta)**28 + 1.0993638633613e+71*cos(theta)**26 - 2.55757520109106e+70*cos(theta)**24 + 4.70593837000756e+69*cos(theta)**22 - 6.79844755141805e+68*cos(theta)**20 + 7.62517730088211e+67*cos(theta)**18 - 6.53586625789895e+66*cos(theta)**16 + 4.18965785762753e+65*cos(theta)**14 - 1.950173222732e+64*cos(theta)**12 + 6.32799570797993e+62*cos(theta)**10 - 1.35021245547225e+61*cos(theta)**8 + 1.73421783271665e+59*cos(theta)**6 - 1.15768880688695e+57*cos(theta)**4 + 3.00698391399207e+54*cos(theta)**2 - 1.26930515575858e+51)*sin(28*phi)

#@torch.jit.script
def Yl74_m_minus_27(theta, phi):
    return 2.55078856344285e-50*(1.0 - cos(theta)**2)**13.5*(1.58189696531951e+69*cos(theta)**47 - 1.16328613572135e+70*cos(theta)**45 + 3.97121818746255e+70*cos(theta)**43 - 8.35899772326034e+70*cos(theta)**41 + 1.21531527182154e+71*cos(theta)**39 - 1.29575340492052e+71*cos(theta)**37 + 1.04984399960714e+71*cos(theta)**35 - 6.6101288864153e+70*cos(theta)**33 + 3.2802143346121e+70*cos(theta)**31 - 1.2937232108521e+70*cos(theta)**29 + 4.07171801244925e+69*cos(theta)**27 - 1.02303008043643e+69*cos(theta)**25 + 2.04606016087285e+68*cos(theta)**23 - 3.23735597686574e+67*cos(theta)**21 + 4.01325121099058e+66*cos(theta)**19 - 3.84462721052879e+65*cos(theta)**17 + 2.79310523841835e+64*cos(theta)**15 - 1.50013324825538e+63*cos(theta)**13 + 5.75272337089085e+61*cos(theta)**11 - 1.50023606163583e+60*cos(theta)**9 + 2.47745404673807e+58*cos(theta)**7 - 2.3153776137739e+56*cos(theta)**5 + 1.00232797133069e+54*cos(theta)**3 - 1.26930515575858e+51*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl74_m_minus_26(theta, phi):
    return 1.77605236657185e-48*(1.0 - cos(theta)**2)**13*(3.29561867774898e+67*cos(theta)**48 - 2.52888290374207e+68*cos(theta)**46 + 9.02549588059671e+68*cos(theta)**44 - 1.99023755315722e+69*cos(theta)**42 + 3.03828817955385e+69*cos(theta)**40 - 3.40987738136979e+69*cos(theta)**38 + 2.91623333224204e+69*cos(theta)**36 - 1.94415555482803e+69*cos(theta)**34 + 1.02506697956628e+69*cos(theta)**32 - 4.31241070284034e+68*cos(theta)**30 + 1.45418500444616e+68*cos(theta)**28 - 3.93473107860164e+67*cos(theta)**26 + 8.52525067030355e+66*cos(theta)**24 - 1.47152544402988e+66*cos(theta)**22 + 2.00662560549529e+65*cos(theta)**20 - 2.13590400584933e+64*cos(theta)**18 + 1.74569077401147e+63*cos(theta)**16 - 1.07152374875384e+62*cos(theta)**14 + 4.79393614240904e+60*cos(theta)**12 - 1.50023606163583e+59*cos(theta)**10 + 3.09681755842258e+57*cos(theta)**8 - 3.85896268962316e+55*cos(theta)**6 + 2.50581992832673e+53*cos(theta)**4 - 6.34652577879289e+50*cos(theta)**2 + 2.61820370412248e+47)*sin(26*phi)

#@torch.jit.script
def Yl74_m_minus_25(theta, phi):
    return 1.2432366566003e-46*(1.0 - cos(theta)**2)**12.5*(6.72575240356935e+65*cos(theta)**49 - 5.38060192285548e+66*cos(theta)**47 + 2.00566575124371e+67*cos(theta)**45 - 4.62845942594703e+67*cos(theta)**43 + 7.41045897452158e+67*cos(theta)**41 - 8.7432753368456e+67*cos(theta)**39 + 7.88171170876228e+67*cos(theta)**37 - 5.55473015665151e+67*cos(theta)**35 + 3.10626357444328e+67*cos(theta)**33 - 1.39110022672269e+67*cos(theta)**31 + 5.01443104981435e+66*cos(theta)**29 - 1.4573078068895e+66*cos(theta)**27 + 3.41010026812142e+65*cos(theta)**25 - 6.39793671317339e+64*cos(theta)**23 + 9.55536002616806e+63*cos(theta)**21 - 1.12416000307859e+63*cos(theta)**19 + 1.0268769258891e+62*cos(theta)**17 - 7.14349165835896e+60*cos(theta)**15 + 3.68764318646849e+59*cos(theta)**13 - 1.36385096512348e+58*cos(theta)**11 + 3.44090839824732e+56*cos(theta)**9 - 5.5128038423188e+54*cos(theta)**7 + 5.01163985665345e+52*cos(theta)**5 - 2.11550859293096e+50*cos(theta)**3 + 2.61820370412248e+47*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl74_m_minus_24(theta, phi):
    return 8.74694521096234e-45*(1.0 - cos(theta)**2)**12*(1.34515048071387e+64*cos(theta)**50 - 1.12095873392822e+65*cos(theta)**48 + 4.36014293748634e+65*cos(theta)**46 - 1.05192259680614e+66*cos(theta)**44 + 1.76439499393371e+66*cos(theta)**42 - 2.1858188342114e+66*cos(theta)**40 + 2.0741346602006e+66*cos(theta)**38 - 1.54298059906986e+66*cos(theta)**36 + 9.13606933659788e+65*cos(theta)**34 - 4.34718820850841e+65*cos(theta)**32 + 1.67147701660478e+65*cos(theta)**30 - 5.20467073889105e+64*cos(theta)**28 + 1.31157702620055e+64*cos(theta)**26 - 2.66580696382225e+63*cos(theta)**24 + 4.34334546644003e+62*cos(theta)**22 - 5.62080001539297e+61*cos(theta)**20 + 5.70487181049501e+60*cos(theta)**18 - 4.46468228647435e+59*cos(theta)**16 + 2.63403084747749e+58*cos(theta)**14 - 1.13654247093623e+57*cos(theta)**12 + 3.44090839824732e+55*cos(theta)**10 - 6.8910048028985e+53*cos(theta)**8 + 8.35273309442242e+51*cos(theta)**6 - 5.28877148232741e+49*cos(theta)**4 + 1.30910185206124e+47*cos(theta)**2 - 5.28930041236865e+43)*sin(24*phi)

#@torch.jit.script
def Yl74_m_minus_23(theta, phi):
    return 6.18378714475877e-43*(1.0 - cos(theta)**2)**11.5*(2.63754996218406e+62*cos(theta)**51 - 2.28767088556781e+63*cos(theta)**49 + 9.2768998669922e+63*cos(theta)**47 - 2.33760577068032e+64*cos(theta)**45 + 4.10324417193886e+64*cos(theta)**43 - 5.3312654492961e+64*cos(theta)**41 + 5.31829400051436e+64*cos(theta)**39 - 4.17021783532396e+64*cos(theta)**37 + 2.61030552474225e+64*cos(theta)**35 - 1.31732976015406e+64*cos(theta)**33 + 5.39186134388639e+63*cos(theta)**31 - 1.79471404789347e+63*cos(theta)**29 + 4.85769268963165e+62*cos(theta)**27 - 1.0663227855289e+62*cos(theta)**25 + 1.88841107236523e+61*cos(theta)**23 - 2.67657143590142e+60*cos(theta)**21 + 3.00256411078684e+59*cos(theta)**19 - 2.62628369792609e+58*cos(theta)**17 + 1.756020564985e+57*cos(theta)**15 - 8.74263439181719e+55*cos(theta)**13 + 3.1280985438612e+54*cos(theta)**11 - 7.65667200322055e+52*cos(theta)**9 + 1.19324758491749e+51*cos(theta)**7 - 1.05775429646548e+49*cos(theta)**5 + 4.36367284020413e+46*cos(theta)**3 - 5.28930041236865e+43*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl74_m_minus_22(theta, phi):
    return 4.39179511236912e-41*(1.0 - cos(theta)**2)**11*(5.07221146573857e+60*cos(theta)**52 - 4.57534177113561e+61*cos(theta)**50 + 1.93268747229004e+62*cos(theta)**48 - 5.081751675392e+62*cos(theta)**46 + 9.32555493622468e+62*cos(theta)**44 - 1.26934891649907e+63*cos(theta)**42 + 1.32957350012859e+63*cos(theta)**40 - 1.09742574613788e+63*cos(theta)**38 + 7.25084867983959e+62*cos(theta)**36 - 3.87449929457077e+62*cos(theta)**34 + 1.6849566699645e+62*cos(theta)**32 - 5.98238015964489e+61*cos(theta)**30 + 1.73489024629702e+61*cos(theta)**28 - 4.10124148280346e+60*cos(theta)**26 + 7.86837946818845e+59*cos(theta)**24 - 1.21662337995519e+59*cos(theta)**22 + 1.50128205539342e+58*cos(theta)**20 - 1.45904649884783e+57*cos(theta)**18 + 1.09751285311562e+56*cos(theta)**16 - 6.24473885129799e+54*cos(theta)**14 + 2.606748786551e+53*cos(theta)**12 - 7.65667200322055e+51*cos(theta)**10 + 1.49155948114686e+50*cos(theta)**8 - 1.76292382744247e+48*cos(theta)**6 + 1.09091821005103e+46*cos(theta)**4 - 2.64465020618432e+43*cos(theta)**2 + 1.04863211981932e+40)*sin(22*phi)

#@torch.jit.script
def Yl74_m_minus_21(theta, phi):
    return 3.13267702778855e-39*(1.0 - cos(theta)**2)**10.5*(9.57021031271429e+58*cos(theta)**53 - 8.97125837477571e+59*cos(theta)**51 + 3.9442601475307e+60*cos(theta)**49 - 1.0812237607217e+61*cos(theta)**47 + 2.07234554138326e+61*cos(theta)**45 - 2.95197422441645e+61*cos(theta)**43 + 3.24286219543558e+61*cos(theta)**41 - 2.81391216958432e+61*cos(theta)**39 + 1.95968883238908e+61*cos(theta)**37 - 1.10699979844879e+61*cos(theta)**35 + 5.10592930292272e+60*cos(theta)**33 - 1.92980005149835e+60*cos(theta)**31 + 5.98238015964489e+59*cos(theta)**29 - 1.51897832696424e+59*cos(theta)**27 + 3.14735178727538e+58*cos(theta)**25 - 5.28966686937039e+57*cos(theta)**23 + 7.14896216854011e+56*cos(theta)**21 - 7.67919209919909e+55*cos(theta)**19 + 6.45595795950366e+54*cos(theta)**17 - 4.16315923419866e+53*cos(theta)**15 + 2.00519137427e+52*cos(theta)**13 - 6.96061091201868e+50*cos(theta)**11 + 1.6572883123854e+49*cos(theta)**9 - 2.5184626106321e+47*cos(theta)**7 + 2.18183642010207e+45*cos(theta)**5 - 8.81550068728108e+42*cos(theta)**3 + 1.04863211981932e+40*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl74_m_minus_20(theta, phi):
    return 2.24374916822329e-37*(1.0 - cos(theta)**2)**10*(1.77226116902116e+57*cos(theta)**54 - 1.72524199514917e+58*cos(theta)**52 + 7.8885202950614e+58*cos(theta)**50 - 2.25254950150355e+59*cos(theta)**48 + 4.50509900300709e+59*cos(theta)**46 - 6.70903232821919e+59*cos(theta)**44 + 7.72110046532282e+59*cos(theta)**42 - 7.03478042396079e+59*cos(theta)**40 + 5.1570758747081e+59*cos(theta)**38 - 3.07499944013553e+59*cos(theta)**36 + 1.50174391262433e+59*cos(theta)**34 - 6.03062516093235e+58*cos(theta)**32 + 1.99412671988163e+58*cos(theta)**30 - 5.42492259630087e+57*cos(theta)**28 + 1.21051991818284e+57*cos(theta)**26 - 2.20402786223766e+56*cos(theta)**24 + 3.24952825842732e+55*cos(theta)**22 - 3.83959604959955e+54*cos(theta)**20 + 3.58664331083537e+53*cos(theta)**18 - 2.60197452137416e+52*cos(theta)**16 + 1.43227955305e+51*cos(theta)**14 - 5.8005090933489e+49*cos(theta)**12 + 1.6572883123854e+48*cos(theta)**10 - 3.14807826329012e+46*cos(theta)**8 + 3.63639403350344e+44*cos(theta)**6 - 2.20387517182027e+42*cos(theta)**4 + 5.2431605990966e+39*cos(theta)**2 - 2.04411719263025e+36)*sin(20*phi)

#@torch.jit.script
def Yl74_m_minus_19(theta, phi):
    return 1.6133165035292e-35*(1.0 - cos(theta)**2)**9.5*(3.22229303458393e+55*cos(theta)**55 - 3.25517357575316e+56*cos(theta)**53 + 1.54676868530616e+57*cos(theta)**51 - 4.59703979898683e+57*cos(theta)**49 + 9.58531702767466e+57*cos(theta)**47 - 1.4908960729376e+58*cos(theta)**45 + 1.7956047593774e+58*cos(theta)**43 - 1.71580010340507e+58*cos(theta)**41 + 1.32232714736105e+58*cos(theta)**39 - 8.3108092976636e+57*cos(theta)**37 + 4.29069689321237e+57*cos(theta)**35 - 1.8274621699795e+57*cos(theta)**33 + 6.43266683832784e+56*cos(theta)**31 - 1.87066296424168e+56*cos(theta)**29 + 4.48340710438088e+55*cos(theta)**27 - 8.81611144895065e+54*cos(theta)**25 + 1.41283837322927e+54*cos(theta)**23 - 1.82837907123788e+53*cos(theta)**21 + 1.88770700570283e+52*cos(theta)**19 - 1.53057324786716e+51*cos(theta)**17 + 9.54853035366666e+49*cos(theta)**15 - 4.46193007180685e+48*cos(theta)**13 + 1.50662573853218e+47*cos(theta)**11 - 3.49786473698903e+45*cos(theta)**9 + 5.19484861929063e+43*cos(theta)**7 - 4.40775034364054e+41*cos(theta)**5 + 1.74772019969887e+39*cos(theta)**3 - 2.04411719263025e+36*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl74_m_minus_18(theta, phi):
    return 1.16427363845596e-33*(1.0 - cos(theta)**2)**9*(5.75409470461417e+53*cos(theta)**56 - 6.0280992143577e+54*cos(theta)**54 + 2.9745551640503e+55*cos(theta)**52 - 9.19407959797366e+55*cos(theta)**50 + 1.99694104743222e+56*cos(theta)**48 - 3.24107841942956e+56*cos(theta)**46 + 4.08091990767591e+56*cos(theta)**44 - 4.08523834144064e+56*cos(theta)**42 + 3.30581786840263e+56*cos(theta)**40 - 2.18705507833253e+56*cos(theta)**38 + 1.19186024811455e+56*cos(theta)**36 - 5.37488873523382e+55*cos(theta)**34 + 2.01020838697745e+55*cos(theta)**32 - 6.23554321413893e+54*cos(theta)**30 + 1.60121682299317e+54*cos(theta)**28 - 3.39081209575025e+53*cos(theta)**26 + 5.88682655512196e+52*cos(theta)**24 - 8.31081396017218e+51*cos(theta)**22 + 9.43853502851413e+50*cos(theta)**20 - 8.50318471037309e+49*cos(theta)**18 + 5.96783147104166e+48*cos(theta)**16 - 3.18709290843346e+47*cos(theta)**14 + 1.25552144877682e+46*cos(theta)**12 - 3.49786473698903e+44*cos(theta)**10 + 6.49356077411329e+42*cos(theta)**8 - 7.34625057273423e+40*cos(theta)**6 + 4.36930049924716e+38*cos(theta)**4 - 1.02205859631513e+36*cos(theta)**2 + 3.92495620704733e+32)*sin(18*phi)

#@torch.jit.script
def Yl74_m_minus_17(theta, phi):
    return 8.43114203633594e-32*(1.0 - cos(theta)**2)**8.5*(1.00949029905512e+52*cos(theta)**57 - 1.09601803897413e+53*cos(theta)**55 + 5.61236823405717e+53*cos(theta)**53 - 1.80276070548503e+54*cos(theta)**51 + 4.07538989271882e+54*cos(theta)**49 - 6.8959115307012e+54*cos(theta)**47 + 9.06871090594646e+54*cos(theta)**45 - 9.5005542824201e+54*cos(theta)**43 + 8.06297041073812e+54*cos(theta)**41 - 5.60783353418597e+54*cos(theta)**39 + 3.2212439138231e+54*cos(theta)**37 - 1.53568249578109e+54*cos(theta)**35 + 6.09154056659833e+53*cos(theta)**33 - 2.01146555294804e+53*cos(theta)**31 + 5.52143732066611e+52*cos(theta)**29 - 1.25585633175935e+52*cos(theta)**27 + 2.35473062204878e+51*cos(theta)**25 - 3.6133973739879e+50*cos(theta)**23 + 4.49454048976863e+49*cos(theta)**21 - 4.47536037388057e+48*cos(theta)**19 + 3.51048910061274e+47*cos(theta)**17 - 2.12472860562231e+46*cos(theta)**15 + 9.65785729828322e+44*cos(theta)**13 - 3.17987703362639e+43*cos(theta)**11 + 7.21506752679255e+41*cos(theta)**9 - 1.04946436753346e+40*cos(theta)**7 + 8.73860099849433e+37*cos(theta)**5 - 3.40686198771709e+35*cos(theta)**3 + 3.92495620704733e+32*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl74_m_minus_16(theta, phi):
    return 6.12521163358953e-30*(1.0 - cos(theta)**2)**8*(1.74050051561227e+50*cos(theta)**58 - 1.95717506959666e+51*cos(theta)**56 + 1.03932745075133e+52*cos(theta)**54 - 3.46684751054814e+52*cos(theta)**52 + 8.15077978543764e+52*cos(theta)**50 - 1.43664823556275e+53*cos(theta)**48 + 1.97145889259706e+53*cos(theta)**46 - 2.15921688236821e+53*cos(theta)**44 + 1.91975485969955e+53*cos(theta)**42 - 1.40195838354649e+53*cos(theta)**40 + 8.47695766795553e+52*cos(theta)**38 - 4.26578471050303e+52*cos(theta)**36 + 1.79162957841127e+52*cos(theta)**34 - 6.28582985296263e+51*cos(theta)**32 + 1.8404791068887e+51*cos(theta)**30 - 4.48520118485483e+50*cos(theta)**28 + 9.05665623864917e+49*cos(theta)**26 - 1.50558223916163e+49*cos(theta)**24 + 2.04297294989483e+48*cos(theta)**22 - 2.23768018694029e+47*cos(theta)**20 + 1.95027172256263e+46*cos(theta)**18 - 1.32795537851394e+45*cos(theta)**16 + 6.89846949877373e+43*cos(theta)**14 - 2.64989752802199e+42*cos(theta)**12 + 7.21506752679255e+40*cos(theta)**10 - 1.31183045941683e+39*cos(theta)**8 + 1.45643349974905e+37*cos(theta)**6 - 8.51715496929272e+34*cos(theta)**4 + 1.96247810352367e+32*cos(theta)**2 - 7.43644601562587e+28)*sin(16*phi)

#@torch.jit.script
def Yl74_m_minus_15(theta, phi):
    return 4.46342620890884e-28*(1.0 - cos(theta)**2)**7.5*(2.9500008739191e+48*cos(theta)**59 - 3.43364047297659e+49*cos(theta)**57 + 1.88968627409332e+50*cos(theta)**55 - 6.54122171801535e+50*cos(theta)**53 + 1.59819211479169e+51*cos(theta)**51 - 2.93193517461786e+51*cos(theta)**49 + 4.19459338850438e+51*cos(theta)**47 - 4.79825973859601e+51*cos(theta)**45 + 4.46454618534779e+51*cos(theta)**43 - 3.41941069157681e+51*cos(theta)**41 + 2.17357888921937e+51*cos(theta)**39 - 1.15291478662244e+51*cos(theta)**37 + 5.11894165260364e+50*cos(theta)**35 - 1.90479692514019e+50*cos(theta)**33 + 5.93702937706034e+49*cos(theta)**31 - 1.5466210982258e+49*cos(theta)**29 + 3.35431712542562e+48*cos(theta)**27 - 6.02232895664651e+47*cos(theta)**25 + 8.88249108649927e+46*cos(theta)**23 - 1.06556199378109e+46*cos(theta)**21 + 1.02645880134875e+45*cos(theta)**19 - 7.81150222655261e+43*cos(theta)**17 + 4.59897966584915e+42*cos(theta)**15 - 2.03838271386307e+41*cos(theta)**13 + 6.55915229708413e+39*cos(theta)**11 - 1.45758939935203e+38*cos(theta)**9 + 2.08061928535579e+36*cos(theta)**7 - 1.70343099385854e+34*cos(theta)**5 + 6.54159367841222e+31*cos(theta)**3 - 7.43644601562587e+28*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl74_m_minus_14(theta, phi):
    return 3.26166225427279e-26*(1.0 - cos(theta)**2)**7*(4.91666812319851e+46*cos(theta)**60 - 5.92006978099412e+47*cos(theta)**58 + 3.37443977516665e+48*cos(theta)**56 - 1.21133735518803e+49*cos(theta)**54 + 3.07344637459941e+49*cos(theta)**52 - 5.86387034923571e+49*cos(theta)**50 + 8.73873622605079e+49*cos(theta)**48 - 1.04309994317305e+50*cos(theta)**46 + 1.01466958757904e+50*cos(theta)**44 - 8.14145402756383e+49*cos(theta)**42 + 5.43394722304842e+49*cos(theta)**40 - 3.03398628058537e+49*cos(theta)**38 + 1.42192823683434e+49*cos(theta)**36 - 5.60234389747115e+48*cos(theta)**34 + 1.85532168033136e+48*cos(theta)**32 - 5.15540366075267e+47*cos(theta)**30 + 1.19797040193772e+47*cos(theta)**28 - 2.31628036794096e+46*cos(theta)**26 + 3.70103795270803e+45*cos(theta)**24 - 4.84346360809586e+44*cos(theta)**22 + 5.13229400674377e+43*cos(theta)**20 - 4.33972345919589e+42*cos(theta)**18 + 2.87436229115572e+41*cos(theta)**16 - 1.45598765275934e+40*cos(theta)**14 + 5.46596024757011e+38*cos(theta)**12 - 1.45758939935203e+37*cos(theta)**10 + 2.60077410669474e+35*cos(theta)**8 - 2.83905165643091e+33*cos(theta)**6 + 1.63539841960306e+31*cos(theta)**4 - 3.71822300781294e+28*cos(theta)**2 + 1.39259288682132e+25)*sin(14*phi)

#@torch.jit.script
def Yl74_m_minus_13(theta, phi):
    return 2.38971022234848e-24*(1.0 - cos(theta)**2)**6.5*(8.0601116773746e+44*cos(theta)**61 - 1.00340165779561e+46*cos(theta)**59 + 5.92006978099412e+46*cos(theta)**57 - 2.20243155488732e+47*cos(theta)**55 + 5.79895542377247e+47*cos(theta)**53 - 1.14977849985014e+48*cos(theta)**51 + 1.7834155563369e+48*cos(theta)**49 - 2.21936158121925e+48*cos(theta)**47 + 2.25482130573121e+48*cos(theta)**45 - 1.89336140175903e+48*cos(theta)**43 + 1.32535298123132e+48*cos(theta)**41 - 7.77945200150096e+47*cos(theta)**39 + 3.84304928874147e+47*cos(theta)**37 - 1.60066968499176e+47*cos(theta)**35 + 5.62218691009502e+46*cos(theta)**33 - 1.66303343895248e+46*cos(theta)**31 + 4.1309324204749e+45*cos(theta)**29 - 8.57881617755912e+44*cos(theta)**27 + 1.48041518108321e+44*cos(theta)**25 - 2.10585374265037e+43*cos(theta)**23 + 2.44394952702085e+42*cos(theta)**21 - 2.28406497852415e+41*cos(theta)**19 + 1.69080134773866e+40*cos(theta)**17 - 9.7065843517289e+38*cos(theta)**15 + 4.20458480582316e+37*cos(theta)**13 - 1.32508127213821e+36*cos(theta)**11 + 2.8897490074386e+34*cos(theta)**9 - 4.05578808061558e+32*cos(theta)**7 + 3.27079683920611e+30*cos(theta)**5 - 1.23940766927098e+28*cos(theta)**3 + 1.39259288682132e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl74_m_minus_12(theta, phi):
    return 1.75509533709773e-22*(1.0 - cos(theta)**2)**6*(1.30001801247977e+43*cos(theta)**62 - 1.67233609632602e+44*cos(theta)**60 + 1.0207016863783e+45*cos(theta)**58 - 3.93291349087022e+45*cos(theta)**56 + 1.07388063403194e+46*cos(theta)**54 - 2.21111249971181e+46*cos(theta)**52 + 3.56683111267379e+46*cos(theta)**50 - 4.62366996087343e+46*cos(theta)**48 + 4.90178544724176e+46*cos(theta)**46 - 4.30309409490689e+46*cos(theta)**44 + 3.15560233626505e+46*cos(theta)**42 - 1.94486300037524e+46*cos(theta)**40 + 1.01132876019512e+46*cos(theta)**38 - 4.44630468053266e+45*cos(theta)**36 + 1.65358438532206e+45*cos(theta)**34 - 5.19697949672649e+44*cos(theta)**32 + 1.37697747349163e+44*cos(theta)**30 - 3.06386292055683e+43*cos(theta)**28 + 5.69390454262774e+42*cos(theta)**26 - 8.77439059437655e+41*cos(theta)**24 + 1.11088614864584e+41*cos(theta)**22 - 1.14203248926208e+40*cos(theta)**20 + 9.39334082077033e+38*cos(theta)**18 - 6.06661521983056e+37*cos(theta)**16 + 3.00327486130226e+36*cos(theta)**14 - 1.10423439344851e+35*cos(theta)**12 + 2.8897490074386e+33*cos(theta)**10 - 5.06973510076947e+31*cos(theta)**8 + 5.45132806534352e+29*cos(theta)**6 - 3.09851917317745e+27*cos(theta)**4 + 6.96296443410662e+24*cos(theta)**2 - 2.58174432113705e+21)*sin(12*phi)

#@torch.jit.script
def Yl74_m_minus_11(theta, phi):
    return 1.29187416345375e-20*(1.0 - cos(theta)**2)**5.5*(2.0635206547298e+41*cos(theta)**63 - 2.74153458414102e+42*cos(theta)**61 + 1.7300028582683e+43*cos(theta)**59 - 6.89984822959688e+43*cos(theta)**57 + 1.95251024369444e+44*cos(theta)**55 - 4.17191037681473e+44*cos(theta)**53 + 6.9937864954388e+44*cos(theta)**51 - 9.43606114463966e+44*cos(theta)**49 + 1.04293307388123e+45*cos(theta)**47 - 9.5624313220153e+44*cos(theta)**45 + 7.33861008433733e+44*cos(theta)**43 - 4.74356829359814e+44*cos(theta)**41 + 2.59315066716698e+44*cos(theta)**39 - 1.20170396771153e+44*cos(theta)**37 + 4.7245268152059e+43*cos(theta)**35 - 1.5748422717353e+43*cos(theta)**33 + 4.44186281771494e+42*cos(theta)**31 - 1.05650445536442e+42*cos(theta)**29 + 2.10885353430657e+41*cos(theta)**27 - 3.50975623775062e+40*cos(theta)**25 + 4.82993977672104e+39*cos(theta)**23 - 5.43824994886703e+38*cos(theta)**21 + 4.94386358987912e+37*cos(theta)**19 - 3.56859718813563e+36*cos(theta)**17 + 2.00218324086817e+35*cos(theta)**15 - 8.49411071883467e+33*cos(theta)**13 + 2.62704455221691e+32*cos(theta)**11 - 5.63303900085497e+30*cos(theta)**9 + 7.78761152191932e+28*cos(theta)**7 - 6.19703834635489e+26*cos(theta)**5 + 2.32098814470221e+24*cos(theta)**3 - 2.58174432113705e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl74_m_minus_10(theta, phi):
    return 9.52839302655195e-19*(1.0 - cos(theta)**2)**5*(3.22425102301531e+39*cos(theta)**64 - 4.421829974421e+40*cos(theta)**62 + 2.88333809711383e+41*cos(theta)**60 - 1.18962900510291e+42*cos(theta)**58 + 3.48662543516864e+42*cos(theta)**56 - 7.72575995706431e+42*cos(theta)**54 + 1.34495894143054e+43*cos(theta)**52 - 1.88721222892793e+43*cos(theta)**50 + 2.17277723725255e+43*cos(theta)**48 - 2.07878941782941e+43*cos(theta)**46 + 1.66786592825848e+43*cos(theta)**44 - 1.12942102228527e+43*cos(theta)**42 + 6.48287666791746e+42*cos(theta)**40 - 3.16237886239876e+42*cos(theta)**38 + 1.31236855977942e+42*cos(theta)**36 - 4.63188903451558e+41*cos(theta)**34 + 1.38808213053592e+41*cos(theta)**32 - 3.52168151788141e+40*cos(theta)**30 + 7.53161976538061e+39*cos(theta)**28 - 1.3499062452887e+39*cos(theta)**26 + 2.0124749069671e+38*cos(theta)**24 - 2.47193179493956e+37*cos(theta)**22 + 2.47193179493956e+36*cos(theta)**20 - 1.98255399340868e+35*cos(theta)**18 + 1.25136452554261e+34*cos(theta)**16 - 6.06722194202477e+32*cos(theta)**14 + 2.18920379351409e+31*cos(theta)**12 - 5.63303900085497e+29*cos(theta)**10 + 9.73451440239914e+27*cos(theta)**8 - 1.03283972439248e+26*cos(theta)**6 + 5.80247036175552e+23*cos(theta)**4 - 1.29087216056852e+21*cos(theta)**2 + 4.74585353150193e+17)*sin(10*phi)

#@torch.jit.script
def Yl74_m_minus_9(theta, phi):
    return 7.04070233875644e-17*(1.0 - cos(theta)**2)**4.5*(4.96038618925433e+37*cos(theta)**65 - 7.01877773717619e+38*cos(theta)**63 + 4.72678376576038e+39*cos(theta)**61 - 2.01632034763205e+40*cos(theta)**59 + 6.11688672836603e+40*cos(theta)**57 - 1.40468362855715e+41*cos(theta)**55 + 2.53765838005762e+41*cos(theta)**53 - 3.70041613515281e+41*cos(theta)**51 + 4.43423925969909e+41*cos(theta)**49 - 4.42295620814769e+41*cos(theta)**47 + 3.7063687294633e+41*cos(theta)**45 - 2.62656051694249e+41*cos(theta)**43 + 1.58118943119938e+41*cos(theta)**41 - 8.10866374974042e+40*cos(theta)**39 + 3.54694205345788e+40*cos(theta)**37 - 1.32339686700445e+40*cos(theta)**35 + 4.20630948647249e+39*cos(theta)**33 - 1.13602629609078e+39*cos(theta)**31 + 2.59711026392435e+38*cos(theta)**29 - 4.99965276032852e+37*cos(theta)**27 + 8.0498996278684e+36*cos(theta)**25 - 1.07475295432155e+36*cos(theta)**23 + 1.17711037854265e+35*cos(theta)**21 - 1.0434494702151e+34*cos(theta)**19 + 7.36096779730946e+32*cos(theta)**17 - 4.04481462801651e+31*cos(theta)**15 + 1.68400291808776e+30*cos(theta)**13 - 5.12094454623179e+28*cos(theta)**11 + 1.08161271137768e+27*cos(theta)**9 - 1.47548532056069e+25*cos(theta)**7 + 1.1604940723511e+23*cos(theta)**5 - 4.30290720189508e+20*cos(theta)**3 + 4.74585353150193e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl74_m_minus_8(theta, phi):
    return 5.21107109008342e-15*(1.0 - cos(theta)**2)**4*(7.51573665038535e+35*cos(theta)**66 - 1.09668402143378e+37*cos(theta)**64 + 7.62384478348449e+37*cos(theta)**62 - 3.36053391272008e+38*cos(theta)**60 + 1.05463564282173e+39*cos(theta)**58 - 2.50836362242348e+39*cos(theta)**56 + 4.69936737047708e+39*cos(theta)**54 - 7.11618487529386e+39*cos(theta)**52 + 8.86847851939817e+39*cos(theta)**50 - 9.21449210030769e+39*cos(theta)**48 + 8.05732332492021e+39*cos(theta)**46 - 5.96945572032385e+39*cos(theta)**44 + 3.76473674095091e+39*cos(theta)**42 - 2.0271659374351e+39*cos(theta)**40 + 9.33405803541547e+38*cos(theta)**38 - 3.6761024083457e+38*cos(theta)**36 + 1.2371498489625e+38*cos(theta)**34 - 3.55008217528368e+37*cos(theta)**32 + 8.65703421308116e+36*cos(theta)**30 - 1.7855902715459e+36*cos(theta)**28 + 3.09611524148784e+35*cos(theta)**26 - 4.47813730967312e+34*cos(theta)**24 + 5.3505017206484e+33*cos(theta)**22 - 5.21724735107548e+32*cos(theta)**20 + 4.08942655406081e+31*cos(theta)**18 - 2.52800914251032e+30*cos(theta)**16 + 1.20285922720554e+29*cos(theta)**14 - 4.26745378852649e+27*cos(theta)**12 + 1.08161271137768e+26*cos(theta)**10 - 1.84435665070086e+24*cos(theta)**8 + 1.93415678725184e+22*cos(theta)**6 - 1.07572680047377e+20*cos(theta)**4 + 2.37292676575096e+17*cos(theta)**2 - 86634785167979.7)*sin(8*phi)

#@torch.jit.script
def Yl74_m_minus_7(theta, phi):
    return 3.86252519617713e-13*(1.0 - cos(theta)**2)**3.5*(1.12175173886348e+34*cos(theta)**67 - 1.6872061868212e+35*cos(theta)**65 + 1.21013409261659e+36*cos(theta)**63 - 5.50907198806571e+36*cos(theta)**61 + 1.7875180386809e+37*cos(theta)**59 - 4.40063793407628e+37*cos(theta)**57 + 8.54430430995832e+37*cos(theta)**55 - 1.34267639156488e+38*cos(theta)**53 + 1.73891735674474e+38*cos(theta)**51 - 1.88050859189953e+38*cos(theta)**49 + 1.71432411168515e+38*cos(theta)**47 - 1.32654571562752e+38*cos(theta)**45 + 8.75520172314165e+37*cos(theta)**43 - 4.94430716447586e+37*cos(theta)**41 + 2.3933482142091e+37*cos(theta)**39 - 9.93541191444784e+36*cos(theta)**37 + 3.53471385417856e+36*cos(theta)**35 - 1.07578247735869e+36*cos(theta)**33 + 2.79259168163908e+35*cos(theta)**31 - 6.1572078329169e+34*cos(theta)**29 + 1.1467093486992e+34*cos(theta)**27 - 1.79125492386925e+33*cos(theta)**25 + 2.32630509593409e+32*cos(theta)**23 - 2.48440350051213e+31*cos(theta)**21 + 2.15232976529516e+30*cos(theta)**19 - 1.48706420147666e+29*cos(theta)**17 + 8.01906151470363e+27*cos(theta)**15 - 3.28265676040499e+26*cos(theta)**13 + 9.83284283070621e+24*cos(theta)**11 - 2.0492851674454e+23*cos(theta)**9 + 2.76308112464548e+21*cos(theta)**7 - 2.15145360094754e+19*cos(theta)**5 + 7.90975588583655e+16*cos(theta)**3 - 86634785167979.7*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl74_m_minus_6(theta, phi):
    return 2.86660788578062e-11*(1.0 - cos(theta)**2)**3*(1.64963491009336e+32*cos(theta)**68 - 2.55637301033515e+33*cos(theta)**66 + 1.89083451971341e+34*cos(theta)**64 - 8.88559998075115e+34*cos(theta)**62 + 2.97919673113483e+35*cos(theta)**60 - 7.58730678289014e+35*cos(theta)**58 + 1.52576862677827e+36*cos(theta)**56 - 2.48643776215718e+36*cos(theta)**54 + 3.34407183989373e+36*cos(theta)**52 - 3.76101718379906e+36*cos(theta)**50 + 3.57150856601073e+36*cos(theta)**48 - 2.88379503397287e+36*cos(theta)**46 + 1.98981857344128e+36*cos(theta)**44 - 1.17721599154187e+36*cos(theta)**42 + 5.98337053552274e+35*cos(theta)**40 - 2.61458208274943e+35*cos(theta)**38 + 9.81864959494044e+34*cos(theta)**36 - 3.16406610987851e+34*cos(theta)**34 + 8.72684900512213e+33*cos(theta)**32 - 2.0524026109723e+33*cos(theta)**30 + 4.09539053106858e+32*cos(theta)**28 - 6.88944201488172e+31*cos(theta)**26 + 9.69293789972536e+30*cos(theta)**24 - 1.12927431841461e+30*cos(theta)**22 + 1.07616488264758e+29*cos(theta)**20 - 8.26146778598144e+27*cos(theta)**18 + 5.01191344668977e+26*cos(theta)**16 - 2.34475482886071e+25*cos(theta)**14 + 8.19403569225517e+23*cos(theta)**12 - 2.0492851674454e+22*cos(theta)**10 + 3.45385140580686e+20*cos(theta)**8 - 3.58575600157923e+18*cos(theta)**6 + 1.97743897145914e+16*cos(theta)**4 - 43317392583989.9*cos(theta)**2 + 15728900720.403)*sin(6*phi)

#@torch.jit.script
def Yl74_m_minus_5(theta, phi):
    return 2.12979513228208e-9*(1.0 - cos(theta)**2)**2.5*(2.39077523201936e+30*cos(theta)**69 - 3.81548210497784e+31*cos(theta)**67 + 2.90897618417448e+32*cos(theta)**65 - 1.41041269535733e+33*cos(theta)**63 + 4.88392906743414e+33*cos(theta)**61 - 1.28598420048985e+34*cos(theta)**59 + 2.67678706452328e+34*cos(theta)**57 - 4.52079593119488e+34*cos(theta)**55 + 6.30956950923345e+34*cos(theta)**53 - 7.37454349764521e+34*cos(theta)**51 + 7.28879299185864e+34*cos(theta)**49 - 6.1357341148359e+34*cos(theta)**47 + 4.42181905209174e+34*cos(theta)**45 - 2.73771160823691e+34*cos(theta)**43 + 1.45935866720067e+34*cos(theta)**41 - 6.70405662243444e+33*cos(theta)**39 + 2.65368907971363e+33*cos(theta)**37 - 9.04018888536716e+32*cos(theta)**35 + 2.64449969852186e+32*cos(theta)**33 - 6.62065358378161e+31*cos(theta)**31 + 1.41220363140296e+31*cos(theta)**29 - 2.55164519069693e+30*cos(theta)**27 + 3.87717515989015e+29*cos(theta)**25 - 4.90988834093307e+28*cos(theta)**23 + 5.1245946792742e+27*cos(theta)**21 - 4.34814093999023e+26*cos(theta)**19 + 2.94818438040575e+25*cos(theta)**17 - 1.56316988590714e+24*cos(theta)**15 + 6.30310437865782e+22*cos(theta)**13 - 1.86298651585946e+21*cos(theta)**11 + 3.83761267311873e+19*cos(theta)**9 - 5.12250857368462e+17*cos(theta)**7 + 3.95487794291827e+15*cos(theta)**5 - 14439130861329.9*cos(theta)**3 + 15728900720.403*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl74_m_minus_4(theta, phi):
    return 1.58380020833984e-7*(1.0 - cos(theta)**2)**2*(3.41539318859909e+28*cos(theta)**70 - 5.61100309555565e+29*cos(theta)**68 + 4.40753967299164e+30*cos(theta)**66 - 2.20376983649582e+31*cos(theta)**64 + 7.87730494747442e+31*cos(theta)**62 - 2.14330700081642e+32*cos(theta)**60 + 4.61515011124704e+32*cos(theta)**58 - 8.07284987713371e+32*cos(theta)**56 + 1.1684387980062e+33*cos(theta)**54 - 1.41818144185485e+33*cos(theta)**52 + 1.45775859837173e+33*cos(theta)**50 - 1.27827794059081e+33*cos(theta)**48 + 9.61265011324291e+32*cos(theta)**46 - 6.22207183690207e+32*cos(theta)**44 + 3.47466349333492e+32*cos(theta)**42 - 1.67601415560861e+32*cos(theta)**40 + 6.98339231503588e+31*cos(theta)**38 - 2.51116357926866e+31*cos(theta)**36 + 7.77794028977017e+30*cos(theta)**34 - 2.06895424493175e+30*cos(theta)**32 + 4.70734543800986e+29*cos(theta)**30 - 9.11301853820333e+28*cos(theta)**28 + 1.49122121534236e+28*cos(theta)**26 - 2.04578680872211e+27*cos(theta)**24 + 2.32936121785191e+26*cos(theta)**22 - 2.17407046999511e+25*cos(theta)**20 + 1.63788021133653e+24*cos(theta)**18 - 9.76981178691963e+22*cos(theta)**16 + 4.50221741332702e+21*cos(theta)**14 - 1.55248876321621e+20*cos(theta)**12 + 3.83761267311873e+18*cos(theta)**10 - 6.40313571710578e+16*cos(theta)**8 + 659146323819712.0*cos(theta)**6 - 3609782715332.49*cos(theta)**4 + 7864450360.2015*cos(theta)**2 - 2844285.8445575)*sin(4*phi)

#@torch.jit.script
def Yl74_m_minus_3(theta, phi):
    return 1.17862831831977e-5*(1.0 - cos(theta)**2)**1.5*(4.81041294168886e+26*cos(theta)**71 - 8.13188854428354e+27*cos(theta)**69 + 6.57841742237558e+28*cos(theta)**67 - 3.39041513307049e+29*cos(theta)**65 + 1.25036586467848e+30*cos(theta)**63 - 3.51361803412528e+30*cos(theta)**61 + 7.82228832414753e+30*cos(theta)**59 - 1.41628945212872e+31*cos(theta)**57 + 2.12443417819308e+31*cos(theta)**55 - 2.67581404123556e+31*cos(theta)**53 + 2.85835019288574e+31*cos(theta)**51 - 2.60873049100166e+31*cos(theta)**49 + 2.0452447049453e+31*cos(theta)**47 - 1.38268263042268e+31*cos(theta)**45 + 8.0806127751975e+30*cos(theta)**43 - 4.08783940392344e+30*cos(theta)**41 + 1.79061341411176e+30*cos(theta)**39 - 6.78692859261799e+29*cos(theta)**37 + 2.22226865422005e+29*cos(theta)**35 - 6.26955831797501e+28*cos(theta)**33 + 1.51849852839028e+28*cos(theta)**31 - 3.14242018558736e+27*cos(theta)**29 + 5.52304153830505e+26*cos(theta)**27 - 8.18314723488844e+25*cos(theta)**25 + 1.01276574689213e+25*cos(theta)**23 - 1.03527165237863e+24*cos(theta)**21 + 8.62042216492908e+22*cos(theta)**19 - 5.74694810995272e+21*cos(theta)**17 + 3.00147827555134e+20*cos(theta)**15 - 1.19422212555093e+19*cos(theta)**13 + 3.4887387937443e+17*cos(theta)**11 - 7.11459524122864e+15*cos(theta)**9 + 94163760545673.2*cos(theta)**7 - 721956543066.498*cos(theta)**5 + 2621483453.4005*cos(theta)**3 - 2844285.8445575*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl74_m_minus_2(theta, phi):
    return 0.000877583566816282*(1.0 - cos(theta)**2)*(6.68112908567897e+24*cos(theta)**72 - 1.16169836346908e+26*cos(theta)**70 + 9.67414326819939e+26*cos(theta)**68 - 5.13699262586438e+27*cos(theta)**66 + 1.95369666356012e+28*cos(theta)**64 - 5.66712586149239e+28*cos(theta)**62 + 1.30371472069125e+29*cos(theta)**60 - 2.44187836573917e+29*cos(theta)**58 + 3.79363246105908e+29*cos(theta)**56 - 4.95521118747326e+29*cos(theta)**54 + 5.49682729401104e+29*cos(theta)**52 - 5.21746098200332e+29*cos(theta)**50 + 4.26092646863604e+29*cos(theta)**48 - 3.0058318052667e+29*cos(theta)**46 + 1.83650290345398e+29*cos(theta)**44 - 9.73295096172248e+28*cos(theta)**42 + 4.47653353527941e+28*cos(theta)**40 - 1.78603384016263e+28*cos(theta)**38 + 6.17296848394458e+27*cos(theta)**36 - 1.84398774058088e+27*cos(theta)**34 + 4.74530790121962e+26*cos(theta)**32 - 1.04747339519579e+26*cos(theta)**30 + 1.97251483510895e+25*cos(theta)**28 - 3.14736432111094e+24*cos(theta)**26 + 4.21985727871723e+23*cos(theta)**24 - 4.70578023808466e+22*cos(theta)**22 + 4.31021108246454e+21*cos(theta)**20 - 3.19274894997373e+20*cos(theta)**18 + 1.87592392221959e+19*cos(theta)**16 - 8.53015803964952e+17*cos(theta)**14 + 2.90728232812025e+16*cos(theta)**12 - 711459524122864.0*cos(theta)**10 + 11770470068209.1*cos(theta)**8 - 120326090511.083*cos(theta)**6 + 655370863.350125*cos(theta)**4 - 1422142.92227875*cos(theta)**2 + 513.038572250632)*sin(2*phi)

#@torch.jit.script
def Yl74_m_minus_1(theta, phi):
    return 0.0653667222836417*(1.0 - cos(theta)**2)**0.5*(9.15223162421776e+22*cos(theta)**73 - 1.63619487812546e+24*cos(theta)**71 + 1.4020497490144e+25*cos(theta)**69 - 7.66715317293192e+25*cos(theta)**67 + 3.00568717470788e+26*cos(theta)**65 - 8.99543787538475e+26*cos(theta)**63 + 2.13723724703484e+27*cos(theta)**61 - 4.13877689108335e+27*cos(theta)**59 + 6.65549554571768e+27*cos(theta)**57 - 9.00947488631502e+27*cos(theta)**55 + 1.0371372252851e+28*cos(theta)**53 - 1.02303156509869e+28*cos(theta)**51 + 8.69576830333886e+27*cos(theta)**49 - 6.39538681971639e+27*cos(theta)**47 + 4.08111756323106e+27*cos(theta)**45 - 2.26347696784244e+27*cos(theta)**43 + 1.09183744762912e+27*cos(theta)**41 - 4.57957394913494e+26*cos(theta)**39 + 1.66836986052556e+26*cos(theta)**37 - 5.26853640165967e+25*cos(theta)**35 + 1.43797209127867e+25*cos(theta)**33 - 3.37894643611544e+24*cos(theta)**31 + 6.80177529347913e+23*cos(theta)**29 - 1.16569048930035e+23*cos(theta)**27 + 1.68794291148689e+22*cos(theta)**25 - 2.0459914078629e+21*cos(theta)**23 + 2.05248146784026e+20*cos(theta)**21 - 1.6803941841967e+19*cos(theta)**19 + 1.10348466012917e+18*cos(theta)**17 - 5.68677202643301e+16*cos(theta)**15 + 2.23637102163096e+15*cos(theta)**13 - 64678138556624.0*cos(theta)**11 + 1307830007578.79*cos(theta)**9 - 17189441501.5833*cos(theta)**7 + 131074172.670025*cos(theta)**5 - 474047.640759584*cos(theta)**3 + 513.038572250632*cos(theta))*sin(phi)

#@torch.jit.script
def Yl74_m0(theta, phi):
    return 1.33792989509846e+22*cos(theta)**74 - 2.45833241269452e+23*cos(theta)**72 + 2.16672332649904e+24*cos(theta)**70 - 1.21972886561659e+25*cos(theta)**68 + 4.92649353878474e+25*cos(theta)**66 - 1.52047894110694e+26*cos(theta)**64 + 3.72905784096302e+26*cos(theta)**62 - 7.46206177487943e+26*cos(theta)**60 + 1.24133922382863e+27*cos(theta)**58 - 1.74040181254344e+27*cos(theta)**56 + 2.07768898551698e+27*cos(theta)**54 - 2.12825550341789e+27*cos(theta)**52 + 1.88137786502142e+27*cos(theta)**50 - 1.44133075963179e+27*cos(theta)**48 + 9.59752713615504e+26*cos(theta)**46 - 5.56495270919914e+26*cos(theta)**44 + 2.81220366608033e+26*cos(theta)**42 - 1.23852038695405e+26*cos(theta)**40 + 4.7494882095583e+25*cos(theta)**38 - 1.58316273651943e+25*cos(theta)**36 + 4.57519506425341e+24*cos(theta)**34 - 1.14227166490706e+24*cos(theta)**32 + 2.4526698952117e+23*cos(theta)**30 - 4.50363615203498e+22*cos(theta)**28 + 7.02299696975753e+21*cos(theta)**26 - 9.22211723301493e+20*cos(theta)**24 + 1.00924042676928e+20*cos(theta)**22 - 9.08906583172333e+18*cos(theta)**20 + 6.6318068664648e+17*cos(theta)**18 - 3.84488992258095e+16*cos(theta)**16 + 1.72804041464313e+15*cos(theta)**14 - 58306146730635.7*cos(theta)**12 + 1414781501552.19*cos(theta)**10 - 23243945808.634*cos(theta)**8 + 236321889.121914*cos(theta)**6 - 1282035.56485668*cos(theta)**4 + 2774.96875510103*cos(theta)**2 - 0.999988740576949

#@torch.jit.script
def Yl74_m1(theta, phi):
    return 0.0653667222836417*(1.0 - cos(theta)**2)**0.5*(9.15223162421776e+22*cos(theta)**73 - 1.63619487812546e+24*cos(theta)**71 + 1.4020497490144e+25*cos(theta)**69 - 7.66715317293192e+25*cos(theta)**67 + 3.00568717470788e+26*cos(theta)**65 - 8.99543787538475e+26*cos(theta)**63 + 2.13723724703484e+27*cos(theta)**61 - 4.13877689108335e+27*cos(theta)**59 + 6.65549554571768e+27*cos(theta)**57 - 9.00947488631502e+27*cos(theta)**55 + 1.0371372252851e+28*cos(theta)**53 - 1.02303156509869e+28*cos(theta)**51 + 8.69576830333886e+27*cos(theta)**49 - 6.39538681971639e+27*cos(theta)**47 + 4.08111756323106e+27*cos(theta)**45 - 2.26347696784244e+27*cos(theta)**43 + 1.09183744762912e+27*cos(theta)**41 - 4.57957394913494e+26*cos(theta)**39 + 1.66836986052556e+26*cos(theta)**37 - 5.26853640165967e+25*cos(theta)**35 + 1.43797209127867e+25*cos(theta)**33 - 3.37894643611544e+24*cos(theta)**31 + 6.80177529347913e+23*cos(theta)**29 - 1.16569048930035e+23*cos(theta)**27 + 1.68794291148689e+22*cos(theta)**25 - 2.0459914078629e+21*cos(theta)**23 + 2.05248146784026e+20*cos(theta)**21 - 1.6803941841967e+19*cos(theta)**19 + 1.10348466012917e+18*cos(theta)**17 - 5.68677202643301e+16*cos(theta)**15 + 2.23637102163096e+15*cos(theta)**13 - 64678138556624.0*cos(theta)**11 + 1307830007578.79*cos(theta)**9 - 17189441501.5833*cos(theta)**7 + 131074172.670025*cos(theta)**5 - 474047.640759584*cos(theta)**3 + 513.038572250632*cos(theta))*cos(phi)

#@torch.jit.script
def Yl74_m2(theta, phi):
    return 0.000877583566816282*(1.0 - cos(theta)**2)*(6.68112908567897e+24*cos(theta)**72 - 1.16169836346908e+26*cos(theta)**70 + 9.67414326819939e+26*cos(theta)**68 - 5.13699262586438e+27*cos(theta)**66 + 1.95369666356012e+28*cos(theta)**64 - 5.66712586149239e+28*cos(theta)**62 + 1.30371472069125e+29*cos(theta)**60 - 2.44187836573917e+29*cos(theta)**58 + 3.79363246105908e+29*cos(theta)**56 - 4.95521118747326e+29*cos(theta)**54 + 5.49682729401104e+29*cos(theta)**52 - 5.21746098200332e+29*cos(theta)**50 + 4.26092646863604e+29*cos(theta)**48 - 3.0058318052667e+29*cos(theta)**46 + 1.83650290345398e+29*cos(theta)**44 - 9.73295096172248e+28*cos(theta)**42 + 4.47653353527941e+28*cos(theta)**40 - 1.78603384016263e+28*cos(theta)**38 + 6.17296848394458e+27*cos(theta)**36 - 1.84398774058088e+27*cos(theta)**34 + 4.74530790121962e+26*cos(theta)**32 - 1.04747339519579e+26*cos(theta)**30 + 1.97251483510895e+25*cos(theta)**28 - 3.14736432111094e+24*cos(theta)**26 + 4.21985727871723e+23*cos(theta)**24 - 4.70578023808466e+22*cos(theta)**22 + 4.31021108246454e+21*cos(theta)**20 - 3.19274894997373e+20*cos(theta)**18 + 1.87592392221959e+19*cos(theta)**16 - 8.53015803964952e+17*cos(theta)**14 + 2.90728232812025e+16*cos(theta)**12 - 711459524122864.0*cos(theta)**10 + 11770470068209.1*cos(theta)**8 - 120326090511.083*cos(theta)**6 + 655370863.350125*cos(theta)**4 - 1422142.92227875*cos(theta)**2 + 513.038572250632)*cos(2*phi)

#@torch.jit.script
def Yl74_m3(theta, phi):
    return 1.17862831831977e-5*(1.0 - cos(theta)**2)**1.5*(4.81041294168886e+26*cos(theta)**71 - 8.13188854428354e+27*cos(theta)**69 + 6.57841742237558e+28*cos(theta)**67 - 3.39041513307049e+29*cos(theta)**65 + 1.25036586467848e+30*cos(theta)**63 - 3.51361803412528e+30*cos(theta)**61 + 7.82228832414753e+30*cos(theta)**59 - 1.41628945212872e+31*cos(theta)**57 + 2.12443417819308e+31*cos(theta)**55 - 2.67581404123556e+31*cos(theta)**53 + 2.85835019288574e+31*cos(theta)**51 - 2.60873049100166e+31*cos(theta)**49 + 2.0452447049453e+31*cos(theta)**47 - 1.38268263042268e+31*cos(theta)**45 + 8.0806127751975e+30*cos(theta)**43 - 4.08783940392344e+30*cos(theta)**41 + 1.79061341411176e+30*cos(theta)**39 - 6.78692859261799e+29*cos(theta)**37 + 2.22226865422005e+29*cos(theta)**35 - 6.26955831797501e+28*cos(theta)**33 + 1.51849852839028e+28*cos(theta)**31 - 3.14242018558736e+27*cos(theta)**29 + 5.52304153830505e+26*cos(theta)**27 - 8.18314723488844e+25*cos(theta)**25 + 1.01276574689213e+25*cos(theta)**23 - 1.03527165237863e+24*cos(theta)**21 + 8.62042216492908e+22*cos(theta)**19 - 5.74694810995272e+21*cos(theta)**17 + 3.00147827555134e+20*cos(theta)**15 - 1.19422212555093e+19*cos(theta)**13 + 3.4887387937443e+17*cos(theta)**11 - 7.11459524122864e+15*cos(theta)**9 + 94163760545673.2*cos(theta)**7 - 721956543066.498*cos(theta)**5 + 2621483453.4005*cos(theta)**3 - 2844285.8445575*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl74_m4(theta, phi):
    return 1.58380020833984e-7*(1.0 - cos(theta)**2)**2*(3.41539318859909e+28*cos(theta)**70 - 5.61100309555565e+29*cos(theta)**68 + 4.40753967299164e+30*cos(theta)**66 - 2.20376983649582e+31*cos(theta)**64 + 7.87730494747442e+31*cos(theta)**62 - 2.14330700081642e+32*cos(theta)**60 + 4.61515011124704e+32*cos(theta)**58 - 8.07284987713371e+32*cos(theta)**56 + 1.1684387980062e+33*cos(theta)**54 - 1.41818144185485e+33*cos(theta)**52 + 1.45775859837173e+33*cos(theta)**50 - 1.27827794059081e+33*cos(theta)**48 + 9.61265011324291e+32*cos(theta)**46 - 6.22207183690207e+32*cos(theta)**44 + 3.47466349333492e+32*cos(theta)**42 - 1.67601415560861e+32*cos(theta)**40 + 6.98339231503588e+31*cos(theta)**38 - 2.51116357926866e+31*cos(theta)**36 + 7.77794028977017e+30*cos(theta)**34 - 2.06895424493175e+30*cos(theta)**32 + 4.70734543800986e+29*cos(theta)**30 - 9.11301853820333e+28*cos(theta)**28 + 1.49122121534236e+28*cos(theta)**26 - 2.04578680872211e+27*cos(theta)**24 + 2.32936121785191e+26*cos(theta)**22 - 2.17407046999511e+25*cos(theta)**20 + 1.63788021133653e+24*cos(theta)**18 - 9.76981178691963e+22*cos(theta)**16 + 4.50221741332702e+21*cos(theta)**14 - 1.55248876321621e+20*cos(theta)**12 + 3.83761267311873e+18*cos(theta)**10 - 6.40313571710578e+16*cos(theta)**8 + 659146323819712.0*cos(theta)**6 - 3609782715332.49*cos(theta)**4 + 7864450360.2015*cos(theta)**2 - 2844285.8445575)*cos(4*phi)

#@torch.jit.script
def Yl74_m5(theta, phi):
    return 2.12979513228208e-9*(1.0 - cos(theta)**2)**2.5*(2.39077523201936e+30*cos(theta)**69 - 3.81548210497784e+31*cos(theta)**67 + 2.90897618417448e+32*cos(theta)**65 - 1.41041269535733e+33*cos(theta)**63 + 4.88392906743414e+33*cos(theta)**61 - 1.28598420048985e+34*cos(theta)**59 + 2.67678706452328e+34*cos(theta)**57 - 4.52079593119488e+34*cos(theta)**55 + 6.30956950923345e+34*cos(theta)**53 - 7.37454349764521e+34*cos(theta)**51 + 7.28879299185864e+34*cos(theta)**49 - 6.1357341148359e+34*cos(theta)**47 + 4.42181905209174e+34*cos(theta)**45 - 2.73771160823691e+34*cos(theta)**43 + 1.45935866720067e+34*cos(theta)**41 - 6.70405662243444e+33*cos(theta)**39 + 2.65368907971363e+33*cos(theta)**37 - 9.04018888536716e+32*cos(theta)**35 + 2.64449969852186e+32*cos(theta)**33 - 6.62065358378161e+31*cos(theta)**31 + 1.41220363140296e+31*cos(theta)**29 - 2.55164519069693e+30*cos(theta)**27 + 3.87717515989015e+29*cos(theta)**25 - 4.90988834093307e+28*cos(theta)**23 + 5.1245946792742e+27*cos(theta)**21 - 4.34814093999023e+26*cos(theta)**19 + 2.94818438040575e+25*cos(theta)**17 - 1.56316988590714e+24*cos(theta)**15 + 6.30310437865782e+22*cos(theta)**13 - 1.86298651585946e+21*cos(theta)**11 + 3.83761267311873e+19*cos(theta)**9 - 5.12250857368462e+17*cos(theta)**7 + 3.95487794291827e+15*cos(theta)**5 - 14439130861329.9*cos(theta)**3 + 15728900720.403*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl74_m6(theta, phi):
    return 2.86660788578062e-11*(1.0 - cos(theta)**2)**3*(1.64963491009336e+32*cos(theta)**68 - 2.55637301033515e+33*cos(theta)**66 + 1.89083451971341e+34*cos(theta)**64 - 8.88559998075115e+34*cos(theta)**62 + 2.97919673113483e+35*cos(theta)**60 - 7.58730678289014e+35*cos(theta)**58 + 1.52576862677827e+36*cos(theta)**56 - 2.48643776215718e+36*cos(theta)**54 + 3.34407183989373e+36*cos(theta)**52 - 3.76101718379906e+36*cos(theta)**50 + 3.57150856601073e+36*cos(theta)**48 - 2.88379503397287e+36*cos(theta)**46 + 1.98981857344128e+36*cos(theta)**44 - 1.17721599154187e+36*cos(theta)**42 + 5.98337053552274e+35*cos(theta)**40 - 2.61458208274943e+35*cos(theta)**38 + 9.81864959494044e+34*cos(theta)**36 - 3.16406610987851e+34*cos(theta)**34 + 8.72684900512213e+33*cos(theta)**32 - 2.0524026109723e+33*cos(theta)**30 + 4.09539053106858e+32*cos(theta)**28 - 6.88944201488172e+31*cos(theta)**26 + 9.69293789972536e+30*cos(theta)**24 - 1.12927431841461e+30*cos(theta)**22 + 1.07616488264758e+29*cos(theta)**20 - 8.26146778598144e+27*cos(theta)**18 + 5.01191344668977e+26*cos(theta)**16 - 2.34475482886071e+25*cos(theta)**14 + 8.19403569225517e+23*cos(theta)**12 - 2.0492851674454e+22*cos(theta)**10 + 3.45385140580686e+20*cos(theta)**8 - 3.58575600157923e+18*cos(theta)**6 + 1.97743897145914e+16*cos(theta)**4 - 43317392583989.9*cos(theta)**2 + 15728900720.403)*cos(6*phi)

#@torch.jit.script
def Yl74_m7(theta, phi):
    return 3.86252519617713e-13*(1.0 - cos(theta)**2)**3.5*(1.12175173886348e+34*cos(theta)**67 - 1.6872061868212e+35*cos(theta)**65 + 1.21013409261659e+36*cos(theta)**63 - 5.50907198806571e+36*cos(theta)**61 + 1.7875180386809e+37*cos(theta)**59 - 4.40063793407628e+37*cos(theta)**57 + 8.54430430995832e+37*cos(theta)**55 - 1.34267639156488e+38*cos(theta)**53 + 1.73891735674474e+38*cos(theta)**51 - 1.88050859189953e+38*cos(theta)**49 + 1.71432411168515e+38*cos(theta)**47 - 1.32654571562752e+38*cos(theta)**45 + 8.75520172314165e+37*cos(theta)**43 - 4.94430716447586e+37*cos(theta)**41 + 2.3933482142091e+37*cos(theta)**39 - 9.93541191444784e+36*cos(theta)**37 + 3.53471385417856e+36*cos(theta)**35 - 1.07578247735869e+36*cos(theta)**33 + 2.79259168163908e+35*cos(theta)**31 - 6.1572078329169e+34*cos(theta)**29 + 1.1467093486992e+34*cos(theta)**27 - 1.79125492386925e+33*cos(theta)**25 + 2.32630509593409e+32*cos(theta)**23 - 2.48440350051213e+31*cos(theta)**21 + 2.15232976529516e+30*cos(theta)**19 - 1.48706420147666e+29*cos(theta)**17 + 8.01906151470363e+27*cos(theta)**15 - 3.28265676040499e+26*cos(theta)**13 + 9.83284283070621e+24*cos(theta)**11 - 2.0492851674454e+23*cos(theta)**9 + 2.76308112464548e+21*cos(theta)**7 - 2.15145360094754e+19*cos(theta)**5 + 7.90975588583655e+16*cos(theta)**3 - 86634785167979.7*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl74_m8(theta, phi):
    return 5.21107109008342e-15*(1.0 - cos(theta)**2)**4*(7.51573665038535e+35*cos(theta)**66 - 1.09668402143378e+37*cos(theta)**64 + 7.62384478348449e+37*cos(theta)**62 - 3.36053391272008e+38*cos(theta)**60 + 1.05463564282173e+39*cos(theta)**58 - 2.50836362242348e+39*cos(theta)**56 + 4.69936737047708e+39*cos(theta)**54 - 7.11618487529386e+39*cos(theta)**52 + 8.86847851939817e+39*cos(theta)**50 - 9.21449210030769e+39*cos(theta)**48 + 8.05732332492021e+39*cos(theta)**46 - 5.96945572032385e+39*cos(theta)**44 + 3.76473674095091e+39*cos(theta)**42 - 2.0271659374351e+39*cos(theta)**40 + 9.33405803541547e+38*cos(theta)**38 - 3.6761024083457e+38*cos(theta)**36 + 1.2371498489625e+38*cos(theta)**34 - 3.55008217528368e+37*cos(theta)**32 + 8.65703421308116e+36*cos(theta)**30 - 1.7855902715459e+36*cos(theta)**28 + 3.09611524148784e+35*cos(theta)**26 - 4.47813730967312e+34*cos(theta)**24 + 5.3505017206484e+33*cos(theta)**22 - 5.21724735107548e+32*cos(theta)**20 + 4.08942655406081e+31*cos(theta)**18 - 2.52800914251032e+30*cos(theta)**16 + 1.20285922720554e+29*cos(theta)**14 - 4.26745378852649e+27*cos(theta)**12 + 1.08161271137768e+26*cos(theta)**10 - 1.84435665070086e+24*cos(theta)**8 + 1.93415678725184e+22*cos(theta)**6 - 1.07572680047377e+20*cos(theta)**4 + 2.37292676575096e+17*cos(theta)**2 - 86634785167979.7)*cos(8*phi)

#@torch.jit.script
def Yl74_m9(theta, phi):
    return 7.04070233875644e-17*(1.0 - cos(theta)**2)**4.5*(4.96038618925433e+37*cos(theta)**65 - 7.01877773717619e+38*cos(theta)**63 + 4.72678376576038e+39*cos(theta)**61 - 2.01632034763205e+40*cos(theta)**59 + 6.11688672836603e+40*cos(theta)**57 - 1.40468362855715e+41*cos(theta)**55 + 2.53765838005762e+41*cos(theta)**53 - 3.70041613515281e+41*cos(theta)**51 + 4.43423925969909e+41*cos(theta)**49 - 4.42295620814769e+41*cos(theta)**47 + 3.7063687294633e+41*cos(theta)**45 - 2.62656051694249e+41*cos(theta)**43 + 1.58118943119938e+41*cos(theta)**41 - 8.10866374974042e+40*cos(theta)**39 + 3.54694205345788e+40*cos(theta)**37 - 1.32339686700445e+40*cos(theta)**35 + 4.20630948647249e+39*cos(theta)**33 - 1.13602629609078e+39*cos(theta)**31 + 2.59711026392435e+38*cos(theta)**29 - 4.99965276032852e+37*cos(theta)**27 + 8.0498996278684e+36*cos(theta)**25 - 1.07475295432155e+36*cos(theta)**23 + 1.17711037854265e+35*cos(theta)**21 - 1.0434494702151e+34*cos(theta)**19 + 7.36096779730946e+32*cos(theta)**17 - 4.04481462801651e+31*cos(theta)**15 + 1.68400291808776e+30*cos(theta)**13 - 5.12094454623179e+28*cos(theta)**11 + 1.08161271137768e+27*cos(theta)**9 - 1.47548532056069e+25*cos(theta)**7 + 1.1604940723511e+23*cos(theta)**5 - 4.30290720189508e+20*cos(theta)**3 + 4.74585353150193e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl74_m10(theta, phi):
    return 9.52839302655195e-19*(1.0 - cos(theta)**2)**5*(3.22425102301531e+39*cos(theta)**64 - 4.421829974421e+40*cos(theta)**62 + 2.88333809711383e+41*cos(theta)**60 - 1.18962900510291e+42*cos(theta)**58 + 3.48662543516864e+42*cos(theta)**56 - 7.72575995706431e+42*cos(theta)**54 + 1.34495894143054e+43*cos(theta)**52 - 1.88721222892793e+43*cos(theta)**50 + 2.17277723725255e+43*cos(theta)**48 - 2.07878941782941e+43*cos(theta)**46 + 1.66786592825848e+43*cos(theta)**44 - 1.12942102228527e+43*cos(theta)**42 + 6.48287666791746e+42*cos(theta)**40 - 3.16237886239876e+42*cos(theta)**38 + 1.31236855977942e+42*cos(theta)**36 - 4.63188903451558e+41*cos(theta)**34 + 1.38808213053592e+41*cos(theta)**32 - 3.52168151788141e+40*cos(theta)**30 + 7.53161976538061e+39*cos(theta)**28 - 1.3499062452887e+39*cos(theta)**26 + 2.0124749069671e+38*cos(theta)**24 - 2.47193179493956e+37*cos(theta)**22 + 2.47193179493956e+36*cos(theta)**20 - 1.98255399340868e+35*cos(theta)**18 + 1.25136452554261e+34*cos(theta)**16 - 6.06722194202477e+32*cos(theta)**14 + 2.18920379351409e+31*cos(theta)**12 - 5.63303900085497e+29*cos(theta)**10 + 9.73451440239914e+27*cos(theta)**8 - 1.03283972439248e+26*cos(theta)**6 + 5.80247036175552e+23*cos(theta)**4 - 1.29087216056852e+21*cos(theta)**2 + 4.74585353150193e+17)*cos(10*phi)

#@torch.jit.script
def Yl74_m11(theta, phi):
    return 1.29187416345375e-20*(1.0 - cos(theta)**2)**5.5*(2.0635206547298e+41*cos(theta)**63 - 2.74153458414102e+42*cos(theta)**61 + 1.7300028582683e+43*cos(theta)**59 - 6.89984822959688e+43*cos(theta)**57 + 1.95251024369444e+44*cos(theta)**55 - 4.17191037681473e+44*cos(theta)**53 + 6.9937864954388e+44*cos(theta)**51 - 9.43606114463966e+44*cos(theta)**49 + 1.04293307388123e+45*cos(theta)**47 - 9.5624313220153e+44*cos(theta)**45 + 7.33861008433733e+44*cos(theta)**43 - 4.74356829359814e+44*cos(theta)**41 + 2.59315066716698e+44*cos(theta)**39 - 1.20170396771153e+44*cos(theta)**37 + 4.7245268152059e+43*cos(theta)**35 - 1.5748422717353e+43*cos(theta)**33 + 4.44186281771494e+42*cos(theta)**31 - 1.05650445536442e+42*cos(theta)**29 + 2.10885353430657e+41*cos(theta)**27 - 3.50975623775062e+40*cos(theta)**25 + 4.82993977672104e+39*cos(theta)**23 - 5.43824994886703e+38*cos(theta)**21 + 4.94386358987912e+37*cos(theta)**19 - 3.56859718813563e+36*cos(theta)**17 + 2.00218324086817e+35*cos(theta)**15 - 8.49411071883467e+33*cos(theta)**13 + 2.62704455221691e+32*cos(theta)**11 - 5.63303900085497e+30*cos(theta)**9 + 7.78761152191932e+28*cos(theta)**7 - 6.19703834635489e+26*cos(theta)**5 + 2.32098814470221e+24*cos(theta)**3 - 2.58174432113705e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl74_m12(theta, phi):
    return 1.75509533709773e-22*(1.0 - cos(theta)**2)**6*(1.30001801247977e+43*cos(theta)**62 - 1.67233609632602e+44*cos(theta)**60 + 1.0207016863783e+45*cos(theta)**58 - 3.93291349087022e+45*cos(theta)**56 + 1.07388063403194e+46*cos(theta)**54 - 2.21111249971181e+46*cos(theta)**52 + 3.56683111267379e+46*cos(theta)**50 - 4.62366996087343e+46*cos(theta)**48 + 4.90178544724176e+46*cos(theta)**46 - 4.30309409490689e+46*cos(theta)**44 + 3.15560233626505e+46*cos(theta)**42 - 1.94486300037524e+46*cos(theta)**40 + 1.01132876019512e+46*cos(theta)**38 - 4.44630468053266e+45*cos(theta)**36 + 1.65358438532206e+45*cos(theta)**34 - 5.19697949672649e+44*cos(theta)**32 + 1.37697747349163e+44*cos(theta)**30 - 3.06386292055683e+43*cos(theta)**28 + 5.69390454262774e+42*cos(theta)**26 - 8.77439059437655e+41*cos(theta)**24 + 1.11088614864584e+41*cos(theta)**22 - 1.14203248926208e+40*cos(theta)**20 + 9.39334082077033e+38*cos(theta)**18 - 6.06661521983056e+37*cos(theta)**16 + 3.00327486130226e+36*cos(theta)**14 - 1.10423439344851e+35*cos(theta)**12 + 2.8897490074386e+33*cos(theta)**10 - 5.06973510076947e+31*cos(theta)**8 + 5.45132806534352e+29*cos(theta)**6 - 3.09851917317745e+27*cos(theta)**4 + 6.96296443410662e+24*cos(theta)**2 - 2.58174432113705e+21)*cos(12*phi)

#@torch.jit.script
def Yl74_m13(theta, phi):
    return 2.38971022234848e-24*(1.0 - cos(theta)**2)**6.5*(8.0601116773746e+44*cos(theta)**61 - 1.00340165779561e+46*cos(theta)**59 + 5.92006978099412e+46*cos(theta)**57 - 2.20243155488732e+47*cos(theta)**55 + 5.79895542377247e+47*cos(theta)**53 - 1.14977849985014e+48*cos(theta)**51 + 1.7834155563369e+48*cos(theta)**49 - 2.21936158121925e+48*cos(theta)**47 + 2.25482130573121e+48*cos(theta)**45 - 1.89336140175903e+48*cos(theta)**43 + 1.32535298123132e+48*cos(theta)**41 - 7.77945200150096e+47*cos(theta)**39 + 3.84304928874147e+47*cos(theta)**37 - 1.60066968499176e+47*cos(theta)**35 + 5.62218691009502e+46*cos(theta)**33 - 1.66303343895248e+46*cos(theta)**31 + 4.1309324204749e+45*cos(theta)**29 - 8.57881617755912e+44*cos(theta)**27 + 1.48041518108321e+44*cos(theta)**25 - 2.10585374265037e+43*cos(theta)**23 + 2.44394952702085e+42*cos(theta)**21 - 2.28406497852415e+41*cos(theta)**19 + 1.69080134773866e+40*cos(theta)**17 - 9.7065843517289e+38*cos(theta)**15 + 4.20458480582316e+37*cos(theta)**13 - 1.32508127213821e+36*cos(theta)**11 + 2.8897490074386e+34*cos(theta)**9 - 4.05578808061558e+32*cos(theta)**7 + 3.27079683920611e+30*cos(theta)**5 - 1.23940766927098e+28*cos(theta)**3 + 1.39259288682132e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl74_m14(theta, phi):
    return 3.26166225427279e-26*(1.0 - cos(theta)**2)**7*(4.91666812319851e+46*cos(theta)**60 - 5.92006978099412e+47*cos(theta)**58 + 3.37443977516665e+48*cos(theta)**56 - 1.21133735518803e+49*cos(theta)**54 + 3.07344637459941e+49*cos(theta)**52 - 5.86387034923571e+49*cos(theta)**50 + 8.73873622605079e+49*cos(theta)**48 - 1.04309994317305e+50*cos(theta)**46 + 1.01466958757904e+50*cos(theta)**44 - 8.14145402756383e+49*cos(theta)**42 + 5.43394722304842e+49*cos(theta)**40 - 3.03398628058537e+49*cos(theta)**38 + 1.42192823683434e+49*cos(theta)**36 - 5.60234389747115e+48*cos(theta)**34 + 1.85532168033136e+48*cos(theta)**32 - 5.15540366075267e+47*cos(theta)**30 + 1.19797040193772e+47*cos(theta)**28 - 2.31628036794096e+46*cos(theta)**26 + 3.70103795270803e+45*cos(theta)**24 - 4.84346360809586e+44*cos(theta)**22 + 5.13229400674377e+43*cos(theta)**20 - 4.33972345919589e+42*cos(theta)**18 + 2.87436229115572e+41*cos(theta)**16 - 1.45598765275934e+40*cos(theta)**14 + 5.46596024757011e+38*cos(theta)**12 - 1.45758939935203e+37*cos(theta)**10 + 2.60077410669474e+35*cos(theta)**8 - 2.83905165643091e+33*cos(theta)**6 + 1.63539841960306e+31*cos(theta)**4 - 3.71822300781294e+28*cos(theta)**2 + 1.39259288682132e+25)*cos(14*phi)

#@torch.jit.script
def Yl74_m15(theta, phi):
    return 4.46342620890884e-28*(1.0 - cos(theta)**2)**7.5*(2.9500008739191e+48*cos(theta)**59 - 3.43364047297659e+49*cos(theta)**57 + 1.88968627409332e+50*cos(theta)**55 - 6.54122171801535e+50*cos(theta)**53 + 1.59819211479169e+51*cos(theta)**51 - 2.93193517461786e+51*cos(theta)**49 + 4.19459338850438e+51*cos(theta)**47 - 4.79825973859601e+51*cos(theta)**45 + 4.46454618534779e+51*cos(theta)**43 - 3.41941069157681e+51*cos(theta)**41 + 2.17357888921937e+51*cos(theta)**39 - 1.15291478662244e+51*cos(theta)**37 + 5.11894165260364e+50*cos(theta)**35 - 1.90479692514019e+50*cos(theta)**33 + 5.93702937706034e+49*cos(theta)**31 - 1.5466210982258e+49*cos(theta)**29 + 3.35431712542562e+48*cos(theta)**27 - 6.02232895664651e+47*cos(theta)**25 + 8.88249108649927e+46*cos(theta)**23 - 1.06556199378109e+46*cos(theta)**21 + 1.02645880134875e+45*cos(theta)**19 - 7.81150222655261e+43*cos(theta)**17 + 4.59897966584915e+42*cos(theta)**15 - 2.03838271386307e+41*cos(theta)**13 + 6.55915229708413e+39*cos(theta)**11 - 1.45758939935203e+38*cos(theta)**9 + 2.08061928535579e+36*cos(theta)**7 - 1.70343099385854e+34*cos(theta)**5 + 6.54159367841222e+31*cos(theta)**3 - 7.43644601562587e+28*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl74_m16(theta, phi):
    return 6.12521163358953e-30*(1.0 - cos(theta)**2)**8*(1.74050051561227e+50*cos(theta)**58 - 1.95717506959666e+51*cos(theta)**56 + 1.03932745075133e+52*cos(theta)**54 - 3.46684751054814e+52*cos(theta)**52 + 8.15077978543764e+52*cos(theta)**50 - 1.43664823556275e+53*cos(theta)**48 + 1.97145889259706e+53*cos(theta)**46 - 2.15921688236821e+53*cos(theta)**44 + 1.91975485969955e+53*cos(theta)**42 - 1.40195838354649e+53*cos(theta)**40 + 8.47695766795553e+52*cos(theta)**38 - 4.26578471050303e+52*cos(theta)**36 + 1.79162957841127e+52*cos(theta)**34 - 6.28582985296263e+51*cos(theta)**32 + 1.8404791068887e+51*cos(theta)**30 - 4.48520118485483e+50*cos(theta)**28 + 9.05665623864917e+49*cos(theta)**26 - 1.50558223916163e+49*cos(theta)**24 + 2.04297294989483e+48*cos(theta)**22 - 2.23768018694029e+47*cos(theta)**20 + 1.95027172256263e+46*cos(theta)**18 - 1.32795537851394e+45*cos(theta)**16 + 6.89846949877373e+43*cos(theta)**14 - 2.64989752802199e+42*cos(theta)**12 + 7.21506752679255e+40*cos(theta)**10 - 1.31183045941683e+39*cos(theta)**8 + 1.45643349974905e+37*cos(theta)**6 - 8.51715496929272e+34*cos(theta)**4 + 1.96247810352367e+32*cos(theta)**2 - 7.43644601562587e+28)*cos(16*phi)

#@torch.jit.script
def Yl74_m17(theta, phi):
    return 8.43114203633594e-32*(1.0 - cos(theta)**2)**8.5*(1.00949029905512e+52*cos(theta)**57 - 1.09601803897413e+53*cos(theta)**55 + 5.61236823405717e+53*cos(theta)**53 - 1.80276070548503e+54*cos(theta)**51 + 4.07538989271882e+54*cos(theta)**49 - 6.8959115307012e+54*cos(theta)**47 + 9.06871090594646e+54*cos(theta)**45 - 9.5005542824201e+54*cos(theta)**43 + 8.06297041073812e+54*cos(theta)**41 - 5.60783353418597e+54*cos(theta)**39 + 3.2212439138231e+54*cos(theta)**37 - 1.53568249578109e+54*cos(theta)**35 + 6.09154056659833e+53*cos(theta)**33 - 2.01146555294804e+53*cos(theta)**31 + 5.52143732066611e+52*cos(theta)**29 - 1.25585633175935e+52*cos(theta)**27 + 2.35473062204878e+51*cos(theta)**25 - 3.6133973739879e+50*cos(theta)**23 + 4.49454048976863e+49*cos(theta)**21 - 4.47536037388057e+48*cos(theta)**19 + 3.51048910061274e+47*cos(theta)**17 - 2.12472860562231e+46*cos(theta)**15 + 9.65785729828322e+44*cos(theta)**13 - 3.17987703362639e+43*cos(theta)**11 + 7.21506752679255e+41*cos(theta)**9 - 1.04946436753346e+40*cos(theta)**7 + 8.73860099849433e+37*cos(theta)**5 - 3.40686198771709e+35*cos(theta)**3 + 3.92495620704733e+32*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl74_m18(theta, phi):
    return 1.16427363845596e-33*(1.0 - cos(theta)**2)**9*(5.75409470461417e+53*cos(theta)**56 - 6.0280992143577e+54*cos(theta)**54 + 2.9745551640503e+55*cos(theta)**52 - 9.19407959797366e+55*cos(theta)**50 + 1.99694104743222e+56*cos(theta)**48 - 3.24107841942956e+56*cos(theta)**46 + 4.08091990767591e+56*cos(theta)**44 - 4.08523834144064e+56*cos(theta)**42 + 3.30581786840263e+56*cos(theta)**40 - 2.18705507833253e+56*cos(theta)**38 + 1.19186024811455e+56*cos(theta)**36 - 5.37488873523382e+55*cos(theta)**34 + 2.01020838697745e+55*cos(theta)**32 - 6.23554321413893e+54*cos(theta)**30 + 1.60121682299317e+54*cos(theta)**28 - 3.39081209575025e+53*cos(theta)**26 + 5.88682655512196e+52*cos(theta)**24 - 8.31081396017218e+51*cos(theta)**22 + 9.43853502851413e+50*cos(theta)**20 - 8.50318471037309e+49*cos(theta)**18 + 5.96783147104166e+48*cos(theta)**16 - 3.18709290843346e+47*cos(theta)**14 + 1.25552144877682e+46*cos(theta)**12 - 3.49786473698903e+44*cos(theta)**10 + 6.49356077411329e+42*cos(theta)**8 - 7.34625057273423e+40*cos(theta)**6 + 4.36930049924716e+38*cos(theta)**4 - 1.02205859631513e+36*cos(theta)**2 + 3.92495620704733e+32)*cos(18*phi)

#@torch.jit.script
def Yl74_m19(theta, phi):
    return 1.6133165035292e-35*(1.0 - cos(theta)**2)**9.5*(3.22229303458393e+55*cos(theta)**55 - 3.25517357575316e+56*cos(theta)**53 + 1.54676868530616e+57*cos(theta)**51 - 4.59703979898683e+57*cos(theta)**49 + 9.58531702767466e+57*cos(theta)**47 - 1.4908960729376e+58*cos(theta)**45 + 1.7956047593774e+58*cos(theta)**43 - 1.71580010340507e+58*cos(theta)**41 + 1.32232714736105e+58*cos(theta)**39 - 8.3108092976636e+57*cos(theta)**37 + 4.29069689321237e+57*cos(theta)**35 - 1.8274621699795e+57*cos(theta)**33 + 6.43266683832784e+56*cos(theta)**31 - 1.87066296424168e+56*cos(theta)**29 + 4.48340710438088e+55*cos(theta)**27 - 8.81611144895065e+54*cos(theta)**25 + 1.41283837322927e+54*cos(theta)**23 - 1.82837907123788e+53*cos(theta)**21 + 1.88770700570283e+52*cos(theta)**19 - 1.53057324786716e+51*cos(theta)**17 + 9.54853035366666e+49*cos(theta)**15 - 4.46193007180685e+48*cos(theta)**13 + 1.50662573853218e+47*cos(theta)**11 - 3.49786473698903e+45*cos(theta)**9 + 5.19484861929063e+43*cos(theta)**7 - 4.40775034364054e+41*cos(theta)**5 + 1.74772019969887e+39*cos(theta)**3 - 2.04411719263025e+36*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl74_m20(theta, phi):
    return 2.24374916822329e-37*(1.0 - cos(theta)**2)**10*(1.77226116902116e+57*cos(theta)**54 - 1.72524199514917e+58*cos(theta)**52 + 7.8885202950614e+58*cos(theta)**50 - 2.25254950150355e+59*cos(theta)**48 + 4.50509900300709e+59*cos(theta)**46 - 6.70903232821919e+59*cos(theta)**44 + 7.72110046532282e+59*cos(theta)**42 - 7.03478042396079e+59*cos(theta)**40 + 5.1570758747081e+59*cos(theta)**38 - 3.07499944013553e+59*cos(theta)**36 + 1.50174391262433e+59*cos(theta)**34 - 6.03062516093235e+58*cos(theta)**32 + 1.99412671988163e+58*cos(theta)**30 - 5.42492259630087e+57*cos(theta)**28 + 1.21051991818284e+57*cos(theta)**26 - 2.20402786223766e+56*cos(theta)**24 + 3.24952825842732e+55*cos(theta)**22 - 3.83959604959955e+54*cos(theta)**20 + 3.58664331083537e+53*cos(theta)**18 - 2.60197452137416e+52*cos(theta)**16 + 1.43227955305e+51*cos(theta)**14 - 5.8005090933489e+49*cos(theta)**12 + 1.6572883123854e+48*cos(theta)**10 - 3.14807826329012e+46*cos(theta)**8 + 3.63639403350344e+44*cos(theta)**6 - 2.20387517182027e+42*cos(theta)**4 + 5.2431605990966e+39*cos(theta)**2 - 2.04411719263025e+36)*cos(20*phi)

#@torch.jit.script
def Yl74_m21(theta, phi):
    return 3.13267702778855e-39*(1.0 - cos(theta)**2)**10.5*(9.57021031271429e+58*cos(theta)**53 - 8.97125837477571e+59*cos(theta)**51 + 3.9442601475307e+60*cos(theta)**49 - 1.0812237607217e+61*cos(theta)**47 + 2.07234554138326e+61*cos(theta)**45 - 2.95197422441645e+61*cos(theta)**43 + 3.24286219543558e+61*cos(theta)**41 - 2.81391216958432e+61*cos(theta)**39 + 1.95968883238908e+61*cos(theta)**37 - 1.10699979844879e+61*cos(theta)**35 + 5.10592930292272e+60*cos(theta)**33 - 1.92980005149835e+60*cos(theta)**31 + 5.98238015964489e+59*cos(theta)**29 - 1.51897832696424e+59*cos(theta)**27 + 3.14735178727538e+58*cos(theta)**25 - 5.28966686937039e+57*cos(theta)**23 + 7.14896216854011e+56*cos(theta)**21 - 7.67919209919909e+55*cos(theta)**19 + 6.45595795950366e+54*cos(theta)**17 - 4.16315923419866e+53*cos(theta)**15 + 2.00519137427e+52*cos(theta)**13 - 6.96061091201868e+50*cos(theta)**11 + 1.6572883123854e+49*cos(theta)**9 - 2.5184626106321e+47*cos(theta)**7 + 2.18183642010207e+45*cos(theta)**5 - 8.81550068728108e+42*cos(theta)**3 + 1.04863211981932e+40*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl74_m22(theta, phi):
    return 4.39179511236912e-41*(1.0 - cos(theta)**2)**11*(5.07221146573857e+60*cos(theta)**52 - 4.57534177113561e+61*cos(theta)**50 + 1.93268747229004e+62*cos(theta)**48 - 5.081751675392e+62*cos(theta)**46 + 9.32555493622468e+62*cos(theta)**44 - 1.26934891649907e+63*cos(theta)**42 + 1.32957350012859e+63*cos(theta)**40 - 1.09742574613788e+63*cos(theta)**38 + 7.25084867983959e+62*cos(theta)**36 - 3.87449929457077e+62*cos(theta)**34 + 1.6849566699645e+62*cos(theta)**32 - 5.98238015964489e+61*cos(theta)**30 + 1.73489024629702e+61*cos(theta)**28 - 4.10124148280346e+60*cos(theta)**26 + 7.86837946818845e+59*cos(theta)**24 - 1.21662337995519e+59*cos(theta)**22 + 1.50128205539342e+58*cos(theta)**20 - 1.45904649884783e+57*cos(theta)**18 + 1.09751285311562e+56*cos(theta)**16 - 6.24473885129799e+54*cos(theta)**14 + 2.606748786551e+53*cos(theta)**12 - 7.65667200322055e+51*cos(theta)**10 + 1.49155948114686e+50*cos(theta)**8 - 1.76292382744247e+48*cos(theta)**6 + 1.09091821005103e+46*cos(theta)**4 - 2.64465020618432e+43*cos(theta)**2 + 1.04863211981932e+40)*cos(22*phi)

#@torch.jit.script
def Yl74_m23(theta, phi):
    return 6.18378714475877e-43*(1.0 - cos(theta)**2)**11.5*(2.63754996218406e+62*cos(theta)**51 - 2.28767088556781e+63*cos(theta)**49 + 9.2768998669922e+63*cos(theta)**47 - 2.33760577068032e+64*cos(theta)**45 + 4.10324417193886e+64*cos(theta)**43 - 5.3312654492961e+64*cos(theta)**41 + 5.31829400051436e+64*cos(theta)**39 - 4.17021783532396e+64*cos(theta)**37 + 2.61030552474225e+64*cos(theta)**35 - 1.31732976015406e+64*cos(theta)**33 + 5.39186134388639e+63*cos(theta)**31 - 1.79471404789347e+63*cos(theta)**29 + 4.85769268963165e+62*cos(theta)**27 - 1.0663227855289e+62*cos(theta)**25 + 1.88841107236523e+61*cos(theta)**23 - 2.67657143590142e+60*cos(theta)**21 + 3.00256411078684e+59*cos(theta)**19 - 2.62628369792609e+58*cos(theta)**17 + 1.756020564985e+57*cos(theta)**15 - 8.74263439181719e+55*cos(theta)**13 + 3.1280985438612e+54*cos(theta)**11 - 7.65667200322055e+52*cos(theta)**9 + 1.19324758491749e+51*cos(theta)**7 - 1.05775429646548e+49*cos(theta)**5 + 4.36367284020413e+46*cos(theta)**3 - 5.28930041236865e+43*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl74_m24(theta, phi):
    return 8.74694521096234e-45*(1.0 - cos(theta)**2)**12*(1.34515048071387e+64*cos(theta)**50 - 1.12095873392822e+65*cos(theta)**48 + 4.36014293748634e+65*cos(theta)**46 - 1.05192259680614e+66*cos(theta)**44 + 1.76439499393371e+66*cos(theta)**42 - 2.1858188342114e+66*cos(theta)**40 + 2.0741346602006e+66*cos(theta)**38 - 1.54298059906986e+66*cos(theta)**36 + 9.13606933659788e+65*cos(theta)**34 - 4.34718820850841e+65*cos(theta)**32 + 1.67147701660478e+65*cos(theta)**30 - 5.20467073889105e+64*cos(theta)**28 + 1.31157702620055e+64*cos(theta)**26 - 2.66580696382225e+63*cos(theta)**24 + 4.34334546644003e+62*cos(theta)**22 - 5.62080001539297e+61*cos(theta)**20 + 5.70487181049501e+60*cos(theta)**18 - 4.46468228647435e+59*cos(theta)**16 + 2.63403084747749e+58*cos(theta)**14 - 1.13654247093623e+57*cos(theta)**12 + 3.44090839824732e+55*cos(theta)**10 - 6.8910048028985e+53*cos(theta)**8 + 8.35273309442242e+51*cos(theta)**6 - 5.28877148232741e+49*cos(theta)**4 + 1.30910185206124e+47*cos(theta)**2 - 5.28930041236865e+43)*cos(24*phi)

#@torch.jit.script
def Yl74_m25(theta, phi):
    return 1.2432366566003e-46*(1.0 - cos(theta)**2)**12.5*(6.72575240356935e+65*cos(theta)**49 - 5.38060192285548e+66*cos(theta)**47 + 2.00566575124371e+67*cos(theta)**45 - 4.62845942594703e+67*cos(theta)**43 + 7.41045897452158e+67*cos(theta)**41 - 8.7432753368456e+67*cos(theta)**39 + 7.88171170876228e+67*cos(theta)**37 - 5.55473015665151e+67*cos(theta)**35 + 3.10626357444328e+67*cos(theta)**33 - 1.39110022672269e+67*cos(theta)**31 + 5.01443104981435e+66*cos(theta)**29 - 1.4573078068895e+66*cos(theta)**27 + 3.41010026812142e+65*cos(theta)**25 - 6.39793671317339e+64*cos(theta)**23 + 9.55536002616806e+63*cos(theta)**21 - 1.12416000307859e+63*cos(theta)**19 + 1.0268769258891e+62*cos(theta)**17 - 7.14349165835896e+60*cos(theta)**15 + 3.68764318646849e+59*cos(theta)**13 - 1.36385096512348e+58*cos(theta)**11 + 3.44090839824732e+56*cos(theta)**9 - 5.5128038423188e+54*cos(theta)**7 + 5.01163985665345e+52*cos(theta)**5 - 2.11550859293096e+50*cos(theta)**3 + 2.61820370412248e+47*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl74_m26(theta, phi):
    return 1.77605236657185e-48*(1.0 - cos(theta)**2)**13*(3.29561867774898e+67*cos(theta)**48 - 2.52888290374207e+68*cos(theta)**46 + 9.02549588059671e+68*cos(theta)**44 - 1.99023755315722e+69*cos(theta)**42 + 3.03828817955385e+69*cos(theta)**40 - 3.40987738136979e+69*cos(theta)**38 + 2.91623333224204e+69*cos(theta)**36 - 1.94415555482803e+69*cos(theta)**34 + 1.02506697956628e+69*cos(theta)**32 - 4.31241070284034e+68*cos(theta)**30 + 1.45418500444616e+68*cos(theta)**28 - 3.93473107860164e+67*cos(theta)**26 + 8.52525067030355e+66*cos(theta)**24 - 1.47152544402988e+66*cos(theta)**22 + 2.00662560549529e+65*cos(theta)**20 - 2.13590400584933e+64*cos(theta)**18 + 1.74569077401147e+63*cos(theta)**16 - 1.07152374875384e+62*cos(theta)**14 + 4.79393614240904e+60*cos(theta)**12 - 1.50023606163583e+59*cos(theta)**10 + 3.09681755842258e+57*cos(theta)**8 - 3.85896268962316e+55*cos(theta)**6 + 2.50581992832673e+53*cos(theta)**4 - 6.34652577879289e+50*cos(theta)**2 + 2.61820370412248e+47)*cos(26*phi)

#@torch.jit.script
def Yl74_m27(theta, phi):
    return 2.55078856344285e-50*(1.0 - cos(theta)**2)**13.5*(1.58189696531951e+69*cos(theta)**47 - 1.16328613572135e+70*cos(theta)**45 + 3.97121818746255e+70*cos(theta)**43 - 8.35899772326034e+70*cos(theta)**41 + 1.21531527182154e+71*cos(theta)**39 - 1.29575340492052e+71*cos(theta)**37 + 1.04984399960714e+71*cos(theta)**35 - 6.6101288864153e+70*cos(theta)**33 + 3.2802143346121e+70*cos(theta)**31 - 1.2937232108521e+70*cos(theta)**29 + 4.07171801244925e+69*cos(theta)**27 - 1.02303008043643e+69*cos(theta)**25 + 2.04606016087285e+68*cos(theta)**23 - 3.23735597686574e+67*cos(theta)**21 + 4.01325121099058e+66*cos(theta)**19 - 3.84462721052879e+65*cos(theta)**17 + 2.79310523841835e+64*cos(theta)**15 - 1.50013324825538e+63*cos(theta)**13 + 5.75272337089085e+61*cos(theta)**11 - 1.50023606163583e+60*cos(theta)**9 + 2.47745404673807e+58*cos(theta)**7 - 2.3153776137739e+56*cos(theta)**5 + 1.00232797133069e+54*cos(theta)**3 - 1.26930515575858e+51*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl74_m28(theta, phi):
    return 3.68404941024624e-52*(1.0 - cos(theta)**2)**14*(7.4349157370017e+70*cos(theta)**46 - 5.23478761074609e+71*cos(theta)**44 + 1.7076238206089e+72*cos(theta)**42 - 3.42718906653674e+72*cos(theta)**40 + 4.739729560104e+72*cos(theta)**38 - 4.79428759820592e+72*cos(theta)**36 + 3.67445399862497e+72*cos(theta)**34 - 2.18134253251705e+72*cos(theta)**32 + 1.01686644372975e+72*cos(theta)**30 - 3.75179731147109e+71*cos(theta)**28 + 1.0993638633613e+71*cos(theta)**26 - 2.55757520109106e+70*cos(theta)**24 + 4.70593837000756e+69*cos(theta)**22 - 6.79844755141805e+68*cos(theta)**20 + 7.62517730088211e+67*cos(theta)**18 - 6.53586625789895e+66*cos(theta)**16 + 4.18965785762753e+65*cos(theta)**14 - 1.950173222732e+64*cos(theta)**12 + 6.32799570797993e+62*cos(theta)**10 - 1.35021245547225e+61*cos(theta)**8 + 1.73421783271665e+59*cos(theta)**6 - 1.15768880688695e+57*cos(theta)**4 + 3.00698391399207e+54*cos(theta)**2 - 1.26930515575858e+51)*cos(28*phi)

#@torch.jit.script
def Yl74_m29(theta, phi):
    return 5.35214558293554e-54*(1.0 - cos(theta)**2)**14.5*(3.42006123902078e+72*cos(theta)**45 - 2.30330654872828e+73*cos(theta)**43 + 7.17202004655737e+73*cos(theta)**41 - 1.3708756266147e+74*cos(theta)**39 + 1.80109723283952e+74*cos(theta)**37 - 1.72594353535413e+74*cos(theta)**35 + 1.24931435953249e+74*cos(theta)**33 - 6.98029610405455e+73*cos(theta)**31 + 3.05059933118926e+73*cos(theta)**29 - 1.05050324721191e+73*cos(theta)**27 + 2.85834604473937e+72*cos(theta)**25 - 6.13818048261855e+71*cos(theta)**23 + 1.03530644140166e+71*cos(theta)**21 - 1.35968951028361e+70*cos(theta)**19 + 1.37253191415878e+69*cos(theta)**17 - 1.04573860126383e+68*cos(theta)**15 + 5.86552100067854e+66*cos(theta)**13 - 2.3402078672784e+65*cos(theta)**11 + 6.32799570797993e+63*cos(theta)**9 - 1.0801699643778e+62*cos(theta)**7 + 1.04053069962999e+60*cos(theta)**5 - 4.63075522754779e+57*cos(theta)**3 + 6.01396782798414e+54*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl74_m30(theta, phi):
    return 7.82357034002052e-56*(1.0 - cos(theta)**2)**15*(1.53902755755935e+74*cos(theta)**44 - 9.90421815953161e+74*cos(theta)**42 + 2.94052821908852e+75*cos(theta)**40 - 5.34641494379731e+75*cos(theta)**38 + 6.66405976150623e+75*cos(theta)**36 - 6.04080237373946e+75*cos(theta)**34 + 4.12273738645722e+75*cos(theta)**32 - 2.16389179225691e+75*cos(theta)**30 + 8.84673806044884e+74*cos(theta)**28 - 2.83635876747215e+74*cos(theta)**26 + 7.14586511184843e+73*cos(theta)**24 - 1.41178151100227e+73*cos(theta)**22 + 2.17414352694349e+72*cos(theta)**20 - 2.58341006953886e+71*cos(theta)**18 + 2.33330425406992e+70*cos(theta)**16 - 1.56860790189575e+69*cos(theta)**14 + 7.62517730088211e+67*cos(theta)**12 - 2.57422865400624e+66*cos(theta)**10 + 5.69519613718194e+64*cos(theta)**8 - 7.56118975064458e+62*cos(theta)**6 + 5.20265349814994e+60*cos(theta)**4 - 1.38922656826434e+58*cos(theta)**2 + 6.01396782798414e+54)*cos(30*phi)

#@torch.jit.script
def Yl74_m31(theta, phi):
    return 1.15102300503607e-57*(1.0 - cos(theta)**2)**15.5*(6.77172125326115e+75*cos(theta)**43 - 4.15977162700328e+76*cos(theta)**41 + 1.17621128763541e+77*cos(theta)**39 - 2.03163767864298e+77*cos(theta)**37 + 2.39906151414224e+77*cos(theta)**35 - 2.05387280707142e+77*cos(theta)**33 + 1.31927596366631e+77*cos(theta)**31 - 6.49167537677074e+76*cos(theta)**29 + 2.47708665692568e+76*cos(theta)**27 - 7.37453279542758e+75*cos(theta)**25 + 1.71500762684362e+75*cos(theta)**23 - 3.10591932420499e+74*cos(theta)**21 + 4.34828705388698e+73*cos(theta)**19 - 4.65013812516994e+72*cos(theta)**17 + 3.73328680651188e+71*cos(theta)**15 - 2.19605106265405e+70*cos(theta)**13 + 9.15021276105853e+68*cos(theta)**11 - 2.57422865400624e+67*cos(theta)**9 + 4.55615690974555e+65*cos(theta)**7 - 4.53671385038675e+63*cos(theta)**5 + 2.08106139925998e+61*cos(theta)**3 - 2.77845313652867e+58*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl74_m32(theta, phi):
    return 1.70489188407376e-59*(1.0 - cos(theta)**2)**16*(2.91184013890229e+77*cos(theta)**42 - 1.70550636707134e+78*cos(theta)**40 + 4.5872240217781e+78*cos(theta)**38 - 7.51705941097902e+78*cos(theta)**36 + 8.39671529949785e+78*cos(theta)**34 - 6.77778026333567e+78*cos(theta)**32 + 4.08975548736556e+78*cos(theta)**30 - 1.88258585926351e+78*cos(theta)**28 + 6.68813397369932e+77*cos(theta)**26 - 1.8436331988569e+77*cos(theta)**24 + 3.94451754174034e+76*cos(theta)**22 - 6.52243058083048e+75*cos(theta)**20 + 8.26174540238527e+74*cos(theta)**18 - 7.90523481278891e+73*cos(theta)**16 + 5.59993020976782e+72*cos(theta)**14 - 2.85486638145026e+71*cos(theta)**12 + 1.00652340371644e+70*cos(theta)**10 - 2.31680578860561e+68*cos(theta)**8 + 3.18930983682189e+66*cos(theta)**6 - 2.26835692519338e+64*cos(theta)**4 + 6.24318419777993e+61*cos(theta)**2 - 2.77845313652867e+58)*cos(32*phi)

#@torch.jit.script
def Yl74_m33(theta, phi):
    return 2.5431987961142e-61*(1.0 - cos(theta)**2)**16.5*(1.22297285833896e+79*cos(theta)**41 - 6.82202546828537e+79*cos(theta)**39 + 1.74314512827568e+80*cos(theta)**37 - 2.70614138795245e+80*cos(theta)**35 + 2.85488320182927e+80*cos(theta)**33 - 2.16888968426741e+80*cos(theta)**31 + 1.22692664620967e+80*cos(theta)**29 - 5.27124040593784e+79*cos(theta)**27 + 1.73891483316182e+79*cos(theta)**25 - 4.42471967725655e+78*cos(theta)**23 + 8.67793859182874e+77*cos(theta)**21 - 1.3044861161661e+77*cos(theta)**19 + 1.48711417242935e+76*cos(theta)**17 - 1.26483757004622e+75*cos(theta)**15 + 7.83990229367495e+73*cos(theta)**13 - 3.42583965774031e+72*cos(theta)**11 + 1.00652340371644e+71*cos(theta)**9 - 1.85344463088449e+69*cos(theta)**7 + 1.91358590209313e+67*cos(theta)**5 - 9.0734277007735e+64*cos(theta)**3 + 1.24863683955599e+62*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl74_m34(theta, phi):
    return 3.82187521563157e-63*(1.0 - cos(theta)**2)**17*(5.01418871918975e+80*cos(theta)**40 - 2.6605899326313e+81*cos(theta)**38 + 6.44963697462e+81*cos(theta)**36 - 9.47149485783357e+81*cos(theta)**34 + 9.42111456603658e+81*cos(theta)**32 - 6.72355802122899e+81*cos(theta)**30 + 3.55808727400804e+81*cos(theta)**28 - 1.42323490960322e+81*cos(theta)**26 + 4.34728708290456e+80*cos(theta)**24 - 1.01768552576901e+80*cos(theta)**22 + 1.82236710428403e+79*cos(theta)**20 - 2.47852362071558e+78*cos(theta)**18 + 2.52809409312989e+77*cos(theta)**16 - 1.89725635506934e+76*cos(theta)**14 + 1.01918729817774e+75*cos(theta)**12 - 3.76842362351435e+73*cos(theta)**10 + 9.05871063344794e+71*cos(theta)**8 - 1.29741124161914e+70*cos(theta)**6 + 9.56792951046566e+67*cos(theta)**4 - 2.72202831023205e+65*cos(theta)**2 + 1.24863683955599e+62)*cos(34*phi)

#@torch.jit.script
def Yl74_m35(theta, phi):
    return 5.78806312057407e-65*(1.0 - cos(theta)**2)**17.5*(2.0056754876759e+82*cos(theta)**39 - 1.01102417439989e+83*cos(theta)**37 + 2.3218693108632e+83*cos(theta)**35 - 3.22030825166341e+83*cos(theta)**33 + 3.01475666113171e+83*cos(theta)**31 - 2.0170674063687e+83*cos(theta)**29 + 9.96264436722251e+82*cos(theta)**27 - 3.70041076496836e+82*cos(theta)**25 + 1.04334889989709e+82*cos(theta)**23 - 2.23890815669181e+81*cos(theta)**21 + 3.64473420856807e+80*cos(theta)**19 - 4.46134251728805e+79*cos(theta)**17 + 4.04495054900783e+78*cos(theta)**15 - 2.65615889709707e+77*cos(theta)**13 + 1.22302475781329e+76*cos(theta)**11 - 3.76842362351435e+74*cos(theta)**9 + 7.24696850675836e+72*cos(theta)**7 - 7.78446744971486e+70*cos(theta)**5 + 3.82717180418626e+68*cos(theta)**3 - 5.4440566204641e+65*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl74_m36(theta, phi):
    return 8.83699506561061e-67*(1.0 - cos(theta)**2)**18*(7.82213440193601e+83*cos(theta)**38 - 3.7407894452796e+84*cos(theta)**36 + 8.1265425880212e+84*cos(theta)**34 - 1.06270172304893e+85*cos(theta)**32 + 9.34574564950829e+84*cos(theta)**30 - 5.84949547846922e+84*cos(theta)**28 + 2.68991397915008e+84*cos(theta)**26 - 9.2510269124209e+83*cos(theta)**24 + 2.39970246976332e+83*cos(theta)**22 - 4.70170712905281e+82*cos(theta)**20 + 6.92499499627933e+81*cos(theta)**18 - 7.58428227938968e+80*cos(theta)**16 + 6.06742582351174e+79*cos(theta)**14 - 3.45300656622619e+78*cos(theta)**12 + 1.34532723359462e+77*cos(theta)**10 - 3.39158126116291e+75*cos(theta)**8 + 5.07287795473085e+73*cos(theta)**6 - 3.89223372485743e+71*cos(theta)**4 + 1.14815154125588e+69*cos(theta)**2 - 5.4440566204641e+65)*cos(36*phi)

#@torch.jit.script
def Yl74_m37(theta, phi):
    return 1.36066534806227e-68*(1.0 - cos(theta)**2)**18.5*(2.97241107273568e+85*cos(theta)**37 - 1.34668420030066e+86*cos(theta)**35 + 2.76302447992721e+86*cos(theta)**33 - 3.40064551375657e+86*cos(theta)**31 + 2.80372369485249e+86*cos(theta)**29 - 1.63785873397138e+86*cos(theta)**27 + 6.9937763457902e+85*cos(theta)**25 - 2.22024645898102e+85*cos(theta)**23 + 5.2793454334793e+84*cos(theta)**21 - 9.40341425810562e+83*cos(theta)**19 + 1.24649909933028e+83*cos(theta)**17 - 1.21348516470235e+82*cos(theta)**15 + 8.49439615291644e+80*cos(theta)**13 - 4.14360787947143e+79*cos(theta)**11 + 1.34532723359462e+78*cos(theta)**9 - 2.71326500893033e+76*cos(theta)**7 + 3.04372677283851e+74*cos(theta)**5 - 1.55689348994297e+72*cos(theta)**3 + 2.29630308251176e+69*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl74_m38(theta, phi):
    return 2.11369077232848e-70*(1.0 - cos(theta)**2)**19*(1.0997920969122e+87*cos(theta)**36 - 4.7133947010523e+87*cos(theta)**34 + 9.11798078375979e+87*cos(theta)**32 - 1.05420010926454e+88*cos(theta)**30 + 8.13079871507221e+87*cos(theta)**28 - 4.42221858172273e+87*cos(theta)**26 + 1.74844408644755e+87*cos(theta)**24 - 5.10656685565634e+86*cos(theta)**22 + 1.10866254103065e+86*cos(theta)**20 - 1.78664870904007e+85*cos(theta)**18 + 2.11904846886148e+84*cos(theta)**16 - 1.82022774705352e+83*cos(theta)**14 + 1.10427149987914e+82*cos(theta)**12 - 4.55796866741858e+80*cos(theta)**10 + 1.21079451023516e+79*cos(theta)**8 - 1.89928550625123e+77*cos(theta)**6 + 1.52186338641925e+75*cos(theta)**4 - 4.67068046982891e+72*cos(theta)**2 + 2.29630308251176e+69)*cos(38*phi)

#@torch.jit.script
def Yl74_m39(theta, phi):
    return 3.31398836473207e-72*(1.0 - cos(theta)**2)**19.5*(3.95925154888393e+88*cos(theta)**35 - 1.60255419835778e+89*cos(theta)**33 + 2.91775385080313e+89*cos(theta)**31 - 3.16260032779361e+89*cos(theta)**29 + 2.27662364022022e+89*cos(theta)**27 - 1.14977683124791e+89*cos(theta)**25 + 4.19626580747412e+88*cos(theta)**23 - 1.12344470824439e+88*cos(theta)**21 + 2.21732508206131e+87*cos(theta)**19 - 3.21596767627212e+86*cos(theta)**17 + 3.39047755017836e+85*cos(theta)**15 - 2.54831884587493e+84*cos(theta)**13 + 1.32512579985496e+83*cos(theta)**11 - 4.55796866741858e+81*cos(theta)**9 + 9.68635608188127e+79*cos(theta)**7 - 1.13957130375074e+78*cos(theta)**5 + 6.08745354567702e+75*cos(theta)**3 - 9.34136093965783e+72*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl74_m40(theta, phi):
    return 5.24643783713255e-74*(1.0 - cos(theta)**2)**20*(1.38573804210938e+90*cos(theta)**34 - 5.28842885458068e+90*cos(theta)**32 + 9.04503693748971e+90*cos(theta)**30 - 9.17154095060146e+90*cos(theta)**28 + 6.14688382859459e+90*cos(theta)**26 - 2.87444207811977e+90*cos(theta)**24 + 9.65141135719048e+89*cos(theta)**22 - 2.35923388731323e+89*cos(theta)**20 + 4.21291765591648e+88*cos(theta)**18 - 5.46714504966261e+87*cos(theta)**16 + 5.08571632526754e+86*cos(theta)**14 - 3.31281449963741e+85*cos(theta)**12 + 1.45763837984046e+84*cos(theta)**10 - 4.10217180067672e+82*cos(theta)**8 + 6.78044925731689e+80*cos(theta)**6 - 5.69785651875369e+78*cos(theta)**4 + 1.82623606370311e+76*cos(theta)**2 - 9.34136093965783e+72)*cos(40*phi)

#@torch.jit.script
def Yl74_m41(theta, phi):
    return 8.39027417390453e-76*(1.0 - cos(theta)**2)**20.5*(4.71150934317188e+91*cos(theta)**33 - 1.69229723346582e+92*cos(theta)**31 + 2.71351108124691e+92*cos(theta)**29 - 2.56803146616841e+92*cos(theta)**27 + 1.59818979543459e+92*cos(theta)**25 - 6.89866098748746e+91*cos(theta)**23 + 2.12331049858191e+91*cos(theta)**21 - 4.71846777462646e+90*cos(theta)**19 + 7.58325178064966e+89*cos(theta)**17 - 8.74743207946017e+88*cos(theta)**15 + 7.12000285537456e+87*cos(theta)**13 - 3.97537739956489e+86*cos(theta)**11 + 1.45763837984046e+85*cos(theta)**9 - 3.28173744054138e+83*cos(theta)**7 + 4.06826955439013e+81*cos(theta)**5 - 2.27914260750148e+79*cos(theta)**3 + 3.65247212740621e+76*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl74_m42(theta, phi):
    return 1.35609522951268e-77*(1.0 - cos(theta)**2)**21*(1.55479808324672e+93*cos(theta)**32 - 5.24612142374403e+93*cos(theta)**30 + 7.86918213561605e+93*cos(theta)**28 - 6.9336849586547e+93*cos(theta)**26 + 3.99547448858649e+93*cos(theta)**24 - 1.58669202712212e+93*cos(theta)**22 + 4.458952047022e+92*cos(theta)**20 - 8.96508877179027e+91*cos(theta)**18 + 1.28915280271044e+91*cos(theta)**16 - 1.31211481191903e+90*cos(theta)**14 + 9.25600371198692e+88*cos(theta)**12 - 4.37291513952138e+87*cos(theta)**10 + 1.31187454185641e+86*cos(theta)**8 - 2.29721620837896e+84*cos(theta)**6 + 2.03413477719507e+82*cos(theta)**4 - 6.83742782250443e+79*cos(theta)**2 + 3.65247212740621e+76)*cos(42*phi)

#@torch.jit.script
def Yl74_m43(theta, phi):
    return 2.21626796076129e-79*(1.0 - cos(theta)**2)**21.5*(4.9753538663895e+94*cos(theta)**31 - 1.57383642712321e+95*cos(theta)**29 + 2.20337099797249e+95*cos(theta)**27 - 1.80275808925022e+95*cos(theta)**25 + 9.58913877260756e+94*cos(theta)**23 - 3.49072245966865e+94*cos(theta)**21 + 8.917904094044e+93*cos(theta)**19 - 1.61371597892225e+93*cos(theta)**17 + 2.06264448433671e+92*cos(theta)**15 - 1.83696073668664e+91*cos(theta)**13 + 1.11072044543843e+90*cos(theta)**11 - 4.37291513952138e+88*cos(theta)**9 + 1.04949963348513e+87*cos(theta)**7 - 1.37832972502738e+85*cos(theta)**5 + 8.13653910878027e+82*cos(theta)**3 - 1.36748556450089e+80*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl74_m44(theta, phi):
    return 3.66437926999678e-81*(1.0 - cos(theta)**2)**22*(1.54235969858075e+96*cos(theta)**30 - 4.56412563865731e+96*cos(theta)**28 + 5.94910169452573e+96*cos(theta)**26 - 4.50689522312556e+96*cos(theta)**24 + 2.20550191769974e+96*cos(theta)**22 - 7.33051716530417e+95*cos(theta)**20 + 1.69440177786836e+95*cos(theta)**18 - 2.74331716416782e+94*cos(theta)**16 + 3.09396672650506e+93*cos(theta)**14 - 2.38804895769263e+92*cos(theta)**12 + 1.22179248998227e+91*cos(theta)**10 - 3.93562362556924e+89*cos(theta)**8 + 7.34649743439592e+87*cos(theta)**6 - 6.89164862513689e+85*cos(theta)**4 + 2.44096173263408e+83*cos(theta)**2 - 1.36748556450089e+80)*cos(44*phi)

#@torch.jit.script
def Yl74_m45(theta, phi):
    return 6.13290601841919e-83*(1.0 - cos(theta)**2)**22.5*(4.62707909574224e+97*cos(theta)**29 - 1.27795517882405e+98*cos(theta)**27 + 1.54676644057669e+98*cos(theta)**25 - 1.08165485355013e+98*cos(theta)**23 + 4.85210421893943e+97*cos(theta)**21 - 1.46610343306083e+97*cos(theta)**19 + 3.04992320016305e+96*cos(theta)**17 - 4.38930746266852e+95*cos(theta)**15 + 4.33155341710709e+94*cos(theta)**13 - 2.86565874923115e+93*cos(theta)**11 + 1.22179248998227e+92*cos(theta)**9 - 3.1484989004554e+90*cos(theta)**7 + 4.40789846063755e+88*cos(theta)**5 - 2.75665945005475e+86*cos(theta)**3 + 4.88192346526816e+83*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl74_m46(theta, phi):
    return 1.03962493555662e-84*(1.0 - cos(theta)**2)**23*(1.34185293776525e+99*cos(theta)**28 - 3.45047898282493e+99*cos(theta)**26 + 3.86691610144173e+99*cos(theta)**24 - 2.48780616316531e+99*cos(theta)**22 + 1.01894188597728e+99*cos(theta)**20 - 2.78559652281558e+98*cos(theta)**18 + 5.18486944027718e+97*cos(theta)**16 - 6.58396119400277e+96*cos(theta)**14 + 5.63101944223921e+95*cos(theta)**12 - 3.15222462415427e+94*cos(theta)**10 + 1.09961324098405e+93*cos(theta)**8 - 2.20394923031878e+91*cos(theta)**6 + 2.20394923031878e+89*cos(theta)**4 - 8.26997835016427e+86*cos(theta)**2 + 4.88192346526816e+83)*cos(46*phi)

#@torch.jit.script
def Yl74_m47(theta, phi):
    return 1.78609677679504e-86*(1.0 - cos(theta)**2)**23.5*(3.7571882257427e+100*cos(theta)**27 - 8.97124535534481e+100*cos(theta)**25 + 9.28059864346014e+100*cos(theta)**23 - 5.47317355896367e+100*cos(theta)**21 + 2.03788377195456e+100*cos(theta)**19 - 5.01407374106805e+99*cos(theta)**17 + 8.29579110444349e+98*cos(theta)**15 - 9.21754567160388e+97*cos(theta)**13 + 6.75722333068706e+96*cos(theta)**11 - 3.15222462415427e+95*cos(theta)**9 + 8.79690592787237e+93*cos(theta)**7 - 1.32236953819127e+92*cos(theta)**5 + 8.81579692127511e+89*cos(theta)**3 - 1.65399567003285e+87*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl74_m48(theta, phi):
    return 3.11202580364349e-88*(1.0 - cos(theta)**2)**24*(1.01444082095053e+102*cos(theta)**26 - 2.2428113388362e+102*cos(theta)**24 + 2.13453768799583e+102*cos(theta)**22 - 1.14936644738237e+102*cos(theta)**20 + 3.87197916671366e+101*cos(theta)**18 - 8.52392535981569e+100*cos(theta)**16 + 1.24436866566652e+100*cos(theta)**14 - 1.1982809373085e+99*cos(theta)**12 + 7.43294566375576e+97*cos(theta)**10 - 2.83700216173884e+96*cos(theta)**8 + 6.15783414951066e+94*cos(theta)**6 - 6.61184769095633e+92*cos(theta)**4 + 2.64473907638253e+90*cos(theta)**2 - 1.65399567003285e+87)*cos(48*phi)

#@torch.jit.script
def Yl74_m49(theta, phi):
    return 5.50305634635573e-90*(1.0 - cos(theta)**2)**24.5*(2.63754613447137e+103*cos(theta)**25 - 5.38274721320688e+103*cos(theta)**23 + 4.69598291359083e+103*cos(theta)**21 - 2.29873289476474e+103*cos(theta)**19 + 6.96956250008459e+102*cos(theta)**17 - 1.36382805757051e+102*cos(theta)**15 + 1.74211613193313e+101*cos(theta)**13 - 1.43793712477021e+100*cos(theta)**11 + 7.43294566375576e+98*cos(theta)**9 - 2.26960172939107e+97*cos(theta)**7 + 3.6947004897064e+95*cos(theta)**5 - 2.64473907638253e+93*cos(theta)**3 + 5.28947815276506e+90*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl74_m50(theta, phi):
    return 9.88378097157581e-92*(1.0 - cos(theta)**2)**25*(6.59386533617843e+104*cos(theta)**24 - 1.23803185903758e+105*cos(theta)**22 + 9.86156411854075e+104*cos(theta)**20 - 4.36759250005301e+104*cos(theta)**18 + 1.18482562501438e+104*cos(theta)**16 - 2.04574208635577e+103*cos(theta)**14 + 2.26475097151307e+102*cos(theta)**12 - 1.58173083724723e+101*cos(theta)**10 + 6.68965109738019e+99*cos(theta)**8 - 1.58872121057375e+98*cos(theta)**6 + 1.8473502448532e+96*cos(theta)**4 - 7.9342172291476e+93*cos(theta)**2 + 5.28947815276506e+90)*cos(50*phi)

#@torch.jit.script
def Yl74_m51(theta, phi):
    return 1.80452326385747e-93*(1.0 - cos(theta)**2)**25.5*(1.58252768068282e+106*cos(theta)**23 - 2.72367008988268e+106*cos(theta)**21 + 1.97231282370815e+106*cos(theta)**19 - 7.86166650009542e+105*cos(theta)**17 + 1.89572100002301e+105*cos(theta)**15 - 2.86403892089807e+104*cos(theta)**13 + 2.71770116581569e+103*cos(theta)**11 - 1.58173083724723e+102*cos(theta)**9 + 5.35172087790415e+100*cos(theta)**7 - 9.5323272634425e+98*cos(theta)**5 + 7.38940097941279e+96*cos(theta)**3 - 1.58684344582952e+94*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl74_m52(theta, phi):
    return 3.35207166344377e-95*(1.0 - cos(theta)**2)**26*(3.63981366557049e+107*cos(theta)**22 - 5.71970718875363e+107*cos(theta)**20 + 3.74739436504548e+107*cos(theta)**18 - 1.33648330501622e+107*cos(theta)**16 + 2.84358150003451e+106*cos(theta)**14 - 3.72325059716749e+105*cos(theta)**12 + 2.98947128239726e+104*cos(theta)**10 - 1.4235577535225e+103*cos(theta)**8 + 3.7462046145329e+101*cos(theta)**6 - 4.76616363172125e+99*cos(theta)**4 + 2.21682029382384e+97*cos(theta)**2 - 1.58684344582952e+94)*cos(52*phi)

#@torch.jit.script
def Yl74_m53(theta, phi):
    return 6.34161823364269e-97*(1.0 - cos(theta)**2)**26.5*(8.00759006425509e+108*cos(theta)**21 - 1.14394143775073e+109*cos(theta)**19 + 6.74530985708187e+108*cos(theta)**17 - 2.13837328802595e+108*cos(theta)**15 + 3.98101410004832e+107*cos(theta)**13 - 4.46790071660099e+106*cos(theta)**11 + 2.98947128239726e+105*cos(theta)**9 - 1.138846202818e+104*cos(theta)**7 + 2.24772276871974e+102*cos(theta)**5 - 1.9064654526885e+100*cos(theta)**3 + 4.43364058764768e+97*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl74_m54(theta, phi):
    return 1.22316617203969e-98*(1.0 - cos(theta)**2)**27*(1.68159391349357e+110*cos(theta)**20 - 2.17348873172638e+110*cos(theta)**18 + 1.14670267570392e+110*cos(theta)**16 - 3.20755993203893e+109*cos(theta)**14 + 5.17531833006282e+108*cos(theta)**12 - 4.91469078826109e+107*cos(theta)**10 + 2.69052415415753e+106*cos(theta)**8 - 7.97192341972602e+104*cos(theta)**6 + 1.12386138435987e+103*cos(theta)**4 - 5.7193963580655e+100*cos(theta)**2 + 4.43364058764768e+97)*cos(54*phi)

#@torch.jit.script
def Yl74_m55(theta, phi):
    return 2.40810604953822e-100*(1.0 - cos(theta)**2)**27.5*(3.36318782698714e+111*cos(theta)**19 - 3.91227971710749e+111*cos(theta)**17 + 1.83472428112627e+111*cos(theta)**15 - 4.49058390485451e+110*cos(theta)**13 + 6.21038199607538e+109*cos(theta)**11 - 4.91469078826109e+108*cos(theta)**9 + 2.15241932332603e+107*cos(theta)**7 - 4.78315405183561e+105*cos(theta)**5 + 4.49544553743949e+103*cos(theta)**3 - 1.1438792716131e+101*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl74_m56(theta, phi):
    return 4.84537207548491e-102*(1.0 - cos(theta)**2)**28*(6.39005687127556e+112*cos(theta)**18 - 6.65087551908273e+112*cos(theta)**16 + 2.7520864216894e+112*cos(theta)**14 - 5.83775907631086e+111*cos(theta)**12 + 6.83142019568292e+110*cos(theta)**10 - 4.42322170943498e+109*cos(theta)**8 + 1.50669352632822e+108*cos(theta)**6 - 2.39157702591781e+106*cos(theta)**4 + 1.34863366123185e+104*cos(theta)**2 - 1.1438792716131e+101)*cos(56*phi)

#@torch.jit.script
def Yl74_m57(theta, phi):
    return 9.97826955093323e-104*(1.0 - cos(theta)**2)**28.5*(1.1502102368296e+114*cos(theta)**17 - 1.06414008305324e+114*cos(theta)**15 + 3.85292099036517e+113*cos(theta)**13 - 7.00531089157303e+112*cos(theta)**11 + 6.83142019568292e+111*cos(theta)**9 - 3.53857736754799e+110*cos(theta)**7 + 9.04016115796931e+108*cos(theta)**5 - 9.56630810367122e+106*cos(theta)**3 + 2.69726732246369e+104*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl74_m58(theta, phi):
    return 2.10641435321022e-105*(1.0 - cos(theta)**2)**29*(1.95535740261032e+115*cos(theta)**16 - 1.59621012457985e+115*cos(theta)**14 + 5.00879728747472e+114*cos(theta)**12 - 7.70584198073033e+113*cos(theta)**10 + 6.14827817611463e+112*cos(theta)**8 - 2.47700415728359e+111*cos(theta)**6 + 4.52008057898465e+109*cos(theta)**4 - 2.86989243110137e+107*cos(theta)**2 + 2.69726732246369e+104)*cos(58*phi)

#@torch.jit.script
def Yl74_m59(theta, phi):
    return 4.56623221404321e-107*(1.0 - cos(theta)**2)**29.5*(3.12857184417651e+116*cos(theta)**15 - 2.2346941744118e+116*cos(theta)**13 + 6.01055674496966e+115*cos(theta)**11 - 7.70584198073033e+114*cos(theta)**9 + 4.9186225408917e+113*cos(theta)**7 - 1.48620249437015e+112*cos(theta)**5 + 1.80803223159386e+110*cos(theta)**3 - 5.73978486220273e+107*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl74_m60(theta, phi):
    return 1.01849749430168e-108*(1.0 - cos(theta)**2)**30*(4.69285776626477e+117*cos(theta)**14 - 2.90510242673533e+117*cos(theta)**12 + 6.61161241946662e+116*cos(theta)**10 - 6.9352577826573e+115*cos(theta)**8 + 3.44303577862419e+114*cos(theta)**6 - 7.43101247185077e+112*cos(theta)**4 + 5.42409669478158e+110*cos(theta)**2 - 5.73978486220273e+107)*cos(60*phi)

#@torch.jit.script
def Yl74_m61(theta, phi):
    return 2.34276681031359e-110*(1.0 - cos(theta)**2)**30.5*(6.57000087277068e+118*cos(theta)**13 - 3.4861229120824e+118*cos(theta)**11 + 6.61161241946662e+117*cos(theta)**9 - 5.54820622612584e+116*cos(theta)**7 + 2.06582146717451e+115*cos(theta)**5 - 2.97240498874031e+113*cos(theta)**3 + 1.08481933895632e+111*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl74_m62(theta, phi):
    return 5.57170266890608e-112*(1.0 - cos(theta)**2)**31*(8.54100113460188e+119*cos(theta)**12 - 3.83473520329064e+119*cos(theta)**10 + 5.95045117751996e+118*cos(theta)**8 - 3.88374435828809e+117*cos(theta)**6 + 1.03291073358726e+116*cos(theta)**4 - 8.91721496622092e+113*cos(theta)**2 + 1.08481933895632e+111)*cos(62*phi)

#@torch.jit.script
def Yl74_m63(theta, phi):
    return 1.37415912422983e-113*(1.0 - cos(theta)**2)**31.5*(1.02492013615223e+121*cos(theta)**11 - 3.83473520329064e+120*cos(theta)**9 + 4.76036094201597e+119*cos(theta)**7 - 2.33024661497285e+118*cos(theta)**5 + 4.13164293434903e+116*cos(theta)**3 - 1.78344299324418e+114*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl74_m64(theta, phi):
    return 3.52696491989079e-115*(1.0 - cos(theta)**2)**32*(1.12741214976745e+122*cos(theta)**10 - 3.45126168296158e+121*cos(theta)**8 + 3.33225265941118e+120*cos(theta)**6 - 1.16512330748643e+119*cos(theta)**4 + 1.23949288030471e+117*cos(theta)**2 - 1.78344299324418e+114)*cos(64*phi)

#@torch.jit.script
def Yl74_m65(theta, phi):
    return 9.46005671197665e-117*(1.0 - cos(theta)**2)**32.5*(1.12741214976745e+123*cos(theta)**9 - 2.76100934636926e+122*cos(theta)**7 + 1.99935159564671e+121*cos(theta)**5 - 4.6604932299457e+119*cos(theta)**3 + 2.47898576060942e+117*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl74_m66(theta, phi):
    return 2.66506906003338e-118*(1.0 - cos(theta)**2)**33*(1.0146709347907e+124*cos(theta)**8 - 1.93270654245848e+123*cos(theta)**6 + 9.99675797823354e+121*cos(theta)**4 - 1.39814796898371e+120*cos(theta)**2 + 2.47898576060942e+117)*cos(66*phi)

#@torch.jit.script
def Yl74_m67(theta, phi):
    return 7.93512765114446e-120*(1.0 - cos(theta)**2)**33.5*(8.11736747832563e+124*cos(theta)**7 - 1.15962392547509e+124*cos(theta)**5 + 3.99870319129341e+122*cos(theta)**3 - 2.79629593796742e+120*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl74_m68(theta, phi):
    return 2.51686965917654e-121*(1.0 - cos(theta)**2)**34*(5.68215723482794e+125*cos(theta)**6 - 5.79811962737545e+124*cos(theta)**4 + 1.19961095738802e+123*cos(theta)**2 - 2.79629593796742e+120)*cos(68*phi)

#@torch.jit.script
def Yl74_m69(theta, phi):
    return 8.59245134182199e-123*(1.0 - cos(theta)**2)**34.5*(3.40929434089676e+126*cos(theta)**5 - 2.31924785095018e+125*cos(theta)**3 + 2.39922191477605e+123*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl74_m70(theta, phi):
    return 3.20221754894554e-124*(1.0 - cos(theta)**2)**35*(1.70464717044838e+127*cos(theta)**4 - 6.95774355285054e+125*cos(theta)**2 + 2.39922191477605e+123)*cos(70*phi)

#@torch.jit.script
def Yl74_m71(theta, phi):
    return 1.32964846474125e-125*(1.0 - cos(theta)**2)**35.5*(6.81858868179353e+127*cos(theta)**3 - 1.39154871057011e+126*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl74_m72(theta, phi):
    return 6.35330611770864e-127*(1.0 - cos(theta)**2)**36*(2.04557660453806e+128*cos(theta)**2 - 1.39154871057011e+126)*cos(72*phi)

#@torch.jit.script
def Yl74_m73(theta, phi):
    return 15.159045609564*(1.0 - cos(theta)**2)**36.5*cos(73*phi)*cos(theta)

#@torch.jit.script
def Yl74_m74(theta, phi):
    return 1.24606587336403*(1.0 - cos(theta)**2)**37*cos(74*phi)

#@torch.jit.script
def Yl75_m_minus_75(theta, phi):
    return 1.25021252666665*(1.0 - cos(theta)**2)**37.5*sin(75*phi)

#@torch.jit.script
def Yl75_m_minus_74(theta, phi):
    return 15.311913801845*(1.0 - cos(theta)**2)**37*sin(74*phi)*cos(theta)

#@torch.jit.script
def Yl75_m_minus_73(theta, phi):
    return 4.33616296245739e-129*(1.0 - cos(theta)**2)**36.5*(3.04790914076171e+130*cos(theta)**2 - 2.04557660453806e+128)*sin(73*phi)

#@torch.jit.script
def Yl75_m_minus_72(theta, phi):
    return 9.13686231767905e-128*(1.0 - cos(theta)**2)**36*(1.01596971358724e+130*cos(theta)**3 - 2.04557660453806e+128*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl75_m_minus_71(theta, phi):
    return 2.21557136583743e-126*(1.0 - cos(theta)**2)**35.5*(2.53992428396809e+129*cos(theta)**4 - 1.02278830226903e+128*cos(theta)**2 + 3.47887177642527e+125)*sin(71*phi)

#@torch.jit.script
def Yl75_m_minus_70(theta, phi):
    return 5.98614419162843e-125*(1.0 - cos(theta)**2)**35*(5.07984856793618e+128*cos(theta)**5 - 3.40929434089676e+127*cos(theta)**3 + 3.47887177642527e+125*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl75_m_minus_69(theta, phi):
    return 1.7656588681334e-123*(1.0 - cos(theta)**2)**34.5*(8.46641427989363e+127*cos(theta)**6 - 8.52323585224191e+126*cos(theta)**4 + 1.73943588821264e+125*cos(theta)**2 - 3.99870319129341e+122)*sin(69*phi)

#@torch.jit.script
def Yl75_m_minus_68(theta, phi):
    return 5.60579311830811e-122*(1.0 - cos(theta)**2)**34*(1.20948775427052e+127*cos(theta)**7 - 1.70464717044838e+126*cos(theta)**5 + 5.79811962737545e+124*cos(theta)**3 - 3.99870319129341e+122*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl75_m_minus_67(theta, phi):
    return 1.89605127723776e-120*(1.0 - cos(theta)**2)**33.5*(1.51185969283815e+126*cos(theta)**8 - 2.84107861741397e+125*cos(theta)**6 + 1.44952990684386e+124*cos(theta)**4 - 1.99935159564671e+122*cos(theta)**2 + 3.49536992245928e+119)*sin(67*phi)

#@torch.jit.script
def Yl75_m_minus_66(theta, phi):
    return 6.77821757535069e-119*(1.0 - cos(theta)**2)**33*(1.6798441031535e+125*cos(theta)**9 - 4.05868373916282e+124*cos(theta)**7 + 2.89905981368773e+123*cos(theta)**5 - 6.66450531882236e+121*cos(theta)**3 + 3.49536992245928e+119*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl75_m_minus_65(theta, phi):
    return 2.54521844314586e-117*(1.0 - cos(theta)**2)**32.5*(1.6798441031535e+124*cos(theta)**10 - 5.07335467395352e+123*cos(theta)**8 + 4.83176635614621e+122*cos(theta)**6 - 1.66612632970559e+121*cos(theta)**4 + 1.74768496122964e+119*cos(theta)**2 - 2.47898576060942e+116)*sin(65*phi)

#@torch.jit.script
def Yl75_m_minus_64(theta, phi):
    return 9.98815841981289e-116*(1.0 - cos(theta)**2)**32*(1.52713100286682e+123*cos(theta)**11 - 5.63706074883724e+122*cos(theta)**9 + 6.90252336592316e+121*cos(theta)**7 - 3.33225265941118e+120*cos(theta)**5 + 5.82561653743213e+118*cos(theta)**3 - 2.47898576060942e+116*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl75_m_minus_63(theta, phi):
    return 4.07927933312929e-114*(1.0 - cos(theta)**2)**31.5*(1.27260916905568e+122*cos(theta)**12 - 5.63706074883724e+121*cos(theta)**10 + 8.62815420740394e+120*cos(theta)**8 - 5.55375443235196e+119*cos(theta)**6 + 1.45640413435803e+118*cos(theta)**4 - 1.23949288030471e+116*cos(theta)**2 + 1.48620249437015e+113)*sin(63*phi)

#@torch.jit.script
def Yl75_m_minus_62(theta, phi):
    return 1.72780475345411e-112*(1.0 - cos(theta)**2)**31*(9.78930130042831e+120*cos(theta)**13 - 5.12460068076113e+120*cos(theta)**11 + 9.5868380082266e+119*cos(theta)**9 - 7.93393490335995e+118*cos(theta)**7 + 2.91280826871606e+117*cos(theta)**5 - 4.13164293434903e+115*cos(theta)**3 + 1.48620249437015e+113*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl75_m_minus_61(theta, phi):
    return 7.56691692322602e-111*(1.0 - cos(theta)**2)**30.5*(6.99235807173451e+119*cos(theta)**14 - 4.27050056730094e+119*cos(theta)**12 + 9.5868380082266e+118*cos(theta)**10 - 9.91741862919994e+117*cos(theta)**8 + 4.85468044786011e+116*cos(theta)**6 - 1.03291073358726e+115*cos(theta)**4 + 7.43101247185077e+112*cos(theta)**2 - 7.74870956397369e+109)*sin(61*phi)

#@torch.jit.script
def Yl75_m_minus_60(theta, phi):
    return 3.41770087507565e-109*(1.0 - cos(theta)**2)**30*(4.66157204782301e+118*cos(theta)**15 - 3.28500043638534e+118*cos(theta)**13 + 8.715307280206e+117*cos(theta)**11 - 1.10193540324444e+117*cos(theta)**9 + 6.9352577826573e+115*cos(theta)**7 - 2.06582146717451e+114*cos(theta)**5 + 2.47700415728359e+112*cos(theta)**3 - 7.74870956397369e+109*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl75_m_minus_59(theta, phi):
    return 1.58840382857838e-107*(1.0 - cos(theta)**2)**29.5*(2.91348252988938e+117*cos(theta)**16 - 2.34642888313239e+117*cos(theta)**14 + 7.26275606683834e+116*cos(theta)**12 - 1.10193540324444e+116*cos(theta)**10 + 8.66907222832162e+114*cos(theta)**8 - 3.44303577862419e+113*cos(theta)**6 + 6.19251039320898e+111*cos(theta)**4 - 3.87435478198685e+109*cos(theta)**2 + 3.58736553887671e+106)*sin(59*phi)

#@torch.jit.script
def Yl75_m_minus_58(theta, phi):
    return 7.58119705203574e-106*(1.0 - cos(theta)**2)**29*(1.71381325287611e+116*cos(theta)**17 - 1.56428592208826e+116*cos(theta)**15 + 5.58673543602949e+115*cos(theta)**13 - 1.00175945749494e+115*cos(theta)**11 + 9.63230247591291e+113*cos(theta)**9 - 4.9186225408917e+112*cos(theta)**7 + 1.2385020786418e+111*cos(theta)**5 - 1.29145159399562e+109*cos(theta)**3 + 3.58736553887671e+106*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl75_m_minus_57(theta, phi):
    return 3.70936746208647e-104*(1.0 - cos(theta)**2)**28.5*(9.52118473820058e+114*cos(theta)**18 - 9.77678701305161e+114*cos(theta)**16 + 3.99052531144964e+114*cos(theta)**14 - 8.34799547912452e+113*cos(theta)**12 + 9.63230247591291e+112*cos(theta)**10 - 6.14827817611463e+111*cos(theta)**8 + 2.06417013106966e+110*cos(theta)**6 - 3.22862898498904e+108*cos(theta)**4 + 1.79368276943835e+106*cos(theta)**2 - 1.49848184581316e+103)*sin(57*phi)

#@torch.jit.script
def Yl75_m_minus_56(theta, phi):
    return 1.85764885480854e-102*(1.0 - cos(theta)**2)**28*(5.01114986221083e+113*cos(theta)**19 - 5.751051184148e+113*cos(theta)**17 + 2.66035020763309e+113*cos(theta)**15 - 6.42153498394194e+112*cos(theta)**13 + 8.75663861446629e+111*cos(theta)**11 - 6.83142019568292e+110*cos(theta)**9 + 2.94881447295665e+109*cos(theta)**7 - 6.45725796997808e+107*cos(theta)**5 + 5.97894256479452e+105*cos(theta)**3 - 1.49848184581316e+103*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl75_m_minus_55(theta, phi):
    return 9.5085494590717e-101*(1.0 - cos(theta)**2)**27.5*(2.50557493110542e+112*cos(theta)**20 - 3.19502843563778e+112*cos(theta)**18 + 1.66271887977068e+112*cos(theta)**16 - 4.58681070281567e+111*cos(theta)**14 + 7.29719884538857e+110*cos(theta)**12 - 6.83142019568292e+109*cos(theta)**10 + 3.68601809119582e+108*cos(theta)**8 - 1.07620966166301e+107*cos(theta)**6 + 1.49473564119863e+105*cos(theta)**4 - 7.49240922906581e+102*cos(theta)**2 + 5.7193963580655e+99)*sin(55*phi)

#@torch.jit.script
def Yl75_m_minus_54(theta, phi):
    return 4.96816022272453e-99*(1.0 - cos(theta)**2)**27*(1.19313091957401e+111*cos(theta)**21 - 1.68159391349357e+111*cos(theta)**19 + 9.78069929276872e+110*cos(theta)**17 - 3.05787380187712e+110*cos(theta)**15 + 5.61322988106813e+109*cos(theta)**13 - 6.21038199607538e+108*cos(theta)**11 + 4.09557565688424e+107*cos(theta)**9 - 1.5374423738043e+106*cos(theta)**7 + 2.98947128239726e+104*cos(theta)**5 - 2.49746974302194e+102*cos(theta)**3 + 5.7193963580655e+99*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl75_m_minus_53(theta, phi):
    return 2.64668215326668e-97*(1.0 - cos(theta)**2)**26.5*(5.42332236170004e+109*cos(theta)**22 - 8.40796956746784e+109*cos(theta)**20 + 5.43372182931595e+109*cos(theta)**18 - 1.9111711261732e+109*cos(theta)**16 + 4.00944991504867e+108*cos(theta)**14 - 5.17531833006282e+107*cos(theta)**12 + 4.09557565688424e+106*cos(theta)**10 - 1.92180296725538e+105*cos(theta)**8 + 4.98245213732876e+103*cos(theta)**6 - 6.24367435755484e+101*cos(theta)**4 + 2.85969817903275e+99*cos(theta)**2 - 2.01529117620349e+96)*sin(53*phi)

#@torch.jit.script
def Yl75_m_minus_52(theta, phi):
    return 1.43605373791225e-95*(1.0 - cos(theta)**2)**26*(2.35796624421741e+108*cos(theta)**23 - 4.00379503212754e+108*cos(theta)**21 + 2.85985359437682e+108*cos(theta)**19 - 1.12421830951365e+108*cos(theta)**17 + 2.67296661003244e+107*cos(theta)**15 - 3.98101410004832e+106*cos(theta)**13 + 3.72325059716749e+105*cos(theta)**11 - 2.13533663028376e+104*cos(theta)**9 + 7.11778876761252e+102*cos(theta)**7 - 1.24873487151097e+101*cos(theta)**5 + 9.5323272634425e+98*cos(theta)**3 - 2.01529117620349e+96*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl75_m_minus_51(theta, phi):
    return 7.92826527731477e-94*(1.0 - cos(theta)**2)**25.5*(9.82485935090586e+106*cos(theta)**24 - 1.81990683278525e+107*cos(theta)**22 + 1.42992679718841e+107*cos(theta)**20 - 6.24565727507581e+106*cos(theta)**18 + 1.67060413127028e+106*cos(theta)**16 - 2.84358150003451e+105*cos(theta)**14 + 3.10270883097291e+104*cos(theta)**12 - 2.13533663028376e+103*cos(theta)**10 + 8.89723595951565e+101*cos(theta)**8 - 2.08122478585161e+100*cos(theta)**6 + 2.38308181586063e+98*cos(theta)**4 - 1.00764558810174e+96*cos(theta)**2 + 6.61184769095633e+92)*sin(51*phi)

#@torch.jit.script
def Yl75_m_minus_50(theta, phi):
    return 4.44972785087522e-92*(1.0 - cos(theta)**2)**25*(3.92994374036235e+105*cos(theta)**25 - 7.91263840341412e+105*cos(theta)**23 + 6.80917522470671e+105*cos(theta)**21 - 3.28718803951358e+105*cos(theta)**19 + 9.82708312511928e+104*cos(theta)**17 - 1.89572100002301e+104*cos(theta)**15 + 2.38669910074839e+103*cos(theta)**13 - 1.94121511843978e+102*cos(theta)**11 + 9.88581773279516e+100*cos(theta)**9 - 2.9731782655023e+99*cos(theta)**7 + 4.76616363172125e+97*cos(theta)**5 - 3.35881862700582e+95*cos(theta)**3 + 6.61184769095633e+92*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl75_m_minus_49(theta, phi):
    return 2.53673517197357e-90*(1.0 - cos(theta)**2)**24.5*(1.51151682321629e+104*cos(theta)**26 - 3.29693266808922e+104*cos(theta)**24 + 3.09507964759396e+104*cos(theta)**22 - 1.64359401975679e+104*cos(theta)**20 + 5.45949062506627e+103*cos(theta)**18 - 1.18482562501438e+103*cos(theta)**16 + 1.70478507196314e+102*cos(theta)**14 - 1.61767926536648e+101*cos(theta)**12 + 9.88581773279516e+99*cos(theta)**10 - 3.71647283187788e+98*cos(theta)**8 + 7.94360605286875e+96*cos(theta)**6 - 8.39704656751454e+94*cos(theta)**4 + 3.30592384547817e+92*cos(theta)**2 - 2.03441467414041e+89)*sin(49*phi)

#@torch.jit.script
def Yl75_m_minus_48(theta, phi):
    return 1.46780328429843e-88*(1.0 - cos(theta)**2)**24*(5.59821045635662e+102*cos(theta)**27 - 1.31877306723569e+103*cos(theta)**25 + 1.34568680330172e+103*cos(theta)**23 - 7.82663818931805e+102*cos(theta)**21 + 2.87341611845593e+102*cos(theta)**19 - 6.96956250008459e+101*cos(theta)**17 + 1.13652338130876e+101*cos(theta)**15 - 1.24436866566652e+100*cos(theta)**13 + 8.98710702981379e+98*cos(theta)**11 - 4.12941425764209e+97*cos(theta)**9 + 1.13480086469554e+96*cos(theta)**7 - 1.67940931350291e+94*cos(theta)**5 + 1.10197461515939e+92*cos(theta)**3 - 2.03441467414041e+89*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl75_m_minus_47(theta, phi):
    return 8.61389208310165e-87*(1.0 - cos(theta)**2)**23.5*(1.99936087727022e+101*cos(theta)**28 - 5.07220410475264e+101*cos(theta)**26 + 5.6070283470905e+101*cos(theta)**24 - 3.55756281332639e+101*cos(theta)**22 + 1.43670805922796e+101*cos(theta)**20 - 3.87197916671366e+100*cos(theta)**18 + 7.10327113317974e+99*cos(theta)**16 - 8.88834761190374e+98*cos(theta)**14 + 7.48925585817816e+97*cos(theta)**12 - 4.12941425764209e+96*cos(theta)**10 + 1.41850108086942e+95*cos(theta)**8 - 2.79901552250485e+93*cos(theta)**6 + 2.75493653789847e+91*cos(theta)**4 - 1.0172073370702e+89*cos(theta)**2 + 5.90712739297447e+85)*sin(47*phi)

#@torch.jit.script
def Yl75_m_minus_46(theta, phi):
    return 5.12363685351293e-85*(1.0 - cos(theta)**2)**23*(6.89434785265593e+99*cos(theta)**29 - 1.87859411287135e+100*cos(theta)**27 + 2.2428113388362e+100*cos(theta)**25 - 1.54676644057669e+100*cos(theta)**23 + 6.84146694870459e+99*cos(theta)**21 - 2.03788377195456e+99*cos(theta)**19 + 4.17839478422338e+98*cos(theta)**17 - 5.9255650746025e+97*cos(theta)**15 + 5.76096604475243e+96*cos(theta)**13 - 3.75401296149281e+95*cos(theta)**11 + 1.57611231207713e+94*cos(theta)**9 - 3.99859360357835e+92*cos(theta)**7 + 5.50987307579694e+90*cos(theta)**5 - 3.39069112356735e+88*cos(theta)**3 + 5.90712739297447e+85*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl75_m_minus_45(theta, phi):
    return 3.08696462924721e-83*(1.0 - cos(theta)**2)**22.5*(2.29811595088531e+98*cos(theta)**30 - 6.70926468882624e+98*cos(theta)**28 + 8.62619745706231e+98*cos(theta)**26 - 6.44486016906954e+98*cos(theta)**24 + 3.10975770395663e+98*cos(theta)**22 - 1.01894188597728e+98*cos(theta)**20 + 2.32133043567965e+97*cos(theta)**18 - 3.70347817162656e+96*cos(theta)**16 + 4.11497574625173e+95*cos(theta)**14 - 3.12834413457734e+94*cos(theta)**12 + 1.57611231207713e+93*cos(theta)**10 - 4.99824200447294e+91*cos(theta)**8 + 9.1831217929949e+89*cos(theta)**6 - 8.47672780891837e+87*cos(theta)**4 + 2.95356369648724e+85*cos(theta)**2 - 1.62730782175605e+82)*sin(45*phi)

#@torch.jit.script
def Yl75_m_minus_44(theta, phi):
    return 1.88279537695074e-81*(1.0 - cos(theta)**2)**22*(7.41327726092036e+96*cos(theta)**31 - 2.31353954787112e+97*cos(theta)**29 + 3.19488794706012e+97*cos(theta)**27 - 2.57794406762782e+97*cos(theta)**25 + 1.35206856693767e+97*cos(theta)**23 - 4.85210421893943e+96*cos(theta)**21 + 1.22175286088403e+96*cos(theta)**19 - 2.17851657154504e+95*cos(theta)**17 + 2.74331716416782e+94*cos(theta)**15 - 2.40641856505949e+93*cos(theta)**13 + 1.43282937461558e+92*cos(theta)**11 - 5.55360222719216e+90*cos(theta)**9 + 1.31187454185641e+89*cos(theta)**7 - 1.69534556178367e+87*cos(theta)**5 + 9.84521232162413e+84*cos(theta)**3 - 1.62730782175605e+82*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl75_m_minus_43(theta, phi):
    return 1.16185409527301e-79*(1.0 - cos(theta)**2)**21.5*(2.31664914403761e+95*cos(theta)**32 - 7.71179849290373e+95*cos(theta)**30 + 1.14103140966433e+96*cos(theta)**28 - 9.91516949087622e+95*cos(theta)**26 + 5.63361902890694e+95*cos(theta)**24 - 2.20550191769974e+95*cos(theta)**22 + 6.10876430442014e+94*cos(theta)**20 - 1.21028698419169e+94*cos(theta)**18 + 1.71457322760489e+93*cos(theta)**16 - 1.71887040361392e+92*cos(theta)**14 + 1.19402447884631e+91*cos(theta)**12 - 5.55360222719216e+89*cos(theta)**10 + 1.63984317732052e+88*cos(theta)**8 - 2.82557593630612e+86*cos(theta)**6 + 2.46130308040603e+84*cos(theta)**4 - 8.13653910878027e+81*cos(theta)**2 + 4.27339238906527e+78)*sin(43*phi)

#@torch.jit.script
def Yl75_m_minus_42(theta, phi):
    return 7.25019298454061e-78*(1.0 - cos(theta)**2)**21*(7.0201489213261e+93*cos(theta)**33 - 2.48767693319475e+94*cos(theta)**31 + 3.93459106780802e+94*cos(theta)**29 - 3.67228499662082e+94*cos(theta)**27 + 2.25344761156278e+94*cos(theta)**25 - 9.58913877260756e+93*cos(theta)**23 + 2.90893538305721e+93*cos(theta)**21 - 6.36993149574572e+92*cos(theta)**19 + 1.00857248682641e+92*cos(theta)**17 - 1.14591360240928e+91*cos(theta)**15 + 9.18480368343318e+89*cos(theta)**13 - 5.04872929744741e+88*cos(theta)**11 + 1.82204797480058e+87*cos(theta)**9 - 4.03653705186589e+85*cos(theta)**7 + 4.92260616081206e+83*cos(theta)**5 - 2.71217970292676e+81*cos(theta)**3 + 4.27339238906527e+78*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl75_m_minus_41(theta, phi):
    return 4.57279735708286e-76*(1.0 - cos(theta)**2)**20.5*(2.06474968274297e+92*cos(theta)**34 - 7.7739904162336e+92*cos(theta)**32 + 1.31153035593601e+93*cos(theta)**30 - 1.31153035593601e+93*cos(theta)**28 + 8.66710619831838e+92*cos(theta)**26 - 3.99547448858649e+92*cos(theta)**24 + 1.3222433559351e+92*cos(theta)**22 - 3.18496574787286e+91*cos(theta)**20 + 5.60318048236892e+90*cos(theta)**18 - 7.16196001505801e+89*cos(theta)**16 + 6.56057405959513e+88*cos(theta)**14 - 4.20727441453951e+87*cos(theta)**12 + 1.82204797480058e+86*cos(theta)**10 - 5.04567131483236e+84*cos(theta)**8 + 8.20434360135344e+82*cos(theta)**6 - 6.78044925731689e+80*cos(theta)**4 + 2.13669619453263e+78*cos(theta)**2 - 1.07425650806065e+75)*sin(41*phi)

#@torch.jit.script
def Yl75_m_minus_40(theta, phi):
    return 2.91370093207783e-74*(1.0 - cos(theta)**2)**20*(5.89928480783706e+90*cos(theta)**35 - 2.35575467158594e+91*cos(theta)**33 + 4.23074308366454e+91*cos(theta)**31 - 4.52251846874486e+91*cos(theta)**29 + 3.21003933271051e+91*cos(theta)**27 - 1.59818979543459e+91*cos(theta)**25 + 5.74888415623955e+90*cos(theta)**23 - 1.51665035612993e+90*cos(theta)**21 + 2.94904235914154e+89*cos(theta)**19 - 4.21291765591648e+88*cos(theta)**17 + 4.37371603973009e+87*cos(theta)**15 - 3.23636493426116e+86*cos(theta)**13 + 1.65640724981871e+85*cos(theta)**11 - 5.60630146092485e+83*cos(theta)**9 + 1.17204908590763e+82*cos(theta)**7 - 1.35608985146338e+80*cos(theta)**5 + 7.12232064844211e+77*cos(theta)**3 - 1.07425650806065e+75*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl75_m_minus_39(theta, phi):
    return 1.87475768896644e-72*(1.0 - cos(theta)**2)**19.5*(1.63869022439918e+89*cos(theta)**36 - 6.92869021054688e+89*cos(theta)**34 + 1.32210721364517e+90*cos(theta)**32 - 1.50750615624829e+90*cos(theta)**30 + 1.14644261882518e+90*cos(theta)**28 - 6.14688382859459e+89*cos(theta)**26 + 2.39536839843314e+89*cos(theta)**24 - 6.89386525513606e+88*cos(theta)**22 + 1.47452117957077e+88*cos(theta)**20 - 2.34050980884249e+87*cos(theta)**18 + 2.7335725248313e+86*cos(theta)**16 - 2.31168923875797e+85*cos(theta)**14 + 1.38033937484892e+84*cos(theta)**12 - 5.60630146092485e+82*cos(theta)**10 + 1.46506135738454e+81*cos(theta)**8 - 2.26014975243896e+79*cos(theta)**6 + 1.78058016211053e+77*cos(theta)**4 - 5.37128254030325e+74*cos(theta)**2 + 2.59482248323829e+71)*sin(39*phi)

#@torch.jit.script
def Yl75_m_minus_38(theta, phi):
    return 1.21758259444216e-70*(1.0 - cos(theta)**2)**19*(4.42889249837617e+87*cos(theta)**37 - 1.97962577444196e+88*cos(theta)**35 + 4.00638549589445e+88*cos(theta)**33 - 4.86292308467189e+88*cos(theta)**31 + 3.95325040974201e+88*cos(theta)**29 - 2.27662364022022e+88*cos(theta)**27 + 9.58147359373258e+87*cos(theta)**25 - 2.99733271962437e+87*cos(theta)**23 + 7.02152942652747e+86*cos(theta)**21 - 1.23184726781184e+86*cos(theta)**19 + 1.60798383813606e+85*cos(theta)**17 - 1.54112615917198e+84*cos(theta)**15 + 1.06179951911455e+83*cos(theta)**13 - 5.09663769174986e+81*cos(theta)**11 + 1.62784595264949e+80*cos(theta)**9 - 3.22878536062709e+78*cos(theta)**7 + 3.56116032422106e+76*cos(theta)**5 - 1.79042751343442e+74*cos(theta)**3 + 2.59482248323829e+71*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl75_m_minus_37(theta, phi):
    return 7.97865067865162e-69*(1.0 - cos(theta)**2)**18.5*(1.16549802588847e+86*cos(theta)**38 - 5.49896048456101e+86*cos(theta)**36 + 1.17834867526307e+87*cos(theta)**34 - 1.51966346395996e+87*cos(theta)**32 + 1.31775013658067e+87*cos(theta)**30 - 8.13079871507221e+86*cos(theta)**28 + 3.68518215143561e+86*cos(theta)**26 - 1.24888863317682e+86*cos(theta)**24 + 3.19160428478521e+85*cos(theta)**22 - 6.15923633905918e+84*cos(theta)**20 + 8.93324354520034e+83*cos(theta)**18 - 9.63203849482489e+82*cos(theta)**16 + 7.58428227938968e+81*cos(theta)**14 - 4.24719807645822e+80*cos(theta)**12 + 1.62784595264949e+79*cos(theta)**10 - 4.03598170078386e+77*cos(theta)**8 + 5.93526720703509e+75*cos(theta)**6 - 4.47606878358604e+73*cos(theta)**4 + 1.29741124161914e+71*cos(theta)**2 - 6.04290284871515e+67)*sin(37*phi)

#@torch.jit.script
def Yl75_m_minus_36(theta, phi):
    return 5.27315777817911e-67*(1.0 - cos(theta)**2)**18*(2.98845647663709e+84*cos(theta)**39 - 1.48620553636784e+85*cos(theta)**37 + 3.36671050075164e+85*cos(theta)**35 - 4.60504079987868e+85*cos(theta)**33 + 4.25080689219571e+85*cos(theta)**31 - 2.80372369485249e+85*cos(theta)**29 + 1.36488227830948e+85*cos(theta)**27 - 4.99555453270729e+84*cos(theta)**25 + 1.38765403686314e+84*cos(theta)**23 - 2.93296968526628e+83*cos(theta)**21 + 4.70170712905281e+82*cos(theta)**19 - 5.66590499695582e+81*cos(theta)**17 + 5.05618818625978e+80*cos(theta)**15 - 3.2670754434294e+79*cos(theta)**13 + 1.47985995695408e+78*cos(theta)**11 - 4.48442411198207e+76*cos(theta)**9 + 8.47895315290728e+74*cos(theta)**7 - 8.95213756717209e+72*cos(theta)**5 + 4.32470413873048e+70*cos(theta)**3 - 6.04290284871515e+67*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl75_m_minus_35(theta, phi):
    return 3.51368035987702e-65*(1.0 - cos(theta)**2)**17.5*(7.47114119159273e+82*cos(theta)**40 - 3.911067200968e+83*cos(theta)**38 + 9.351973613199e+83*cos(theta)**36 - 1.3544237646702e+84*cos(theta)**34 + 1.32837715381116e+84*cos(theta)**32 - 9.34574564950829e+83*cos(theta)**30 + 4.87457956539101e+83*cos(theta)**28 - 1.92136712796434e+83*cos(theta)**26 + 5.78189182026307e+82*cos(theta)**24 - 1.3331680387574e+82*cos(theta)**22 + 2.35085356452641e+81*cos(theta)**20 - 3.14772499830879e+80*cos(theta)**18 + 3.16011761641237e+79*cos(theta)**16 - 2.33362531673528e+78*cos(theta)**14 + 1.23321663079507e+77*cos(theta)**12 - 4.48442411198207e+75*cos(theta)**10 + 1.05986914411341e+74*cos(theta)**8 - 1.49202292786201e+72*cos(theta)**6 + 1.08117603468262e+70*cos(theta)**4 - 3.02145142435758e+67*cos(theta)**2 + 1.36101415511602e+64)*sin(35*phi)

#@torch.jit.script
def Yl75_m_minus_34(theta, phi):
    return 2.35966593012546e-63*(1.0 - cos(theta)**2)**17*(1.82222955892506e+81*cos(theta)**41 - 1.00283774383795e+82*cos(theta)**39 + 2.52756043599973e+82*cos(theta)**37 - 3.869782184772e+82*cos(theta)**35 + 4.02538531457927e+82*cos(theta)**33 - 3.01475666113171e+82*cos(theta)**31 + 1.68088950530725e+82*cos(theta)**29 - 7.11617454801608e+81*cos(theta)**27 + 2.31275672810523e+81*cos(theta)**25 - 5.79638277720608e+80*cos(theta)**23 + 1.11945407834591e+80*cos(theta)**21 - 1.65669736753094e+79*cos(theta)**19 + 1.85889271553669e+78*cos(theta)**17 - 1.55575021115686e+77*cos(theta)**15 + 9.48628177534669e+75*cos(theta)**13 - 4.07674919271097e+74*cos(theta)**11 + 1.17763238234823e+73*cos(theta)**9 - 2.13146132551716e+71*cos(theta)**7 + 2.16235206936524e+69*cos(theta)**5 - 1.00715047478586e+67*cos(theta)**3 + 1.36101415511602e+64*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl75_m_minus_33(theta, phi):
    return 1.59657166064091e-61*(1.0 - cos(theta)**2)**16.5*(4.33864180696442e+79*cos(theta)**42 - 2.50709435959487e+80*cos(theta)**40 + 6.65147483157824e+80*cos(theta)**38 - 1.07493949577e+81*cos(theta)**36 + 1.1839368572292e+81*cos(theta)**34 - 9.42111456603658e+80*cos(theta)**32 + 5.60296501769082e+80*cos(theta)**30 - 2.54149091000574e+80*cos(theta)**28 + 8.8952181850201e+79*cos(theta)**26 - 2.41515949050253e+79*cos(theta)**24 + 5.08842762884503e+78*cos(theta)**22 - 8.2834868376547e+77*cos(theta)**20 + 1.03271817529816e+77*cos(theta)**18 - 9.72343881973035e+75*cos(theta)**16 + 6.77591555381906e+74*cos(theta)**14 - 3.39729099392581e+73*cos(theta)**12 + 1.17763238234823e+72*cos(theta)**10 - 2.66432665689645e+70*cos(theta)**8 + 3.60392011560873e+68*cos(theta)**6 - 2.51787618696465e+66*cos(theta)**4 + 6.80507077558012e+63*cos(theta)**2 - 2.97294485608568e+60)*sin(33*phi)

#@torch.jit.script
def Yl75_m_minus_32(theta, phi):
    return 1.08801409539383e-59*(1.0 - cos(theta)**2)**16*(1.00898646673591e+78*cos(theta)**43 - 6.11486429169482e+78*cos(theta)**41 + 1.70550636707134e+79*cos(theta)**39 - 2.90524188045946e+79*cos(theta)**37 + 3.38267673494056e+79*cos(theta)**35 - 2.85488320182927e+79*cos(theta)**33 + 1.80740807022285e+79*cos(theta)**31 - 8.76376175864049e+78*cos(theta)**29 + 3.29452525371115e+78*cos(theta)**27 - 9.66063796201013e+77*cos(theta)**25 + 2.21235983862827e+77*cos(theta)**23 - 3.94451754174034e+76*cos(theta)**21 + 5.43535881735873e+75*cos(theta)**19 - 5.71966989395903e+74*cos(theta)**17 + 4.51727703587938e+73*cos(theta)**15 - 2.61330076455832e+72*cos(theta)**13 + 1.07057489304385e+71*cos(theta)**11 - 2.96036295210717e+69*cos(theta)**9 + 5.14845730801247e+67*cos(theta)**7 - 5.03575237392929e+65*cos(theta)**5 + 2.26835692519338e+63*cos(theta)**3 - 2.97294485608568e+60*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl75_m_minus_31(theta, phi):
    return 7.46539426602489e-58*(1.0 - cos(theta)**2)**15.5*(2.29315106076343e+76*cos(theta)**44 - 1.45592006945115e+77*cos(theta)**42 + 4.26376591767836e+77*cos(theta)**40 - 7.64537336963016e+77*cos(theta)**38 + 9.39632426372378e+77*cos(theta)**36 - 8.39671529949785e+77*cos(theta)**34 + 5.64815021944639e+77*cos(theta)**32 - 2.92125391954683e+77*cos(theta)**30 + 1.1766161620397e+77*cos(theta)**28 - 3.71562998538851e+76*cos(theta)**26 + 9.21816599428448e+75*cos(theta)**24 - 1.79296251897288e+75*cos(theta)**22 + 2.71767940867936e+74*cos(theta)**20 - 3.1775943855328e+73*cos(theta)**18 + 2.82329814742461e+72*cos(theta)**16 - 1.86664340325594e+71*cos(theta)**14 + 8.92145744203207e+69*cos(theta)**12 - 2.96036295210717e+68*cos(theta)**10 + 6.43557163501559e+66*cos(theta)**8 - 8.39292062321549e+64*cos(theta)**6 + 5.67089231298344e+62*cos(theta)**4 - 1.48647242804284e+60*cos(theta)**2 + 6.31466621938335e+56)*sin(31*phi)

#@torch.jit.script
def Yl75_m_minus_30(theta, phi):
    return 5.15598848020563e-56*(1.0 - cos(theta)**2)**15*(5.09589124614096e+74*cos(theta)**45 - 3.38586062663057e+75*cos(theta)**43 + 1.03994290675082e+76*cos(theta)**41 - 1.96035214605902e+76*cos(theta)**39 + 2.53954709830372e+76*cos(theta)**37 - 2.39906151414224e+76*cos(theta)**35 + 1.71156067255951e+76*cos(theta)**33 - 9.42339974047365e+75*cos(theta)**31 + 4.05729711048171e+75*cos(theta)**29 - 1.3761592538476e+75*cos(theta)**27 + 3.68726639771379e+74*cos(theta)**25 - 7.79548921292556e+73*cos(theta)**23 + 1.29413305175208e+73*cos(theta)**21 - 1.67241809764884e+72*cos(theta)**19 + 1.66076361613212e+71*cos(theta)**17 - 1.24442893550396e+70*cos(theta)**15 + 6.8626595707939e+68*cos(theta)**13 - 2.69123904737016e+67*cos(theta)**11 + 7.15063515001732e+65*cos(theta)**9 - 1.19898866045936e+64*cos(theta)**7 + 1.13417846259669e+62*cos(theta)**5 - 4.95490809347614e+59*cos(theta)**3 + 6.31466621938335e+56*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl75_m_minus_29(theta, phi):
    return 3.58331925893721e-54*(1.0 - cos(theta)**2)**14.5*(1.10780244481325e+73*cos(theta)**46 - 7.69513778779676e+73*cos(theta)**44 + 2.4760545398829e+74*cos(theta)**42 - 4.90088036514754e+74*cos(theta)**40 + 6.68301867974664e+74*cos(theta)**38 - 6.66405976150623e+74*cos(theta)**36 + 5.03400197811621e+74*cos(theta)**34 - 2.94481241889802e+74*cos(theta)**32 + 1.35243237016057e+74*cos(theta)**30 - 4.91485447802713e+73*cos(theta)**28 + 1.41817938373607e+73*cos(theta)**26 - 3.24812050538565e+72*cos(theta)**24 + 5.88242296250945e+71*cos(theta)**22 - 8.3620904882442e+70*cos(theta)**20 + 9.22646453406735e+69*cos(theta)**18 - 7.77768084689975e+68*cos(theta)**16 + 4.90189969342421e+67*cos(theta)**14 - 2.2426992061418e+66*cos(theta)**12 + 7.15063515001732e+64*cos(theta)**10 - 1.49873582557419e+63*cos(theta)**8 + 1.89029743766115e+61*cos(theta)**6 - 1.23872702336903e+59*cos(theta)**4 + 3.15733310969168e+56*cos(theta)**2 - 1.30738431043134e+53)*sin(29*phi)

#@torch.jit.script
def Yl75_m_minus_28(theta, phi):
    return 2.50525018198317e-52*(1.0 - cos(theta)**2)**14*(2.35702647832607e+71*cos(theta)**47 - 1.71003061951039e+72*cos(theta)**45 + 5.7582663718207e+72*cos(theta)**43 - 1.19533667442623e+73*cos(theta)**41 + 1.71359453326837e+73*cos(theta)**39 - 1.80109723283952e+73*cos(theta)**37 + 1.43828627946178e+73*cos(theta)**35 - 8.92367399666065e+72*cos(theta)**33 + 4.3626850650341e+72*cos(theta)**31 - 1.69477740621625e+72*cos(theta)**29 + 5.25251623605953e+71*cos(theta)**27 - 1.29924820215426e+71*cos(theta)**25 + 2.55757520109106e+70*cos(theta)**23 - 3.98194785154486e+69*cos(theta)**21 + 4.85603396529861e+68*cos(theta)**19 - 4.57510638052927e+67*cos(theta)**17 + 3.26793312894947e+66*cos(theta)**15 - 1.72515323549369e+65*cos(theta)**13 + 6.50057740910666e+63*cos(theta)**11 - 1.66526202841577e+62*cos(theta)**9 + 2.70042491094449e+60*cos(theta)**7 - 2.47745404673807e+58*cos(theta)**5 + 1.05244436989723e+56*cos(theta)**3 - 1.30738431043134e+53*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl75_m_minus_27(theta, phi):
    return 1.76153117420814e-50*(1.0 - cos(theta)**2)**13.5*(4.91047182984598e+69*cos(theta)**48 - 3.71745786850085e+70*cos(theta)**46 + 1.30869690268652e+71*cos(theta)**44 - 2.84603970101483e+71*cos(theta)**42 + 4.28398633317092e+71*cos(theta)**40 - 4.739729560104e+71*cos(theta)**38 + 3.9952396651716e+71*cos(theta)**36 - 2.62460999901784e+71*cos(theta)**34 + 1.36333908282316e+71*cos(theta)**32 - 5.64925802072084e+70*cos(theta)**30 + 1.87589865573555e+70*cos(theta)**28 - 4.99710846982408e+69*cos(theta)**26 + 1.06565633378794e+69*cos(theta)**24 - 1.80997629615675e+68*cos(theta)**22 + 2.4280169826493e+67*cos(theta)**20 - 2.5417257669607e+66*cos(theta)**18 + 2.04245820559342e+65*cos(theta)**16 - 1.23225231106692e+64*cos(theta)**14 + 5.41714784092221e+62*cos(theta)**12 - 1.66526202841577e+61*cos(theta)**10 + 3.37553113868062e+59*cos(theta)**8 - 4.12909007789678e+57*cos(theta)**6 + 2.63111092474306e+55*cos(theta)**4 - 6.53692155215668e+52*cos(theta)**2 + 2.6443857411637e+49)*sin(27*phi)

#@torch.jit.script
def Yl75_m_minus_26(theta, phi):
    return 1.24534149550957e-48*(1.0 - cos(theta)**2)**13*(1.00213710813183e+68*cos(theta)**49 - 7.90948482659755e+68*cos(theta)**47 + 2.90821533930339e+69*cos(theta)**45 - 6.61869697910426e+69*cos(theta)**43 + 1.04487471540754e+70*cos(theta)**41 - 1.21531527182154e+70*cos(theta)**39 + 1.07979450410043e+70*cos(theta)**37 - 7.49888571147954e+69*cos(theta)**35 + 4.13133055400956e+69*cos(theta)**33 - 1.82234129700672e+69*cos(theta)**31 + 6.46861605426051e+68*cos(theta)**29 - 1.85078091474966e+68*cos(theta)**27 + 4.26262533515177e+67*cos(theta)**25 - 7.86946215720327e+66*cos(theta)**23 + 1.15619856316633e+66*cos(theta)**21 - 1.33775040366353e+65*cos(theta)**19 + 1.20144600329025e+64*cos(theta)**17 - 8.21501540711281e+62*cos(theta)**15 + 4.1670368007094e+61*cos(theta)**13 - 1.51387457128706e+60*cos(theta)**11 + 3.75059015408958e+58*cos(theta)**9 - 5.89870011128111e+56*cos(theta)**7 + 5.26222184948613e+54*cos(theta)**5 - 2.17897385071889e+52*cos(theta)**3 + 2.6443857411637e+49*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl75_m_minus_25(theta, phi):
    return 8.84981410777198e-47*(1.0 - cos(theta)**2)**12.5*(2.00427421626367e+66*cos(theta)**50 - 1.64780933887449e+67*cos(theta)**48 + 6.32220725935519e+67*cos(theta)**46 - 1.50424931343279e+68*cos(theta)**44 + 2.48779694144653e+68*cos(theta)**42 - 3.03828817955385e+68*cos(theta)**40 + 2.84156448447482e+68*cos(theta)**38 - 2.08302380874432e+68*cos(theta)**36 + 1.21509722176752e+68*cos(theta)**34 - 5.69481655314601e+67*cos(theta)**32 + 2.15620535142017e+67*cos(theta)**30 - 6.60993183839164e+66*cos(theta)**28 + 1.63947128275068e+66*cos(theta)**26 - 3.27894256550136e+65*cos(theta)**24 + 5.25544801439243e+64*cos(theta)**22 - 6.68875201831764e+63*cos(theta)**20 + 6.67470001827916e+62*cos(theta)**18 - 5.13438462944551e+61*cos(theta)**16 + 2.97645485764957e+60*cos(theta)**14 - 1.26156214273922e+59*cos(theta)**12 + 3.75059015408958e+57*cos(theta)**10 - 7.37337513910139e+55*cos(theta)**8 + 8.77036974914354e+53*cos(theta)**6 - 5.44743462679723e+51*cos(theta)**4 + 1.32219287058185e+49*cos(theta)**2 - 5.23640740824496e+45)*sin(25*phi)

#@torch.jit.script
def Yl75_m_minus_24(theta, phi):
    return 6.32003140565624e-45*(1.0 - cos(theta)**2)**12*(3.92994944365425e+64*cos(theta)**51 - 3.36287620178467e+65*cos(theta)**49 + 1.34515048071387e+66*cos(theta)**47 - 3.34277625207286e+66*cos(theta)**45 + 5.78557428243379e+66*cos(theta)**43 - 7.41045897452158e+66*cos(theta)**41 + 7.28606278070467e+66*cos(theta)**39 - 5.62979407768734e+66*cos(theta)**37 + 3.47170634790719e+66*cos(theta)**35 - 1.72570198580182e+66*cos(theta)**33 + 6.95550113361345e+65*cos(theta)**31 - 2.2792868408247e+65*cos(theta)**29 + 6.07211586203956e+64*cos(theta)**27 - 1.31157702620055e+64*cos(theta)**25 + 2.28497739756193e+63*cos(theta)**23 - 3.18512000872269e+62*cos(theta)**21 + 3.51300000962061e+61*cos(theta)**19 - 3.020226252615e+60*cos(theta)**17 + 1.98430323843305e+59*cos(theta)**15 - 9.70432417491708e+57*cos(theta)**13 + 3.4096274128087e+56*cos(theta)**11 - 8.19263904344599e+54*cos(theta)**9 + 1.25290996416336e+53*cos(theta)**7 - 1.08948692535945e+51*cos(theta)**5 + 4.40730956860617e+48*cos(theta)**3 - 5.23640740824496e+45*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl75_m_minus_23(theta, phi):
    return 4.53459500720562e-43*(1.0 - cos(theta)**2)**11.5*(7.55759508395047e+62*cos(theta)**52 - 6.72575240356935e+63*cos(theta)**50 + 2.80239683482056e+64*cos(theta)**48 - 7.26690489581056e+64*cos(theta)**46 + 1.31490324600768e+65*cos(theta)**44 - 1.76439499393371e+65*cos(theta)**42 + 1.82151569517617e+65*cos(theta)**40 - 1.48152475728614e+65*cos(theta)**38 + 9.64362874418665e+64*cos(theta)**36 - 5.07559407588771e+64*cos(theta)**34 + 2.1735941042542e+64*cos(theta)**32 - 7.59762280274901e+63*cos(theta)**30 + 2.16861280787127e+63*cos(theta)**28 - 5.04452702384825e+62*cos(theta)**26 + 9.52073915650803e+61*cos(theta)**24 - 1.44778182214668e+61*cos(theta)**22 + 1.7565000048103e+60*cos(theta)**20 - 1.677903473675e+59*cos(theta)**18 + 1.24018952402065e+58*cos(theta)**16 - 6.93166012494077e+56*cos(theta)**14 + 2.84135617734059e+55*cos(theta)**12 - 8.19263904344599e+53*cos(theta)**10 + 1.5661374552042e+52*cos(theta)**8 - 1.81581154226574e+50*cos(theta)**6 + 1.10182739215154e+48*cos(theta)**4 - 2.61820370412248e+45*cos(theta)**2 + 1.01717315622474e+42)*sin(23*phi)

#@torch.jit.script
def Yl75_m_minus_22(theta, phi):
    return 3.26805591233487e-41*(1.0 - cos(theta)**2)**11*(1.42596133659443e+61*cos(theta)**53 - 1.31877498109203e+62*cos(theta)**51 + 5.71917721391951e+62*cos(theta)**49 - 1.54614997783203e+63*cos(theta)**47 + 2.9220072133504e+63*cos(theta)**45 - 4.10324417193886e+63*cos(theta)**43 + 4.44272120774675e+63*cos(theta)**41 - 3.79878142893883e+63*cos(theta)**39 + 2.60638614707747e+63*cos(theta)**37 - 1.45016973596792e+63*cos(theta)**35 + 6.58664880077031e+62*cos(theta)**33 - 2.45084606540291e+62*cos(theta)**31 + 7.47797519955611e+61*cos(theta)**29 - 1.86834334216602e+61*cos(theta)**27 + 3.80829566260321e+60*cos(theta)**25 - 6.29470357455076e+59*cos(theta)**23 + 8.36428573719193e+58*cos(theta)**21 - 8.83107091407896e+57*cos(theta)**19 + 7.29523249423914e+56*cos(theta)**17 - 4.62110674996052e+55*cos(theta)**15 + 2.1856585979543e+54*cos(theta)**13 - 7.44785367585999e+52*cos(theta)**11 + 1.74015272800467e+51*cos(theta)**9 - 2.59401648895106e+49*cos(theta)**7 + 2.20365478430309e+47*cos(theta)**5 - 8.72734568040827e+44*cos(theta)**3 + 1.01717315622474e+42*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl75_m_minus_21(theta, phi):
    return 2.36522371709142e-39*(1.0 - cos(theta)**2)**10.5*(2.64066914184154e+59*cos(theta)**54 - 2.53610573286929e+60*cos(theta)**52 + 1.1438354427839e+61*cos(theta)**50 - 3.22114578715007e+61*cos(theta)**48 + 6.35218959424e+61*cos(theta)**46 - 9.32555493622468e+61*cos(theta)**44 + 1.05779076374923e+62*cos(theta)**42 - 9.49695357234707e+61*cos(theta)**40 + 6.85891091336177e+61*cos(theta)**38 - 4.02824926657755e+61*cos(theta)**36 + 1.93724964728539e+61*cos(theta)**34 - 7.65889395438408e+60*cos(theta)**32 + 2.49265839985204e+60*cos(theta)**30 - 6.67265479345007e+59*cos(theta)**28 + 1.46472910100123e+59*cos(theta)**26 - 2.62279315606282e+58*cos(theta)**24 + 3.80194806235997e+57*cos(theta)**22 - 4.41553545703948e+56*cos(theta)**20 + 4.05290694124397e+55*cos(theta)**18 - 2.88819171872532e+54*cos(theta)**16 + 1.5611847128245e+53*cos(theta)**14 - 6.20654472988333e+51*cos(theta)**12 + 1.74015272800467e+50*cos(theta)**10 - 3.24252061118883e+48*cos(theta)**8 + 3.67275797383848e+46*cos(theta)**6 - 2.18183642010207e+44*cos(theta)**4 + 5.0858657811237e+41*cos(theta)**2 - 1.94191133299874e+38)*sin(21*phi)

#@torch.jit.script
def Yl75_m_minus_20(theta, phi):
    return 1.71865690189719e-37*(1.0 - cos(theta)**2)**10*(4.80121662153006e+57*cos(theta)**55 - 4.78510515635714e+58*cos(theta)**53 + 2.24281459369393e+59*cos(theta)**51 - 6.57376691255116e+59*cos(theta)**49 + 1.35152970090213e+60*cos(theta)**47 - 2.07234554138326e+60*cos(theta)**45 + 2.45997852034704e+60*cos(theta)**43 - 2.31633013959685e+60*cos(theta)**41 + 1.7586951059902e+60*cos(theta)**39 - 1.08871601799393e+60*cos(theta)**37 + 5.53499899224396e+59*cos(theta)**35 - 2.32087695587396e+59*cos(theta)**33 + 8.0408335479098e+58*cos(theta)**31 - 2.30091544601727e+58*cos(theta)**29 + 5.42492259630087e+57*cos(theta)**27 - 1.04911726242513e+57*cos(theta)**25 + 1.65302089667825e+56*cos(theta)**23 - 2.10263593192356e+55*cos(theta)**21 + 2.13310891644419e+54*cos(theta)**19 - 1.69893630513254e+53*cos(theta)**17 + 1.04078980854967e+52*cos(theta)**15 - 4.77426517683333e+50*cos(theta)**13 + 1.58195702545879e+49*cos(theta)**11 - 3.6028006790987e+47*cos(theta)**9 + 5.24679710548354e+45*cos(theta)**7 - 4.36367284020413e+43*cos(theta)**5 + 1.6952885937079e+41*cos(theta)**3 - 1.94191133299874e+38*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl75_m_minus_19(theta, phi):
    return 1.25355964465416e-35*(1.0 - cos(theta)**2)**9.5*(8.57360110987511e+55*cos(theta)**56 - 8.86130584510582e+56*cos(theta)**54 + 4.31310498787294e+57*cos(theta)**52 - 1.31475338251023e+58*cos(theta)**50 + 2.81568687687943e+58*cos(theta)**48 - 4.50509900300709e+58*cos(theta)**46 + 5.590860273516e+58*cos(theta)**44 - 5.51507176094487e+58*cos(theta)**42 + 4.39673776497549e+58*cos(theta)**40 - 2.86504215261561e+58*cos(theta)**38 + 1.53749972006777e+58*cos(theta)**36 - 6.82610869374695e+57*cos(theta)**34 + 2.51276048372181e+57*cos(theta)**32 - 7.66971815339088e+56*cos(theta)**30 + 1.93747235582174e+56*cos(theta)**28 - 4.0350663939428e+55*cos(theta)**26 + 6.88758706949269e+54*cos(theta)**24 - 9.557436054198e+53*cos(theta)**22 + 1.0665544582221e+53*cos(theta)**20 - 9.43853502851413e+51*cos(theta)**18 + 6.50493630343541e+50*cos(theta)**16 - 3.41018941202381e+49*cos(theta)**14 + 1.31829752121566e+48*cos(theta)**12 - 3.6028006790987e+46*cos(theta)**10 + 6.55849638185443e+44*cos(theta)**8 - 7.27278806700689e+42*cos(theta)**6 + 4.23822148426975e+40*cos(theta)**4 - 9.7095566649937e+37*cos(theta)**2 + 3.65020927255402e+34)*sin(19*phi)

#@torch.jit.script
def Yl75_m_minus_18(theta, phi):
    return 9.17585109498617e-34*(1.0 - cos(theta)**2)**9*(1.50414054559213e+54*cos(theta)**57 - 1.61114651729197e+55*cos(theta)**55 + 8.1379339393829e+55*cos(theta)**53 - 2.57794780884359e+56*cos(theta)**51 + 5.74629974873353e+56*cos(theta)**49 - 9.58531702767466e+56*cos(theta)**47 + 1.24241339411467e+57*cos(theta)**45 - 1.28257482812671e+57*cos(theta)**43 + 1.07237506462817e+57*cos(theta)**41 - 7.34626192978362e+56*cos(theta)**39 + 4.1554046488318e+56*cos(theta)**37 - 1.95031676964199e+56*cos(theta)**35 + 7.61442570824791e+55*cos(theta)**33 - 2.47410263012609e+55*cos(theta)**31 + 6.680939158006e+54*cos(theta)**29 - 1.49446903479363e+54*cos(theta)**27 + 2.75503482779708e+53*cos(theta)**25 - 4.15540698008609e+52*cos(theta)**23 + 5.07883075343855e+51*cos(theta)**21 - 4.96765001500743e+50*cos(theta)**19 + 3.82643311966789e+49*cos(theta)**17 - 2.27345960801587e+48*cos(theta)**15 + 1.01407501631974e+47*cos(theta)**13 - 3.27527334463518e+45*cos(theta)**11 + 7.28721820206047e+43*cos(theta)**9 - 1.03896972385813e+42*cos(theta)**7 + 8.4764429685395e+39*cos(theta)**5 - 3.23651888833123e+37*cos(theta)**3 + 3.65020927255402e+34*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl75_m_minus_17(theta, phi):
    return 6.73909887487811e-32*(1.0 - cos(theta)**2)**8.5*(2.59334576826228e+52*cos(theta)**58 - 2.87704735230709e+53*cos(theta)**56 + 1.50702480358943e+54*cos(theta)**54 - 4.95759194008383e+54*cos(theta)**52 + 1.14925994974671e+55*cos(theta)**50 - 1.99694104743222e+55*cos(theta)**48 + 2.70089868285797e+55*cos(theta)**46 - 2.91494279119708e+55*cos(theta)**44 + 2.5532739634004e+55*cos(theta)**42 - 1.8365654824459e+55*cos(theta)**40 + 1.09352753916626e+55*cos(theta)**38 - 5.41754658233885e+54*cos(theta)**36 + 2.23953697301409e+54*cos(theta)**34 - 7.73157071914404e+53*cos(theta)**32 + 2.22697971933533e+53*cos(theta)**30 - 5.33738940997724e+52*cos(theta)**28 + 1.05962877992195e+52*cos(theta)**26 - 1.73141957503587e+51*cos(theta)**24 + 2.30855943338116e+50*cos(theta)**22 - 2.48382500750372e+49*cos(theta)**20 + 2.12579617759327e+48*cos(theta)**18 - 1.42091225500992e+47*cos(theta)**16 + 7.24339297371242e+45*cos(theta)**14 - 2.72939445386265e+44*cos(theta)**12 + 7.28721820206047e+42*cos(theta)**10 - 1.29871215482266e+41*cos(theta)**8 + 1.41274049475658e+39*cos(theta)**6 - 8.09129722082808e+36*cos(theta)**4 + 1.82510463627701e+34*cos(theta)**2 - 6.76716587421954e+30)*sin(17*phi)

#@torch.jit.script
def Yl75_m_minus_16(theta, phi):
    return 4.96502852345423e-30*(1.0 - cos(theta)**2)**8*(4.39550130213947e+50*cos(theta)**59 - 5.04745149527559e+51*cos(theta)**57 + 2.74004509743532e+52*cos(theta)**55 - 9.35394705676195e+52*cos(theta)**53 + 2.25345088185629e+53*cos(theta)**51 - 4.07538989271882e+53*cos(theta)**49 + 5.746592942251e+53*cos(theta)**47 - 6.47765064710462e+53*cos(theta)**45 + 5.93784642651257e+53*cos(theta)**43 - 4.47942800596562e+53*cos(theta)**41 + 2.80391676709298e+53*cos(theta)**39 - 1.4642017790105e+53*cos(theta)**37 + 6.39867706575455e+52*cos(theta)**35 - 2.34290021792244e+52*cos(theta)**33 + 7.18380554624301e+51*cos(theta)**31 - 1.8404791068887e+51*cos(theta)**29 + 3.92455103674797e+50*cos(theta)**27 - 6.92567830014348e+49*cos(theta)**25 + 1.00372149277442e+49*cos(theta)**23 - 1.18277381309701e+48*cos(theta)**21 + 1.11884009347014e+47*cos(theta)**19 - 8.35830738241129e+45*cos(theta)**17 + 4.82892864914161e+44*cos(theta)**15 - 2.09953419527896e+43*cos(theta)**13 + 6.62474382005498e+41*cos(theta)**11 - 1.44301350535851e+40*cos(theta)**9 + 2.01820070679512e+38*cos(theta)**7 - 1.61825944416562e+36*cos(theta)**5 + 6.08368212092337e+33*cos(theta)**3 - 6.76716587421954e+30*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl75_m_minus_15(theta, phi):
    return 3.66874958239696e-28*(1.0 - cos(theta)**2)**7.5*(7.32583550356578e+48*cos(theta)**60 - 8.70250257806136e+49*cos(theta)**58 + 4.89293767399164e+50*cos(theta)**56 - 1.73221241791888e+51*cos(theta)**54 + 4.33355938818517e+51*cos(theta)**52 - 8.15077978543764e+51*cos(theta)**50 + 1.19720686296896e+52*cos(theta)**48 - 1.40818492328361e+52*cos(theta)**46 + 1.34951055148013e+52*cos(theta)**44 - 1.06653047761086e+52*cos(theta)**42 + 7.00979191773246e+51*cos(theta)**40 - 3.85316257634342e+51*cos(theta)**38 + 1.77741029604293e+51*cos(theta)**36 - 6.89088299388952e+50*cos(theta)**34 + 2.24493923320094e+50*cos(theta)**32 - 6.13493035629568e+49*cos(theta)**30 + 1.40162537026713e+49*cos(theta)**28 - 2.66372242313211e+48*cos(theta)**26 + 4.18217288656007e+47*cos(theta)**24 - 5.3762446049864e+46*cos(theta)**22 + 5.59420046735071e+45*cos(theta)**20 - 4.64350410133961e+44*cos(theta)**18 + 3.01808040571351e+43*cos(theta)**16 - 1.49966728234212e+42*cos(theta)**14 + 5.52061985004581e+40*cos(theta)**12 - 1.44301350535851e+39*cos(theta)**10 + 2.5227508834939e+37*cos(theta)**8 - 2.69709907360936e+35*cos(theta)**6 + 1.52092053023084e+33*cos(theta)**4 - 3.38358293710977e+30*cos(theta)**2 + 1.23940766927098e+27)*sin(15*phi)

#@torch.jit.script
def Yl75_m_minus_14(theta, phi):
    return 2.71834291445864e-26*(1.0 - cos(theta)**2)**7*(1.20095663992882e+47*cos(theta)**61 - 1.47500043695955e+48*cos(theta)**59 + 8.58410118244148e+48*cos(theta)**57 - 3.14947712348887e+49*cos(theta)**55 + 8.17652714751919e+49*cos(theta)**53 - 1.59819211479169e+50*cos(theta)**51 + 2.44327931218155e+50*cos(theta)**49 - 2.99613813464598e+50*cos(theta)**47 + 2.99891233662251e+50*cos(theta)**45 - 2.48030343630433e+50*cos(theta)**43 + 1.7097053457884e+50*cos(theta)**41 - 9.87990404190621e+49*cos(theta)**39 + 4.80381161092684e+49*cos(theta)**37 - 1.96882371253986e+49*cos(theta)**35 + 6.80284616121497e+48*cos(theta)**33 - 1.97900979235345e+48*cos(theta)**31 + 4.83319093195563e+47*cos(theta)**29 - 9.86563860419299e+46*cos(theta)**27 + 1.67286915462403e+46*cos(theta)**25 - 2.33749765434191e+45*cos(theta)**23 + 2.66390498445272e+44*cos(theta)**21 - 2.44394952702084e+43*cos(theta)**19 + 1.77534141512559e+42*cos(theta)**17 - 9.99778188228077e+40*cos(theta)**15 + 4.24663065388139e+39*cos(theta)**13 - 1.31183045941683e+38*cos(theta)**11 + 2.80305653721544e+36*cos(theta)**9 - 3.8529986765848e+34*cos(theta)**7 + 3.04184106046168e+32*cos(theta)**5 - 1.12786097903659e+30*cos(theta)**3 + 1.23940766927098e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl75_m_minus_13(theta, phi):
    return 2.01927323784677e-24*(1.0 - cos(theta)**2)**6.5*(1.93702683859486e+45*cos(theta)**62 - 2.45833406159925e+46*cos(theta)**60 + 1.48001744524853e+47*cos(theta)**58 - 5.62406629194442e+47*cos(theta)**56 + 1.51417169398503e+48*cos(theta)**54 - 3.07344637459941e+48*cos(theta)**52 + 4.88655862436309e+48*cos(theta)**50 - 6.24195444717913e+48*cos(theta)**48 + 6.51937464483154e+48*cos(theta)**46 - 5.63705326432802e+48*cos(theta)**44 + 4.07072701378192e+48*cos(theta)**42 - 2.46997601047655e+48*cos(theta)**40 + 1.26416095024391e+48*cos(theta)**38 - 5.46895475705517e+47*cos(theta)**36 + 2.0008371062397e+47*cos(theta)**34 - 6.18440560110452e+46*cos(theta)**32 + 1.61106364398521e+46*cos(theta)**30 - 3.52344235864035e+45*cos(theta)**28 + 6.43411213316934e+44*cos(theta)**26 - 9.73957355975797e+43*cos(theta)**24 + 1.21086590202396e+43*cos(theta)**22 - 1.22197476351042e+42*cos(theta)**20 + 9.86300786180885e+40*cos(theta)**18 - 6.24861367642548e+39*cos(theta)**16 + 3.03330760991528e+38*cos(theta)**14 - 1.09319204951402e+37*cos(theta)**12 + 2.80305653721544e+35*cos(theta)**10 - 4.816248345731e+33*cos(theta)**8 + 5.06973510076947e+31*cos(theta)**6 - 2.81965244759148e+29*cos(theta)**4 + 6.19703834635489e+26*cos(theta)**2 - 2.24611755938923e+23)*sin(13*phi)

#@torch.jit.script
def Yl75_m_minus_12(theta, phi):
    return 1.5035113130257e-22*(1.0 - cos(theta)**2)**6*(3.0746457755474e+43*cos(theta)**63 - 4.0300558386873e+44*cos(theta)**61 + 2.50850414448903e+45*cos(theta)**59 - 9.86678296832354e+45*cos(theta)**57 + 2.75303944360915e+46*cos(theta)**55 - 5.79895542377247e+46*cos(theta)**53 + 9.58148749875116e+46*cos(theta)**51 - 1.27386825452635e+47*cos(theta)**49 + 1.38710098826203e+47*cos(theta)**47 - 1.25267850318401e+47*cos(theta)**45 + 9.46680700879515e+46*cos(theta)**43 - 6.02433173286964e+46*cos(theta)**41 + 3.24143833395873e+46*cos(theta)**39 - 1.47809588028518e+46*cos(theta)**37 + 5.71667744639913e+45*cos(theta)**35 - 1.87406230336501e+45*cos(theta)**33 + 5.19697949672649e+44*cos(theta)**31 - 1.21498012366909e+44*cos(theta)**29 + 2.38300449376642e+43*cos(theta)**27 - 3.89582942390319e+42*cos(theta)**25 + 5.26463435662593e+41*cos(theta)**23 - 5.81892744528773e+40*cos(theta)**21 + 5.19105676937308e+39*cos(theta)**19 - 3.6756551037797e+38*cos(theta)**17 + 2.02220507327685e+37*cos(theta)**15 - 8.40916961164633e+35*cos(theta)**13 + 2.5482332156504e+34*cos(theta)**11 - 5.35138705081222e+32*cos(theta)**9 + 7.24247871538496e+30*cos(theta)**7 - 5.63930489518295e+28*cos(theta)**5 + 2.06567944878496e+26*cos(theta)**3 - 2.24611755938923e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl75_m_minus_11(theta, phi):
    return 1.12190559417584e-20*(1.0 - cos(theta)**2)**5.5*(4.80413402429282e+41*cos(theta)**64 - 6.50009006239887e+42*cos(theta)**62 + 4.18084024081506e+43*cos(theta)**60 - 1.70116947729716e+44*cos(theta)**58 + 4.91614186358778e+44*cos(theta)**56 - 1.07388063403194e+45*cos(theta)**54 + 1.84259374975984e+45*cos(theta)**52 - 2.54773650905271e+45*cos(theta)**50 + 2.88979372554589e+45*cos(theta)**48 - 2.72321413735653e+45*cos(theta)**46 + 2.15154704745344e+45*cos(theta)**44 - 1.4343646983023e+45*cos(theta)**42 + 8.10359583489683e+44*cos(theta)**40 - 3.88972600075048e+44*cos(theta)**38 + 1.58796595733309e+44*cos(theta)**36 - 5.51194795107355e+43*cos(theta)**34 + 1.62405609272703e+43*cos(theta)**32 - 4.04993374556363e+42*cos(theta)**30 + 8.51073033488008e+41*cos(theta)**28 - 1.49839593227046e+41*cos(theta)**26 + 2.19359764859414e+40*cos(theta)**24 - 2.64496702058533e+39*cos(theta)**22 + 2.59552838468654e+38*cos(theta)**20 - 2.04203061321094e+37*cos(theta)**18 + 1.26387817079803e+36*cos(theta)**16 - 6.00654972260452e+34*cos(theta)**14 + 2.12352767970867e+33*cos(theta)**12 - 5.35138705081222e+31*cos(theta)**10 + 9.0530983942312e+29*cos(theta)**8 - 9.39884149197159e+27*cos(theta)**6 + 5.16419862196241e+25*cos(theta)**4 - 1.12305877969462e+23*cos(theta)**2 + 4.03397550177664e+19)*sin(11*phi)

#@torch.jit.script
def Yl75_m_minus_10(theta, phi):
    return 8.38807331092106e-19*(1.0 - cos(theta)**2)**5*(7.39097542198895e+39*cos(theta)**65 - 1.0317603273649e+41*cos(theta)**63 + 6.85383646035255e+41*cos(theta)**61 - 2.88333809711383e+42*cos(theta)**59 + 8.6248102869961e+42*cos(theta)**57 - 1.95251024369444e+43*cos(theta)**55 + 3.47659198067894e+43*cos(theta)**53 - 4.99556178245629e+43*cos(theta)**51 + 5.89753821539979e+43*cos(theta)**49 - 5.79407263267347e+43*cos(theta)**47 + 4.78121566100765e+43*cos(theta)**45 - 3.33573185651697e+43*cos(theta)**43 + 1.97648678899923e+43*cos(theta)**41 - 9.97365641218071e+42*cos(theta)**39 + 4.29179988468403e+42*cos(theta)**37 - 1.5748422717353e+42*cos(theta)**35 + 4.92138209917281e+41*cos(theta)**33 - 1.3064302405044e+41*cos(theta)**31 + 2.93473459823451e+40*cos(theta)**29 - 5.54961456396466e+39*cos(theta)**27 + 8.77439059437655e+38*cos(theta)**25 - 1.14998566112406e+38*cos(theta)**23 + 1.23596589746978e+37*cos(theta)**21 - 1.07475295432155e+36*cos(theta)**19 + 7.43457747528255e+34*cos(theta)**17 - 4.00436648173635e+33*cos(theta)**15 + 1.63348283054513e+32*cos(theta)**13 - 4.8648973189202e+30*cos(theta)**11 + 1.00589982158124e+29*cos(theta)**9 - 1.34269164171023e+27*cos(theta)**7 + 1.03283972439248e+25*cos(theta)**5 - 3.74352926564872e+22*cos(theta)**3 + 4.03397550177664e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl75_m_minus_9(theta, phi):
    return 6.28266131036249e-17*(1.0 - cos(theta)**2)**4.5*(1.11984476090742e+38*cos(theta)**66 - 1.61212551150766e+39*cos(theta)**64 + 1.10545749360525e+40*cos(theta)**62 - 4.80556349518972e+40*cos(theta)**60 + 1.48703625637864e+41*cos(theta)**58 - 3.48662543516863e+41*cos(theta)**56 + 6.43813329755359e+41*cos(theta)**54 - 9.60684958164671e+41*cos(theta)**52 + 1.17950764307996e+42*cos(theta)**50 - 1.20709846514031e+42*cos(theta)**48 + 1.03939470891471e+42*cos(theta)**46 - 7.58120876481129e+41*cos(theta)**44 + 4.70592092618863e+41*cos(theta)**42 - 2.49341410304518e+41*cos(theta)**40 + 1.12942102228527e+41*cos(theta)**38 - 4.37456186593138e+40*cos(theta)**36 + 1.44746532328612e+40*cos(theta)**34 - 4.08259450157624e+39*cos(theta)**32 + 9.78244866078171e+38*cos(theta)**30 - 1.98200520141595e+38*cos(theta)**28 + 3.37476561322175e+37*cos(theta)**26 - 4.79160692135024e+36*cos(theta)**24 + 5.61802680668082e+35*cos(theta)**22 - 5.37376477160774e+34*cos(theta)**20 + 4.13032081960142e+33*cos(theta)**18 - 2.50272905108522e+32*cos(theta)**16 + 1.16677345038938e+31*cos(theta)**14 - 4.05408109910017e+29*cos(theta)**12 + 1.00589982158124e+28*cos(theta)**10 - 1.67836455213778e+26*cos(theta)**8 + 1.72139954065414e+24*cos(theta)**6 - 9.3588231641218e+21*cos(theta)**4 + 2.01698775088832e+19*cos(theta)**2 - 7.19068716894232e+15)*sin(9*phi)

#@torch.jit.script
def Yl75_m_minus_8(theta, phi):
    return 4.71325234754096e-15*(1.0 - cos(theta)**2)**4*(1.67141009090659e+36*cos(theta)**67 - 2.48019309462716e+37*cos(theta)**65 + 1.75469443429405e+38*cos(theta)**63 - 7.87797294293397e+38*cos(theta)**61 + 2.52040043454006e+39*cos(theta)**59 - 6.11688672836603e+39*cos(theta)**57 + 1.17056969046429e+40*cos(theta)**55 - 1.81261312861259e+40*cos(theta)**53 + 2.3127600844705e+40*cos(theta)**51 - 2.46346625538838e+40*cos(theta)**49 + 2.21147810407384e+40*cos(theta)**47 - 1.68471305884695e+40*cos(theta)**45 + 1.09440021539271e+40*cos(theta)**43 - 6.08149781230531e+39*cos(theta)**41 + 2.89595133919301e+39*cos(theta)**39 - 1.18231401781929e+39*cos(theta)**37 + 4.13561520938891e+38*cos(theta)**35 - 1.2371498489625e+38*cos(theta)**33 + 3.15562860025216e+37*cos(theta)**31 - 6.83450069453775e+36*cos(theta)**29 + 1.24991319008213e+36*cos(theta)**27 - 1.91664276854009e+35*cos(theta)**25 + 2.44262035073079e+34*cos(theta)**23 - 2.5589356055275e+33*cos(theta)**21 + 2.17385306294812e+32*cos(theta)**19 - 1.47219355946189e+31*cos(theta)**17 + 7.77848966926252e+29*cos(theta)**15 - 3.11852392238474e+28*cos(theta)**13 + 9.14454383255677e+26*cos(theta)**11 - 1.86484950237531e+25*cos(theta)**9 + 2.45914220093448e+23*cos(theta)**7 - 1.87176463282436e+21*cos(theta)**5 + 6.72329250296106e+18*cos(theta)**3 - 7.19068716894232e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl75_m_minus_7(theta, phi):
    return 3.54090434735807e-13*(1.0 - cos(theta)**2)**3.5*(2.45795601603911e+34*cos(theta)**68 - 3.75786832519267e+35*cos(theta)**66 + 2.74171005358445e+36*cos(theta)**64 - 1.27064079724741e+37*cos(theta)**62 + 4.20066739090011e+37*cos(theta)**60 - 1.05463564282173e+38*cos(theta)**58 + 2.09030301868623e+38*cos(theta)**56 - 3.3566909789122e+38*cos(theta)**54 + 4.44761554705866e+38*cos(theta)**52 - 4.92693251077676e+38*cos(theta)**50 + 4.60724605015384e+38*cos(theta)**48 - 3.66241969314555e+38*cos(theta)**46 + 2.4872732168016e+38*cos(theta)**44 - 1.4479756695965e+38*cos(theta)**42 + 7.23987834798251e+37*cos(theta)**40 - 3.11135267847182e+37*cos(theta)**38 + 1.14878200260803e+37*cos(theta)**36 - 3.63867602636028e+36*cos(theta)**34 + 9.86133937578801e+35*cos(theta)**32 - 2.27816689817925e+35*cos(theta)**30 + 4.46397567886475e+34*cos(theta)**28 - 7.37170295592344e+33*cos(theta)**26 + 1.01775847947116e+33*cos(theta)**24 - 1.16315254796704e+32*cos(theta)**22 + 1.08692653147406e+31*cos(theta)**20 - 8.17885310812162e+29*cos(theta)**18 + 4.86155604328908e+28*cos(theta)**16 - 2.22751708741767e+27*cos(theta)**14 + 7.62045319379731e+25*cos(theta)**12 - 1.86484950237531e+24*cos(theta)**10 + 3.0739277511681e+22*cos(theta)**8 - 3.11960772137393e+20*cos(theta)**6 + 1.68082312574027e+18*cos(theta)**4 - 3.59534358447116e+15*cos(theta)**2 + 1274040958352.64)*sin(7*phi)

#@torch.jit.script
def Yl75_m_minus_6(theta, phi):
    return 2.6634568581566e-11*(1.0 - cos(theta)**2)**3*(3.56225509570885e+32*cos(theta)**69 - 5.60875869431742e+33*cos(theta)**67 + 4.218015467053e+34*cos(theta)**65 - 2.01689015436098e+35*cos(theta)**63 + 6.88633998508214e+35*cos(theta)**61 - 1.7875180386809e+36*cos(theta)**59 + 3.6671982783969e+36*cos(theta)**57 - 6.10307450711309e+36*cos(theta)**55 + 8.39172744728049e+36*cos(theta)**53 - 9.66065198191522e+36*cos(theta)**51 + 9.40254295949764e+36*cos(theta)**49 - 7.7923823258416e+36*cos(theta)**47 + 5.52727381511468e+36*cos(theta)**45 - 3.3673852781314e+36*cos(theta)**43 + 1.76582398731281e+36*cos(theta)**41 - 7.97782738069699e+35*cos(theta)**39 + 3.10481622326495e+35*cos(theta)**37 - 1.03962172181722e+35*cos(theta)**35 + 2.9882846593297e+34*cos(theta)**33 - 7.34892547799759e+33*cos(theta)**31 + 1.53930195822922e+33*cos(theta)**29 - 2.73026035404572e+32*cos(theta)**27 + 4.07103391788465e+31*cos(theta)**25 - 5.05718499116106e+30*cos(theta)**23 + 5.17584062606694e+29*cos(theta)**21 - 4.30465953059033e+28*cos(theta)**19 + 2.85973884899357e+27*cos(theta)**17 - 1.48501139161178e+26*cos(theta)**15 + 5.86188707215178e+24*cos(theta)**13 - 1.6953177294321e+23*cos(theta)**11 + 3.41547527907567e+21*cos(theta)**9 - 4.45658245910562e+19*cos(theta)**7 + 3.36164625148053e+17*cos(theta)**5 - 1.19844786149039e+15*cos(theta)**3 + 1274040958352.64*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl75_m_minus_5(theta, phi):
    return 2.0055670970559e-9*(1.0 - cos(theta)**2)**2.5*(5.08893585101264e+30*cos(theta)**70 - 8.2481745504668e+31*cos(theta)**68 + 6.39093252583788e+32*cos(theta)**66 - 3.15139086618902e+33*cos(theta)**64 + 1.11069999759389e+34*cos(theta)**62 - 2.97919673113483e+34*cos(theta)**60 + 6.32275565240844e+34*cos(theta)**58 - 1.08983473341305e+35*cos(theta)**56 + 1.55402360134824e+35*cos(theta)**54 - 1.85781768882985e+35*cos(theta)**52 + 1.88050859189953e+35*cos(theta)**50 - 1.62341298455033e+35*cos(theta)**48 + 1.20158126415536e+35*cos(theta)**46 - 7.65314835938955e+34*cos(theta)**44 + 4.20434282693526e+34*cos(theta)**42 - 1.99445684517425e+34*cos(theta)**40 + 8.17056900859198e+33*cos(theta)**38 - 2.88783811615895e+33*cos(theta)**36 + 8.78907252744029e+32*cos(theta)**34 - 2.29653921187425e+32*cos(theta)**32 + 5.13100652743075e+31*cos(theta)**30 - 9.75092983587756e+30*cos(theta)**28 + 1.56578227610948e+30*cos(theta)**26 - 2.10716041298377e+29*cos(theta)**24 + 2.35265483003043e+28*cos(theta)**22 - 2.15232976529516e+27*cos(theta)**20 + 1.58874380499643e+26*cos(theta)**18 - 9.28132119757365e+24*cos(theta)**16 + 4.18706219439413e+23*cos(theta)**14 - 1.41276477452675e+22*cos(theta)**12 + 3.41547527907567e+20*cos(theta)**10 - 5.57072807388202e+18*cos(theta)**8 + 5.60274375246755e+16*cos(theta)**6 - 299611965372596.0*cos(theta)**4 + 637020479176.321*cos(theta)**2 - 224698581.720043)*sin(5*phi)

#@torch.jit.script
def Yl75_m_minus_4(theta, phi):
    return 1.51151118033925e-7*(1.0 - cos(theta)**2)**2*(7.1675152831164e+28*cos(theta)**71 - 1.19538761600968e+30*cos(theta)**69 + 9.5387052624446e+30*cos(theta)**67 - 4.84829364029081e+31*cos(theta)**65 + 1.76301586919666e+32*cos(theta)**63 - 4.88392906743414e+32*cos(theta)**61 + 1.07165350040821e+33*cos(theta)**59 - 1.91199076037377e+33*cos(theta)**57 + 2.8254974569968e+33*cos(theta)**55 - 3.50531639401859e+33*cos(theta)**53 + 3.6872717488226e+33*cos(theta)**51 - 3.31308772357211e+33*cos(theta)**49 + 2.55655588118163e+33*cos(theta)**47 - 1.7006996354199e+33*cos(theta)**45 + 9.77754145798897e+32*cos(theta)**43 - 4.86452889066889e+32*cos(theta)**41 + 2.09501769451076e+32*cos(theta)**39 - 7.80496788151069e+31*cos(theta)**37 + 2.51116357926866e+31*cos(theta)**35 - 6.95920973295226e+30*cos(theta)**33 + 1.6551633959454e+30*cos(theta)**31 - 3.36238959857847e+29*cos(theta)**29 + 5.7991936152203e+28*cos(theta)**27 - 8.4286416519351e+27*cos(theta)**25 + 1.02289340436106e+27*cos(theta)**23 - 1.02491893585484e+26*cos(theta)**21 + 8.36180949998121e+24*cos(theta)**19 - 5.45960070445509e+23*cos(theta)**17 + 2.79137479626275e+22*cos(theta)**15 - 1.08674213425135e+21*cos(theta)**13 + 3.10497752643243e+19*cos(theta)**11 - 6.18969785986892e+17*cos(theta)**9 + 8.00391964638222e+15*cos(theta)**7 - 59922393074519.3*cos(theta)**5 + 212340159725.44*cos(theta)**3 - 224698581.720043*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl75_m_minus_3(theta, phi):
    return 1.13996405569108e-5*(1.0 - cos(theta)**2)**1.5*(9.95488233766166e+26*cos(theta)**72 - 1.70769659429954e+28*cos(theta)**70 + 1.40275077388891e+29*cos(theta)**68 - 7.34589945498607e+29*cos(theta)**66 + 2.75471229561978e+30*cos(theta)**64 - 7.87730494747442e+30*cos(theta)**62 + 1.78608916734702e+31*cos(theta)**60 - 3.29653579374789e+31*cos(theta)**58 + 5.04553117320857e+31*cos(theta)**56 - 6.49132665558997e+31*cos(theta)**54 + 7.09090720927424e+31*cos(theta)**52 - 6.62617544714421e+31*cos(theta)**50 + 5.32615808579505e+31*cos(theta)**48 - 3.69717312047804e+31*cos(theta)**46 + 2.22216851317931e+31*cos(theta)**44 - 1.15822116444497e+31*cos(theta)**42 + 5.23754423627691e+30*cos(theta)**40 - 2.05393891618702e+30*cos(theta)**38 + 6.97545438685738e+29*cos(theta)**36 - 2.04682639204478e+29*cos(theta)**34 + 5.17238561232938e+28*cos(theta)**32 - 1.12079653285949e+28*cos(theta)**30 + 2.07114057686439e+27*cos(theta)**28 - 3.24178525074427e+26*cos(theta)**26 + 4.2620558515044e+25*cos(theta)**24 - 4.65872243570382e+24*cos(theta)**22 + 4.1809047499906e+23*cos(theta)**20 - 3.03311150247505e+22*cos(theta)**18 + 1.74460924766422e+21*cos(theta)**16 - 7.76244381608106e+19*cos(theta)**14 + 2.58748127202702e+18*cos(theta)**12 - 6.18969785986892e+16*cos(theta)**10 + 1.00048995579778e+15*cos(theta)**8 - 9987065512419.88*cos(theta)**6 + 53085039931.3601*cos(theta)**4 - 112349290.860021*cos(theta)**2 + 39503.9700632987)*sin(3*phi)

#@torch.jit.script
def Yl75_m_minus_2(theta, phi):
    return 0.000860200893212514*(1.0 - cos(theta)**2)*(1.36368251200845e+25*cos(theta)**73 - 2.40520647084443e+26*cos(theta)**71 + 2.03297213607089e+27*cos(theta)**69 - 1.09640290372926e+28*cos(theta)**67 + 4.23801891633812e+28*cos(theta)**65 - 1.25036586467848e+29*cos(theta)**63 + 2.92801502843774e+29*cos(theta)**61 - 5.58734880296252e+29*cos(theta)**59 + 8.85180907580451e+29*cos(theta)**57 - 1.18024121010727e+30*cos(theta)**55 + 1.33790702061778e+30*cos(theta)**53 - 1.29925008767534e+30*cos(theta)**51 + 1.08697103791736e+30*cos(theta)**49 - 7.86632578825116e+29*cos(theta)**47 + 4.93815225150958e+29*cos(theta)**45 - 2.6935375917325e+29*cos(theta)**43 + 1.27744981372608e+29*cos(theta)**41 - 5.26651004150519e+28*cos(theta)**39 + 1.88525794239389e+28*cos(theta)**37 - 5.84807540584223e+27*cos(theta)**35 + 1.56738957949375e+27*cos(theta)**33 - 3.61547268664352e+26*cos(theta)**31 + 7.14186405815308e+25*cos(theta)**29 - 1.20066120397936e+25*cos(theta)**27 + 1.70482234060176e+24*cos(theta)**25 - 2.02553149378427e+23*cos(theta)**23 + 1.99090702380505e+22*cos(theta)**21 - 1.59637447498687e+21*cos(theta)**19 + 1.02624073392013e+20*cos(theta)**17 - 5.17496254405404e+18*cos(theta)**15 + 1.99037020925155e+17*cos(theta)**13 - 5.62699805442629e+15*cos(theta)**11 + 111165550644198.0*cos(theta)**9 - 1426723644631.41*cos(theta)**7 + 10617007986.272*cos(theta)**5 - 37449763.6200071*cos(theta)**3 + 39503.9700632987*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl75_m_minus_1(theta, phi):
    return 0.0649323486094812*(1.0 - cos(theta)**2)**0.5*(1.84281420541682e+23*cos(theta)**74 - 3.34056454283948e+24*cos(theta)**72 + 2.90424590867269e+25*cos(theta)**70 - 1.61235721136656e+26*cos(theta)**68 + 6.42124078233048e+26*cos(theta)**66 - 1.95369666356012e+27*cos(theta)**64 + 4.72260488457699e+27*cos(theta)**62 - 9.31224800493753e+27*cos(theta)**60 + 1.52617397858698e+28*cos(theta)**58 - 2.10757358947726e+28*cos(theta)**56 + 2.47760559373663e+28*cos(theta)**54 - 2.49855786091411e+28*cos(theta)**52 + 2.17394207583472e+28*cos(theta)**50 - 1.63881787255232e+28*cos(theta)**48 + 1.07351135902382e+28*cos(theta)**46 - 6.12167634484659e+27*cos(theta)**44 + 3.04154717553827e+27*cos(theta)**42 - 1.3166275103763e+27*cos(theta)**40 + 4.96120511156286e+26*cos(theta)**38 - 1.62446539051173e+26*cos(theta)**36 + 4.60996935145221e+25*cos(theta)**34 - 1.1298352145761e+25*cos(theta)**32 + 2.38062135271769e+24*cos(theta)**30 - 4.28807572849771e+23*cos(theta)**28 + 6.55700900231446e+22*cos(theta)**26 - 8.43971455743445e+21*cos(theta)**24 + 9.04957738093205e+20*cos(theta)**22 - 7.98187237493434e+19*cos(theta)**20 + 5.70133741066738e+18*cos(theta)**18 - 3.23435159003378e+17*cos(theta)**16 + 1.42169300660825e+16*cos(theta)**14 - 468916504535524.0*cos(theta)**12 + 11116555064419.8*cos(theta)**10 - 178340455578.926*cos(theta)**8 + 1769501331.04534*cos(theta)**6 - 9362440.90500178*cos(theta)**4 + 19751.9850316493*cos(theta)**2 - 6.93295367906259)*sin(phi)

#@torch.jit.script
def Yl75_m0(theta, phi):
    return 2.67580032598531e+22*cos(theta)**75 - 4.98345362725453e+23*cos(theta)**73 + 4.45459732395405e+24*cos(theta)**71 - 2.54475272414386e+25*cos(theta)**69 + 1.04370452637089e+26*cos(theta)**67 - 3.27323504653339e+26*cos(theta)**65 + 8.16346390502333e+26*cos(theta)**63 - 1.66248644489161e+27*cos(theta)**61 + 2.81699092051079e+27*cos(theta)**59 - 4.02662611946028e+27*cos(theta)**57 + 4.90572159286917e+27*cos(theta)**55 - 5.13389469021192e+27*cos(theta)**53 + 4.64206488393178e+27*cos(theta)**51 - 3.6422355243157e+27*cos(theta)**49 + 2.48738035806926e+27*cos(theta)**47 - 1.48146455486109e+27*cos(theta)**45 + 7.70299322117896e+26*cos(theta)**43 - 3.49713568563328e+26*cos(theta)**41 + 1.38533877401898e+26*cos(theta)**39 - 4.78125771564074e+25*cos(theta)**37 + 1.43437731469222e+25*cos(theta)**35 - 3.72850372320608e+24*cos(theta)**33 + 8.36299900532204e+23*cos(theta)**31 - 1.6102668892235e+23*cos(theta)**29 + 2.64469400090915e+22*cos(theta)**27 - 3.67638651215489e+21*cos(theta)**25 + 4.28483276474929e+20*cos(theta)**23 - 4.13922370936071e+19*cos(theta)**21 + 3.26780819160056e+18*cos(theta)**19 - 2.07191398132627e+17*cos(theta)**17 + 1.03216227641162e+16*cos(theta)**15 - 392812754705402.0*cos(theta)**13 + 11005529765453.1*cos(theta)**11 - 215794701283.394*cos(theta)**9 + 2752873581.21976*cos(theta)**7 - 20391656.1571834*cos(theta)**5 + 71700.6193993792*cos(theta)**3 - 75.500827728374*cos(theta)

#@torch.jit.script
def Yl75_m1(theta, phi):
    return 0.0649323486094812*(1.0 - cos(theta)**2)**0.5*(1.84281420541682e+23*cos(theta)**74 - 3.34056454283948e+24*cos(theta)**72 + 2.90424590867269e+25*cos(theta)**70 - 1.61235721136656e+26*cos(theta)**68 + 6.42124078233048e+26*cos(theta)**66 - 1.95369666356012e+27*cos(theta)**64 + 4.72260488457699e+27*cos(theta)**62 - 9.31224800493753e+27*cos(theta)**60 + 1.52617397858698e+28*cos(theta)**58 - 2.10757358947726e+28*cos(theta)**56 + 2.47760559373663e+28*cos(theta)**54 - 2.49855786091411e+28*cos(theta)**52 + 2.17394207583472e+28*cos(theta)**50 - 1.63881787255232e+28*cos(theta)**48 + 1.07351135902382e+28*cos(theta)**46 - 6.12167634484659e+27*cos(theta)**44 + 3.04154717553827e+27*cos(theta)**42 - 1.3166275103763e+27*cos(theta)**40 + 4.96120511156286e+26*cos(theta)**38 - 1.62446539051173e+26*cos(theta)**36 + 4.60996935145221e+25*cos(theta)**34 - 1.1298352145761e+25*cos(theta)**32 + 2.38062135271769e+24*cos(theta)**30 - 4.28807572849771e+23*cos(theta)**28 + 6.55700900231446e+22*cos(theta)**26 - 8.43971455743445e+21*cos(theta)**24 + 9.04957738093205e+20*cos(theta)**22 - 7.98187237493434e+19*cos(theta)**20 + 5.70133741066738e+18*cos(theta)**18 - 3.23435159003378e+17*cos(theta)**16 + 1.42169300660825e+16*cos(theta)**14 - 468916504535524.0*cos(theta)**12 + 11116555064419.8*cos(theta)**10 - 178340455578.926*cos(theta)**8 + 1769501331.04534*cos(theta)**6 - 9362440.90500178*cos(theta)**4 + 19751.9850316493*cos(theta)**2 - 6.93295367906259)*cos(phi)

#@torch.jit.script
def Yl75_m2(theta, phi):
    return 0.000860200893212514*(1.0 - cos(theta)**2)*(1.36368251200845e+25*cos(theta)**73 - 2.40520647084443e+26*cos(theta)**71 + 2.03297213607089e+27*cos(theta)**69 - 1.09640290372926e+28*cos(theta)**67 + 4.23801891633812e+28*cos(theta)**65 - 1.25036586467848e+29*cos(theta)**63 + 2.92801502843774e+29*cos(theta)**61 - 5.58734880296252e+29*cos(theta)**59 + 8.85180907580451e+29*cos(theta)**57 - 1.18024121010727e+30*cos(theta)**55 + 1.33790702061778e+30*cos(theta)**53 - 1.29925008767534e+30*cos(theta)**51 + 1.08697103791736e+30*cos(theta)**49 - 7.86632578825116e+29*cos(theta)**47 + 4.93815225150958e+29*cos(theta)**45 - 2.6935375917325e+29*cos(theta)**43 + 1.27744981372608e+29*cos(theta)**41 - 5.26651004150519e+28*cos(theta)**39 + 1.88525794239389e+28*cos(theta)**37 - 5.84807540584223e+27*cos(theta)**35 + 1.56738957949375e+27*cos(theta)**33 - 3.61547268664352e+26*cos(theta)**31 + 7.14186405815308e+25*cos(theta)**29 - 1.20066120397936e+25*cos(theta)**27 + 1.70482234060176e+24*cos(theta)**25 - 2.02553149378427e+23*cos(theta)**23 + 1.99090702380505e+22*cos(theta)**21 - 1.59637447498687e+21*cos(theta)**19 + 1.02624073392013e+20*cos(theta)**17 - 5.17496254405404e+18*cos(theta)**15 + 1.99037020925155e+17*cos(theta)**13 - 5.62699805442629e+15*cos(theta)**11 + 111165550644198.0*cos(theta)**9 - 1426723644631.41*cos(theta)**7 + 10617007986.272*cos(theta)**5 - 37449763.6200071*cos(theta)**3 + 39503.9700632987*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl75_m3(theta, phi):
    return 1.13996405569108e-5*(1.0 - cos(theta)**2)**1.5*(9.95488233766166e+26*cos(theta)**72 - 1.70769659429954e+28*cos(theta)**70 + 1.40275077388891e+29*cos(theta)**68 - 7.34589945498607e+29*cos(theta)**66 + 2.75471229561978e+30*cos(theta)**64 - 7.87730494747442e+30*cos(theta)**62 + 1.78608916734702e+31*cos(theta)**60 - 3.29653579374789e+31*cos(theta)**58 + 5.04553117320857e+31*cos(theta)**56 - 6.49132665558997e+31*cos(theta)**54 + 7.09090720927424e+31*cos(theta)**52 - 6.62617544714421e+31*cos(theta)**50 + 5.32615808579505e+31*cos(theta)**48 - 3.69717312047804e+31*cos(theta)**46 + 2.22216851317931e+31*cos(theta)**44 - 1.15822116444497e+31*cos(theta)**42 + 5.23754423627691e+30*cos(theta)**40 - 2.05393891618702e+30*cos(theta)**38 + 6.97545438685738e+29*cos(theta)**36 - 2.04682639204478e+29*cos(theta)**34 + 5.17238561232938e+28*cos(theta)**32 - 1.12079653285949e+28*cos(theta)**30 + 2.07114057686439e+27*cos(theta)**28 - 3.24178525074427e+26*cos(theta)**26 + 4.2620558515044e+25*cos(theta)**24 - 4.65872243570382e+24*cos(theta)**22 + 4.1809047499906e+23*cos(theta)**20 - 3.03311150247505e+22*cos(theta)**18 + 1.74460924766422e+21*cos(theta)**16 - 7.76244381608106e+19*cos(theta)**14 + 2.58748127202702e+18*cos(theta)**12 - 6.18969785986892e+16*cos(theta)**10 + 1.00048995579778e+15*cos(theta)**8 - 9987065512419.88*cos(theta)**6 + 53085039931.3601*cos(theta)**4 - 112349290.860021*cos(theta)**2 + 39503.9700632987)*cos(3*phi)

#@torch.jit.script
def Yl75_m4(theta, phi):
    return 1.51151118033925e-7*(1.0 - cos(theta)**2)**2*(7.1675152831164e+28*cos(theta)**71 - 1.19538761600968e+30*cos(theta)**69 + 9.5387052624446e+30*cos(theta)**67 - 4.84829364029081e+31*cos(theta)**65 + 1.76301586919666e+32*cos(theta)**63 - 4.88392906743414e+32*cos(theta)**61 + 1.07165350040821e+33*cos(theta)**59 - 1.91199076037377e+33*cos(theta)**57 + 2.8254974569968e+33*cos(theta)**55 - 3.50531639401859e+33*cos(theta)**53 + 3.6872717488226e+33*cos(theta)**51 - 3.31308772357211e+33*cos(theta)**49 + 2.55655588118163e+33*cos(theta)**47 - 1.7006996354199e+33*cos(theta)**45 + 9.77754145798897e+32*cos(theta)**43 - 4.86452889066889e+32*cos(theta)**41 + 2.09501769451076e+32*cos(theta)**39 - 7.80496788151069e+31*cos(theta)**37 + 2.51116357926866e+31*cos(theta)**35 - 6.95920973295226e+30*cos(theta)**33 + 1.6551633959454e+30*cos(theta)**31 - 3.36238959857847e+29*cos(theta)**29 + 5.7991936152203e+28*cos(theta)**27 - 8.4286416519351e+27*cos(theta)**25 + 1.02289340436106e+27*cos(theta)**23 - 1.02491893585484e+26*cos(theta)**21 + 8.36180949998121e+24*cos(theta)**19 - 5.45960070445509e+23*cos(theta)**17 + 2.79137479626275e+22*cos(theta)**15 - 1.08674213425135e+21*cos(theta)**13 + 3.10497752643243e+19*cos(theta)**11 - 6.18969785986892e+17*cos(theta)**9 + 8.00391964638222e+15*cos(theta)**7 - 59922393074519.3*cos(theta)**5 + 212340159725.44*cos(theta)**3 - 224698581.720043*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl75_m5(theta, phi):
    return 2.0055670970559e-9*(1.0 - cos(theta)**2)**2.5*(5.08893585101264e+30*cos(theta)**70 - 8.2481745504668e+31*cos(theta)**68 + 6.39093252583788e+32*cos(theta)**66 - 3.15139086618902e+33*cos(theta)**64 + 1.11069999759389e+34*cos(theta)**62 - 2.97919673113483e+34*cos(theta)**60 + 6.32275565240844e+34*cos(theta)**58 - 1.08983473341305e+35*cos(theta)**56 + 1.55402360134824e+35*cos(theta)**54 - 1.85781768882985e+35*cos(theta)**52 + 1.88050859189953e+35*cos(theta)**50 - 1.62341298455033e+35*cos(theta)**48 + 1.20158126415536e+35*cos(theta)**46 - 7.65314835938955e+34*cos(theta)**44 + 4.20434282693526e+34*cos(theta)**42 - 1.99445684517425e+34*cos(theta)**40 + 8.17056900859198e+33*cos(theta)**38 - 2.88783811615895e+33*cos(theta)**36 + 8.78907252744029e+32*cos(theta)**34 - 2.29653921187425e+32*cos(theta)**32 + 5.13100652743075e+31*cos(theta)**30 - 9.75092983587756e+30*cos(theta)**28 + 1.56578227610948e+30*cos(theta)**26 - 2.10716041298377e+29*cos(theta)**24 + 2.35265483003043e+28*cos(theta)**22 - 2.15232976529516e+27*cos(theta)**20 + 1.58874380499643e+26*cos(theta)**18 - 9.28132119757365e+24*cos(theta)**16 + 4.18706219439413e+23*cos(theta)**14 - 1.41276477452675e+22*cos(theta)**12 + 3.41547527907567e+20*cos(theta)**10 - 5.57072807388202e+18*cos(theta)**8 + 5.60274375246755e+16*cos(theta)**6 - 299611965372596.0*cos(theta)**4 + 637020479176.321*cos(theta)**2 - 224698581.720043)*cos(5*phi)

#@torch.jit.script
def Yl75_m6(theta, phi):
    return 2.6634568581566e-11*(1.0 - cos(theta)**2)**3*(3.56225509570885e+32*cos(theta)**69 - 5.60875869431742e+33*cos(theta)**67 + 4.218015467053e+34*cos(theta)**65 - 2.01689015436098e+35*cos(theta)**63 + 6.88633998508214e+35*cos(theta)**61 - 1.7875180386809e+36*cos(theta)**59 + 3.6671982783969e+36*cos(theta)**57 - 6.10307450711309e+36*cos(theta)**55 + 8.39172744728049e+36*cos(theta)**53 - 9.66065198191522e+36*cos(theta)**51 + 9.40254295949764e+36*cos(theta)**49 - 7.7923823258416e+36*cos(theta)**47 + 5.52727381511468e+36*cos(theta)**45 - 3.3673852781314e+36*cos(theta)**43 + 1.76582398731281e+36*cos(theta)**41 - 7.97782738069699e+35*cos(theta)**39 + 3.10481622326495e+35*cos(theta)**37 - 1.03962172181722e+35*cos(theta)**35 + 2.9882846593297e+34*cos(theta)**33 - 7.34892547799759e+33*cos(theta)**31 + 1.53930195822922e+33*cos(theta)**29 - 2.73026035404572e+32*cos(theta)**27 + 4.07103391788465e+31*cos(theta)**25 - 5.05718499116106e+30*cos(theta)**23 + 5.17584062606694e+29*cos(theta)**21 - 4.30465953059033e+28*cos(theta)**19 + 2.85973884899357e+27*cos(theta)**17 - 1.48501139161178e+26*cos(theta)**15 + 5.86188707215178e+24*cos(theta)**13 - 1.6953177294321e+23*cos(theta)**11 + 3.41547527907567e+21*cos(theta)**9 - 4.45658245910562e+19*cos(theta)**7 + 3.36164625148053e+17*cos(theta)**5 - 1.19844786149039e+15*cos(theta)**3 + 1274040958352.64*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl75_m7(theta, phi):
    return 3.54090434735807e-13*(1.0 - cos(theta)**2)**3.5*(2.45795601603911e+34*cos(theta)**68 - 3.75786832519267e+35*cos(theta)**66 + 2.74171005358445e+36*cos(theta)**64 - 1.27064079724741e+37*cos(theta)**62 + 4.20066739090011e+37*cos(theta)**60 - 1.05463564282173e+38*cos(theta)**58 + 2.09030301868623e+38*cos(theta)**56 - 3.3566909789122e+38*cos(theta)**54 + 4.44761554705866e+38*cos(theta)**52 - 4.92693251077676e+38*cos(theta)**50 + 4.60724605015384e+38*cos(theta)**48 - 3.66241969314555e+38*cos(theta)**46 + 2.4872732168016e+38*cos(theta)**44 - 1.4479756695965e+38*cos(theta)**42 + 7.23987834798251e+37*cos(theta)**40 - 3.11135267847182e+37*cos(theta)**38 + 1.14878200260803e+37*cos(theta)**36 - 3.63867602636028e+36*cos(theta)**34 + 9.86133937578801e+35*cos(theta)**32 - 2.27816689817925e+35*cos(theta)**30 + 4.46397567886475e+34*cos(theta)**28 - 7.37170295592344e+33*cos(theta)**26 + 1.01775847947116e+33*cos(theta)**24 - 1.16315254796704e+32*cos(theta)**22 + 1.08692653147406e+31*cos(theta)**20 - 8.17885310812162e+29*cos(theta)**18 + 4.86155604328908e+28*cos(theta)**16 - 2.22751708741767e+27*cos(theta)**14 + 7.62045319379731e+25*cos(theta)**12 - 1.86484950237531e+24*cos(theta)**10 + 3.0739277511681e+22*cos(theta)**8 - 3.11960772137393e+20*cos(theta)**6 + 1.68082312574027e+18*cos(theta)**4 - 3.59534358447116e+15*cos(theta)**2 + 1274040958352.64)*cos(7*phi)

#@torch.jit.script
def Yl75_m8(theta, phi):
    return 4.71325234754096e-15*(1.0 - cos(theta)**2)**4*(1.67141009090659e+36*cos(theta)**67 - 2.48019309462716e+37*cos(theta)**65 + 1.75469443429405e+38*cos(theta)**63 - 7.87797294293397e+38*cos(theta)**61 + 2.52040043454006e+39*cos(theta)**59 - 6.11688672836603e+39*cos(theta)**57 + 1.17056969046429e+40*cos(theta)**55 - 1.81261312861259e+40*cos(theta)**53 + 2.3127600844705e+40*cos(theta)**51 - 2.46346625538838e+40*cos(theta)**49 + 2.21147810407384e+40*cos(theta)**47 - 1.68471305884695e+40*cos(theta)**45 + 1.09440021539271e+40*cos(theta)**43 - 6.08149781230531e+39*cos(theta)**41 + 2.89595133919301e+39*cos(theta)**39 - 1.18231401781929e+39*cos(theta)**37 + 4.13561520938891e+38*cos(theta)**35 - 1.2371498489625e+38*cos(theta)**33 + 3.15562860025216e+37*cos(theta)**31 - 6.83450069453775e+36*cos(theta)**29 + 1.24991319008213e+36*cos(theta)**27 - 1.91664276854009e+35*cos(theta)**25 + 2.44262035073079e+34*cos(theta)**23 - 2.5589356055275e+33*cos(theta)**21 + 2.17385306294812e+32*cos(theta)**19 - 1.47219355946189e+31*cos(theta)**17 + 7.77848966926252e+29*cos(theta)**15 - 3.11852392238474e+28*cos(theta)**13 + 9.14454383255677e+26*cos(theta)**11 - 1.86484950237531e+25*cos(theta)**9 + 2.45914220093448e+23*cos(theta)**7 - 1.87176463282436e+21*cos(theta)**5 + 6.72329250296106e+18*cos(theta)**3 - 7.19068716894232e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl75_m9(theta, phi):
    return 6.28266131036249e-17*(1.0 - cos(theta)**2)**4.5*(1.11984476090742e+38*cos(theta)**66 - 1.61212551150766e+39*cos(theta)**64 + 1.10545749360525e+40*cos(theta)**62 - 4.80556349518972e+40*cos(theta)**60 + 1.48703625637864e+41*cos(theta)**58 - 3.48662543516863e+41*cos(theta)**56 + 6.43813329755359e+41*cos(theta)**54 - 9.60684958164671e+41*cos(theta)**52 + 1.17950764307996e+42*cos(theta)**50 - 1.20709846514031e+42*cos(theta)**48 + 1.03939470891471e+42*cos(theta)**46 - 7.58120876481129e+41*cos(theta)**44 + 4.70592092618863e+41*cos(theta)**42 - 2.49341410304518e+41*cos(theta)**40 + 1.12942102228527e+41*cos(theta)**38 - 4.37456186593138e+40*cos(theta)**36 + 1.44746532328612e+40*cos(theta)**34 - 4.08259450157624e+39*cos(theta)**32 + 9.78244866078171e+38*cos(theta)**30 - 1.98200520141595e+38*cos(theta)**28 + 3.37476561322175e+37*cos(theta)**26 - 4.79160692135024e+36*cos(theta)**24 + 5.61802680668082e+35*cos(theta)**22 - 5.37376477160774e+34*cos(theta)**20 + 4.13032081960142e+33*cos(theta)**18 - 2.50272905108522e+32*cos(theta)**16 + 1.16677345038938e+31*cos(theta)**14 - 4.05408109910017e+29*cos(theta)**12 + 1.00589982158124e+28*cos(theta)**10 - 1.67836455213778e+26*cos(theta)**8 + 1.72139954065414e+24*cos(theta)**6 - 9.3588231641218e+21*cos(theta)**4 + 2.01698775088832e+19*cos(theta)**2 - 7.19068716894232e+15)*cos(9*phi)

#@torch.jit.script
def Yl75_m10(theta, phi):
    return 8.38807331092106e-19*(1.0 - cos(theta)**2)**5*(7.39097542198895e+39*cos(theta)**65 - 1.0317603273649e+41*cos(theta)**63 + 6.85383646035255e+41*cos(theta)**61 - 2.88333809711383e+42*cos(theta)**59 + 8.6248102869961e+42*cos(theta)**57 - 1.95251024369444e+43*cos(theta)**55 + 3.47659198067894e+43*cos(theta)**53 - 4.99556178245629e+43*cos(theta)**51 + 5.89753821539979e+43*cos(theta)**49 - 5.79407263267347e+43*cos(theta)**47 + 4.78121566100765e+43*cos(theta)**45 - 3.33573185651697e+43*cos(theta)**43 + 1.97648678899923e+43*cos(theta)**41 - 9.97365641218071e+42*cos(theta)**39 + 4.29179988468403e+42*cos(theta)**37 - 1.5748422717353e+42*cos(theta)**35 + 4.92138209917281e+41*cos(theta)**33 - 1.3064302405044e+41*cos(theta)**31 + 2.93473459823451e+40*cos(theta)**29 - 5.54961456396466e+39*cos(theta)**27 + 8.77439059437655e+38*cos(theta)**25 - 1.14998566112406e+38*cos(theta)**23 + 1.23596589746978e+37*cos(theta)**21 - 1.07475295432155e+36*cos(theta)**19 + 7.43457747528255e+34*cos(theta)**17 - 4.00436648173635e+33*cos(theta)**15 + 1.63348283054513e+32*cos(theta)**13 - 4.8648973189202e+30*cos(theta)**11 + 1.00589982158124e+29*cos(theta)**9 - 1.34269164171023e+27*cos(theta)**7 + 1.03283972439248e+25*cos(theta)**5 - 3.74352926564872e+22*cos(theta)**3 + 4.03397550177664e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl75_m11(theta, phi):
    return 1.12190559417584e-20*(1.0 - cos(theta)**2)**5.5*(4.80413402429282e+41*cos(theta)**64 - 6.50009006239887e+42*cos(theta)**62 + 4.18084024081506e+43*cos(theta)**60 - 1.70116947729716e+44*cos(theta)**58 + 4.91614186358778e+44*cos(theta)**56 - 1.07388063403194e+45*cos(theta)**54 + 1.84259374975984e+45*cos(theta)**52 - 2.54773650905271e+45*cos(theta)**50 + 2.88979372554589e+45*cos(theta)**48 - 2.72321413735653e+45*cos(theta)**46 + 2.15154704745344e+45*cos(theta)**44 - 1.4343646983023e+45*cos(theta)**42 + 8.10359583489683e+44*cos(theta)**40 - 3.88972600075048e+44*cos(theta)**38 + 1.58796595733309e+44*cos(theta)**36 - 5.51194795107355e+43*cos(theta)**34 + 1.62405609272703e+43*cos(theta)**32 - 4.04993374556363e+42*cos(theta)**30 + 8.51073033488008e+41*cos(theta)**28 - 1.49839593227046e+41*cos(theta)**26 + 2.19359764859414e+40*cos(theta)**24 - 2.64496702058533e+39*cos(theta)**22 + 2.59552838468654e+38*cos(theta)**20 - 2.04203061321094e+37*cos(theta)**18 + 1.26387817079803e+36*cos(theta)**16 - 6.00654972260452e+34*cos(theta)**14 + 2.12352767970867e+33*cos(theta)**12 - 5.35138705081222e+31*cos(theta)**10 + 9.0530983942312e+29*cos(theta)**8 - 9.39884149197159e+27*cos(theta)**6 + 5.16419862196241e+25*cos(theta)**4 - 1.12305877969462e+23*cos(theta)**2 + 4.03397550177664e+19)*cos(11*phi)

#@torch.jit.script
def Yl75_m12(theta, phi):
    return 1.5035113130257e-22*(1.0 - cos(theta)**2)**6*(3.0746457755474e+43*cos(theta)**63 - 4.0300558386873e+44*cos(theta)**61 + 2.50850414448903e+45*cos(theta)**59 - 9.86678296832354e+45*cos(theta)**57 + 2.75303944360915e+46*cos(theta)**55 - 5.79895542377247e+46*cos(theta)**53 + 9.58148749875116e+46*cos(theta)**51 - 1.27386825452635e+47*cos(theta)**49 + 1.38710098826203e+47*cos(theta)**47 - 1.25267850318401e+47*cos(theta)**45 + 9.46680700879515e+46*cos(theta)**43 - 6.02433173286964e+46*cos(theta)**41 + 3.24143833395873e+46*cos(theta)**39 - 1.47809588028518e+46*cos(theta)**37 + 5.71667744639913e+45*cos(theta)**35 - 1.87406230336501e+45*cos(theta)**33 + 5.19697949672649e+44*cos(theta)**31 - 1.21498012366909e+44*cos(theta)**29 + 2.38300449376642e+43*cos(theta)**27 - 3.89582942390319e+42*cos(theta)**25 + 5.26463435662593e+41*cos(theta)**23 - 5.81892744528773e+40*cos(theta)**21 + 5.19105676937308e+39*cos(theta)**19 - 3.6756551037797e+38*cos(theta)**17 + 2.02220507327685e+37*cos(theta)**15 - 8.40916961164633e+35*cos(theta)**13 + 2.5482332156504e+34*cos(theta)**11 - 5.35138705081222e+32*cos(theta)**9 + 7.24247871538496e+30*cos(theta)**7 - 5.63930489518295e+28*cos(theta)**5 + 2.06567944878496e+26*cos(theta)**3 - 2.24611755938923e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl75_m13(theta, phi):
    return 2.01927323784677e-24*(1.0 - cos(theta)**2)**6.5*(1.93702683859486e+45*cos(theta)**62 - 2.45833406159925e+46*cos(theta)**60 + 1.48001744524853e+47*cos(theta)**58 - 5.62406629194442e+47*cos(theta)**56 + 1.51417169398503e+48*cos(theta)**54 - 3.07344637459941e+48*cos(theta)**52 + 4.88655862436309e+48*cos(theta)**50 - 6.24195444717913e+48*cos(theta)**48 + 6.51937464483154e+48*cos(theta)**46 - 5.63705326432802e+48*cos(theta)**44 + 4.07072701378192e+48*cos(theta)**42 - 2.46997601047655e+48*cos(theta)**40 + 1.26416095024391e+48*cos(theta)**38 - 5.46895475705517e+47*cos(theta)**36 + 2.0008371062397e+47*cos(theta)**34 - 6.18440560110452e+46*cos(theta)**32 + 1.61106364398521e+46*cos(theta)**30 - 3.52344235864035e+45*cos(theta)**28 + 6.43411213316934e+44*cos(theta)**26 - 9.73957355975797e+43*cos(theta)**24 + 1.21086590202396e+43*cos(theta)**22 - 1.22197476351042e+42*cos(theta)**20 + 9.86300786180885e+40*cos(theta)**18 - 6.24861367642548e+39*cos(theta)**16 + 3.03330760991528e+38*cos(theta)**14 - 1.09319204951402e+37*cos(theta)**12 + 2.80305653721544e+35*cos(theta)**10 - 4.816248345731e+33*cos(theta)**8 + 5.06973510076947e+31*cos(theta)**6 - 2.81965244759148e+29*cos(theta)**4 + 6.19703834635489e+26*cos(theta)**2 - 2.24611755938923e+23)*cos(13*phi)

#@torch.jit.script
def Yl75_m14(theta, phi):
    return 2.71834291445864e-26*(1.0 - cos(theta)**2)**7*(1.20095663992882e+47*cos(theta)**61 - 1.47500043695955e+48*cos(theta)**59 + 8.58410118244148e+48*cos(theta)**57 - 3.14947712348887e+49*cos(theta)**55 + 8.17652714751919e+49*cos(theta)**53 - 1.59819211479169e+50*cos(theta)**51 + 2.44327931218155e+50*cos(theta)**49 - 2.99613813464598e+50*cos(theta)**47 + 2.99891233662251e+50*cos(theta)**45 - 2.48030343630433e+50*cos(theta)**43 + 1.7097053457884e+50*cos(theta)**41 - 9.87990404190621e+49*cos(theta)**39 + 4.80381161092684e+49*cos(theta)**37 - 1.96882371253986e+49*cos(theta)**35 + 6.80284616121497e+48*cos(theta)**33 - 1.97900979235345e+48*cos(theta)**31 + 4.83319093195563e+47*cos(theta)**29 - 9.86563860419299e+46*cos(theta)**27 + 1.67286915462403e+46*cos(theta)**25 - 2.33749765434191e+45*cos(theta)**23 + 2.66390498445272e+44*cos(theta)**21 - 2.44394952702084e+43*cos(theta)**19 + 1.77534141512559e+42*cos(theta)**17 - 9.99778188228077e+40*cos(theta)**15 + 4.24663065388139e+39*cos(theta)**13 - 1.31183045941683e+38*cos(theta)**11 + 2.80305653721544e+36*cos(theta)**9 - 3.8529986765848e+34*cos(theta)**7 + 3.04184106046168e+32*cos(theta)**5 - 1.12786097903659e+30*cos(theta)**3 + 1.23940766927098e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl75_m15(theta, phi):
    return 3.66874958239696e-28*(1.0 - cos(theta)**2)**7.5*(7.32583550356578e+48*cos(theta)**60 - 8.70250257806136e+49*cos(theta)**58 + 4.89293767399164e+50*cos(theta)**56 - 1.73221241791888e+51*cos(theta)**54 + 4.33355938818517e+51*cos(theta)**52 - 8.15077978543764e+51*cos(theta)**50 + 1.19720686296896e+52*cos(theta)**48 - 1.40818492328361e+52*cos(theta)**46 + 1.34951055148013e+52*cos(theta)**44 - 1.06653047761086e+52*cos(theta)**42 + 7.00979191773246e+51*cos(theta)**40 - 3.85316257634342e+51*cos(theta)**38 + 1.77741029604293e+51*cos(theta)**36 - 6.89088299388952e+50*cos(theta)**34 + 2.24493923320094e+50*cos(theta)**32 - 6.13493035629568e+49*cos(theta)**30 + 1.40162537026713e+49*cos(theta)**28 - 2.66372242313211e+48*cos(theta)**26 + 4.18217288656007e+47*cos(theta)**24 - 5.3762446049864e+46*cos(theta)**22 + 5.59420046735071e+45*cos(theta)**20 - 4.64350410133961e+44*cos(theta)**18 + 3.01808040571351e+43*cos(theta)**16 - 1.49966728234212e+42*cos(theta)**14 + 5.52061985004581e+40*cos(theta)**12 - 1.44301350535851e+39*cos(theta)**10 + 2.5227508834939e+37*cos(theta)**8 - 2.69709907360936e+35*cos(theta)**6 + 1.52092053023084e+33*cos(theta)**4 - 3.38358293710977e+30*cos(theta)**2 + 1.23940766927098e+27)*cos(15*phi)

#@torch.jit.script
def Yl75_m16(theta, phi):
    return 4.96502852345423e-30*(1.0 - cos(theta)**2)**8*(4.39550130213947e+50*cos(theta)**59 - 5.04745149527559e+51*cos(theta)**57 + 2.74004509743532e+52*cos(theta)**55 - 9.35394705676195e+52*cos(theta)**53 + 2.25345088185629e+53*cos(theta)**51 - 4.07538989271882e+53*cos(theta)**49 + 5.746592942251e+53*cos(theta)**47 - 6.47765064710462e+53*cos(theta)**45 + 5.93784642651257e+53*cos(theta)**43 - 4.47942800596562e+53*cos(theta)**41 + 2.80391676709298e+53*cos(theta)**39 - 1.4642017790105e+53*cos(theta)**37 + 6.39867706575455e+52*cos(theta)**35 - 2.34290021792244e+52*cos(theta)**33 + 7.18380554624301e+51*cos(theta)**31 - 1.8404791068887e+51*cos(theta)**29 + 3.92455103674797e+50*cos(theta)**27 - 6.92567830014348e+49*cos(theta)**25 + 1.00372149277442e+49*cos(theta)**23 - 1.18277381309701e+48*cos(theta)**21 + 1.11884009347014e+47*cos(theta)**19 - 8.35830738241129e+45*cos(theta)**17 + 4.82892864914161e+44*cos(theta)**15 - 2.09953419527896e+43*cos(theta)**13 + 6.62474382005498e+41*cos(theta)**11 - 1.44301350535851e+40*cos(theta)**9 + 2.01820070679512e+38*cos(theta)**7 - 1.61825944416562e+36*cos(theta)**5 + 6.08368212092337e+33*cos(theta)**3 - 6.76716587421954e+30*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl75_m17(theta, phi):
    return 6.73909887487811e-32*(1.0 - cos(theta)**2)**8.5*(2.59334576826228e+52*cos(theta)**58 - 2.87704735230709e+53*cos(theta)**56 + 1.50702480358943e+54*cos(theta)**54 - 4.95759194008383e+54*cos(theta)**52 + 1.14925994974671e+55*cos(theta)**50 - 1.99694104743222e+55*cos(theta)**48 + 2.70089868285797e+55*cos(theta)**46 - 2.91494279119708e+55*cos(theta)**44 + 2.5532739634004e+55*cos(theta)**42 - 1.8365654824459e+55*cos(theta)**40 + 1.09352753916626e+55*cos(theta)**38 - 5.41754658233885e+54*cos(theta)**36 + 2.23953697301409e+54*cos(theta)**34 - 7.73157071914404e+53*cos(theta)**32 + 2.22697971933533e+53*cos(theta)**30 - 5.33738940997724e+52*cos(theta)**28 + 1.05962877992195e+52*cos(theta)**26 - 1.73141957503587e+51*cos(theta)**24 + 2.30855943338116e+50*cos(theta)**22 - 2.48382500750372e+49*cos(theta)**20 + 2.12579617759327e+48*cos(theta)**18 - 1.42091225500992e+47*cos(theta)**16 + 7.24339297371242e+45*cos(theta)**14 - 2.72939445386265e+44*cos(theta)**12 + 7.28721820206047e+42*cos(theta)**10 - 1.29871215482266e+41*cos(theta)**8 + 1.41274049475658e+39*cos(theta)**6 - 8.09129722082808e+36*cos(theta)**4 + 1.82510463627701e+34*cos(theta)**2 - 6.76716587421954e+30)*cos(17*phi)

#@torch.jit.script
def Yl75_m18(theta, phi):
    return 9.17585109498617e-34*(1.0 - cos(theta)**2)**9*(1.50414054559213e+54*cos(theta)**57 - 1.61114651729197e+55*cos(theta)**55 + 8.1379339393829e+55*cos(theta)**53 - 2.57794780884359e+56*cos(theta)**51 + 5.74629974873353e+56*cos(theta)**49 - 9.58531702767466e+56*cos(theta)**47 + 1.24241339411467e+57*cos(theta)**45 - 1.28257482812671e+57*cos(theta)**43 + 1.07237506462817e+57*cos(theta)**41 - 7.34626192978362e+56*cos(theta)**39 + 4.1554046488318e+56*cos(theta)**37 - 1.95031676964199e+56*cos(theta)**35 + 7.61442570824791e+55*cos(theta)**33 - 2.47410263012609e+55*cos(theta)**31 + 6.680939158006e+54*cos(theta)**29 - 1.49446903479363e+54*cos(theta)**27 + 2.75503482779708e+53*cos(theta)**25 - 4.15540698008609e+52*cos(theta)**23 + 5.07883075343855e+51*cos(theta)**21 - 4.96765001500743e+50*cos(theta)**19 + 3.82643311966789e+49*cos(theta)**17 - 2.27345960801587e+48*cos(theta)**15 + 1.01407501631974e+47*cos(theta)**13 - 3.27527334463518e+45*cos(theta)**11 + 7.28721820206047e+43*cos(theta)**9 - 1.03896972385813e+42*cos(theta)**7 + 8.4764429685395e+39*cos(theta)**5 - 3.23651888833123e+37*cos(theta)**3 + 3.65020927255402e+34*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl75_m19(theta, phi):
    return 1.25355964465416e-35*(1.0 - cos(theta)**2)**9.5*(8.57360110987511e+55*cos(theta)**56 - 8.86130584510582e+56*cos(theta)**54 + 4.31310498787294e+57*cos(theta)**52 - 1.31475338251023e+58*cos(theta)**50 + 2.81568687687943e+58*cos(theta)**48 - 4.50509900300709e+58*cos(theta)**46 + 5.590860273516e+58*cos(theta)**44 - 5.51507176094487e+58*cos(theta)**42 + 4.39673776497549e+58*cos(theta)**40 - 2.86504215261561e+58*cos(theta)**38 + 1.53749972006777e+58*cos(theta)**36 - 6.82610869374695e+57*cos(theta)**34 + 2.51276048372181e+57*cos(theta)**32 - 7.66971815339088e+56*cos(theta)**30 + 1.93747235582174e+56*cos(theta)**28 - 4.0350663939428e+55*cos(theta)**26 + 6.88758706949269e+54*cos(theta)**24 - 9.557436054198e+53*cos(theta)**22 + 1.0665544582221e+53*cos(theta)**20 - 9.43853502851413e+51*cos(theta)**18 + 6.50493630343541e+50*cos(theta)**16 - 3.41018941202381e+49*cos(theta)**14 + 1.31829752121566e+48*cos(theta)**12 - 3.6028006790987e+46*cos(theta)**10 + 6.55849638185443e+44*cos(theta)**8 - 7.27278806700689e+42*cos(theta)**6 + 4.23822148426975e+40*cos(theta)**4 - 9.7095566649937e+37*cos(theta)**2 + 3.65020927255402e+34)*cos(19*phi)

#@torch.jit.script
def Yl75_m20(theta, phi):
    return 1.71865690189719e-37*(1.0 - cos(theta)**2)**10*(4.80121662153006e+57*cos(theta)**55 - 4.78510515635714e+58*cos(theta)**53 + 2.24281459369393e+59*cos(theta)**51 - 6.57376691255116e+59*cos(theta)**49 + 1.35152970090213e+60*cos(theta)**47 - 2.07234554138326e+60*cos(theta)**45 + 2.45997852034704e+60*cos(theta)**43 - 2.31633013959685e+60*cos(theta)**41 + 1.7586951059902e+60*cos(theta)**39 - 1.08871601799393e+60*cos(theta)**37 + 5.53499899224396e+59*cos(theta)**35 - 2.32087695587396e+59*cos(theta)**33 + 8.0408335479098e+58*cos(theta)**31 - 2.30091544601727e+58*cos(theta)**29 + 5.42492259630087e+57*cos(theta)**27 - 1.04911726242513e+57*cos(theta)**25 + 1.65302089667825e+56*cos(theta)**23 - 2.10263593192356e+55*cos(theta)**21 + 2.13310891644419e+54*cos(theta)**19 - 1.69893630513254e+53*cos(theta)**17 + 1.04078980854967e+52*cos(theta)**15 - 4.77426517683333e+50*cos(theta)**13 + 1.58195702545879e+49*cos(theta)**11 - 3.6028006790987e+47*cos(theta)**9 + 5.24679710548354e+45*cos(theta)**7 - 4.36367284020413e+43*cos(theta)**5 + 1.6952885937079e+41*cos(theta)**3 - 1.94191133299874e+38*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl75_m21(theta, phi):
    return 2.36522371709142e-39*(1.0 - cos(theta)**2)**10.5*(2.64066914184154e+59*cos(theta)**54 - 2.53610573286929e+60*cos(theta)**52 + 1.1438354427839e+61*cos(theta)**50 - 3.22114578715007e+61*cos(theta)**48 + 6.35218959424e+61*cos(theta)**46 - 9.32555493622468e+61*cos(theta)**44 + 1.05779076374923e+62*cos(theta)**42 - 9.49695357234707e+61*cos(theta)**40 + 6.85891091336177e+61*cos(theta)**38 - 4.02824926657755e+61*cos(theta)**36 + 1.93724964728539e+61*cos(theta)**34 - 7.65889395438408e+60*cos(theta)**32 + 2.49265839985204e+60*cos(theta)**30 - 6.67265479345007e+59*cos(theta)**28 + 1.46472910100123e+59*cos(theta)**26 - 2.62279315606282e+58*cos(theta)**24 + 3.80194806235997e+57*cos(theta)**22 - 4.41553545703948e+56*cos(theta)**20 + 4.05290694124397e+55*cos(theta)**18 - 2.88819171872532e+54*cos(theta)**16 + 1.5611847128245e+53*cos(theta)**14 - 6.20654472988333e+51*cos(theta)**12 + 1.74015272800467e+50*cos(theta)**10 - 3.24252061118883e+48*cos(theta)**8 + 3.67275797383848e+46*cos(theta)**6 - 2.18183642010207e+44*cos(theta)**4 + 5.0858657811237e+41*cos(theta)**2 - 1.94191133299874e+38)*cos(21*phi)

#@torch.jit.script
def Yl75_m22(theta, phi):
    return 3.26805591233487e-41*(1.0 - cos(theta)**2)**11*(1.42596133659443e+61*cos(theta)**53 - 1.31877498109203e+62*cos(theta)**51 + 5.71917721391951e+62*cos(theta)**49 - 1.54614997783203e+63*cos(theta)**47 + 2.9220072133504e+63*cos(theta)**45 - 4.10324417193886e+63*cos(theta)**43 + 4.44272120774675e+63*cos(theta)**41 - 3.79878142893883e+63*cos(theta)**39 + 2.60638614707747e+63*cos(theta)**37 - 1.45016973596792e+63*cos(theta)**35 + 6.58664880077031e+62*cos(theta)**33 - 2.45084606540291e+62*cos(theta)**31 + 7.47797519955611e+61*cos(theta)**29 - 1.86834334216602e+61*cos(theta)**27 + 3.80829566260321e+60*cos(theta)**25 - 6.29470357455076e+59*cos(theta)**23 + 8.36428573719193e+58*cos(theta)**21 - 8.83107091407896e+57*cos(theta)**19 + 7.29523249423914e+56*cos(theta)**17 - 4.62110674996052e+55*cos(theta)**15 + 2.1856585979543e+54*cos(theta)**13 - 7.44785367585999e+52*cos(theta)**11 + 1.74015272800467e+51*cos(theta)**9 - 2.59401648895106e+49*cos(theta)**7 + 2.20365478430309e+47*cos(theta)**5 - 8.72734568040827e+44*cos(theta)**3 + 1.01717315622474e+42*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl75_m23(theta, phi):
    return 4.53459500720562e-43*(1.0 - cos(theta)**2)**11.5*(7.55759508395047e+62*cos(theta)**52 - 6.72575240356935e+63*cos(theta)**50 + 2.80239683482056e+64*cos(theta)**48 - 7.26690489581056e+64*cos(theta)**46 + 1.31490324600768e+65*cos(theta)**44 - 1.76439499393371e+65*cos(theta)**42 + 1.82151569517617e+65*cos(theta)**40 - 1.48152475728614e+65*cos(theta)**38 + 9.64362874418665e+64*cos(theta)**36 - 5.07559407588771e+64*cos(theta)**34 + 2.1735941042542e+64*cos(theta)**32 - 7.59762280274901e+63*cos(theta)**30 + 2.16861280787127e+63*cos(theta)**28 - 5.04452702384825e+62*cos(theta)**26 + 9.52073915650803e+61*cos(theta)**24 - 1.44778182214668e+61*cos(theta)**22 + 1.7565000048103e+60*cos(theta)**20 - 1.677903473675e+59*cos(theta)**18 + 1.24018952402065e+58*cos(theta)**16 - 6.93166012494077e+56*cos(theta)**14 + 2.84135617734059e+55*cos(theta)**12 - 8.19263904344599e+53*cos(theta)**10 + 1.5661374552042e+52*cos(theta)**8 - 1.81581154226574e+50*cos(theta)**6 + 1.10182739215154e+48*cos(theta)**4 - 2.61820370412248e+45*cos(theta)**2 + 1.01717315622474e+42)*cos(23*phi)

#@torch.jit.script
def Yl75_m24(theta, phi):
    return 6.32003140565624e-45*(1.0 - cos(theta)**2)**12*(3.92994944365425e+64*cos(theta)**51 - 3.36287620178467e+65*cos(theta)**49 + 1.34515048071387e+66*cos(theta)**47 - 3.34277625207286e+66*cos(theta)**45 + 5.78557428243379e+66*cos(theta)**43 - 7.41045897452158e+66*cos(theta)**41 + 7.28606278070467e+66*cos(theta)**39 - 5.62979407768734e+66*cos(theta)**37 + 3.47170634790719e+66*cos(theta)**35 - 1.72570198580182e+66*cos(theta)**33 + 6.95550113361345e+65*cos(theta)**31 - 2.2792868408247e+65*cos(theta)**29 + 6.07211586203956e+64*cos(theta)**27 - 1.31157702620055e+64*cos(theta)**25 + 2.28497739756193e+63*cos(theta)**23 - 3.18512000872269e+62*cos(theta)**21 + 3.51300000962061e+61*cos(theta)**19 - 3.020226252615e+60*cos(theta)**17 + 1.98430323843305e+59*cos(theta)**15 - 9.70432417491708e+57*cos(theta)**13 + 3.4096274128087e+56*cos(theta)**11 - 8.19263904344599e+54*cos(theta)**9 + 1.25290996416336e+53*cos(theta)**7 - 1.08948692535945e+51*cos(theta)**5 + 4.40730956860617e+48*cos(theta)**3 - 5.23640740824496e+45*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl75_m25(theta, phi):
    return 8.84981410777198e-47*(1.0 - cos(theta)**2)**12.5*(2.00427421626367e+66*cos(theta)**50 - 1.64780933887449e+67*cos(theta)**48 + 6.32220725935519e+67*cos(theta)**46 - 1.50424931343279e+68*cos(theta)**44 + 2.48779694144653e+68*cos(theta)**42 - 3.03828817955385e+68*cos(theta)**40 + 2.84156448447482e+68*cos(theta)**38 - 2.08302380874432e+68*cos(theta)**36 + 1.21509722176752e+68*cos(theta)**34 - 5.69481655314601e+67*cos(theta)**32 + 2.15620535142017e+67*cos(theta)**30 - 6.60993183839164e+66*cos(theta)**28 + 1.63947128275068e+66*cos(theta)**26 - 3.27894256550136e+65*cos(theta)**24 + 5.25544801439243e+64*cos(theta)**22 - 6.68875201831764e+63*cos(theta)**20 + 6.67470001827916e+62*cos(theta)**18 - 5.13438462944551e+61*cos(theta)**16 + 2.97645485764957e+60*cos(theta)**14 - 1.26156214273922e+59*cos(theta)**12 + 3.75059015408958e+57*cos(theta)**10 - 7.37337513910139e+55*cos(theta)**8 + 8.77036974914354e+53*cos(theta)**6 - 5.44743462679723e+51*cos(theta)**4 + 1.32219287058185e+49*cos(theta)**2 - 5.23640740824496e+45)*cos(25*phi)

#@torch.jit.script
def Yl75_m26(theta, phi):
    return 1.24534149550957e-48*(1.0 - cos(theta)**2)**13*(1.00213710813183e+68*cos(theta)**49 - 7.90948482659755e+68*cos(theta)**47 + 2.90821533930339e+69*cos(theta)**45 - 6.61869697910426e+69*cos(theta)**43 + 1.04487471540754e+70*cos(theta)**41 - 1.21531527182154e+70*cos(theta)**39 + 1.07979450410043e+70*cos(theta)**37 - 7.49888571147954e+69*cos(theta)**35 + 4.13133055400956e+69*cos(theta)**33 - 1.82234129700672e+69*cos(theta)**31 + 6.46861605426051e+68*cos(theta)**29 - 1.85078091474966e+68*cos(theta)**27 + 4.26262533515177e+67*cos(theta)**25 - 7.86946215720327e+66*cos(theta)**23 + 1.15619856316633e+66*cos(theta)**21 - 1.33775040366353e+65*cos(theta)**19 + 1.20144600329025e+64*cos(theta)**17 - 8.21501540711281e+62*cos(theta)**15 + 4.1670368007094e+61*cos(theta)**13 - 1.51387457128706e+60*cos(theta)**11 + 3.75059015408958e+58*cos(theta)**9 - 5.89870011128111e+56*cos(theta)**7 + 5.26222184948613e+54*cos(theta)**5 - 2.17897385071889e+52*cos(theta)**3 + 2.6443857411637e+49*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl75_m27(theta, phi):
    return 1.76153117420814e-50*(1.0 - cos(theta)**2)**13.5*(4.91047182984598e+69*cos(theta)**48 - 3.71745786850085e+70*cos(theta)**46 + 1.30869690268652e+71*cos(theta)**44 - 2.84603970101483e+71*cos(theta)**42 + 4.28398633317092e+71*cos(theta)**40 - 4.739729560104e+71*cos(theta)**38 + 3.9952396651716e+71*cos(theta)**36 - 2.62460999901784e+71*cos(theta)**34 + 1.36333908282316e+71*cos(theta)**32 - 5.64925802072084e+70*cos(theta)**30 + 1.87589865573555e+70*cos(theta)**28 - 4.99710846982408e+69*cos(theta)**26 + 1.06565633378794e+69*cos(theta)**24 - 1.80997629615675e+68*cos(theta)**22 + 2.4280169826493e+67*cos(theta)**20 - 2.5417257669607e+66*cos(theta)**18 + 2.04245820559342e+65*cos(theta)**16 - 1.23225231106692e+64*cos(theta)**14 + 5.41714784092221e+62*cos(theta)**12 - 1.66526202841577e+61*cos(theta)**10 + 3.37553113868062e+59*cos(theta)**8 - 4.12909007789678e+57*cos(theta)**6 + 2.63111092474306e+55*cos(theta)**4 - 6.53692155215668e+52*cos(theta)**2 + 2.6443857411637e+49)*cos(27*phi)

#@torch.jit.script
def Yl75_m28(theta, phi):
    return 2.50525018198317e-52*(1.0 - cos(theta)**2)**14*(2.35702647832607e+71*cos(theta)**47 - 1.71003061951039e+72*cos(theta)**45 + 5.7582663718207e+72*cos(theta)**43 - 1.19533667442623e+73*cos(theta)**41 + 1.71359453326837e+73*cos(theta)**39 - 1.80109723283952e+73*cos(theta)**37 + 1.43828627946178e+73*cos(theta)**35 - 8.92367399666065e+72*cos(theta)**33 + 4.3626850650341e+72*cos(theta)**31 - 1.69477740621625e+72*cos(theta)**29 + 5.25251623605953e+71*cos(theta)**27 - 1.29924820215426e+71*cos(theta)**25 + 2.55757520109106e+70*cos(theta)**23 - 3.98194785154486e+69*cos(theta)**21 + 4.85603396529861e+68*cos(theta)**19 - 4.57510638052927e+67*cos(theta)**17 + 3.26793312894947e+66*cos(theta)**15 - 1.72515323549369e+65*cos(theta)**13 + 6.50057740910666e+63*cos(theta)**11 - 1.66526202841577e+62*cos(theta)**9 + 2.70042491094449e+60*cos(theta)**7 - 2.47745404673807e+58*cos(theta)**5 + 1.05244436989723e+56*cos(theta)**3 - 1.30738431043134e+53*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl75_m29(theta, phi):
    return 3.58331925893721e-54*(1.0 - cos(theta)**2)**14.5*(1.10780244481325e+73*cos(theta)**46 - 7.69513778779676e+73*cos(theta)**44 + 2.4760545398829e+74*cos(theta)**42 - 4.90088036514754e+74*cos(theta)**40 + 6.68301867974664e+74*cos(theta)**38 - 6.66405976150623e+74*cos(theta)**36 + 5.03400197811621e+74*cos(theta)**34 - 2.94481241889802e+74*cos(theta)**32 + 1.35243237016057e+74*cos(theta)**30 - 4.91485447802713e+73*cos(theta)**28 + 1.41817938373607e+73*cos(theta)**26 - 3.24812050538565e+72*cos(theta)**24 + 5.88242296250945e+71*cos(theta)**22 - 8.3620904882442e+70*cos(theta)**20 + 9.22646453406735e+69*cos(theta)**18 - 7.77768084689975e+68*cos(theta)**16 + 4.90189969342421e+67*cos(theta)**14 - 2.2426992061418e+66*cos(theta)**12 + 7.15063515001732e+64*cos(theta)**10 - 1.49873582557419e+63*cos(theta)**8 + 1.89029743766115e+61*cos(theta)**6 - 1.23872702336903e+59*cos(theta)**4 + 3.15733310969168e+56*cos(theta)**2 - 1.30738431043134e+53)*cos(29*phi)

#@torch.jit.script
def Yl75_m30(theta, phi):
    return 5.15598848020563e-56*(1.0 - cos(theta)**2)**15*(5.09589124614096e+74*cos(theta)**45 - 3.38586062663057e+75*cos(theta)**43 + 1.03994290675082e+76*cos(theta)**41 - 1.96035214605902e+76*cos(theta)**39 + 2.53954709830372e+76*cos(theta)**37 - 2.39906151414224e+76*cos(theta)**35 + 1.71156067255951e+76*cos(theta)**33 - 9.42339974047365e+75*cos(theta)**31 + 4.05729711048171e+75*cos(theta)**29 - 1.3761592538476e+75*cos(theta)**27 + 3.68726639771379e+74*cos(theta)**25 - 7.79548921292556e+73*cos(theta)**23 + 1.29413305175208e+73*cos(theta)**21 - 1.67241809764884e+72*cos(theta)**19 + 1.66076361613212e+71*cos(theta)**17 - 1.24442893550396e+70*cos(theta)**15 + 6.8626595707939e+68*cos(theta)**13 - 2.69123904737016e+67*cos(theta)**11 + 7.15063515001732e+65*cos(theta)**9 - 1.19898866045936e+64*cos(theta)**7 + 1.13417846259669e+62*cos(theta)**5 - 4.95490809347614e+59*cos(theta)**3 + 6.31466621938335e+56*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl75_m31(theta, phi):
    return 7.46539426602489e-58*(1.0 - cos(theta)**2)**15.5*(2.29315106076343e+76*cos(theta)**44 - 1.45592006945115e+77*cos(theta)**42 + 4.26376591767836e+77*cos(theta)**40 - 7.64537336963016e+77*cos(theta)**38 + 9.39632426372378e+77*cos(theta)**36 - 8.39671529949785e+77*cos(theta)**34 + 5.64815021944639e+77*cos(theta)**32 - 2.92125391954683e+77*cos(theta)**30 + 1.1766161620397e+77*cos(theta)**28 - 3.71562998538851e+76*cos(theta)**26 + 9.21816599428448e+75*cos(theta)**24 - 1.79296251897288e+75*cos(theta)**22 + 2.71767940867936e+74*cos(theta)**20 - 3.1775943855328e+73*cos(theta)**18 + 2.82329814742461e+72*cos(theta)**16 - 1.86664340325594e+71*cos(theta)**14 + 8.92145744203207e+69*cos(theta)**12 - 2.96036295210717e+68*cos(theta)**10 + 6.43557163501559e+66*cos(theta)**8 - 8.39292062321549e+64*cos(theta)**6 + 5.67089231298344e+62*cos(theta)**4 - 1.48647242804284e+60*cos(theta)**2 + 6.31466621938335e+56)*cos(31*phi)

#@torch.jit.script
def Yl75_m32(theta, phi):
    return 1.08801409539383e-59*(1.0 - cos(theta)**2)**16*(1.00898646673591e+78*cos(theta)**43 - 6.11486429169482e+78*cos(theta)**41 + 1.70550636707134e+79*cos(theta)**39 - 2.90524188045946e+79*cos(theta)**37 + 3.38267673494056e+79*cos(theta)**35 - 2.85488320182927e+79*cos(theta)**33 + 1.80740807022285e+79*cos(theta)**31 - 8.76376175864049e+78*cos(theta)**29 + 3.29452525371115e+78*cos(theta)**27 - 9.66063796201013e+77*cos(theta)**25 + 2.21235983862827e+77*cos(theta)**23 - 3.94451754174034e+76*cos(theta)**21 + 5.43535881735873e+75*cos(theta)**19 - 5.71966989395903e+74*cos(theta)**17 + 4.51727703587938e+73*cos(theta)**15 - 2.61330076455832e+72*cos(theta)**13 + 1.07057489304385e+71*cos(theta)**11 - 2.96036295210717e+69*cos(theta)**9 + 5.14845730801247e+67*cos(theta)**7 - 5.03575237392929e+65*cos(theta)**5 + 2.26835692519338e+63*cos(theta)**3 - 2.97294485608568e+60*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl75_m33(theta, phi):
    return 1.59657166064091e-61*(1.0 - cos(theta)**2)**16.5*(4.33864180696442e+79*cos(theta)**42 - 2.50709435959487e+80*cos(theta)**40 + 6.65147483157824e+80*cos(theta)**38 - 1.07493949577e+81*cos(theta)**36 + 1.1839368572292e+81*cos(theta)**34 - 9.42111456603658e+80*cos(theta)**32 + 5.60296501769082e+80*cos(theta)**30 - 2.54149091000574e+80*cos(theta)**28 + 8.8952181850201e+79*cos(theta)**26 - 2.41515949050253e+79*cos(theta)**24 + 5.08842762884503e+78*cos(theta)**22 - 8.2834868376547e+77*cos(theta)**20 + 1.03271817529816e+77*cos(theta)**18 - 9.72343881973035e+75*cos(theta)**16 + 6.77591555381906e+74*cos(theta)**14 - 3.39729099392581e+73*cos(theta)**12 + 1.17763238234823e+72*cos(theta)**10 - 2.66432665689645e+70*cos(theta)**8 + 3.60392011560873e+68*cos(theta)**6 - 2.51787618696465e+66*cos(theta)**4 + 6.80507077558012e+63*cos(theta)**2 - 2.97294485608568e+60)*cos(33*phi)

#@torch.jit.script
def Yl75_m34(theta, phi):
    return 2.35966593012546e-63*(1.0 - cos(theta)**2)**17*(1.82222955892506e+81*cos(theta)**41 - 1.00283774383795e+82*cos(theta)**39 + 2.52756043599973e+82*cos(theta)**37 - 3.869782184772e+82*cos(theta)**35 + 4.02538531457927e+82*cos(theta)**33 - 3.01475666113171e+82*cos(theta)**31 + 1.68088950530725e+82*cos(theta)**29 - 7.11617454801608e+81*cos(theta)**27 + 2.31275672810523e+81*cos(theta)**25 - 5.79638277720608e+80*cos(theta)**23 + 1.11945407834591e+80*cos(theta)**21 - 1.65669736753094e+79*cos(theta)**19 + 1.85889271553669e+78*cos(theta)**17 - 1.55575021115686e+77*cos(theta)**15 + 9.48628177534669e+75*cos(theta)**13 - 4.07674919271097e+74*cos(theta)**11 + 1.17763238234823e+73*cos(theta)**9 - 2.13146132551716e+71*cos(theta)**7 + 2.16235206936524e+69*cos(theta)**5 - 1.00715047478586e+67*cos(theta)**3 + 1.36101415511602e+64*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl75_m35(theta, phi):
    return 3.51368035987702e-65*(1.0 - cos(theta)**2)**17.5*(7.47114119159273e+82*cos(theta)**40 - 3.911067200968e+83*cos(theta)**38 + 9.351973613199e+83*cos(theta)**36 - 1.3544237646702e+84*cos(theta)**34 + 1.32837715381116e+84*cos(theta)**32 - 9.34574564950829e+83*cos(theta)**30 + 4.87457956539101e+83*cos(theta)**28 - 1.92136712796434e+83*cos(theta)**26 + 5.78189182026307e+82*cos(theta)**24 - 1.3331680387574e+82*cos(theta)**22 + 2.35085356452641e+81*cos(theta)**20 - 3.14772499830879e+80*cos(theta)**18 + 3.16011761641237e+79*cos(theta)**16 - 2.33362531673528e+78*cos(theta)**14 + 1.23321663079507e+77*cos(theta)**12 - 4.48442411198207e+75*cos(theta)**10 + 1.05986914411341e+74*cos(theta)**8 - 1.49202292786201e+72*cos(theta)**6 + 1.08117603468262e+70*cos(theta)**4 - 3.02145142435758e+67*cos(theta)**2 + 1.36101415511602e+64)*cos(35*phi)

#@torch.jit.script
def Yl75_m36(theta, phi):
    return 5.27315777817911e-67*(1.0 - cos(theta)**2)**18*(2.98845647663709e+84*cos(theta)**39 - 1.48620553636784e+85*cos(theta)**37 + 3.36671050075164e+85*cos(theta)**35 - 4.60504079987868e+85*cos(theta)**33 + 4.25080689219571e+85*cos(theta)**31 - 2.80372369485249e+85*cos(theta)**29 + 1.36488227830948e+85*cos(theta)**27 - 4.99555453270729e+84*cos(theta)**25 + 1.38765403686314e+84*cos(theta)**23 - 2.93296968526628e+83*cos(theta)**21 + 4.70170712905281e+82*cos(theta)**19 - 5.66590499695582e+81*cos(theta)**17 + 5.05618818625978e+80*cos(theta)**15 - 3.2670754434294e+79*cos(theta)**13 + 1.47985995695408e+78*cos(theta)**11 - 4.48442411198207e+76*cos(theta)**9 + 8.47895315290728e+74*cos(theta)**7 - 8.95213756717209e+72*cos(theta)**5 + 4.32470413873048e+70*cos(theta)**3 - 6.04290284871515e+67*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl75_m37(theta, phi):
    return 7.97865067865162e-69*(1.0 - cos(theta)**2)**18.5*(1.16549802588847e+86*cos(theta)**38 - 5.49896048456101e+86*cos(theta)**36 + 1.17834867526307e+87*cos(theta)**34 - 1.51966346395996e+87*cos(theta)**32 + 1.31775013658067e+87*cos(theta)**30 - 8.13079871507221e+86*cos(theta)**28 + 3.68518215143561e+86*cos(theta)**26 - 1.24888863317682e+86*cos(theta)**24 + 3.19160428478521e+85*cos(theta)**22 - 6.15923633905918e+84*cos(theta)**20 + 8.93324354520034e+83*cos(theta)**18 - 9.63203849482489e+82*cos(theta)**16 + 7.58428227938968e+81*cos(theta)**14 - 4.24719807645822e+80*cos(theta)**12 + 1.62784595264949e+79*cos(theta)**10 - 4.03598170078386e+77*cos(theta)**8 + 5.93526720703509e+75*cos(theta)**6 - 4.47606878358604e+73*cos(theta)**4 + 1.29741124161914e+71*cos(theta)**2 - 6.04290284871515e+67)*cos(37*phi)

#@torch.jit.script
def Yl75_m38(theta, phi):
    return 1.21758259444216e-70*(1.0 - cos(theta)**2)**19*(4.42889249837617e+87*cos(theta)**37 - 1.97962577444196e+88*cos(theta)**35 + 4.00638549589445e+88*cos(theta)**33 - 4.86292308467189e+88*cos(theta)**31 + 3.95325040974201e+88*cos(theta)**29 - 2.27662364022022e+88*cos(theta)**27 + 9.58147359373258e+87*cos(theta)**25 - 2.99733271962437e+87*cos(theta)**23 + 7.02152942652747e+86*cos(theta)**21 - 1.23184726781184e+86*cos(theta)**19 + 1.60798383813606e+85*cos(theta)**17 - 1.54112615917198e+84*cos(theta)**15 + 1.06179951911455e+83*cos(theta)**13 - 5.09663769174986e+81*cos(theta)**11 + 1.62784595264949e+80*cos(theta)**9 - 3.22878536062709e+78*cos(theta)**7 + 3.56116032422106e+76*cos(theta)**5 - 1.79042751343442e+74*cos(theta)**3 + 2.59482248323829e+71*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl75_m39(theta, phi):
    return 1.87475768896644e-72*(1.0 - cos(theta)**2)**19.5*(1.63869022439918e+89*cos(theta)**36 - 6.92869021054688e+89*cos(theta)**34 + 1.32210721364517e+90*cos(theta)**32 - 1.50750615624829e+90*cos(theta)**30 + 1.14644261882518e+90*cos(theta)**28 - 6.14688382859459e+89*cos(theta)**26 + 2.39536839843314e+89*cos(theta)**24 - 6.89386525513606e+88*cos(theta)**22 + 1.47452117957077e+88*cos(theta)**20 - 2.34050980884249e+87*cos(theta)**18 + 2.7335725248313e+86*cos(theta)**16 - 2.31168923875797e+85*cos(theta)**14 + 1.38033937484892e+84*cos(theta)**12 - 5.60630146092485e+82*cos(theta)**10 + 1.46506135738454e+81*cos(theta)**8 - 2.26014975243896e+79*cos(theta)**6 + 1.78058016211053e+77*cos(theta)**4 - 5.37128254030325e+74*cos(theta)**2 + 2.59482248323829e+71)*cos(39*phi)

#@torch.jit.script
def Yl75_m40(theta, phi):
    return 2.91370093207783e-74*(1.0 - cos(theta)**2)**20*(5.89928480783706e+90*cos(theta)**35 - 2.35575467158594e+91*cos(theta)**33 + 4.23074308366454e+91*cos(theta)**31 - 4.52251846874486e+91*cos(theta)**29 + 3.21003933271051e+91*cos(theta)**27 - 1.59818979543459e+91*cos(theta)**25 + 5.74888415623955e+90*cos(theta)**23 - 1.51665035612993e+90*cos(theta)**21 + 2.94904235914154e+89*cos(theta)**19 - 4.21291765591648e+88*cos(theta)**17 + 4.37371603973009e+87*cos(theta)**15 - 3.23636493426116e+86*cos(theta)**13 + 1.65640724981871e+85*cos(theta)**11 - 5.60630146092485e+83*cos(theta)**9 + 1.17204908590763e+82*cos(theta)**7 - 1.35608985146338e+80*cos(theta)**5 + 7.12232064844211e+77*cos(theta)**3 - 1.07425650806065e+75*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl75_m41(theta, phi):
    return 4.57279735708286e-76*(1.0 - cos(theta)**2)**20.5*(2.06474968274297e+92*cos(theta)**34 - 7.7739904162336e+92*cos(theta)**32 + 1.31153035593601e+93*cos(theta)**30 - 1.31153035593601e+93*cos(theta)**28 + 8.66710619831838e+92*cos(theta)**26 - 3.99547448858649e+92*cos(theta)**24 + 1.3222433559351e+92*cos(theta)**22 - 3.18496574787286e+91*cos(theta)**20 + 5.60318048236892e+90*cos(theta)**18 - 7.16196001505801e+89*cos(theta)**16 + 6.56057405959513e+88*cos(theta)**14 - 4.20727441453951e+87*cos(theta)**12 + 1.82204797480058e+86*cos(theta)**10 - 5.04567131483236e+84*cos(theta)**8 + 8.20434360135344e+82*cos(theta)**6 - 6.78044925731689e+80*cos(theta)**4 + 2.13669619453263e+78*cos(theta)**2 - 1.07425650806065e+75)*cos(41*phi)

#@torch.jit.script
def Yl75_m42(theta, phi):
    return 7.25019298454061e-78*(1.0 - cos(theta)**2)**21*(7.0201489213261e+93*cos(theta)**33 - 2.48767693319475e+94*cos(theta)**31 + 3.93459106780802e+94*cos(theta)**29 - 3.67228499662082e+94*cos(theta)**27 + 2.25344761156278e+94*cos(theta)**25 - 9.58913877260756e+93*cos(theta)**23 + 2.90893538305721e+93*cos(theta)**21 - 6.36993149574572e+92*cos(theta)**19 + 1.00857248682641e+92*cos(theta)**17 - 1.14591360240928e+91*cos(theta)**15 + 9.18480368343318e+89*cos(theta)**13 - 5.04872929744741e+88*cos(theta)**11 + 1.82204797480058e+87*cos(theta)**9 - 4.03653705186589e+85*cos(theta)**7 + 4.92260616081206e+83*cos(theta)**5 - 2.71217970292676e+81*cos(theta)**3 + 4.27339238906527e+78*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl75_m43(theta, phi):
    return 1.16185409527301e-79*(1.0 - cos(theta)**2)**21.5*(2.31664914403761e+95*cos(theta)**32 - 7.71179849290373e+95*cos(theta)**30 + 1.14103140966433e+96*cos(theta)**28 - 9.91516949087622e+95*cos(theta)**26 + 5.63361902890694e+95*cos(theta)**24 - 2.20550191769974e+95*cos(theta)**22 + 6.10876430442014e+94*cos(theta)**20 - 1.21028698419169e+94*cos(theta)**18 + 1.71457322760489e+93*cos(theta)**16 - 1.71887040361392e+92*cos(theta)**14 + 1.19402447884631e+91*cos(theta)**12 - 5.55360222719216e+89*cos(theta)**10 + 1.63984317732052e+88*cos(theta)**8 - 2.82557593630612e+86*cos(theta)**6 + 2.46130308040603e+84*cos(theta)**4 - 8.13653910878027e+81*cos(theta)**2 + 4.27339238906527e+78)*cos(43*phi)

#@torch.jit.script
def Yl75_m44(theta, phi):
    return 1.88279537695074e-81*(1.0 - cos(theta)**2)**22*(7.41327726092036e+96*cos(theta)**31 - 2.31353954787112e+97*cos(theta)**29 + 3.19488794706012e+97*cos(theta)**27 - 2.57794406762782e+97*cos(theta)**25 + 1.35206856693767e+97*cos(theta)**23 - 4.85210421893943e+96*cos(theta)**21 + 1.22175286088403e+96*cos(theta)**19 - 2.17851657154504e+95*cos(theta)**17 + 2.74331716416782e+94*cos(theta)**15 - 2.40641856505949e+93*cos(theta)**13 + 1.43282937461558e+92*cos(theta)**11 - 5.55360222719216e+90*cos(theta)**9 + 1.31187454185641e+89*cos(theta)**7 - 1.69534556178367e+87*cos(theta)**5 + 9.84521232162413e+84*cos(theta)**3 - 1.62730782175605e+82*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl75_m45(theta, phi):
    return 3.08696462924721e-83*(1.0 - cos(theta)**2)**22.5*(2.29811595088531e+98*cos(theta)**30 - 6.70926468882624e+98*cos(theta)**28 + 8.62619745706231e+98*cos(theta)**26 - 6.44486016906954e+98*cos(theta)**24 + 3.10975770395663e+98*cos(theta)**22 - 1.01894188597728e+98*cos(theta)**20 + 2.32133043567965e+97*cos(theta)**18 - 3.70347817162656e+96*cos(theta)**16 + 4.11497574625173e+95*cos(theta)**14 - 3.12834413457734e+94*cos(theta)**12 + 1.57611231207713e+93*cos(theta)**10 - 4.99824200447294e+91*cos(theta)**8 + 9.1831217929949e+89*cos(theta)**6 - 8.47672780891837e+87*cos(theta)**4 + 2.95356369648724e+85*cos(theta)**2 - 1.62730782175605e+82)*cos(45*phi)

#@torch.jit.script
def Yl75_m46(theta, phi):
    return 5.12363685351293e-85*(1.0 - cos(theta)**2)**23*(6.89434785265593e+99*cos(theta)**29 - 1.87859411287135e+100*cos(theta)**27 + 2.2428113388362e+100*cos(theta)**25 - 1.54676644057669e+100*cos(theta)**23 + 6.84146694870459e+99*cos(theta)**21 - 2.03788377195456e+99*cos(theta)**19 + 4.17839478422338e+98*cos(theta)**17 - 5.9255650746025e+97*cos(theta)**15 + 5.76096604475243e+96*cos(theta)**13 - 3.75401296149281e+95*cos(theta)**11 + 1.57611231207713e+94*cos(theta)**9 - 3.99859360357835e+92*cos(theta)**7 + 5.50987307579694e+90*cos(theta)**5 - 3.39069112356735e+88*cos(theta)**3 + 5.90712739297447e+85*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl75_m47(theta, phi):
    return 8.61389208310165e-87*(1.0 - cos(theta)**2)**23.5*(1.99936087727022e+101*cos(theta)**28 - 5.07220410475264e+101*cos(theta)**26 + 5.6070283470905e+101*cos(theta)**24 - 3.55756281332639e+101*cos(theta)**22 + 1.43670805922796e+101*cos(theta)**20 - 3.87197916671366e+100*cos(theta)**18 + 7.10327113317974e+99*cos(theta)**16 - 8.88834761190374e+98*cos(theta)**14 + 7.48925585817816e+97*cos(theta)**12 - 4.12941425764209e+96*cos(theta)**10 + 1.41850108086942e+95*cos(theta)**8 - 2.79901552250485e+93*cos(theta)**6 + 2.75493653789847e+91*cos(theta)**4 - 1.0172073370702e+89*cos(theta)**2 + 5.90712739297447e+85)*cos(47*phi)

#@torch.jit.script
def Yl75_m48(theta, phi):
    return 1.46780328429843e-88*(1.0 - cos(theta)**2)**24*(5.59821045635662e+102*cos(theta)**27 - 1.31877306723569e+103*cos(theta)**25 + 1.34568680330172e+103*cos(theta)**23 - 7.82663818931805e+102*cos(theta)**21 + 2.87341611845593e+102*cos(theta)**19 - 6.96956250008459e+101*cos(theta)**17 + 1.13652338130876e+101*cos(theta)**15 - 1.24436866566652e+100*cos(theta)**13 + 8.98710702981379e+98*cos(theta)**11 - 4.12941425764209e+97*cos(theta)**9 + 1.13480086469554e+96*cos(theta)**7 - 1.67940931350291e+94*cos(theta)**5 + 1.10197461515939e+92*cos(theta)**3 - 2.03441467414041e+89*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl75_m49(theta, phi):
    return 2.53673517197357e-90*(1.0 - cos(theta)**2)**24.5*(1.51151682321629e+104*cos(theta)**26 - 3.29693266808922e+104*cos(theta)**24 + 3.09507964759396e+104*cos(theta)**22 - 1.64359401975679e+104*cos(theta)**20 + 5.45949062506627e+103*cos(theta)**18 - 1.18482562501438e+103*cos(theta)**16 + 1.70478507196314e+102*cos(theta)**14 - 1.61767926536648e+101*cos(theta)**12 + 9.88581773279516e+99*cos(theta)**10 - 3.71647283187788e+98*cos(theta)**8 + 7.94360605286875e+96*cos(theta)**6 - 8.39704656751454e+94*cos(theta)**4 + 3.30592384547817e+92*cos(theta)**2 - 2.03441467414041e+89)*cos(49*phi)

#@torch.jit.script
def Yl75_m50(theta, phi):
    return 4.44972785087522e-92*(1.0 - cos(theta)**2)**25*(3.92994374036235e+105*cos(theta)**25 - 7.91263840341412e+105*cos(theta)**23 + 6.80917522470671e+105*cos(theta)**21 - 3.28718803951358e+105*cos(theta)**19 + 9.82708312511928e+104*cos(theta)**17 - 1.89572100002301e+104*cos(theta)**15 + 2.38669910074839e+103*cos(theta)**13 - 1.94121511843978e+102*cos(theta)**11 + 9.88581773279516e+100*cos(theta)**9 - 2.9731782655023e+99*cos(theta)**7 + 4.76616363172125e+97*cos(theta)**5 - 3.35881862700582e+95*cos(theta)**3 + 6.61184769095633e+92*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl75_m51(theta, phi):
    return 7.92826527731477e-94*(1.0 - cos(theta)**2)**25.5*(9.82485935090586e+106*cos(theta)**24 - 1.81990683278525e+107*cos(theta)**22 + 1.42992679718841e+107*cos(theta)**20 - 6.24565727507581e+106*cos(theta)**18 + 1.67060413127028e+106*cos(theta)**16 - 2.84358150003451e+105*cos(theta)**14 + 3.10270883097291e+104*cos(theta)**12 - 2.13533663028376e+103*cos(theta)**10 + 8.89723595951565e+101*cos(theta)**8 - 2.08122478585161e+100*cos(theta)**6 + 2.38308181586063e+98*cos(theta)**4 - 1.00764558810174e+96*cos(theta)**2 + 6.61184769095633e+92)*cos(51*phi)

#@torch.jit.script
def Yl75_m52(theta, phi):
    return 1.43605373791225e-95*(1.0 - cos(theta)**2)**26*(2.35796624421741e+108*cos(theta)**23 - 4.00379503212754e+108*cos(theta)**21 + 2.85985359437682e+108*cos(theta)**19 - 1.12421830951365e+108*cos(theta)**17 + 2.67296661003244e+107*cos(theta)**15 - 3.98101410004832e+106*cos(theta)**13 + 3.72325059716749e+105*cos(theta)**11 - 2.13533663028376e+104*cos(theta)**9 + 7.11778876761252e+102*cos(theta)**7 - 1.24873487151097e+101*cos(theta)**5 + 9.5323272634425e+98*cos(theta)**3 - 2.01529117620349e+96*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl75_m53(theta, phi):
    return 2.64668215326668e-97*(1.0 - cos(theta)**2)**26.5*(5.42332236170004e+109*cos(theta)**22 - 8.40796956746784e+109*cos(theta)**20 + 5.43372182931595e+109*cos(theta)**18 - 1.9111711261732e+109*cos(theta)**16 + 4.00944991504867e+108*cos(theta)**14 - 5.17531833006282e+107*cos(theta)**12 + 4.09557565688424e+106*cos(theta)**10 - 1.92180296725538e+105*cos(theta)**8 + 4.98245213732876e+103*cos(theta)**6 - 6.24367435755484e+101*cos(theta)**4 + 2.85969817903275e+99*cos(theta)**2 - 2.01529117620349e+96)*cos(53*phi)

#@torch.jit.script
def Yl75_m54(theta, phi):
    return 4.96816022272453e-99*(1.0 - cos(theta)**2)**27*(1.19313091957401e+111*cos(theta)**21 - 1.68159391349357e+111*cos(theta)**19 + 9.78069929276872e+110*cos(theta)**17 - 3.05787380187712e+110*cos(theta)**15 + 5.61322988106813e+109*cos(theta)**13 - 6.21038199607538e+108*cos(theta)**11 + 4.09557565688424e+107*cos(theta)**9 - 1.5374423738043e+106*cos(theta)**7 + 2.98947128239726e+104*cos(theta)**5 - 2.49746974302194e+102*cos(theta)**3 + 5.7193963580655e+99*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl75_m55(theta, phi):
    return 9.5085494590717e-101*(1.0 - cos(theta)**2)**27.5*(2.50557493110542e+112*cos(theta)**20 - 3.19502843563778e+112*cos(theta)**18 + 1.66271887977068e+112*cos(theta)**16 - 4.58681070281567e+111*cos(theta)**14 + 7.29719884538857e+110*cos(theta)**12 - 6.83142019568292e+109*cos(theta)**10 + 3.68601809119582e+108*cos(theta)**8 - 1.07620966166301e+107*cos(theta)**6 + 1.49473564119863e+105*cos(theta)**4 - 7.49240922906581e+102*cos(theta)**2 + 5.7193963580655e+99)*cos(55*phi)

#@torch.jit.script
def Yl75_m56(theta, phi):
    return 1.85764885480854e-102*(1.0 - cos(theta)**2)**28*(5.01114986221083e+113*cos(theta)**19 - 5.751051184148e+113*cos(theta)**17 + 2.66035020763309e+113*cos(theta)**15 - 6.42153498394194e+112*cos(theta)**13 + 8.75663861446629e+111*cos(theta)**11 - 6.83142019568292e+110*cos(theta)**9 + 2.94881447295665e+109*cos(theta)**7 - 6.45725796997808e+107*cos(theta)**5 + 5.97894256479452e+105*cos(theta)**3 - 1.49848184581316e+103*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl75_m57(theta, phi):
    return 3.70936746208647e-104*(1.0 - cos(theta)**2)**28.5*(9.52118473820058e+114*cos(theta)**18 - 9.77678701305161e+114*cos(theta)**16 + 3.99052531144964e+114*cos(theta)**14 - 8.34799547912452e+113*cos(theta)**12 + 9.63230247591291e+112*cos(theta)**10 - 6.14827817611463e+111*cos(theta)**8 + 2.06417013106966e+110*cos(theta)**6 - 3.22862898498904e+108*cos(theta)**4 + 1.79368276943835e+106*cos(theta)**2 - 1.49848184581316e+103)*cos(57*phi)

#@torch.jit.script
def Yl75_m58(theta, phi):
    return 7.58119705203574e-106*(1.0 - cos(theta)**2)**29*(1.71381325287611e+116*cos(theta)**17 - 1.56428592208826e+116*cos(theta)**15 + 5.58673543602949e+115*cos(theta)**13 - 1.00175945749494e+115*cos(theta)**11 + 9.63230247591291e+113*cos(theta)**9 - 4.9186225408917e+112*cos(theta)**7 + 1.2385020786418e+111*cos(theta)**5 - 1.29145159399562e+109*cos(theta)**3 + 3.58736553887671e+106*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl75_m59(theta, phi):
    return 1.58840382857838e-107*(1.0 - cos(theta)**2)**29.5*(2.91348252988938e+117*cos(theta)**16 - 2.34642888313239e+117*cos(theta)**14 + 7.26275606683834e+116*cos(theta)**12 - 1.10193540324444e+116*cos(theta)**10 + 8.66907222832162e+114*cos(theta)**8 - 3.44303577862419e+113*cos(theta)**6 + 6.19251039320898e+111*cos(theta)**4 - 3.87435478198685e+109*cos(theta)**2 + 3.58736553887671e+106)*cos(59*phi)

#@torch.jit.script
def Yl75_m60(theta, phi):
    return 3.41770087507565e-109*(1.0 - cos(theta)**2)**30*(4.66157204782301e+118*cos(theta)**15 - 3.28500043638534e+118*cos(theta)**13 + 8.715307280206e+117*cos(theta)**11 - 1.10193540324444e+117*cos(theta)**9 + 6.9352577826573e+115*cos(theta)**7 - 2.06582146717451e+114*cos(theta)**5 + 2.47700415728359e+112*cos(theta)**3 - 7.74870956397369e+109*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl75_m61(theta, phi):
    return 7.56691692322602e-111*(1.0 - cos(theta)**2)**30.5*(6.99235807173451e+119*cos(theta)**14 - 4.27050056730094e+119*cos(theta)**12 + 9.5868380082266e+118*cos(theta)**10 - 9.91741862919994e+117*cos(theta)**8 + 4.85468044786011e+116*cos(theta)**6 - 1.03291073358726e+115*cos(theta)**4 + 7.43101247185077e+112*cos(theta)**2 - 7.74870956397369e+109)*cos(61*phi)

#@torch.jit.script
def Yl75_m62(theta, phi):
    return 1.72780475345411e-112*(1.0 - cos(theta)**2)**31*(9.78930130042831e+120*cos(theta)**13 - 5.12460068076113e+120*cos(theta)**11 + 9.5868380082266e+119*cos(theta)**9 - 7.93393490335995e+118*cos(theta)**7 + 2.91280826871606e+117*cos(theta)**5 - 4.13164293434903e+115*cos(theta)**3 + 1.48620249437015e+113*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl75_m63(theta, phi):
    return 4.07927933312929e-114*(1.0 - cos(theta)**2)**31.5*(1.27260916905568e+122*cos(theta)**12 - 5.63706074883724e+121*cos(theta)**10 + 8.62815420740394e+120*cos(theta)**8 - 5.55375443235196e+119*cos(theta)**6 + 1.45640413435803e+118*cos(theta)**4 - 1.23949288030471e+116*cos(theta)**2 + 1.48620249437015e+113)*cos(63*phi)

#@torch.jit.script
def Yl75_m64(theta, phi):
    return 9.98815841981289e-116*(1.0 - cos(theta)**2)**32*(1.52713100286682e+123*cos(theta)**11 - 5.63706074883724e+122*cos(theta)**9 + 6.90252336592316e+121*cos(theta)**7 - 3.33225265941118e+120*cos(theta)**5 + 5.82561653743213e+118*cos(theta)**3 - 2.47898576060942e+116*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl75_m65(theta, phi):
    return 2.54521844314586e-117*(1.0 - cos(theta)**2)**32.5*(1.6798441031535e+124*cos(theta)**10 - 5.07335467395352e+123*cos(theta)**8 + 4.83176635614621e+122*cos(theta)**6 - 1.66612632970559e+121*cos(theta)**4 + 1.74768496122964e+119*cos(theta)**2 - 2.47898576060942e+116)*cos(65*phi)

#@torch.jit.script
def Yl75_m66(theta, phi):
    return 6.77821757535069e-119*(1.0 - cos(theta)**2)**33*(1.6798441031535e+125*cos(theta)**9 - 4.05868373916282e+124*cos(theta)**7 + 2.89905981368773e+123*cos(theta)**5 - 6.66450531882236e+121*cos(theta)**3 + 3.49536992245928e+119*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl75_m67(theta, phi):
    return 1.89605127723776e-120*(1.0 - cos(theta)**2)**33.5*(1.51185969283815e+126*cos(theta)**8 - 2.84107861741397e+125*cos(theta)**6 + 1.44952990684386e+124*cos(theta)**4 - 1.99935159564671e+122*cos(theta)**2 + 3.49536992245928e+119)*cos(67*phi)

#@torch.jit.script
def Yl75_m68(theta, phi):
    return 5.60579311830811e-122*(1.0 - cos(theta)**2)**34*(1.20948775427052e+127*cos(theta)**7 - 1.70464717044838e+126*cos(theta)**5 + 5.79811962737545e+124*cos(theta)**3 - 3.99870319129341e+122*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl75_m69(theta, phi):
    return 1.7656588681334e-123*(1.0 - cos(theta)**2)**34.5*(8.46641427989363e+127*cos(theta)**6 - 8.52323585224191e+126*cos(theta)**4 + 1.73943588821264e+125*cos(theta)**2 - 3.99870319129341e+122)*cos(69*phi)

#@torch.jit.script
def Yl75_m70(theta, phi):
    return 5.98614419162843e-125*(1.0 - cos(theta)**2)**35*(5.07984856793618e+128*cos(theta)**5 - 3.40929434089676e+127*cos(theta)**3 + 3.47887177642527e+125*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl75_m71(theta, phi):
    return 2.21557136583743e-126*(1.0 - cos(theta)**2)**35.5*(2.53992428396809e+129*cos(theta)**4 - 1.02278830226903e+128*cos(theta)**2 + 3.47887177642527e+125)*cos(71*phi)

#@torch.jit.script
def Yl75_m72(theta, phi):
    return 9.13686231767905e-128*(1.0 - cos(theta)**2)**36*(1.01596971358724e+130*cos(theta)**3 - 2.04557660453806e+128*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl75_m73(theta, phi):
    return 4.33616296245739e-129*(1.0 - cos(theta)**2)**36.5*(3.04790914076171e+130*cos(theta)**2 - 2.04557660453806e+128)*cos(73*phi)

#@torch.jit.script
def Yl75_m74(theta, phi):
    return 15.311913801845*(1.0 - cos(theta)**2)**37*cos(74*phi)*cos(theta)

#@torch.jit.script
def Yl75_m75(theta, phi):
    return 1.25021252666665*(1.0 - cos(theta)**2)**37.5*cos(75*phi)

#@torch.jit.script
def Yl76_m_minus_76(theta, phi):
    return 1.25431832598384*(1.0 - cos(theta)**2)**38*sin(76*phi)

#@torch.jit.script
def Yl76_m_minus_75(theta, phi):
    return 15.4642749057508*(1.0 - cos(theta)**2)**37.5*sin(75*phi)*cos(theta)

#@torch.jit.script
def Yl76_m_minus_74(theta, phi):
    return 2.91960483102034e-131*(1.0 - cos(theta)**2)**37*(4.60234280255018e+132*cos(theta)**2 - 3.04790914076171e+130)*sin(74*phi)

#@torch.jit.script
def Yl76_m_minus_73(theta, phi):
    return 6.19341712319846e-130*(1.0 - cos(theta)**2)**36.5*(1.53411426751673e+132*cos(theta)**3 - 3.04790914076171e+130*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl76_m_minus_72(theta, phi):
    return 1.51200581131519e-128*(1.0 - cos(theta)**2)**36*(3.83528566879182e+131*cos(theta)**4 - 1.52395457038085e+130*cos(theta)**2 + 5.11394151134515e+127)*sin(72*phi)

#@torch.jit.script
def Yl76_m_minus_71(theta, phi):
    return 4.11310049032803e-127*(1.0 - cos(theta)**2)**35.5*(7.67057133758363e+130*cos(theta)**5 - 5.07984856793618e+129*cos(theta)**3 + 5.11394151134515e+127*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl76_m_minus_70(theta, phi):
    return 1.22152852433332e-125*(1.0 - cos(theta)**2)**35*(1.27842855626394e+130*cos(theta)**6 - 1.26996214198404e+129*cos(theta)**4 + 2.55697075567257e+127*cos(theta)**2 - 5.79811962737545e+124)*sin(70*phi)

#@torch.jit.script
def Yl76_m_minus_69(theta, phi):
    return 3.90507213550102e-124*(1.0 - cos(theta)**2)**34.5*(1.82632650894848e+129*cos(theta)**7 - 2.53992428396809e+128*cos(theta)**5 + 8.52323585224191e+126*cos(theta)**3 - 5.79811962737545e+124*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl76_m_minus_68(theta, phi):
    return 1.3300196436452e-122*(1.0 - cos(theta)**2)**34*(2.2829081361856e+128*cos(theta)**8 - 4.23320713994682e+127*cos(theta)**6 + 2.13080896306048e+126*cos(theta)**4 - 2.89905981368773e+124*cos(theta)**2 + 4.99837898911677e+121)*sin(68*phi)

#@torch.jit.script
def Yl76_m_minus_67(theta, phi):
    return 4.78807071712273e-121*(1.0 - cos(theta)**2)**33.5*(2.53656459576178e+127*cos(theta)**9 - 6.04743877135259e+126*cos(theta)**7 + 4.26161792612096e+125*cos(theta)**5 - 9.66353271229242e+123*cos(theta)**3 + 4.99837898911677e+121*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl76_m_minus_66(theta, phi):
    return 1.81062525953883e-119*(1.0 - cos(theta)**2)**33*(2.53656459576178e+126*cos(theta)**10 - 7.55929846419074e+125*cos(theta)**8 + 7.10269654353493e+124*cos(theta)**6 - 2.4158831780731e+123*cos(theta)**4 + 2.49918949455838e+121*cos(theta)**2 - 3.49536992245928e+118)*sin(66*phi)

#@torch.jit.script
def Yl76_m_minus_65(theta, phi):
    return 7.15597952988258e-118*(1.0 - cos(theta)**2)**32.5*(2.30596781432889e+125*cos(theta)**11 - 8.39922051576749e+124*cos(theta)**9 + 1.0146709347907e+124*cos(theta)**7 - 4.83176635614621e+122*cos(theta)**5 + 8.33063164852795e+120*cos(theta)**3 - 3.49536992245928e+118*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl76_m_minus_64(theta, phi):
    return 2.94353543906491e-116*(1.0 - cos(theta)**2)**32*(1.92163984527408e+124*cos(theta)**12 - 8.39922051576749e+123*cos(theta)**10 + 1.26833866848838e+123*cos(theta)**8 - 8.05294392691035e+121*cos(theta)**6 + 2.08265791213199e+120*cos(theta)**4 - 1.74768496122964e+118*cos(theta)**2 + 2.06582146717451e+115)*sin(64*phi)

#@torch.jit.script
def Yl76_m_minus_63(theta, phi):
    return 1.25575513550519e-114*(1.0 - cos(theta)**2)**31.5*(1.47818449636468e+123*cos(theta)**13 - 7.63565501433408e+122*cos(theta)**11 + 1.40926518720931e+122*cos(theta)**9 - 1.15042056098719e+121*cos(theta)**7 + 4.16531582426397e+119*cos(theta)**5 - 5.82561653743213e+117*cos(theta)**3 + 2.06582146717451e+115*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl76_m_minus_62(theta, phi):
    return 5.539574161284e-113*(1.0 - cos(theta)**2)**31*(1.05584606883191e+122*cos(theta)**14 - 6.3630458452784e+121*cos(theta)**12 + 1.40926518720931e+121*cos(theta)**10 - 1.43802570123399e+120*cos(theta)**8 + 6.94219304043996e+118*cos(theta)**6 - 1.45640413435803e+117*cos(theta)**4 + 1.03291073358726e+115*cos(theta)**2 - 1.0615732102644e+112)*sin(62*phi)

#@torch.jit.script
def Yl76_m_minus_61(theta, phi):
    return 2.52035405268617e-111*(1.0 - cos(theta)**2)**30.5*(7.03897379221274e+120*cos(theta)**15 - 4.89465065021416e+120*cos(theta)**13 + 1.28115017019028e+120*cos(theta)**11 - 1.59780633470443e+119*cos(theta)**9 + 9.91741862919994e+117*cos(theta)**7 - 2.91280826871606e+116*cos(theta)**5 + 3.44303577862419e+114*cos(theta)**3 - 1.0615732102644e+112*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl76_m_minus_60(theta, phi):
    return 1.17999951421831e-109*(1.0 - cos(theta)**2)**30*(4.39935862013296e+119*cos(theta)**16 - 3.49617903586725e+119*cos(theta)**14 + 1.06762514182524e+119*cos(theta)**12 - 1.59780633470443e+118*cos(theta)**10 + 1.23967732864999e+117*cos(theta)**8 - 4.85468044786011e+115*cos(theta)**6 + 8.60758944656048e+113*cos(theta)**4 - 5.30786605132198e+111*cos(theta)**2 + 4.84294347748356e+108)*sin(60*phi)

#@torch.jit.script
def Yl76_m_minus_59(theta, phi):
    return 5.67382247644406e-108*(1.0 - cos(theta)**2)**29.5*(2.58785801184292e+118*cos(theta)**17 - 2.3307860239115e+118*cos(theta)**15 + 8.21250109096335e+117*cos(theta)**13 - 1.45255121336767e+117*cos(theta)**11 + 1.37741925405555e+116*cos(theta)**9 - 6.9352577826573e+114*cos(theta)**7 + 1.7215178893121e+113*cos(theta)**5 - 1.76928868377399e+111*cos(theta)**3 + 4.84294347748356e+108*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl76_m_minus_58(theta, phi):
    return 2.79691250186541e-106*(1.0 - cos(theta)**2)**29*(1.43769889546829e+117*cos(theta)**18 - 1.45674126494469e+117*cos(theta)**16 + 5.86607220783096e+116*cos(theta)**14 - 1.21045934447306e+116*cos(theta)**12 + 1.37741925405555e+115*cos(theta)**10 - 8.66907222832162e+113*cos(theta)**8 + 2.86919648218683e+112*cos(theta)**6 - 4.42322170943498e+110*cos(theta)**4 + 2.42147173874178e+108*cos(theta)**2 - 1.9929808549315e+105)*sin(58*phi)

#@torch.jit.script
def Yl76_m_minus_57(theta, phi):
    return 1.41126340407132e-104*(1.0 - cos(theta)**2)**28.5*(7.56683629193836e+115*cos(theta)**19 - 8.56906626438053e+115*cos(theta)**17 + 3.91071480522064e+115*cos(theta)**15 - 9.31122572671582e+114*cos(theta)**13 + 1.25219932186868e+114*cos(theta)**11 - 9.63230247591291e+112*cos(theta)**9 + 4.09885211740975e+111*cos(theta)**7 - 8.84644341886996e+109*cos(theta)**5 + 8.0715724624726e+107*cos(theta)**3 - 1.9929808549315e+105*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl76_m_minus_56(theta, phi):
    return 7.27861751466912e-103*(1.0 - cos(theta)**2)**28*(3.78341814596918e+114*cos(theta)**20 - 4.76059236910029e+114*cos(theta)**18 + 2.4441967532629e+114*cos(theta)**16 - 6.65087551908273e+113*cos(theta)**14 + 1.04349943489057e+113*cos(theta)**12 - 9.63230247591291e+111*cos(theta)**10 + 5.12356514676219e+110*cos(theta)**8 - 1.47440723647833e+109*cos(theta)**6 + 2.01789311561815e+107*cos(theta)**4 - 9.96490427465752e+104*cos(theta)**2 + 7.49240922906581e+101)*sin(56*phi)

#@torch.jit.script
def Yl76_m_minus_55(theta, phi):
    return 3.83217656884021e-101*(1.0 - cos(theta)**2)**27.5*(1.80162768855675e+113*cos(theta)**21 - 2.50557493110542e+113*cos(theta)**19 + 1.437762796037e+113*cos(theta)**17 - 4.43391701272182e+112*cos(theta)**15 + 8.02691872992743e+111*cos(theta)**13 - 8.75663861446628e+110*cos(theta)**11 + 5.6928501630691e+109*cos(theta)**9 - 2.1062960521119e+108*cos(theta)**7 + 4.0357862312363e+106*cos(theta)**5 - 3.32163475821918e+104*cos(theta)**3 + 7.49240922906581e+101*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl76_m_minus_54(theta, phi):
    return 2.05727571434266e-99*(1.0 - cos(theta)**2)**27*(8.18921676616706e+111*cos(theta)**22 - 1.25278746555271e+112*cos(theta)**20 + 7.98757108909445e+111*cos(theta)**18 - 2.77119813295114e+111*cos(theta)**16 + 5.73351337851959e+110*cos(theta)**14 - 7.29719884538857e+109*cos(theta)**12 + 5.6928501630691e+108*cos(theta)**10 - 2.63287006513987e+107*cos(theta)**8 + 6.72631038539383e+105*cos(theta)**6 - 8.30408689554794e+103*cos(theta)**4 + 3.7462046145329e+101*cos(theta)**2 - 2.5997256173025e+98)*sin(54*phi)

#@torch.jit.script
def Yl76_m_minus_53(theta, phi):
    return 1.12493672092363e-97*(1.0 - cos(theta)**2)**26.5*(3.56052902876829e+110*cos(theta)**23 - 5.96565459787004e+110*cos(theta)**21 + 4.20398478373392e+110*cos(theta)**19 - 1.63011654879479e+110*cos(theta)**17 + 3.82234225234639e+109*cos(theta)**15 - 5.61322988106813e+108*cos(theta)**13 + 5.17531833006282e+107*cos(theta)**11 - 2.92541118348874e+106*cos(theta)**9 + 9.6090148362769e+104*cos(theta)**7 - 1.66081737910959e+103*cos(theta)**5 + 1.24873487151097e+101*cos(theta)**3 - 2.5997256173025e+98*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl76_m_minus_52(theta, phi):
    return 6.2593403888518e-96*(1.0 - cos(theta)**2)**26*(1.48355376198679e+109*cos(theta)**24 - 2.71166118085002e+109*cos(theta)**22 + 2.10199239186696e+109*cos(theta)**20 - 9.05620304885992e+108*cos(theta)**18 + 2.3889639077165e+108*cos(theta)**16 - 4.00944991504867e+107*cos(theta)**14 + 4.31276527505235e+106*cos(theta)**12 - 2.92541118348875e+105*cos(theta)**10 + 1.20112685453461e+104*cos(theta)**8 - 2.76802896518265e+102*cos(theta)**6 + 3.12183717877742e+100*cos(theta)**4 - 1.29986280865125e+98*cos(theta)**2 + 8.39704656751454e+94)*sin(52*phi)

#@torch.jit.script
def Yl76_m_minus_51(theta, phi):
    return 3.54081762776956e-94*(1.0 - cos(theta)**2)**25.5*(5.93421504794714e+107*cos(theta)**25 - 1.1789831221087e+108*cos(theta)**23 + 1.00094875803189e+108*cos(theta)**21 - 4.7664226572947e+107*cos(theta)**19 + 1.40527288689206e+107*cos(theta)**17 - 2.67296661003244e+106*cos(theta)**15 + 3.31751175004027e+105*cos(theta)**13 - 2.6594647122625e+104*cos(theta)**11 + 1.33458539392735e+103*cos(theta)**9 - 3.95432709311807e+101*cos(theta)**7 + 6.24367435755484e+99*cos(theta)**5 - 4.3328760288375e+97*cos(theta)**3 + 8.39704656751454e+94*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl76_m_minus_50(theta, phi):
    return 2.03466115213945e-92*(1.0 - cos(theta)**2)**25*(2.28239040305659e+106*cos(theta)**26 - 4.91242967545293e+106*cos(theta)**24 + 4.54976708196312e+106*cos(theta)**22 - 2.38321132864735e+106*cos(theta)**20 + 7.80707159384476e+105*cos(theta)**18 - 1.67060413127028e+105*cos(theta)**16 + 2.36965125002876e+104*cos(theta)**14 - 2.21622059355208e+103*cos(theta)**12 + 1.33458539392735e+102*cos(theta)**10 - 4.94290886639758e+100*cos(theta)**8 + 1.04061239292581e+99*cos(theta)**6 - 1.08321900720938e+97*cos(theta)**4 + 4.19852328375727e+94*cos(theta)**2 - 2.54301834267551e+91)*sin(50*phi)

#@torch.jit.script
def Yl76_m_minus_49(theta, phi):
    return 1.18675002025256e-90*(1.0 - cos(theta)**2)**24.5*(8.45329778909849e+104*cos(theta)**27 - 1.96497187018117e+105*cos(theta)**25 + 1.97815960085353e+105*cos(theta)**23 - 1.13486253745112e+105*cos(theta)**21 + 4.10898504939198e+104*cos(theta)**19 - 9.82708312511928e+103*cos(theta)**17 + 1.57976750001917e+103*cos(theta)**15 - 1.70478507196314e+102*cos(theta)**13 + 1.21325944902486e+101*cos(theta)**11 - 5.49212096266398e+99*cos(theta)**9 + 1.48658913275115e+98*cos(theta)**7 - 2.16643801441875e+96*cos(theta)**5 + 1.39950776125242e+94*cos(theta)**3 - 2.54301834267551e+91*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl76_m_minus_48(theta, phi):
    return 7.02090780240922e-89*(1.0 - cos(theta)**2)**24*(3.01903492467803e+103*cos(theta)**28 - 7.55758411608143e+103*cos(theta)**26 + 8.24233167022304e+103*cos(theta)**24 - 5.15846607932326e+103*cos(theta)**22 + 2.05449252469599e+103*cos(theta)**20 - 5.45949062506626e+102*cos(theta)**18 + 9.87354687511984e+101*cos(theta)**16 - 1.21770362283081e+101*cos(theta)**14 + 1.01104954085405e+100*cos(theta)**12 - 5.49212096266398e+98*cos(theta)**10 + 1.85823641593894e+97*cos(theta)**8 - 3.61073002403125e+95*cos(theta)**6 + 3.49876940313106e+93*cos(theta)**4 - 1.27150917133776e+91*cos(theta)**2 + 7.2657666933586e+87)*sin(48*phi)

#@torch.jit.script
def Yl76_m_minus_47(theta, phi):
    return 4.21020372839927e-87*(1.0 - cos(theta)**2)**23.5*(1.04104652575105e+102*cos(theta)**29 - 2.79910522817831e+102*cos(theta)**27 + 3.29693266808922e+102*cos(theta)**25 - 2.2428113388362e+102*cos(theta)**23 + 9.78329773664757e+101*cos(theta)**21 - 2.87341611845593e+101*cos(theta)**19 + 5.8079687500705e+100*cos(theta)**17 - 8.11802415220542e+99*cos(theta)**15 + 7.77730416041578e+98*cos(theta)**13 - 4.99283723878544e+97*cos(theta)**11 + 2.06470712882105e+96*cos(theta)**9 - 5.15818574861607e+94*cos(theta)**7 + 6.99753880626212e+92*cos(theta)**5 - 4.23836390445919e+90*cos(theta)**3 + 7.2657666933586e+87*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl76_m_minus_46(theta, phi):
    return 2.55750384073561e-85*(1.0 - cos(theta)**2)**23*(3.47015508583682e+100*cos(theta)**30 - 9.9968043863511e+100*cos(theta)**28 + 1.26805102618816e+101*cos(theta)**26 - 9.34504724515084e+100*cos(theta)**24 + 4.44695351665799e+100*cos(theta)**22 - 1.43670805922796e+100*cos(theta)**20 + 3.22664930559472e+99*cos(theta)**18 - 5.07376509512839e+98*cos(theta)**16 + 5.55521725743984e+97*cos(theta)**14 - 4.16069769898786e+96*cos(theta)**12 + 2.06470712882105e+95*cos(theta)**10 - 6.44773218577009e+93*cos(theta)**8 + 1.16625646771035e+92*cos(theta)**6 - 1.0595909761148e+90*cos(theta)**4 + 3.6328833466793e+87*cos(theta)**2 - 1.96904246432483e+84)*sin(46*phi)

#@torch.jit.script
def Yl76_m_minus_45(theta, phi):
    return 1.57281287940801e-83*(1.0 - cos(theta)**2)**22.5*(1.11940486639897e+99*cos(theta)**31 - 3.44717392632797e+99*cos(theta)**29 + 4.69648528217837e+99*cos(theta)**27 - 3.73801889806034e+99*cos(theta)**25 + 1.93345805072086e+99*cos(theta)**23 - 6.84146694870459e+98*cos(theta)**21 + 1.6982364766288e+98*cos(theta)**19 - 2.9845677030167e+97*cos(theta)**17 + 3.70347817162656e+96*cos(theta)**15 - 3.20053669152913e+95*cos(theta)**13 + 1.8770064807464e+94*cos(theta)**11 - 7.16414687307788e+92*cos(theta)**9 + 1.66608066815765e+91*cos(theta)**7 - 2.11918195222959e+89*cos(theta)**5 + 1.21096111555977e+87*cos(theta)**3 - 1.96904246432483e+84*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl76_m_minus_44(theta, phi):
    return 9.78689054258913e-82*(1.0 - cos(theta)**2)**22*(3.49814020749679e+97*cos(theta)**32 - 1.14905797544266e+98*cos(theta)**30 + 1.67731617220656e+98*cos(theta)**28 - 1.43769957617705e+98*cos(theta)**26 + 8.05607521133693e+97*cos(theta)**24 - 3.10975770395663e+97*cos(theta)**22 + 8.491182383144e+96*cos(theta)**20 - 1.65809316834261e+96*cos(theta)**18 + 2.3146738572666e+95*cos(theta)**16 - 2.28609763680652e+94*cos(theta)**14 + 1.56417206728867e+93*cos(theta)**12 - 7.16414687307788e+91*cos(theta)**10 + 2.08260083519706e+90*cos(theta)**8 - 3.53196992038265e+88*cos(theta)**6 + 3.02740278889942e+86*cos(theta)**4 - 9.84521232162413e+83*cos(theta)**2 + 5.08533694298767e+80)*sin(44*phi)

#@torch.jit.script
def Yl76_m_minus_43(theta, phi):
    return 6.15874643828416e-80*(1.0 - cos(theta)**2)**21.5*(1.06004248712024e+96*cos(theta)**33 - 3.70663863046018e+96*cos(theta)**31 + 5.7838488696778e+96*cos(theta)**29 - 5.32481324510019e+96*cos(theta)**27 + 3.22243008453477e+96*cos(theta)**25 - 1.35206856693767e+96*cos(theta)**23 + 4.04342018244952e+95*cos(theta)**21 - 8.72680614917163e+94*cos(theta)**19 + 1.36157285721565e+94*cos(theta)**17 - 1.52406509120435e+93*cos(theta)**15 + 1.20320928252975e+92*cos(theta)**13 - 6.51286079370716e+90*cos(theta)**11 + 2.31400092799673e+89*cos(theta)**9 - 5.04567131483236e+87*cos(theta)**7 + 6.05480557779884e+85*cos(theta)**5 - 3.28173744054138e+83*cos(theta)**3 + 5.08533694298767e+80*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl76_m_minus_42(theta, phi):
    return 3.91746624769251e-78*(1.0 - cos(theta)**2)**21*(3.11777202094188e+94*cos(theta)**34 - 1.15832457201881e+95*cos(theta)**32 + 1.92794962322593e+95*cos(theta)**30 - 1.90171901610721e+95*cos(theta)**28 + 1.23939618635953e+95*cos(theta)**26 - 5.63361902890694e+94*cos(theta)**24 + 1.83791826474978e+94*cos(theta)**22 - 4.36340307458582e+93*cos(theta)**20 + 7.56429365119804e+92*cos(theta)**18 - 9.52540682002716e+91*cos(theta)**16 + 8.59435201806962e+90*cos(theta)**14 - 5.42738399475597e+89*cos(theta)**12 + 2.31400092799673e+88*cos(theta)**10 - 6.30708914354046e+86*cos(theta)**8 + 1.00913426296647e+85*cos(theta)**6 - 8.20434360135344e+82*cos(theta)**4 + 2.54266847149383e+80*cos(theta)**2 - 1.25688011443096e+77)*sin(42*phi)

#@torch.jit.script
def Yl76_m_minus_41(theta, phi):
    return 2.51756266340037e-76*(1.0 - cos(theta)**2)**20.5*(8.90792005983395e+92*cos(theta)**35 - 3.51007446066305e+93*cos(theta)**33 + 6.21919233298688e+93*cos(theta)**31 - 6.55765177968004e+93*cos(theta)**29 + 4.59035624577603e+93*cos(theta)**27 - 2.25344761156278e+93*cos(theta)**25 + 7.99094897717297e+92*cos(theta)**23 - 2.07781098789801e+92*cos(theta)**21 + 3.98120718484107e+91*cos(theta)**19 - 5.60318048236892e+90*cos(theta)**17 + 5.72956801204641e+89*cos(theta)**15 - 4.1749107651969e+88*cos(theta)**13 + 2.10363720726976e+87*cos(theta)**11 - 7.00787682615606e+85*cos(theta)**9 + 1.44162037566639e+84*cos(theta)**7 - 1.64086872027069e+82*cos(theta)**5 + 8.47556157164611e+79*cos(theta)**3 - 1.25688011443096e+77*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl76_m_minus_40(theta, phi):
    return 1.63389622897507e-74*(1.0 - cos(theta)**2)**20*(2.47442223884277e+91*cos(theta)**36 - 1.03237484137148e+92*cos(theta)**34 + 1.9434976040584e+92*cos(theta)**32 - 2.18588392656001e+92*cos(theta)**30 + 1.63941294492001e+92*cos(theta)**28 - 8.66710619831838e+91*cos(theta)**26 + 3.32956207382207e+91*cos(theta)**24 - 9.4445953995364e+90*cos(theta)**22 + 1.99060359242054e+90*cos(theta)**20 - 3.11287804576051e+89*cos(theta)**18 + 3.58098000752901e+88*cos(theta)**16 - 2.98207911799779e+87*cos(theta)**14 + 1.75303100605813e+86*cos(theta)**12 - 7.00787682615606e+84*cos(theta)**10 + 1.80202546958299e+83*cos(theta)**8 - 2.73478120045115e+81*cos(theta)**6 + 2.11889039291153e+79*cos(theta)**4 - 6.2844005721548e+76*cos(theta)**2 + 2.98404585572403e+73)*sin(40*phi)

#@torch.jit.script
def Yl76_m_minus_39(theta, phi):
    return 1.07042027630539e-72*(1.0 - cos(theta)**2)**19.5*(6.68762767254801e+89*cos(theta)**37 - 2.94964240391853e+90*cos(theta)**35 + 5.88938667896485e+90*cos(theta)**33 - 7.05123847277424e+90*cos(theta)**31 + 5.65314808593107e+90*cos(theta)**29 - 3.21003933271051e+90*cos(theta)**27 + 1.33182482952883e+90*cos(theta)**25 - 4.10634582588539e+89*cos(theta)**23 + 9.47906472581208e+88*cos(theta)**21 - 1.63835686618974e+88*cos(theta)**19 + 2.10645882795824e+87*cos(theta)**17 - 1.98805274533186e+86*cos(theta)**15 + 1.34848538927548e+85*cos(theta)**13 - 6.37079711468733e+83*cos(theta)**11 + 2.00225052175887e+82*cos(theta)**9 - 3.90683028635878e+80*cos(theta)**7 + 4.23778078582306e+78*cos(theta)**5 - 2.09480019071827e+76*cos(theta)**3 + 2.98404585572403e+73*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl76_m_minus_38(theta, phi):
    return 7.07611765860017e-71*(1.0 - cos(theta)**2)**19*(1.75990201909158e+88*cos(theta)**38 - 8.19345112199591e+88*cos(theta)**36 + 1.73217255263672e+89*cos(theta)**34 - 2.20351202274195e+89*cos(theta)**32 + 1.88438269531036e+89*cos(theta)**30 - 1.14644261882518e+89*cos(theta)**28 + 5.12240319049549e+88*cos(theta)**26 - 1.71097742745225e+88*cos(theta)**24 + 4.30866578446004e+87*cos(theta)**22 - 8.19178433094871e+86*cos(theta)**20 + 1.17025490442124e+86*cos(theta)**18 - 1.24253296583241e+85*cos(theta)**16 + 9.63203849482489e+83*cos(theta)**14 - 5.30899759557277e+82*cos(theta)**12 + 2.00225052175887e+81*cos(theta)**10 - 4.88353785794848e+79*cos(theta)**8 + 7.06296797637176e+77*cos(theta)**6 - 5.23700047679567e+75*cos(theta)**4 + 1.49202292786201e+73*cos(theta)**2 - 6.82848021904812e+69)*sin(38*phi)

#@torch.jit.script
def Yl76_m_minus_37(theta, phi):
    return 4.71823724723755e-69*(1.0 - cos(theta)**2)**18.5*(4.51256927972201e+86*cos(theta)**39 - 2.21444624918808e+87*cos(theta)**37 + 4.94906443610491e+87*cos(theta)**35 - 6.67730915982409e+87*cos(theta)**33 + 6.07865385583986e+87*cos(theta)**31 - 3.95325040974201e+87*cos(theta)**29 + 1.89718636685018e+87*cos(theta)**27 - 6.84390970980898e+86*cos(theta)**25 + 1.87333294976523e+86*cos(theta)**23 - 3.90084968140415e+85*cos(theta)**21 + 6.15923633905918e+84*cos(theta)**19 - 7.309017446073e+83*cos(theta)**17 + 6.42135899654993e+82*cos(theta)**15 - 4.08384430428675e+81*cos(theta)**13 + 1.82022774705352e+80*cos(theta)**11 - 5.4261531754983e+78*cos(theta)**9 + 1.00899542519597e+77*cos(theta)**7 - 1.04740009535913e+75*cos(theta)**5 + 4.97340975954005e+72*cos(theta)**3 - 6.82848021904812e+69*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl76_m_minus_36(theta, phi):
    return 3.17211550073312e-67*(1.0 - cos(theta)**2)**18*(1.1281423199305e+85*cos(theta)**40 - 5.82749012944233e+85*cos(theta)**38 + 1.37474012114025e+86*cos(theta)**36 - 1.96391445877179e+86*cos(theta)**34 + 1.89957932994996e+86*cos(theta)**32 - 1.31775013658067e+86*cos(theta)**30 + 6.77566559589351e+85*cos(theta)**28 - 2.63227296531115e+85*cos(theta)**26 + 7.80555395735514e+84*cos(theta)**24 - 1.77311349154734e+84*cos(theta)**22 + 3.07961816952959e+83*cos(theta)**20 - 4.06056524781834e+82*cos(theta)**18 + 4.0133493728437e+81*cos(theta)**16 - 2.91703164591911e+80*cos(theta)**14 + 1.51685645587794e+79*cos(theta)**12 - 5.42615317549831e+77*cos(theta)**10 + 1.26124428149496e+76*cos(theta)**8 - 1.74566682559856e+74*cos(theta)**6 + 1.24335243988501e+72*cos(theta)**4 - 3.41424010952406e+69*cos(theta)**2 + 1.51072571217879e+66)*sin(36*phi)

#@torch.jit.script
def Yl76_m_minus_35(theta, phi):
    return 2.14956178129312e-65*(1.0 - cos(theta)**2)**17.5*(2.75156663397683e+83*cos(theta)**41 - 1.49422823831855e+84*cos(theta)**39 + 3.7155138409196e+84*cos(theta)**37 - 5.6111841679194e+84*cos(theta)**35 + 5.75630099984835e+84*cos(theta)**33 - 4.25080689219571e+84*cos(theta)**31 + 2.33643641237707e+84*cos(theta)**29 - 9.74915913078203e+83*cos(theta)**27 + 3.12222158294206e+83*cos(theta)**25 - 7.70918909368409e+82*cos(theta)**23 + 1.46648484263314e+82*cos(theta)**21 - 2.13713960411491e+81*cos(theta)**19 + 2.36079374873159e+80*cos(theta)**17 - 1.94468776394607e+79*cos(theta)**15 + 1.16681265836764e+78*cos(theta)**13 - 4.93286652318028e+76*cos(theta)**11 + 1.4013825349944e+75*cos(theta)**9 - 2.49380975085508e+73*cos(theta)**7 + 2.48670487977002e+71*cos(theta)**5 - 1.13808003650802e+69*cos(theta)**3 + 1.51072571217879e+66*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl76_m_minus_34(theta, phi):
    return 1.46769585064961e-63*(1.0 - cos(theta)**2)**17*(6.55134912851627e+81*cos(theta)**42 - 3.73557059579636e+82*cos(theta)**40 + 9.77766800242001e+82*cos(theta)**38 - 1.5586622688665e+83*cos(theta)**36 + 1.69302970583775e+83*cos(theta)**34 - 1.32837715381116e+83*cos(theta)**32 + 7.78812137459024e+82*cos(theta)**30 - 3.48184254670787e+82*cos(theta)**28 + 1.20085445497771e+82*cos(theta)**26 - 3.21216212236837e+81*cos(theta)**24 + 6.66584019378699e+80*cos(theta)**22 - 1.06856980205746e+80*cos(theta)**20 + 1.31155208262866e+79*cos(theta)**18 - 1.21542985246629e+78*cos(theta)**16 + 8.33437613119745e+76*cos(theta)**14 - 4.11072210265023e+75*cos(theta)**12 + 1.4013825349944e+74*cos(theta)**10 - 3.11726218856885e+72*cos(theta)**8 + 4.14450813295004e+70*cos(theta)**6 - 2.84520009127005e+68*cos(theta)**4 + 7.55362856089394e+65*cos(theta)**2 - 3.24050989313339e+62)*sin(34*phi)

#@torch.jit.script
def Yl76_m_minus_33(theta, phi):
    return 1.00940775459507e-61*(1.0 - cos(theta)**2)**16.5*(1.52356956477123e+80*cos(theta)**43 - 9.11114779462528e+80*cos(theta)**41 + 2.50709435959487e+81*cos(theta)**39 - 4.21260072666622e+81*cos(theta)**37 + 4.837227730965e+81*cos(theta)**35 - 4.02538531457927e+81*cos(theta)**33 + 2.51229721760976e+81*cos(theta)**31 - 1.20063536093375e+81*cos(theta)**29 + 4.44760909251005e+80*cos(theta)**27 - 1.28486484894735e+80*cos(theta)**25 + 2.89819138860304e+79*cos(theta)**23 - 5.08842762884503e+78*cos(theta)**21 + 6.90290569804559e+77*cos(theta)**19 - 7.14958736744879e+76*cos(theta)**17 + 5.55625075413163e+75*cos(theta)**15 - 3.16209392511556e+74*cos(theta)**13 + 1.27398412272218e+73*cos(theta)**11 - 3.46362465396539e+71*cos(theta)**9 + 5.92072590421434e+69*cos(theta)**7 - 5.6904001825401e+67*cos(theta)**5 + 2.51787618696465e+65*cos(theta)**3 - 3.24050989313339e+62*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl76_m_minus_32(theta, phi):
    return 6.99046754953901e-60*(1.0 - cos(theta)**2)**16*(3.46265810175279e+78*cos(theta)**44 - 2.16932090348221e+79*cos(theta)**42 + 6.26773589898719e+79*cos(theta)**40 - 1.10857913859637e+80*cos(theta)**38 + 1.3436743697125e+80*cos(theta)**36 - 1.1839368572292e+80*cos(theta)**34 + 7.85092880503049e+79*cos(theta)**32 - 4.00211786977916e+79*cos(theta)**30 + 1.58843181875359e+79*cos(theta)**28 - 4.94178788056672e+78*cos(theta)**26 + 1.20757974525127e+78*cos(theta)**24 - 2.31292164947501e+77*cos(theta)**22 + 3.45145284902279e+76*cos(theta)**20 - 3.97199298191599e+75*cos(theta)**18 + 3.47265672133227e+74*cos(theta)**16 - 2.25863851793969e+73*cos(theta)**14 + 1.06165343560182e+72*cos(theta)**12 - 3.46362465396539e+70*cos(theta)**10 + 7.40090738026793e+68*cos(theta)**8 - 9.4840003042335e+66*cos(theta)**6 + 6.29469046741162e+64*cos(theta)**4 - 1.6202549465667e+62*cos(theta)**2 + 6.75669285474019e+58)*sin(32*phi)

#@torch.jit.script
def Yl76_m_minus_31(theta, phi):
    return 4.87331359228223e-58*(1.0 - cos(theta)**2)**15.5*(7.69479578167286e+76*cos(theta)**45 - 5.04493233367955e+77*cos(theta)**43 + 1.5287160729237e+78*cos(theta)**41 - 2.84251061178557e+78*cos(theta)**39 + 3.63155235057433e+78*cos(theta)**37 - 3.38267673494056e+78*cos(theta)**35 + 2.37906933485772e+78*cos(theta)**33 - 1.29100576444489e+78*cos(theta)**31 + 5.47735109915031e+77*cos(theta)**29 - 1.8302918076173e+77*cos(theta)**27 + 4.83031898100507e+76*cos(theta)**25 - 1.0056181084674e+76*cos(theta)**23 + 1.64354897572514e+75*cos(theta)**21 - 2.09052262206105e+74*cos(theta)**19 + 2.04273924784251e+73*cos(theta)**17 - 1.50575901195979e+72*cos(theta)**15 + 8.16656488924474e+70*cos(theta)**13 - 3.14874968542308e+69*cos(theta)**11 + 8.22323042251992e+67*cos(theta)**9 - 1.35485718631907e+66*cos(theta)**7 + 1.25893809348232e+64*cos(theta)**5 - 5.40084982188899e+61*cos(theta)**3 + 6.75669285474019e+58*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl76_m_minus_30(theta, phi):
    return 3.41896900227033e-56*(1.0 - cos(theta)**2)**15*(1.67278169166801e+75*cos(theta)**46 - 1.14657553038172e+76*cos(theta)**44 + 3.63980017362787e+76*cos(theta)**42 - 7.10627652946393e+76*cos(theta)**40 + 9.5567167120377e+76*cos(theta)**38 - 9.39632426372378e+76*cos(theta)**36 + 6.99726274958154e+76*cos(theta)**34 - 4.03439301389028e+76*cos(theta)**32 + 1.82578369971677e+76*cos(theta)**30 - 6.53675645577609e+75*cos(theta)**28 + 1.85781499269426e+75*cos(theta)**26 - 4.19007545194749e+74*cos(theta)**24 + 7.470677162387e+73*cos(theta)**22 - 1.04526131103052e+73*cos(theta)**20 + 1.13485513769028e+72*cos(theta)**18 - 9.4109938247487e+70*cos(theta)**16 + 5.83326063517481e+69*cos(theta)**14 - 2.6239580711859e+68*cos(theta)**12 + 8.22323042251992e+66*cos(theta)**10 - 1.69357148289884e+65*cos(theta)**8 + 2.09823015580387e+63*cos(theta)**6 - 1.35021245547225e+61*cos(theta)**4 + 3.37834642737009e+58*cos(theta)**2 - 1.3727535259529e+55)*sin(30*phi)

#@torch.jit.script
def Yl76_m_minus_29(theta, phi):
    return 2.4132206055339e-54*(1.0 - cos(theta)**2)**14.5*(3.55910998227237e+73*cos(theta)**47 - 2.54794562307048e+74*cos(theta)**45 + 8.46465156657643e+74*cos(theta)**43 - 1.73323817791803e+75*cos(theta)**41 + 2.45044018257377e+75*cos(theta)**39 - 2.53954709830372e+75*cos(theta)**37 + 1.99921792845187e+75*cos(theta)**35 - 1.22254333754251e+75*cos(theta)**33 + 5.88962483779603e+74*cos(theta)**31 - 2.25405395026762e+74*cos(theta)**29 + 6.88079626923799e+73*cos(theta)**27 - 1.676030180779e+73*cos(theta)**25 + 3.24812050538565e+72*cos(theta)**23 - 4.97743481443107e+71*cos(theta)**21 + 5.97292177731729e+70*cos(theta)**19 - 5.53587872044041e+69*cos(theta)**17 + 3.88884042344988e+68*cos(theta)**15 - 2.01842928552762e+67*cos(theta)**13 + 7.47566402047265e+65*cos(theta)**11 - 1.88174609210982e+64*cos(theta)**9 + 2.99747165114839e+62*cos(theta)**7 - 2.70042491094449e+60*cos(theta)**5 + 1.12611547579003e+58*cos(theta)**3 - 1.3727535259529e+55*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl76_m_minus_28(theta, phi):
    return 1.71321667638702e-52*(1.0 - cos(theta)**2)**14*(7.41481246306743e+71*cos(theta)**48 - 5.53901222406627e+72*cos(theta)**46 + 1.92378444694919e+73*cos(theta)**44 - 4.1267575664715e+73*cos(theta)**42 + 6.12610045643442e+73*cos(theta)**40 - 6.68301867974664e+73*cos(theta)**38 + 5.55338313458852e+73*cos(theta)**36 - 3.59571569865444e+73*cos(theta)**34 + 1.84050776181126e+73*cos(theta)**32 - 7.51351316755872e+72*cos(theta)**30 + 2.45742723901357e+72*cos(theta)**28 - 6.44626992607306e+71*cos(theta)**26 + 1.35338354391069e+71*cos(theta)**24 - 2.26247037019594e+70*cos(theta)**22 + 2.98646088865864e+69*cos(theta)**20 - 3.07548817802245e+68*cos(theta)**18 + 2.43052526465617e+67*cos(theta)**16 - 1.4417352039483e+66*cos(theta)**14 + 6.22972001706055e+64*cos(theta)**12 - 1.88174609210982e+63*cos(theta)**10 + 3.74683956393549e+61*cos(theta)**8 - 4.50070818490749e+59*cos(theta)**6 + 2.81528868947508e+57*cos(theta)**4 - 6.86376762976451e+54*cos(theta)**2 + 2.72371731339862e+51)*sin(28*phi)

#@torch.jit.script
def Yl76_m_minus_27(theta, phi):
    return 1.2230015369474e-50*(1.0 - cos(theta)**2)**13.5*(1.51322703327907e+70*cos(theta)**49 - 1.17851323916304e+71*cos(theta)**47 + 4.27507654877598e+71*cos(theta)**45 - 9.59711061970117e+71*cos(theta)**43 + 1.49417084303279e+72*cos(theta)**41 - 1.71359453326837e+72*cos(theta)**39 + 1.5009143606996e+72*cos(theta)**37 - 1.0273473424727e+72*cos(theta)**35 + 5.57729624791291e+71*cos(theta)**33 - 2.42371392501894e+71*cos(theta)**31 + 8.47388703108126e+70*cos(theta)**29 - 2.38750738002706e+70*cos(theta)**27 + 5.41353417564275e+69*cos(theta)**25 - 9.83682769650409e+68*cos(theta)**23 + 1.42212423269459e+68*cos(theta)**21 - 1.61867798843287e+67*cos(theta)**19 + 1.4297207439154e+66*cos(theta)**17 - 9.61156802632198e+64*cos(theta)**15 + 4.7920923208158e+63*cos(theta)**13 - 1.71067826555438e+62*cos(theta)**11 + 4.16315507103943e+60*cos(theta)**9 - 6.42958312129641e+58*cos(theta)**7 + 5.63057737895015e+56*cos(theta)**5 - 2.28792254325484e+54*cos(theta)**3 + 2.72371731339862e+51*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl76_m_minus_26(theta, phi):
    return 8.77668713740263e-49*(1.0 - cos(theta)**2)**13*(3.02645406655813e+68*cos(theta)**50 - 2.45523591492299e+69*cos(theta)**48 + 9.29364467125212e+69*cos(theta)**46 - 2.18116150447754e+70*cos(theta)**44 + 3.55754962626854e+70*cos(theta)**42 - 4.28398633317092e+70*cos(theta)**40 + 3.94977463342e+70*cos(theta)**38 - 2.85374261797971e+70*cos(theta)**36 + 1.64038124938615e+70*cos(theta)**34 - 7.57410601568419e+69*cos(theta)**32 + 2.82462901036042e+69*cos(theta)**30 - 8.52681207152521e+68*cos(theta)**28 + 2.08212852909337e+68*cos(theta)**26 - 4.09867820687671e+67*cos(theta)**24 + 6.46420105770269e+66*cos(theta)**22 - 8.09338994216434e+65*cos(theta)**20 + 7.9428930217522e+64*cos(theta)**18 - 6.00723001645124e+63*cos(theta)**16 + 3.422923086297e+62*cos(theta)**14 - 1.42556522129532e+61*cos(theta)**12 + 4.16315507103943e+59*cos(theta)**10 - 8.03697890162052e+57*cos(theta)**8 + 9.38429563158359e+55*cos(theta)**6 - 5.71980635813709e+53*cos(theta)**4 + 1.36185865669931e+51*cos(theta)**2 - 5.28877148232741e+47)*sin(26*phi)

#@torch.jit.script
def Yl76_m_minus_25(theta, phi):
    return 6.33017609103435e-47*(1.0 - cos(theta)**2)**12.5*(5.93422365991791e+66*cos(theta)**51 - 5.01068554065916e+67*cos(theta)**49 + 1.97737120664939e+68*cos(theta)**47 - 4.84702556550564e+68*cos(theta)**45 + 8.27337122388032e+68*cos(theta)**43 - 1.04487471540754e+69*cos(theta)**41 + 1.01276272651795e+69*cos(theta)**39 - 7.71281788643166e+68*cos(theta)**37 + 4.68680356967471e+68*cos(theta)**35 - 2.29518364111642e+68*cos(theta)**33 + 9.11170648503362e+67*cos(theta)**31 - 2.94028002466387e+67*cos(theta)**29 + 7.71158714479025e+66*cos(theta)**27 - 1.63947128275068e+66*cos(theta)**25 + 2.81052219900117e+65*cos(theta)**23 - 3.85399521055445e+64*cos(theta)**21 + 4.18047001144852e+63*cos(theta)**19 - 3.53366471555955e+62*cos(theta)**17 + 2.281948724198e+61*cos(theta)**15 - 1.09658863176563e+60*cos(theta)**13 + 3.78468642821766e+58*cos(theta)**11 - 8.92997655735613e+56*cos(theta)**9 + 1.3406136616548e+55*cos(theta)**7 - 1.14396127162742e+53*cos(theta)**5 + 4.53952885566436e+50*cos(theta)**3 - 5.28877148232741e+47*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl76_m_minus_24(theta, phi):
    return 4.58752189435731e-45*(1.0 - cos(theta)**2)**12*(1.14119685767652e+65*cos(theta)**52 - 1.00213710813183e+66*cos(theta)**50 + 4.11952334718622e+66*cos(theta)**48 - 1.05370120989253e+67*cos(theta)**46 + 1.88031164179098e+67*cos(theta)**44 - 2.48779694144653e+67*cos(theta)**42 + 2.53190681629487e+67*cos(theta)**40 - 2.02968891748202e+67*cos(theta)**38 + 1.3018898804652e+67*cos(theta)**36 - 6.75054012093065e+66*cos(theta)**34 + 2.84740827657301e+66*cos(theta)**32 - 9.80093341554622e+65*cos(theta)**30 + 2.75413826599652e+65*cos(theta)**28 - 6.30565877981032e+64*cos(theta)**26 + 1.17105091625049e+64*cos(theta)**24 - 1.75181600479748e+63*cos(theta)**22 + 2.09023500572426e+62*cos(theta)**20 - 1.96314706419975e+61*cos(theta)**18 + 1.42621795262375e+60*cos(theta)**16 - 7.83277594118307e+58*cos(theta)**14 + 3.15390535684805e+57*cos(theta)**12 - 8.92997655735613e+55*cos(theta)**10 + 1.6757670770685e+54*cos(theta)**8 - 1.90660211937903e+52*cos(theta)**6 + 1.13488221391609e+50*cos(theta)**4 - 2.6443857411637e+47*cos(theta)**2 + 1.00700142466249e+44)*sin(24*phi)

#@torch.jit.script
def Yl76_m_minus_23(theta, phi):
    return 3.33976635104016e-43*(1.0 - cos(theta)**2)**11.5*(2.15320161825759e+63*cos(theta)**53 - 1.96497472182712e+64*cos(theta)**51 + 8.40719050446168e+64*cos(theta)**49 - 2.24191746785645e+65*cos(theta)**47 + 4.17847031509107e+65*cos(theta)**45 - 5.78557428243379e+65*cos(theta)**43 + 6.17538247876798e+65*cos(theta)**41 - 5.20433055764619e+65*cos(theta)**39 + 3.51862129855459e+65*cos(theta)**37 - 1.92872574883733e+65*cos(theta)**35 + 8.62850992900911e+64*cos(theta)**33 - 3.16159142436975e+64*cos(theta)**31 + 9.49702850343626e+63*cos(theta)**29 - 2.33542917770752e+63*cos(theta)**27 + 4.68420366500195e+62*cos(theta)**25 - 7.61659132520642e+61*cos(theta)**23 + 9.95350002725839e+60*cos(theta)**21 - 1.03323529694724e+60*cos(theta)**19 + 8.38951736837501e+58*cos(theta)**17 - 5.22185062745538e+57*cos(theta)**15 + 2.42608104372927e+56*cos(theta)**13 - 8.11816050668739e+54*cos(theta)**11 + 1.861963418965e+53*cos(theta)**9 - 2.72371731339862e+51*cos(theta)**7 + 2.26976442783218e+49*cos(theta)**5 - 8.81461913721235e+46*cos(theta)**3 + 1.00700142466249e+44*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl76_m_minus_22(theta, phi):
    return 2.4419151088525e-41*(1.0 - cos(theta)**2)**11*(3.98741040418072e+61*cos(theta)**54 - 3.77879754197524e+62*cos(theta)**52 + 1.68143810089234e+63*cos(theta)**50 - 4.6706613913676e+63*cos(theta)**48 + 9.0836311197632e+63*cos(theta)**46 - 1.31490324600768e+64*cos(theta)**44 + 1.47032916161142e+64*cos(theta)**42 - 1.30108263941155e+64*cos(theta)**40 + 9.25952973303839e+63*cos(theta)**38 - 5.35757152454814e+63*cos(theta)**36 + 2.53779703794386e+63*cos(theta)**34 - 9.87997320115547e+62*cos(theta)**32 + 3.16567616781209e+62*cos(theta)**30 - 8.34081849181259e+61*cos(theta)**28 + 1.80161679423152e+61*cos(theta)**26 - 3.17357971883601e+60*cos(theta)**24 + 4.52431819420836e+59*cos(theta)**22 - 5.16617648473619e+58*cos(theta)**20 + 4.66084298243056e+57*cos(theta)**18 - 3.26365664215961e+56*cos(theta)**16 + 1.73291503123519e+55*cos(theta)**14 - 6.76513375557283e+53*cos(theta)**12 + 1.861963418965e+52*cos(theta)**10 - 3.40464664174827e+50*cos(theta)**8 + 3.78294071305363e+48*cos(theta)**6 - 2.20365478430309e+46*cos(theta)**4 + 5.03500712331246e+43*cos(theta)**2 - 1.88365399300878e+40)*sin(22*phi)

#@torch.jit.script
def Yl76_m_minus_21(theta, phi):
    return 1.79277152085142e-39*(1.0 - cos(theta)**2)**10.5*(7.2498370985104e+59*cos(theta)**55 - 7.12980668297214e+60*cos(theta)**53 + 3.29693745273007e+61*cos(theta)**51 - 9.53196202319919e+61*cos(theta)**49 + 1.93268747229004e+62*cos(theta)**47 - 2.9220072133504e+62*cos(theta)**45 + 3.41937014328238e+62*cos(theta)**43 - 3.17337229124768e+62*cos(theta)**41 + 2.37423839308677e+62*cos(theta)**39 - 1.44799230393193e+62*cos(theta)**37 + 7.25084867983959e+61*cos(theta)**35 - 2.99393127307741e+61*cos(theta)**33 + 1.02118586058454e+61*cos(theta)**31 - 2.87614430752158e+60*cos(theta)**29 + 6.67265479345007e+59*cos(theta)**27 - 1.2694318875344e+59*cos(theta)**25 + 1.96709486704711e+58*cos(theta)**23 - 2.46008404035057e+57*cos(theta)**21 + 2.45307525391082e+56*cos(theta)**19 - 1.91979802479977e+55*cos(theta)**17 + 1.15527668749013e+54*cos(theta)**15 - 5.20394904274833e+52*cos(theta)**13 + 1.69269401724091e+51*cos(theta)**11 - 3.78294071305363e+49*cos(theta)**9 + 5.40420101864805e+47*cos(theta)**7 - 4.40730956860617e+45*cos(theta)**5 + 1.67833570777082e+43*cos(theta)**3 - 1.88365399300878e+40*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl76_m_minus_20(theta, phi):
    return 1.32131031447958e-37*(1.0 - cos(theta)**2)**10*(1.29461376759114e+58*cos(theta)**56 - 1.32033457092077e+59*cos(theta)**54 + 6.34026433217322e+59*cos(theta)**52 - 1.90639240463984e+60*cos(theta)**50 + 4.02643223393759e+60*cos(theta)**48 - 6.35218959424e+60*cos(theta)**46 + 7.77129578018723e+60*cos(theta)**44 - 7.55564831249447e+60*cos(theta)**42 + 5.93559598271692e+60*cos(theta)**40 - 3.81050606297876e+60*cos(theta)**38 + 2.01412463328877e+60*cos(theta)**36 - 8.80568021493357e+59*cos(theta)**34 + 3.1912058143267e+59*cos(theta)**32 - 9.58714769173861e+58*cos(theta)**30 + 2.38309099766074e+58*cos(theta)**28 - 4.88243033667078e+57*cos(theta)**26 + 8.1962286126963e+56*cos(theta)**24 - 1.11822001834117e+56*cos(theta)**22 + 1.22653762695541e+55*cos(theta)**20 - 1.0665544582221e+54*cos(theta)**18 + 7.22047929681331e+52*cos(theta)**16 - 3.71710645910595e+51*cos(theta)**14 + 1.41057834770076e+50*cos(theta)**12 - 3.78294071305363e+48*cos(theta)**10 + 6.75525127331006e+46*cos(theta)**8 - 7.34551594767696e+44*cos(theta)**6 + 4.19583926942705e+42*cos(theta)**4 - 9.41826996504389e+39*cos(theta)**2 + 3.46769880892632e+36)*sin(20*phi)

#@torch.jit.script
def Yl76_m_minus_19(theta, phi):
    return 9.77412456581428e-36*(1.0 - cos(theta)**2)**9.5*(2.27125222384411e+56*cos(theta)**57 - 2.40060831076503e+57*cos(theta)**55 + 1.19627628908929e+58*cos(theta)**53 - 3.73802432282321e+58*cos(theta)**51 + 8.21720864068895e+58*cos(theta)**49 - 1.35152970090213e+59*cos(theta)**47 + 1.72695461781939e+59*cos(theta)**45 - 1.7571275145336e+59*cos(theta)**43 + 1.44770633724803e+59*cos(theta)**41 - 9.77052836661221e+58*cos(theta)**39 + 5.44358008996966e+58*cos(theta)**37 - 2.51590863283816e+58*cos(theta)**35 + 9.67032064947485e+57*cos(theta)**33 - 3.09262828765761e+57*cos(theta)**31 + 8.21755516434738e+56*cos(theta)**29 - 1.80830753210029e+56*cos(theta)**27 + 3.27849144507852e+55*cos(theta)**25 - 4.86182616670072e+54*cos(theta)**23 + 5.84065536645434e+53*cos(theta)**21 - 5.6134445169584e+52*cos(theta)**19 + 4.24734076283136e+51*cos(theta)**17 - 2.4780709727373e+50*cos(theta)**15 + 1.08506026746212e+49*cos(theta)**13 - 3.43903701186694e+47*cos(theta)**11 + 7.50583474812229e+45*cos(theta)**9 - 1.04935942109671e+44*cos(theta)**7 + 8.3916785388541e+41*cos(theta)**5 - 3.1394233216813e+39*cos(theta)**3 + 3.46769880892632e+36*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl76_m_minus_18(theta, phi):
    return 7.25527150260126e-34*(1.0 - cos(theta)**2)**9*(3.91595211007605e+54*cos(theta)**58 - 4.28680055493756e+55*cos(theta)**56 + 2.21532646127646e+56*cos(theta)**54 - 7.18850831312156e+56*cos(theta)**52 + 1.64344172813779e+57*cos(theta)**50 - 2.81568687687943e+57*cos(theta)**48 + 3.75424916917258e+57*cos(theta)**46 - 3.99347162394e+57*cos(theta)**44 + 3.44691985059054e+57*cos(theta)**42 - 2.44263209165305e+57*cos(theta)**40 + 1.43252107630781e+57*cos(theta)**38 - 6.98863509121712e+56*cos(theta)**36 + 2.8442119557279e+56*cos(theta)**34 - 9.66446339893005e+55*cos(theta)**32 + 2.73918505478246e+55*cos(theta)**30 - 6.45824118607246e+54*cos(theta)**28 + 1.26095824810712e+54*cos(theta)**26 - 2.02576090279197e+53*cos(theta)**24 + 2.65484334838833e+52*cos(theta)**22 - 2.8067222584792e+51*cos(theta)**20 + 2.35963375712853e+50*cos(theta)**18 - 1.54879435796081e+49*cos(theta)**16 + 7.75043048187229e+47*cos(theta)**14 - 2.86586417655578e+46*cos(theta)**12 + 7.50583474812229e+44*cos(theta)**10 - 1.31169927637089e+43*cos(theta)**8 + 1.39861308980902e+41*cos(theta)**6 - 7.84855830420324e+38*cos(theta)**4 + 1.73384940446316e+36*cos(theta)**2 - 6.29346426302417e+32)*sin(18*phi)

#@torch.jit.script
def Yl76_m_minus_17(theta, phi):
    return 5.40310741648762e-32*(1.0 - cos(theta)**2)**8.5*(6.63720696623059e+52*cos(theta)**59 - 7.52070272796063e+53*cos(theta)**57 + 4.02786629322992e+54*cos(theta)**55 - 1.35632232323048e+55*cos(theta)**53 + 3.22243476105449e+55*cos(theta)**51 - 5.74629974873353e+55*cos(theta)**49 + 7.98776418972889e+55*cos(theta)**47 - 8.87438138653333e+55*cos(theta)**45 + 8.01609267579196e+55*cos(theta)**43 - 5.95763924793427e+55*cos(theta)**41 + 3.67313096489181e+55*cos(theta)**39 - 1.88882029492355e+55*cos(theta)**37 + 8.12631987350828e+54*cos(theta)**35 - 2.92862527240304e+54*cos(theta)**33 + 8.8360808218789e+53*cos(theta)**31 - 2.22697971933533e+53*cos(theta)**29 + 4.67021573373009e+52*cos(theta)**27 - 8.10304361116787e+51*cos(theta)**25 + 1.15427971669058e+51*cos(theta)**23 - 1.33653440879962e+50*cos(theta)**21 + 1.24191250375186e+49*cos(theta)**19 - 9.11055504682831e+47*cos(theta)**17 + 5.16695365458152e+46*cos(theta)**15 - 2.20451090504291e+45*cos(theta)**13 + 6.82348613465663e+43*cos(theta)**11 - 1.45744364041209e+42*cos(theta)**9 + 1.99801869972717e+40*cos(theta)**7 - 1.56971166084065e+38*cos(theta)**5 + 5.7794980148772e+35*cos(theta)**3 - 6.29346426302417e+32*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl76_m_minus_16(theta, phi):
    return 4.03608869114515e-30*(1.0 - cos(theta)**2)**8*(1.10620116103843e+51*cos(theta)**60 - 1.29667288413114e+52*cos(theta)**58 + 7.19261838076771e+52*cos(theta)**56 - 2.51170800598238e+53*cos(theta)**54 + 6.19698992510479e+53*cos(theta)**52 - 1.14925994974671e+54*cos(theta)**50 + 1.66411753952685e+54*cos(theta)**48 - 1.92921334489855e+54*cos(theta)**46 + 1.82183924449817e+54*cos(theta)**44 - 1.41848553522245e+54*cos(theta)**42 + 9.18282741222952e+53*cos(theta)**40 - 4.97057972348302e+53*cos(theta)**38 + 2.25731107597452e+53*cos(theta)**36 - 8.6136037423619e+52*cos(theta)**34 + 2.76127525683716e+52*cos(theta)**32 - 7.42326573111777e+51*cos(theta)**30 + 1.66793419061789e+51*cos(theta)**28 - 3.11655523506457e+50*cos(theta)**26 + 4.80949881954408e+49*cos(theta)**24 - 6.07515640363463e+48*cos(theta)**22 + 6.20956251875929e+47*cos(theta)**20 - 5.06141947046017e+46*cos(theta)**18 + 3.22934603411345e+45*cos(theta)**16 - 1.57465064645922e+44*cos(theta)**14 + 5.68623844554719e+42*cos(theta)**12 - 1.45744364041209e+41*cos(theta)**10 + 2.49752337465896e+39*cos(theta)**8 - 2.61618610140108e+37*cos(theta)**6 + 1.4448745037193e+35*cos(theta)**4 - 3.14673213151209e+32*cos(theta)**2 + 1.12786097903659e+29)*sin(16*phi)

#@torch.jit.script
def Yl76_m_minus_15(theta, phi):
    return 3.0235665514537e-28*(1.0 - cos(theta)**2)**7.5*(1.81344452629251e+49*cos(theta)**61 - 2.19775065106973e+50*cos(theta)**59 + 1.2618628738189e+51*cos(theta)**57 - 4.56674182905887e+51*cos(theta)**55 + 1.16924338209524e+52*cos(theta)**53 - 2.25345088185629e+52*cos(theta)**51 + 3.39615824393235e+52*cos(theta)**49 - 4.104709244465e+52*cos(theta)**47 + 4.04853165444039e+52*cos(theta)**45 - 3.29880357028476e+52*cos(theta)**43 + 2.23971400298281e+52*cos(theta)**41 - 1.2745076214059e+52*cos(theta)**39 + 6.10084074587709e+51*cos(theta)**37 - 2.46102964067483e+51*cos(theta)**35 + 8.36750077829441e+50*cos(theta)**33 - 2.39460184874767e+50*cos(theta)**31 + 5.7514972090272e+49*cos(theta)**29 - 1.15427971669058e+49*cos(theta)**27 + 1.92379952781763e+48*cos(theta)**25 - 2.64137234940636e+47*cos(theta)**23 + 2.95693453274252e+46*cos(theta)**21 - 2.66390498445272e+45*cos(theta)**19 + 1.89961531418438e+44*cos(theta)**17 - 1.04976709763948e+43*cos(theta)**15 + 4.37402957349784e+41*cos(theta)**13 - 1.324948764011e+40*cos(theta)**11 + 2.77502597184329e+38*cos(theta)**9 - 3.73740871628726e+36*cos(theta)**7 + 2.8897490074386e+34*cos(theta)**5 - 1.04891071050403e+32*cos(theta)**3 + 1.12786097903659e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl76_m_minus_14(theta, phi):
    return 2.27109903718475e-26*(1.0 - cos(theta)**2)**7*(2.92491052627824e+47*cos(theta)**62 - 3.66291775178289e+48*cos(theta)**60 + 2.17562564451534e+49*cos(theta)**58 - 8.1548961233194e+49*cos(theta)**56 + 2.1652655223986e+50*cos(theta)**54 - 4.33355938818517e+50*cos(theta)**52 + 6.7923164878647e+50*cos(theta)**50 - 8.55147759263541e+50*cos(theta)**48 + 8.80115577052258e+50*cos(theta)**46 - 7.49728084155627e+50*cos(theta)**44 + 5.33265238805431e+50*cos(theta)**42 - 3.18626905351475e+50*cos(theta)**40 + 1.60548440680976e+50*cos(theta)**38 - 6.83619344631896e+49*cos(theta)**36 + 2.46102964067483e+49*cos(theta)**34 - 7.48313077733647e+48*cos(theta)**32 + 1.9171657363424e+48*cos(theta)**30 - 4.12242755960922e+47*cos(theta)**28 + 7.39922895314475e+46*cos(theta)**26 - 1.10057181225265e+46*cos(theta)**24 + 1.3440611512466e+45*cos(theta)**22 - 1.33195249222636e+44*cos(theta)**20 + 1.05534184121355e+43*cos(theta)**18 - 6.56104436024676e+41*cos(theta)**16 + 3.12430683821274e+40*cos(theta)**14 - 1.10412397000916e+39*cos(theta)**12 + 2.77502597184329e+37*cos(theta)**10 - 4.67176089535907e+35*cos(theta)**8 + 4.816248345731e+33*cos(theta)**6 - 2.62227677626007e+31*cos(theta)**4 + 5.63930489518295e+28*cos(theta)**2 - 1.99904462785642e+25)*sin(14*phi)

#@torch.jit.script
def Yl76_m_minus_13(theta, phi):
    return 1.71012400264125e-24*(1.0 - cos(theta)**2)**6.5*(4.64271512107658e+45*cos(theta)**63 - 6.00478319964408e+46*cos(theta)**61 + 3.68750109239888e+47*cos(theta)**59 - 1.43068353040691e+48*cos(theta)**57 + 3.93684640436109e+48*cos(theta)**55 - 8.17652714751919e+48*cos(theta)**53 + 1.33182676232641e+49*cos(theta)**51 - 1.7451995087011e+49*cos(theta)**49 + 1.87258633415374e+49*cos(theta)**47 - 1.66606240923473e+49*cos(theta)**45 + 1.24015171815216e+49*cos(theta)**43 - 7.77138793540184e+48*cos(theta)**41 + 4.11662668412759e+48*cos(theta)**39 - 1.84761985035648e+48*cos(theta)**37 + 7.03151325907093e+47*cos(theta)**35 - 2.26761538707166e+47*cos(theta)**33 + 6.18440560110452e+46*cos(theta)**31 - 1.42152674469283e+46*cos(theta)**29 + 2.74045516783139e+45*cos(theta)**27 - 4.4022872490106e+44*cos(theta)**25 + 5.84374413585478e+43*cos(theta)**23 - 6.34263091536362e+42*cos(theta)**21 + 5.55443074322919e+41*cos(theta)**19 - 3.85943785896868e+40*cos(theta)**17 + 2.08287122547516e+39*cos(theta)**15 - 8.49326130776279e+37*cos(theta)**13 + 2.5227508834939e+36*cos(theta)**11 - 5.19084543928786e+34*cos(theta)**9 + 6.88035477961571e+32*cos(theta)**7 - 5.24455355252015e+30*cos(theta)**5 + 1.87976829839432e+28*cos(theta)**3 - 1.99904462785642e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl76_m_minus_12(theta, phi):
    return 1.29066220595158e-22*(1.0 - cos(theta)**2)**6*(7.25424237668215e+43*cos(theta)**64 - 9.68513419297432e+44*cos(theta)**62 + 6.14583515399813e+45*cos(theta)**60 - 2.46669574208088e+46*cos(theta)**58 + 7.03008286493052e+46*cos(theta)**56 - 1.51417169398503e+47*cos(theta)**54 + 2.56120531216618e+47*cos(theta)**52 - 3.49039901740221e+47*cos(theta)**50 + 3.90122152948696e+47*cos(theta)**48 - 3.62187480268419e+47*cos(theta)**46 + 2.81852663216401e+47*cos(theta)**44 - 1.85033046080996e+47*cos(theta)**42 + 1.0291566710319e+47*cos(theta)**40 - 4.8621575009381e+46*cos(theta)**38 + 1.9531981275197e+46*cos(theta)**36 - 6.66945702079899e+45*cos(theta)**34 + 1.93262675034516e+45*cos(theta)**32 - 4.73842248230944e+44*cos(theta)**30 + 9.7873398851121e+43*cos(theta)**28 - 1.69318740346562e+43*cos(theta)**26 + 2.43489338993949e+42*cos(theta)**24 - 2.88301405243801e+41*cos(theta)**22 + 2.7772153716146e+40*cos(theta)**20 - 2.14413214387149e+39*cos(theta)**18 + 1.30179451592198e+38*cos(theta)**16 - 6.06661521983056e+36*cos(theta)**14 + 2.10229240291158e+35*cos(theta)**12 - 5.19084543928786e+33*cos(theta)**10 + 8.60044347451964e+31*cos(theta)**8 - 8.74092258753358e+29*cos(theta)**6 + 4.69942074598579e+27*cos(theta)**4 - 9.99522313928208e+24*cos(theta)**2 + 3.50955868654568e+21)*sin(12*phi)

#@torch.jit.script
def Yl76_m_minus_11(theta, phi):
    return 9.76136623576158e-21*(1.0 - cos(theta)**2)**5.5*(1.11603728872033e+42*cos(theta)**65 - 1.5373228877737e+43*cos(theta)**63 + 1.00751395967183e+44*cos(theta)**61 - 4.18084024081506e+44*cos(theta)**59 + 1.23334787104044e+45*cos(theta)**57 - 2.75303944360915e+45*cos(theta)**55 + 4.83246285314373e+45*cos(theta)**53 - 6.84391964196512e+45*cos(theta)**51 + 7.96167659078971e+45*cos(theta)**49 - 7.70611660145572e+45*cos(theta)**47 + 6.26339251592002e+45*cos(theta)**45 - 4.30309409490689e+45*cos(theta)**43 + 2.51013822202902e+45*cos(theta)**41 - 1.24670705152259e+45*cos(theta)**39 + 5.27891385816136e+44*cos(theta)**37 - 1.90555914879971e+44*cos(theta)**35 + 5.85644469801564e+43*cos(theta)**33 - 1.52852338139014e+43*cos(theta)**31 + 3.37494478796969e+42*cos(theta)**29 - 6.27106445728006e+41*cos(theta)**27 + 9.73957355975797e+40*cos(theta)**25 - 1.25348437062522e+40*cos(theta)**23 + 1.32248351029266e+39*cos(theta)**21 - 1.12849060203763e+38*cos(theta)**19 + 7.65761479954103e+36*cos(theta)**17 - 4.04441014655371e+35*cos(theta)**15 + 1.61714800223968e+34*cos(theta)**13 - 4.7189503993526e+32*cos(theta)**11 + 9.55604830502183e+30*cos(theta)**9 - 1.24870322679051e+29*cos(theta)**7 + 9.39884149197159e+26*cos(theta)**5 - 3.33174104642736e+24*cos(theta)**3 + 3.50955868654568e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl76_m_minus_10(theta, phi):
    return 7.39677147726305e-19*(1.0 - cos(theta)**2)**5*(1.6909655889702e+40*cos(theta)**66 - 2.40206701214641e+41*cos(theta)**64 + 1.62502251559972e+42*cos(theta)**62 - 6.96806706802509e+42*cos(theta)**60 + 2.12646184662145e+43*cos(theta)**58 - 4.91614186358778e+43*cos(theta)**56 + 8.9490052835995e+43*cos(theta)**54 - 1.3161383926856e+44*cos(theta)**52 + 1.59233531815794e+44*cos(theta)**50 - 1.60544095863661e+44*cos(theta)**48 + 1.36160706867827e+44*cos(theta)**46 - 9.77975930660656e+43*cos(theta)**44 + 5.97651957625957e+43*cos(theta)**42 - 3.11676762880647e+43*cos(theta)**40 + 1.38918785741088e+43*cos(theta)**38 - 5.29321985777698e+42*cos(theta)**36 + 1.72248373471048e+42*cos(theta)**34 - 4.7766355668442e+41*cos(theta)**32 + 1.1249815959899e+41*cos(theta)**30 - 2.23966587760002e+40*cos(theta)**28 + 3.74598983067614e+39*cos(theta)**26 - 5.22285154427176e+38*cos(theta)**24 + 6.01128868314848e+37*cos(theta)**22 - 5.64245301018813e+36*cos(theta)**20 + 4.25423044418946e+35*cos(theta)**18 - 2.52775634159607e+34*cos(theta)**16 + 1.15510571588548e+33*cos(theta)**14 - 3.93245866612716e+31*cos(theta)**12 + 9.55604830502183e+29*cos(theta)**10 - 1.56087903348814e+28*cos(theta)**8 + 1.56647358199526e+26*cos(theta)**6 - 8.3293526160684e+23*cos(theta)**4 + 1.75477934327284e+21*cos(theta)**2 - 6.11208409360097e+17)*sin(10*phi)

#@torch.jit.script
def Yl76_m_minus_9(theta, phi):
    return 5.61472937361047e-17*(1.0 - cos(theta)**2)**4.5*(2.52382923726895e+38*cos(theta)**67 - 3.69548771099448e+39*cos(theta)**65 + 2.57940081841225e+40*cos(theta)**63 - 1.14230607672543e+41*cos(theta)**61 + 3.60417262139229e+41*cos(theta)**59 - 8.6248102869961e+41*cos(theta)**57 + 1.62709186974536e+42*cos(theta)**55 - 2.48327998619924e+42*cos(theta)**53 + 3.12222611403518e+42*cos(theta)**51 - 3.27641011966655e+42*cos(theta)**49 + 2.89703631633674e+42*cos(theta)**47 - 2.17327984591257e+42*cos(theta)**45 + 1.38988827354874e+42*cos(theta)**43 - 7.60187226538164e+41*cos(theta)**41 + 3.5620201472074e+41*cos(theta)**39 - 1.43059996156134e+41*cos(theta)**37 + 4.92138209917281e+40*cos(theta)**35 - 1.44746532328612e+40*cos(theta)**33 + 3.62897289028999e+39*cos(theta)**31 - 7.72298578482766e+38*cos(theta)**29 + 1.38740364099116e+38*cos(theta)**27 - 2.0891406177087e+37*cos(theta)**25 + 2.61360377528195e+36*cos(theta)**23 - 2.68688238580387e+35*cos(theta)**21 + 2.23906865483656e+34*cos(theta)**19 - 1.48691549505651e+33*cos(theta)**17 + 7.7007047725699e+31*cos(theta)**15 - 3.0249682047132e+30*cos(theta)**13 + 8.68731664092893e+28*cos(theta)**11 - 1.73431003720904e+27*cos(theta)**9 + 2.23781940285038e+25*cos(theta)**7 - 1.66587052321368e+23*cos(theta)**5 + 5.84926447757613e+20*cos(theta)**3 - 6.11208409360097e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl76_m_minus_8(theta, phi):
    return 4.26867162858366e-15*(1.0 - cos(theta)**2)**4*(3.71151358421905e+36*cos(theta)**68 - 5.59922380453708e+37*cos(theta)**66 + 4.03031377876914e+38*cos(theta)**64 - 1.84242915600875e+39*cos(theta)**62 + 6.00695436898715e+39*cos(theta)**60 - 1.48703625637864e+40*cos(theta)**58 + 2.90552119597386e+40*cos(theta)**56 - 4.59866664110971e+40*cos(theta)**54 + 6.00428098852919e+40*cos(theta)**52 - 6.55282023933309e+40*cos(theta)**50 + 6.03549232570153e+40*cos(theta)**48 - 4.72452140415776e+40*cos(theta)**46 + 3.15883698533804e+40*cos(theta)**44 - 1.80996958699563e+40*cos(theta)**42 + 8.90505036801849e+39*cos(theta)**40 - 3.76473674095091e+39*cos(theta)**38 + 1.36705058310356e+39*cos(theta)**36 - 4.25725095084153e+38*cos(theta)**34 + 1.13405402821562e+38*cos(theta)**32 - 2.57432859494255e+37*cos(theta)**30 + 4.95501300353987e+36*cos(theta)**28 - 8.03515622195655e+35*cos(theta)**26 + 1.08900157303414e+35*cos(theta)**24 - 1.2213101753654e+34*cos(theta)**22 + 1.11953432741828e+33*cos(theta)**20 - 8.26064163920284e+31*cos(theta)**18 + 4.81294048285618e+30*cos(theta)**16 - 2.16069157479514e+29*cos(theta)**14 + 7.23943053410744e+27*cos(theta)**12 - 1.73431003720904e+26*cos(theta)**10 + 2.79727425356297e+24*cos(theta)**8 - 2.7764508720228e+22*cos(theta)**6 + 1.46231611939403e+20*cos(theta)**4 - 3.05604204680048e+17*cos(theta)**2 + 105745399543269.0)*sin(8*phi)

#@torch.jit.script
def Yl76_m_minus_7(theta, phi):
    return 3.24980225724004e-13*(1.0 - cos(theta)**2)**3.5*(5.37900519452036e+34*cos(theta)**69 - 8.35705045453296e+35*cos(theta)**67 + 6.20048273656791e+36*cos(theta)**65 - 2.92449072382341e+37*cos(theta)**63 + 9.84746617866746e+37*cos(theta)**61 - 2.52040043454006e+38*cos(theta)**59 + 5.09740560697169e+38*cos(theta)**57 - 8.36121207474493e+38*cos(theta)**55 + 1.13288320538287e+39*cos(theta)**53 - 1.28486671359472e+39*cos(theta)**51 + 1.23173312769419e+39*cos(theta)**49 - 1.00521732003357e+39*cos(theta)**47 + 7.01963774519564e+38*cos(theta)**45 - 4.20923159766425e+38*cos(theta)**43 + 2.17196350439475e+38*cos(theta)**41 - 9.65317113064335e+37*cos(theta)**39 + 3.69473130568529e+37*cos(theta)**37 - 1.21635741452615e+37*cos(theta)**35 + 3.43652735822916e+36*cos(theta)**33 - 8.30428579013727e+35*cos(theta)**31 + 1.70862517363444e+35*cos(theta)**29 - 2.97598378590983e+34*cos(theta)**27 + 4.35600629213658e+33*cos(theta)**25 - 5.31004424071911e+32*cos(theta)**23 + 5.33111584484895e+31*cos(theta)**21 - 4.34770612589623e+30*cos(theta)**19 + 2.83114146050364e+29*cos(theta)**17 - 1.44046104986343e+28*cos(theta)**15 + 5.56879271854419e+26*cos(theta)**13 - 1.57664548837186e+25*cos(theta)**11 + 3.10808250395886e+23*cos(theta)**9 - 3.966358388604e+21*cos(theta)**7 + 2.92463223878806e+19*cos(theta)**5 - 1.01868068226683e+17*cos(theta)**3 + 105745399543269.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl76_m_minus_6(theta, phi):
    return 2.47710834385285e-11*(1.0 - cos(theta)**2)**3*(7.68429313502909e+32*cos(theta)**70 - 1.22897800801955e+34*cos(theta)**68 + 9.39467081298168e+34*cos(theta)**66 - 4.56951675597408e+35*cos(theta)**64 + 1.58830099655927e+36*cos(theta)**62 - 4.20066739090011e+36*cos(theta)**60 + 8.78863035684774e+36*cos(theta)**58 - 1.49307358477588e+37*cos(theta)**56 + 2.09793186182012e+37*cos(theta)**54 - 2.4708975261437e+37*cos(theta)**52 + 2.46346625538838e+37*cos(theta)**50 - 2.09420275006993e+37*cos(theta)**48 + 1.52600820547731e+37*cos(theta)**46 - 9.56643544923694e+36*cos(theta)**44 + 5.17134167713037e+36*cos(theta)**42 - 2.41329278266084e+36*cos(theta)**40 + 9.72297712022445e+35*cos(theta)**38 - 3.37877059590598e+35*cos(theta)**36 + 1.01074334065563e+35*cos(theta)**34 - 2.5950893094179e+34*cos(theta)**32 + 5.69541724544813e+33*cos(theta)**30 - 1.06285135211065e+33*cos(theta)**28 + 1.67538703543715e+32*cos(theta)**26 - 2.21251843363296e+31*cos(theta)**24 + 2.42323447493134e+30*cos(theta)**22 - 2.17385306294812e+29*cos(theta)**20 + 1.57285636694647e+28*cos(theta)**18 - 9.00288156164644e+26*cos(theta)**16 + 3.97770908467442e+25*cos(theta)**14 - 1.31387124030988e+24*cos(theta)**12 + 3.10808250395886e+22*cos(theta)**10 - 4.957947985755e+20*cos(theta)**8 + 4.87438706464677e+18*cos(theta)**6 - 2.54670170566707e+16*cos(theta)**4 + 52872699771634.7*cos(theta)**2 - 18200585119.3235)*sin(6*phi)

#@torch.jit.script
def Yl76_m_minus_5(theta, phi):
    return 1.8900839870258e-9*(1.0 - cos(theta)**2)**2.5*(1.08229480775058e+31*cos(theta)**71 - 1.78112754785442e+32*cos(theta)**69 + 1.40218967357936e+33*cos(theta)**67 - 7.03002577842167e+33*cos(theta)**65 + 2.52111269295122e+34*cos(theta)**63 - 6.88633998508214e+34*cos(theta)**61 + 1.48959836556741e+35*cos(theta)**59 - 2.61942734171207e+35*cos(theta)**57 + 3.81442156694568e+35*cos(theta)**55 - 4.66207080404472e+35*cos(theta)**53 + 4.83032599095761e+35*cos(theta)**51 - 4.27388316340802e+35*cos(theta)**49 + 3.24682596910066e+35*cos(theta)**47 - 2.12587454427488e+35*cos(theta)**45 + 1.20263759933264e+35*cos(theta)**43 - 5.88607995770936e+34*cos(theta)**41 + 2.49307105646781e+34*cos(theta)**39 - 9.1318124213675e+33*cos(theta)**37 + 2.88783811615895e+33*cos(theta)**35 - 7.86390699823605e+32*cos(theta)**33 + 1.8372313694994e+32*cos(theta)**31 - 3.66500466245053e+31*cos(theta)**29 + 6.20513716828572e+30*cos(theta)**27 - 8.85007373453185e+29*cos(theta)**25 + 1.05358020649189e+29*cos(theta)**23 - 1.03516812521339e+28*cos(theta)**21 + 8.2781914049814e+26*cos(theta)**19 - 5.29581268332143e+25*cos(theta)**17 + 2.65180605644961e+24*cos(theta)**15 - 1.01067018485375e+23*cos(theta)**13 + 2.82552954905351e+21*cos(theta)**11 - 5.50883109528334e+19*cos(theta)**9 + 6.96341009235253e+17*cos(theta)**7 - 5.09340341133414e+15*cos(theta)**5 + 17624233257211.6*cos(theta)**3 - 18200585119.3235*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl76_m_minus_4(theta, phi):
    return 1.44341050057709e-7*(1.0 - cos(theta)**2)**2*(1.50318723298691e+29*cos(theta)**72 - 2.54446792550632e+30*cos(theta)**70 + 2.0620436376167e+31*cos(theta)**68 - 1.06515542097298e+32*cos(theta)**66 + 3.93923858273628e+32*cos(theta)**64 - 1.11069999759389e+33*cos(theta)**62 + 2.48266394261236e+33*cos(theta)**60 - 4.5162540374346e+33*cos(theta)**58 + 6.81146708383157e+33*cos(theta)**56 - 8.63346445193466e+33*cos(theta)**54 + 9.28908844414925e+33*cos(theta)**52 - 8.54776632681604e+33*cos(theta)**50 + 6.76422076895972e+33*cos(theta)**48 - 4.62146640059755e+33*cos(theta)**46 + 2.73326727121055e+33*cos(theta)**44 - 1.40144760897842e+33*cos(theta)**42 + 6.23267764116952e+32*cos(theta)**40 - 2.40310853193882e+32*cos(theta)**38 + 8.02177254488598e+31*cos(theta)**36 - 2.3129138230106e+31*cos(theta)**34 + 5.74134802968561e+30*cos(theta)**32 - 1.22166822081684e+30*cos(theta)**30 + 2.2161204172449e+29*cos(theta)**28 - 3.40387451328148e+28*cos(theta)**26 + 4.38991752704953e+27*cos(theta)**24 - 4.70530966006086e+26*cos(theta)**22 + 4.1390957024907e+25*cos(theta)**20 - 2.9421181574008e+24*cos(theta)**18 + 1.65737878528101e+23*cos(theta)**16 - 7.21907274895539e+21*cos(theta)**14 + 2.35460795754459e+20*cos(theta)**12 - 5.50883109528334e+18*cos(theta)**10 + 8.70426261544066e+16*cos(theta)**8 - 848900568555690.0*cos(theta)**6 + 4406058314302.89*cos(theta)**4 - 9100292559.66173*cos(theta)**2 + 3120813.63500059)*sin(4*phi)

#@torch.jit.script
def Yl76_m_minus_3(theta, phi):
    return 1.10305275573515e-5*(1.0 - cos(theta)**2)**1.5*(2.05916059313275e+27*cos(theta)**73 - 3.5837576415582e+28*cos(theta)**71 + 2.9884690400242e+29*cos(theta)**69 - 1.58978421040743e+30*cos(theta)**67 + 6.06036705036351e+30*cos(theta)**65 - 1.76301586919666e+31*cos(theta)**63 + 4.06994088952845e+31*cos(theta)**61 - 7.65466786005865e+31*cos(theta)**59 + 1.19499422523361e+32*cos(theta)**57 - 1.56972080944267e+32*cos(theta)**55 + 1.75265819700929e+32*cos(theta)**53 - 1.67603261310118e+32*cos(theta)**51 + 1.38045321815504e+32*cos(theta)**49 - 9.83290723531395e+31*cos(theta)**47 + 6.07392726935679e+31*cos(theta)**45 - 3.25918048599632e+31*cos(theta)**43 + 1.52016527833403e+31*cos(theta)**41 - 6.16181674856107e+30*cos(theta)**39 + 2.16804663375297e+30*cos(theta)**37 - 6.60832520860172e+29*cos(theta)**35 + 1.73980243323806e+29*cos(theta)**33 - 3.94086522844143e+28*cos(theta)**31 + 7.6417945422238e+27*cos(theta)**29 - 1.26069426417833e+27*cos(theta)**27 + 1.75596701081981e+26*cos(theta)**25 - 2.04578680872211e+25*cos(theta)**23 + 1.970997953567e+24*cos(theta)**21 - 1.54848324073726e+23*cos(theta)**19 + 9.74928697224122e+21*cos(theta)**17 - 4.81271516597026e+20*cos(theta)**15 + 1.81123689041891e+19*cos(theta)**13 - 5.0080282684394e+17*cos(theta)**11 + 9.67140290604518e+15*cos(theta)**9 - 121271509793670.0*cos(theta)**7 + 881211662860.578*cos(theta)**5 - 3033430853.22058*cos(theta)**3 + 3120813.63500059*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl76_m_minus_2(theta, phi):
    return 0.000843384644322593*(1.0 - cos(theta)**2)*(2.7826494501794e+25*cos(theta)**74 - 4.97744116883083e+26*cos(theta)**72 + 4.26924148574886e+27*cos(theta)**70 - 2.33791795648152e+28*cos(theta)**68 + 9.18237431873259e+28*cos(theta)**66 - 2.75471229561978e+29*cos(theta)**64 + 6.56442078956202e+29*cos(theta)**62 - 1.27577797667644e+30*cos(theta)**60 + 2.06033487109243e+30*cos(theta)**58 - 2.80307287400476e+30*cos(theta)**56 + 3.24566332779499e+30*cos(theta)**54 - 3.2231396405792e+30*cos(theta)**52 + 2.76090643631009e+30*cos(theta)**50 - 2.04852234069041e+30*cos(theta)**48 + 1.3204189715993e+30*cos(theta)**46 - 7.40722837726437e+29*cos(theta)**44 + 3.61944113889055e+29*cos(theta)**42 - 1.54045418714027e+29*cos(theta)**40 + 5.70538587829729e+28*cos(theta)**38 - 1.83564589127826e+28*cos(theta)**36 + 5.11706598011195e+27*cos(theta)**34 - 1.23152038388795e+27*cos(theta)**32 + 2.54726484740793e+26*cos(theta)**30 - 4.50247951492259e+25*cos(theta)**28 + 6.75371927238389e+24*cos(theta)**26 - 8.5241117030088e+23*cos(theta)**24 + 8.95908160712273e+22*cos(theta)**22 - 7.74241620368631e+21*cos(theta)**20 + 5.41627054013401e+20*cos(theta)**18 - 3.00794697873141e+19*cos(theta)**16 + 1.29374063601351e+18*cos(theta)**14 - 4.17335689036616e+16*cos(theta)**12 + 967140290604518.0*cos(theta)**10 - 15158938724208.8*cos(theta)**8 + 146868610476.763*cos(theta)**6 - 758357713.305144*cos(theta)**4 + 1560406.8175003*cos(theta)**2 - 533.83743328782)*sin(2*phi)

#@torch.jit.script
def Yl76_m_minus_1(theta, phi):
    return 0.0645065213829812*(1.0 - cos(theta)**2)**0.5*(3.71019926690586e+23*cos(theta)**75 - 6.81841256004223e+24*cos(theta)**73 + 6.01301617711107e+25*cos(theta)**71 - 3.38828689345148e+26*cos(theta)**69 + 1.37050362966158e+27*cos(theta)**67 - 4.23801891633812e+27*cos(theta)**65 + 1.04197155389873e+28*cos(theta)**63 - 2.09143930602695e+28*cos(theta)**61 + 3.49209300185157e+28*cos(theta)**59 - 4.91767170878028e+28*cos(theta)**57 + 5.90120605053634e+28*cos(theta)**55 - 6.08139554826264e+28*cos(theta)**53 + 5.41354203198057e+28*cos(theta)**51 - 4.18065783814368e+28*cos(theta)**49 + 2.80940206723256e+28*cos(theta)**47 - 1.64605075050319e+28*cos(theta)**45 + 8.41730497416406e+27*cos(theta)**43 - 3.75720533448846e+27*cos(theta)**41 + 1.46291945597366e+27*cos(theta)**39 - 4.96120511156286e+26*cos(theta)**37 + 1.46201885146056e+26*cos(theta)**35 - 3.7318799511756e+25*cos(theta)**33 + 8.21698337873527e+24*cos(theta)**31 - 1.55257914307676e+24*cos(theta)**29 + 2.50137750829033e+23*cos(theta)**27 - 3.40964468120352e+22*cos(theta)**25 + 3.89525287266205e+21*cos(theta)**23 - 3.68686485889824e+20*cos(theta)**21 + 2.85066870533369e+19*cos(theta)**19 - 1.76938057572436e+18*cos(theta)**17 + 8.6249375734234e+16*cos(theta)**15 - 3.2102745310509e+15*cos(theta)**13 + 87921844600410.8*cos(theta)**11 - 1684326524912.08*cos(theta)**9 + 20981230068.109*cos(theta)**7 - 151671542.661029*cos(theta)**5 + 520135.605833432*cos(theta)**3 - 533.83743328782*cos(theta))*sin(phi)

#@torch.jit.script
def Yl76_m0(theta, phi):
    return 5.35148483526008e+22*cos(theta)**76 - 1.01004846228419e+24*cos(theta)**74 + 9.15483522358923e+24*cos(theta)**72 - 5.30606776224355e+25*cos(theta)**70 + 2.20933683548589e+26*cos(theta)**68 - 7.03897805767394e+26*cos(theta)**66 + 1.78470542951662e+27*cos(theta)**64 - 3.69780693309918e+27*cos(theta)**62 + 6.38006652417021e+27*cos(theta)**60 - 9.29441789940845e+27*cos(theta)**58 + 1.15516336749791e+28*cos(theta)**56 - 1.23452573625731e+28*cos(theta)**54 + 1.14121855851693e+28*cos(theta)**52 - 9.16569235974226e+27*cos(theta)**50 + 6.41598465181958e+27*cos(theta)**48 - 3.92261825867344e+27*cos(theta)**46 + 2.09706089758626e+27*cos(theta)**44 - 9.80632530458035e+26*cos(theta)**42 + 4.00913869289823e+26*cos(theta)**40 - 1.4311799452909e+26*cos(theta)**38 + 4.45185620150223e+25*cos(theta)**36 - 1.20320437878439e+25*cos(theta)**34 + 2.81483593201852e+24*cos(theta)**32 - 5.67313540138637e+23*cos(theta)**30 + 9.79291230001219e+22*cos(theta)**28 - 1.43756149491441e+22*cos(theta)**26 + 1.77916026598318e+21*cos(theta)**24 - 1.83706783917455e+20*cos(theta)**22 + 1.56245460548351e+19*cos(theta)**20 - 1.07755490033346e+18*cos(theta)**18 + 5.9091720340867e+16*cos(theta)**16 - 2.51364992587878e+15*cos(theta)**14 + 80316763783345.8*cos(theta)**12 - 1846362385824.04*cos(theta)**10 + 28749587322.5197*cos(theta)**8 - 277104456.120672*cos(theta)**6 + 1425434.44506518*cos(theta)**4 - 2925.96875483787*cos(theta)**2 + 0.999989321544044

#@torch.jit.script
def Yl76_m1(theta, phi):
    return 0.0645065213829812*(1.0 - cos(theta)**2)**0.5*(3.71019926690586e+23*cos(theta)**75 - 6.81841256004223e+24*cos(theta)**73 + 6.01301617711107e+25*cos(theta)**71 - 3.38828689345148e+26*cos(theta)**69 + 1.37050362966158e+27*cos(theta)**67 - 4.23801891633812e+27*cos(theta)**65 + 1.04197155389873e+28*cos(theta)**63 - 2.09143930602695e+28*cos(theta)**61 + 3.49209300185157e+28*cos(theta)**59 - 4.91767170878028e+28*cos(theta)**57 + 5.90120605053634e+28*cos(theta)**55 - 6.08139554826264e+28*cos(theta)**53 + 5.41354203198057e+28*cos(theta)**51 - 4.18065783814368e+28*cos(theta)**49 + 2.80940206723256e+28*cos(theta)**47 - 1.64605075050319e+28*cos(theta)**45 + 8.41730497416406e+27*cos(theta)**43 - 3.75720533448846e+27*cos(theta)**41 + 1.46291945597366e+27*cos(theta)**39 - 4.96120511156286e+26*cos(theta)**37 + 1.46201885146056e+26*cos(theta)**35 - 3.7318799511756e+25*cos(theta)**33 + 8.21698337873527e+24*cos(theta)**31 - 1.55257914307676e+24*cos(theta)**29 + 2.50137750829033e+23*cos(theta)**27 - 3.40964468120352e+22*cos(theta)**25 + 3.89525287266205e+21*cos(theta)**23 - 3.68686485889824e+20*cos(theta)**21 + 2.85066870533369e+19*cos(theta)**19 - 1.76938057572436e+18*cos(theta)**17 + 8.6249375734234e+16*cos(theta)**15 - 3.2102745310509e+15*cos(theta)**13 + 87921844600410.8*cos(theta)**11 - 1684326524912.08*cos(theta)**9 + 20981230068.109*cos(theta)**7 - 151671542.661029*cos(theta)**5 + 520135.605833432*cos(theta)**3 - 533.83743328782*cos(theta))*cos(phi)

#@torch.jit.script
def Yl76_m2(theta, phi):
    return 0.000843384644322593*(1.0 - cos(theta)**2)*(2.7826494501794e+25*cos(theta)**74 - 4.97744116883083e+26*cos(theta)**72 + 4.26924148574886e+27*cos(theta)**70 - 2.33791795648152e+28*cos(theta)**68 + 9.18237431873259e+28*cos(theta)**66 - 2.75471229561978e+29*cos(theta)**64 + 6.56442078956202e+29*cos(theta)**62 - 1.27577797667644e+30*cos(theta)**60 + 2.06033487109243e+30*cos(theta)**58 - 2.80307287400476e+30*cos(theta)**56 + 3.24566332779499e+30*cos(theta)**54 - 3.2231396405792e+30*cos(theta)**52 + 2.76090643631009e+30*cos(theta)**50 - 2.04852234069041e+30*cos(theta)**48 + 1.3204189715993e+30*cos(theta)**46 - 7.40722837726437e+29*cos(theta)**44 + 3.61944113889055e+29*cos(theta)**42 - 1.54045418714027e+29*cos(theta)**40 + 5.70538587829729e+28*cos(theta)**38 - 1.83564589127826e+28*cos(theta)**36 + 5.11706598011195e+27*cos(theta)**34 - 1.23152038388795e+27*cos(theta)**32 + 2.54726484740793e+26*cos(theta)**30 - 4.50247951492259e+25*cos(theta)**28 + 6.75371927238389e+24*cos(theta)**26 - 8.5241117030088e+23*cos(theta)**24 + 8.95908160712273e+22*cos(theta)**22 - 7.74241620368631e+21*cos(theta)**20 + 5.41627054013401e+20*cos(theta)**18 - 3.00794697873141e+19*cos(theta)**16 + 1.29374063601351e+18*cos(theta)**14 - 4.17335689036616e+16*cos(theta)**12 + 967140290604518.0*cos(theta)**10 - 15158938724208.8*cos(theta)**8 + 146868610476.763*cos(theta)**6 - 758357713.305144*cos(theta)**4 + 1560406.8175003*cos(theta)**2 - 533.83743328782)*cos(2*phi)

#@torch.jit.script
def Yl76_m3(theta, phi):
    return 1.10305275573515e-5*(1.0 - cos(theta)**2)**1.5*(2.05916059313275e+27*cos(theta)**73 - 3.5837576415582e+28*cos(theta)**71 + 2.9884690400242e+29*cos(theta)**69 - 1.58978421040743e+30*cos(theta)**67 + 6.06036705036351e+30*cos(theta)**65 - 1.76301586919666e+31*cos(theta)**63 + 4.06994088952845e+31*cos(theta)**61 - 7.65466786005865e+31*cos(theta)**59 + 1.19499422523361e+32*cos(theta)**57 - 1.56972080944267e+32*cos(theta)**55 + 1.75265819700929e+32*cos(theta)**53 - 1.67603261310118e+32*cos(theta)**51 + 1.38045321815504e+32*cos(theta)**49 - 9.83290723531395e+31*cos(theta)**47 + 6.07392726935679e+31*cos(theta)**45 - 3.25918048599632e+31*cos(theta)**43 + 1.52016527833403e+31*cos(theta)**41 - 6.16181674856107e+30*cos(theta)**39 + 2.16804663375297e+30*cos(theta)**37 - 6.60832520860172e+29*cos(theta)**35 + 1.73980243323806e+29*cos(theta)**33 - 3.94086522844143e+28*cos(theta)**31 + 7.6417945422238e+27*cos(theta)**29 - 1.26069426417833e+27*cos(theta)**27 + 1.75596701081981e+26*cos(theta)**25 - 2.04578680872211e+25*cos(theta)**23 + 1.970997953567e+24*cos(theta)**21 - 1.54848324073726e+23*cos(theta)**19 + 9.74928697224122e+21*cos(theta)**17 - 4.81271516597026e+20*cos(theta)**15 + 1.81123689041891e+19*cos(theta)**13 - 5.0080282684394e+17*cos(theta)**11 + 9.67140290604518e+15*cos(theta)**9 - 121271509793670.0*cos(theta)**7 + 881211662860.578*cos(theta)**5 - 3033430853.22058*cos(theta)**3 + 3120813.63500059*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl76_m4(theta, phi):
    return 1.44341050057709e-7*(1.0 - cos(theta)**2)**2*(1.50318723298691e+29*cos(theta)**72 - 2.54446792550632e+30*cos(theta)**70 + 2.0620436376167e+31*cos(theta)**68 - 1.06515542097298e+32*cos(theta)**66 + 3.93923858273628e+32*cos(theta)**64 - 1.11069999759389e+33*cos(theta)**62 + 2.48266394261236e+33*cos(theta)**60 - 4.5162540374346e+33*cos(theta)**58 + 6.81146708383157e+33*cos(theta)**56 - 8.63346445193466e+33*cos(theta)**54 + 9.28908844414925e+33*cos(theta)**52 - 8.54776632681604e+33*cos(theta)**50 + 6.76422076895972e+33*cos(theta)**48 - 4.62146640059755e+33*cos(theta)**46 + 2.73326727121055e+33*cos(theta)**44 - 1.40144760897842e+33*cos(theta)**42 + 6.23267764116952e+32*cos(theta)**40 - 2.40310853193882e+32*cos(theta)**38 + 8.02177254488598e+31*cos(theta)**36 - 2.3129138230106e+31*cos(theta)**34 + 5.74134802968561e+30*cos(theta)**32 - 1.22166822081684e+30*cos(theta)**30 + 2.2161204172449e+29*cos(theta)**28 - 3.40387451328148e+28*cos(theta)**26 + 4.38991752704953e+27*cos(theta)**24 - 4.70530966006086e+26*cos(theta)**22 + 4.1390957024907e+25*cos(theta)**20 - 2.9421181574008e+24*cos(theta)**18 + 1.65737878528101e+23*cos(theta)**16 - 7.21907274895539e+21*cos(theta)**14 + 2.35460795754459e+20*cos(theta)**12 - 5.50883109528334e+18*cos(theta)**10 + 8.70426261544066e+16*cos(theta)**8 - 848900568555690.0*cos(theta)**6 + 4406058314302.89*cos(theta)**4 - 9100292559.66173*cos(theta)**2 + 3120813.63500059)*cos(4*phi)

#@torch.jit.script
def Yl76_m5(theta, phi):
    return 1.8900839870258e-9*(1.0 - cos(theta)**2)**2.5*(1.08229480775058e+31*cos(theta)**71 - 1.78112754785442e+32*cos(theta)**69 + 1.40218967357936e+33*cos(theta)**67 - 7.03002577842167e+33*cos(theta)**65 + 2.52111269295122e+34*cos(theta)**63 - 6.88633998508214e+34*cos(theta)**61 + 1.48959836556741e+35*cos(theta)**59 - 2.61942734171207e+35*cos(theta)**57 + 3.81442156694568e+35*cos(theta)**55 - 4.66207080404472e+35*cos(theta)**53 + 4.83032599095761e+35*cos(theta)**51 - 4.27388316340802e+35*cos(theta)**49 + 3.24682596910066e+35*cos(theta)**47 - 2.12587454427488e+35*cos(theta)**45 + 1.20263759933264e+35*cos(theta)**43 - 5.88607995770936e+34*cos(theta)**41 + 2.49307105646781e+34*cos(theta)**39 - 9.1318124213675e+33*cos(theta)**37 + 2.88783811615895e+33*cos(theta)**35 - 7.86390699823605e+32*cos(theta)**33 + 1.8372313694994e+32*cos(theta)**31 - 3.66500466245053e+31*cos(theta)**29 + 6.20513716828572e+30*cos(theta)**27 - 8.85007373453185e+29*cos(theta)**25 + 1.05358020649189e+29*cos(theta)**23 - 1.03516812521339e+28*cos(theta)**21 + 8.2781914049814e+26*cos(theta)**19 - 5.29581268332143e+25*cos(theta)**17 + 2.65180605644961e+24*cos(theta)**15 - 1.01067018485375e+23*cos(theta)**13 + 2.82552954905351e+21*cos(theta)**11 - 5.50883109528334e+19*cos(theta)**9 + 6.96341009235253e+17*cos(theta)**7 - 5.09340341133414e+15*cos(theta)**5 + 17624233257211.6*cos(theta)**3 - 18200585119.3235*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl76_m6(theta, phi):
    return 2.47710834385285e-11*(1.0 - cos(theta)**2)**3*(7.68429313502909e+32*cos(theta)**70 - 1.22897800801955e+34*cos(theta)**68 + 9.39467081298168e+34*cos(theta)**66 - 4.56951675597408e+35*cos(theta)**64 + 1.58830099655927e+36*cos(theta)**62 - 4.20066739090011e+36*cos(theta)**60 + 8.78863035684774e+36*cos(theta)**58 - 1.49307358477588e+37*cos(theta)**56 + 2.09793186182012e+37*cos(theta)**54 - 2.4708975261437e+37*cos(theta)**52 + 2.46346625538838e+37*cos(theta)**50 - 2.09420275006993e+37*cos(theta)**48 + 1.52600820547731e+37*cos(theta)**46 - 9.56643544923694e+36*cos(theta)**44 + 5.17134167713037e+36*cos(theta)**42 - 2.41329278266084e+36*cos(theta)**40 + 9.72297712022445e+35*cos(theta)**38 - 3.37877059590598e+35*cos(theta)**36 + 1.01074334065563e+35*cos(theta)**34 - 2.5950893094179e+34*cos(theta)**32 + 5.69541724544813e+33*cos(theta)**30 - 1.06285135211065e+33*cos(theta)**28 + 1.67538703543715e+32*cos(theta)**26 - 2.21251843363296e+31*cos(theta)**24 + 2.42323447493134e+30*cos(theta)**22 - 2.17385306294812e+29*cos(theta)**20 + 1.57285636694647e+28*cos(theta)**18 - 9.00288156164644e+26*cos(theta)**16 + 3.97770908467442e+25*cos(theta)**14 - 1.31387124030988e+24*cos(theta)**12 + 3.10808250395886e+22*cos(theta)**10 - 4.957947985755e+20*cos(theta)**8 + 4.87438706464677e+18*cos(theta)**6 - 2.54670170566707e+16*cos(theta)**4 + 52872699771634.7*cos(theta)**2 - 18200585119.3235)*cos(6*phi)

#@torch.jit.script
def Yl76_m7(theta, phi):
    return 3.24980225724004e-13*(1.0 - cos(theta)**2)**3.5*(5.37900519452036e+34*cos(theta)**69 - 8.35705045453296e+35*cos(theta)**67 + 6.20048273656791e+36*cos(theta)**65 - 2.92449072382341e+37*cos(theta)**63 + 9.84746617866746e+37*cos(theta)**61 - 2.52040043454006e+38*cos(theta)**59 + 5.09740560697169e+38*cos(theta)**57 - 8.36121207474493e+38*cos(theta)**55 + 1.13288320538287e+39*cos(theta)**53 - 1.28486671359472e+39*cos(theta)**51 + 1.23173312769419e+39*cos(theta)**49 - 1.00521732003357e+39*cos(theta)**47 + 7.01963774519564e+38*cos(theta)**45 - 4.20923159766425e+38*cos(theta)**43 + 2.17196350439475e+38*cos(theta)**41 - 9.65317113064335e+37*cos(theta)**39 + 3.69473130568529e+37*cos(theta)**37 - 1.21635741452615e+37*cos(theta)**35 + 3.43652735822916e+36*cos(theta)**33 - 8.30428579013727e+35*cos(theta)**31 + 1.70862517363444e+35*cos(theta)**29 - 2.97598378590983e+34*cos(theta)**27 + 4.35600629213658e+33*cos(theta)**25 - 5.31004424071911e+32*cos(theta)**23 + 5.33111584484895e+31*cos(theta)**21 - 4.34770612589623e+30*cos(theta)**19 + 2.83114146050364e+29*cos(theta)**17 - 1.44046104986343e+28*cos(theta)**15 + 5.56879271854419e+26*cos(theta)**13 - 1.57664548837186e+25*cos(theta)**11 + 3.10808250395886e+23*cos(theta)**9 - 3.966358388604e+21*cos(theta)**7 + 2.92463223878806e+19*cos(theta)**5 - 1.01868068226683e+17*cos(theta)**3 + 105745399543269.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl76_m8(theta, phi):
    return 4.26867162858366e-15*(1.0 - cos(theta)**2)**4*(3.71151358421905e+36*cos(theta)**68 - 5.59922380453708e+37*cos(theta)**66 + 4.03031377876914e+38*cos(theta)**64 - 1.84242915600875e+39*cos(theta)**62 + 6.00695436898715e+39*cos(theta)**60 - 1.48703625637864e+40*cos(theta)**58 + 2.90552119597386e+40*cos(theta)**56 - 4.59866664110971e+40*cos(theta)**54 + 6.00428098852919e+40*cos(theta)**52 - 6.55282023933309e+40*cos(theta)**50 + 6.03549232570153e+40*cos(theta)**48 - 4.72452140415776e+40*cos(theta)**46 + 3.15883698533804e+40*cos(theta)**44 - 1.80996958699563e+40*cos(theta)**42 + 8.90505036801849e+39*cos(theta)**40 - 3.76473674095091e+39*cos(theta)**38 + 1.36705058310356e+39*cos(theta)**36 - 4.25725095084153e+38*cos(theta)**34 + 1.13405402821562e+38*cos(theta)**32 - 2.57432859494255e+37*cos(theta)**30 + 4.95501300353987e+36*cos(theta)**28 - 8.03515622195655e+35*cos(theta)**26 + 1.08900157303414e+35*cos(theta)**24 - 1.2213101753654e+34*cos(theta)**22 + 1.11953432741828e+33*cos(theta)**20 - 8.26064163920284e+31*cos(theta)**18 + 4.81294048285618e+30*cos(theta)**16 - 2.16069157479514e+29*cos(theta)**14 + 7.23943053410744e+27*cos(theta)**12 - 1.73431003720904e+26*cos(theta)**10 + 2.79727425356297e+24*cos(theta)**8 - 2.7764508720228e+22*cos(theta)**6 + 1.46231611939403e+20*cos(theta)**4 - 3.05604204680048e+17*cos(theta)**2 + 105745399543269.0)*cos(8*phi)

#@torch.jit.script
def Yl76_m9(theta, phi):
    return 5.61472937361047e-17*(1.0 - cos(theta)**2)**4.5*(2.52382923726895e+38*cos(theta)**67 - 3.69548771099448e+39*cos(theta)**65 + 2.57940081841225e+40*cos(theta)**63 - 1.14230607672543e+41*cos(theta)**61 + 3.60417262139229e+41*cos(theta)**59 - 8.6248102869961e+41*cos(theta)**57 + 1.62709186974536e+42*cos(theta)**55 - 2.48327998619924e+42*cos(theta)**53 + 3.12222611403518e+42*cos(theta)**51 - 3.27641011966655e+42*cos(theta)**49 + 2.89703631633674e+42*cos(theta)**47 - 2.17327984591257e+42*cos(theta)**45 + 1.38988827354874e+42*cos(theta)**43 - 7.60187226538164e+41*cos(theta)**41 + 3.5620201472074e+41*cos(theta)**39 - 1.43059996156134e+41*cos(theta)**37 + 4.92138209917281e+40*cos(theta)**35 - 1.44746532328612e+40*cos(theta)**33 + 3.62897289028999e+39*cos(theta)**31 - 7.72298578482766e+38*cos(theta)**29 + 1.38740364099116e+38*cos(theta)**27 - 2.0891406177087e+37*cos(theta)**25 + 2.61360377528195e+36*cos(theta)**23 - 2.68688238580387e+35*cos(theta)**21 + 2.23906865483656e+34*cos(theta)**19 - 1.48691549505651e+33*cos(theta)**17 + 7.7007047725699e+31*cos(theta)**15 - 3.0249682047132e+30*cos(theta)**13 + 8.68731664092893e+28*cos(theta)**11 - 1.73431003720904e+27*cos(theta)**9 + 2.23781940285038e+25*cos(theta)**7 - 1.66587052321368e+23*cos(theta)**5 + 5.84926447757613e+20*cos(theta)**3 - 6.11208409360097e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl76_m10(theta, phi):
    return 7.39677147726305e-19*(1.0 - cos(theta)**2)**5*(1.6909655889702e+40*cos(theta)**66 - 2.40206701214641e+41*cos(theta)**64 + 1.62502251559972e+42*cos(theta)**62 - 6.96806706802509e+42*cos(theta)**60 + 2.12646184662145e+43*cos(theta)**58 - 4.91614186358778e+43*cos(theta)**56 + 8.9490052835995e+43*cos(theta)**54 - 1.3161383926856e+44*cos(theta)**52 + 1.59233531815794e+44*cos(theta)**50 - 1.60544095863661e+44*cos(theta)**48 + 1.36160706867827e+44*cos(theta)**46 - 9.77975930660656e+43*cos(theta)**44 + 5.97651957625957e+43*cos(theta)**42 - 3.11676762880647e+43*cos(theta)**40 + 1.38918785741088e+43*cos(theta)**38 - 5.29321985777698e+42*cos(theta)**36 + 1.72248373471048e+42*cos(theta)**34 - 4.7766355668442e+41*cos(theta)**32 + 1.1249815959899e+41*cos(theta)**30 - 2.23966587760002e+40*cos(theta)**28 + 3.74598983067614e+39*cos(theta)**26 - 5.22285154427176e+38*cos(theta)**24 + 6.01128868314848e+37*cos(theta)**22 - 5.64245301018813e+36*cos(theta)**20 + 4.25423044418946e+35*cos(theta)**18 - 2.52775634159607e+34*cos(theta)**16 + 1.15510571588548e+33*cos(theta)**14 - 3.93245866612716e+31*cos(theta)**12 + 9.55604830502183e+29*cos(theta)**10 - 1.56087903348814e+28*cos(theta)**8 + 1.56647358199526e+26*cos(theta)**6 - 8.3293526160684e+23*cos(theta)**4 + 1.75477934327284e+21*cos(theta)**2 - 6.11208409360097e+17)*cos(10*phi)

#@torch.jit.script
def Yl76_m11(theta, phi):
    return 9.76136623576158e-21*(1.0 - cos(theta)**2)**5.5*(1.11603728872033e+42*cos(theta)**65 - 1.5373228877737e+43*cos(theta)**63 + 1.00751395967183e+44*cos(theta)**61 - 4.18084024081506e+44*cos(theta)**59 + 1.23334787104044e+45*cos(theta)**57 - 2.75303944360915e+45*cos(theta)**55 + 4.83246285314373e+45*cos(theta)**53 - 6.84391964196512e+45*cos(theta)**51 + 7.96167659078971e+45*cos(theta)**49 - 7.70611660145572e+45*cos(theta)**47 + 6.26339251592002e+45*cos(theta)**45 - 4.30309409490689e+45*cos(theta)**43 + 2.51013822202902e+45*cos(theta)**41 - 1.24670705152259e+45*cos(theta)**39 + 5.27891385816136e+44*cos(theta)**37 - 1.90555914879971e+44*cos(theta)**35 + 5.85644469801564e+43*cos(theta)**33 - 1.52852338139014e+43*cos(theta)**31 + 3.37494478796969e+42*cos(theta)**29 - 6.27106445728006e+41*cos(theta)**27 + 9.73957355975797e+40*cos(theta)**25 - 1.25348437062522e+40*cos(theta)**23 + 1.32248351029266e+39*cos(theta)**21 - 1.12849060203763e+38*cos(theta)**19 + 7.65761479954103e+36*cos(theta)**17 - 4.04441014655371e+35*cos(theta)**15 + 1.61714800223968e+34*cos(theta)**13 - 4.7189503993526e+32*cos(theta)**11 + 9.55604830502183e+30*cos(theta)**9 - 1.24870322679051e+29*cos(theta)**7 + 9.39884149197159e+26*cos(theta)**5 - 3.33174104642736e+24*cos(theta)**3 + 3.50955868654568e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl76_m12(theta, phi):
    return 1.29066220595158e-22*(1.0 - cos(theta)**2)**6*(7.25424237668215e+43*cos(theta)**64 - 9.68513419297432e+44*cos(theta)**62 + 6.14583515399813e+45*cos(theta)**60 - 2.46669574208088e+46*cos(theta)**58 + 7.03008286493052e+46*cos(theta)**56 - 1.51417169398503e+47*cos(theta)**54 + 2.56120531216618e+47*cos(theta)**52 - 3.49039901740221e+47*cos(theta)**50 + 3.90122152948696e+47*cos(theta)**48 - 3.62187480268419e+47*cos(theta)**46 + 2.81852663216401e+47*cos(theta)**44 - 1.85033046080996e+47*cos(theta)**42 + 1.0291566710319e+47*cos(theta)**40 - 4.8621575009381e+46*cos(theta)**38 + 1.9531981275197e+46*cos(theta)**36 - 6.66945702079899e+45*cos(theta)**34 + 1.93262675034516e+45*cos(theta)**32 - 4.73842248230944e+44*cos(theta)**30 + 9.7873398851121e+43*cos(theta)**28 - 1.69318740346562e+43*cos(theta)**26 + 2.43489338993949e+42*cos(theta)**24 - 2.88301405243801e+41*cos(theta)**22 + 2.7772153716146e+40*cos(theta)**20 - 2.14413214387149e+39*cos(theta)**18 + 1.30179451592198e+38*cos(theta)**16 - 6.06661521983056e+36*cos(theta)**14 + 2.10229240291158e+35*cos(theta)**12 - 5.19084543928786e+33*cos(theta)**10 + 8.60044347451964e+31*cos(theta)**8 - 8.74092258753358e+29*cos(theta)**6 + 4.69942074598579e+27*cos(theta)**4 - 9.99522313928208e+24*cos(theta)**2 + 3.50955868654568e+21)*cos(12*phi)

#@torch.jit.script
def Yl76_m13(theta, phi):
    return 1.71012400264125e-24*(1.0 - cos(theta)**2)**6.5*(4.64271512107658e+45*cos(theta)**63 - 6.00478319964408e+46*cos(theta)**61 + 3.68750109239888e+47*cos(theta)**59 - 1.43068353040691e+48*cos(theta)**57 + 3.93684640436109e+48*cos(theta)**55 - 8.17652714751919e+48*cos(theta)**53 + 1.33182676232641e+49*cos(theta)**51 - 1.7451995087011e+49*cos(theta)**49 + 1.87258633415374e+49*cos(theta)**47 - 1.66606240923473e+49*cos(theta)**45 + 1.24015171815216e+49*cos(theta)**43 - 7.77138793540184e+48*cos(theta)**41 + 4.11662668412759e+48*cos(theta)**39 - 1.84761985035648e+48*cos(theta)**37 + 7.03151325907093e+47*cos(theta)**35 - 2.26761538707166e+47*cos(theta)**33 + 6.18440560110452e+46*cos(theta)**31 - 1.42152674469283e+46*cos(theta)**29 + 2.74045516783139e+45*cos(theta)**27 - 4.4022872490106e+44*cos(theta)**25 + 5.84374413585478e+43*cos(theta)**23 - 6.34263091536362e+42*cos(theta)**21 + 5.55443074322919e+41*cos(theta)**19 - 3.85943785896868e+40*cos(theta)**17 + 2.08287122547516e+39*cos(theta)**15 - 8.49326130776279e+37*cos(theta)**13 + 2.5227508834939e+36*cos(theta)**11 - 5.19084543928786e+34*cos(theta)**9 + 6.88035477961571e+32*cos(theta)**7 - 5.24455355252015e+30*cos(theta)**5 + 1.87976829839432e+28*cos(theta)**3 - 1.99904462785642e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl76_m14(theta, phi):
    return 2.27109903718475e-26*(1.0 - cos(theta)**2)**7*(2.92491052627824e+47*cos(theta)**62 - 3.66291775178289e+48*cos(theta)**60 + 2.17562564451534e+49*cos(theta)**58 - 8.1548961233194e+49*cos(theta)**56 + 2.1652655223986e+50*cos(theta)**54 - 4.33355938818517e+50*cos(theta)**52 + 6.7923164878647e+50*cos(theta)**50 - 8.55147759263541e+50*cos(theta)**48 + 8.80115577052258e+50*cos(theta)**46 - 7.49728084155627e+50*cos(theta)**44 + 5.33265238805431e+50*cos(theta)**42 - 3.18626905351475e+50*cos(theta)**40 + 1.60548440680976e+50*cos(theta)**38 - 6.83619344631896e+49*cos(theta)**36 + 2.46102964067483e+49*cos(theta)**34 - 7.48313077733647e+48*cos(theta)**32 + 1.9171657363424e+48*cos(theta)**30 - 4.12242755960922e+47*cos(theta)**28 + 7.39922895314475e+46*cos(theta)**26 - 1.10057181225265e+46*cos(theta)**24 + 1.3440611512466e+45*cos(theta)**22 - 1.33195249222636e+44*cos(theta)**20 + 1.05534184121355e+43*cos(theta)**18 - 6.56104436024676e+41*cos(theta)**16 + 3.12430683821274e+40*cos(theta)**14 - 1.10412397000916e+39*cos(theta)**12 + 2.77502597184329e+37*cos(theta)**10 - 4.67176089535907e+35*cos(theta)**8 + 4.816248345731e+33*cos(theta)**6 - 2.62227677626007e+31*cos(theta)**4 + 5.63930489518295e+28*cos(theta)**2 - 1.99904462785642e+25)*cos(14*phi)

#@torch.jit.script
def Yl76_m15(theta, phi):
    return 3.0235665514537e-28*(1.0 - cos(theta)**2)**7.5*(1.81344452629251e+49*cos(theta)**61 - 2.19775065106973e+50*cos(theta)**59 + 1.2618628738189e+51*cos(theta)**57 - 4.56674182905887e+51*cos(theta)**55 + 1.16924338209524e+52*cos(theta)**53 - 2.25345088185629e+52*cos(theta)**51 + 3.39615824393235e+52*cos(theta)**49 - 4.104709244465e+52*cos(theta)**47 + 4.04853165444039e+52*cos(theta)**45 - 3.29880357028476e+52*cos(theta)**43 + 2.23971400298281e+52*cos(theta)**41 - 1.2745076214059e+52*cos(theta)**39 + 6.10084074587709e+51*cos(theta)**37 - 2.46102964067483e+51*cos(theta)**35 + 8.36750077829441e+50*cos(theta)**33 - 2.39460184874767e+50*cos(theta)**31 + 5.7514972090272e+49*cos(theta)**29 - 1.15427971669058e+49*cos(theta)**27 + 1.92379952781763e+48*cos(theta)**25 - 2.64137234940636e+47*cos(theta)**23 + 2.95693453274252e+46*cos(theta)**21 - 2.66390498445272e+45*cos(theta)**19 + 1.89961531418438e+44*cos(theta)**17 - 1.04976709763948e+43*cos(theta)**15 + 4.37402957349784e+41*cos(theta)**13 - 1.324948764011e+40*cos(theta)**11 + 2.77502597184329e+38*cos(theta)**9 - 3.73740871628726e+36*cos(theta)**7 + 2.8897490074386e+34*cos(theta)**5 - 1.04891071050403e+32*cos(theta)**3 + 1.12786097903659e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl76_m16(theta, phi):
    return 4.03608869114515e-30*(1.0 - cos(theta)**2)**8*(1.10620116103843e+51*cos(theta)**60 - 1.29667288413114e+52*cos(theta)**58 + 7.19261838076771e+52*cos(theta)**56 - 2.51170800598238e+53*cos(theta)**54 + 6.19698992510479e+53*cos(theta)**52 - 1.14925994974671e+54*cos(theta)**50 + 1.66411753952685e+54*cos(theta)**48 - 1.92921334489855e+54*cos(theta)**46 + 1.82183924449817e+54*cos(theta)**44 - 1.41848553522245e+54*cos(theta)**42 + 9.18282741222952e+53*cos(theta)**40 - 4.97057972348302e+53*cos(theta)**38 + 2.25731107597452e+53*cos(theta)**36 - 8.6136037423619e+52*cos(theta)**34 + 2.76127525683716e+52*cos(theta)**32 - 7.42326573111777e+51*cos(theta)**30 + 1.66793419061789e+51*cos(theta)**28 - 3.11655523506457e+50*cos(theta)**26 + 4.80949881954408e+49*cos(theta)**24 - 6.07515640363463e+48*cos(theta)**22 + 6.20956251875929e+47*cos(theta)**20 - 5.06141947046017e+46*cos(theta)**18 + 3.22934603411345e+45*cos(theta)**16 - 1.57465064645922e+44*cos(theta)**14 + 5.68623844554719e+42*cos(theta)**12 - 1.45744364041209e+41*cos(theta)**10 + 2.49752337465896e+39*cos(theta)**8 - 2.61618610140108e+37*cos(theta)**6 + 1.4448745037193e+35*cos(theta)**4 - 3.14673213151209e+32*cos(theta)**2 + 1.12786097903659e+29)*cos(16*phi)

#@torch.jit.script
def Yl76_m17(theta, phi):
    return 5.40310741648762e-32*(1.0 - cos(theta)**2)**8.5*(6.63720696623059e+52*cos(theta)**59 - 7.52070272796063e+53*cos(theta)**57 + 4.02786629322992e+54*cos(theta)**55 - 1.35632232323048e+55*cos(theta)**53 + 3.22243476105449e+55*cos(theta)**51 - 5.74629974873353e+55*cos(theta)**49 + 7.98776418972889e+55*cos(theta)**47 - 8.87438138653333e+55*cos(theta)**45 + 8.01609267579196e+55*cos(theta)**43 - 5.95763924793427e+55*cos(theta)**41 + 3.67313096489181e+55*cos(theta)**39 - 1.88882029492355e+55*cos(theta)**37 + 8.12631987350828e+54*cos(theta)**35 - 2.92862527240304e+54*cos(theta)**33 + 8.8360808218789e+53*cos(theta)**31 - 2.22697971933533e+53*cos(theta)**29 + 4.67021573373009e+52*cos(theta)**27 - 8.10304361116787e+51*cos(theta)**25 + 1.15427971669058e+51*cos(theta)**23 - 1.33653440879962e+50*cos(theta)**21 + 1.24191250375186e+49*cos(theta)**19 - 9.11055504682831e+47*cos(theta)**17 + 5.16695365458152e+46*cos(theta)**15 - 2.20451090504291e+45*cos(theta)**13 + 6.82348613465663e+43*cos(theta)**11 - 1.45744364041209e+42*cos(theta)**9 + 1.99801869972717e+40*cos(theta)**7 - 1.56971166084065e+38*cos(theta)**5 + 5.7794980148772e+35*cos(theta)**3 - 6.29346426302417e+32*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl76_m18(theta, phi):
    return 7.25527150260126e-34*(1.0 - cos(theta)**2)**9*(3.91595211007605e+54*cos(theta)**58 - 4.28680055493756e+55*cos(theta)**56 + 2.21532646127646e+56*cos(theta)**54 - 7.18850831312156e+56*cos(theta)**52 + 1.64344172813779e+57*cos(theta)**50 - 2.81568687687943e+57*cos(theta)**48 + 3.75424916917258e+57*cos(theta)**46 - 3.99347162394e+57*cos(theta)**44 + 3.44691985059054e+57*cos(theta)**42 - 2.44263209165305e+57*cos(theta)**40 + 1.43252107630781e+57*cos(theta)**38 - 6.98863509121712e+56*cos(theta)**36 + 2.8442119557279e+56*cos(theta)**34 - 9.66446339893005e+55*cos(theta)**32 + 2.73918505478246e+55*cos(theta)**30 - 6.45824118607246e+54*cos(theta)**28 + 1.26095824810712e+54*cos(theta)**26 - 2.02576090279197e+53*cos(theta)**24 + 2.65484334838833e+52*cos(theta)**22 - 2.8067222584792e+51*cos(theta)**20 + 2.35963375712853e+50*cos(theta)**18 - 1.54879435796081e+49*cos(theta)**16 + 7.75043048187229e+47*cos(theta)**14 - 2.86586417655578e+46*cos(theta)**12 + 7.50583474812229e+44*cos(theta)**10 - 1.31169927637089e+43*cos(theta)**8 + 1.39861308980902e+41*cos(theta)**6 - 7.84855830420324e+38*cos(theta)**4 + 1.73384940446316e+36*cos(theta)**2 - 6.29346426302417e+32)*cos(18*phi)

#@torch.jit.script
def Yl76_m19(theta, phi):
    return 9.77412456581428e-36*(1.0 - cos(theta)**2)**9.5*(2.27125222384411e+56*cos(theta)**57 - 2.40060831076503e+57*cos(theta)**55 + 1.19627628908929e+58*cos(theta)**53 - 3.73802432282321e+58*cos(theta)**51 + 8.21720864068895e+58*cos(theta)**49 - 1.35152970090213e+59*cos(theta)**47 + 1.72695461781939e+59*cos(theta)**45 - 1.7571275145336e+59*cos(theta)**43 + 1.44770633724803e+59*cos(theta)**41 - 9.77052836661221e+58*cos(theta)**39 + 5.44358008996966e+58*cos(theta)**37 - 2.51590863283816e+58*cos(theta)**35 + 9.67032064947485e+57*cos(theta)**33 - 3.09262828765761e+57*cos(theta)**31 + 8.21755516434738e+56*cos(theta)**29 - 1.80830753210029e+56*cos(theta)**27 + 3.27849144507852e+55*cos(theta)**25 - 4.86182616670072e+54*cos(theta)**23 + 5.84065536645434e+53*cos(theta)**21 - 5.6134445169584e+52*cos(theta)**19 + 4.24734076283136e+51*cos(theta)**17 - 2.4780709727373e+50*cos(theta)**15 + 1.08506026746212e+49*cos(theta)**13 - 3.43903701186694e+47*cos(theta)**11 + 7.50583474812229e+45*cos(theta)**9 - 1.04935942109671e+44*cos(theta)**7 + 8.3916785388541e+41*cos(theta)**5 - 3.1394233216813e+39*cos(theta)**3 + 3.46769880892632e+36*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl76_m20(theta, phi):
    return 1.32131031447958e-37*(1.0 - cos(theta)**2)**10*(1.29461376759114e+58*cos(theta)**56 - 1.32033457092077e+59*cos(theta)**54 + 6.34026433217322e+59*cos(theta)**52 - 1.90639240463984e+60*cos(theta)**50 + 4.02643223393759e+60*cos(theta)**48 - 6.35218959424e+60*cos(theta)**46 + 7.77129578018723e+60*cos(theta)**44 - 7.55564831249447e+60*cos(theta)**42 + 5.93559598271692e+60*cos(theta)**40 - 3.81050606297876e+60*cos(theta)**38 + 2.01412463328877e+60*cos(theta)**36 - 8.80568021493357e+59*cos(theta)**34 + 3.1912058143267e+59*cos(theta)**32 - 9.58714769173861e+58*cos(theta)**30 + 2.38309099766074e+58*cos(theta)**28 - 4.88243033667078e+57*cos(theta)**26 + 8.1962286126963e+56*cos(theta)**24 - 1.11822001834117e+56*cos(theta)**22 + 1.22653762695541e+55*cos(theta)**20 - 1.0665544582221e+54*cos(theta)**18 + 7.22047929681331e+52*cos(theta)**16 - 3.71710645910595e+51*cos(theta)**14 + 1.41057834770076e+50*cos(theta)**12 - 3.78294071305363e+48*cos(theta)**10 + 6.75525127331006e+46*cos(theta)**8 - 7.34551594767696e+44*cos(theta)**6 + 4.19583926942705e+42*cos(theta)**4 - 9.41826996504389e+39*cos(theta)**2 + 3.46769880892632e+36)*cos(20*phi)

#@torch.jit.script
def Yl76_m21(theta, phi):
    return 1.79277152085142e-39*(1.0 - cos(theta)**2)**10.5*(7.2498370985104e+59*cos(theta)**55 - 7.12980668297214e+60*cos(theta)**53 + 3.29693745273007e+61*cos(theta)**51 - 9.53196202319919e+61*cos(theta)**49 + 1.93268747229004e+62*cos(theta)**47 - 2.9220072133504e+62*cos(theta)**45 + 3.41937014328238e+62*cos(theta)**43 - 3.17337229124768e+62*cos(theta)**41 + 2.37423839308677e+62*cos(theta)**39 - 1.44799230393193e+62*cos(theta)**37 + 7.25084867983959e+61*cos(theta)**35 - 2.99393127307741e+61*cos(theta)**33 + 1.02118586058454e+61*cos(theta)**31 - 2.87614430752158e+60*cos(theta)**29 + 6.67265479345007e+59*cos(theta)**27 - 1.2694318875344e+59*cos(theta)**25 + 1.96709486704711e+58*cos(theta)**23 - 2.46008404035057e+57*cos(theta)**21 + 2.45307525391082e+56*cos(theta)**19 - 1.91979802479977e+55*cos(theta)**17 + 1.15527668749013e+54*cos(theta)**15 - 5.20394904274833e+52*cos(theta)**13 + 1.69269401724091e+51*cos(theta)**11 - 3.78294071305363e+49*cos(theta)**9 + 5.40420101864805e+47*cos(theta)**7 - 4.40730956860617e+45*cos(theta)**5 + 1.67833570777082e+43*cos(theta)**3 - 1.88365399300878e+40*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl76_m22(theta, phi):
    return 2.4419151088525e-41*(1.0 - cos(theta)**2)**11*(3.98741040418072e+61*cos(theta)**54 - 3.77879754197524e+62*cos(theta)**52 + 1.68143810089234e+63*cos(theta)**50 - 4.6706613913676e+63*cos(theta)**48 + 9.0836311197632e+63*cos(theta)**46 - 1.31490324600768e+64*cos(theta)**44 + 1.47032916161142e+64*cos(theta)**42 - 1.30108263941155e+64*cos(theta)**40 + 9.25952973303839e+63*cos(theta)**38 - 5.35757152454814e+63*cos(theta)**36 + 2.53779703794386e+63*cos(theta)**34 - 9.87997320115547e+62*cos(theta)**32 + 3.16567616781209e+62*cos(theta)**30 - 8.34081849181259e+61*cos(theta)**28 + 1.80161679423152e+61*cos(theta)**26 - 3.17357971883601e+60*cos(theta)**24 + 4.52431819420836e+59*cos(theta)**22 - 5.16617648473619e+58*cos(theta)**20 + 4.66084298243056e+57*cos(theta)**18 - 3.26365664215961e+56*cos(theta)**16 + 1.73291503123519e+55*cos(theta)**14 - 6.76513375557283e+53*cos(theta)**12 + 1.861963418965e+52*cos(theta)**10 - 3.40464664174827e+50*cos(theta)**8 + 3.78294071305363e+48*cos(theta)**6 - 2.20365478430309e+46*cos(theta)**4 + 5.03500712331246e+43*cos(theta)**2 - 1.88365399300878e+40)*cos(22*phi)

#@torch.jit.script
def Yl76_m23(theta, phi):
    return 3.33976635104016e-43*(1.0 - cos(theta)**2)**11.5*(2.15320161825759e+63*cos(theta)**53 - 1.96497472182712e+64*cos(theta)**51 + 8.40719050446168e+64*cos(theta)**49 - 2.24191746785645e+65*cos(theta)**47 + 4.17847031509107e+65*cos(theta)**45 - 5.78557428243379e+65*cos(theta)**43 + 6.17538247876798e+65*cos(theta)**41 - 5.20433055764619e+65*cos(theta)**39 + 3.51862129855459e+65*cos(theta)**37 - 1.92872574883733e+65*cos(theta)**35 + 8.62850992900911e+64*cos(theta)**33 - 3.16159142436975e+64*cos(theta)**31 + 9.49702850343626e+63*cos(theta)**29 - 2.33542917770752e+63*cos(theta)**27 + 4.68420366500195e+62*cos(theta)**25 - 7.61659132520642e+61*cos(theta)**23 + 9.95350002725839e+60*cos(theta)**21 - 1.03323529694724e+60*cos(theta)**19 + 8.38951736837501e+58*cos(theta)**17 - 5.22185062745538e+57*cos(theta)**15 + 2.42608104372927e+56*cos(theta)**13 - 8.11816050668739e+54*cos(theta)**11 + 1.861963418965e+53*cos(theta)**9 - 2.72371731339862e+51*cos(theta)**7 + 2.26976442783218e+49*cos(theta)**5 - 8.81461913721235e+46*cos(theta)**3 + 1.00700142466249e+44*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl76_m24(theta, phi):
    return 4.58752189435731e-45*(1.0 - cos(theta)**2)**12*(1.14119685767652e+65*cos(theta)**52 - 1.00213710813183e+66*cos(theta)**50 + 4.11952334718622e+66*cos(theta)**48 - 1.05370120989253e+67*cos(theta)**46 + 1.88031164179098e+67*cos(theta)**44 - 2.48779694144653e+67*cos(theta)**42 + 2.53190681629487e+67*cos(theta)**40 - 2.02968891748202e+67*cos(theta)**38 + 1.3018898804652e+67*cos(theta)**36 - 6.75054012093065e+66*cos(theta)**34 + 2.84740827657301e+66*cos(theta)**32 - 9.80093341554622e+65*cos(theta)**30 + 2.75413826599652e+65*cos(theta)**28 - 6.30565877981032e+64*cos(theta)**26 + 1.17105091625049e+64*cos(theta)**24 - 1.75181600479748e+63*cos(theta)**22 + 2.09023500572426e+62*cos(theta)**20 - 1.96314706419975e+61*cos(theta)**18 + 1.42621795262375e+60*cos(theta)**16 - 7.83277594118307e+58*cos(theta)**14 + 3.15390535684805e+57*cos(theta)**12 - 8.92997655735613e+55*cos(theta)**10 + 1.6757670770685e+54*cos(theta)**8 - 1.90660211937903e+52*cos(theta)**6 + 1.13488221391609e+50*cos(theta)**4 - 2.6443857411637e+47*cos(theta)**2 + 1.00700142466249e+44)*cos(24*phi)

#@torch.jit.script
def Yl76_m25(theta, phi):
    return 6.33017609103435e-47*(1.0 - cos(theta)**2)**12.5*(5.93422365991791e+66*cos(theta)**51 - 5.01068554065916e+67*cos(theta)**49 + 1.97737120664939e+68*cos(theta)**47 - 4.84702556550564e+68*cos(theta)**45 + 8.27337122388032e+68*cos(theta)**43 - 1.04487471540754e+69*cos(theta)**41 + 1.01276272651795e+69*cos(theta)**39 - 7.71281788643166e+68*cos(theta)**37 + 4.68680356967471e+68*cos(theta)**35 - 2.29518364111642e+68*cos(theta)**33 + 9.11170648503362e+67*cos(theta)**31 - 2.94028002466387e+67*cos(theta)**29 + 7.71158714479025e+66*cos(theta)**27 - 1.63947128275068e+66*cos(theta)**25 + 2.81052219900117e+65*cos(theta)**23 - 3.85399521055445e+64*cos(theta)**21 + 4.18047001144852e+63*cos(theta)**19 - 3.53366471555955e+62*cos(theta)**17 + 2.281948724198e+61*cos(theta)**15 - 1.09658863176563e+60*cos(theta)**13 + 3.78468642821766e+58*cos(theta)**11 - 8.92997655735613e+56*cos(theta)**9 + 1.3406136616548e+55*cos(theta)**7 - 1.14396127162742e+53*cos(theta)**5 + 4.53952885566436e+50*cos(theta)**3 - 5.28877148232741e+47*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl76_m26(theta, phi):
    return 8.77668713740263e-49*(1.0 - cos(theta)**2)**13*(3.02645406655813e+68*cos(theta)**50 - 2.45523591492299e+69*cos(theta)**48 + 9.29364467125212e+69*cos(theta)**46 - 2.18116150447754e+70*cos(theta)**44 + 3.55754962626854e+70*cos(theta)**42 - 4.28398633317092e+70*cos(theta)**40 + 3.94977463342e+70*cos(theta)**38 - 2.85374261797971e+70*cos(theta)**36 + 1.64038124938615e+70*cos(theta)**34 - 7.57410601568419e+69*cos(theta)**32 + 2.82462901036042e+69*cos(theta)**30 - 8.52681207152521e+68*cos(theta)**28 + 2.08212852909337e+68*cos(theta)**26 - 4.09867820687671e+67*cos(theta)**24 + 6.46420105770269e+66*cos(theta)**22 - 8.09338994216434e+65*cos(theta)**20 + 7.9428930217522e+64*cos(theta)**18 - 6.00723001645124e+63*cos(theta)**16 + 3.422923086297e+62*cos(theta)**14 - 1.42556522129532e+61*cos(theta)**12 + 4.16315507103943e+59*cos(theta)**10 - 8.03697890162052e+57*cos(theta)**8 + 9.38429563158359e+55*cos(theta)**6 - 5.71980635813709e+53*cos(theta)**4 + 1.36185865669931e+51*cos(theta)**2 - 5.28877148232741e+47)*cos(26*phi)

#@torch.jit.script
def Yl76_m27(theta, phi):
    return 1.2230015369474e-50*(1.0 - cos(theta)**2)**13.5*(1.51322703327907e+70*cos(theta)**49 - 1.17851323916304e+71*cos(theta)**47 + 4.27507654877598e+71*cos(theta)**45 - 9.59711061970117e+71*cos(theta)**43 + 1.49417084303279e+72*cos(theta)**41 - 1.71359453326837e+72*cos(theta)**39 + 1.5009143606996e+72*cos(theta)**37 - 1.0273473424727e+72*cos(theta)**35 + 5.57729624791291e+71*cos(theta)**33 - 2.42371392501894e+71*cos(theta)**31 + 8.47388703108126e+70*cos(theta)**29 - 2.38750738002706e+70*cos(theta)**27 + 5.41353417564275e+69*cos(theta)**25 - 9.83682769650409e+68*cos(theta)**23 + 1.42212423269459e+68*cos(theta)**21 - 1.61867798843287e+67*cos(theta)**19 + 1.4297207439154e+66*cos(theta)**17 - 9.61156802632198e+64*cos(theta)**15 + 4.7920923208158e+63*cos(theta)**13 - 1.71067826555438e+62*cos(theta)**11 + 4.16315507103943e+60*cos(theta)**9 - 6.42958312129641e+58*cos(theta)**7 + 5.63057737895015e+56*cos(theta)**5 - 2.28792254325484e+54*cos(theta)**3 + 2.72371731339862e+51*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl76_m28(theta, phi):
    return 1.71321667638702e-52*(1.0 - cos(theta)**2)**14*(7.41481246306743e+71*cos(theta)**48 - 5.53901222406627e+72*cos(theta)**46 + 1.92378444694919e+73*cos(theta)**44 - 4.1267575664715e+73*cos(theta)**42 + 6.12610045643442e+73*cos(theta)**40 - 6.68301867974664e+73*cos(theta)**38 + 5.55338313458852e+73*cos(theta)**36 - 3.59571569865444e+73*cos(theta)**34 + 1.84050776181126e+73*cos(theta)**32 - 7.51351316755872e+72*cos(theta)**30 + 2.45742723901357e+72*cos(theta)**28 - 6.44626992607306e+71*cos(theta)**26 + 1.35338354391069e+71*cos(theta)**24 - 2.26247037019594e+70*cos(theta)**22 + 2.98646088865864e+69*cos(theta)**20 - 3.07548817802245e+68*cos(theta)**18 + 2.43052526465617e+67*cos(theta)**16 - 1.4417352039483e+66*cos(theta)**14 + 6.22972001706055e+64*cos(theta)**12 - 1.88174609210982e+63*cos(theta)**10 + 3.74683956393549e+61*cos(theta)**8 - 4.50070818490749e+59*cos(theta)**6 + 2.81528868947508e+57*cos(theta)**4 - 6.86376762976451e+54*cos(theta)**2 + 2.72371731339862e+51)*cos(28*phi)

#@torch.jit.script
def Yl76_m29(theta, phi):
    return 2.4132206055339e-54*(1.0 - cos(theta)**2)**14.5*(3.55910998227237e+73*cos(theta)**47 - 2.54794562307048e+74*cos(theta)**45 + 8.46465156657643e+74*cos(theta)**43 - 1.73323817791803e+75*cos(theta)**41 + 2.45044018257377e+75*cos(theta)**39 - 2.53954709830372e+75*cos(theta)**37 + 1.99921792845187e+75*cos(theta)**35 - 1.22254333754251e+75*cos(theta)**33 + 5.88962483779603e+74*cos(theta)**31 - 2.25405395026762e+74*cos(theta)**29 + 6.88079626923799e+73*cos(theta)**27 - 1.676030180779e+73*cos(theta)**25 + 3.24812050538565e+72*cos(theta)**23 - 4.97743481443107e+71*cos(theta)**21 + 5.97292177731729e+70*cos(theta)**19 - 5.53587872044041e+69*cos(theta)**17 + 3.88884042344988e+68*cos(theta)**15 - 2.01842928552762e+67*cos(theta)**13 + 7.47566402047265e+65*cos(theta)**11 - 1.88174609210982e+64*cos(theta)**9 + 2.99747165114839e+62*cos(theta)**7 - 2.70042491094449e+60*cos(theta)**5 + 1.12611547579003e+58*cos(theta)**3 - 1.3727535259529e+55*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl76_m30(theta, phi):
    return 3.41896900227033e-56*(1.0 - cos(theta)**2)**15*(1.67278169166801e+75*cos(theta)**46 - 1.14657553038172e+76*cos(theta)**44 + 3.63980017362787e+76*cos(theta)**42 - 7.10627652946393e+76*cos(theta)**40 + 9.5567167120377e+76*cos(theta)**38 - 9.39632426372378e+76*cos(theta)**36 + 6.99726274958154e+76*cos(theta)**34 - 4.03439301389028e+76*cos(theta)**32 + 1.82578369971677e+76*cos(theta)**30 - 6.53675645577609e+75*cos(theta)**28 + 1.85781499269426e+75*cos(theta)**26 - 4.19007545194749e+74*cos(theta)**24 + 7.470677162387e+73*cos(theta)**22 - 1.04526131103052e+73*cos(theta)**20 + 1.13485513769028e+72*cos(theta)**18 - 9.4109938247487e+70*cos(theta)**16 + 5.83326063517481e+69*cos(theta)**14 - 2.6239580711859e+68*cos(theta)**12 + 8.22323042251992e+66*cos(theta)**10 - 1.69357148289884e+65*cos(theta)**8 + 2.09823015580387e+63*cos(theta)**6 - 1.35021245547225e+61*cos(theta)**4 + 3.37834642737009e+58*cos(theta)**2 - 1.3727535259529e+55)*cos(30*phi)

#@torch.jit.script
def Yl76_m31(theta, phi):
    return 4.87331359228223e-58*(1.0 - cos(theta)**2)**15.5*(7.69479578167286e+76*cos(theta)**45 - 5.04493233367955e+77*cos(theta)**43 + 1.5287160729237e+78*cos(theta)**41 - 2.84251061178557e+78*cos(theta)**39 + 3.63155235057433e+78*cos(theta)**37 - 3.38267673494056e+78*cos(theta)**35 + 2.37906933485772e+78*cos(theta)**33 - 1.29100576444489e+78*cos(theta)**31 + 5.47735109915031e+77*cos(theta)**29 - 1.8302918076173e+77*cos(theta)**27 + 4.83031898100507e+76*cos(theta)**25 - 1.0056181084674e+76*cos(theta)**23 + 1.64354897572514e+75*cos(theta)**21 - 2.09052262206105e+74*cos(theta)**19 + 2.04273924784251e+73*cos(theta)**17 - 1.50575901195979e+72*cos(theta)**15 + 8.16656488924474e+70*cos(theta)**13 - 3.14874968542308e+69*cos(theta)**11 + 8.22323042251992e+67*cos(theta)**9 - 1.35485718631907e+66*cos(theta)**7 + 1.25893809348232e+64*cos(theta)**5 - 5.40084982188899e+61*cos(theta)**3 + 6.75669285474019e+58*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl76_m32(theta, phi):
    return 6.99046754953901e-60*(1.0 - cos(theta)**2)**16*(3.46265810175279e+78*cos(theta)**44 - 2.16932090348221e+79*cos(theta)**42 + 6.26773589898719e+79*cos(theta)**40 - 1.10857913859637e+80*cos(theta)**38 + 1.3436743697125e+80*cos(theta)**36 - 1.1839368572292e+80*cos(theta)**34 + 7.85092880503049e+79*cos(theta)**32 - 4.00211786977916e+79*cos(theta)**30 + 1.58843181875359e+79*cos(theta)**28 - 4.94178788056672e+78*cos(theta)**26 + 1.20757974525127e+78*cos(theta)**24 - 2.31292164947501e+77*cos(theta)**22 + 3.45145284902279e+76*cos(theta)**20 - 3.97199298191599e+75*cos(theta)**18 + 3.47265672133227e+74*cos(theta)**16 - 2.25863851793969e+73*cos(theta)**14 + 1.06165343560182e+72*cos(theta)**12 - 3.46362465396539e+70*cos(theta)**10 + 7.40090738026793e+68*cos(theta)**8 - 9.4840003042335e+66*cos(theta)**6 + 6.29469046741162e+64*cos(theta)**4 - 1.6202549465667e+62*cos(theta)**2 + 6.75669285474019e+58)*cos(32*phi)

#@torch.jit.script
def Yl76_m33(theta, phi):
    return 1.00940775459507e-61*(1.0 - cos(theta)**2)**16.5*(1.52356956477123e+80*cos(theta)**43 - 9.11114779462528e+80*cos(theta)**41 + 2.50709435959487e+81*cos(theta)**39 - 4.21260072666622e+81*cos(theta)**37 + 4.837227730965e+81*cos(theta)**35 - 4.02538531457927e+81*cos(theta)**33 + 2.51229721760976e+81*cos(theta)**31 - 1.20063536093375e+81*cos(theta)**29 + 4.44760909251005e+80*cos(theta)**27 - 1.28486484894735e+80*cos(theta)**25 + 2.89819138860304e+79*cos(theta)**23 - 5.08842762884503e+78*cos(theta)**21 + 6.90290569804559e+77*cos(theta)**19 - 7.14958736744879e+76*cos(theta)**17 + 5.55625075413163e+75*cos(theta)**15 - 3.16209392511556e+74*cos(theta)**13 + 1.27398412272218e+73*cos(theta)**11 - 3.46362465396539e+71*cos(theta)**9 + 5.92072590421434e+69*cos(theta)**7 - 5.6904001825401e+67*cos(theta)**5 + 2.51787618696465e+65*cos(theta)**3 - 3.24050989313339e+62*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl76_m34(theta, phi):
    return 1.46769585064961e-63*(1.0 - cos(theta)**2)**17*(6.55134912851627e+81*cos(theta)**42 - 3.73557059579636e+82*cos(theta)**40 + 9.77766800242001e+82*cos(theta)**38 - 1.5586622688665e+83*cos(theta)**36 + 1.69302970583775e+83*cos(theta)**34 - 1.32837715381116e+83*cos(theta)**32 + 7.78812137459024e+82*cos(theta)**30 - 3.48184254670787e+82*cos(theta)**28 + 1.20085445497771e+82*cos(theta)**26 - 3.21216212236837e+81*cos(theta)**24 + 6.66584019378699e+80*cos(theta)**22 - 1.06856980205746e+80*cos(theta)**20 + 1.31155208262866e+79*cos(theta)**18 - 1.21542985246629e+78*cos(theta)**16 + 8.33437613119745e+76*cos(theta)**14 - 4.11072210265023e+75*cos(theta)**12 + 1.4013825349944e+74*cos(theta)**10 - 3.11726218856885e+72*cos(theta)**8 + 4.14450813295004e+70*cos(theta)**6 - 2.84520009127005e+68*cos(theta)**4 + 7.55362856089394e+65*cos(theta)**2 - 3.24050989313339e+62)*cos(34*phi)

#@torch.jit.script
def Yl76_m35(theta, phi):
    return 2.14956178129312e-65*(1.0 - cos(theta)**2)**17.5*(2.75156663397683e+83*cos(theta)**41 - 1.49422823831855e+84*cos(theta)**39 + 3.7155138409196e+84*cos(theta)**37 - 5.6111841679194e+84*cos(theta)**35 + 5.75630099984835e+84*cos(theta)**33 - 4.25080689219571e+84*cos(theta)**31 + 2.33643641237707e+84*cos(theta)**29 - 9.74915913078203e+83*cos(theta)**27 + 3.12222158294206e+83*cos(theta)**25 - 7.70918909368409e+82*cos(theta)**23 + 1.46648484263314e+82*cos(theta)**21 - 2.13713960411491e+81*cos(theta)**19 + 2.36079374873159e+80*cos(theta)**17 - 1.94468776394607e+79*cos(theta)**15 + 1.16681265836764e+78*cos(theta)**13 - 4.93286652318028e+76*cos(theta)**11 + 1.4013825349944e+75*cos(theta)**9 - 2.49380975085508e+73*cos(theta)**7 + 2.48670487977002e+71*cos(theta)**5 - 1.13808003650802e+69*cos(theta)**3 + 1.51072571217879e+66*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl76_m36(theta, phi):
    return 3.17211550073312e-67*(1.0 - cos(theta)**2)**18*(1.1281423199305e+85*cos(theta)**40 - 5.82749012944233e+85*cos(theta)**38 + 1.37474012114025e+86*cos(theta)**36 - 1.96391445877179e+86*cos(theta)**34 + 1.89957932994996e+86*cos(theta)**32 - 1.31775013658067e+86*cos(theta)**30 + 6.77566559589351e+85*cos(theta)**28 - 2.63227296531115e+85*cos(theta)**26 + 7.80555395735514e+84*cos(theta)**24 - 1.77311349154734e+84*cos(theta)**22 + 3.07961816952959e+83*cos(theta)**20 - 4.06056524781834e+82*cos(theta)**18 + 4.0133493728437e+81*cos(theta)**16 - 2.91703164591911e+80*cos(theta)**14 + 1.51685645587794e+79*cos(theta)**12 - 5.42615317549831e+77*cos(theta)**10 + 1.26124428149496e+76*cos(theta)**8 - 1.74566682559856e+74*cos(theta)**6 + 1.24335243988501e+72*cos(theta)**4 - 3.41424010952406e+69*cos(theta)**2 + 1.51072571217879e+66)*cos(36*phi)

#@torch.jit.script
def Yl76_m37(theta, phi):
    return 4.71823724723755e-69*(1.0 - cos(theta)**2)**18.5*(4.51256927972201e+86*cos(theta)**39 - 2.21444624918808e+87*cos(theta)**37 + 4.94906443610491e+87*cos(theta)**35 - 6.67730915982409e+87*cos(theta)**33 + 6.07865385583986e+87*cos(theta)**31 - 3.95325040974201e+87*cos(theta)**29 + 1.89718636685018e+87*cos(theta)**27 - 6.84390970980898e+86*cos(theta)**25 + 1.87333294976523e+86*cos(theta)**23 - 3.90084968140415e+85*cos(theta)**21 + 6.15923633905918e+84*cos(theta)**19 - 7.309017446073e+83*cos(theta)**17 + 6.42135899654993e+82*cos(theta)**15 - 4.08384430428675e+81*cos(theta)**13 + 1.82022774705352e+80*cos(theta)**11 - 5.4261531754983e+78*cos(theta)**9 + 1.00899542519597e+77*cos(theta)**7 - 1.04740009535913e+75*cos(theta)**5 + 4.97340975954005e+72*cos(theta)**3 - 6.82848021904812e+69*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl76_m38(theta, phi):
    return 7.07611765860017e-71*(1.0 - cos(theta)**2)**19*(1.75990201909158e+88*cos(theta)**38 - 8.19345112199591e+88*cos(theta)**36 + 1.73217255263672e+89*cos(theta)**34 - 2.20351202274195e+89*cos(theta)**32 + 1.88438269531036e+89*cos(theta)**30 - 1.14644261882518e+89*cos(theta)**28 + 5.12240319049549e+88*cos(theta)**26 - 1.71097742745225e+88*cos(theta)**24 + 4.30866578446004e+87*cos(theta)**22 - 8.19178433094871e+86*cos(theta)**20 + 1.17025490442124e+86*cos(theta)**18 - 1.24253296583241e+85*cos(theta)**16 + 9.63203849482489e+83*cos(theta)**14 - 5.30899759557277e+82*cos(theta)**12 + 2.00225052175887e+81*cos(theta)**10 - 4.88353785794848e+79*cos(theta)**8 + 7.06296797637176e+77*cos(theta)**6 - 5.23700047679567e+75*cos(theta)**4 + 1.49202292786201e+73*cos(theta)**2 - 6.82848021904812e+69)*cos(38*phi)

#@torch.jit.script
def Yl76_m39(theta, phi):
    return 1.07042027630539e-72*(1.0 - cos(theta)**2)**19.5*(6.68762767254801e+89*cos(theta)**37 - 2.94964240391853e+90*cos(theta)**35 + 5.88938667896485e+90*cos(theta)**33 - 7.05123847277424e+90*cos(theta)**31 + 5.65314808593107e+90*cos(theta)**29 - 3.21003933271051e+90*cos(theta)**27 + 1.33182482952883e+90*cos(theta)**25 - 4.10634582588539e+89*cos(theta)**23 + 9.47906472581208e+88*cos(theta)**21 - 1.63835686618974e+88*cos(theta)**19 + 2.10645882795824e+87*cos(theta)**17 - 1.98805274533186e+86*cos(theta)**15 + 1.34848538927548e+85*cos(theta)**13 - 6.37079711468733e+83*cos(theta)**11 + 2.00225052175887e+82*cos(theta)**9 - 3.90683028635878e+80*cos(theta)**7 + 4.23778078582306e+78*cos(theta)**5 - 2.09480019071827e+76*cos(theta)**3 + 2.98404585572403e+73*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl76_m40(theta, phi):
    return 1.63389622897507e-74*(1.0 - cos(theta)**2)**20*(2.47442223884277e+91*cos(theta)**36 - 1.03237484137148e+92*cos(theta)**34 + 1.9434976040584e+92*cos(theta)**32 - 2.18588392656001e+92*cos(theta)**30 + 1.63941294492001e+92*cos(theta)**28 - 8.66710619831838e+91*cos(theta)**26 + 3.32956207382207e+91*cos(theta)**24 - 9.4445953995364e+90*cos(theta)**22 + 1.99060359242054e+90*cos(theta)**20 - 3.11287804576051e+89*cos(theta)**18 + 3.58098000752901e+88*cos(theta)**16 - 2.98207911799779e+87*cos(theta)**14 + 1.75303100605813e+86*cos(theta)**12 - 7.00787682615606e+84*cos(theta)**10 + 1.80202546958299e+83*cos(theta)**8 - 2.73478120045115e+81*cos(theta)**6 + 2.11889039291153e+79*cos(theta)**4 - 6.2844005721548e+76*cos(theta)**2 + 2.98404585572403e+73)*cos(40*phi)

#@torch.jit.script
def Yl76_m41(theta, phi):
    return 2.51756266340037e-76*(1.0 - cos(theta)**2)**20.5*(8.90792005983395e+92*cos(theta)**35 - 3.51007446066305e+93*cos(theta)**33 + 6.21919233298688e+93*cos(theta)**31 - 6.55765177968004e+93*cos(theta)**29 + 4.59035624577603e+93*cos(theta)**27 - 2.25344761156278e+93*cos(theta)**25 + 7.99094897717297e+92*cos(theta)**23 - 2.07781098789801e+92*cos(theta)**21 + 3.98120718484107e+91*cos(theta)**19 - 5.60318048236892e+90*cos(theta)**17 + 5.72956801204641e+89*cos(theta)**15 - 4.1749107651969e+88*cos(theta)**13 + 2.10363720726976e+87*cos(theta)**11 - 7.00787682615606e+85*cos(theta)**9 + 1.44162037566639e+84*cos(theta)**7 - 1.64086872027069e+82*cos(theta)**5 + 8.47556157164611e+79*cos(theta)**3 - 1.25688011443096e+77*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl76_m42(theta, phi):
    return 3.91746624769251e-78*(1.0 - cos(theta)**2)**21*(3.11777202094188e+94*cos(theta)**34 - 1.15832457201881e+95*cos(theta)**32 + 1.92794962322593e+95*cos(theta)**30 - 1.90171901610721e+95*cos(theta)**28 + 1.23939618635953e+95*cos(theta)**26 - 5.63361902890694e+94*cos(theta)**24 + 1.83791826474978e+94*cos(theta)**22 - 4.36340307458582e+93*cos(theta)**20 + 7.56429365119804e+92*cos(theta)**18 - 9.52540682002716e+91*cos(theta)**16 + 8.59435201806962e+90*cos(theta)**14 - 5.42738399475597e+89*cos(theta)**12 + 2.31400092799673e+88*cos(theta)**10 - 6.30708914354046e+86*cos(theta)**8 + 1.00913426296647e+85*cos(theta)**6 - 8.20434360135344e+82*cos(theta)**4 + 2.54266847149383e+80*cos(theta)**2 - 1.25688011443096e+77)*cos(42*phi)

#@torch.jit.script
def Yl76_m43(theta, phi):
    return 6.15874643828416e-80*(1.0 - cos(theta)**2)**21.5*(1.06004248712024e+96*cos(theta)**33 - 3.70663863046018e+96*cos(theta)**31 + 5.7838488696778e+96*cos(theta)**29 - 5.32481324510019e+96*cos(theta)**27 + 3.22243008453477e+96*cos(theta)**25 - 1.35206856693767e+96*cos(theta)**23 + 4.04342018244952e+95*cos(theta)**21 - 8.72680614917163e+94*cos(theta)**19 + 1.36157285721565e+94*cos(theta)**17 - 1.52406509120435e+93*cos(theta)**15 + 1.20320928252975e+92*cos(theta)**13 - 6.51286079370716e+90*cos(theta)**11 + 2.31400092799673e+89*cos(theta)**9 - 5.04567131483236e+87*cos(theta)**7 + 6.05480557779884e+85*cos(theta)**5 - 3.28173744054138e+83*cos(theta)**3 + 5.08533694298767e+80*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl76_m44(theta, phi):
    return 9.78689054258913e-82*(1.0 - cos(theta)**2)**22*(3.49814020749679e+97*cos(theta)**32 - 1.14905797544266e+98*cos(theta)**30 + 1.67731617220656e+98*cos(theta)**28 - 1.43769957617705e+98*cos(theta)**26 + 8.05607521133693e+97*cos(theta)**24 - 3.10975770395663e+97*cos(theta)**22 + 8.491182383144e+96*cos(theta)**20 - 1.65809316834261e+96*cos(theta)**18 + 2.3146738572666e+95*cos(theta)**16 - 2.28609763680652e+94*cos(theta)**14 + 1.56417206728867e+93*cos(theta)**12 - 7.16414687307788e+91*cos(theta)**10 + 2.08260083519706e+90*cos(theta)**8 - 3.53196992038265e+88*cos(theta)**6 + 3.02740278889942e+86*cos(theta)**4 - 9.84521232162413e+83*cos(theta)**2 + 5.08533694298767e+80)*cos(44*phi)

#@torch.jit.script
def Yl76_m45(theta, phi):
    return 1.57281287940801e-83*(1.0 - cos(theta)**2)**22.5*(1.11940486639897e+99*cos(theta)**31 - 3.44717392632797e+99*cos(theta)**29 + 4.69648528217837e+99*cos(theta)**27 - 3.73801889806034e+99*cos(theta)**25 + 1.93345805072086e+99*cos(theta)**23 - 6.84146694870459e+98*cos(theta)**21 + 1.6982364766288e+98*cos(theta)**19 - 2.9845677030167e+97*cos(theta)**17 + 3.70347817162656e+96*cos(theta)**15 - 3.20053669152913e+95*cos(theta)**13 + 1.8770064807464e+94*cos(theta)**11 - 7.16414687307788e+92*cos(theta)**9 + 1.66608066815765e+91*cos(theta)**7 - 2.11918195222959e+89*cos(theta)**5 + 1.21096111555977e+87*cos(theta)**3 - 1.96904246432483e+84*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl76_m46(theta, phi):
    return 2.55750384073561e-85*(1.0 - cos(theta)**2)**23*(3.47015508583682e+100*cos(theta)**30 - 9.9968043863511e+100*cos(theta)**28 + 1.26805102618816e+101*cos(theta)**26 - 9.34504724515084e+100*cos(theta)**24 + 4.44695351665799e+100*cos(theta)**22 - 1.43670805922796e+100*cos(theta)**20 + 3.22664930559472e+99*cos(theta)**18 - 5.07376509512839e+98*cos(theta)**16 + 5.55521725743984e+97*cos(theta)**14 - 4.16069769898786e+96*cos(theta)**12 + 2.06470712882105e+95*cos(theta)**10 - 6.44773218577009e+93*cos(theta)**8 + 1.16625646771035e+92*cos(theta)**6 - 1.0595909761148e+90*cos(theta)**4 + 3.6328833466793e+87*cos(theta)**2 - 1.96904246432483e+84)*cos(46*phi)

#@torch.jit.script
def Yl76_m47(theta, phi):
    return 4.21020372839927e-87*(1.0 - cos(theta)**2)**23.5*(1.04104652575105e+102*cos(theta)**29 - 2.79910522817831e+102*cos(theta)**27 + 3.29693266808922e+102*cos(theta)**25 - 2.2428113388362e+102*cos(theta)**23 + 9.78329773664757e+101*cos(theta)**21 - 2.87341611845593e+101*cos(theta)**19 + 5.8079687500705e+100*cos(theta)**17 - 8.11802415220542e+99*cos(theta)**15 + 7.77730416041578e+98*cos(theta)**13 - 4.99283723878544e+97*cos(theta)**11 + 2.06470712882105e+96*cos(theta)**9 - 5.15818574861607e+94*cos(theta)**7 + 6.99753880626212e+92*cos(theta)**5 - 4.23836390445919e+90*cos(theta)**3 + 7.2657666933586e+87*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl76_m48(theta, phi):
    return 7.02090780240922e-89*(1.0 - cos(theta)**2)**24*(3.01903492467803e+103*cos(theta)**28 - 7.55758411608143e+103*cos(theta)**26 + 8.24233167022304e+103*cos(theta)**24 - 5.15846607932326e+103*cos(theta)**22 + 2.05449252469599e+103*cos(theta)**20 - 5.45949062506626e+102*cos(theta)**18 + 9.87354687511984e+101*cos(theta)**16 - 1.21770362283081e+101*cos(theta)**14 + 1.01104954085405e+100*cos(theta)**12 - 5.49212096266398e+98*cos(theta)**10 + 1.85823641593894e+97*cos(theta)**8 - 3.61073002403125e+95*cos(theta)**6 + 3.49876940313106e+93*cos(theta)**4 - 1.27150917133776e+91*cos(theta)**2 + 7.2657666933586e+87)*cos(48*phi)

#@torch.jit.script
def Yl76_m49(theta, phi):
    return 1.18675002025256e-90*(1.0 - cos(theta)**2)**24.5*(8.45329778909849e+104*cos(theta)**27 - 1.96497187018117e+105*cos(theta)**25 + 1.97815960085353e+105*cos(theta)**23 - 1.13486253745112e+105*cos(theta)**21 + 4.10898504939198e+104*cos(theta)**19 - 9.82708312511928e+103*cos(theta)**17 + 1.57976750001917e+103*cos(theta)**15 - 1.70478507196314e+102*cos(theta)**13 + 1.21325944902486e+101*cos(theta)**11 - 5.49212096266398e+99*cos(theta)**9 + 1.48658913275115e+98*cos(theta)**7 - 2.16643801441875e+96*cos(theta)**5 + 1.39950776125242e+94*cos(theta)**3 - 2.54301834267551e+91*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl76_m50(theta, phi):
    return 2.03466115213945e-92*(1.0 - cos(theta)**2)**25*(2.28239040305659e+106*cos(theta)**26 - 4.91242967545293e+106*cos(theta)**24 + 4.54976708196312e+106*cos(theta)**22 - 2.38321132864735e+106*cos(theta)**20 + 7.80707159384476e+105*cos(theta)**18 - 1.67060413127028e+105*cos(theta)**16 + 2.36965125002876e+104*cos(theta)**14 - 2.21622059355208e+103*cos(theta)**12 + 1.33458539392735e+102*cos(theta)**10 - 4.94290886639758e+100*cos(theta)**8 + 1.04061239292581e+99*cos(theta)**6 - 1.08321900720938e+97*cos(theta)**4 + 4.19852328375727e+94*cos(theta)**2 - 2.54301834267551e+91)*cos(50*phi)

#@torch.jit.script
def Yl76_m51(theta, phi):
    return 3.54081762776956e-94*(1.0 - cos(theta)**2)**25.5*(5.93421504794714e+107*cos(theta)**25 - 1.1789831221087e+108*cos(theta)**23 + 1.00094875803189e+108*cos(theta)**21 - 4.7664226572947e+107*cos(theta)**19 + 1.40527288689206e+107*cos(theta)**17 - 2.67296661003244e+106*cos(theta)**15 + 3.31751175004027e+105*cos(theta)**13 - 2.6594647122625e+104*cos(theta)**11 + 1.33458539392735e+103*cos(theta)**9 - 3.95432709311807e+101*cos(theta)**7 + 6.24367435755484e+99*cos(theta)**5 - 4.3328760288375e+97*cos(theta)**3 + 8.39704656751454e+94*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl76_m52(theta, phi):
    return 6.2593403888518e-96*(1.0 - cos(theta)**2)**26*(1.48355376198679e+109*cos(theta)**24 - 2.71166118085002e+109*cos(theta)**22 + 2.10199239186696e+109*cos(theta)**20 - 9.05620304885992e+108*cos(theta)**18 + 2.3889639077165e+108*cos(theta)**16 - 4.00944991504867e+107*cos(theta)**14 + 4.31276527505235e+106*cos(theta)**12 - 2.92541118348875e+105*cos(theta)**10 + 1.20112685453461e+104*cos(theta)**8 - 2.76802896518265e+102*cos(theta)**6 + 3.12183717877742e+100*cos(theta)**4 - 1.29986280865125e+98*cos(theta)**2 + 8.39704656751454e+94)*cos(52*phi)

#@torch.jit.script
def Yl76_m53(theta, phi):
    return 1.12493672092363e-97*(1.0 - cos(theta)**2)**26.5*(3.56052902876829e+110*cos(theta)**23 - 5.96565459787004e+110*cos(theta)**21 + 4.20398478373392e+110*cos(theta)**19 - 1.63011654879479e+110*cos(theta)**17 + 3.82234225234639e+109*cos(theta)**15 - 5.61322988106813e+108*cos(theta)**13 + 5.17531833006282e+107*cos(theta)**11 - 2.92541118348874e+106*cos(theta)**9 + 9.6090148362769e+104*cos(theta)**7 - 1.66081737910959e+103*cos(theta)**5 + 1.24873487151097e+101*cos(theta)**3 - 2.5997256173025e+98*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl76_m54(theta, phi):
    return 2.05727571434266e-99*(1.0 - cos(theta)**2)**27*(8.18921676616706e+111*cos(theta)**22 - 1.25278746555271e+112*cos(theta)**20 + 7.98757108909445e+111*cos(theta)**18 - 2.77119813295114e+111*cos(theta)**16 + 5.73351337851959e+110*cos(theta)**14 - 7.29719884538857e+109*cos(theta)**12 + 5.6928501630691e+108*cos(theta)**10 - 2.63287006513987e+107*cos(theta)**8 + 6.72631038539383e+105*cos(theta)**6 - 8.30408689554794e+103*cos(theta)**4 + 3.7462046145329e+101*cos(theta)**2 - 2.5997256173025e+98)*cos(54*phi)

#@torch.jit.script
def Yl76_m55(theta, phi):
    return 3.83217656884021e-101*(1.0 - cos(theta)**2)**27.5*(1.80162768855675e+113*cos(theta)**21 - 2.50557493110542e+113*cos(theta)**19 + 1.437762796037e+113*cos(theta)**17 - 4.43391701272182e+112*cos(theta)**15 + 8.02691872992743e+111*cos(theta)**13 - 8.75663861446628e+110*cos(theta)**11 + 5.6928501630691e+109*cos(theta)**9 - 2.1062960521119e+108*cos(theta)**7 + 4.0357862312363e+106*cos(theta)**5 - 3.32163475821918e+104*cos(theta)**3 + 7.49240922906581e+101*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl76_m56(theta, phi):
    return 7.27861751466912e-103*(1.0 - cos(theta)**2)**28*(3.78341814596918e+114*cos(theta)**20 - 4.76059236910029e+114*cos(theta)**18 + 2.4441967532629e+114*cos(theta)**16 - 6.65087551908273e+113*cos(theta)**14 + 1.04349943489057e+113*cos(theta)**12 - 9.63230247591291e+111*cos(theta)**10 + 5.12356514676219e+110*cos(theta)**8 - 1.47440723647833e+109*cos(theta)**6 + 2.01789311561815e+107*cos(theta)**4 - 9.96490427465752e+104*cos(theta)**2 + 7.49240922906581e+101)*cos(56*phi)

#@torch.jit.script
def Yl76_m57(theta, phi):
    return 1.41126340407132e-104*(1.0 - cos(theta)**2)**28.5*(7.56683629193836e+115*cos(theta)**19 - 8.56906626438053e+115*cos(theta)**17 + 3.91071480522064e+115*cos(theta)**15 - 9.31122572671582e+114*cos(theta)**13 + 1.25219932186868e+114*cos(theta)**11 - 9.63230247591291e+112*cos(theta)**9 + 4.09885211740975e+111*cos(theta)**7 - 8.84644341886996e+109*cos(theta)**5 + 8.0715724624726e+107*cos(theta)**3 - 1.9929808549315e+105*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl76_m58(theta, phi):
    return 2.79691250186541e-106*(1.0 - cos(theta)**2)**29*(1.43769889546829e+117*cos(theta)**18 - 1.45674126494469e+117*cos(theta)**16 + 5.86607220783096e+116*cos(theta)**14 - 1.21045934447306e+116*cos(theta)**12 + 1.37741925405555e+115*cos(theta)**10 - 8.66907222832162e+113*cos(theta)**8 + 2.86919648218683e+112*cos(theta)**6 - 4.42322170943498e+110*cos(theta)**4 + 2.42147173874178e+108*cos(theta)**2 - 1.9929808549315e+105)*cos(58*phi)

#@torch.jit.script
def Yl76_m59(theta, phi):
    return 5.67382247644406e-108*(1.0 - cos(theta)**2)**29.5*(2.58785801184292e+118*cos(theta)**17 - 2.3307860239115e+118*cos(theta)**15 + 8.21250109096335e+117*cos(theta)**13 - 1.45255121336767e+117*cos(theta)**11 + 1.37741925405555e+116*cos(theta)**9 - 6.9352577826573e+114*cos(theta)**7 + 1.7215178893121e+113*cos(theta)**5 - 1.76928868377399e+111*cos(theta)**3 + 4.84294347748356e+108*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl76_m60(theta, phi):
    return 1.17999951421831e-109*(1.0 - cos(theta)**2)**30*(4.39935862013296e+119*cos(theta)**16 - 3.49617903586725e+119*cos(theta)**14 + 1.06762514182524e+119*cos(theta)**12 - 1.59780633470443e+118*cos(theta)**10 + 1.23967732864999e+117*cos(theta)**8 - 4.85468044786011e+115*cos(theta)**6 + 8.60758944656048e+113*cos(theta)**4 - 5.30786605132198e+111*cos(theta)**2 + 4.84294347748356e+108)*cos(60*phi)

#@torch.jit.script
def Yl76_m61(theta, phi):
    return 2.52035405268617e-111*(1.0 - cos(theta)**2)**30.5*(7.03897379221274e+120*cos(theta)**15 - 4.89465065021416e+120*cos(theta)**13 + 1.28115017019028e+120*cos(theta)**11 - 1.59780633470443e+119*cos(theta)**9 + 9.91741862919994e+117*cos(theta)**7 - 2.91280826871606e+116*cos(theta)**5 + 3.44303577862419e+114*cos(theta)**3 - 1.0615732102644e+112*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl76_m62(theta, phi):
    return 5.539574161284e-113*(1.0 - cos(theta)**2)**31*(1.05584606883191e+122*cos(theta)**14 - 6.3630458452784e+121*cos(theta)**12 + 1.40926518720931e+121*cos(theta)**10 - 1.43802570123399e+120*cos(theta)**8 + 6.94219304043996e+118*cos(theta)**6 - 1.45640413435803e+117*cos(theta)**4 + 1.03291073358726e+115*cos(theta)**2 - 1.0615732102644e+112)*cos(62*phi)

#@torch.jit.script
def Yl76_m63(theta, phi):
    return 1.25575513550519e-114*(1.0 - cos(theta)**2)**31.5*(1.47818449636468e+123*cos(theta)**13 - 7.63565501433408e+122*cos(theta)**11 + 1.40926518720931e+122*cos(theta)**9 - 1.15042056098719e+121*cos(theta)**7 + 4.16531582426397e+119*cos(theta)**5 - 5.82561653743213e+117*cos(theta)**3 + 2.06582146717451e+115*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl76_m64(theta, phi):
    return 2.94353543906491e-116*(1.0 - cos(theta)**2)**32*(1.92163984527408e+124*cos(theta)**12 - 8.39922051576749e+123*cos(theta)**10 + 1.26833866848838e+123*cos(theta)**8 - 8.05294392691035e+121*cos(theta)**6 + 2.08265791213199e+120*cos(theta)**4 - 1.74768496122964e+118*cos(theta)**2 + 2.06582146717451e+115)*cos(64*phi)

#@torch.jit.script
def Yl76_m65(theta, phi):
    return 7.15597952988258e-118*(1.0 - cos(theta)**2)**32.5*(2.30596781432889e+125*cos(theta)**11 - 8.39922051576749e+124*cos(theta)**9 + 1.0146709347907e+124*cos(theta)**7 - 4.83176635614621e+122*cos(theta)**5 + 8.33063164852795e+120*cos(theta)**3 - 3.49536992245928e+118*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl76_m66(theta, phi):
    return 1.81062525953883e-119*(1.0 - cos(theta)**2)**33*(2.53656459576178e+126*cos(theta)**10 - 7.55929846419074e+125*cos(theta)**8 + 7.10269654353493e+124*cos(theta)**6 - 2.4158831780731e+123*cos(theta)**4 + 2.49918949455838e+121*cos(theta)**2 - 3.49536992245928e+118)*cos(66*phi)

#@torch.jit.script
def Yl76_m67(theta, phi):
    return 4.78807071712273e-121*(1.0 - cos(theta)**2)**33.5*(2.53656459576178e+127*cos(theta)**9 - 6.04743877135259e+126*cos(theta)**7 + 4.26161792612096e+125*cos(theta)**5 - 9.66353271229242e+123*cos(theta)**3 + 4.99837898911677e+121*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl76_m68(theta, phi):
    return 1.3300196436452e-122*(1.0 - cos(theta)**2)**34*(2.2829081361856e+128*cos(theta)**8 - 4.23320713994682e+127*cos(theta)**6 + 2.13080896306048e+126*cos(theta)**4 - 2.89905981368773e+124*cos(theta)**2 + 4.99837898911677e+121)*cos(68*phi)

#@torch.jit.script
def Yl76_m69(theta, phi):
    return 3.90507213550102e-124*(1.0 - cos(theta)**2)**34.5*(1.82632650894848e+129*cos(theta)**7 - 2.53992428396809e+128*cos(theta)**5 + 8.52323585224191e+126*cos(theta)**3 - 5.79811962737545e+124*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl76_m70(theta, phi):
    return 1.22152852433332e-125*(1.0 - cos(theta)**2)**35*(1.27842855626394e+130*cos(theta)**6 - 1.26996214198404e+129*cos(theta)**4 + 2.55697075567257e+127*cos(theta)**2 - 5.79811962737545e+124)*cos(70*phi)

#@torch.jit.script
def Yl76_m71(theta, phi):
    return 4.11310049032803e-127*(1.0 - cos(theta)**2)**35.5*(7.67057133758363e+130*cos(theta)**5 - 5.07984856793618e+129*cos(theta)**3 + 5.11394151134515e+127*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl76_m72(theta, phi):
    return 1.51200581131519e-128*(1.0 - cos(theta)**2)**36*(3.83528566879182e+131*cos(theta)**4 - 1.52395457038085e+130*cos(theta)**2 + 5.11394151134515e+127)*cos(72*phi)

#@torch.jit.script
def Yl76_m73(theta, phi):
    return 6.19341712319846e-130*(1.0 - cos(theta)**2)**36.5*(1.53411426751673e+132*cos(theta)**3 - 3.04790914076171e+130*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl76_m74(theta, phi):
    return 2.91960483102034e-131*(1.0 - cos(theta)**2)**37*(4.60234280255018e+132*cos(theta)**2 - 3.04790914076171e+130)*cos(74*phi)

#@torch.jit.script
def Yl76_m75(theta, phi):
    return 15.4642749057508*(1.0 - cos(theta)**2)**37.5*cos(75*phi)*cos(theta)

#@torch.jit.script
def Yl76_m76(theta, phi):
    return 1.25431832598384*(1.0 - cos(theta)**2)**38*cos(76*phi)

#@torch.jit.script
def Yl77_m_minus_77(theta, phi):
    return 1.25838419831944*(1.0 - cos(theta)**2)**38.5*sin(77*phi)

#@torch.jit.script
def Yl77_m_minus_76(theta, phi):
    return 15.6161372224161*(1.0 - cos(theta)**2)**38*sin(76*phi)*cos(theta)

#@torch.jit.script
def Yl77_m_minus_75(theta, phi):
    return 1.93969720345593e-133*(1.0 - cos(theta)**2)**37.5*(7.04158448790177e+134*cos(theta)**2 - 4.60234280255018e+132)*sin(75*phi)

#@torch.jit.script
def Yl77_m_minus_74(theta, phi):
    return 4.14205976530905e-132*(1.0 - cos(theta)**2)**37*(2.34719482930059e+134*cos(theta)**3 - 4.60234280255018e+132*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl77_m_minus_73(theta, phi):
    return 1.01796965062976e-130*(1.0 - cos(theta)**2)**36.5*(5.86798707325148e+133*cos(theta)**4 - 2.30117140127509e+132*cos(theta)**2 + 7.61977285190427e+129)*sin(73*phi)

#@torch.jit.script
def Yl77_m_minus_72(theta, phi):
    return 2.78782470252787e-129*(1.0 - cos(theta)**2)**36*(1.1735974146503e+133*cos(theta)**5 - 7.67057133758363e+131*cos(theta)**3 + 7.61977285190427e+129*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl77_m_minus_71(theta, phi):
    return 8.33554924128577e-128*(1.0 - cos(theta)**2)**35.5*(1.95599569108383e+132*cos(theta)**6 - 1.91764283439591e+131*cos(theta)**4 + 3.80988642595213e+129*cos(theta)**2 - 8.52323585224191e+126)*sin(71*phi)

#@torch.jit.script
def Yl77_m_minus_70(theta, phi):
    return 2.6829593898425e-126*(1.0 - cos(theta)**2)**35*(2.79427955869118e+131*cos(theta)**7 - 3.83528566879182e+130*cos(theta)**5 + 1.26996214198404e+129*cos(theta)**3 - 8.52323585224191e+126*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl77_m_minus_69(theta, phi):
    return 9.20063410801222e-125*(1.0 - cos(theta)**2)**34.5*(3.49284944836398e+130*cos(theta)**8 - 6.39214278131969e+129*cos(theta)**6 + 3.17490535496011e+128*cos(theta)**4 - 4.26161792612096e+126*cos(theta)**2 + 7.24764953421931e+123)*sin(69*phi)

#@torch.jit.script
def Yl77_m_minus_68(theta, phi):
    return 3.33515054740002e-123*(1.0 - cos(theta)**2)**34*(3.88094383151553e+129*cos(theta)**9 - 9.13163254474242e+128*cos(theta)**7 + 6.34981070992022e+127*cos(theta)**5 - 1.42053930870699e+126*cos(theta)**3 + 7.24764953421931e+123*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl77_m_minus_67(theta, phi):
    return 1.26998749214482e-121*(1.0 - cos(theta)**2)**33.5*(3.88094383151553e+128*cos(theta)**10 - 1.1414540680928e+128*cos(theta)**8 + 1.0583017849867e+127*cos(theta)**6 - 3.55134827176746e+125*cos(theta)**4 + 3.62382476710966e+123*cos(theta)**2 - 4.99837898911677e+120)*sin(67*phi)

#@torch.jit.script
def Yl77_m_minus_66(theta, phi):
    return 5.05448639986654e-120*(1.0 - cos(theta)**2)**33*(3.52813075592321e+127*cos(theta)**11 - 1.26828229788089e+127*cos(theta)**9 + 1.51185969283815e+126*cos(theta)**7 - 7.10269654353493e+124*cos(theta)**5 + 1.20794158903655e+123*cos(theta)**3 - 4.99837898911677e+120*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl77_m_minus_65(theta, phi):
    return 2.09380230745894e-118*(1.0 - cos(theta)**2)**32.5*(2.94010896326934e+126*cos(theta)**12 - 1.26828229788089e+126*cos(theta)**10 + 1.88982461604769e+125*cos(theta)**8 - 1.18378275725582e+124*cos(theta)**6 + 3.01985397259138e+122*cos(theta)**4 - 2.49918949455838e+120*cos(theta)**2 + 2.91280826871606e+117)*sin(65*phi)

#@torch.jit.script
def Yl77_m_minus_64(theta, phi):
    return 8.99604299546297e-117*(1.0 - cos(theta)**2)**32*(2.26162227943795e+125*cos(theta)**13 - 1.15298390716445e+125*cos(theta)**11 + 2.09980512894187e+124*cos(theta)**9 - 1.69111822465117e+123*cos(theta)**7 + 6.03970794518276e+121*cos(theta)**5 - 8.33063164852795e+119*cos(theta)**3 + 2.91280826871606e+117*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl77_m_minus_63(theta, phi):
    return 3.99691669444655e-115*(1.0 - cos(theta)**2)**31.5*(1.61544448531282e+124*cos(theta)**14 - 9.60819922637039e+123*cos(theta)**12 + 2.09980512894187e+123*cos(theta)**10 - 2.11389778081397e+122*cos(theta)**8 + 1.00661799086379e+121*cos(theta)**6 - 2.08265791213199e+119*cos(theta)**4 + 1.45640413435803e+117*cos(theta)**2 - 1.47558676226751e+114)*sin(63*phi)

#@torch.jit.script
def Yl77_m_minus_62(theta, phi):
    return 1.8316173298734e-113*(1.0 - cos(theta)**2)**31*(1.07696299020855e+123*cos(theta)**15 - 7.39092248182338e+122*cos(theta)**13 + 1.90891375358352e+122*cos(theta)**11 - 2.34877531201552e+121*cos(theta)**9 + 1.43802570123399e+120*cos(theta)**7 - 4.16531582426397e+118*cos(theta)**5 + 4.85468044786011e+116*cos(theta)**3 - 1.47558676226751e+114*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl77_m_minus_61(theta, phi):
    return 8.63777993690384e-112*(1.0 - cos(theta)**2)**30.5*(6.73101868880343e+121*cos(theta)**16 - 5.27923034415955e+121*cos(theta)**14 + 1.5907614613196e+121*cos(theta)**12 - 2.34877531201552e+120*cos(theta)**10 + 1.79753212654249e+119*cos(theta)**8 - 6.94219304043996e+117*cos(theta)**6 + 1.21367011196503e+116*cos(theta)**4 - 7.37793381133755e+113*cos(theta)**2 + 6.63483256415247e+110)*sin(61*phi)

#@torch.jit.script
def Yl77_m_minus_60(theta, phi):
    return 4.18375398764358e-110*(1.0 - cos(theta)**2)**30*(3.95942275811967e+120*cos(theta)**17 - 3.51948689610637e+120*cos(theta)**15 + 1.22366266255354e+120*cos(theta)**13 - 2.13525028365047e+119*cos(theta)**11 + 1.99725791838054e+118*cos(theta)**9 - 9.91741862919994e+116*cos(theta)**7 + 2.42734022393005e+115*cos(theta)**5 - 2.45931127044585e+113*cos(theta)**3 + 6.63483256415247e+110*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl77_m_minus_59(theta, phi):
    return 2.07760353436883e-108*(1.0 - cos(theta)**2)**29.5*(2.19967931006648e+119*cos(theta)**18 - 2.19967931006648e+119*cos(theta)**16 + 8.74044758966814e+118*cos(theta)**14 - 1.77937523637539e+118*cos(theta)**12 + 1.99725791838054e+117*cos(theta)**10 - 1.23967732864999e+116*cos(theta)**8 + 4.04556703988342e+114*cos(theta)**6 - 6.14827817611463e+112*cos(theta)**4 + 3.31741628207624e+110*cos(theta)**2 - 2.69052415415753e+107)*sin(59*phi)

#@torch.jit.script
def Yl77_m_minus_58(theta, phi):
    return 1.05610945344318e-106*(1.0 - cos(theta)**2)**29*(1.15772595266657e+118*cos(theta)**19 - 1.29392900592146e+118*cos(theta)**17 + 5.82696505977876e+117*cos(theta)**15 - 1.36875018182722e+117*cos(theta)**13 + 1.81568901670958e+116*cos(theta)**11 - 1.37741925405555e+115*cos(theta)**9 + 5.77938148554775e+113*cos(theta)**7 - 1.22965563522293e+112*cos(theta)**5 + 1.10580542735875e+110*cos(theta)**3 - 2.69052415415753e+107*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl77_m_minus_57(theta, phi):
    return 5.48770569515216e-105*(1.0 - cos(theta)**2)**28.5*(5.78862976333285e+116*cos(theta)**20 - 7.18849447734144e+116*cos(theta)**18 + 3.64185316236172e+116*cos(theta)**16 - 9.77678701305161e+115*cos(theta)**14 + 1.51307418059132e+115*cos(theta)**12 - 1.37741925405555e+114*cos(theta)**10 + 7.22422685693468e+112*cos(theta)**8 - 2.04942605870488e+111*cos(theta)**6 + 2.76451356839686e+109*cos(theta)**4 - 1.34526207707877e+107*cos(theta)**2 + 9.96490427465753e+103)*sin(57*phi)

#@torch.jit.script
def Yl77_m_minus_56(theta, phi):
    return 2.91107140798105e-103*(1.0 - cos(theta)**2)**28*(2.75649036349183e+115*cos(theta)**21 - 3.78341814596918e+115*cos(theta)**19 + 2.14226656609513e+115*cos(theta)**17 - 6.51785800870107e+114*cos(theta)**15 + 1.16390321583948e+114*cos(theta)**13 - 1.25219932186868e+113*cos(theta)**11 + 8.02691872992743e+111*cos(theta)**9 - 2.92775151243554e+110*cos(theta)**7 + 5.52902713679373e+108*cos(theta)**5 - 4.48420692359589e+106*cos(theta)**3 + 9.96490427465753e+103*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl77_m_minus_55(theta, phi):
    return 1.57467168985028e-101*(1.0 - cos(theta)**2)**27.5*(1.25295016522356e+114*cos(theta)**22 - 1.89170907298459e+114*cos(theta)**20 + 1.19014809227507e+114*cos(theta)**18 - 4.07366125543817e+113*cos(theta)**16 + 8.31359439885341e+112*cos(theta)**14 - 1.04349943489057e+112*cos(theta)**12 + 8.02691872992743e+110*cos(theta)**10 - 3.65968939054442e+109*cos(theta)**8 + 9.21504522798955e+107*cos(theta)**6 - 1.12105173089897e+106*cos(theta)**4 + 4.98245213732876e+103*cos(theta)**2 - 3.40564055866628e+100)*sin(55*phi)

#@torch.jit.script
def Yl77_m_minus_54(theta, phi):
    return 8.67642672184648e-100*(1.0 - cos(theta)**2)**27*(5.44760941401548e+112*cos(theta)**23 - 9.00813844278376e+112*cos(theta)**21 + 6.26393732776354e+112*cos(theta)**19 - 2.39627132672834e+112*cos(theta)**17 + 5.54239626590227e+111*cos(theta)**15 - 8.02691872992743e+110*cos(theta)**13 + 7.29719884538857e+109*cos(theta)**11 - 4.06632154504936e+108*cos(theta)**9 + 1.31643503256994e+107*cos(theta)**7 - 2.24210346179794e+105*cos(theta)**5 + 1.66081737910959e+103*cos(theta)**3 - 3.40564055866628e+100*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl77_m_minus_53(theta, phi):
    return 4.864992464472e-98*(1.0 - cos(theta)**2)**26.5*(2.26983725583978e+111*cos(theta)**24 - 4.09460838308353e+111*cos(theta)**22 + 3.13196866388177e+111*cos(theta)**20 - 1.33126184818241e+111*cos(theta)**18 + 3.46399766618892e+110*cos(theta)**16 - 5.73351337851959e+109*cos(theta)**14 + 6.08099903782381e+108*cos(theta)**12 - 4.06632154504936e+107*cos(theta)**10 + 1.64554379071242e+106*cos(theta)**8 - 3.73683910299657e+104*cos(theta)**6 + 4.15204344777397e+102*cos(theta)**4 - 1.70282027933314e+100*cos(theta)**2 + 1.08321900720938e+97)*sin(53*phi)

#@torch.jit.script
def Yl77_m_minus_52(theta, phi):
    return 2.77347242564173e-96*(1.0 - cos(theta)**2)**26*(9.07934902335913e+109*cos(theta)**25 - 1.78026451438414e+110*cos(theta)**23 + 1.49141364946751e+110*cos(theta)**21 - 7.0066413062232e+109*cos(theta)**19 + 2.03764568599348e+109*cos(theta)**17 - 3.82234225234639e+108*cos(theta)**15 + 4.67769156755678e+107*cos(theta)**13 - 3.69665595004487e+106*cos(theta)**11 + 1.82838198968047e+105*cos(theta)**9 - 5.33834157570939e+103*cos(theta)**7 + 8.30408689554794e+101*cos(theta)**5 - 5.67606759777713e+99*cos(theta)**3 + 1.08321900720938e+97*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl77_m_minus_51(theta, phi):
    return 1.60622130287506e-94*(1.0 - cos(theta)**2)**25.5*(3.49205731667659e+108*cos(theta)**26 - 7.41776880993393e+108*cos(theta)**24 + 6.77915295212505e+108*cos(theta)**22 - 3.5033206531116e+108*cos(theta)**20 + 1.13202538110749e+108*cos(theta)**18 - 2.3889639077165e+107*cos(theta)**16 + 3.34120826254055e+106*cos(theta)**14 - 3.08054662503739e+105*cos(theta)**12 + 1.82838198968047e+104*cos(theta)**10 - 6.67292696963674e+102*cos(theta)**8 + 1.38401448259132e+101*cos(theta)**6 - 1.41901689944428e+99*cos(theta)**4 + 5.41609503604688e+96*cos(theta)**2 - 3.2296332951979e+93)*sin(51*phi)

#@torch.jit.script
def Yl77_m_minus_50(theta, phi):
    return 9.4426142544775e-93*(1.0 - cos(theta)**2)**25*(1.29335456173207e+107*cos(theta)**27 - 2.96710752397357e+107*cos(theta)**25 + 2.94745780527176e+107*cos(theta)**23 - 1.66824793005314e+107*cos(theta)**21 + 5.95802832161837e+106*cos(theta)**19 - 1.40527288689206e+106*cos(theta)**17 + 2.22747217502704e+105*cos(theta)**15 - 2.36965125002876e+104*cos(theta)**13 + 1.66216544516406e+103*cos(theta)**11 - 7.41436329959637e+101*cos(theta)**9 + 1.97716354655903e+100*cos(theta)**7 - 2.83803379888856e+98*cos(theta)**5 + 1.80536501201563e+96*cos(theta)**3 - 3.2296332951979e+93*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl77_m_minus_49(theta, phi):
    return 5.63083919001166e-91*(1.0 - cos(theta)**2)**24.5*(4.61912343475739e+105*cos(theta)**28 - 1.1411952015283e+106*cos(theta)**26 + 1.22810741886323e+106*cos(theta)**24 - 7.5829451366052e+105*cos(theta)**22 + 2.97901416080918e+105*cos(theta)**20 - 7.80707159384476e+104*cos(theta)**18 + 1.3921701093919e+104*cos(theta)**16 - 1.69260803573483e+103*cos(theta)**14 + 1.38513787097005e+102*cos(theta)**12 - 7.41436329959637e+100*cos(theta)**10 + 2.47145443319879e+99*cos(theta)**8 - 4.73005633148094e+97*cos(theta)**6 + 4.51341253003906e+95*cos(theta)**4 - 1.61481664759895e+93*cos(theta)**2 + 9.08220836669826e+89)*sin(49*phi)

#@torch.jit.script
def Yl77_m_minus_48(theta, phi):
    return 3.40374797599205e-89*(1.0 - cos(theta)**2)**24*(1.5928011843991e+104*cos(theta)**29 - 4.22664889454925e+104*cos(theta)**27 + 4.91242967545293e+104*cos(theta)**25 - 3.29693266808922e+104*cos(theta)**23 + 1.4185781718139e+104*cos(theta)**21 - 4.10898504939198e+103*cos(theta)**19 + 8.1892359375994e+102*cos(theta)**17 - 1.12840535715655e+102*cos(theta)**15 + 1.06549066997696e+101*cos(theta)**13 - 6.74033027236034e+99*cos(theta)**11 + 2.74606048133199e+98*cos(theta)**9 - 6.75722333068706e+96*cos(theta)**7 + 9.02682506007813e+94*cos(theta)**5 - 5.38272215866317e+92*cos(theta)**3 + 9.08220836669826e+89*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl77_m_minus_47(theta, phi):
    return 2.08436143855288e-87*(1.0 - cos(theta)**2)**23.5*(5.30933728133033e+102*cos(theta)**30 - 1.50951746233902e+103*cos(theta)**28 + 1.88939602902036e+103*cos(theta)**26 - 1.37372194503717e+103*cos(theta)**24 + 6.44808259915408e+102*cos(theta)**22 - 2.05449252469599e+102*cos(theta)**20 + 4.54957552088855e+101*cos(theta)**18 - 7.05253348222846e+100*cos(theta)**16 + 7.61064764269258e+99*cos(theta)**14 - 5.61694189363362e+98*cos(theta)**12 + 2.74606048133199e+97*cos(theta)**10 - 8.44652916335882e+95*cos(theta)**8 + 1.50447084334635e+94*cos(theta)**6 - 1.34568053966579e+92*cos(theta)**4 + 4.54110418334913e+89*cos(theta)**2 - 2.42192223111953e+86)*sin(47*phi)

#@torch.jit.script
def Yl77_m_minus_46(theta, phi):
    return 1.29230409190279e-85*(1.0 - cos(theta)**2)**23*(1.71268944559043e+101*cos(theta)**31 - 5.20523262875523e+101*cos(theta)**29 + 6.99776307044577e+101*cos(theta)**27 - 5.49488778014869e+101*cos(theta)**25 + 2.80351417354525e+101*cos(theta)**23 - 9.78329773664757e+100*cos(theta)**21 + 2.39451343204661e+100*cos(theta)**19 - 4.14854910719321e+99*cos(theta)**17 + 5.07376509512839e+98*cos(theta)**15 - 4.32072453356432e+97*cos(theta)**13 + 2.49641861939272e+96*cos(theta)**11 - 9.38503240373202e+94*cos(theta)**9 + 2.14924406192336e+93*cos(theta)**7 - 2.69136107933158e+91*cos(theta)**5 + 1.51370139444971e+89*cos(theta)**3 - 2.42192223111953e+86*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl77_m_minus_45(theta, phi):
    return 8.10759907270583e-84*(1.0 - cos(theta)**2)**22.5*(5.35215451747009e+99*cos(theta)**32 - 1.73507754291841e+100*cos(theta)**30 + 2.49920109658778e+100*cos(theta)**28 - 2.11341837698027e+100*cos(theta)**26 + 1.16813090564385e+100*cos(theta)**24 - 4.44695351665799e+99*cos(theta)**22 + 1.1972567160233e+99*cos(theta)**20 - 2.30474950399623e+98*cos(theta)**18 + 3.17110318445524e+97*cos(theta)**16 - 3.0862318096888e+96*cos(theta)**14 + 2.08034884949393e+95*cos(theta)**12 - 9.38503240373202e+93*cos(theta)**10 + 2.68655507740421e+92*cos(theta)**8 - 4.48560179888597e+90*cos(theta)**6 + 3.78425348612427e+88*cos(theta)**4 - 1.21096111555977e+86*cos(theta)**2 + 6.15325770101508e+82)*sin(45*phi)

#@torch.jit.script
def Yl77_m_minus_44(theta, phi):
    return 5.14433390368256e-82*(1.0 - cos(theta)**2)**22*(1.62186500529397e+98*cos(theta)**33 - 5.59702433199487e+98*cos(theta)**31 + 8.61793481581992e+98*cos(theta)**29 - 7.82747547029728e+98*cos(theta)**27 + 4.67252362257542e+98*cos(theta)**25 - 1.93345805072086e+98*cos(theta)**23 + 5.70122245725383e+97*cos(theta)**21 - 1.21302605473486e+97*cos(theta)**19 + 1.86535481438544e+96*cos(theta)**17 - 2.05748787312587e+95*cos(theta)**15 + 1.60026834576456e+94*cos(theta)**13 - 8.53184763975639e+92*cos(theta)**11 + 2.98506119711578e+91*cos(theta)**9 - 6.4080025698371e+89*cos(theta)**7 + 7.56850697224855e+87*cos(theta)**5 - 4.03653705186589e+85*cos(theta)**3 + 6.15325770101508e+82*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl77_m_minus_43(theta, phi):
    return 3.29959998757342e-80*(1.0 - cos(theta)**2)**21.5*(4.77019119204108e+96*cos(theta)**34 - 1.7490701037484e+97*cos(theta)**32 + 2.87264493860664e+97*cos(theta)**30 - 2.7955269536776e+97*cos(theta)**28 + 1.79712447022132e+97*cos(theta)**26 - 8.05607521133693e+96*cos(theta)**24 + 2.59146475329719e+96*cos(theta)**22 - 6.06513027367428e+95*cos(theta)**20 + 1.03630823021413e+95*cos(theta)**18 - 1.28592992070367e+94*cos(theta)**16 + 1.14304881840326e+93*cos(theta)**14 - 7.10987303313032e+91*cos(theta)**12 + 2.98506119711578e+90*cos(theta)**10 - 8.01000321229638e+88*cos(theta)**8 + 1.26141782870809e+87*cos(theta)**6 - 1.00913426296647e+85*cos(theta)**4 + 3.07662885050754e+82*cos(theta)**2 - 1.49568733617284e+79)*sin(43*phi)

#@torch.jit.script
def Yl77_m_minus_42(theta, phi):
    return 2.13838519279332e-78*(1.0 - cos(theta)**2)**21*(1.3629117691546e+95*cos(theta)**35 - 5.3002124356012e+95*cos(theta)**33 + 9.26659657615045e+95*cos(theta)**31 - 9.63974811612966e+95*cos(theta)**29 + 6.65601655637524e+95*cos(theta)**27 - 3.22243008453477e+95*cos(theta)**25 + 1.12672380578139e+95*cos(theta)**23 - 2.88815727317823e+94*cos(theta)**21 + 5.45425384323227e+93*cos(theta)**19 - 7.56429365119804e+92*cos(theta)**17 + 7.62032545602173e+91*cos(theta)**15 - 5.46913310240794e+90*cos(theta)**13 + 2.71369199737799e+89*cos(theta)**11 - 8.9000035692182e+87*cos(theta)**9 + 1.80202546958299e+86*cos(theta)**7 - 2.01826852593295e+84*cos(theta)**5 + 1.02554295016918e+82*cos(theta)**3 - 1.49568733617284e+79*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl77_m_minus_41(theta, phi):
    return 1.39962170750292e-76*(1.0 - cos(theta)**2)**20.5*(3.78586602542943e+93*cos(theta)**36 - 1.55888601047094e+94*cos(theta)**34 + 2.89581143004702e+94*cos(theta)**32 - 3.21324937204322e+94*cos(theta)**30 + 2.37714877013401e+94*cos(theta)**28 - 1.23939618635953e+94*cos(theta)**26 + 4.69468252408912e+93*cos(theta)**24 - 1.31279876053556e+93*cos(theta)**22 + 2.72712692161614e+92*cos(theta)**20 - 4.20238536177669e+91*cos(theta)**18 + 4.76270341001358e+90*cos(theta)**16 - 3.9065236445771e+89*cos(theta)**14 + 2.26140999781499e+88*cos(theta)**12 - 8.9000035692182e+86*cos(theta)**10 + 2.25253183697873e+85*cos(theta)**8 - 3.36378087655491e+83*cos(theta)**6 + 2.56385737542295e+81*cos(theta)**4 - 7.47843668086422e+78*cos(theta)**2 + 3.49133365119711e+75)*sin(41*phi)

#@torch.jit.script
def Yl77_m_minus_40(theta, phi):
    return 9.24810038585174e-75*(1.0 - cos(theta)**2)**20*(1.02320703389985e+92*cos(theta)**37 - 4.45396002991698e+92*cos(theta)**35 + 8.77518615165762e+92*cos(theta)**33 - 1.03653205549781e+93*cos(theta)**31 + 8.19706472460005e+92*cos(theta)**29 - 4.59035624577603e+92*cos(theta)**27 + 1.87787300963565e+92*cos(theta)**25 - 5.70782069798069e+91*cos(theta)**23 + 1.29863186743625e+91*cos(theta)**21 - 2.21178176935615e+90*cos(theta)**19 + 2.80159024118446e+89*cos(theta)**17 - 2.60434909638473e+88*cos(theta)**15 + 1.73954615216538e+87*cos(theta)**13 - 8.09091233565291e+85*cos(theta)**11 + 2.50281315219859e+84*cos(theta)**9 - 4.8054012522213e+82*cos(theta)**7 + 5.1277147508459e+80*cos(theta)**5 - 2.49281222695474e+78*cos(theta)**3 + 3.49133365119711e+75*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl77_m_minus_39(theta, phi):
    return 6.16647910788834e-73*(1.0 - cos(theta)**2)**19.5*(2.69265008921012e+90*cos(theta)**38 - 1.23721111942138e+91*cos(theta)**36 + 2.58093710342871e+91*cos(theta)**34 - 3.23916267343067e+91*cos(theta)**32 + 2.73235490820002e+91*cos(theta)**30 - 1.63941294492001e+91*cos(theta)**28 + 7.22258849859865e+90*cos(theta)**26 - 2.37825862415862e+90*cos(theta)**24 + 5.90287212471025e+89*cos(theta)**22 - 1.10589088467808e+89*cos(theta)**20 + 1.55643902288026e+88*cos(theta)**18 - 1.62771818524046e+87*cos(theta)**16 + 1.24253296583241e+86*cos(theta)**14 - 6.74242694637742e+84*cos(theta)**12 + 2.50281315219859e+83*cos(theta)**10 - 6.00675156527662e+81*cos(theta)**8 + 8.54619125140983e+79*cos(theta)**6 - 6.23203056738685e+77*cos(theta)**4 + 1.74566682559856e+75*cos(theta)**2 - 7.85275225190534e+71)*sin(39*phi)

#@torch.jit.script
def Yl77_m_minus_38(theta, phi):
    return 4.14761620447478e-71*(1.0 - cos(theta)**2)**19*(6.90423099797467e+88*cos(theta)**39 - 3.34381383627401e+89*cos(theta)**37 + 7.37410600979632e+89*cos(theta)**35 - 9.81564446494141e+89*cos(theta)**33 + 8.8140480909678e+89*cos(theta)**31 - 5.65314808593107e+89*cos(theta)**29 + 2.67503277725876e+89*cos(theta)**27 - 9.51303449663449e+88*cos(theta)**25 + 2.56646614117837e+88*cos(theta)**23 - 5.2661470698956e+87*cos(theta)**21 + 8.19178433094871e+86*cos(theta)**19 - 9.57481285435564e+85*cos(theta)**17 + 8.2835531055494e+84*cos(theta)**15 - 5.18648226644417e+83*cos(theta)**13 + 2.2752846838169e+82*cos(theta)**11 - 6.67416840586292e+80*cos(theta)**9 + 1.22088446448712e+79*cos(theta)**7 - 1.24640611347737e+77*cos(theta)**5 + 5.81888941866186e+74*cos(theta)**3 - 7.85275225190534e+71*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl77_m_minus_37(theta, phi):
    return 2.81305017421055e-69*(1.0 - cos(theta)**2)**18.5*(1.72605774949367e+87*cos(theta)**40 - 8.79951009545791e+87*cos(theta)**38 + 2.04836278049898e+88*cos(theta)**36 - 2.88695425439453e+88*cos(theta)**34 + 2.75439002842744e+88*cos(theta)**32 - 1.88438269531036e+88*cos(theta)**30 + 9.55368849020985e+87*cos(theta)**28 - 3.6588594217825e+87*cos(theta)**26 + 1.06936089215765e+87*cos(theta)**24 - 2.39370321358891e+86*cos(theta)**22 + 4.09589216547436e+85*cos(theta)**20 - 5.31934047464202e+84*cos(theta)**18 + 5.17722069096838e+83*cos(theta)**16 - 3.70463019031727e+82*cos(theta)**14 + 1.89607056984742e+81*cos(theta)**12 - 6.67416840586291e+79*cos(theta)**10 + 1.5261055806089e+78*cos(theta)**8 - 2.07734352246228e+76*cos(theta)**6 + 1.45472235466546e+74*cos(theta)**4 - 3.92637612595267e+71*cos(theta)**2 + 1.70712005476203e+68)*sin(37*phi)

#@torch.jit.script
def Yl77_m_minus_36(theta, phi):
    return 1.92318840717684e-67*(1.0 - cos(theta)**2)**18*(4.20989694998455e+85*cos(theta)**41 - 2.256284639861e+86*cos(theta)**39 + 5.53611562297021e+86*cos(theta)**37 - 8.24844072684152e+86*cos(theta)**35 + 8.34663644978011e+86*cos(theta)**33 - 6.07865385583986e+86*cos(theta)**31 + 3.29437534145167e+86*cos(theta)**29 - 1.3551331191787e+86*cos(theta)**27 + 4.27744356863062e+85*cos(theta)**25 - 1.04074052764735e+85*cos(theta)**23 + 1.95042484070207e+84*cos(theta)**21 - 2.79965288139054e+83*cos(theta)**19 + 3.04542393586375e+82*cos(theta)**17 - 2.46975346021151e+81*cos(theta)**15 + 1.45851582295955e+80*cos(theta)**13 - 6.06742582351174e+78*cos(theta)**11 + 1.69567286734322e+77*cos(theta)**9 - 2.96763360351755e+75*cos(theta)**7 + 2.90944470933093e+73*cos(theta)**5 - 1.30879204198422e+71*cos(theta)**3 + 1.70712005476203e+68*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl77_m_minus_35(theta, phi):
    return 1.32490792965112e-65*(1.0 - cos(theta)**2)**17.5*(1.00235641666299e+84*cos(theta)**42 - 5.64071159965251e+84*cos(theta)**40 + 1.45687253236058e+85*cos(theta)**38 - 2.29123353523376e+85*cos(theta)**36 + 2.45489307346474e+85*cos(theta)**34 - 1.89957932994996e+85*cos(theta)**32 + 1.09812511381722e+85*cos(theta)**30 - 4.83976113992394e+84*cos(theta)**28 + 1.64517060331947e+84*cos(theta)**26 - 4.3364188651973e+83*cos(theta)**24 + 8.8655674577367e+82*cos(theta)**22 - 1.39982644069527e+82*cos(theta)**20 + 1.69190218659097e+81*cos(theta)**18 - 1.54359591263219e+80*cos(theta)**16 + 1.04179701639968e+79*cos(theta)**14 - 5.05618818625978e+77*cos(theta)**12 + 1.69567286734322e+76*cos(theta)**10 - 3.70954200439693e+74*cos(theta)**8 + 4.84907451555155e+72*cos(theta)**6 - 3.27198010496056e+70*cos(theta)**4 + 8.53560027381015e+67*cos(theta)**2 - 3.59696598137807e+64)*sin(35*phi)

#@torch.jit.script
def Yl77_m_minus_34(theta, phi):
    return 9.19451738929479e-64*(1.0 - cos(theta)**2)**17*(2.33106143409998e+82*cos(theta)**43 - 1.37578331698842e+83*cos(theta)**41 + 3.73557059579636e+83*cos(theta)**39 - 6.19252306819934e+83*cos(theta)**37 + 7.01398020989925e+83*cos(theta)**35 - 5.75630099984835e+83*cos(theta)**33 + 3.54233907682976e+83*cos(theta)**31 - 1.66888315169791e+83*cos(theta)**29 + 6.09322445673877e+82*cos(theta)**27 - 1.73456754607892e+82*cos(theta)**25 + 3.85459454684204e+81*cos(theta)**23 - 6.66584019378699e+80*cos(theta)**21 + 8.90474835047881e+79*cos(theta)**19 - 9.07997595665996e+78*cos(theta)**17 + 6.94531344266454e+77*cos(theta)**15 - 3.88937552789214e+76*cos(theta)**13 + 1.54152078849384e+75*cos(theta)**11 - 4.12171333821881e+73*cos(theta)**9 + 6.92724930793078e+71*cos(theta)**7 - 6.54396020992112e+69*cos(theta)**5 + 2.84520009127005e+67*cos(theta)**3 - 3.59696598137807e+64*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl77_m_minus_33(theta, phi):
    return 6.42564556062396e-62*(1.0 - cos(theta)**2)**16.5*(5.29786689568176e+80*cos(theta)**44 - 3.27567456425813e+81*cos(theta)**42 + 9.33892648949091e+81*cos(theta)**40 - 1.62961133373667e+82*cos(theta)**38 + 1.94832783608313e+82*cos(theta)**36 - 1.69302970583775e+82*cos(theta)**34 + 1.1069809615093e+82*cos(theta)**32 - 5.56294383899303e+81*cos(theta)**30 + 2.17615159169242e+81*cos(theta)**28 - 6.67141363876508e+80*cos(theta)**26 + 1.60608106118418e+80*cos(theta)**24 - 3.02992736081227e+79*cos(theta)**22 + 4.4523741752394e+78*cos(theta)**20 - 5.04443108703331e+77*cos(theta)**18 + 4.34082090166534e+76*cos(theta)**16 - 2.77812537706582e+75*cos(theta)**14 + 1.2846006570782e+74*cos(theta)**12 - 4.12171333821881e+72*cos(theta)**10 + 8.65906163491348e+70*cos(theta)**8 - 1.09066003498685e+69*cos(theta)**6 + 7.11300022817513e+66*cos(theta)**4 - 1.79848299068903e+64*cos(theta)**2 + 7.3647952116668e+60)*sin(33*phi)

#@torch.jit.script
def Yl77_m_minus_32(theta, phi):
    return 4.52084238068851e-60*(1.0 - cos(theta)**2)**16*(1.17730375459595e+79*cos(theta)**45 - 7.61784782385613e+79*cos(theta)**43 + 2.27778694865632e+80*cos(theta)**41 - 4.17849059932479e+80*cos(theta)**39 + 5.26575090833277e+80*cos(theta)**37 - 4.837227730965e+80*cos(theta)**35 + 3.35448776214939e+80*cos(theta)**33 - 1.7944980125784e+80*cos(theta)**31 + 7.50397100583592e+79*cos(theta)**29 - 2.47089394028336e+79*cos(theta)**27 + 6.42432424473674e+78*cos(theta)**25 - 1.31735972209229e+78*cos(theta)**23 + 2.12017817868543e+77*cos(theta)**21 - 2.65496373001753e+76*cos(theta)**19 + 2.55342405980314e+75*cos(theta)**17 - 1.85208358471054e+74*cos(theta)**15 + 9.88154351598613e+72*cos(theta)**13 - 3.74701212565347e+71*cos(theta)**11 + 9.62117959434831e+69*cos(theta)**9 - 1.55808576426693e+68*cos(theta)**7 + 1.42260004563503e+66*cos(theta)**5 - 5.99494330229678e+63*cos(theta)**3 + 7.3647952116668e+60*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl77_m_minus_31(theta, phi):
    return 3.20119058128037e-58*(1.0 - cos(theta)**2)**15.5*(2.55935598825206e+77*cos(theta)**46 - 1.73132905087639e+78*cos(theta)**44 + 5.42330225870552e+78*cos(theta)**42 - 1.0446226498312e+79*cos(theta)**40 + 1.38572392324547e+79*cos(theta)**38 - 1.3436743697125e+79*cos(theta)**36 + 9.86614047690997e+78*cos(theta)**34 - 5.60780628930749e+78*cos(theta)**32 + 2.50132366861197e+78*cos(theta)**30 - 8.82462121529772e+77*cos(theta)**28 + 2.47089394028336e+77*cos(theta)**26 - 5.48899884205121e+76*cos(theta)**24 + 9.63717353947923e+75*cos(theta)**22 - 1.32748186500877e+75*cos(theta)**20 + 1.41856892211286e+74*cos(theta)**18 - 1.15755224044409e+73*cos(theta)**16 + 7.05824536856152e+71*cos(theta)**14 - 3.12251010471122e+70*cos(theta)**12 + 9.62117959434831e+68*cos(theta)**10 - 1.94760720533367e+67*cos(theta)**8 + 2.37100007605838e+65*cos(theta)**6 - 1.49873582557419e+63*cos(theta)**4 + 3.6823976058334e+60*cos(theta)**2 - 1.46884627276961e+57)*sin(31*phi)

#@torch.jit.script
def Yl77_m_minus_30(theta, phi):
    return 2.28072192287561e-56*(1.0 - cos(theta)**2)**15*(5.44543827287672e+75*cos(theta)**47 - 3.84739789083643e+76*cos(theta)**45 + 1.26123308341989e+77*cos(theta)**43 - 2.54786012153951e+77*cos(theta)**41 + 3.55313826473197e+77*cos(theta)**39 - 3.63155235057433e+77*cos(theta)**37 + 2.81889727911713e+77*cos(theta)**35 - 1.69933523918409e+77*cos(theta)**33 + 8.06878602778056e+76*cos(theta)**31 - 3.04297283286128e+76*cos(theta)**29 + 9.15145903808652e+75*cos(theta)**27 - 2.19559953682049e+75*cos(theta)**25 + 4.19007545194749e+74*cos(theta)**23 - 6.32134221432746e+73*cos(theta)**21 + 7.46615222164661e+72*cos(theta)**19 - 6.80913082614171e+71*cos(theta)**17 + 4.70549691237435e+70*cos(theta)**15 - 2.40193084977786e+69*cos(theta)**13 + 8.74652690395301e+67*cos(theta)**11 - 2.16400800592629e+66*cos(theta)**9 + 3.38714296579768e+64*cos(theta)**7 - 2.99747165114839e+62*cos(theta)**5 + 1.22746586861113e+60*cos(theta)**3 - 1.46884627276961e+57*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl77_m_minus_29(theta, phi):
    return 1.63449969795033e-54*(1.0 - cos(theta)**2)**14.5*(1.13446630684932e+74*cos(theta)**48 - 8.36390845834006e+74*cos(theta)**46 + 2.86643882595429e+75*cos(theta)**44 - 6.06633362271311e+75*cos(theta)**42 + 8.88284566182991e+75*cos(theta)**40 - 9.5567167120377e+75*cos(theta)**38 + 7.83027021976982e+75*cos(theta)**36 - 4.99804482112967e+75*cos(theta)**34 + 2.52149563368143e+75*cos(theta)**32 - 1.01432427762043e+75*cos(theta)**30 + 3.26837822788804e+74*cos(theta)**28 - 8.44461360315571e+73*cos(theta)**26 + 1.74586477164479e+73*cos(theta)**24 - 2.87333737014885e+72*cos(theta)**22 + 3.7330761108233e+71*cos(theta)**20 - 3.78285045896761e+70*cos(theta)**18 + 2.94093557023397e+69*cos(theta)**16 - 1.71566489269847e+68*cos(theta)**14 + 7.28877241996084e+66*cos(theta)**12 - 2.16400800592629e+65*cos(theta)**10 + 4.2339287072471e+63*cos(theta)**8 - 4.99578608524731e+61*cos(theta)**6 + 3.06866467152783e+59*cos(theta)**4 - 7.34423136384803e+56*cos(theta)**2 + 2.85990317906855e+53)*sin(29*phi)

#@torch.jit.script
def Yl77_m_minus_28(theta, phi):
    return 1.17797430489561e-52*(1.0 - cos(theta)**2)**14*(2.31523736091697e+72*cos(theta)**49 - 1.77955499113618e+73*cos(theta)**47 + 6.36986405767621e+73*cos(theta)**45 - 1.41077526109607e+74*cos(theta)**43 + 2.16654772239754e+74*cos(theta)**41 - 2.45044018257377e+74*cos(theta)**39 + 2.11628924858644e+74*cos(theta)**37 - 1.42801280603705e+74*cos(theta)**35 + 7.64089585964068e+73*cos(theta)**33 - 3.27201379877557e+73*cos(theta)**31 + 1.12702697513381e+73*cos(theta)**29 - 3.12763466783545e+72*cos(theta)**27 + 6.98345908657915e+71*cos(theta)**25 - 1.24927711745602e+71*cos(theta)**23 + 1.77765529086824e+70*cos(theta)**21 - 1.99097392577243e+69*cos(theta)**19 + 1.72996210013763e+68*cos(theta)**17 - 1.14377659513232e+67*cos(theta)**15 + 5.60674801535449e+65*cos(theta)**13 - 1.96728000538754e+64*cos(theta)**11 + 4.70436523027455e+62*cos(theta)**9 - 7.13683726463902e+60*cos(theta)**7 + 6.13732934305567e+58*cos(theta)**5 - 2.44807712128268e+56*cos(theta)**3 + 2.85990317906855e+53*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl77_m_minus_27(theta, phi):
    return 8.53523472478644e-51*(1.0 - cos(theta)**2)**13.5*(4.63047472183395e+70*cos(theta)**50 - 3.70740623153372e+71*cos(theta)**48 + 1.38475305601657e+72*cos(theta)**46 - 3.20630741158198e+72*cos(theta)**44 + 5.15844695808938e+72*cos(theta)**42 - 6.12610045643442e+72*cos(theta)**40 + 5.5691822331222e+72*cos(theta)**38 - 3.9667022389918e+72*cos(theta)**36 + 2.24732231165902e+72*cos(theta)**34 - 1.02250431211737e+72*cos(theta)**32 + 3.75675658377936e+71*cos(theta)**30 - 1.1170123813698e+71*cos(theta)**28 + 2.68594580253044e+70*cos(theta)**26 - 5.20532132273342e+69*cos(theta)**24 + 8.08025132212836e+68*cos(theta)**22 - 9.95486962886214e+67*cos(theta)**20 + 9.61090055632016e+66*cos(theta)**18 - 7.14860371957698e+65*cos(theta)**16 + 4.00482001096749e+64*cos(theta)**14 - 1.63940000448962e+63*cos(theta)**12 + 4.70436523027455e+61*cos(theta)**10 - 8.92104658079878e+59*cos(theta)**8 + 1.02288822384261e+58*cos(theta)**6 - 6.12019280320669e+55*cos(theta)**4 + 1.42995158953427e+53*cos(theta)**2 - 5.44743462679723e+49)*sin(27*phi)

#@torch.jit.script
def Yl77_m_minus_26(theta, phi):
    return 6.2160890397853e-49*(1.0 - cos(theta)**2)**13*(9.0793621996744e+68*cos(theta)**51 - 7.56613516639534e+69*cos(theta)**49 + 2.94628309790759e+70*cos(theta)**47 - 7.12512758129329e+70*cos(theta)**45 + 1.19963882746265e+71*cos(theta)**43 - 1.49417084303279e+71*cos(theta)**41 + 1.42799544439031e+71*cos(theta)**39 - 1.072081686214e+71*cos(theta)**37 + 6.42092089045436e+70*cos(theta)**35 - 3.09849791550717e+70*cos(theta)**33 + 1.21185696250947e+70*cos(theta)**31 - 3.85176683230967e+69*cos(theta)**29 + 9.94794741677942e+68*cos(theta)**27 - 2.08212852909337e+68*cos(theta)**25 + 3.51315274875146e+67*cos(theta)**23 - 4.74041410898197e+66*cos(theta)**21 + 5.05836871385271e+65*cos(theta)**19 - 4.20506101151587e+64*cos(theta)**17 + 2.66988000731166e+63*cos(theta)**15 - 1.26107692653047e+62*cos(theta)**13 + 4.27669566388596e+60*cos(theta)**11 - 9.91227397866531e+58*cos(theta)**9 + 1.46126889120373e+57*cos(theta)**7 - 1.22403856064134e+55*cos(theta)**5 + 4.76650529844758e+52*cos(theta)**3 - 5.44743462679723e+49*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl77_m_minus_25(theta, phi):
    return 4.54922598211044e-47*(1.0 - cos(theta)**2)**12.5*(1.74603119224508e+67*cos(theta)**52 - 1.51322703327907e+68*cos(theta)**50 + 6.13808978730748e+68*cos(theta)**48 - 1.54894077854202e+69*cos(theta)**46 + 2.72645188059692e+69*cos(theta)**44 - 3.55754962626854e+69*cos(theta)**42 + 3.56998861097577e+69*cos(theta)**40 - 2.8212675953e+69*cos(theta)**38 + 1.78358913623732e+69*cos(theta)**36 - 9.11322916325638e+68*cos(theta)**34 + 3.7870530078421e+68*cos(theta)**32 - 1.28392227743656e+68*cos(theta)**30 + 3.55283836313551e+67*cos(theta)**28 - 8.0081866503591e+66*cos(theta)**26 + 1.46381364531311e+66*cos(theta)**24 - 2.1547336859009e+65*cos(theta)**22 + 2.52918435692636e+64*cos(theta)**20 - 2.3361450063977e+63*cos(theta)**18 + 1.66867500456979e+62*cos(theta)**16 - 9.00769233236054e+60*cos(theta)**14 + 3.5639130532383e+59*cos(theta)**12 - 9.91227397866531e+57*cos(theta)**10 + 1.82658611400466e+56*cos(theta)**8 - 2.04006426773556e+54*cos(theta)**6 + 1.19162632461189e+52*cos(theta)**4 - 2.72371731339862e+49*cos(theta)**2 + 1.01707143890912e+46)*sin(25*phi)

#@torch.jit.script
def Yl77_m_minus_24(theta, phi):
    return 3.34484141235851e-45*(1.0 - cos(theta)**2)**12*(3.29439847593411e+65*cos(theta)**53 - 2.96711182995896e+66*cos(theta)**51 + 1.25267138516479e+67*cos(theta)**49 - 3.29561867774898e+67*cos(theta)**47 + 6.05878195688205e+67*cos(theta)**45 - 8.27337122388032e+67*cos(theta)**43 + 8.70728929506286e+67*cos(theta)**41 - 7.23401947512821e+67*cos(theta)**39 + 4.82051117901979e+67*cos(theta)**37 - 2.6037797609304e+67*cos(theta)**35 + 1.14759182055821e+67*cos(theta)**33 - 4.14168476592437e+66*cos(theta)**31 + 1.22511667694328e+66*cos(theta)**29 - 2.96599505568856e+65*cos(theta)**27 + 5.85525458125244e+64*cos(theta)**25 - 9.3684073300039e+63*cos(theta)**23 + 1.20437350329827e+63*cos(theta)**21 - 1.22955000336721e+62*cos(theta)**19 + 9.81573532099876e+60*cos(theta)**17 - 6.00512822157369e+59*cos(theta)**15 + 2.74147157941408e+58*cos(theta)**13 - 9.01115816242301e+56*cos(theta)**11 + 2.02954012667185e+55*cos(theta)**9 - 2.91437752533652e+53*cos(theta)**7 + 2.38325264922379e+51*cos(theta)**5 - 9.07905771132872e+48*cos(theta)**3 + 1.01707143890912e+46*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl77_m_minus_23(theta, phi):
    return 2.47020557967673e-43*(1.0 - cos(theta)**2)**11.5*(6.1007379183965e+63*cos(theta)**54 - 5.70598428838261e+64*cos(theta)**52 + 2.50534277032958e+65*cos(theta)**50 - 6.86587224531038e+65*cos(theta)**48 + 1.31712651236566e+66*cos(theta)**46 - 1.88031164179098e+66*cos(theta)**44 + 2.07316411787211e+66*cos(theta)**42 - 1.80850486878205e+66*cos(theta)**40 + 1.26855557342626e+66*cos(theta)**38 - 7.23272155813999e+65*cos(theta)**36 + 3.37527006046533e+65*cos(theta)**34 - 1.29427648935137e+65*cos(theta)**32 + 4.08372225647759e+64*cos(theta)**30 - 1.0592839484602e+64*cos(theta)**28 + 2.2520209927894e+63*cos(theta)**26 - 3.90350305416829e+62*cos(theta)**24 + 5.47442501499211e+61*cos(theta)**22 - 6.14775001683606e+60*cos(theta)**20 + 5.45318628944375e+59*cos(theta)**18 - 3.75320513848356e+58*cos(theta)**16 + 1.95819398529577e+57*cos(theta)**14 - 7.50929846868584e+55*cos(theta)**12 + 2.02954012667185e+54*cos(theta)**10 - 3.64297190667065e+52*cos(theta)**8 + 3.97208774870631e+50*cos(theta)**6 - 2.26976442783218e+48*cos(theta)**4 + 5.08535719454559e+45*cos(theta)**2 - 1.86481745307869e+42)*sin(23*phi)

#@torch.jit.script
def Yl77_m_minus_22(theta, phi):
    return 1.83195348828138e-41*(1.0 - cos(theta)**2)**11*(1.10922507607209e+62*cos(theta)**55 - 1.07660080912879e+63*cos(theta)**53 + 4.91243680456781e+63*cos(theta)**51 - 1.40119841741028e+64*cos(theta)**49 + 2.80239683482056e+64*cos(theta)**47 - 4.17847031509107e+64*cos(theta)**45 + 4.82131190202816e+64*cos(theta)**43 - 4.41098748483427e+64*cos(theta)**41 + 3.25270659852887e+64*cos(theta)**39 - 1.9547896103081e+64*cos(theta)**37 + 9.64362874418665e+63*cos(theta)**35 - 3.92204996773141e+63*cos(theta)**33 + 1.31732976015406e+63*cos(theta)**31 - 3.65270327055241e+62*cos(theta)**29 + 8.34081849181259e+61*cos(theta)**27 - 1.56140122166732e+61*cos(theta)**25 + 2.38018478912701e+60*cos(theta)**23 - 2.92750000801717e+59*cos(theta)**21 + 2.87009804707566e+58*cos(theta)**19 - 2.20776772851974e+57*cos(theta)**17 + 1.30546265686385e+56*cos(theta)**15 - 5.77638343745064e+54*cos(theta)**13 + 1.84503647879259e+53*cos(theta)**11 - 4.04774656296739e+51*cos(theta)**9 + 5.67441106958045e+49*cos(theta)**7 - 4.53952885566436e+47*cos(theta)**5 + 1.69511906484853e+45*cos(theta)**3 - 1.86481745307869e+42*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl77_m_minus_21(theta, phi):
    return 1.36403669545239e-39*(1.0 - cos(theta)**2)**10.5*(1.98075906441445e+60*cos(theta)**56 - 1.99370520209036e+61*cos(theta)**54 + 9.44699385493809e+61*cos(theta)**52 - 2.80239683482056e+62*cos(theta)**50 + 5.8383267392095e+62*cos(theta)**48 - 9.0836311197632e+62*cos(theta)**46 + 1.0957527050064e+63*cos(theta)**44 - 1.05023511543673e+63*cos(theta)**42 + 8.13176649632218e+62*cos(theta)**40 - 5.14418318502133e+62*cos(theta)**38 + 2.67878576227407e+62*cos(theta)**36 - 1.1535441081563e+62*cos(theta)**34 + 4.11665550048144e+61*cos(theta)**32 - 1.2175677568508e+61*cos(theta)**30 + 2.97886374707592e+60*cos(theta)**28 - 6.00538931410506e+59*cos(theta)**26 + 9.91743662136253e+58*cos(theta)**24 - 1.33068182182599e+58*cos(theta)**22 + 1.43504902353783e+57*cos(theta)**20 - 1.22653762695541e+56*cos(theta)**18 + 8.15914160539904e+54*cos(theta)**16 - 4.1259881696076e+53*cos(theta)**14 + 1.53753039899382e+52*cos(theta)**12 - 4.04774656296739e+50*cos(theta)**10 + 7.09301383697556e+48*cos(theta)**8 - 7.56588142610727e+46*cos(theta)**6 + 4.23779766212132e+44*cos(theta)**4 - 9.32408726539345e+41*cos(theta)**2 + 3.36366784465853e+38)*sin(21*phi)

#@torch.jit.script
def Yl77_m_minus_20(theta, phi):
    return 1.01947485751912e-37*(1.0 - cos(theta)**2)**10*(3.47501590248149e+58*cos(theta)**57 - 3.6249185492552e+59*cos(theta)**55 + 1.78245167074304e+60*cos(theta)**53 - 5.49489575455012e+60*cos(theta)**51 + 1.1914952528999e+61*cos(theta)**49 - 1.93268747229004e+61*cos(theta)**47 + 2.43500601112533e+61*cos(theta)**45 - 2.4424072452017e+61*cos(theta)**43 + 1.9833576820298e+61*cos(theta)**41 - 1.31902132949265e+61*cos(theta)**39 + 7.23996151965965e+60*cos(theta)**37 - 3.29584030901799e+60*cos(theta)**35 + 1.24747136378226e+60*cos(theta)**33 - 3.92763792532517e+59*cos(theta)**31 + 1.02719439554342e+59*cos(theta)**29 - 2.22421826448336e+58*cos(theta)**27 + 3.96697464854501e+57*cos(theta)**25 - 5.78557313837386e+56*cos(theta)**23 + 6.83356677875157e+55*cos(theta)**21 - 6.45546119450216e+54*cos(theta)**19 + 4.79949506199943e+53*cos(theta)**17 - 2.7506587797384e+52*cos(theta)**15 + 1.18271569153371e+51*cos(theta)**13 - 3.67976960269763e+49*cos(theta)**11 + 7.8811264855284e+47*cos(theta)**9 - 1.08084020372961e+46*cos(theta)**7 + 8.47559532424264e+43*cos(theta)**5 - 3.10802908846448e+41*cos(theta)**3 + 3.36366784465853e+38*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl77_m_minus_19(theta, phi):
    return 7.6467410510944e-36*(1.0 - cos(theta)**2)**9.5*(5.99140672841636e+56*cos(theta)**58 - 6.47306883795571e+57*cos(theta)**56 + 3.30083642730192e+58*cos(theta)**54 - 1.05671072202887e+59*cos(theta)**52 + 2.3829905057998e+59*cos(theta)**50 - 4.02643223393759e+59*cos(theta)**48 + 5.29349132853333e+59*cos(theta)**46 - 5.55092555727659e+59*cos(theta)**44 + 4.72228019530905e+59*cos(theta)**42 - 3.29755332373162e+59*cos(theta)**40 + 1.90525303148938e+59*cos(theta)**38 - 9.15511196949443e+58*cos(theta)**36 + 3.66903342288899e+58*cos(theta)**34 - 1.22738685166412e+58*cos(theta)**32 + 3.42398131847807e+57*cos(theta)**30 - 7.94363665886913e+56*cos(theta)**28 + 1.52575948020962e+56*cos(theta)**26 - 2.41065547432244e+55*cos(theta)**24 + 3.10616671761435e+54*cos(theta)**22 - 3.22773059725108e+53*cos(theta)**20 + 2.66638614555524e+52*cos(theta)**18 - 1.7191617373365e+51*cos(theta)**16 + 8.44796922524079e+49*cos(theta)**14 - 3.06647466891469e+48*cos(theta)**12 + 7.8811264855284e+46*cos(theta)**10 - 1.35105025466201e+45*cos(theta)**8 + 1.41259922070711e+43*cos(theta)**6 - 7.77007272116121e+40*cos(theta)**4 + 1.68183392232927e+38*cos(theta)**2 - 5.97879104987297e+34)*sin(19*phi)

#@torch.jit.script
def Yl77_m_minus_18(theta, phi):
    return 5.75490297269134e-34*(1.0 - cos(theta)**2)**9*(1.01549266583328e+55*cos(theta)**59 - 1.13562611192205e+56*cos(theta)**57 + 6.00152077691258e+56*cos(theta)**55 - 1.99379381514881e+57*cos(theta)**53 + 4.67253040352901e+57*cos(theta)**51 - 8.21720864068896e+57*cos(theta)**49 + 1.12627475075177e+58*cos(theta)**47 - 1.23353901272813e+58*cos(theta)**45 + 1.0982046965835e+58*cos(theta)**43 - 8.04281298471127e+57*cos(theta)**41 + 4.8852641833061e+57*cos(theta)**39 - 2.47435458634985e+57*cos(theta)**37 + 1.04829526368257e+57*cos(theta)**35 - 3.71935409595187e+56*cos(theta)**33 + 1.10451010273486e+56*cos(theta)**31 - 2.73918505478246e+55*cos(theta)**29 + 5.65096103781341e+54*cos(theta)**27 - 9.64262189728977e+53*cos(theta)**25 + 1.35050726852798e+53*cos(theta)**23 - 1.53701457011956e+52*cos(theta)**21 + 1.4033611292396e+51*cos(theta)**19 - 1.01127161019794e+50*cos(theta)**17 + 5.63197948349386e+48*cos(theta)**15 - 2.35882666839591e+47*cos(theta)**13 + 7.16466044138946e+45*cos(theta)**11 - 1.50116694962446e+44*cos(theta)**9 + 2.01799888672444e+42*cos(theta)**7 - 1.55401454423224e+40*cos(theta)**5 + 5.60611307443088e+37*cos(theta)**3 - 5.97879104987297e+34*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl77_m_minus_17(theta, phi):
    return 4.34485646348671e-32*(1.0 - cos(theta)**2)**8.5*(1.6924877763888e+53*cos(theta)**60 - 1.95797605503803e+54*cos(theta)**58 + 1.07170013873439e+55*cos(theta)**56 - 3.69221076879409e+55*cos(theta)**54 + 8.98563539140195e+55*cos(theta)**52 - 1.64344172813779e+56*cos(theta)**50 + 2.34640573073286e+56*cos(theta)**48 - 2.68160654940898e+56*cos(theta)**46 + 2.4959197649625e+56*cos(theta)**44 - 1.9149554725503e+56*cos(theta)**42 + 1.22131604582653e+56*cos(theta)**40 - 6.51145943776275e+55*cos(theta)**38 + 2.91193128800713e+55*cos(theta)**36 - 1.09392767527996e+55*cos(theta)**34 + 3.45159407104645e+54*cos(theta)**32 - 9.13061684927486e+53*cos(theta)**30 + 2.01820037064765e+53*cos(theta)**28 - 3.70870072972683e+52*cos(theta)**26 + 5.62711361886658e+51*cos(theta)**24 - 6.98642986417983e+50*cos(theta)**22 + 7.016805646198e+49*cos(theta)**20 - 5.61817561221079e+48*cos(theta)**18 + 3.51998717718366e+47*cos(theta)**16 - 1.68487619171137e+46*cos(theta)**14 + 5.97055036782455e+44*cos(theta)**12 - 1.50116694962446e+43*cos(theta)**10 + 2.52249860840555e+41*cos(theta)**8 - 2.59002424038707e+39*cos(theta)**6 + 1.40152826860772e+37*cos(theta)**4 - 2.98939552493648e+34*cos(theta)**2 + 1.04891071050403e+31)*sin(17*phi)

#@torch.jit.script
def Yl77_m_minus_16(theta, phi):
    return 3.29006348365385e-30*(1.0 - cos(theta)**2)**8*(2.77457012522754e+51*cos(theta)**61 - 3.3186034831153e+52*cos(theta)**59 + 1.88017568199016e+53*cos(theta)**57 - 6.71311048871653e+53*cos(theta)**55 + 1.6954029040381e+54*cos(theta)**53 - 3.22243476105449e+54*cos(theta)**51 + 4.78858312394461e+54*cos(theta)**49 - 5.70554584980635e+54*cos(theta)**47 + 5.54648836658333e+54*cos(theta)**45 - 4.45338481988442e+54*cos(theta)**43 + 2.97881962396714e+54*cos(theta)**41 - 1.66960498404173e+54*cos(theta)**39 + 7.87008456218144e+53*cos(theta)**37 - 3.12550764365703e+53*cos(theta)**35 + 1.0459375972868e+53*cos(theta)**33 - 2.94536027395963e+52*cos(theta)**31 + 6.95931162292291e+51*cos(theta)**29 - 1.37359286286179e+51*cos(theta)**27 + 2.25084544754663e+50*cos(theta)**25 - 3.03757820181732e+49*cos(theta)**23 + 3.34133602199905e+48*cos(theta)**21 - 2.95693453274252e+47*cos(theta)**19 + 2.07058069246098e+46*cos(theta)**17 - 1.12325079447424e+45*cos(theta)**15 + 4.59273105217273e+43*cos(theta)**13 - 1.36469722693133e+42*cos(theta)**11 + 2.80277623156172e+40*cos(theta)**9 - 3.70003462912438e+38*cos(theta)**7 + 2.80305653721544e+36*cos(theta)**5 - 9.96465174978828e+33*cos(theta)**3 + 1.04891071050403e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl77_m_minus_15(theta, phi):
    return 2.49828279445783e-28*(1.0 - cos(theta)**2)**7.5*(4.47511310520571e+49*cos(theta)**62 - 5.53100580519216e+50*cos(theta)**60 + 3.24168221032786e+51*cos(theta)**58 - 1.19876973012795e+52*cos(theta)**56 + 3.13963500747797e+52*cos(theta)**54 - 6.19698992510479e+52*cos(theta)**52 + 9.57716624788922e+52*cos(theta)**50 - 1.18865538537632e+53*cos(theta)**48 + 1.20575834056159e+53*cos(theta)**46 - 1.0121329136101e+53*cos(theta)**44 + 7.09242767611223e+52*cos(theta)**42 - 4.17401246010433e+52*cos(theta)**40 + 2.07107488478459e+52*cos(theta)**38 - 8.68196567682508e+51*cos(theta)**36 + 3.07628705084353e+51*cos(theta)**34 - 9.20425085612385e+50*cos(theta)**32 + 2.3197705409743e+50*cos(theta)**30 - 4.90568879593497e+49*cos(theta)**28 + 8.65709787517935e+48*cos(theta)**26 - 1.26565758409055e+48*cos(theta)**24 + 1.51878910090866e+47*cos(theta)**22 - 1.47846726637126e+46*cos(theta)**20 + 1.15032260692277e+45*cos(theta)**18 - 7.02031746546403e+43*cos(theta)**16 + 3.28052218012338e+42*cos(theta)**14 - 1.13724768910944e+41*cos(theta)**12 + 2.80277623156172e+39*cos(theta)**10 - 4.62504328640548e+37*cos(theta)**8 + 4.67176089535907e+35*cos(theta)**6 - 2.49116293744707e+33*cos(theta)**4 + 5.24455355252015e+30*cos(theta)**2 - 1.81913061134934e+27)*sin(15*phi)

#@torch.jit.script
def Yl77_m_minus_14(theta, phi):
    return 1.90197929732695e-26*(1.0 - cos(theta)**2)**7*(7.10335413524717e+47*cos(theta)**63 - 9.06722263146256e+48*cos(theta)**61 + 5.49437662767433e+49*cos(theta)**59 - 2.10310478969816e+50*cos(theta)**57 + 5.70842728632358e+50*cos(theta)**55 - 1.16924338209524e+51*cos(theta)**53 + 1.87787573488024e+51*cos(theta)**51 - 2.42582731709454e+51*cos(theta)**49 + 2.56544327779062e+51*cos(theta)**47 - 2.24918425246688e+51*cos(theta)**45 + 1.64940178514238e+51*cos(theta)**43 - 1.01805181953764e+51*cos(theta)**41 + 5.31044842252459e+50*cos(theta)**39 - 2.34647720995273e+50*cos(theta)**37 + 8.78939157383867e+49*cos(theta)**35 - 2.78916692609814e+49*cos(theta)**33 + 7.48313077733647e+48*cos(theta)**31 - 1.69161682618447e+48*cos(theta)**29 + 3.20633254636272e+47*cos(theta)**27 - 5.06263033636219e+46*cos(theta)**25 + 6.60343087351591e+45*cos(theta)**23 - 7.04032031605362e+44*cos(theta)**21 + 6.05432951011982e+43*cos(theta)**19 - 4.12959850909649e+42*cos(theta)**17 + 2.18701478674892e+41*cos(theta)**15 - 8.74805914699567e+39*cos(theta)**13 + 2.54797839232884e+38*cos(theta)**11 - 5.13893698489498e+36*cos(theta)**9 + 6.67394413622724e+34*cos(theta)**7 - 4.98232587489414e+32*cos(theta)**5 + 1.74818451750672e+30*cos(theta)**3 - 1.81913061134934e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl77_m_minus_13(theta, phi):
    return 1.45149808960291e-24*(1.0 - cos(theta)**2)**6.5*(1.10989908363237e+46*cos(theta)**64 - 1.46245526313912e+47*cos(theta)**62 + 9.15729437945722e+47*cos(theta)**60 - 3.6260427408589e+48*cos(theta)**58 + 1.01936201541493e+49*cos(theta)**56 - 2.1652655223986e+49*cos(theta)**54 + 3.61129949015431e+49*cos(theta)**52 - 4.85165463418907e+49*cos(theta)**50 + 5.34467349539713e+49*cos(theta)**48 - 4.88953098362365e+49*cos(theta)**46 + 3.74864042077813e+49*cos(theta)**44 - 2.42393290366105e+49*cos(theta)**42 + 1.32761210563115e+49*cos(theta)**40 - 6.17494002619138e+48*cos(theta)**38 + 2.44149765939963e+48*cos(theta)**36 - 8.20343213558276e+47*cos(theta)**34 + 2.33847836791765e+47*cos(theta)**32 - 5.63872275394824e+46*cos(theta)**30 + 1.14511876655812e+46*cos(theta)**28 - 1.94716551398546e+45*cos(theta)**26 + 2.75142953063163e+44*cos(theta)**24 - 3.20014559820619e+43*cos(theta)**22 + 3.02716475505991e+42*cos(theta)**20 - 2.29422139394249e+41*cos(theta)**18 + 1.36688424171807e+40*cos(theta)**16 - 6.24861367642548e+38*cos(theta)**14 + 2.1233153269407e+37*cos(theta)**12 - 5.13893698489498e+35*cos(theta)**10 + 8.34243017028405e+33*cos(theta)**8 - 8.3038764581569e+31*cos(theta)**6 + 4.37046129376679e+29*cos(theta)**4 - 9.0956530567467e+26*cos(theta)**2 + 3.12350723102565e+23)*sin(13*phi)

#@torch.jit.script
def Yl77_m_minus_12(theta, phi):
    return 1.11018256242418e-22*(1.0 - cos(theta)**2)**6*(1.70753705174211e+44*cos(theta)**65 - 2.32135756053829e+45*cos(theta)**63 + 1.50119579991102e+46*cos(theta)**61 - 6.14583515399813e+46*cos(theta)**59 + 1.78835441300864e+47*cos(theta)**57 - 3.93684640436109e+47*cos(theta)**55 + 6.81377262293266e+47*cos(theta)**53 - 9.51304830233151e+47*cos(theta)**51 + 1.09074969293819e+48*cos(theta)**49 - 1.04032574119652e+48*cos(theta)**47 + 8.33031204617363e+47*cos(theta)**45 - 5.63705326432802e+47*cos(theta)**43 + 3.23807830641743e+47*cos(theta)**41 - 1.58331795543369e+47*cos(theta)**39 + 6.5986423227017e+46*cos(theta)**37 - 2.34383775302364e+46*cos(theta)**35 + 7.08629808459893e+45*cos(theta)**33 - 1.81894282385427e+45*cos(theta)**31 + 3.94868540192454e+44*cos(theta)**29 - 7.21172412587207e+43*cos(theta)**27 + 1.10057181225265e+43*cos(theta)**25 - 1.391367651394e+42*cos(theta)**23 + 1.441507026219e+41*cos(theta)**21 - 1.20748494418026e+40*cos(theta)**19 + 8.04049553951808e+38*cos(theta)**17 - 4.16574245095032e+37*cos(theta)**15 + 1.63331948226207e+36*cos(theta)**13 - 4.67176089535907e+34*cos(theta)**11 + 9.26936685587117e+32*cos(theta)**9 - 1.18626806545099e+31*cos(theta)**7 + 8.74092258753358e+28*cos(theta)**5 - 3.0318843522489e+26*cos(theta)**3 + 3.12350723102565e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl77_m_minus_11(theta, phi):
    return 8.50866397321199e-21*(1.0 - cos(theta)**2)**5.5*(2.5871773511244e+42*cos(theta)**66 - 3.62712118834108e+43*cos(theta)**64 + 2.42128354824358e+44*cos(theta)**62 - 1.02430585899969e+45*cos(theta)**60 + 3.0833696776011e+45*cos(theta)**58 - 7.03008286493052e+45*cos(theta)**56 + 1.26180974498753e+46*cos(theta)**54 - 1.82943236583298e+46*cos(theta)**52 + 2.18149938587638e+46*cos(theta)**50 - 2.16734529415942e+46*cos(theta)**48 + 1.81093740134209e+46*cos(theta)**46 - 1.28114846916546e+46*cos(theta)**44 + 7.70971025337484e+45*cos(theta)**42 - 3.95829488858422e+45*cos(theta)**40 + 1.73648482176361e+45*cos(theta)**38 - 6.51066042506568e+44*cos(theta)**36 + 2.08420531899968e+44*cos(theta)**34 - 5.68419632454459e+43*cos(theta)**32 + 1.31622846730818e+43*cos(theta)**30 - 2.57561575924003e+42*cos(theta)**28 + 4.23296850866404e+41*cos(theta)**26 - 5.79736521414165e+40*cos(theta)**24 + 6.55230466463184e+39*cos(theta)**22 - 6.0374247209013e+38*cos(theta)**20 + 4.46694196639893e+37*cos(theta)**18 - 2.60358903184395e+36*cos(theta)**16 + 1.16665677304434e+35*cos(theta)**14 - 3.89313407946589e+33*cos(theta)**12 + 9.26936685587117e+31*cos(theta)**10 - 1.48283508181373e+30*cos(theta)**8 + 1.4568204312556e+28*cos(theta)**6 - 7.57971088062225e+25*cos(theta)**4 + 1.56175361551283e+23*cos(theta)**2 - 5.31751316143284e+19)*sin(11*phi)

#@torch.jit.script
def Yl77_m_minus_10(theta, phi):
    return 6.53341296676457e-19*(1.0 - cos(theta)**2)**5*(3.8614587330215e+40*cos(theta)**67 - 5.58018644360166e+41*cos(theta)**65 + 3.84330721943425e+42*cos(theta)**63 - 1.67918993278638e+43*cos(theta)**61 + 5.22605030101882e+43*cos(theta)**59 - 1.23334787104044e+44*cos(theta)**57 + 2.29419953634096e+44*cos(theta)**55 - 3.45175918081695e+44*cos(theta)**53 + 4.2774497762282e+44*cos(theta)**51 - 4.42315366154984e+44*cos(theta)**49 + 3.85305830072786e+44*cos(theta)**47 - 2.84699659814547e+44*cos(theta)**45 + 1.79295587287787e+44*cos(theta)**43 - 9.65437777703468e+43*cos(theta)**41 + 4.45252518400925e+43*cos(theta)**39 - 1.75963795272045e+43*cos(theta)**37 + 5.9548723399991e+42*cos(theta)**35 - 1.72248373471048e+42*cos(theta)**33 + 4.24589828163929e+41*cos(theta)**31 - 8.88143365255181e+40*cos(theta)**29 + 1.56776611432002e+40*cos(theta)**27 - 2.31894608565666e+39*cos(theta)**25 + 2.84882811505732e+38*cos(theta)**23 - 2.87496415281014e+37*cos(theta)**21 + 2.35102208757839e+36*cos(theta)**19 - 1.53152295990821e+35*cos(theta)**17 + 7.77771182029559e+33*cos(theta)**15 - 2.99471852266607e+32*cos(theta)**13 + 8.42669714170106e+30*cos(theta)**11 - 1.64759453534859e+29*cos(theta)**9 + 2.08117204465085e+27*cos(theta)**7 - 1.51594217612445e+25*cos(theta)**5 + 5.20584538504275e+22*cos(theta)**3 - 5.31751316143284e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl77_m_minus_9(theta, phi):
    return 5.02520973916716e-17*(1.0 - cos(theta)**2)**4.5*(5.67861578385515e+38*cos(theta)**68 - 8.454827944851e+39*cos(theta)**66 + 6.00516753036602e+40*cos(theta)**64 - 2.70837085933286e+41*cos(theta)**62 + 8.71008383503137e+41*cos(theta)**60 - 2.12646184662145e+42*cos(theta)**58 + 4.09678488632315e+42*cos(theta)**56 - 6.3921466311425e+42*cos(theta)**54 + 8.22586495428499e+42*cos(theta)**52 - 8.84630732309968e+42*cos(theta)**50 + 8.02720479318304e+42*cos(theta)**48 - 6.18912303944667e+42*cos(theta)**46 + 4.07489971108607e+42*cos(theta)**44 - 2.29866137548445e+42*cos(theta)**42 + 1.11313129600231e+42*cos(theta)**40 - 4.63062619136962e+41*cos(theta)**38 + 1.6541312055553e+41*cos(theta)**36 - 5.06612863150142e+40*cos(theta)**34 + 1.32684321301228e+40*cos(theta)**32 - 2.96047788418394e+39*cos(theta)**30 + 5.59916469400005e+38*cos(theta)**28 - 8.91902340637177e+37*cos(theta)**26 + 1.18701171460722e+37*cos(theta)**24 - 1.30680188764097e+36*cos(theta)**22 + 1.17551104378919e+35*cos(theta)**20 - 8.50846088837892e+33*cos(theta)**18 + 4.86106988768475e+32*cos(theta)**16 - 2.13908465904719e+31*cos(theta)**14 + 7.02224761808422e+29*cos(theta)**12 - 1.64759453534859e+28*cos(theta)**10 + 2.60146505581356e+26*cos(theta)**8 - 2.52657029354075e+24*cos(theta)**6 + 1.30146134626069e+22*cos(theta)**4 - 2.65875658071642e+19*cos(theta)**2 + 8.98835896117789e+15)*sin(9*phi)

#@torch.jit.script
def Yl77_m_minus_8(theta, phi):
    return 3.87104271692821e-15*(1.0 - cos(theta)**2)**4*(8.22987794761615e+36*cos(theta)**69 - 1.26191461863448e+38*cos(theta)**67 + 9.23871927748619e+38*cos(theta)**65 - 4.29900136402042e+39*cos(theta)**63 + 1.42788259590678e+40*cos(theta)**61 - 3.60417262139229e+40*cos(theta)**59 + 7.18734190583008e+40*cos(theta)**57 - 1.16220847838955e+41*cos(theta)**55 + 1.55204999137453e+41*cos(theta)**53 - 1.73457006335288e+41*cos(theta)**51 + 1.63820505983327e+41*cos(theta)**49 - 1.31683468924397e+41*cos(theta)**47 + 9.05533269130237e+40*cos(theta)**45 - 5.3457241290336e+40*cos(theta)**43 + 2.71495438049344e+40*cos(theta)**41 - 1.18734004906913e+40*cos(theta)**39 + 4.4706248798792e+39*cos(theta)**37 - 1.44746532328612e+39*cos(theta)**35 + 4.02073700912811e+38*cos(theta)**33 - 9.54992865865786e+37*cos(theta)**31 + 1.93074644620692e+37*cos(theta)**29 - 3.30334200235991e+36*cos(theta)**27 + 4.74804685842887e+35*cos(theta)**25 - 5.68174733756945e+34*cos(theta)**23 + 5.5976716370914e+33*cos(theta)**21 - 4.47813730967312e+32*cos(theta)**19 + 2.85945287510867e+31*cos(theta)**17 - 1.4260564393648e+30*cos(theta)**15 + 5.40172893698786e+28*cos(theta)**13 - 1.49781321395326e+27*cos(theta)**11 + 2.89051672868174e+25*cos(theta)**9 - 3.60938613362964e+23*cos(theta)**7 + 2.60292269252138e+21*cos(theta)**5 - 8.8625219357214e+18*cos(theta)**3 + 8.98835896117789e+15*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl77_m_minus_7(theta, phi):
    return 2.9859769207394e-13*(1.0 - cos(theta)**2)**3.5*(1.17569684965945e+35*cos(theta)**70 - 1.85575679210953e+36*cos(theta)**68 + 1.39980595113427e+37*cos(theta)**66 - 6.7171896312819e+37*cos(theta)**64 + 2.30303644501094e+38*cos(theta)**62 - 6.00695436898715e+38*cos(theta)**60 + 1.23919688031553e+39*cos(theta)**58 - 2.07537228283847e+39*cos(theta)**56 + 2.87416665069357e+39*cos(theta)**54 - 3.335711660294e+39*cos(theta)**52 + 3.27641011966655e+39*cos(theta)**50 - 2.74340560259161e+39*cos(theta)**48 + 1.96855058506573e+39*cos(theta)**46 - 1.21493730205309e+39*cos(theta)**44 + 6.46417709641296e+38*cos(theta)**42 - 2.96835012267283e+38*cos(theta)**40 + 1.17648023154716e+38*cos(theta)**38 - 4.02073700912811e+37*cos(theta)**36 + 1.18256970856709e+37*cos(theta)**34 - 2.98435270583058e+36*cos(theta)**32 + 6.43582148735639e+35*cos(theta)**30 - 1.17976500084283e+35*cos(theta)**28 + 1.82617186862649e+34*cos(theta)**26 - 2.36739472398727e+33*cos(theta)**24 + 2.54439619867791e+32*cos(theta)**22 - 2.23906865483656e+31*cos(theta)**20 + 1.58858493061593e+30*cos(theta)**18 - 8.91285274602997e+28*cos(theta)**16 + 3.85837781213419e+27*cos(theta)**14 - 1.24817767829439e+26*cos(theta)**12 + 2.89051672868174e+24*cos(theta)**10 - 4.51173266703705e+22*cos(theta)**8 + 4.33820448753563e+20*cos(theta)**6 - 2.21563048393035e+18*cos(theta)**4 + 4.49417948058895e+15*cos(theta)**2 - 1510648564903.85)*sin(7*phi)

#@torch.jit.script
def Yl77_m_minus_6(theta, phi):
    return 2.30597855438786e-11*(1.0 - cos(theta)**2)**3*(1.65591105585838e+33*cos(theta)**71 - 2.68950259726018e+34*cos(theta)**69 + 2.08926261363324e+35*cos(theta)**67 - 1.03341378942799e+36*cos(theta)**65 + 3.65561340477927e+36*cos(theta)**63 - 9.84746617866746e+36*cos(theta)**61 + 2.10033369545005e+37*cos(theta)**59 - 3.64100400497978e+37*cos(theta)**57 + 5.22575754671558e+37*cos(theta)**55 - 6.29379558546037e+37*cos(theta)**53 + 6.42433356797362e+37*cos(theta)**51 - 5.5987869440645e+37*cos(theta)**49 + 4.18840550013986e+37*cos(theta)**47 - 2.69986067122909e+37*cos(theta)**45 + 1.5032969991658e+37*cos(theta)**43 - 7.23987834798251e+36*cos(theta)**41 + 3.01661597832605e+36*cos(theta)**39 - 1.08668567814273e+36*cos(theta)**37 + 3.37877059590598e+35*cos(theta)**35 - 9.04349304797146e+34*cos(theta)**33 + 2.07607144753432e+34*cos(theta)**31 - 4.06815517532009e+33*cos(theta)**29 + 6.76359951343144e+32*cos(theta)**27 - 9.46957889594908e+31*cos(theta)**25 + 1.10625921681648e+31*cos(theta)**23 - 1.06622316896979e+30*cos(theta)**21 + 8.36097331903121e+28*cos(theta)**19 - 5.24285455648822e+27*cos(theta)**17 + 2.57225187475612e+26*cos(theta)**15 - 9.60136675611067e+24*cos(theta)**13 + 2.62774248061976e+23*cos(theta)**11 - 5.01303629670784e+21*cos(theta)**9 + 6.19743498219375e+19*cos(theta)**7 - 4.4312609678607e+17*cos(theta)**5 + 1.49805982686298e+15*cos(theta)**3 - 1510648564903.85*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl77_m_minus_5(theta, phi):
    return 1.78262732138665e-9*(1.0 - cos(theta)**2)**2.5*(2.29987646646997e+31*cos(theta)**72 - 3.84214656751454e+32*cos(theta)**70 + 3.07244502004888e+33*cos(theta)**68 - 1.56577846883028e+34*cos(theta)**66 + 5.71189594496761e+34*cos(theta)**64 - 1.58830099655927e+35*cos(theta)**62 + 3.50055615908342e+35*cos(theta)**60 - 6.2775931120341e+35*cos(theta)**58 + 9.33170990484925e+35*cos(theta)**56 - 1.16551770101118e+36*cos(theta)**54 + 1.23544876307185e+36*cos(theta)**52 - 1.1197573888129e+36*cos(theta)**50 + 8.72584479195804e+35*cos(theta)**48 - 5.86926232875889e+35*cos(theta)**46 + 3.41658408901319e+35*cos(theta)**44 - 1.72378055904346e+35*cos(theta)**42 + 7.54153994581512e+34*cos(theta)**40 - 2.85969915300719e+34*cos(theta)**38 + 9.3854738775166e+33*cos(theta)**36 - 2.65985089646219e+33*cos(theta)**34 + 6.48772327354474e+32*cos(theta)**32 - 1.3560517251067e+32*cos(theta)**30 + 2.41557125479694e+31*cos(theta)**28 - 3.64214572921119e+30*cos(theta)**26 + 4.60941340340201e+29*cos(theta)**24 - 4.84646894986268e+28*cos(theta)**22 + 4.18048665951561e+27*cos(theta)**20 - 2.91269697582679e+26*cos(theta)**18 + 1.60765742172258e+25*cos(theta)**16 - 6.85811911150762e+23*cos(theta)**14 + 2.18978540051647e+22*cos(theta)**12 - 5.01303629670784e+20*cos(theta)**10 + 7.74679372774219e+18*cos(theta)**8 - 7.3854349464345e+16*cos(theta)**6 + 374514956715746.0*cos(theta)**4 - 755324282451.924*cos(theta)**2 + 252785904.435048)*sin(5*phi)

#@torch.jit.script
def Yl77_m_minus_4(theta, phi):
    return 1.37920529144096e-7*(1.0 - cos(theta)**2)**2*(3.15051570749311e+29*cos(theta)**73 - 5.41147403875288e+30*cos(theta)**71 + 4.45281886963606e+31*cos(theta)**69 - 2.33698278929893e+32*cos(theta)**67 + 8.78753222302709e+32*cos(theta)**65 - 2.52111269295122e+33*cos(theta)**63 + 5.73861665423512e+33*cos(theta)**61 - 1.06399883254815e+34*cos(theta)**59 + 1.63714208857004e+34*cos(theta)**57 - 2.1191230927476e+34*cos(theta)**55 + 2.33103540202236e+34*cos(theta)**53 - 2.19560272316255e+34*cos(theta)**51 + 1.78078465142001e+34*cos(theta)**49 - 1.24877921888487e+34*cos(theta)**47 + 7.59240908669598e+33*cos(theta)**45 - 4.00879199777548e+33*cos(theta)**43 + 1.83939998678418e+33*cos(theta)**41 - 7.33256193078767e+32*cos(theta)**39 + 2.53661456149097e+32*cos(theta)**37 - 7.59957398989198e+31*cos(theta)**35 + 1.96597674955901e+31*cos(theta)**33 - 4.37436040356999e+30*cos(theta)**31 + 8.32955605102394e+29*cos(theta)**29 - 1.34894286267081e+29*cos(theta)**27 + 1.8437653613608e+28*cos(theta)**25 - 2.10716041298377e+27*cos(theta)**23 + 1.99070793310267e+26*cos(theta)**21 - 1.53299840832989e+25*cos(theta)**19 + 9.45680836307399e+23*cos(theta)**17 - 4.57207940767175e+22*cos(theta)**15 + 1.68445030808959e+21*cos(theta)**13 - 4.55730572427985e+19*cos(theta)**11 + 8.60754858638021e+17*cos(theta)**9 - 1.05506213520493e+16*cos(theta)**7 + 74902991343149.1*cos(theta)**5 - 251774760817.308*cos(theta)**3 + 252785904.435048*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl77_m_minus_3(theta, phi):
    return 1.06779352743013e-5*(1.0 - cos(theta)**2)**1.5*(4.25745365877448e+27*cos(theta)**74 - 7.51593616493456e+28*cos(theta)**72 + 6.3611698137658e+29*cos(theta)**70 - 3.43673939602783e+30*cos(theta)**68 + 1.33144427621623e+31*cos(theta)**66 - 3.93923858273628e+31*cos(theta)**64 + 9.25583331328245e+31*cos(theta)**62 - 1.77333138758025e+32*cos(theta)**60 + 2.82265877339663e+32*cos(theta)**58 - 3.78414837990643e+32*cos(theta)**56 + 4.31673222596733e+32*cos(theta)**54 - 4.22231292915875e+32*cos(theta)**52 + 3.56156930284001e+32*cos(theta)**50 - 2.60162337267681e+32*cos(theta)**48 + 1.65052371449913e+32*cos(theta)**46 - 9.11089090403518e+31*cos(theta)**44 + 4.37952377805756e+31*cos(theta)**42 - 1.83314048269692e+31*cos(theta)**40 + 6.67530147760782e+30*cos(theta)**38 - 2.11099277497e+30*cos(theta)**36 + 5.78228455752651e+29*cos(theta)**34 - 1.36698762611562e+29*cos(theta)**32 + 2.77651868367465e+28*cos(theta)**30 - 4.81765308096718e+27*cos(theta)**28 + 7.09140523600309e+26*cos(theta)**26 - 8.77983505409906e+25*cos(theta)**24 + 9.04867242319395e+24*cos(theta)**22 - 7.66499204164944e+23*cos(theta)**20 + 5.25378242392999e+22*cos(theta)**18 - 2.85754962979484e+21*cos(theta)**16 + 1.20317879149256e+20*cos(theta)**14 - 3.79775477023321e+18*cos(theta)**12 + 8.60754858638021e+16*cos(theta)**10 - 1.31882766900616e+15*cos(theta)**8 + 12483831890524.9*cos(theta)**6 - 62943690204.327*cos(theta)**4 + 126392952.217524*cos(theta)**2 - 42173.1572297378)*sin(3*phi)

#@torch.jit.script
def Yl77_m_minus_2(theta, phi):
    return 0.000827109309784994*(1.0 - cos(theta)**2)*(5.67660487836597e+25*cos(theta)**75 - 1.02958029656638e+27*cos(theta)**73 + 8.9593941038955e+27*cos(theta)**71 - 4.98078173337367e+28*cos(theta)**69 + 1.98723026300929e+29*cos(theta)**67 - 6.06036705036351e+29*cos(theta)**65 + 1.46917989099721e+30*cos(theta)**63 - 2.90710063537747e+30*cos(theta)**61 + 4.78416741253666e+30*cos(theta)**59 - 6.63885680685338e+30*cos(theta)**57 + 7.84860404721333e+30*cos(theta)**55 - 7.96662816822406e+30*cos(theta)**53 + 6.98346922125493e+30*cos(theta)**51 - 5.30943545444248e+30*cos(theta)**49 + 3.51175258404069e+30*cos(theta)**47 - 2.02464242311893e+30*cos(theta)**45 + 1.01849390187385e+30*cos(theta)**43 - 4.47107434804126e+29*cos(theta)**41 + 1.71161576348919e+29*cos(theta)**39 - 5.70538587829729e+28*cos(theta)**37 + 1.65208130215043e+28*cos(theta)**35 - 4.14238674580492e+27*cos(theta)**33 + 8.95651188282144e+26*cos(theta)**31 - 1.66125968309213e+26*cos(theta)**29 + 2.62644638370485e+25*cos(theta)**27 - 3.51193402163962e+24*cos(theta)**25 + 3.93420540138868e+23*cos(theta)**23 - 3.64999621030926e+22*cos(theta)**21 + 2.76514864417368e+21*cos(theta)**19 - 1.68091154693814e+20*cos(theta)**17 + 8.02119194328377e+18*cos(theta)**15 - 2.92134982325631e+17*cos(theta)**13 + 7.82504416943656e+15*cos(theta)**11 - 146536407667351.0*cos(theta)**9 + 1783404555789.26*cos(theta)**7 - 12588738040.8654*cos(theta)**5 + 42130984.072508*cos(theta)**3 - 42173.1572297378*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl77_m_minus_1(theta, phi):
    return 0.0640889639582307*(1.0 - cos(theta)**2)**0.5*(7.46921694521839e+23*cos(theta)**76 - 1.3913247250897e+25*cos(theta)**74 + 1.24436029220771e+26*cos(theta)**72 - 7.1154024762481e+26*cos(theta)**70 + 2.9223974456019e+27*cos(theta)**68 - 9.18237431873259e+27*cos(theta)**66 + 2.29559357968315e+28*cos(theta)**64 - 4.6888719925443e+28*cos(theta)**62 + 7.97361235422776e+28*cos(theta)**60 - 1.14463048394024e+29*cos(theta)**58 + 1.40153643700238e+29*cos(theta)**56 - 1.47530151263408e+29*cos(theta)**54 + 1.34297485024133e+29*cos(theta)**52 - 1.0618870908885e+29*cos(theta)**50 + 7.31615121675145e+28*cos(theta)**48 - 4.40139657199767e+28*cos(theta)**46 + 2.31475886789512e+28*cos(theta)**44 - 1.0645415114384e+28*cos(theta)**42 + 4.27903940872296e+27*cos(theta)**40 - 1.50141733639402e+27*cos(theta)**38 + 4.58911472819564e+26*cos(theta)**36 - 1.2183490428838e+26*cos(theta)**34 + 2.7989099633817e+25*cos(theta)**32 - 5.53753227697377e+24*cos(theta)**30 + 9.38016565608874e+23*cos(theta)**28 - 1.35074385447678e+23*cos(theta)**26 + 1.63925225057861e+22*cos(theta)**24 - 1.65908918650421e+21*cos(theta)**22 + 1.38257432208684e+20*cos(theta)**20 - 9.33839748298968e+18*cos(theta)**18 + 5.01324496455235e+17*cos(theta)**16 - 2.08667844518308e+16*cos(theta)**14 + 652087014119713.0*cos(theta)**12 - 14653640766735.1*cos(theta)**10 + 222925569473.658*cos(theta)**8 - 2098123006.8109*cos(theta)**6 + 10532746.018127*cos(theta)**4 - 21086.5786148689*cos(theta)**2 + 7.0241767537871)*sin(phi)

#@torch.jit.script
def Yl77_m0(theta, phi):
    return 1.07027440194302e+23*cos(theta)**77 - 2.04681235299692e+24*cos(theta)**75 + 1.88076300647896e+25*cos(theta)**73 - 1.10573717696347e+26*cos(theta)**71 + 4.67305592645275e+26*cos(theta)**69 - 1.5121364418563e+27*cos(theta)**67 + 3.89665929247584e+27*cos(theta)**65 - 8.21180479062792e+27*cos(theta)**63 + 1.44223513993672e+28*cos(theta)**61 - 2.1405436383489e+28*cos(theta)**59 + 2.7129408631222e+28*cos(theta)**57 - 2.95957185067877e+28*cos(theta)**55 + 2.7957787520725e+28*cos(theta)**53 - 2.29730657147042e+28*cos(theta)**51 + 1.64739363252238e+28*cos(theta)**49 - 1.03324528631804e+28*cos(theta)**47 + 5.67549875259043e+27*cos(theta)**45 - 2.73152346381358e+27*cos(theta)**43 + 1.15152459749004e+27*cos(theta)**41 - 4.24763909105637e+26*cos(theta)**39 + 1.36847850716207e+26*cos(theta)**37 - 3.8407361389378e+25*cos(theta)**35 + 9.35805897898441e+24*cos(theta)**33 - 1.97090352648734e+24*cos(theta)**31 + 3.56880895567218e+23*cos(theta)**29 - 5.51975785143963e+22*cos(theta)**27 + 7.23463407712962e+21*cos(theta)**25 - 7.95889337417999e+20*cos(theta)**23 + 7.26406934945e+19*cos(theta)**21 - 5.4228743810327e+18*cos(theta)**19 + 3.25372462861962e+17*cos(theta)**17 - 1.53488223896035e+16*cos(theta)**15 + 553443115009741.0*cos(theta)**13 - 14698182829676.5*cos(theta)**11 + 273292784189.387*cos(theta)**9 - 3307072346.49342*cos(theta)**7 + 23242476.330777*cos(theta)**5 - 77552.4735761663*cos(theta)**3 + 77.5008063719184*cos(theta)

#@torch.jit.script
def Yl77_m1(theta, phi):
    return 0.0640889639582307*(1.0 - cos(theta)**2)**0.5*(7.46921694521839e+23*cos(theta)**76 - 1.3913247250897e+25*cos(theta)**74 + 1.24436029220771e+26*cos(theta)**72 - 7.1154024762481e+26*cos(theta)**70 + 2.9223974456019e+27*cos(theta)**68 - 9.18237431873259e+27*cos(theta)**66 + 2.29559357968315e+28*cos(theta)**64 - 4.6888719925443e+28*cos(theta)**62 + 7.97361235422776e+28*cos(theta)**60 - 1.14463048394024e+29*cos(theta)**58 + 1.40153643700238e+29*cos(theta)**56 - 1.47530151263408e+29*cos(theta)**54 + 1.34297485024133e+29*cos(theta)**52 - 1.0618870908885e+29*cos(theta)**50 + 7.31615121675145e+28*cos(theta)**48 - 4.40139657199767e+28*cos(theta)**46 + 2.31475886789512e+28*cos(theta)**44 - 1.0645415114384e+28*cos(theta)**42 + 4.27903940872296e+27*cos(theta)**40 - 1.50141733639402e+27*cos(theta)**38 + 4.58911472819564e+26*cos(theta)**36 - 1.2183490428838e+26*cos(theta)**34 + 2.7989099633817e+25*cos(theta)**32 - 5.53753227697377e+24*cos(theta)**30 + 9.38016565608874e+23*cos(theta)**28 - 1.35074385447678e+23*cos(theta)**26 + 1.63925225057861e+22*cos(theta)**24 - 1.65908918650421e+21*cos(theta)**22 + 1.38257432208684e+20*cos(theta)**20 - 9.33839748298968e+18*cos(theta)**18 + 5.01324496455235e+17*cos(theta)**16 - 2.08667844518308e+16*cos(theta)**14 + 652087014119713.0*cos(theta)**12 - 14653640766735.1*cos(theta)**10 + 222925569473.658*cos(theta)**8 - 2098123006.8109*cos(theta)**6 + 10532746.018127*cos(theta)**4 - 21086.5786148689*cos(theta)**2 + 7.0241767537871)*cos(phi)

#@torch.jit.script
def Yl77_m2(theta, phi):
    return 0.000827109309784994*(1.0 - cos(theta)**2)*(5.67660487836597e+25*cos(theta)**75 - 1.02958029656638e+27*cos(theta)**73 + 8.9593941038955e+27*cos(theta)**71 - 4.98078173337367e+28*cos(theta)**69 + 1.98723026300929e+29*cos(theta)**67 - 6.06036705036351e+29*cos(theta)**65 + 1.46917989099721e+30*cos(theta)**63 - 2.90710063537747e+30*cos(theta)**61 + 4.78416741253666e+30*cos(theta)**59 - 6.63885680685338e+30*cos(theta)**57 + 7.84860404721333e+30*cos(theta)**55 - 7.96662816822406e+30*cos(theta)**53 + 6.98346922125493e+30*cos(theta)**51 - 5.30943545444248e+30*cos(theta)**49 + 3.51175258404069e+30*cos(theta)**47 - 2.02464242311893e+30*cos(theta)**45 + 1.01849390187385e+30*cos(theta)**43 - 4.47107434804126e+29*cos(theta)**41 + 1.71161576348919e+29*cos(theta)**39 - 5.70538587829729e+28*cos(theta)**37 + 1.65208130215043e+28*cos(theta)**35 - 4.14238674580492e+27*cos(theta)**33 + 8.95651188282144e+26*cos(theta)**31 - 1.66125968309213e+26*cos(theta)**29 + 2.62644638370485e+25*cos(theta)**27 - 3.51193402163962e+24*cos(theta)**25 + 3.93420540138868e+23*cos(theta)**23 - 3.64999621030926e+22*cos(theta)**21 + 2.76514864417368e+21*cos(theta)**19 - 1.68091154693814e+20*cos(theta)**17 + 8.02119194328377e+18*cos(theta)**15 - 2.92134982325631e+17*cos(theta)**13 + 7.82504416943656e+15*cos(theta)**11 - 146536407667351.0*cos(theta)**9 + 1783404555789.26*cos(theta)**7 - 12588738040.8654*cos(theta)**5 + 42130984.072508*cos(theta)**3 - 42173.1572297378*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl77_m3(theta, phi):
    return 1.06779352743013e-5*(1.0 - cos(theta)**2)**1.5*(4.25745365877448e+27*cos(theta)**74 - 7.51593616493456e+28*cos(theta)**72 + 6.3611698137658e+29*cos(theta)**70 - 3.43673939602783e+30*cos(theta)**68 + 1.33144427621623e+31*cos(theta)**66 - 3.93923858273628e+31*cos(theta)**64 + 9.25583331328245e+31*cos(theta)**62 - 1.77333138758025e+32*cos(theta)**60 + 2.82265877339663e+32*cos(theta)**58 - 3.78414837990643e+32*cos(theta)**56 + 4.31673222596733e+32*cos(theta)**54 - 4.22231292915875e+32*cos(theta)**52 + 3.56156930284001e+32*cos(theta)**50 - 2.60162337267681e+32*cos(theta)**48 + 1.65052371449913e+32*cos(theta)**46 - 9.11089090403518e+31*cos(theta)**44 + 4.37952377805756e+31*cos(theta)**42 - 1.83314048269692e+31*cos(theta)**40 + 6.67530147760782e+30*cos(theta)**38 - 2.11099277497e+30*cos(theta)**36 + 5.78228455752651e+29*cos(theta)**34 - 1.36698762611562e+29*cos(theta)**32 + 2.77651868367465e+28*cos(theta)**30 - 4.81765308096718e+27*cos(theta)**28 + 7.09140523600309e+26*cos(theta)**26 - 8.77983505409906e+25*cos(theta)**24 + 9.04867242319395e+24*cos(theta)**22 - 7.66499204164944e+23*cos(theta)**20 + 5.25378242392999e+22*cos(theta)**18 - 2.85754962979484e+21*cos(theta)**16 + 1.20317879149256e+20*cos(theta)**14 - 3.79775477023321e+18*cos(theta)**12 + 8.60754858638021e+16*cos(theta)**10 - 1.31882766900616e+15*cos(theta)**8 + 12483831890524.9*cos(theta)**6 - 62943690204.327*cos(theta)**4 + 126392952.217524*cos(theta)**2 - 42173.1572297378)*cos(3*phi)

#@torch.jit.script
def Yl77_m4(theta, phi):
    return 1.37920529144096e-7*(1.0 - cos(theta)**2)**2*(3.15051570749311e+29*cos(theta)**73 - 5.41147403875288e+30*cos(theta)**71 + 4.45281886963606e+31*cos(theta)**69 - 2.33698278929893e+32*cos(theta)**67 + 8.78753222302709e+32*cos(theta)**65 - 2.52111269295122e+33*cos(theta)**63 + 5.73861665423512e+33*cos(theta)**61 - 1.06399883254815e+34*cos(theta)**59 + 1.63714208857004e+34*cos(theta)**57 - 2.1191230927476e+34*cos(theta)**55 + 2.33103540202236e+34*cos(theta)**53 - 2.19560272316255e+34*cos(theta)**51 + 1.78078465142001e+34*cos(theta)**49 - 1.24877921888487e+34*cos(theta)**47 + 7.59240908669598e+33*cos(theta)**45 - 4.00879199777548e+33*cos(theta)**43 + 1.83939998678418e+33*cos(theta)**41 - 7.33256193078767e+32*cos(theta)**39 + 2.53661456149097e+32*cos(theta)**37 - 7.59957398989198e+31*cos(theta)**35 + 1.96597674955901e+31*cos(theta)**33 - 4.37436040356999e+30*cos(theta)**31 + 8.32955605102394e+29*cos(theta)**29 - 1.34894286267081e+29*cos(theta)**27 + 1.8437653613608e+28*cos(theta)**25 - 2.10716041298377e+27*cos(theta)**23 + 1.99070793310267e+26*cos(theta)**21 - 1.53299840832989e+25*cos(theta)**19 + 9.45680836307399e+23*cos(theta)**17 - 4.57207940767175e+22*cos(theta)**15 + 1.68445030808959e+21*cos(theta)**13 - 4.55730572427985e+19*cos(theta)**11 + 8.60754858638021e+17*cos(theta)**9 - 1.05506213520493e+16*cos(theta)**7 + 74902991343149.1*cos(theta)**5 - 251774760817.308*cos(theta)**3 + 252785904.435048*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl77_m5(theta, phi):
    return 1.78262732138665e-9*(1.0 - cos(theta)**2)**2.5*(2.29987646646997e+31*cos(theta)**72 - 3.84214656751454e+32*cos(theta)**70 + 3.07244502004888e+33*cos(theta)**68 - 1.56577846883028e+34*cos(theta)**66 + 5.71189594496761e+34*cos(theta)**64 - 1.58830099655927e+35*cos(theta)**62 + 3.50055615908342e+35*cos(theta)**60 - 6.2775931120341e+35*cos(theta)**58 + 9.33170990484925e+35*cos(theta)**56 - 1.16551770101118e+36*cos(theta)**54 + 1.23544876307185e+36*cos(theta)**52 - 1.1197573888129e+36*cos(theta)**50 + 8.72584479195804e+35*cos(theta)**48 - 5.86926232875889e+35*cos(theta)**46 + 3.41658408901319e+35*cos(theta)**44 - 1.72378055904346e+35*cos(theta)**42 + 7.54153994581512e+34*cos(theta)**40 - 2.85969915300719e+34*cos(theta)**38 + 9.3854738775166e+33*cos(theta)**36 - 2.65985089646219e+33*cos(theta)**34 + 6.48772327354474e+32*cos(theta)**32 - 1.3560517251067e+32*cos(theta)**30 + 2.41557125479694e+31*cos(theta)**28 - 3.64214572921119e+30*cos(theta)**26 + 4.60941340340201e+29*cos(theta)**24 - 4.84646894986268e+28*cos(theta)**22 + 4.18048665951561e+27*cos(theta)**20 - 2.91269697582679e+26*cos(theta)**18 + 1.60765742172258e+25*cos(theta)**16 - 6.85811911150762e+23*cos(theta)**14 + 2.18978540051647e+22*cos(theta)**12 - 5.01303629670784e+20*cos(theta)**10 + 7.74679372774219e+18*cos(theta)**8 - 7.3854349464345e+16*cos(theta)**6 + 374514956715746.0*cos(theta)**4 - 755324282451.924*cos(theta)**2 + 252785904.435048)*cos(5*phi)

#@torch.jit.script
def Yl77_m6(theta, phi):
    return 2.30597855438786e-11*(1.0 - cos(theta)**2)**3*(1.65591105585838e+33*cos(theta)**71 - 2.68950259726018e+34*cos(theta)**69 + 2.08926261363324e+35*cos(theta)**67 - 1.03341378942799e+36*cos(theta)**65 + 3.65561340477927e+36*cos(theta)**63 - 9.84746617866746e+36*cos(theta)**61 + 2.10033369545005e+37*cos(theta)**59 - 3.64100400497978e+37*cos(theta)**57 + 5.22575754671558e+37*cos(theta)**55 - 6.29379558546037e+37*cos(theta)**53 + 6.42433356797362e+37*cos(theta)**51 - 5.5987869440645e+37*cos(theta)**49 + 4.18840550013986e+37*cos(theta)**47 - 2.69986067122909e+37*cos(theta)**45 + 1.5032969991658e+37*cos(theta)**43 - 7.23987834798251e+36*cos(theta)**41 + 3.01661597832605e+36*cos(theta)**39 - 1.08668567814273e+36*cos(theta)**37 + 3.37877059590598e+35*cos(theta)**35 - 9.04349304797146e+34*cos(theta)**33 + 2.07607144753432e+34*cos(theta)**31 - 4.06815517532009e+33*cos(theta)**29 + 6.76359951343144e+32*cos(theta)**27 - 9.46957889594908e+31*cos(theta)**25 + 1.10625921681648e+31*cos(theta)**23 - 1.06622316896979e+30*cos(theta)**21 + 8.36097331903121e+28*cos(theta)**19 - 5.24285455648822e+27*cos(theta)**17 + 2.57225187475612e+26*cos(theta)**15 - 9.60136675611067e+24*cos(theta)**13 + 2.62774248061976e+23*cos(theta)**11 - 5.01303629670784e+21*cos(theta)**9 + 6.19743498219375e+19*cos(theta)**7 - 4.4312609678607e+17*cos(theta)**5 + 1.49805982686298e+15*cos(theta)**3 - 1510648564903.85*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl77_m7(theta, phi):
    return 2.9859769207394e-13*(1.0 - cos(theta)**2)**3.5*(1.17569684965945e+35*cos(theta)**70 - 1.85575679210953e+36*cos(theta)**68 + 1.39980595113427e+37*cos(theta)**66 - 6.7171896312819e+37*cos(theta)**64 + 2.30303644501094e+38*cos(theta)**62 - 6.00695436898715e+38*cos(theta)**60 + 1.23919688031553e+39*cos(theta)**58 - 2.07537228283847e+39*cos(theta)**56 + 2.87416665069357e+39*cos(theta)**54 - 3.335711660294e+39*cos(theta)**52 + 3.27641011966655e+39*cos(theta)**50 - 2.74340560259161e+39*cos(theta)**48 + 1.96855058506573e+39*cos(theta)**46 - 1.21493730205309e+39*cos(theta)**44 + 6.46417709641296e+38*cos(theta)**42 - 2.96835012267283e+38*cos(theta)**40 + 1.17648023154716e+38*cos(theta)**38 - 4.02073700912811e+37*cos(theta)**36 + 1.18256970856709e+37*cos(theta)**34 - 2.98435270583058e+36*cos(theta)**32 + 6.43582148735639e+35*cos(theta)**30 - 1.17976500084283e+35*cos(theta)**28 + 1.82617186862649e+34*cos(theta)**26 - 2.36739472398727e+33*cos(theta)**24 + 2.54439619867791e+32*cos(theta)**22 - 2.23906865483656e+31*cos(theta)**20 + 1.58858493061593e+30*cos(theta)**18 - 8.91285274602997e+28*cos(theta)**16 + 3.85837781213419e+27*cos(theta)**14 - 1.24817767829439e+26*cos(theta)**12 + 2.89051672868174e+24*cos(theta)**10 - 4.51173266703705e+22*cos(theta)**8 + 4.33820448753563e+20*cos(theta)**6 - 2.21563048393035e+18*cos(theta)**4 + 4.49417948058895e+15*cos(theta)**2 - 1510648564903.85)*cos(7*phi)

#@torch.jit.script
def Yl77_m8(theta, phi):
    return 3.87104271692821e-15*(1.0 - cos(theta)**2)**4*(8.22987794761615e+36*cos(theta)**69 - 1.26191461863448e+38*cos(theta)**67 + 9.23871927748619e+38*cos(theta)**65 - 4.29900136402042e+39*cos(theta)**63 + 1.42788259590678e+40*cos(theta)**61 - 3.60417262139229e+40*cos(theta)**59 + 7.18734190583008e+40*cos(theta)**57 - 1.16220847838955e+41*cos(theta)**55 + 1.55204999137453e+41*cos(theta)**53 - 1.73457006335288e+41*cos(theta)**51 + 1.63820505983327e+41*cos(theta)**49 - 1.31683468924397e+41*cos(theta)**47 + 9.05533269130237e+40*cos(theta)**45 - 5.3457241290336e+40*cos(theta)**43 + 2.71495438049344e+40*cos(theta)**41 - 1.18734004906913e+40*cos(theta)**39 + 4.4706248798792e+39*cos(theta)**37 - 1.44746532328612e+39*cos(theta)**35 + 4.02073700912811e+38*cos(theta)**33 - 9.54992865865786e+37*cos(theta)**31 + 1.93074644620692e+37*cos(theta)**29 - 3.30334200235991e+36*cos(theta)**27 + 4.74804685842887e+35*cos(theta)**25 - 5.68174733756945e+34*cos(theta)**23 + 5.5976716370914e+33*cos(theta)**21 - 4.47813730967312e+32*cos(theta)**19 + 2.85945287510867e+31*cos(theta)**17 - 1.4260564393648e+30*cos(theta)**15 + 5.40172893698786e+28*cos(theta)**13 - 1.49781321395326e+27*cos(theta)**11 + 2.89051672868174e+25*cos(theta)**9 - 3.60938613362964e+23*cos(theta)**7 + 2.60292269252138e+21*cos(theta)**5 - 8.8625219357214e+18*cos(theta)**3 + 8.98835896117789e+15*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl77_m9(theta, phi):
    return 5.02520973916716e-17*(1.0 - cos(theta)**2)**4.5*(5.67861578385515e+38*cos(theta)**68 - 8.454827944851e+39*cos(theta)**66 + 6.00516753036602e+40*cos(theta)**64 - 2.70837085933286e+41*cos(theta)**62 + 8.71008383503137e+41*cos(theta)**60 - 2.12646184662145e+42*cos(theta)**58 + 4.09678488632315e+42*cos(theta)**56 - 6.3921466311425e+42*cos(theta)**54 + 8.22586495428499e+42*cos(theta)**52 - 8.84630732309968e+42*cos(theta)**50 + 8.02720479318304e+42*cos(theta)**48 - 6.18912303944667e+42*cos(theta)**46 + 4.07489971108607e+42*cos(theta)**44 - 2.29866137548445e+42*cos(theta)**42 + 1.11313129600231e+42*cos(theta)**40 - 4.63062619136962e+41*cos(theta)**38 + 1.6541312055553e+41*cos(theta)**36 - 5.06612863150142e+40*cos(theta)**34 + 1.32684321301228e+40*cos(theta)**32 - 2.96047788418394e+39*cos(theta)**30 + 5.59916469400005e+38*cos(theta)**28 - 8.91902340637177e+37*cos(theta)**26 + 1.18701171460722e+37*cos(theta)**24 - 1.30680188764097e+36*cos(theta)**22 + 1.17551104378919e+35*cos(theta)**20 - 8.50846088837892e+33*cos(theta)**18 + 4.86106988768475e+32*cos(theta)**16 - 2.13908465904719e+31*cos(theta)**14 + 7.02224761808422e+29*cos(theta)**12 - 1.64759453534859e+28*cos(theta)**10 + 2.60146505581356e+26*cos(theta)**8 - 2.52657029354075e+24*cos(theta)**6 + 1.30146134626069e+22*cos(theta)**4 - 2.65875658071642e+19*cos(theta)**2 + 8.98835896117789e+15)*cos(9*phi)

#@torch.jit.script
def Yl77_m10(theta, phi):
    return 6.53341296676457e-19*(1.0 - cos(theta)**2)**5*(3.8614587330215e+40*cos(theta)**67 - 5.58018644360166e+41*cos(theta)**65 + 3.84330721943425e+42*cos(theta)**63 - 1.67918993278638e+43*cos(theta)**61 + 5.22605030101882e+43*cos(theta)**59 - 1.23334787104044e+44*cos(theta)**57 + 2.29419953634096e+44*cos(theta)**55 - 3.45175918081695e+44*cos(theta)**53 + 4.2774497762282e+44*cos(theta)**51 - 4.42315366154984e+44*cos(theta)**49 + 3.85305830072786e+44*cos(theta)**47 - 2.84699659814547e+44*cos(theta)**45 + 1.79295587287787e+44*cos(theta)**43 - 9.65437777703468e+43*cos(theta)**41 + 4.45252518400925e+43*cos(theta)**39 - 1.75963795272045e+43*cos(theta)**37 + 5.9548723399991e+42*cos(theta)**35 - 1.72248373471048e+42*cos(theta)**33 + 4.24589828163929e+41*cos(theta)**31 - 8.88143365255181e+40*cos(theta)**29 + 1.56776611432002e+40*cos(theta)**27 - 2.31894608565666e+39*cos(theta)**25 + 2.84882811505732e+38*cos(theta)**23 - 2.87496415281014e+37*cos(theta)**21 + 2.35102208757839e+36*cos(theta)**19 - 1.53152295990821e+35*cos(theta)**17 + 7.77771182029559e+33*cos(theta)**15 - 2.99471852266607e+32*cos(theta)**13 + 8.42669714170106e+30*cos(theta)**11 - 1.64759453534859e+29*cos(theta)**9 + 2.08117204465085e+27*cos(theta)**7 - 1.51594217612445e+25*cos(theta)**5 + 5.20584538504275e+22*cos(theta)**3 - 5.31751316143284e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl77_m11(theta, phi):
    return 8.50866397321199e-21*(1.0 - cos(theta)**2)**5.5*(2.5871773511244e+42*cos(theta)**66 - 3.62712118834108e+43*cos(theta)**64 + 2.42128354824358e+44*cos(theta)**62 - 1.02430585899969e+45*cos(theta)**60 + 3.0833696776011e+45*cos(theta)**58 - 7.03008286493052e+45*cos(theta)**56 + 1.26180974498753e+46*cos(theta)**54 - 1.82943236583298e+46*cos(theta)**52 + 2.18149938587638e+46*cos(theta)**50 - 2.16734529415942e+46*cos(theta)**48 + 1.81093740134209e+46*cos(theta)**46 - 1.28114846916546e+46*cos(theta)**44 + 7.70971025337484e+45*cos(theta)**42 - 3.95829488858422e+45*cos(theta)**40 + 1.73648482176361e+45*cos(theta)**38 - 6.51066042506568e+44*cos(theta)**36 + 2.08420531899968e+44*cos(theta)**34 - 5.68419632454459e+43*cos(theta)**32 + 1.31622846730818e+43*cos(theta)**30 - 2.57561575924003e+42*cos(theta)**28 + 4.23296850866404e+41*cos(theta)**26 - 5.79736521414165e+40*cos(theta)**24 + 6.55230466463184e+39*cos(theta)**22 - 6.0374247209013e+38*cos(theta)**20 + 4.46694196639893e+37*cos(theta)**18 - 2.60358903184395e+36*cos(theta)**16 + 1.16665677304434e+35*cos(theta)**14 - 3.89313407946589e+33*cos(theta)**12 + 9.26936685587117e+31*cos(theta)**10 - 1.48283508181373e+30*cos(theta)**8 + 1.4568204312556e+28*cos(theta)**6 - 7.57971088062225e+25*cos(theta)**4 + 1.56175361551283e+23*cos(theta)**2 - 5.31751316143284e+19)*cos(11*phi)

#@torch.jit.script
def Yl77_m12(theta, phi):
    return 1.11018256242418e-22*(1.0 - cos(theta)**2)**6*(1.70753705174211e+44*cos(theta)**65 - 2.32135756053829e+45*cos(theta)**63 + 1.50119579991102e+46*cos(theta)**61 - 6.14583515399813e+46*cos(theta)**59 + 1.78835441300864e+47*cos(theta)**57 - 3.93684640436109e+47*cos(theta)**55 + 6.81377262293266e+47*cos(theta)**53 - 9.51304830233151e+47*cos(theta)**51 + 1.09074969293819e+48*cos(theta)**49 - 1.04032574119652e+48*cos(theta)**47 + 8.33031204617363e+47*cos(theta)**45 - 5.63705326432802e+47*cos(theta)**43 + 3.23807830641743e+47*cos(theta)**41 - 1.58331795543369e+47*cos(theta)**39 + 6.5986423227017e+46*cos(theta)**37 - 2.34383775302364e+46*cos(theta)**35 + 7.08629808459893e+45*cos(theta)**33 - 1.81894282385427e+45*cos(theta)**31 + 3.94868540192454e+44*cos(theta)**29 - 7.21172412587207e+43*cos(theta)**27 + 1.10057181225265e+43*cos(theta)**25 - 1.391367651394e+42*cos(theta)**23 + 1.441507026219e+41*cos(theta)**21 - 1.20748494418026e+40*cos(theta)**19 + 8.04049553951808e+38*cos(theta)**17 - 4.16574245095032e+37*cos(theta)**15 + 1.63331948226207e+36*cos(theta)**13 - 4.67176089535907e+34*cos(theta)**11 + 9.26936685587117e+32*cos(theta)**9 - 1.18626806545099e+31*cos(theta)**7 + 8.74092258753358e+28*cos(theta)**5 - 3.0318843522489e+26*cos(theta)**3 + 3.12350723102565e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl77_m13(theta, phi):
    return 1.45149808960291e-24*(1.0 - cos(theta)**2)**6.5*(1.10989908363237e+46*cos(theta)**64 - 1.46245526313912e+47*cos(theta)**62 + 9.15729437945722e+47*cos(theta)**60 - 3.6260427408589e+48*cos(theta)**58 + 1.01936201541493e+49*cos(theta)**56 - 2.1652655223986e+49*cos(theta)**54 + 3.61129949015431e+49*cos(theta)**52 - 4.85165463418907e+49*cos(theta)**50 + 5.34467349539713e+49*cos(theta)**48 - 4.88953098362365e+49*cos(theta)**46 + 3.74864042077813e+49*cos(theta)**44 - 2.42393290366105e+49*cos(theta)**42 + 1.32761210563115e+49*cos(theta)**40 - 6.17494002619138e+48*cos(theta)**38 + 2.44149765939963e+48*cos(theta)**36 - 8.20343213558276e+47*cos(theta)**34 + 2.33847836791765e+47*cos(theta)**32 - 5.63872275394824e+46*cos(theta)**30 + 1.14511876655812e+46*cos(theta)**28 - 1.94716551398546e+45*cos(theta)**26 + 2.75142953063163e+44*cos(theta)**24 - 3.20014559820619e+43*cos(theta)**22 + 3.02716475505991e+42*cos(theta)**20 - 2.29422139394249e+41*cos(theta)**18 + 1.36688424171807e+40*cos(theta)**16 - 6.24861367642548e+38*cos(theta)**14 + 2.1233153269407e+37*cos(theta)**12 - 5.13893698489498e+35*cos(theta)**10 + 8.34243017028405e+33*cos(theta)**8 - 8.3038764581569e+31*cos(theta)**6 + 4.37046129376679e+29*cos(theta)**4 - 9.0956530567467e+26*cos(theta)**2 + 3.12350723102565e+23)*cos(13*phi)

#@torch.jit.script
def Yl77_m14(theta, phi):
    return 1.90197929732695e-26*(1.0 - cos(theta)**2)**7*(7.10335413524717e+47*cos(theta)**63 - 9.06722263146256e+48*cos(theta)**61 + 5.49437662767433e+49*cos(theta)**59 - 2.10310478969816e+50*cos(theta)**57 + 5.70842728632358e+50*cos(theta)**55 - 1.16924338209524e+51*cos(theta)**53 + 1.87787573488024e+51*cos(theta)**51 - 2.42582731709454e+51*cos(theta)**49 + 2.56544327779062e+51*cos(theta)**47 - 2.24918425246688e+51*cos(theta)**45 + 1.64940178514238e+51*cos(theta)**43 - 1.01805181953764e+51*cos(theta)**41 + 5.31044842252459e+50*cos(theta)**39 - 2.34647720995273e+50*cos(theta)**37 + 8.78939157383867e+49*cos(theta)**35 - 2.78916692609814e+49*cos(theta)**33 + 7.48313077733647e+48*cos(theta)**31 - 1.69161682618447e+48*cos(theta)**29 + 3.20633254636272e+47*cos(theta)**27 - 5.06263033636219e+46*cos(theta)**25 + 6.60343087351591e+45*cos(theta)**23 - 7.04032031605362e+44*cos(theta)**21 + 6.05432951011982e+43*cos(theta)**19 - 4.12959850909649e+42*cos(theta)**17 + 2.18701478674892e+41*cos(theta)**15 - 8.74805914699567e+39*cos(theta)**13 + 2.54797839232884e+38*cos(theta)**11 - 5.13893698489498e+36*cos(theta)**9 + 6.67394413622724e+34*cos(theta)**7 - 4.98232587489414e+32*cos(theta)**5 + 1.74818451750672e+30*cos(theta)**3 - 1.81913061134934e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl77_m15(theta, phi):
    return 2.49828279445783e-28*(1.0 - cos(theta)**2)**7.5*(4.47511310520571e+49*cos(theta)**62 - 5.53100580519216e+50*cos(theta)**60 + 3.24168221032786e+51*cos(theta)**58 - 1.19876973012795e+52*cos(theta)**56 + 3.13963500747797e+52*cos(theta)**54 - 6.19698992510479e+52*cos(theta)**52 + 9.57716624788922e+52*cos(theta)**50 - 1.18865538537632e+53*cos(theta)**48 + 1.20575834056159e+53*cos(theta)**46 - 1.0121329136101e+53*cos(theta)**44 + 7.09242767611223e+52*cos(theta)**42 - 4.17401246010433e+52*cos(theta)**40 + 2.07107488478459e+52*cos(theta)**38 - 8.68196567682508e+51*cos(theta)**36 + 3.07628705084353e+51*cos(theta)**34 - 9.20425085612385e+50*cos(theta)**32 + 2.3197705409743e+50*cos(theta)**30 - 4.90568879593497e+49*cos(theta)**28 + 8.65709787517935e+48*cos(theta)**26 - 1.26565758409055e+48*cos(theta)**24 + 1.51878910090866e+47*cos(theta)**22 - 1.47846726637126e+46*cos(theta)**20 + 1.15032260692277e+45*cos(theta)**18 - 7.02031746546403e+43*cos(theta)**16 + 3.28052218012338e+42*cos(theta)**14 - 1.13724768910944e+41*cos(theta)**12 + 2.80277623156172e+39*cos(theta)**10 - 4.62504328640548e+37*cos(theta)**8 + 4.67176089535907e+35*cos(theta)**6 - 2.49116293744707e+33*cos(theta)**4 + 5.24455355252015e+30*cos(theta)**2 - 1.81913061134934e+27)*cos(15*phi)

#@torch.jit.script
def Yl77_m16(theta, phi):
    return 3.29006348365385e-30*(1.0 - cos(theta)**2)**8*(2.77457012522754e+51*cos(theta)**61 - 3.3186034831153e+52*cos(theta)**59 + 1.88017568199016e+53*cos(theta)**57 - 6.71311048871653e+53*cos(theta)**55 + 1.6954029040381e+54*cos(theta)**53 - 3.22243476105449e+54*cos(theta)**51 + 4.78858312394461e+54*cos(theta)**49 - 5.70554584980635e+54*cos(theta)**47 + 5.54648836658333e+54*cos(theta)**45 - 4.45338481988442e+54*cos(theta)**43 + 2.97881962396714e+54*cos(theta)**41 - 1.66960498404173e+54*cos(theta)**39 + 7.87008456218144e+53*cos(theta)**37 - 3.12550764365703e+53*cos(theta)**35 + 1.0459375972868e+53*cos(theta)**33 - 2.94536027395963e+52*cos(theta)**31 + 6.95931162292291e+51*cos(theta)**29 - 1.37359286286179e+51*cos(theta)**27 + 2.25084544754663e+50*cos(theta)**25 - 3.03757820181732e+49*cos(theta)**23 + 3.34133602199905e+48*cos(theta)**21 - 2.95693453274252e+47*cos(theta)**19 + 2.07058069246098e+46*cos(theta)**17 - 1.12325079447424e+45*cos(theta)**15 + 4.59273105217273e+43*cos(theta)**13 - 1.36469722693133e+42*cos(theta)**11 + 2.80277623156172e+40*cos(theta)**9 - 3.70003462912438e+38*cos(theta)**7 + 2.80305653721544e+36*cos(theta)**5 - 9.96465174978828e+33*cos(theta)**3 + 1.04891071050403e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl77_m17(theta, phi):
    return 4.34485646348671e-32*(1.0 - cos(theta)**2)**8.5*(1.6924877763888e+53*cos(theta)**60 - 1.95797605503803e+54*cos(theta)**58 + 1.07170013873439e+55*cos(theta)**56 - 3.69221076879409e+55*cos(theta)**54 + 8.98563539140195e+55*cos(theta)**52 - 1.64344172813779e+56*cos(theta)**50 + 2.34640573073286e+56*cos(theta)**48 - 2.68160654940898e+56*cos(theta)**46 + 2.4959197649625e+56*cos(theta)**44 - 1.9149554725503e+56*cos(theta)**42 + 1.22131604582653e+56*cos(theta)**40 - 6.51145943776275e+55*cos(theta)**38 + 2.91193128800713e+55*cos(theta)**36 - 1.09392767527996e+55*cos(theta)**34 + 3.45159407104645e+54*cos(theta)**32 - 9.13061684927486e+53*cos(theta)**30 + 2.01820037064765e+53*cos(theta)**28 - 3.70870072972683e+52*cos(theta)**26 + 5.62711361886658e+51*cos(theta)**24 - 6.98642986417983e+50*cos(theta)**22 + 7.016805646198e+49*cos(theta)**20 - 5.61817561221079e+48*cos(theta)**18 + 3.51998717718366e+47*cos(theta)**16 - 1.68487619171137e+46*cos(theta)**14 + 5.97055036782455e+44*cos(theta)**12 - 1.50116694962446e+43*cos(theta)**10 + 2.52249860840555e+41*cos(theta)**8 - 2.59002424038707e+39*cos(theta)**6 + 1.40152826860772e+37*cos(theta)**4 - 2.98939552493648e+34*cos(theta)**2 + 1.04891071050403e+31)*cos(17*phi)

#@torch.jit.script
def Yl77_m18(theta, phi):
    return 5.75490297269134e-34*(1.0 - cos(theta)**2)**9*(1.01549266583328e+55*cos(theta)**59 - 1.13562611192205e+56*cos(theta)**57 + 6.00152077691258e+56*cos(theta)**55 - 1.99379381514881e+57*cos(theta)**53 + 4.67253040352901e+57*cos(theta)**51 - 8.21720864068896e+57*cos(theta)**49 + 1.12627475075177e+58*cos(theta)**47 - 1.23353901272813e+58*cos(theta)**45 + 1.0982046965835e+58*cos(theta)**43 - 8.04281298471127e+57*cos(theta)**41 + 4.8852641833061e+57*cos(theta)**39 - 2.47435458634985e+57*cos(theta)**37 + 1.04829526368257e+57*cos(theta)**35 - 3.71935409595187e+56*cos(theta)**33 + 1.10451010273486e+56*cos(theta)**31 - 2.73918505478246e+55*cos(theta)**29 + 5.65096103781341e+54*cos(theta)**27 - 9.64262189728977e+53*cos(theta)**25 + 1.35050726852798e+53*cos(theta)**23 - 1.53701457011956e+52*cos(theta)**21 + 1.4033611292396e+51*cos(theta)**19 - 1.01127161019794e+50*cos(theta)**17 + 5.63197948349386e+48*cos(theta)**15 - 2.35882666839591e+47*cos(theta)**13 + 7.16466044138946e+45*cos(theta)**11 - 1.50116694962446e+44*cos(theta)**9 + 2.01799888672444e+42*cos(theta)**7 - 1.55401454423224e+40*cos(theta)**5 + 5.60611307443088e+37*cos(theta)**3 - 5.97879104987297e+34*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl77_m19(theta, phi):
    return 7.6467410510944e-36*(1.0 - cos(theta)**2)**9.5*(5.99140672841636e+56*cos(theta)**58 - 6.47306883795571e+57*cos(theta)**56 + 3.30083642730192e+58*cos(theta)**54 - 1.05671072202887e+59*cos(theta)**52 + 2.3829905057998e+59*cos(theta)**50 - 4.02643223393759e+59*cos(theta)**48 + 5.29349132853333e+59*cos(theta)**46 - 5.55092555727659e+59*cos(theta)**44 + 4.72228019530905e+59*cos(theta)**42 - 3.29755332373162e+59*cos(theta)**40 + 1.90525303148938e+59*cos(theta)**38 - 9.15511196949443e+58*cos(theta)**36 + 3.66903342288899e+58*cos(theta)**34 - 1.22738685166412e+58*cos(theta)**32 + 3.42398131847807e+57*cos(theta)**30 - 7.94363665886913e+56*cos(theta)**28 + 1.52575948020962e+56*cos(theta)**26 - 2.41065547432244e+55*cos(theta)**24 + 3.10616671761435e+54*cos(theta)**22 - 3.22773059725108e+53*cos(theta)**20 + 2.66638614555524e+52*cos(theta)**18 - 1.7191617373365e+51*cos(theta)**16 + 8.44796922524079e+49*cos(theta)**14 - 3.06647466891469e+48*cos(theta)**12 + 7.8811264855284e+46*cos(theta)**10 - 1.35105025466201e+45*cos(theta)**8 + 1.41259922070711e+43*cos(theta)**6 - 7.77007272116121e+40*cos(theta)**4 + 1.68183392232927e+38*cos(theta)**2 - 5.97879104987297e+34)*cos(19*phi)

#@torch.jit.script
def Yl77_m20(theta, phi):
    return 1.01947485751912e-37*(1.0 - cos(theta)**2)**10*(3.47501590248149e+58*cos(theta)**57 - 3.6249185492552e+59*cos(theta)**55 + 1.78245167074304e+60*cos(theta)**53 - 5.49489575455012e+60*cos(theta)**51 + 1.1914952528999e+61*cos(theta)**49 - 1.93268747229004e+61*cos(theta)**47 + 2.43500601112533e+61*cos(theta)**45 - 2.4424072452017e+61*cos(theta)**43 + 1.9833576820298e+61*cos(theta)**41 - 1.31902132949265e+61*cos(theta)**39 + 7.23996151965965e+60*cos(theta)**37 - 3.29584030901799e+60*cos(theta)**35 + 1.24747136378226e+60*cos(theta)**33 - 3.92763792532517e+59*cos(theta)**31 + 1.02719439554342e+59*cos(theta)**29 - 2.22421826448336e+58*cos(theta)**27 + 3.96697464854501e+57*cos(theta)**25 - 5.78557313837386e+56*cos(theta)**23 + 6.83356677875157e+55*cos(theta)**21 - 6.45546119450216e+54*cos(theta)**19 + 4.79949506199943e+53*cos(theta)**17 - 2.7506587797384e+52*cos(theta)**15 + 1.18271569153371e+51*cos(theta)**13 - 3.67976960269763e+49*cos(theta)**11 + 7.8811264855284e+47*cos(theta)**9 - 1.08084020372961e+46*cos(theta)**7 + 8.47559532424264e+43*cos(theta)**5 - 3.10802908846448e+41*cos(theta)**3 + 3.36366784465853e+38*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl77_m21(theta, phi):
    return 1.36403669545239e-39*(1.0 - cos(theta)**2)**10.5*(1.98075906441445e+60*cos(theta)**56 - 1.99370520209036e+61*cos(theta)**54 + 9.44699385493809e+61*cos(theta)**52 - 2.80239683482056e+62*cos(theta)**50 + 5.8383267392095e+62*cos(theta)**48 - 9.0836311197632e+62*cos(theta)**46 + 1.0957527050064e+63*cos(theta)**44 - 1.05023511543673e+63*cos(theta)**42 + 8.13176649632218e+62*cos(theta)**40 - 5.14418318502133e+62*cos(theta)**38 + 2.67878576227407e+62*cos(theta)**36 - 1.1535441081563e+62*cos(theta)**34 + 4.11665550048144e+61*cos(theta)**32 - 1.2175677568508e+61*cos(theta)**30 + 2.97886374707592e+60*cos(theta)**28 - 6.00538931410506e+59*cos(theta)**26 + 9.91743662136253e+58*cos(theta)**24 - 1.33068182182599e+58*cos(theta)**22 + 1.43504902353783e+57*cos(theta)**20 - 1.22653762695541e+56*cos(theta)**18 + 8.15914160539904e+54*cos(theta)**16 - 4.1259881696076e+53*cos(theta)**14 + 1.53753039899382e+52*cos(theta)**12 - 4.04774656296739e+50*cos(theta)**10 + 7.09301383697556e+48*cos(theta)**8 - 7.56588142610727e+46*cos(theta)**6 + 4.23779766212132e+44*cos(theta)**4 - 9.32408726539345e+41*cos(theta)**2 + 3.36366784465853e+38)*cos(21*phi)

#@torch.jit.script
def Yl77_m22(theta, phi):
    return 1.83195348828138e-41*(1.0 - cos(theta)**2)**11*(1.10922507607209e+62*cos(theta)**55 - 1.07660080912879e+63*cos(theta)**53 + 4.91243680456781e+63*cos(theta)**51 - 1.40119841741028e+64*cos(theta)**49 + 2.80239683482056e+64*cos(theta)**47 - 4.17847031509107e+64*cos(theta)**45 + 4.82131190202816e+64*cos(theta)**43 - 4.41098748483427e+64*cos(theta)**41 + 3.25270659852887e+64*cos(theta)**39 - 1.9547896103081e+64*cos(theta)**37 + 9.64362874418665e+63*cos(theta)**35 - 3.92204996773141e+63*cos(theta)**33 + 1.31732976015406e+63*cos(theta)**31 - 3.65270327055241e+62*cos(theta)**29 + 8.34081849181259e+61*cos(theta)**27 - 1.56140122166732e+61*cos(theta)**25 + 2.38018478912701e+60*cos(theta)**23 - 2.92750000801717e+59*cos(theta)**21 + 2.87009804707566e+58*cos(theta)**19 - 2.20776772851974e+57*cos(theta)**17 + 1.30546265686385e+56*cos(theta)**15 - 5.77638343745064e+54*cos(theta)**13 + 1.84503647879259e+53*cos(theta)**11 - 4.04774656296739e+51*cos(theta)**9 + 5.67441106958045e+49*cos(theta)**7 - 4.53952885566436e+47*cos(theta)**5 + 1.69511906484853e+45*cos(theta)**3 - 1.86481745307869e+42*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl77_m23(theta, phi):
    return 2.47020557967673e-43*(1.0 - cos(theta)**2)**11.5*(6.1007379183965e+63*cos(theta)**54 - 5.70598428838261e+64*cos(theta)**52 + 2.50534277032958e+65*cos(theta)**50 - 6.86587224531038e+65*cos(theta)**48 + 1.31712651236566e+66*cos(theta)**46 - 1.88031164179098e+66*cos(theta)**44 + 2.07316411787211e+66*cos(theta)**42 - 1.80850486878205e+66*cos(theta)**40 + 1.26855557342626e+66*cos(theta)**38 - 7.23272155813999e+65*cos(theta)**36 + 3.37527006046533e+65*cos(theta)**34 - 1.29427648935137e+65*cos(theta)**32 + 4.08372225647759e+64*cos(theta)**30 - 1.0592839484602e+64*cos(theta)**28 + 2.2520209927894e+63*cos(theta)**26 - 3.90350305416829e+62*cos(theta)**24 + 5.47442501499211e+61*cos(theta)**22 - 6.14775001683606e+60*cos(theta)**20 + 5.45318628944375e+59*cos(theta)**18 - 3.75320513848356e+58*cos(theta)**16 + 1.95819398529577e+57*cos(theta)**14 - 7.50929846868584e+55*cos(theta)**12 + 2.02954012667185e+54*cos(theta)**10 - 3.64297190667065e+52*cos(theta)**8 + 3.97208774870631e+50*cos(theta)**6 - 2.26976442783218e+48*cos(theta)**4 + 5.08535719454559e+45*cos(theta)**2 - 1.86481745307869e+42)*cos(23*phi)

#@torch.jit.script
def Yl77_m24(theta, phi):
    return 3.34484141235851e-45*(1.0 - cos(theta)**2)**12*(3.29439847593411e+65*cos(theta)**53 - 2.96711182995896e+66*cos(theta)**51 + 1.25267138516479e+67*cos(theta)**49 - 3.29561867774898e+67*cos(theta)**47 + 6.05878195688205e+67*cos(theta)**45 - 8.27337122388032e+67*cos(theta)**43 + 8.70728929506286e+67*cos(theta)**41 - 7.23401947512821e+67*cos(theta)**39 + 4.82051117901979e+67*cos(theta)**37 - 2.6037797609304e+67*cos(theta)**35 + 1.14759182055821e+67*cos(theta)**33 - 4.14168476592437e+66*cos(theta)**31 + 1.22511667694328e+66*cos(theta)**29 - 2.96599505568856e+65*cos(theta)**27 + 5.85525458125244e+64*cos(theta)**25 - 9.3684073300039e+63*cos(theta)**23 + 1.20437350329827e+63*cos(theta)**21 - 1.22955000336721e+62*cos(theta)**19 + 9.81573532099876e+60*cos(theta)**17 - 6.00512822157369e+59*cos(theta)**15 + 2.74147157941408e+58*cos(theta)**13 - 9.01115816242301e+56*cos(theta)**11 + 2.02954012667185e+55*cos(theta)**9 - 2.91437752533652e+53*cos(theta)**7 + 2.38325264922379e+51*cos(theta)**5 - 9.07905771132872e+48*cos(theta)**3 + 1.01707143890912e+46*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl77_m25(theta, phi):
    return 4.54922598211044e-47*(1.0 - cos(theta)**2)**12.5*(1.74603119224508e+67*cos(theta)**52 - 1.51322703327907e+68*cos(theta)**50 + 6.13808978730748e+68*cos(theta)**48 - 1.54894077854202e+69*cos(theta)**46 + 2.72645188059692e+69*cos(theta)**44 - 3.55754962626854e+69*cos(theta)**42 + 3.56998861097577e+69*cos(theta)**40 - 2.8212675953e+69*cos(theta)**38 + 1.78358913623732e+69*cos(theta)**36 - 9.11322916325638e+68*cos(theta)**34 + 3.7870530078421e+68*cos(theta)**32 - 1.28392227743656e+68*cos(theta)**30 + 3.55283836313551e+67*cos(theta)**28 - 8.0081866503591e+66*cos(theta)**26 + 1.46381364531311e+66*cos(theta)**24 - 2.1547336859009e+65*cos(theta)**22 + 2.52918435692636e+64*cos(theta)**20 - 2.3361450063977e+63*cos(theta)**18 + 1.66867500456979e+62*cos(theta)**16 - 9.00769233236054e+60*cos(theta)**14 + 3.5639130532383e+59*cos(theta)**12 - 9.91227397866531e+57*cos(theta)**10 + 1.82658611400466e+56*cos(theta)**8 - 2.04006426773556e+54*cos(theta)**6 + 1.19162632461189e+52*cos(theta)**4 - 2.72371731339862e+49*cos(theta)**2 + 1.01707143890912e+46)*cos(25*phi)

#@torch.jit.script
def Yl77_m26(theta, phi):
    return 6.2160890397853e-49*(1.0 - cos(theta)**2)**13*(9.0793621996744e+68*cos(theta)**51 - 7.56613516639534e+69*cos(theta)**49 + 2.94628309790759e+70*cos(theta)**47 - 7.12512758129329e+70*cos(theta)**45 + 1.19963882746265e+71*cos(theta)**43 - 1.49417084303279e+71*cos(theta)**41 + 1.42799544439031e+71*cos(theta)**39 - 1.072081686214e+71*cos(theta)**37 + 6.42092089045436e+70*cos(theta)**35 - 3.09849791550717e+70*cos(theta)**33 + 1.21185696250947e+70*cos(theta)**31 - 3.85176683230967e+69*cos(theta)**29 + 9.94794741677942e+68*cos(theta)**27 - 2.08212852909337e+68*cos(theta)**25 + 3.51315274875146e+67*cos(theta)**23 - 4.74041410898197e+66*cos(theta)**21 + 5.05836871385271e+65*cos(theta)**19 - 4.20506101151587e+64*cos(theta)**17 + 2.66988000731166e+63*cos(theta)**15 - 1.26107692653047e+62*cos(theta)**13 + 4.27669566388596e+60*cos(theta)**11 - 9.91227397866531e+58*cos(theta)**9 + 1.46126889120373e+57*cos(theta)**7 - 1.22403856064134e+55*cos(theta)**5 + 4.76650529844758e+52*cos(theta)**3 - 5.44743462679723e+49*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl77_m27(theta, phi):
    return 8.53523472478644e-51*(1.0 - cos(theta)**2)**13.5*(4.63047472183395e+70*cos(theta)**50 - 3.70740623153372e+71*cos(theta)**48 + 1.38475305601657e+72*cos(theta)**46 - 3.20630741158198e+72*cos(theta)**44 + 5.15844695808938e+72*cos(theta)**42 - 6.12610045643442e+72*cos(theta)**40 + 5.5691822331222e+72*cos(theta)**38 - 3.9667022389918e+72*cos(theta)**36 + 2.24732231165902e+72*cos(theta)**34 - 1.02250431211737e+72*cos(theta)**32 + 3.75675658377936e+71*cos(theta)**30 - 1.1170123813698e+71*cos(theta)**28 + 2.68594580253044e+70*cos(theta)**26 - 5.20532132273342e+69*cos(theta)**24 + 8.08025132212836e+68*cos(theta)**22 - 9.95486962886214e+67*cos(theta)**20 + 9.61090055632016e+66*cos(theta)**18 - 7.14860371957698e+65*cos(theta)**16 + 4.00482001096749e+64*cos(theta)**14 - 1.63940000448962e+63*cos(theta)**12 + 4.70436523027455e+61*cos(theta)**10 - 8.92104658079878e+59*cos(theta)**8 + 1.02288822384261e+58*cos(theta)**6 - 6.12019280320669e+55*cos(theta)**4 + 1.42995158953427e+53*cos(theta)**2 - 5.44743462679723e+49)*cos(27*phi)

#@torch.jit.script
def Yl77_m28(theta, phi):
    return 1.17797430489561e-52*(1.0 - cos(theta)**2)**14*(2.31523736091697e+72*cos(theta)**49 - 1.77955499113618e+73*cos(theta)**47 + 6.36986405767621e+73*cos(theta)**45 - 1.41077526109607e+74*cos(theta)**43 + 2.16654772239754e+74*cos(theta)**41 - 2.45044018257377e+74*cos(theta)**39 + 2.11628924858644e+74*cos(theta)**37 - 1.42801280603705e+74*cos(theta)**35 + 7.64089585964068e+73*cos(theta)**33 - 3.27201379877557e+73*cos(theta)**31 + 1.12702697513381e+73*cos(theta)**29 - 3.12763466783545e+72*cos(theta)**27 + 6.98345908657915e+71*cos(theta)**25 - 1.24927711745602e+71*cos(theta)**23 + 1.77765529086824e+70*cos(theta)**21 - 1.99097392577243e+69*cos(theta)**19 + 1.72996210013763e+68*cos(theta)**17 - 1.14377659513232e+67*cos(theta)**15 + 5.60674801535449e+65*cos(theta)**13 - 1.96728000538754e+64*cos(theta)**11 + 4.70436523027455e+62*cos(theta)**9 - 7.13683726463902e+60*cos(theta)**7 + 6.13732934305567e+58*cos(theta)**5 - 2.44807712128268e+56*cos(theta)**3 + 2.85990317906855e+53*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl77_m29(theta, phi):
    return 1.63449969795033e-54*(1.0 - cos(theta)**2)**14.5*(1.13446630684932e+74*cos(theta)**48 - 8.36390845834006e+74*cos(theta)**46 + 2.86643882595429e+75*cos(theta)**44 - 6.06633362271311e+75*cos(theta)**42 + 8.88284566182991e+75*cos(theta)**40 - 9.5567167120377e+75*cos(theta)**38 + 7.83027021976982e+75*cos(theta)**36 - 4.99804482112967e+75*cos(theta)**34 + 2.52149563368143e+75*cos(theta)**32 - 1.01432427762043e+75*cos(theta)**30 + 3.26837822788804e+74*cos(theta)**28 - 8.44461360315571e+73*cos(theta)**26 + 1.74586477164479e+73*cos(theta)**24 - 2.87333737014885e+72*cos(theta)**22 + 3.7330761108233e+71*cos(theta)**20 - 3.78285045896761e+70*cos(theta)**18 + 2.94093557023397e+69*cos(theta)**16 - 1.71566489269847e+68*cos(theta)**14 + 7.28877241996084e+66*cos(theta)**12 - 2.16400800592629e+65*cos(theta)**10 + 4.2339287072471e+63*cos(theta)**8 - 4.99578608524731e+61*cos(theta)**6 + 3.06866467152783e+59*cos(theta)**4 - 7.34423136384803e+56*cos(theta)**2 + 2.85990317906855e+53)*cos(29*phi)

#@torch.jit.script
def Yl77_m30(theta, phi):
    return 2.28072192287561e-56*(1.0 - cos(theta)**2)**15*(5.44543827287672e+75*cos(theta)**47 - 3.84739789083643e+76*cos(theta)**45 + 1.26123308341989e+77*cos(theta)**43 - 2.54786012153951e+77*cos(theta)**41 + 3.55313826473197e+77*cos(theta)**39 - 3.63155235057433e+77*cos(theta)**37 + 2.81889727911713e+77*cos(theta)**35 - 1.69933523918409e+77*cos(theta)**33 + 8.06878602778056e+76*cos(theta)**31 - 3.04297283286128e+76*cos(theta)**29 + 9.15145903808652e+75*cos(theta)**27 - 2.19559953682049e+75*cos(theta)**25 + 4.19007545194749e+74*cos(theta)**23 - 6.32134221432746e+73*cos(theta)**21 + 7.46615222164661e+72*cos(theta)**19 - 6.80913082614171e+71*cos(theta)**17 + 4.70549691237435e+70*cos(theta)**15 - 2.40193084977786e+69*cos(theta)**13 + 8.74652690395301e+67*cos(theta)**11 - 2.16400800592629e+66*cos(theta)**9 + 3.38714296579768e+64*cos(theta)**7 - 2.99747165114839e+62*cos(theta)**5 + 1.22746586861113e+60*cos(theta)**3 - 1.46884627276961e+57*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl77_m31(theta, phi):
    return 3.20119058128037e-58*(1.0 - cos(theta)**2)**15.5*(2.55935598825206e+77*cos(theta)**46 - 1.73132905087639e+78*cos(theta)**44 + 5.42330225870552e+78*cos(theta)**42 - 1.0446226498312e+79*cos(theta)**40 + 1.38572392324547e+79*cos(theta)**38 - 1.3436743697125e+79*cos(theta)**36 + 9.86614047690997e+78*cos(theta)**34 - 5.60780628930749e+78*cos(theta)**32 + 2.50132366861197e+78*cos(theta)**30 - 8.82462121529772e+77*cos(theta)**28 + 2.47089394028336e+77*cos(theta)**26 - 5.48899884205121e+76*cos(theta)**24 + 9.63717353947923e+75*cos(theta)**22 - 1.32748186500877e+75*cos(theta)**20 + 1.41856892211286e+74*cos(theta)**18 - 1.15755224044409e+73*cos(theta)**16 + 7.05824536856152e+71*cos(theta)**14 - 3.12251010471122e+70*cos(theta)**12 + 9.62117959434831e+68*cos(theta)**10 - 1.94760720533367e+67*cos(theta)**8 + 2.37100007605838e+65*cos(theta)**6 - 1.49873582557419e+63*cos(theta)**4 + 3.6823976058334e+60*cos(theta)**2 - 1.46884627276961e+57)*cos(31*phi)

#@torch.jit.script
def Yl77_m32(theta, phi):
    return 4.52084238068851e-60*(1.0 - cos(theta)**2)**16*(1.17730375459595e+79*cos(theta)**45 - 7.61784782385613e+79*cos(theta)**43 + 2.27778694865632e+80*cos(theta)**41 - 4.17849059932479e+80*cos(theta)**39 + 5.26575090833277e+80*cos(theta)**37 - 4.837227730965e+80*cos(theta)**35 + 3.35448776214939e+80*cos(theta)**33 - 1.7944980125784e+80*cos(theta)**31 + 7.50397100583592e+79*cos(theta)**29 - 2.47089394028336e+79*cos(theta)**27 + 6.42432424473674e+78*cos(theta)**25 - 1.31735972209229e+78*cos(theta)**23 + 2.12017817868543e+77*cos(theta)**21 - 2.65496373001753e+76*cos(theta)**19 + 2.55342405980314e+75*cos(theta)**17 - 1.85208358471054e+74*cos(theta)**15 + 9.88154351598613e+72*cos(theta)**13 - 3.74701212565347e+71*cos(theta)**11 + 9.62117959434831e+69*cos(theta)**9 - 1.55808576426693e+68*cos(theta)**7 + 1.42260004563503e+66*cos(theta)**5 - 5.99494330229678e+63*cos(theta)**3 + 7.3647952116668e+60*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl77_m33(theta, phi):
    return 6.42564556062396e-62*(1.0 - cos(theta)**2)**16.5*(5.29786689568176e+80*cos(theta)**44 - 3.27567456425813e+81*cos(theta)**42 + 9.33892648949091e+81*cos(theta)**40 - 1.62961133373667e+82*cos(theta)**38 + 1.94832783608313e+82*cos(theta)**36 - 1.69302970583775e+82*cos(theta)**34 + 1.1069809615093e+82*cos(theta)**32 - 5.56294383899303e+81*cos(theta)**30 + 2.17615159169242e+81*cos(theta)**28 - 6.67141363876508e+80*cos(theta)**26 + 1.60608106118418e+80*cos(theta)**24 - 3.02992736081227e+79*cos(theta)**22 + 4.4523741752394e+78*cos(theta)**20 - 5.04443108703331e+77*cos(theta)**18 + 4.34082090166534e+76*cos(theta)**16 - 2.77812537706582e+75*cos(theta)**14 + 1.2846006570782e+74*cos(theta)**12 - 4.12171333821881e+72*cos(theta)**10 + 8.65906163491348e+70*cos(theta)**8 - 1.09066003498685e+69*cos(theta)**6 + 7.11300022817513e+66*cos(theta)**4 - 1.79848299068903e+64*cos(theta)**2 + 7.3647952116668e+60)*cos(33*phi)

#@torch.jit.script
def Yl77_m34(theta, phi):
    return 9.19451738929479e-64*(1.0 - cos(theta)**2)**17*(2.33106143409998e+82*cos(theta)**43 - 1.37578331698842e+83*cos(theta)**41 + 3.73557059579636e+83*cos(theta)**39 - 6.19252306819934e+83*cos(theta)**37 + 7.01398020989925e+83*cos(theta)**35 - 5.75630099984835e+83*cos(theta)**33 + 3.54233907682976e+83*cos(theta)**31 - 1.66888315169791e+83*cos(theta)**29 + 6.09322445673877e+82*cos(theta)**27 - 1.73456754607892e+82*cos(theta)**25 + 3.85459454684204e+81*cos(theta)**23 - 6.66584019378699e+80*cos(theta)**21 + 8.90474835047881e+79*cos(theta)**19 - 9.07997595665996e+78*cos(theta)**17 + 6.94531344266454e+77*cos(theta)**15 - 3.88937552789214e+76*cos(theta)**13 + 1.54152078849384e+75*cos(theta)**11 - 4.12171333821881e+73*cos(theta)**9 + 6.92724930793078e+71*cos(theta)**7 - 6.54396020992112e+69*cos(theta)**5 + 2.84520009127005e+67*cos(theta)**3 - 3.59696598137807e+64*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl77_m35(theta, phi):
    return 1.32490792965112e-65*(1.0 - cos(theta)**2)**17.5*(1.00235641666299e+84*cos(theta)**42 - 5.64071159965251e+84*cos(theta)**40 + 1.45687253236058e+85*cos(theta)**38 - 2.29123353523376e+85*cos(theta)**36 + 2.45489307346474e+85*cos(theta)**34 - 1.89957932994996e+85*cos(theta)**32 + 1.09812511381722e+85*cos(theta)**30 - 4.83976113992394e+84*cos(theta)**28 + 1.64517060331947e+84*cos(theta)**26 - 4.3364188651973e+83*cos(theta)**24 + 8.8655674577367e+82*cos(theta)**22 - 1.39982644069527e+82*cos(theta)**20 + 1.69190218659097e+81*cos(theta)**18 - 1.54359591263219e+80*cos(theta)**16 + 1.04179701639968e+79*cos(theta)**14 - 5.05618818625978e+77*cos(theta)**12 + 1.69567286734322e+76*cos(theta)**10 - 3.70954200439693e+74*cos(theta)**8 + 4.84907451555155e+72*cos(theta)**6 - 3.27198010496056e+70*cos(theta)**4 + 8.53560027381015e+67*cos(theta)**2 - 3.59696598137807e+64)*cos(35*phi)

#@torch.jit.script
def Yl77_m36(theta, phi):
    return 1.92318840717684e-67*(1.0 - cos(theta)**2)**18*(4.20989694998455e+85*cos(theta)**41 - 2.256284639861e+86*cos(theta)**39 + 5.53611562297021e+86*cos(theta)**37 - 8.24844072684152e+86*cos(theta)**35 + 8.34663644978011e+86*cos(theta)**33 - 6.07865385583986e+86*cos(theta)**31 + 3.29437534145167e+86*cos(theta)**29 - 1.3551331191787e+86*cos(theta)**27 + 4.27744356863062e+85*cos(theta)**25 - 1.04074052764735e+85*cos(theta)**23 + 1.95042484070207e+84*cos(theta)**21 - 2.79965288139054e+83*cos(theta)**19 + 3.04542393586375e+82*cos(theta)**17 - 2.46975346021151e+81*cos(theta)**15 + 1.45851582295955e+80*cos(theta)**13 - 6.06742582351174e+78*cos(theta)**11 + 1.69567286734322e+77*cos(theta)**9 - 2.96763360351755e+75*cos(theta)**7 + 2.90944470933093e+73*cos(theta)**5 - 1.30879204198422e+71*cos(theta)**3 + 1.70712005476203e+68*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl77_m37(theta, phi):
    return 2.81305017421055e-69*(1.0 - cos(theta)**2)**18.5*(1.72605774949367e+87*cos(theta)**40 - 8.79951009545791e+87*cos(theta)**38 + 2.04836278049898e+88*cos(theta)**36 - 2.88695425439453e+88*cos(theta)**34 + 2.75439002842744e+88*cos(theta)**32 - 1.88438269531036e+88*cos(theta)**30 + 9.55368849020985e+87*cos(theta)**28 - 3.6588594217825e+87*cos(theta)**26 + 1.06936089215765e+87*cos(theta)**24 - 2.39370321358891e+86*cos(theta)**22 + 4.09589216547436e+85*cos(theta)**20 - 5.31934047464202e+84*cos(theta)**18 + 5.17722069096838e+83*cos(theta)**16 - 3.70463019031727e+82*cos(theta)**14 + 1.89607056984742e+81*cos(theta)**12 - 6.67416840586291e+79*cos(theta)**10 + 1.5261055806089e+78*cos(theta)**8 - 2.07734352246228e+76*cos(theta)**6 + 1.45472235466546e+74*cos(theta)**4 - 3.92637612595267e+71*cos(theta)**2 + 1.70712005476203e+68)*cos(37*phi)

#@torch.jit.script
def Yl77_m38(theta, phi):
    return 4.14761620447478e-71*(1.0 - cos(theta)**2)**19*(6.90423099797467e+88*cos(theta)**39 - 3.34381383627401e+89*cos(theta)**37 + 7.37410600979632e+89*cos(theta)**35 - 9.81564446494141e+89*cos(theta)**33 + 8.8140480909678e+89*cos(theta)**31 - 5.65314808593107e+89*cos(theta)**29 + 2.67503277725876e+89*cos(theta)**27 - 9.51303449663449e+88*cos(theta)**25 + 2.56646614117837e+88*cos(theta)**23 - 5.2661470698956e+87*cos(theta)**21 + 8.19178433094871e+86*cos(theta)**19 - 9.57481285435564e+85*cos(theta)**17 + 8.2835531055494e+84*cos(theta)**15 - 5.18648226644417e+83*cos(theta)**13 + 2.2752846838169e+82*cos(theta)**11 - 6.67416840586292e+80*cos(theta)**9 + 1.22088446448712e+79*cos(theta)**7 - 1.24640611347737e+77*cos(theta)**5 + 5.81888941866186e+74*cos(theta)**3 - 7.85275225190534e+71*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl77_m39(theta, phi):
    return 6.16647910788834e-73*(1.0 - cos(theta)**2)**19.5*(2.69265008921012e+90*cos(theta)**38 - 1.23721111942138e+91*cos(theta)**36 + 2.58093710342871e+91*cos(theta)**34 - 3.23916267343067e+91*cos(theta)**32 + 2.73235490820002e+91*cos(theta)**30 - 1.63941294492001e+91*cos(theta)**28 + 7.22258849859865e+90*cos(theta)**26 - 2.37825862415862e+90*cos(theta)**24 + 5.90287212471025e+89*cos(theta)**22 - 1.10589088467808e+89*cos(theta)**20 + 1.55643902288026e+88*cos(theta)**18 - 1.62771818524046e+87*cos(theta)**16 + 1.24253296583241e+86*cos(theta)**14 - 6.74242694637742e+84*cos(theta)**12 + 2.50281315219859e+83*cos(theta)**10 - 6.00675156527662e+81*cos(theta)**8 + 8.54619125140983e+79*cos(theta)**6 - 6.23203056738685e+77*cos(theta)**4 + 1.74566682559856e+75*cos(theta)**2 - 7.85275225190534e+71)*cos(39*phi)

#@torch.jit.script
def Yl77_m40(theta, phi):
    return 9.24810038585174e-75*(1.0 - cos(theta)**2)**20*(1.02320703389985e+92*cos(theta)**37 - 4.45396002991698e+92*cos(theta)**35 + 8.77518615165762e+92*cos(theta)**33 - 1.03653205549781e+93*cos(theta)**31 + 8.19706472460005e+92*cos(theta)**29 - 4.59035624577603e+92*cos(theta)**27 + 1.87787300963565e+92*cos(theta)**25 - 5.70782069798069e+91*cos(theta)**23 + 1.29863186743625e+91*cos(theta)**21 - 2.21178176935615e+90*cos(theta)**19 + 2.80159024118446e+89*cos(theta)**17 - 2.60434909638473e+88*cos(theta)**15 + 1.73954615216538e+87*cos(theta)**13 - 8.09091233565291e+85*cos(theta)**11 + 2.50281315219859e+84*cos(theta)**9 - 4.8054012522213e+82*cos(theta)**7 + 5.1277147508459e+80*cos(theta)**5 - 2.49281222695474e+78*cos(theta)**3 + 3.49133365119711e+75*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl77_m41(theta, phi):
    return 1.39962170750292e-76*(1.0 - cos(theta)**2)**20.5*(3.78586602542943e+93*cos(theta)**36 - 1.55888601047094e+94*cos(theta)**34 + 2.89581143004702e+94*cos(theta)**32 - 3.21324937204322e+94*cos(theta)**30 + 2.37714877013401e+94*cos(theta)**28 - 1.23939618635953e+94*cos(theta)**26 + 4.69468252408912e+93*cos(theta)**24 - 1.31279876053556e+93*cos(theta)**22 + 2.72712692161614e+92*cos(theta)**20 - 4.20238536177669e+91*cos(theta)**18 + 4.76270341001358e+90*cos(theta)**16 - 3.9065236445771e+89*cos(theta)**14 + 2.26140999781499e+88*cos(theta)**12 - 8.9000035692182e+86*cos(theta)**10 + 2.25253183697873e+85*cos(theta)**8 - 3.36378087655491e+83*cos(theta)**6 + 2.56385737542295e+81*cos(theta)**4 - 7.47843668086422e+78*cos(theta)**2 + 3.49133365119711e+75)*cos(41*phi)

#@torch.jit.script
def Yl77_m42(theta, phi):
    return 2.13838519279332e-78*(1.0 - cos(theta)**2)**21*(1.3629117691546e+95*cos(theta)**35 - 5.3002124356012e+95*cos(theta)**33 + 9.26659657615045e+95*cos(theta)**31 - 9.63974811612966e+95*cos(theta)**29 + 6.65601655637524e+95*cos(theta)**27 - 3.22243008453477e+95*cos(theta)**25 + 1.12672380578139e+95*cos(theta)**23 - 2.88815727317823e+94*cos(theta)**21 + 5.45425384323227e+93*cos(theta)**19 - 7.56429365119804e+92*cos(theta)**17 + 7.62032545602173e+91*cos(theta)**15 - 5.46913310240794e+90*cos(theta)**13 + 2.71369199737799e+89*cos(theta)**11 - 8.9000035692182e+87*cos(theta)**9 + 1.80202546958299e+86*cos(theta)**7 - 2.01826852593295e+84*cos(theta)**5 + 1.02554295016918e+82*cos(theta)**3 - 1.49568733617284e+79*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl77_m43(theta, phi):
    return 3.29959998757342e-80*(1.0 - cos(theta)**2)**21.5*(4.77019119204108e+96*cos(theta)**34 - 1.7490701037484e+97*cos(theta)**32 + 2.87264493860664e+97*cos(theta)**30 - 2.7955269536776e+97*cos(theta)**28 + 1.79712447022132e+97*cos(theta)**26 - 8.05607521133693e+96*cos(theta)**24 + 2.59146475329719e+96*cos(theta)**22 - 6.06513027367428e+95*cos(theta)**20 + 1.03630823021413e+95*cos(theta)**18 - 1.28592992070367e+94*cos(theta)**16 + 1.14304881840326e+93*cos(theta)**14 - 7.10987303313032e+91*cos(theta)**12 + 2.98506119711578e+90*cos(theta)**10 - 8.01000321229638e+88*cos(theta)**8 + 1.26141782870809e+87*cos(theta)**6 - 1.00913426296647e+85*cos(theta)**4 + 3.07662885050754e+82*cos(theta)**2 - 1.49568733617284e+79)*cos(43*phi)

#@torch.jit.script
def Yl77_m44(theta, phi):
    return 5.14433390368256e-82*(1.0 - cos(theta)**2)**22*(1.62186500529397e+98*cos(theta)**33 - 5.59702433199487e+98*cos(theta)**31 + 8.61793481581992e+98*cos(theta)**29 - 7.82747547029728e+98*cos(theta)**27 + 4.67252362257542e+98*cos(theta)**25 - 1.93345805072086e+98*cos(theta)**23 + 5.70122245725383e+97*cos(theta)**21 - 1.21302605473486e+97*cos(theta)**19 + 1.86535481438544e+96*cos(theta)**17 - 2.05748787312587e+95*cos(theta)**15 + 1.60026834576456e+94*cos(theta)**13 - 8.53184763975639e+92*cos(theta)**11 + 2.98506119711578e+91*cos(theta)**9 - 6.4080025698371e+89*cos(theta)**7 + 7.56850697224855e+87*cos(theta)**5 - 4.03653705186589e+85*cos(theta)**3 + 6.15325770101508e+82*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl77_m45(theta, phi):
    return 8.10759907270583e-84*(1.0 - cos(theta)**2)**22.5*(5.35215451747009e+99*cos(theta)**32 - 1.73507754291841e+100*cos(theta)**30 + 2.49920109658778e+100*cos(theta)**28 - 2.11341837698027e+100*cos(theta)**26 + 1.16813090564385e+100*cos(theta)**24 - 4.44695351665799e+99*cos(theta)**22 + 1.1972567160233e+99*cos(theta)**20 - 2.30474950399623e+98*cos(theta)**18 + 3.17110318445524e+97*cos(theta)**16 - 3.0862318096888e+96*cos(theta)**14 + 2.08034884949393e+95*cos(theta)**12 - 9.38503240373202e+93*cos(theta)**10 + 2.68655507740421e+92*cos(theta)**8 - 4.48560179888597e+90*cos(theta)**6 + 3.78425348612427e+88*cos(theta)**4 - 1.21096111555977e+86*cos(theta)**2 + 6.15325770101508e+82)*cos(45*phi)

#@torch.jit.script
def Yl77_m46(theta, phi):
    return 1.29230409190279e-85*(1.0 - cos(theta)**2)**23*(1.71268944559043e+101*cos(theta)**31 - 5.20523262875523e+101*cos(theta)**29 + 6.99776307044577e+101*cos(theta)**27 - 5.49488778014869e+101*cos(theta)**25 + 2.80351417354525e+101*cos(theta)**23 - 9.78329773664757e+100*cos(theta)**21 + 2.39451343204661e+100*cos(theta)**19 - 4.14854910719321e+99*cos(theta)**17 + 5.07376509512839e+98*cos(theta)**15 - 4.32072453356432e+97*cos(theta)**13 + 2.49641861939272e+96*cos(theta)**11 - 9.38503240373202e+94*cos(theta)**9 + 2.14924406192336e+93*cos(theta)**7 - 2.69136107933158e+91*cos(theta)**5 + 1.51370139444971e+89*cos(theta)**3 - 2.42192223111953e+86*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl77_m47(theta, phi):
    return 2.08436143855288e-87*(1.0 - cos(theta)**2)**23.5*(5.30933728133033e+102*cos(theta)**30 - 1.50951746233902e+103*cos(theta)**28 + 1.88939602902036e+103*cos(theta)**26 - 1.37372194503717e+103*cos(theta)**24 + 6.44808259915408e+102*cos(theta)**22 - 2.05449252469599e+102*cos(theta)**20 + 4.54957552088855e+101*cos(theta)**18 - 7.05253348222846e+100*cos(theta)**16 + 7.61064764269258e+99*cos(theta)**14 - 5.61694189363362e+98*cos(theta)**12 + 2.74606048133199e+97*cos(theta)**10 - 8.44652916335882e+95*cos(theta)**8 + 1.50447084334635e+94*cos(theta)**6 - 1.34568053966579e+92*cos(theta)**4 + 4.54110418334913e+89*cos(theta)**2 - 2.42192223111953e+86)*cos(47*phi)

#@torch.jit.script
def Yl77_m48(theta, phi):
    return 3.40374797599205e-89*(1.0 - cos(theta)**2)**24*(1.5928011843991e+104*cos(theta)**29 - 4.22664889454925e+104*cos(theta)**27 + 4.91242967545293e+104*cos(theta)**25 - 3.29693266808922e+104*cos(theta)**23 + 1.4185781718139e+104*cos(theta)**21 - 4.10898504939198e+103*cos(theta)**19 + 8.1892359375994e+102*cos(theta)**17 - 1.12840535715655e+102*cos(theta)**15 + 1.06549066997696e+101*cos(theta)**13 - 6.74033027236034e+99*cos(theta)**11 + 2.74606048133199e+98*cos(theta)**9 - 6.75722333068706e+96*cos(theta)**7 + 9.02682506007813e+94*cos(theta)**5 - 5.38272215866317e+92*cos(theta)**3 + 9.08220836669826e+89*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl77_m49(theta, phi):
    return 5.63083919001166e-91*(1.0 - cos(theta)**2)**24.5*(4.61912343475739e+105*cos(theta)**28 - 1.1411952015283e+106*cos(theta)**26 + 1.22810741886323e+106*cos(theta)**24 - 7.5829451366052e+105*cos(theta)**22 + 2.97901416080918e+105*cos(theta)**20 - 7.80707159384476e+104*cos(theta)**18 + 1.3921701093919e+104*cos(theta)**16 - 1.69260803573483e+103*cos(theta)**14 + 1.38513787097005e+102*cos(theta)**12 - 7.41436329959637e+100*cos(theta)**10 + 2.47145443319879e+99*cos(theta)**8 - 4.73005633148094e+97*cos(theta)**6 + 4.51341253003906e+95*cos(theta)**4 - 1.61481664759895e+93*cos(theta)**2 + 9.08220836669826e+89)*cos(49*phi)

#@torch.jit.script
def Yl77_m50(theta, phi):
    return 9.4426142544775e-93*(1.0 - cos(theta)**2)**25*(1.29335456173207e+107*cos(theta)**27 - 2.96710752397357e+107*cos(theta)**25 + 2.94745780527176e+107*cos(theta)**23 - 1.66824793005314e+107*cos(theta)**21 + 5.95802832161837e+106*cos(theta)**19 - 1.40527288689206e+106*cos(theta)**17 + 2.22747217502704e+105*cos(theta)**15 - 2.36965125002876e+104*cos(theta)**13 + 1.66216544516406e+103*cos(theta)**11 - 7.41436329959637e+101*cos(theta)**9 + 1.97716354655903e+100*cos(theta)**7 - 2.83803379888856e+98*cos(theta)**5 + 1.80536501201563e+96*cos(theta)**3 - 3.2296332951979e+93*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl77_m51(theta, phi):
    return 1.60622130287506e-94*(1.0 - cos(theta)**2)**25.5*(3.49205731667659e+108*cos(theta)**26 - 7.41776880993393e+108*cos(theta)**24 + 6.77915295212505e+108*cos(theta)**22 - 3.5033206531116e+108*cos(theta)**20 + 1.13202538110749e+108*cos(theta)**18 - 2.3889639077165e+107*cos(theta)**16 + 3.34120826254055e+106*cos(theta)**14 - 3.08054662503739e+105*cos(theta)**12 + 1.82838198968047e+104*cos(theta)**10 - 6.67292696963674e+102*cos(theta)**8 + 1.38401448259132e+101*cos(theta)**6 - 1.41901689944428e+99*cos(theta)**4 + 5.41609503604688e+96*cos(theta)**2 - 3.2296332951979e+93)*cos(51*phi)

#@torch.jit.script
def Yl77_m52(theta, phi):
    return 2.77347242564173e-96*(1.0 - cos(theta)**2)**26*(9.07934902335913e+109*cos(theta)**25 - 1.78026451438414e+110*cos(theta)**23 + 1.49141364946751e+110*cos(theta)**21 - 7.0066413062232e+109*cos(theta)**19 + 2.03764568599348e+109*cos(theta)**17 - 3.82234225234639e+108*cos(theta)**15 + 4.67769156755678e+107*cos(theta)**13 - 3.69665595004487e+106*cos(theta)**11 + 1.82838198968047e+105*cos(theta)**9 - 5.33834157570939e+103*cos(theta)**7 + 8.30408689554794e+101*cos(theta)**5 - 5.67606759777713e+99*cos(theta)**3 + 1.08321900720938e+97*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl77_m53(theta, phi):
    return 4.864992464472e-98*(1.0 - cos(theta)**2)**26.5*(2.26983725583978e+111*cos(theta)**24 - 4.09460838308353e+111*cos(theta)**22 + 3.13196866388177e+111*cos(theta)**20 - 1.33126184818241e+111*cos(theta)**18 + 3.46399766618892e+110*cos(theta)**16 - 5.73351337851959e+109*cos(theta)**14 + 6.08099903782381e+108*cos(theta)**12 - 4.06632154504936e+107*cos(theta)**10 + 1.64554379071242e+106*cos(theta)**8 - 3.73683910299657e+104*cos(theta)**6 + 4.15204344777397e+102*cos(theta)**4 - 1.70282027933314e+100*cos(theta)**2 + 1.08321900720938e+97)*cos(53*phi)

#@torch.jit.script
def Yl77_m54(theta, phi):
    return 8.67642672184648e-100*(1.0 - cos(theta)**2)**27*(5.44760941401548e+112*cos(theta)**23 - 9.00813844278376e+112*cos(theta)**21 + 6.26393732776354e+112*cos(theta)**19 - 2.39627132672834e+112*cos(theta)**17 + 5.54239626590227e+111*cos(theta)**15 - 8.02691872992743e+110*cos(theta)**13 + 7.29719884538857e+109*cos(theta)**11 - 4.06632154504936e+108*cos(theta)**9 + 1.31643503256994e+107*cos(theta)**7 - 2.24210346179794e+105*cos(theta)**5 + 1.66081737910959e+103*cos(theta)**3 - 3.40564055866628e+100*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl77_m55(theta, phi):
    return 1.57467168985028e-101*(1.0 - cos(theta)**2)**27.5*(1.25295016522356e+114*cos(theta)**22 - 1.89170907298459e+114*cos(theta)**20 + 1.19014809227507e+114*cos(theta)**18 - 4.07366125543817e+113*cos(theta)**16 + 8.31359439885341e+112*cos(theta)**14 - 1.04349943489057e+112*cos(theta)**12 + 8.02691872992743e+110*cos(theta)**10 - 3.65968939054442e+109*cos(theta)**8 + 9.21504522798955e+107*cos(theta)**6 - 1.12105173089897e+106*cos(theta)**4 + 4.98245213732876e+103*cos(theta)**2 - 3.40564055866628e+100)*cos(55*phi)

#@torch.jit.script
def Yl77_m56(theta, phi):
    return 2.91107140798105e-103*(1.0 - cos(theta)**2)**28*(2.75649036349183e+115*cos(theta)**21 - 3.78341814596918e+115*cos(theta)**19 + 2.14226656609513e+115*cos(theta)**17 - 6.51785800870107e+114*cos(theta)**15 + 1.16390321583948e+114*cos(theta)**13 - 1.25219932186868e+113*cos(theta)**11 + 8.02691872992743e+111*cos(theta)**9 - 2.92775151243554e+110*cos(theta)**7 + 5.52902713679373e+108*cos(theta)**5 - 4.48420692359589e+106*cos(theta)**3 + 9.96490427465753e+103*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl77_m57(theta, phi):
    return 5.48770569515216e-105*(1.0 - cos(theta)**2)**28.5*(5.78862976333285e+116*cos(theta)**20 - 7.18849447734144e+116*cos(theta)**18 + 3.64185316236172e+116*cos(theta)**16 - 9.77678701305161e+115*cos(theta)**14 + 1.51307418059132e+115*cos(theta)**12 - 1.37741925405555e+114*cos(theta)**10 + 7.22422685693468e+112*cos(theta)**8 - 2.04942605870488e+111*cos(theta)**6 + 2.76451356839686e+109*cos(theta)**4 - 1.34526207707877e+107*cos(theta)**2 + 9.96490427465753e+103)*cos(57*phi)

#@torch.jit.script
def Yl77_m58(theta, phi):
    return 1.05610945344318e-106*(1.0 - cos(theta)**2)**29*(1.15772595266657e+118*cos(theta)**19 - 1.29392900592146e+118*cos(theta)**17 + 5.82696505977876e+117*cos(theta)**15 - 1.36875018182722e+117*cos(theta)**13 + 1.81568901670958e+116*cos(theta)**11 - 1.37741925405555e+115*cos(theta)**9 + 5.77938148554775e+113*cos(theta)**7 - 1.22965563522293e+112*cos(theta)**5 + 1.10580542735875e+110*cos(theta)**3 - 2.69052415415753e+107*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl77_m59(theta, phi):
    return 2.07760353436883e-108*(1.0 - cos(theta)**2)**29.5*(2.19967931006648e+119*cos(theta)**18 - 2.19967931006648e+119*cos(theta)**16 + 8.74044758966814e+118*cos(theta)**14 - 1.77937523637539e+118*cos(theta)**12 + 1.99725791838054e+117*cos(theta)**10 - 1.23967732864999e+116*cos(theta)**8 + 4.04556703988342e+114*cos(theta)**6 - 6.14827817611463e+112*cos(theta)**4 + 3.31741628207624e+110*cos(theta)**2 - 2.69052415415753e+107)*cos(59*phi)

#@torch.jit.script
def Yl77_m60(theta, phi):
    return 4.18375398764358e-110*(1.0 - cos(theta)**2)**30*(3.95942275811967e+120*cos(theta)**17 - 3.51948689610637e+120*cos(theta)**15 + 1.22366266255354e+120*cos(theta)**13 - 2.13525028365047e+119*cos(theta)**11 + 1.99725791838054e+118*cos(theta)**9 - 9.91741862919994e+116*cos(theta)**7 + 2.42734022393005e+115*cos(theta)**5 - 2.45931127044585e+113*cos(theta)**3 + 6.63483256415247e+110*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl77_m61(theta, phi):
    return 8.63777993690384e-112*(1.0 - cos(theta)**2)**30.5*(6.73101868880343e+121*cos(theta)**16 - 5.27923034415955e+121*cos(theta)**14 + 1.5907614613196e+121*cos(theta)**12 - 2.34877531201552e+120*cos(theta)**10 + 1.79753212654249e+119*cos(theta)**8 - 6.94219304043996e+117*cos(theta)**6 + 1.21367011196503e+116*cos(theta)**4 - 7.37793381133755e+113*cos(theta)**2 + 6.63483256415247e+110)*cos(61*phi)

#@torch.jit.script
def Yl77_m62(theta, phi):
    return 1.8316173298734e-113*(1.0 - cos(theta)**2)**31*(1.07696299020855e+123*cos(theta)**15 - 7.39092248182338e+122*cos(theta)**13 + 1.90891375358352e+122*cos(theta)**11 - 2.34877531201552e+121*cos(theta)**9 + 1.43802570123399e+120*cos(theta)**7 - 4.16531582426397e+118*cos(theta)**5 + 4.85468044786011e+116*cos(theta)**3 - 1.47558676226751e+114*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl77_m63(theta, phi):
    return 3.99691669444655e-115*(1.0 - cos(theta)**2)**31.5*(1.61544448531282e+124*cos(theta)**14 - 9.60819922637039e+123*cos(theta)**12 + 2.09980512894187e+123*cos(theta)**10 - 2.11389778081397e+122*cos(theta)**8 + 1.00661799086379e+121*cos(theta)**6 - 2.08265791213199e+119*cos(theta)**4 + 1.45640413435803e+117*cos(theta)**2 - 1.47558676226751e+114)*cos(63*phi)

#@torch.jit.script
def Yl77_m64(theta, phi):
    return 8.99604299546297e-117*(1.0 - cos(theta)**2)**32*(2.26162227943795e+125*cos(theta)**13 - 1.15298390716445e+125*cos(theta)**11 + 2.09980512894187e+124*cos(theta)**9 - 1.69111822465117e+123*cos(theta)**7 + 6.03970794518276e+121*cos(theta)**5 - 8.33063164852795e+119*cos(theta)**3 + 2.91280826871606e+117*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl77_m65(theta, phi):
    return 2.09380230745894e-118*(1.0 - cos(theta)**2)**32.5*(2.94010896326934e+126*cos(theta)**12 - 1.26828229788089e+126*cos(theta)**10 + 1.88982461604769e+125*cos(theta)**8 - 1.18378275725582e+124*cos(theta)**6 + 3.01985397259138e+122*cos(theta)**4 - 2.49918949455838e+120*cos(theta)**2 + 2.91280826871606e+117)*cos(65*phi)

#@torch.jit.script
def Yl77_m66(theta, phi):
    return 5.05448639986654e-120*(1.0 - cos(theta)**2)**33*(3.52813075592321e+127*cos(theta)**11 - 1.26828229788089e+127*cos(theta)**9 + 1.51185969283815e+126*cos(theta)**7 - 7.10269654353493e+124*cos(theta)**5 + 1.20794158903655e+123*cos(theta)**3 - 4.99837898911677e+120*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl77_m67(theta, phi):
    return 1.26998749214482e-121*(1.0 - cos(theta)**2)**33.5*(3.88094383151553e+128*cos(theta)**10 - 1.1414540680928e+128*cos(theta)**8 + 1.0583017849867e+127*cos(theta)**6 - 3.55134827176746e+125*cos(theta)**4 + 3.62382476710966e+123*cos(theta)**2 - 4.99837898911677e+120)*cos(67*phi)

#@torch.jit.script
def Yl77_m68(theta, phi):
    return 3.33515054740002e-123*(1.0 - cos(theta)**2)**34*(3.88094383151553e+129*cos(theta)**9 - 9.13163254474242e+128*cos(theta)**7 + 6.34981070992022e+127*cos(theta)**5 - 1.42053930870699e+126*cos(theta)**3 + 7.24764953421931e+123*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl77_m69(theta, phi):
    return 9.20063410801222e-125*(1.0 - cos(theta)**2)**34.5*(3.49284944836398e+130*cos(theta)**8 - 6.39214278131969e+129*cos(theta)**6 + 3.17490535496011e+128*cos(theta)**4 - 4.26161792612096e+126*cos(theta)**2 + 7.24764953421931e+123)*cos(69*phi)

#@torch.jit.script
def Yl77_m70(theta, phi):
    return 2.6829593898425e-126*(1.0 - cos(theta)**2)**35*(2.79427955869118e+131*cos(theta)**7 - 3.83528566879182e+130*cos(theta)**5 + 1.26996214198404e+129*cos(theta)**3 - 8.52323585224191e+126*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl77_m71(theta, phi):
    return 8.33554924128577e-128*(1.0 - cos(theta)**2)**35.5*(1.95599569108383e+132*cos(theta)**6 - 1.91764283439591e+131*cos(theta)**4 + 3.80988642595213e+129*cos(theta)**2 - 8.52323585224191e+126)*cos(71*phi)

#@torch.jit.script
def Yl77_m72(theta, phi):
    return 2.78782470252787e-129*(1.0 - cos(theta)**2)**36*(1.1735974146503e+133*cos(theta)**5 - 7.67057133758363e+131*cos(theta)**3 + 7.61977285190427e+129*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl77_m73(theta, phi):
    return 1.01796965062976e-130*(1.0 - cos(theta)**2)**36.5*(5.86798707325148e+133*cos(theta)**4 - 2.30117140127509e+132*cos(theta)**2 + 7.61977285190427e+129)*cos(73*phi)

#@torch.jit.script
def Yl77_m74(theta, phi):
    return 4.14205976530905e-132*(1.0 - cos(theta)**2)**37*(2.34719482930059e+134*cos(theta)**3 - 4.60234280255018e+132*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl77_m75(theta, phi):
    return 1.93969720345593e-133*(1.0 - cos(theta)**2)**37.5*(7.04158448790177e+134*cos(theta)**2 - 4.60234280255018e+132)*cos(75*phi)

#@torch.jit.script
def Yl77_m76(theta, phi):
    return 15.6161372224161*(1.0 - cos(theta)**2)**38*cos(76*phi)*cos(theta)

#@torch.jit.script
def Yl77_m77(theta, phi):
    return 1.25838419831944*(1.0 - cos(theta)**2)**38.5*cos(77*phi)

#@torch.jit.script
def Yl78_m_minus_78(theta, phi):
    return 1.26241103804633*(1.0 - cos(theta)**2)**39*sin(78*phi)

#@torch.jit.script
def Yl78_m_minus_77(theta, phi):
    return 15.7675088115108*(1.0 - cos(theta)**2)**38.5*sin(77*phi)*cos(theta)

#@torch.jit.script
def Yl78_m_minus_76(theta, phi):
    return 1.27177956062001e-135*(1.0 - cos(theta)**2)**38*(1.09144559562477e+137*cos(theta)**2 - 7.04158448790177e+134)*sin(76*phi)

#@torch.jit.script
def Yl78_m_minus_75(theta, phi):
    return 2.73358654861083e-134*(1.0 - cos(theta)**2)**37.5*(3.63815198541592e+136*cos(theta)**3 - 7.04158448790177e+134*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl78_m_minus_74(theta, phi):
    return 6.76251964601404e-133*(1.0 - cos(theta)**2)**37*(9.09537996353979e+135*cos(theta)**4 - 3.52079224395089e+134*cos(theta)**2 + 1.15058570063754e+132)*sin(74*phi)

#@torch.jit.script
def Yl78_m_minus_73(theta, phi):
    return 1.86429800975251e-131*(1.0 - cos(theta)**2)**36.5*(1.81907599270796e+135*cos(theta)**5 - 1.1735974146503e+134*cos(theta)**3 + 1.15058570063754e+132*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl78_m_minus_72(theta, phi):
    return 5.61150604086412e-130*(1.0 - cos(theta)**2)**36*(3.03179332117993e+134*cos(theta)**6 - 2.93399353662574e+133*cos(theta)**4 + 5.75292850318772e+131*cos(theta)**2 - 1.26996214198404e+129)*sin(72*phi)

#@torch.jit.script
def Yl78_m_minus_71(theta, phi):
    return 1.81833577891948e-128*(1.0 - cos(theta)**2)**35.5*(4.33113331597133e+133*cos(theta)**7 - 5.86798707325148e+132*cos(theta)**5 + 1.91764283439591e+131*cos(theta)**3 - 1.26996214198404e+129*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl78_m_minus_70(theta, phi):
    return 6.27786846456604e-127*(1.0 - cos(theta)**2)**35*(5.41391664496416e+132*cos(theta)**8 - 9.77997845541913e+131*cos(theta)**6 + 4.79410708598977e+130*cos(theta)**4 - 6.34981070992022e+128*cos(theta)**2 + 1.06540448153024e+126)*sin(70*phi)

#@torch.jit.script
def Yl78_m_minus_69(theta, phi):
    return 2.29120698398419e-125*(1.0 - cos(theta)**2)**34.5*(6.01546293884907e+131*cos(theta)**9 - 1.39713977934559e+131*cos(theta)**7 + 9.58821417197954e+129*cos(theta)**5 - 2.11660356997341e+128*cos(theta)**3 + 1.06540448153024e+126*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl78_m_minus_68(theta, phi):
    return 8.78462024329062e-124*(1.0 - cos(theta)**2)**34*(6.01546293884907e+130*cos(theta)**10 - 1.74642472418199e+130*cos(theta)**8 + 1.59803569532992e+129*cos(theta)**6 - 5.29150892493352e+127*cos(theta)**4 + 5.3270224076512e+125*cos(theta)**2 - 7.24764953421931e+122)*sin(68*phi)

#@torch.jit.script
def Yl78_m_minus_67(theta, phi):
    return 3.52043039736682e-122*(1.0 - cos(theta)**2)**33.5*(5.46860267168097e+129*cos(theta)**11 - 1.94047191575776e+129*cos(theta)**9 + 2.2829081361856e+128*cos(theta)**7 - 1.0583017849867e+127*cos(theta)**5 + 1.77567413588373e+125*cos(theta)**3 - 7.24764953421931e+122*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl78_m_minus_66(theta, phi):
    return 1.46848794744477e-120*(1.0 - cos(theta)**2)**33*(4.55716889306748e+128*cos(theta)**12 - 1.94047191575776e+128*cos(theta)**10 + 2.85363517023201e+127*cos(theta)**8 - 1.76383630831117e+126*cos(theta)**6 + 4.43918533970933e+124*cos(theta)**4 - 3.62382476710966e+122*cos(theta)**2 + 4.16531582426397e+119)*sin(66*phi)

#@torch.jit.script
def Yl78_m_minus_65(theta, phi):
    return 6.35365031029558e-119*(1.0 - cos(theta)**2)**32.5*(3.50551453312883e+127*cos(theta)**13 - 1.7640653779616e+127*cos(theta)**11 + 3.17070574470223e+126*cos(theta)**9 - 2.51976615473025e+125*cos(theta)**7 + 8.87837067941866e+123*cos(theta)**5 - 1.20794158903655e+122*cos(theta)**3 + 4.16531582426397e+119*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl78_m_minus_64(theta, phi):
    return 2.84285916421425e-117*(1.0 - cos(theta)**2)**32*(2.50393895223488e+126*cos(theta)**14 - 1.47005448163467e+126*cos(theta)**12 + 3.17070574470223e+125*cos(theta)**10 - 3.14970769341281e+124*cos(theta)**8 + 1.47972844656978e+123*cos(theta)**6 - 3.01985397259138e+121*cos(theta)**4 + 2.08265791213199e+119*cos(theta)**2 - 2.08057733479719e+116)*sin(64*phi)

#@torch.jit.script
def Yl78_m_minus_63(theta, phi):
    return 1.3120341735144e-115*(1.0 - cos(theta)**2)**31.5*(1.66929263482325e+125*cos(theta)**15 - 1.13081113971898e+125*cos(theta)**13 + 2.88245976791112e+124*cos(theta)**11 - 3.49967521490312e+123*cos(theta)**9 + 2.11389778081397e+122*cos(theta)**7 - 6.03970794518276e+120*cos(theta)**5 + 6.94219304043996e+118*cos(theta)**3 - 2.08057733479719e+116*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl78_m_minus_62(theta, phi):
    return 6.23181704247764e-114*(1.0 - cos(theta)**2)**31*(1.04330789676453e+124*cos(theta)**16 - 8.07722242656412e+123*cos(theta)**14 + 2.4020498065926e+123*cos(theta)**12 - 3.49967521490312e+122*cos(theta)**10 + 2.64237222601746e+121*cos(theta)**8 - 1.00661799086379e+120*cos(theta)**6 + 1.73554826010999e+118*cos(theta)**4 - 1.04028866739859e+116*cos(theta)**2 + 9.22241726417194e+112)*sin(62*phi)

#@torch.jit.script
def Yl78_m_minus_61(theta, phi):
    return 3.04020712927881e-112*(1.0 - cos(theta)**2)**30.5*(6.13710527508548e+122*cos(theta)**17 - 5.38481495104275e+122*cos(theta)**15 + 1.84773062045584e+122*cos(theta)**13 - 3.1815229226392e+121*cos(theta)**11 + 2.9359691400194e+120*cos(theta)**9 - 1.43802570123399e+119*cos(theta)**7 + 3.47109652021998e+117*cos(theta)**5 - 3.46762889132865e+115*cos(theta)**3 + 9.22241726417194e+112*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl78_m_minus_60(theta, phi):
    return 1.52071148450559e-110*(1.0 - cos(theta)**2)**30*(3.40950293060305e+121*cos(theta)**18 - 3.36550934440172e+121*cos(theta)**16 + 1.31980758603989e+121*cos(theta)**14 - 2.65126910219933e+120*cos(theta)**12 + 2.9359691400194e+119*cos(theta)**10 - 1.79753212654249e+118*cos(theta)**8 + 5.7851608670333e+116*cos(theta)**6 - 8.66907222832162e+114*cos(theta)**4 + 4.61120863208597e+112*cos(theta)**2 - 3.68601809119582e+109)*sin(60*phi)

#@torch.jit.script
def Yl78_m_minus_59(theta, phi):
    return 7.78687439535216e-109*(1.0 - cos(theta)**2)**29.5*(1.79447522663318e+120*cos(theta)**19 - 1.97971137905983e+120*cos(theta)**17 + 8.79871724026592e+119*cos(theta)**15 - 2.03943777092257e+119*cos(theta)**13 + 2.66906285456309e+118*cos(theta)**11 - 1.99725791838054e+117*cos(theta)**9 + 8.26451552433328e+115*cos(theta)**7 - 1.73381444566432e+114*cos(theta)**5 + 1.53706954402866e+112*cos(theta)**3 - 3.68601809119582e+109*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl78_m_minus_58(theta, phi):
    return 4.07604012745502e-107*(1.0 - cos(theta)**2)**29*(8.97237613316591e+118*cos(theta)**20 - 1.09983965503324e+119*cos(theta)**18 + 5.4991982751662e+118*cos(theta)**16 - 1.45674126494469e+118*cos(theta)**14 + 2.22421904546924e+117*cos(theta)**12 - 1.99725791838054e+116*cos(theta)**10 + 1.03306444054166e+115*cos(theta)**8 - 2.88969074277387e+113*cos(theta)**6 + 3.84267386007164e+111*cos(theta)**4 - 1.84300904559791e+109*cos(theta)**2 + 1.34526207707877e+106)*sin(58*phi)

#@torch.jit.script
def Yl78_m_minus_57(theta, phi):
    return 2.17829930249497e-105*(1.0 - cos(theta)**2)**28.5*(4.27256006341234e+117*cos(theta)**21 - 5.78862976333285e+117*cos(theta)**19 + 3.23482251480365e+117*cos(theta)**17 - 9.7116084329646e+116*cos(theta)**15 + 1.71093772728403e+116*cos(theta)**13 - 1.81568901670958e+115*cos(theta)**11 + 1.14784937837962e+114*cos(theta)**9 - 4.12812963253411e+112*cos(theta)**7 + 7.68534772014328e+110*cos(theta)**5 - 6.14336348532636e+108*cos(theta)**3 + 1.34526207707877e+106*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl78_m_minus_56(theta, phi):
    return 1.18712315781526e-103*(1.0 - cos(theta)**2)**28*(1.94207275609652e+116*cos(theta)**22 - 2.89431488166642e+116*cos(theta)**20 + 1.79712361933536e+116*cos(theta)**18 - 6.06975527060287e+115*cos(theta)**16 + 1.22209837663145e+115*cos(theta)**14 - 1.51307418059132e+114*cos(theta)**12 + 1.14784937837962e+113*cos(theta)**10 - 5.16016204066763e+111*cos(theta)**8 + 1.28089128669055e+110*cos(theta)**6 - 1.53584087133159e+108*cos(theta)**4 + 6.72631038539383e+105*cos(theta)**2 - 4.52950194302615e+102)*sin(56*phi)

#@torch.jit.script
def Yl78_m_minus_55(theta, phi):
    return 6.59040485068495e-102*(1.0 - cos(theta)**2)**27.5*(8.44379459172399e+114*cos(theta)**23 - 1.37824518174592e+115*cos(theta)**21 + 9.45854536492295e+114*cos(theta)**19 - 3.57044427682522e+114*cos(theta)**17 + 8.14732251087634e+113*cos(theta)**15 - 1.16390321583948e+113*cos(theta)**13 + 1.04349943489057e+112*cos(theta)**11 - 5.73351337851959e+110*cos(theta)**9 + 1.82984469527221e+109*cos(theta)**7 - 3.07168174266318e+107*cos(theta)**5 + 2.24210346179794e+105*cos(theta)**3 - 4.52950194302615e+102*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl78_m_minus_54(theta, phi):
    return 3.72343293236516e-100*(1.0 - cos(theta)**2)**27*(3.51824774655166e+113*cos(theta)**24 - 6.2647508261178e+113*cos(theta)**22 + 4.72927268246147e+113*cos(theta)**20 - 1.98358015379179e+113*cos(theta)**18 + 5.09207656929771e+112*cos(theta)**16 - 8.31359439885341e+111*cos(theta)**14 + 8.69582862408805e+110*cos(theta)**12 - 5.73351337851959e+109*cos(theta)**10 + 2.28730586909026e+108*cos(theta)**8 - 5.1194695711053e+106*cos(theta)**6 + 5.60525865449486e+104*cos(theta)**4 - 2.26475097151307e+102*cos(theta)**2 + 1.41901689944428e+99)*sin(54*phi)

#@torch.jit.script
def Yl78_m_minus_53(theta, phi):
    return 2.13894937401544e-98*(1.0 - cos(theta)**2)**26.5*(1.40729909862066e+112*cos(theta)**25 - 2.72380470700774e+112*cos(theta)**23 + 2.25203461069594e+112*cos(theta)**21 - 1.04398955462726e+112*cos(theta)**19 + 2.99533915841042e+111*cos(theta)**17 - 5.54239626590227e+110*cos(theta)**15 + 6.68909894160619e+109*cos(theta)**13 - 5.21228488956326e+108*cos(theta)**11 + 2.54145096565585e+107*cos(theta)**9 - 7.31352795872186e+105*cos(theta)**7 + 1.12105173089897e+104*cos(theta)**5 - 7.54916990504358e+101*cos(theta)**3 + 1.41901689944428e+99*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl78_m_minus_52(theta, phi):
    return 1.24831108583523e-96*(1.0 - cos(theta)**2)**26*(5.41268884084871e+110*cos(theta)**26 - 1.13491862791989e+111*cos(theta)**24 + 1.02365209577088e+111*cos(theta)**22 - 5.21994777313629e+110*cos(theta)**20 + 1.66407731022801e+110*cos(theta)**18 - 3.46399766618892e+109*cos(theta)**16 + 4.77792781543299e+108*cos(theta)**14 - 4.34357074130272e+107*cos(theta)**12 + 2.54145096565585e+106*cos(theta)**10 - 9.14190994840233e+104*cos(theta)**8 + 1.86841955149829e+103*cos(theta)**6 - 1.8872924762609e+101*cos(theta)**4 + 7.09508449722141e+98*cos(theta)**2 - 4.16622695080529e+95)*sin(52*phi)

#@torch.jit.script
def Yl78_m_minus_51(theta, phi):
    return 7.39565060710491e-95*(1.0 - cos(theta)**2)**25.5*(2.00469957068471e+109*cos(theta)**27 - 4.53967451167956e+109*cos(theta)**25 + 4.45066128596036e+109*cos(theta)**23 - 2.48568941577918e+109*cos(theta)**21 + 8.758301632779e+108*cos(theta)**19 - 2.03764568599348e+108*cos(theta)**17 + 3.18528521028866e+107*cos(theta)**15 - 3.34120826254055e+106*cos(theta)**13 + 2.31040996877804e+105*cos(theta)**11 - 1.0157677720447e+104*cos(theta)**9 + 2.66917078785469e+102*cos(theta)**7 - 3.77458495252179e+100*cos(theta)**5 + 2.36502816574047e+98*cos(theta)**3 - 4.16622695080529e+95*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl78_m_minus_50(theta, phi):
    return 4.44477986207826e-93*(1.0 - cos(theta)**2)**25*(7.15964132387396e+107*cos(theta)**28 - 1.74602865833829e+108*cos(theta)**26 + 1.85444220248348e+108*cos(theta)**24 - 1.12985882535417e+108*cos(theta)**22 + 4.3791508163895e+107*cos(theta)**20 - 1.13202538110749e+107*cos(theta)**18 + 1.99080325643041e+106*cos(theta)**16 - 2.38657733038611e+105*cos(theta)**14 + 1.92534164064837e+104*cos(theta)**12 - 1.0157677720447e+103*cos(theta)**10 + 3.33646348481837e+101*cos(theta)**8 - 6.29097492086965e+99*cos(theta)**6 + 5.91257041435118e+97*cos(theta)**4 - 2.08311347540265e+95*cos(theta)**2 + 1.15344046257068e+92)*sin(50*phi)

#@torch.jit.script
def Yl78_m_minus_49(theta, phi):
    return 2.70803479480809e-91*(1.0 - cos(theta)**2)**24.5*(2.46884183581861e+106*cos(theta)**29 - 6.46677280866035e+106*cos(theta)**27 + 7.41776880993393e+106*cos(theta)**25 - 4.91242967545293e+106*cos(theta)**23 + 2.08530991256643e+106*cos(theta)**21 - 5.95802832161837e+105*cos(theta)**19 + 1.17106073907671e+105*cos(theta)**17 - 1.59105155359074e+104*cos(theta)**15 + 1.48103203126798e+103*cos(theta)**13 - 9.23425247313366e+101*cos(theta)**11 + 3.70718164979819e+100*cos(theta)**9 - 8.98710702981379e+98*cos(theta)**7 + 1.18251408287024e+97*cos(theta)**5 - 6.94371158467548e+94*cos(theta)**3 + 1.15344046257068e+92*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl78_m_minus_48(theta, phi):
    return 1.67153982405702e-89*(1.0 - cos(theta)**2)**24*(8.22947278606202e+104*cos(theta)**30 - 2.3095617173787e+105*cos(theta)**28 + 2.85298800382074e+105*cos(theta)**26 - 2.04684569810539e+105*cos(theta)**24 + 9.4786814207565e+104*cos(theta)**22 - 2.97901416080918e+104*cos(theta)**20 + 6.50589299487063e+103*cos(theta)**18 - 9.94407220994213e+102*cos(theta)**16 + 1.05788002233427e+102*cos(theta)**14 - 7.69521039427805e+100*cos(theta)**12 + 3.70718164979819e+99*cos(theta)**10 - 1.12338837872672e+98*cos(theta)**8 + 1.97085680478372e+96*cos(theta)**6 - 1.73592789616887e+94*cos(theta)**4 + 5.76720231285339e+91*cos(theta)**2 - 3.02740278889942e+88)*sin(48*phi)

#@torch.jit.script
def Yl78_m_minus_47(theta, phi):
    return 1.04467895870425e-87*(1.0 - cos(theta)**2)**23.5*(2.65466864066517e+103*cos(theta)**31 - 7.9640059219955e+103*cos(theta)**29 + 1.05666222363731e+104*cos(theta)**27 - 8.18738279242155e+103*cos(theta)**25 + 4.12116583511152e+103*cos(theta)**23 - 1.4185781718139e+103*cos(theta)**21 + 3.42415420782665e+102*cos(theta)**19 - 5.84945424114243e+101*cos(theta)**17 + 7.05253348222846e+100*cos(theta)**15 - 5.91939261098312e+99*cos(theta)**13 + 3.37016513618017e+98*cos(theta)**11 - 1.24820930969636e+97*cos(theta)**9 + 2.81550972111961e+95*cos(theta)**7 - 3.47185579233774e+93*cos(theta)**5 + 1.92240077095113e+91*cos(theta)**3 - 3.02740278889942e+88*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl78_m_minus_46(theta, phi):
    return 6.60712986631682e-86*(1.0 - cos(theta)**2)**23*(8.29583950207865e+101*cos(theta)**32 - 2.65466864066517e+102*cos(theta)**30 + 3.77379365584754e+102*cos(theta)**28 - 3.1489933817006e+102*cos(theta)**26 + 1.71715243129647e+102*cos(theta)**24 - 6.44808259915408e+101*cos(theta)**22 + 1.71207710391332e+101*cos(theta)**20 - 3.24969680063468e+100*cos(theta)**18 + 4.40783342639279e+99*cos(theta)**16 - 4.22813757927366e+98*cos(theta)**14 + 2.80847094681681e+97*cos(theta)**12 - 1.24820930969636e+96*cos(theta)**10 + 3.51938715139951e+94*cos(theta)**8 - 5.7864263205629e+92*cos(theta)**6 + 4.80600192737783e+90*cos(theta)**4 - 1.51370139444971e+88*cos(theta)**2 + 7.56850697224855e+84)*sin(46*phi)

#@torch.jit.script
def Yl78_m_minus_45(theta, phi):
    return 4.22649788202925e-84*(1.0 - cos(theta)**2)**22.5*(2.51389075820565e+100*cos(theta)**33 - 8.56344722795215e+100*cos(theta)**31 + 1.30130815718881e+101*cos(theta)**29 - 1.1662938450743e+101*cos(theta)**27 + 6.86860972518587e+100*cos(theta)**25 - 2.80351417354525e+100*cos(theta)**23 + 8.15274811387297e+99*cos(theta)**21 - 1.71036673717615e+99*cos(theta)**19 + 2.59284319199576e+98*cos(theta)**17 - 2.81875838618244e+97*cos(theta)**15 + 2.16036226678216e+96*cos(theta)**13 - 1.1347357360876e+95*cos(theta)**11 + 3.91043016822168e+93*cos(theta)**9 - 8.26632331508986e+91*cos(theta)**7 + 9.61200385475565e+89*cos(theta)**5 - 5.04567131483236e+87*cos(theta)**3 + 7.56850697224855e+84*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl78_m_minus_44(theta, phi):
    return 2.73320791631936e-82*(1.0 - cos(theta)**2)**22*(7.39379634766368e+98*cos(theta)**34 - 2.67607725873505e+99*cos(theta)**32 + 4.33769385729602e+99*cos(theta)**30 - 4.16533516097963e+99*cos(theta)**28 + 2.64177297122533e+99*cos(theta)**26 - 1.16813090564385e+99*cos(theta)**24 + 3.70579459721499e+98*cos(theta)**22 - 8.55183368588074e+97*cos(theta)**20 + 1.44046843999764e+97*cos(theta)**18 - 1.76172399136402e+96*cos(theta)**16 + 1.5431159048444e+95*cos(theta)**14 - 9.45613113406333e+93*cos(theta)**12 + 3.91043016822168e+92*cos(theta)**10 - 1.03329041438623e+91*cos(theta)**8 + 1.60200064245928e+89*cos(theta)**6 - 1.26141782870809e+87*cos(theta)**4 + 3.78425348612427e+84*cos(theta)**2 - 1.80978167676914e+81)*sin(44*phi)

#@torch.jit.script
def Yl78_m_minus_43(theta, phi):
    return 1.78602119091733e-80*(1.0 - cos(theta)**2)**21.5*(2.11251324218962e+97*cos(theta)**35 - 8.10932502646984e+97*cos(theta)**33 + 1.39925608299872e+98*cos(theta)**31 - 1.43632246930332e+98*cos(theta)**29 + 9.7843443378716e+97*cos(theta)**27 - 4.67252362257542e+97*cos(theta)**25 + 1.61121504226739e+97*cos(theta)**23 - 4.07230175518131e+96*cos(theta)**21 + 7.58141284209286e+95*cos(theta)**19 - 1.03630823021413e+95*cos(theta)**17 + 1.02874393656293e+94*cos(theta)**15 - 7.27394702620256e+92*cos(theta)**13 + 3.55493651656516e+91*cos(theta)**11 - 1.14810046042915e+90*cos(theta)**9 + 2.28857234637039e+88*cos(theta)**7 - 2.52283565741618e+86*cos(theta)**5 + 1.26141782870809e+84*cos(theta)**3 - 1.80978167676914e+81*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl78_m_minus_42(theta, phi):
    return 1.17877398600544e-78*(1.0 - cos(theta)**2)**21*(5.86809233941562e+95*cos(theta)**36 - 2.38509559602054e+96*cos(theta)**34 + 4.37267525937099e+96*cos(theta)**32 - 4.7877415643444e+96*cos(theta)**30 + 3.494408692097e+96*cos(theta)**28 - 1.79712447022132e+96*cos(theta)**26 + 6.71339600944744e+95*cos(theta)**24 - 1.85104625235514e+95*cos(theta)**22 + 3.79070642104643e+94*cos(theta)**20 - 5.75726794563406e+93*cos(theta)**18 + 6.42964960351833e+92*cos(theta)**16 - 5.19567644728754e+91*cos(theta)**14 + 2.96244709713763e+90*cos(theta)**12 - 1.14810046042915e+89*cos(theta)**10 + 2.86071543296299e+87*cos(theta)**8 - 4.20472609569364e+85*cos(theta)**6 + 3.15354457177023e+83*cos(theta)**4 - 9.0489083838457e+80*cos(theta)**2 + 4.15468704492457e+77)*sin(42*phi)

#@torch.jit.script
def Yl78_m_minus_41(theta, phi):
    return 7.85456301061312e-77*(1.0 - cos(theta)**2)**20.5*(1.58597090254476e+94*cos(theta)**37 - 6.81455884577298e+94*cos(theta)**35 + 1.3250531089003e+95*cos(theta)**33 - 1.54443276269174e+95*cos(theta)**31 + 1.20496851451621e+95*cos(theta)**29 - 6.65601655637524e+94*cos(theta)**27 + 2.68535840377898e+94*cos(theta)**25 - 8.04802718415278e+93*cos(theta)**23 + 1.80509829573639e+93*cos(theta)**21 - 3.03014102401793e+92*cos(theta)**19 + 3.78214682559902e+91*cos(theta)**17 - 3.46378429819169e+90*cos(theta)**15 + 2.27880545933664e+89*cos(theta)**13 - 1.04372769129923e+88*cos(theta)**11 + 3.17857270329221e+86*cos(theta)**9 - 6.00675156527662e+84*cos(theta)**7 + 6.30708914354045e+82*cos(theta)**5 - 3.01630279461523e+80*cos(theta)**3 + 4.15468704492457e+77*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl78_m_minus_40(theta, phi):
    return 5.28186512433385e-75*(1.0 - cos(theta)**2)**20*(4.17360763827569e+92*cos(theta)**38 - 1.89293301271472e+93*cos(theta)**36 + 3.89721502617736e+93*cos(theta)**34 - 4.82635238341169e+93*cos(theta)**32 + 4.01656171505403e+93*cos(theta)**30 - 2.37714877013401e+93*cos(theta)**28 + 1.03283015529961e+93*cos(theta)**26 - 3.35334466006366e+92*cos(theta)**24 + 8.20499225334725e+91*cos(theta)**22 - 1.51507051200896e+91*cos(theta)**20 + 2.10119268088834e+90*cos(theta)**18 - 2.16486518636981e+89*cos(theta)**16 + 1.62771818524046e+88*cos(theta)**14 - 8.69773076082688e+86*cos(theta)**12 + 3.17857270329221e+85*cos(theta)**10 - 7.50843945659578e+83*cos(theta)**8 + 1.05118152392341e+82*cos(theta)**6 - 7.54075698653809e+79*cos(theta)**4 + 2.07734352246228e+77*cos(theta)**2 - 9.18772013472925e+73)*sin(40*phi)

#@torch.jit.script
def Yl78_m_minus_39(theta, phi):
    return 3.58311390385504e-73*(1.0 - cos(theta)**2)**19.5*(1.07015580468607e+91*cos(theta)**39 - 5.11603516949923e+91*cos(theta)**37 + 1.11349000747924e+92*cos(theta)**35 - 1.46253102527627e+92*cos(theta)**33 + 1.29566506937227e+92*cos(theta)**31 - 8.19706472460005e+91*cos(theta)**29 + 3.82529687148002e+91*cos(theta)**27 - 1.34133786402546e+91*cos(theta)**25 + 3.56738793623793e+90*cos(theta)**23 - 7.21462148575697e+89*cos(theta)**21 + 1.10589088467808e+89*cos(theta)**19 - 1.2734501096293e+88*cos(theta)**17 + 1.08514545682697e+87*cos(theta)**15 - 6.69056212371298e+85*cos(theta)**13 + 2.88961154844747e+84*cos(theta)**11 - 8.34271050732864e+82*cos(theta)**9 + 1.50168789131916e+81*cos(theta)**7 - 1.50815139730762e+79*cos(theta)**5 + 6.92447840820761e+76*cos(theta)**3 - 9.18772013472925e+73*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl78_m_minus_38(theta, phi):
    return 2.45122705110393e-71*(1.0 - cos(theta)**2)**19*(2.67538951171518e+89*cos(theta)**40 - 1.34632504460506e+90*cos(theta)**38 + 3.09302779855346e+90*cos(theta)**36 - 4.30156183904785e+90*cos(theta)**34 + 4.04895334178833e+90*cos(theta)**32 - 2.73235490820002e+90*cos(theta)**30 + 1.36617745410001e+90*cos(theta)**28 - 5.15899178471332e+89*cos(theta)**26 + 1.48641164009914e+89*cos(theta)**24 - 3.27937340261681e+88*cos(theta)**22 + 5.52945442339038e+87*cos(theta)**20 - 7.07472283127389e+86*cos(theta)**18 + 6.78215910516858e+85*cos(theta)**16 - 4.77897294550927e+84*cos(theta)**14 + 2.40800962370622e+83*cos(theta)**12 - 8.34271050732864e+81*cos(theta)**10 + 1.87710986414895e+80*cos(theta)**8 - 2.51358566217936e+78*cos(theta)**6 + 1.7311196020519e+76*cos(theta)**4 - 4.59386006736462e+73*cos(theta)**2 + 1.96318806297633e+70)*sin(38*phi)

#@torch.jit.script
def Yl78_m_minus_37(theta, phi):
    return 1.69045830621872e-69*(1.0 - cos(theta)**2)**18.5*(6.52534027247606e+87*cos(theta)**41 - 3.45211549898734e+88*cos(theta)**39 + 8.35953459068502e+88*cos(theta)**37 - 1.22901766829939e+89*cos(theta)**35 + 1.22695555811768e+89*cos(theta)**33 - 8.8140480909678e+88*cos(theta)**31 + 4.71095673827589e+88*cos(theta)**29 - 1.91073769804197e+88*cos(theta)**27 + 5.94564656039656e+87*cos(theta)**25 - 1.42581452287687e+87*cos(theta)**23 + 2.6330735349478e+86*cos(theta)**21 - 3.72353833224941e+85*cos(theta)**19 + 3.98950535598152e+84*cos(theta)**17 - 3.18598196367285e+83*cos(theta)**15 + 1.85231509515863e+82*cos(theta)**13 - 7.58428227938968e+80*cos(theta)**11 + 2.08567762683216e+79*cos(theta)**9 - 3.59083666025623e+77*cos(theta)**7 + 3.4622392041038e+75*cos(theta)**5 - 1.53128668912154e+73*cos(theta)**3 + 1.96318806297633e+70*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl78_m_minus_36(theta, phi):
    return 1.17483811850223e-67*(1.0 - cos(theta)**2)**18*(1.55365244582763e+86*cos(theta)**42 - 8.63028874746834e+86*cos(theta)**40 + 2.19987752386448e+87*cos(theta)**38 - 3.4139379674983e+87*cos(theta)**36 + 3.60869281799317e+87*cos(theta)**34 - 2.75439002842744e+87*cos(theta)**32 + 1.57031891275863e+87*cos(theta)**30 - 6.82406320729275e+86*cos(theta)**28 + 2.28678713861406e+86*cos(theta)**26 - 5.9408938453203e+85*cos(theta)**24 + 1.19685160679445e+85*cos(theta)**22 - 1.86176916612471e+84*cos(theta)**20 + 2.21639186443417e+83*cos(theta)**18 - 1.99123872729553e+82*cos(theta)**16 + 1.32308221082759e+81*cos(theta)**14 - 6.32023523282473e+79*cos(theta)**12 + 2.08567762683216e+78*cos(theta)**10 - 4.48854582532029e+76*cos(theta)**8 + 5.77039867350634e+74*cos(theta)**6 - 3.82821672280385e+72*cos(theta)**4 + 9.81594031488167e+69*cos(theta)**2 - 4.06457155895721e+66)*sin(36*phi)

#@torch.jit.script
def Yl78_m_minus_35(theta, phi):
    return 8.22554499846062e-66*(1.0 - cos(theta)**2)**17.5*(3.61314522285496e+84*cos(theta)**43 - 2.10494847499228e+85*cos(theta)**41 + 5.64071159965251e+85*cos(theta)**39 - 9.22685937161702e+85*cos(theta)**37 + 1.03105509085519e+86*cos(theta)**35 - 8.34663644978011e+85*cos(theta)**33 + 5.06554487986655e+85*cos(theta)**31 - 2.35312524389405e+85*cos(theta)**29 + 8.46958199486689e+84*cos(theta)**27 - 2.37635753812812e+84*cos(theta)**25 + 5.20370263823676e+83*cos(theta)**23 - 8.8655674577367e+82*cos(theta)**21 + 1.16652203391272e+82*cos(theta)**19 - 1.17131689840914e+81*cos(theta)**17 + 8.82054807218396e+79*cos(theta)**15 - 4.86171940986518e+78*cos(theta)**13 + 1.89607056984742e+77*cos(theta)**11 - 4.98727313924477e+75*cos(theta)**9 + 8.24342667643763e+73*cos(theta)**7 - 7.65643344560771e+71*cos(theta)**5 + 3.27198010496056e+69*cos(theta)**3 - 4.06457155895721e+66*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl78_m_minus_34(theta, phi):
    return 5.80003003504202e-64*(1.0 - cos(theta)**2)**17*(8.21169368830673e+82*cos(theta)**44 - 5.01178208331495e+83*cos(theta)**42 + 1.41017789991313e+84*cos(theta)**40 - 2.42812088726764e+84*cos(theta)**38 + 2.86404191904219e+84*cos(theta)**36 - 2.45489307346474e+84*cos(theta)**34 + 1.5829827749583e+84*cos(theta)**32 - 7.84375081298017e+83*cos(theta)**30 + 3.02485071245246e+83*cos(theta)**28 - 9.13983668510815e+82*cos(theta)**26 + 2.16820943259865e+82*cos(theta)**24 - 4.02980338988032e+81*cos(theta)**22 + 5.83261016956362e+80*cos(theta)**20 - 6.50731610227297e+79*cos(theta)**18 + 5.51284254511498e+78*cos(theta)**16 - 3.47265672133227e+77*cos(theta)**14 + 1.58005880820618e+76*cos(theta)**12 - 4.98727313924477e+74*cos(theta)**10 + 1.0304283345547e+73*cos(theta)**8 - 1.27607224093462e+71*cos(theta)**6 + 8.17995026240139e+68*cos(theta)**4 - 2.03228577947861e+66*cos(theta)**2 + 8.17492268495015e+62)*sin(34*phi)

#@torch.jit.script
def Yl78_m_minus_33(theta, phi):
    return 4.11761285180192e-62*(1.0 - cos(theta)**2)**16.5*(1.82482081962372e+81*cos(theta)**45 - 1.16553071704999e+82*cos(theta)**43 + 3.43945829247104e+82*cos(theta)**41 - 6.22595099299394e+82*cos(theta)**39 + 7.74065383524918e+82*cos(theta)**37 - 7.01398020989925e+82*cos(theta)**35 + 4.79691749987363e+82*cos(theta)**33 - 2.53024219773554e+82*cos(theta)**31 + 1.04305196981119e+82*cos(theta)**29 - 3.3851246981882e+81*cos(theta)**27 + 8.6728377303946e+80*cos(theta)**25 - 1.75208843038275e+80*cos(theta)**23 + 2.77743341407791e+79*cos(theta)**21 - 3.42490321172262e+78*cos(theta)**19 + 3.24284855594999e+77*cos(theta)**17 - 2.31510448088818e+76*cos(theta)**15 + 1.21542985246629e+75*cos(theta)**13 - 4.5338846720407e+73*cos(theta)**11 + 1.14492037172745e+72*cos(theta)**9 - 1.82296034419231e+70*cos(theta)**7 + 1.63599005248028e+68*cos(theta)**5 - 6.77428593159536e+65*cos(theta)**3 + 8.17492268495015e+62*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl78_m_minus_32(theta, phi):
    return 2.94229298269119e-60*(1.0 - cos(theta)**2)**16*(3.96700178179069e+79*cos(theta)**46 - 2.64893344784088e+80*cos(theta)**44 + 8.18918641064534e+80*cos(theta)**42 - 1.55648774824848e+81*cos(theta)**40 + 2.03701416717084e+81*cos(theta)**38 - 1.94832783608313e+81*cos(theta)**36 + 1.41085808819813e+81*cos(theta)**34 - 7.90700686792356e+80*cos(theta)**32 + 3.47683989937064e+80*cos(theta)**30 - 1.20897310649579e+80*cos(theta)**28 + 3.33570681938254e+79*cos(theta)**26 - 7.30036845992811e+78*cos(theta)**24 + 1.26246973367178e+78*cos(theta)**22 - 1.71245160586131e+77*cos(theta)**20 + 1.80158253108333e+76*cos(theta)**18 - 1.44694030055511e+75*cos(theta)**16 + 8.68164180333067e+73*cos(theta)**14 - 3.77823722670058e+72*cos(theta)**12 + 1.14492037172745e+71*cos(theta)**10 - 2.27870043024039e+69*cos(theta)**8 + 2.72665008746713e+67*cos(theta)**6 - 1.69357148289884e+65*cos(theta)**4 + 4.08746134247508e+62*cos(theta)**2 - 1.60104243731887e+59)*sin(32*phi)

#@torch.jit.script
def Yl78_m_minus_31(theta, phi):
    return 2.11558845098209e-58*(1.0 - cos(theta)**2)**15.5*(8.44042932295892e+77*cos(theta)**47 - 5.88651877297974e+78*cos(theta)**45 + 1.90446195596403e+79*cos(theta)**43 - 3.79631158109386e+79*cos(theta)**41 + 5.22311324915599e+79*cos(theta)**39 - 5.26575090833277e+79*cos(theta)**37 + 4.0310231091375e+79*cos(theta)**35 - 2.39606268724956e+79*cos(theta)**33 + 1.1215612578615e+79*cos(theta)**31 - 4.16887278101996e+78*cos(theta)**29 + 1.23544697014168e+78*cos(theta)**27 - 2.92014738397124e+77*cos(theta)**25 + 5.48899884205121e+76*cos(theta)**23 - 8.15453145648242e+75*cos(theta)**21 + 9.48201332149119e+74*cos(theta)**19 - 8.51141353267713e+73*cos(theta)**17 + 5.78776120222045e+72*cos(theta)**15 - 2.90633632823122e+71*cos(theta)**13 + 1.04083670157041e+70*cos(theta)**11 - 2.53188936693377e+68*cos(theta)**9 + 3.89521441066733e+66*cos(theta)**7 - 3.38714296579768e+64*cos(theta)**5 + 1.36248711415836e+62*cos(theta)**3 - 1.60104243731887e+59*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl78_m_minus_30(theta, phi):
    return 1.53025939736489e-56*(1.0 - cos(theta)**2)**15*(1.75842277561644e+76*cos(theta)**48 - 1.27967799412603e+77*cos(theta)**46 + 4.32832262719098e+77*cos(theta)**44 - 9.03883709784254e+77*cos(theta)**42 + 1.305778312289e+78*cos(theta)**40 - 1.38572392324547e+78*cos(theta)**38 + 1.11972864142708e+78*cos(theta)**36 - 7.04724319779284e+77*cos(theta)**34 + 3.50487893081718e+77*cos(theta)**32 - 1.38962426033999e+77*cos(theta)**30 + 4.41231060764886e+76*cos(theta)**28 - 1.12313360921971e+76*cos(theta)**26 + 2.28708285085467e+75*cos(theta)**24 - 3.70660520749201e+74*cos(theta)**22 + 4.7410066607456e+73*cos(theta)**20 - 4.72856307370952e+72*cos(theta)**18 + 3.61735075138778e+71*cos(theta)**16 - 2.07595452016515e+70*cos(theta)**14 + 8.6736391797534e+68*cos(theta)**12 - 2.53188936693377e+67*cos(theta)**10 + 4.86901801333416e+65*cos(theta)**8 - 5.64523827632946e+63*cos(theta)**6 + 3.4062177853959e+61*cos(theta)**4 - 8.00521218659435e+58*cos(theta)**2 + 3.06009640160334e+55)*sin(30*phi)

#@torch.jit.script
def Yl78_m_minus_29(theta, phi):
    return 1.1132045504982e-54*(1.0 - cos(theta)**2)**14.5*(3.58861790942131e+74*cos(theta)**49 - 2.72271913643836e+75*cos(theta)**47 + 9.61849472709107e+75*cos(theta)**45 - 2.10205513903315e+76*cos(theta)**43 + 3.18482515192438e+76*cos(theta)**41 - 3.55313826473196e+76*cos(theta)**39 + 3.0262936254786e+76*cos(theta)**37 - 2.01349805651224e+76*cos(theta)**35 + 1.06208452449005e+76*cos(theta)**33 - 4.48265890432253e+75*cos(theta)**31 + 1.52148641643064e+75*cos(theta)**29 - 4.15975410822115e+74*cos(theta)**27 + 9.14833140341869e+73*cos(theta)**25 - 1.61156748151827e+73*cos(theta)**23 + 2.25762221940266e+72*cos(theta)**21 - 2.48871740721554e+71*cos(theta)**19 + 2.12785338316928e+70*cos(theta)**17 - 1.3839696801101e+69*cos(theta)**15 + 6.67203013827184e+67*cos(theta)**13 - 2.30171760630342e+66*cos(theta)**11 + 5.41002001481574e+64*cos(theta)**9 - 8.06462610904209e+62*cos(theta)**7 + 6.81243557079179e+60*cos(theta)**5 - 2.66840406219812e+58*cos(theta)**3 + 3.06009640160334e+55*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl78_m_minus_28(theta, phi):
    return 8.14238932143812e-53*(1.0 - cos(theta)**2)**14*(7.17723581884262e+72*cos(theta)**50 - 5.67233153424658e+73*cos(theta)**48 + 2.09097711458502e+74*cos(theta)**46 - 4.77739804325715e+74*cos(theta)**44 + 7.58291702839139e+74*cos(theta)**42 - 8.88284566182991e+74*cos(theta)**40 + 7.96393059336475e+74*cos(theta)**38 - 5.59305015697844e+74*cos(theta)**36 + 3.12377801320604e+74*cos(theta)**34 - 1.40083090760079e+74*cos(theta)**32 + 5.07162138810214e+73*cos(theta)**30 - 1.48562646722184e+73*cos(theta)**28 + 3.51858900131488e+72*cos(theta)**26 - 6.71486450632611e+71*cos(theta)**24 + 1.0261919179103e+71*cos(theta)**22 - 1.24435870360777e+70*cos(theta)**20 + 1.18214076842738e+69*cos(theta)**18 - 8.64981050068814e+67*cos(theta)**16 + 4.76573581305132e+66*cos(theta)**14 - 1.91809800525285e+65*cos(theta)**12 + 5.41002001481574e+63*cos(theta)**10 - 1.00807826363026e+62*cos(theta)**8 + 1.1354059284653e+60*cos(theta)**6 - 6.67101015549529e+57*cos(theta)**4 + 1.53004820080167e+55*cos(theta)**2 - 5.71980635813709e+51)*sin(28*phi)

#@torch.jit.script
def Yl78_m_minus_27(theta, phi):
    return 5.98673293105068e-51*(1.0 - cos(theta)**2)**13.5*(1.40730114094953e+71*cos(theta)**51 - 1.15761868045849e+72*cos(theta)**49 + 4.44888747784046e+72*cos(theta)**47 - 1.0616440096127e+73*cos(theta)**45 + 1.76346907637009e+73*cos(theta)**43 - 2.16654772239754e+73*cos(theta)**41 + 2.04203348547814e+73*cos(theta)**39 - 1.51163517756174e+73*cos(theta)**37 + 8.92508003773155e+72*cos(theta)**35 - 4.24494214424482e+72*cos(theta)**33 + 1.63600689938779e+72*cos(theta)**31 - 5.12284988697186e+71*cos(theta)**29 + 1.3031811115981e+71*cos(theta)**27 - 2.68594580253044e+70*cos(theta)**25 + 4.46170399091436e+69*cos(theta)**23 - 5.92551763622747e+68*cos(theta)**21 + 6.22179351803884e+67*cos(theta)**19 - 5.0881238239342e+66*cos(theta)**17 + 3.17715720870088e+65*cos(theta)**15 - 1.47546000404066e+64*cos(theta)**13 + 4.91820001346885e+62*cos(theta)**11 - 1.12008695958918e+61*cos(theta)**9 + 1.62200846923614e+59*cos(theta)**7 - 1.33420203109906e+57*cos(theta)**5 + 5.10016066933891e+54*cos(theta)**3 - 5.71980635813709e+51*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl78_m_minus_26(theta, phi):
    return 4.42370549070559e-49*(1.0 - cos(theta)**2)**13*(2.70634834797987e+69*cos(theta)**52 - 2.31523736091697e+70*cos(theta)**50 + 9.26851557883429e+70*cos(theta)**48 - 2.30792176002761e+71*cos(theta)**46 + 4.00788426447748e+71*cos(theta)**44 - 5.15844695808938e+71*cos(theta)**42 + 5.10508371369535e+71*cos(theta)**40 - 3.977987309373e+71*cos(theta)**38 + 2.47918889936988e+71*cos(theta)**36 - 1.24851239536612e+71*cos(theta)**34 + 5.11252156058683e+70*cos(theta)**32 - 1.70761662899062e+70*cos(theta)**30 + 4.65421825570751e+69*cos(theta)**28 - 1.03305607789632e+69*cos(theta)**26 + 1.85904332954765e+68*cos(theta)**24 - 2.69341710737612e+67*cos(theta)**22 + 3.11089675901942e+66*cos(theta)**20 - 2.82673545774122e+65*cos(theta)**18 + 1.98572325543805e+64*cos(theta)**16 - 1.05390000288618e+63*cos(theta)**14 + 4.09850001122404e+61*cos(theta)**12 - 1.12008695958918e+60*cos(theta)**10 + 2.02751058654518e+58*cos(theta)**8 - 2.22367005183176e+56*cos(theta)**6 + 1.27504016733473e+54*cos(theta)**4 - 2.85990317906855e+51*cos(theta)**2 + 1.04758358207639e+48)*sin(26*phi)

#@torch.jit.script
def Yl78_m_minus_25(theta, phi):
    return 3.28428480068287e-47*(1.0 - cos(theta)**2)**12.5*(5.10631763769787e+67*cos(theta)**53 - 4.5396810998372e+68*cos(theta)**51 + 1.89153379159883e+69*cos(theta)**49 - 4.91047182984598e+69*cos(theta)**47 + 8.90640947661662e+69*cos(theta)**45 - 1.19963882746265e+70*cos(theta)**43 + 1.24514236919399e+70*cos(theta)**41 - 1.01999674599308e+70*cos(theta)**39 + 6.7005105388375e+69*cos(theta)**37 - 3.56717827247464e+69*cos(theta)**35 + 1.54924895775359e+69*cos(theta)**33 - 5.50844073867941e+68*cos(theta)**31 + 1.60490284679569e+68*cos(theta)**29 - 3.82613362183824e+67*cos(theta)**27 + 7.43617331819059e+66*cos(theta)**25 - 1.17105091625049e+66*cos(theta)**23 + 1.48137940905687e+65*cos(theta)**21 - 1.48775550407433e+64*cos(theta)**19 + 1.16807250319885e+63*cos(theta)**17 - 7.02600001924122e+61*cos(theta)**15 + 3.15269231632619e+60*cos(theta)**13 - 1.0182608723538e+59*cos(theta)**11 + 2.25278954060575e+57*cos(theta)**9 - 3.17667150261681e+55*cos(theta)**7 + 2.55008033466945e+53*cos(theta)**5 - 9.53301059689516e+50*cos(theta)**3 + 1.04758358207639e+48*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl78_m_minus_24(theta, phi):
    return 2.44938076334417e-45*(1.0 - cos(theta)**2)**12*(9.45614377351457e+65*cos(theta)**54 - 8.73015596122539e+66*cos(theta)**52 + 3.78306758319767e+67*cos(theta)**50 - 1.02301496455125e+68*cos(theta)**48 + 1.93617597317753e+68*cos(theta)**46 - 2.72645188059692e+68*cos(theta)**44 + 2.96462468855712e+68*cos(theta)**42 - 2.54999186498269e+68*cos(theta)**40 + 1.7632922470625e+68*cos(theta)**38 - 9.90882853465178e+67*cos(theta)**36 + 4.55661458162819e+67*cos(theta)**34 - 1.72138773083732e+67*cos(theta)**32 + 5.34967615598565e+66*cos(theta)**30 - 1.36647629351366e+66*cos(theta)**28 + 2.86006666084254e+65*cos(theta)**26 - 4.87937881771036e+64*cos(theta)**24 + 6.7335427684403e+63*cos(theta)**22 - 7.43877752037164e+62*cos(theta)**20 + 6.48929168443807e+61*cos(theta)**18 - 4.39125001202576e+60*cos(theta)**16 + 2.25192308309013e+59*cos(theta)**14 - 8.485507269615e+57*cos(theta)**12 + 2.25278954060575e+56*cos(theta)**10 - 3.97083937827101e+54*cos(theta)**8 + 4.25013389111576e+52*cos(theta)**6 - 2.38325264922379e+50*cos(theta)**4 + 5.23791791038195e+47*cos(theta)**2 - 1.88346562760948e+44)*sin(24*phi)

#@torch.jit.script
def Yl78_m_minus_23(theta, phi):
    return 1.83458455664341e-43*(1.0 - cos(theta)**2)**11.5*(1.71929886791174e+64*cos(theta)**55 - 1.64719923796705e+65*cos(theta)**53 + 7.41777957489739e+65*cos(theta)**51 - 2.08778564194132e+66*cos(theta)**49 + 4.11952334718622e+66*cos(theta)**47 - 6.05878195688205e+66*cos(theta)**45 + 6.89447601990027e+66*cos(theta)**43 - 6.21949235361633e+66*cos(theta)**41 + 4.52126217195513e+66*cos(theta)**39 - 2.6780617661221e+66*cos(theta)**37 + 1.3018898804652e+66*cos(theta)**35 - 5.21632645708278e+65*cos(theta)**33 + 1.72570198580182e+65*cos(theta)**31 - 4.71198721901261e+64*cos(theta)**29 + 1.0592839484602e+64*cos(theta)**27 - 1.95175152708415e+63*cos(theta)**25 + 2.92762729062622e+62*cos(theta)**23 - 3.54227500970078e+61*cos(theta)**21 + 3.41541667602004e+60*cos(theta)**19 - 2.58308824236809e+59*cos(theta)**17 + 1.50128205539342e+58*cos(theta)**15 - 6.52731328431923e+56*cos(theta)**13 + 2.04799049145977e+55*cos(theta)**11 - 4.41204375363445e+53*cos(theta)**9 + 6.07161984445108e+51*cos(theta)**7 - 4.76650529844758e+49*cos(theta)**5 + 1.74597263679398e+47*cos(theta)**3 - 1.88346562760948e+44*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl78_m_minus_22(theta, phi):
    return 1.37972468276841e-41*(1.0 - cos(theta)**2)**11*(3.07017654984239e+62*cos(theta)**56 - 3.05036895919825e+63*cos(theta)**54 + 1.42649607209565e+64*cos(theta)**52 - 4.17557128388264e+64*cos(theta)**50 + 8.58234030663797e+64*cos(theta)**48 - 1.31712651236566e+65*cos(theta)**46 + 1.56692636815915e+65*cos(theta)**44 - 1.48083151276579e+65*cos(theta)**42 + 1.13031554298878e+65*cos(theta)**40 - 7.04753096347922e+64*cos(theta)**38 + 3.61636077906999e+64*cos(theta)**36 - 1.53421366384788e+64*cos(theta)**34 + 5.39281870563069e+63*cos(theta)**32 - 1.57066240633754e+63*cos(theta)**30 + 3.78315695878642e+62*cos(theta)**28 - 7.50673664263133e+61*cos(theta)**26 + 1.21984470442759e+61*cos(theta)**24 - 1.61012500440945e+60*cos(theta)**22 + 1.70770833801002e+59*cos(theta)**20 - 1.43504902353783e+58*cos(theta)**18 + 9.38301284620889e+56*cos(theta)**16 - 4.66236663165659e+55*cos(theta)**14 + 1.70665874288314e+54*cos(theta)**12 - 4.41204375363445e+52*cos(theta)**10 + 7.58952480556385e+50*cos(theta)**8 - 7.94417549741263e+48*cos(theta)**6 + 4.36493159198496e+46*cos(theta)**4 - 9.41732813804738e+43*cos(theta)**2 + 3.33003116621195e+40)*sin(22*phi)

#@torch.jit.script
def Yl78_m_minus_21(theta, phi):
    return 1.04166929211579e-39*(1.0 - cos(theta)**2)**10.5*(5.3862746488463e+60*cos(theta)**57 - 5.54612538036045e+61*cos(theta)**55 + 2.69150202282198e+62*cos(theta)**53 - 8.18739467427968e+62*cos(theta)**51 + 1.75149802176285e+63*cos(theta)**49 - 2.80239683482056e+63*cos(theta)**47 + 3.48205859590923e+63*cos(theta)**45 - 3.4437942157344e+63*cos(theta)**43 + 2.75686717802142e+63*cos(theta)**41 - 1.80705922140493e+63*cos(theta)**39 + 9.77394805154052e+62*cos(theta)**37 - 4.38346761099393e+62*cos(theta)**35 + 1.63418748655476e+62*cos(theta)**33 - 5.06665292366947e+61*cos(theta)**31 + 1.30453688234015e+61*cos(theta)**29 - 2.7802728306042e+60*cos(theta)**27 + 4.87937881771036e+59*cos(theta)**25 - 7.00054349743237e+58*cos(theta)**23 + 8.13194446671437e+57*cos(theta)**21 - 7.55288959756753e+56*cos(theta)**19 + 5.51941932129935e+55*cos(theta)**17 - 3.10824442110439e+54*cos(theta)**15 + 1.31281441760242e+53*cos(theta)**13 - 4.01094886694041e+51*cos(theta)**11 + 8.43280533951539e+49*cos(theta)**9 - 1.13488221391609e+48*cos(theta)**7 + 8.72986318396992e+45*cos(theta)**5 - 3.13910937934913e+43*cos(theta)**3 + 3.33003116621195e+40*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl78_m_minus_20(theta, phi):
    return 7.89335173229645e-38*(1.0 - cos(theta)**2)**10*(9.28668042904535e+58*cos(theta)**58 - 9.90379532207224e+59*cos(theta)**56 + 4.9842630052259e+60*cos(theta)**54 - 1.57449897582302e+61*cos(theta)**52 + 3.5029960435257e+61*cos(theta)**50 - 5.8383267392095e+61*cos(theta)**48 + 7.56969259980266e+61*cos(theta)**46 - 7.82680503576e+61*cos(theta)**44 + 6.56396947147957e+61*cos(theta)**42 - 4.51764805351232e+61*cos(theta)**40 + 2.57209159251066e+61*cos(theta)**38 - 1.21762989194276e+61*cos(theta)**36 + 4.80643378398457e+60*cos(theta)**34 - 1.58332903864671e+60*cos(theta)**32 + 4.34845627446715e+59*cos(theta)**30 - 9.92954582358641e+58*cos(theta)**28 + 1.87668416065783e+58*cos(theta)**26 - 2.91689312393016e+57*cos(theta)**24 + 3.69633839396108e+56*cos(theta)**22 - 3.77644479878376e+55*cos(theta)**20 + 3.06634406738853e+54*cos(theta)**18 - 1.94265276319025e+53*cos(theta)**16 + 9.37724584001728e+51*cos(theta)**14 - 3.34245738911701e+50*cos(theta)**12 + 8.43280533951539e+48*cos(theta)**10 - 1.41860276739511e+47*cos(theta)**8 + 1.45497719732832e+45*cos(theta)**6 - 7.84777344837282e+42*cos(theta)**4 + 1.66501558310597e+40*cos(theta)**2 - 5.79942731837678e+36)*sin(20*phi)

#@torch.jit.script
def Yl78_m_minus_19(theta, phi):
    return 6.00206230454399e-36*(1.0 - cos(theta)**2)**9.5*(1.57401363204159e+57*cos(theta)**59 - 1.73750795124074e+58*cos(theta)**57 + 9.06229637313799e+58*cos(theta)**55 - 2.97075278457173e+59*cos(theta)**53 + 6.86861969318765e+59*cos(theta)**51 - 1.1914952528999e+60*cos(theta)**49 + 1.61057289357504e+60*cos(theta)**47 - 1.73929000794667e+60*cos(theta)**45 + 1.52650452825106e+60*cos(theta)**43 - 1.10186537890544e+60*cos(theta)**41 + 6.59510664746324e+59*cos(theta)**39 - 3.29089159984529e+59*cos(theta)**37 + 1.37326679542416e+59*cos(theta)**35 - 4.79796678377791e+58*cos(theta)**33 + 1.40272783047328e+58*cos(theta)**31 - 3.42398131847807e+57*cos(theta)**29 + 6.95068207651049e+56*cos(theta)**27 - 1.16675724957206e+56*cos(theta)**25 + 1.60710364954829e+55*cos(theta)**23 - 1.79830704703989e+54*cos(theta)**21 + 1.61386529862554e+53*cos(theta)**19 - 1.14273691952367e+52*cos(theta)**17 + 6.25149722667819e+50*cos(theta)**15 - 2.57112106855155e+49*cos(theta)**13 + 7.66618667228672e+47*cos(theta)**11 - 1.57622529710568e+46*cos(theta)**9 + 2.07853885332617e+44*cos(theta)**7 - 1.56955468967456e+42*cos(theta)**5 + 5.55005194368658e+39*cos(theta)**3 - 5.79942731837678e+36*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl78_m_minus_18(theta, phi):
    return 4.5789087794189e-34*(1.0 - cos(theta)**2)**9*(2.62335605340264e+55*cos(theta)**60 - 2.99570336420818e+56*cos(theta)**58 + 1.61826720948893e+57*cos(theta)**56 - 5.5013940455032e+57*cos(theta)**54 + 1.32088840253609e+58*cos(theta)**52 - 2.3829905057998e+58*cos(theta)**50 + 3.35536019494799e+58*cos(theta)**48 - 3.78106523466667e+58*cos(theta)**46 + 3.46932847329787e+58*cos(theta)**44 - 2.62348899739391e+58*cos(theta)**42 + 1.64877666186581e+58*cos(theta)**40 - 8.66024105222446e+57*cos(theta)**38 + 3.81462998728934e+57*cos(theta)**36 - 1.41116670111115e+57*cos(theta)**34 + 4.38352447022898e+56*cos(theta)**32 - 1.14132710615936e+56*cos(theta)**30 + 2.4823864558966e+55*cos(theta)**28 - 4.48752788296947e+54*cos(theta)**26 + 6.69626520645123e+53*cos(theta)**24 - 8.1741229410904e+52*cos(theta)**22 + 8.0693264931277e+51*cos(theta)**20 - 6.34853844179819e+50*cos(theta)**18 + 3.90718576667387e+49*cos(theta)**16 - 1.83651504896539e+48*cos(theta)**14 + 6.38848889357227e+46*cos(theta)**12 - 1.57622529710568e+45*cos(theta)**10 + 2.59817356665771e+43*cos(theta)**8 - 2.61592448279094e+41*cos(theta)**6 + 1.38751298592164e+39*cos(theta)**4 - 2.89971365918839e+36*cos(theta)**2 + 9.96465174978828e+32)*sin(18*phi)

#@torch.jit.script
def Yl78_m_minus_17(theta, phi):
    return 3.50398731809295e-32*(1.0 - cos(theta)**2)**8.5*(4.30058369410269e+53*cos(theta)**61 - 5.0774633291664e+54*cos(theta)**59 + 2.83906527980514e+55*cos(theta)**57 - 1.00025346281876e+56*cos(theta)**55 + 2.49224226893601e+56*cos(theta)**53 - 4.67253040352901e+56*cos(theta)**51 + 6.8476738672408e+56*cos(theta)**49 - 8.04481964822695e+56*cos(theta)**47 + 7.70961882955083e+56*cos(theta)**45 - 6.10113720324166e+56*cos(theta)**43 + 4.02140649235563e+56*cos(theta)**41 - 2.2205746287755e+56*cos(theta)**39 + 1.03098107764577e+56*cos(theta)**37 - 4.03190486031757e+55*cos(theta)**35 + 1.32834074855424e+55*cos(theta)**33 - 3.68170034244954e+54*cos(theta)**31 + 8.55995329619518e+53*cos(theta)**29 - 1.66204736406277e+53*cos(theta)**27 + 2.67850608258049e+52*cos(theta)**25 - 3.55396649612626e+51*cos(theta)**23 + 3.8425364252989e+50*cos(theta)**21 - 3.34133602199905e+49*cos(theta)**19 + 2.29834456863169e+48*cos(theta)**17 - 1.22434336597693e+47*cos(theta)**15 + 4.91422222582482e+45*cos(theta)**13 - 1.43293208827789e+44*cos(theta)**11 + 2.88685951850857e+42*cos(theta)**9 - 3.73703497541563e+40*cos(theta)**7 + 2.77502597184329e+38*cos(theta)**5 - 9.66571219729463e+35*cos(theta)**3 + 9.96465174978828e+32*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl78_m_minus_16(theta, phi):
    return 2.68918186012676e-30*(1.0 - cos(theta)**2)**8*(6.93642531306886e+51*cos(theta)**62 - 8.46243888194401e+52*cos(theta)**60 + 4.89494013759506e+53*cos(theta)**58 - 1.78616689789065e+54*cos(theta)**56 + 4.61526346099262e+54*cos(theta)**54 - 8.98563539140195e+54*cos(theta)**52 + 1.36953477344816e+55*cos(theta)**50 - 1.67600409338061e+55*cos(theta)**48 + 1.67600409338061e+55*cos(theta)**46 - 1.38662209164583e+55*cos(theta)**44 + 9.57477736275151e+54*cos(theta)**42 - 5.55143657193876e+54*cos(theta)**40 + 2.71310809906781e+54*cos(theta)**38 - 1.11997357231044e+54*cos(theta)**36 + 3.90688455457129e+53*cos(theta)**34 - 1.15053135701548e+53*cos(theta)**32 + 2.85331776539839e+52*cos(theta)**30 - 5.93588344308131e+51*cos(theta)**28 + 1.03019464714634e+51*cos(theta)**26 - 1.48081937338594e+50*cos(theta)**24 + 1.74660746604496e+49*cos(theta)**22 - 1.67066801099952e+48*cos(theta)**20 + 1.27685809368427e+47*cos(theta)**18 - 7.65214603735579e+45*cos(theta)**16 + 3.51015873273201e+44*cos(theta)**14 - 1.19411007356491e+43*cos(theta)**12 + 2.88685951850857e+41*cos(theta)**10 - 4.67129371926953e+39*cos(theta)**8 + 4.62504328640548e+37*cos(theta)**6 - 2.41642804932366e+35*cos(theta)**4 + 4.98232587489414e+32*cos(theta)**2 - 1.69179146855489e+29)*sin(16*phi)

#@torch.jit.script
def Yl78_m_minus_15(theta, phi):
    return 2.06944731590383e-28*(1.0 - cos(theta)**2)**7.5*(1.10101989096331e+50*cos(theta)**63 - 1.38728506261377e+51*cos(theta)**61 + 8.29650870778824e+51*cos(theta)**59 - 3.13362613665026e+52*cos(theta)**57 + 8.39138811089566e+52*cos(theta)**55 - 1.6954029040381e+53*cos(theta)**53 + 2.68536230087874e+53*cos(theta)**51 - 3.42041651710329e+53*cos(theta)**49 + 3.56596615612897e+53*cos(theta)**47 - 3.08138242587963e+53*cos(theta)**45 + 2.22669240994221e+53*cos(theta)**43 - 1.35400891998506e+53*cos(theta)**41 + 6.95668743350721e+52*cos(theta)**39 - 3.02695560083902e+52*cos(theta)**37 + 1.11625272987751e+52*cos(theta)**35 - 3.48645865762267e+51*cos(theta)**33 + 9.20425085612385e+50*cos(theta)**31 - 2.04685635968321e+50*cos(theta)**29 + 3.81553573017164e+49*cos(theta)**27 - 5.92327749354377e+48*cos(theta)**25 + 7.59394550454329e+47*cos(theta)**23 - 7.95556195714059e+46*cos(theta)**21 + 6.720305756233e+45*cos(theta)**19 - 4.50126237491517e+44*cos(theta)**17 + 2.34010582182134e+43*cos(theta)**15 - 9.18546210434546e+41*cos(theta)**13 + 2.6244177440987e+40*cos(theta)**11 - 5.19032635474393e+38*cos(theta)**9 + 6.60720469486497e+36*cos(theta)**7 - 4.83285609864731e+34*cos(theta)**5 + 1.66077529163138e+32*cos(theta)**3 - 1.69179146855489e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl78_m_minus_14(theta, phi):
    return 1.59656217462807e-26*(1.0 - cos(theta)**2)**7*(1.72034357963017e+48*cos(theta)**64 - 2.23755655260286e+49*cos(theta)**62 + 1.38275145129804e+50*cos(theta)**60 - 5.40280368387976e+50*cos(theta)**58 + 1.49846216265994e+51*cos(theta)**56 - 3.13963500747797e+51*cos(theta)**54 + 5.16415827092066e+51*cos(theta)**52 - 6.84083303420659e+51*cos(theta)**50 + 7.42909615860201e+51*cos(theta)**48 - 6.69865744756441e+51*cos(theta)**46 + 5.06066456805048e+51*cos(theta)**44 - 3.2238307618692e+51*cos(theta)**42 + 1.7391718583768e+51*cos(theta)**40 - 7.96567263378688e+50*cos(theta)**38 + 3.10070202743753e+50*cos(theta)**36 - 1.02542901694784e+50*cos(theta)**34 + 2.8763283925387e+49*cos(theta)**32 - 6.82285453227737e+48*cos(theta)**30 + 1.36269133220416e+48*cos(theta)**28 - 2.27818365136299e+47*cos(theta)**26 + 3.16414396022637e+46*cos(theta)**24 - 3.616164525973e+45*cos(theta)**22 + 3.3601528781165e+44*cos(theta)**20 - 2.50070131939732e+43*cos(theta)**18 + 1.46256613863834e+42*cos(theta)**16 - 6.56104436024676e+40*cos(theta)**14 + 2.18701478674892e+39*cos(theta)**12 - 5.19032635474393e+37*cos(theta)**10 + 8.25900586858121e+35*cos(theta)**8 - 8.05476016441219e+33*cos(theta)**6 + 4.15193822907845e+31*cos(theta)**4 - 8.45895734277443e+28*cos(theta)**2 + 2.84239158023334e+25)*sin(14*phi)

#@torch.jit.script
def Yl78_m_minus_13(theta, phi):
    return 1.23462886930322e-24*(1.0 - cos(theta)**2)**6.5*(2.64668243020027e+46*cos(theta)**65 - 3.55167706762358e+47*cos(theta)**63 + 2.26680565786564e+48*cos(theta)**61 - 9.15729437945722e+48*cos(theta)**59 + 2.6288809871227e+49*cos(theta)**57 - 5.70842728632358e+49*cos(theta)**55 + 9.7436948507937e+49*cos(theta)**53 - 1.34133981062874e+50*cos(theta)**51 + 1.51614207318408e+50*cos(theta)**49 - 1.42524626543924e+50*cos(theta)**47 + 1.12459212623344e+50*cos(theta)**45 - 7.49728084155627e+49*cos(theta)**43 + 4.24188258140684e+49*cos(theta)**41 - 2.04248016250946e+49*cos(theta)**39 + 8.38027574983116e+48*cos(theta)**37 - 2.92979719127956e+48*cos(theta)**35 + 8.71614664405668e+47*cos(theta)**33 - 2.20092081686367e+47*cos(theta)**31 + 4.6989356282902e+46*cos(theta)**29 - 8.43771722727032e+45*cos(theta)**27 + 1.26565758409055e+45*cos(theta)**25 - 1.57224544607522e+44*cos(theta)**23 + 1.6000727991031e+43*cos(theta)**21 - 1.31615858915648e+42*cos(theta)**19 + 8.60333022728435e+40*cos(theta)**17 - 4.37402957349784e+39*cos(theta)**15 + 1.68231906672994e+38*cos(theta)**13 - 4.71847850431266e+36*cos(theta)**11 + 9.17667318731246e+34*cos(theta)**9 - 1.15068002348746e+33*cos(theta)**7 + 8.3038764581569e+30*cos(theta)**5 - 2.81965244759148e+28*cos(theta)**3 + 2.84239158023334e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl78_m_minus_12(theta, phi):
    return 9.56817460133919e-23*(1.0 - cos(theta)**2)**6*(4.01012489424283e+44*cos(theta)**66 - 5.54949541816185e+45*cos(theta)**64 + 3.65613815784781e+46*cos(theta)**62 - 1.52621572990954e+47*cos(theta)**60 + 4.53255342607362e+47*cos(theta)**58 - 1.01936201541493e+48*cos(theta)**56 + 1.80438793533217e+48*cos(theta)**54 - 2.57949963582451e+48*cos(theta)**52 + 3.03228414636817e+48*cos(theta)**50 - 2.96926305299841e+48*cos(theta)**48 + 2.44476549181183e+48*cos(theta)**46 - 1.70392746399006e+48*cos(theta)**44 + 1.0099720431921e+48*cos(theta)**42 - 5.10620040627364e+47*cos(theta)**40 + 2.20533572363978e+47*cos(theta)**38 - 8.1383255313321e+46*cos(theta)**36 + 2.56357254236961e+46*cos(theta)**34 - 6.87787755269896e+45*cos(theta)**32 + 1.56631187609673e+45*cos(theta)**30 - 3.01347043831083e+44*cos(theta)**28 + 4.86791378496365e+43*cos(theta)**26 - 6.55102269198006e+42*cos(theta)**24 + 7.27305817774134e+41*cos(theta)**22 - 6.58079294578241e+40*cos(theta)**20 + 4.77962790404686e+39*cos(theta)**18 - 2.73376848343615e+38*cos(theta)**16 + 1.20165647623567e+37*cos(theta)**14 - 3.93206542026055e+35*cos(theta)**12 + 9.17667318731246e+33*cos(theta)**10 - 1.43835002935932e+32*cos(theta)**8 + 1.38397940969282e+30*cos(theta)**6 - 7.04913111897869e+27*cos(theta)**4 + 1.42119579011667e+25*cos(theta)**2 - 4.73258671367523e+21)*sin(12*phi)

#@torch.jit.script
def Yl78_m_minus_11(theta, phi):
    return 7.42998176421938e-21*(1.0 - cos(theta)**2)**5.5*(5.98526103618333e+42*cos(theta)**67 - 8.53768525871054e+43*cos(theta)**65 + 5.80339390134572e+44*cos(theta)**63 - 2.5019929998517e+45*cos(theta)**61 + 7.68229394249767e+45*cos(theta)**59 - 1.78835441300864e+46*cos(theta)**57 + 3.28070533696758e+46*cos(theta)**55 - 4.8669804449519e+46*cos(theta)**53 + 5.94565518895719e+46*cos(theta)**51 - 6.05972051632328e+46*cos(theta)**49 + 5.20162870598261e+46*cos(theta)**47 - 3.78650547553347e+46*cos(theta)**45 + 2.34877219347001e+46*cos(theta)**43 - 1.24541473323747e+46*cos(theta)**41 + 5.65470698369174e+45*cos(theta)**39 - 2.19954744090057e+45*cos(theta)**37 + 7.32449297819889e+44*cos(theta)**35 - 2.08420531899968e+44*cos(theta)**33 + 5.05261895515075e+43*cos(theta)**31 - 1.03912773734856e+43*cos(theta)**29 + 1.80293103146802e+42*cos(theta)**27 - 2.62040907679203e+41*cos(theta)**25 + 3.16219920771363e+40*cos(theta)**23 - 3.13371092656305e+39*cos(theta)**21 + 2.51559363370887e+38*cos(theta)**19 - 1.60809910790362e+37*cos(theta)**17 + 8.01104317490446e+35*cos(theta)**15 - 3.02466570789273e+34*cos(theta)**13 + 8.34243017028405e+32*cos(theta)**11 - 1.59816669928813e+31*cos(theta)**9 + 1.97711344241831e+29*cos(theta)**7 - 1.40982622379574e+27*cos(theta)**5 + 4.7373193003889e+24*cos(theta)**3 - 4.73258671367523e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl78_m_minus_10(theta, phi):
    return 5.78012469423161e-19*(1.0 - cos(theta)**2)**5*(8.80185446497548e+40*cos(theta)**68 - 1.2935886755622e+42*cos(theta)**66 + 9.06780297085269e+42*cos(theta)**64 - 4.03547258040597e+43*cos(theta)**62 + 1.28038232374961e+44*cos(theta)**60 - 3.0833696776011e+44*cos(theta)**58 + 5.8584023874421e+44*cos(theta)**56 - 9.01292674991092e+44*cos(theta)**54 + 1.14339522864561e+45*cos(theta)**52 - 1.21194410326466e+45*cos(theta)**50 + 1.08367264707971e+45*cos(theta)**48 - 8.23153364246406e+44*cos(theta)**46 + 5.33811862152275e+44*cos(theta)**44 - 2.96527317437494e+44*cos(theta)**42 + 1.41367674592294e+44*cos(theta)**40 - 5.78828273921202e+43*cos(theta)**38 + 2.03458138283303e+43*cos(theta)**36 - 6.13001564411672e+42*cos(theta)**34 + 1.57894342348461e+42*cos(theta)**32 - 3.46375912449521e+41*cos(theta)**30 + 6.43903939810006e+40*cos(theta)**28 - 1.00784964492001e+40*cos(theta)**26 + 1.31758300321401e+39*cos(theta)**24 - 1.42441405752866e+38*cos(theta)**22 + 1.25779681685444e+37*cos(theta)**20 - 8.93388393279787e+35*cos(theta)**18 + 5.00690198431529e+34*cos(theta)**16 - 2.16047550563767e+33*cos(theta)**14 + 6.95202514190338e+31*cos(theta)**12 - 1.59816669928813e+30*cos(theta)**10 + 2.47139180302289e+28*cos(theta)**8 - 2.3497103729929e+26*cos(theta)**6 + 1.18432982509723e+24*cos(theta)**4 - 2.36629335683761e+21*cos(theta)**2 + 7.81987229622477e+17)*sin(10*phi)

#@torch.jit.script
def Yl78_m_minus_9(theta, phi):
    return 4.50404881714018e-17*(1.0 - cos(theta)**2)**4.5*(1.2756310818805e+39*cos(theta)**69 - 1.93072936651075e+40*cos(theta)**67 + 1.39504661090041e+41*cos(theta)**65 - 6.40551203239042e+41*cos(theta)**63 + 2.09898741598297e+42*cos(theta)**61 - 5.22605030101882e+42*cos(theta)**59 + 1.0277898925337e+43*cos(theta)**57 - 1.63871395452926e+43*cos(theta)**55 + 2.15734948801059e+43*cos(theta)**53 - 2.37636098679344e+43*cos(theta)**51 + 2.21157683077492e+43*cos(theta)**49 - 1.75139013669448e+43*cos(theta)**47 + 1.18624858256061e+43*cos(theta)**45 - 6.89598412645334e+42*cos(theta)**43 + 3.44799206322667e+42*cos(theta)**41 - 1.48417506133642e+42*cos(theta)**39 + 5.49886860225142e+41*cos(theta)**37 - 1.75143304117621e+41*cos(theta)**35 + 4.78467704086245e+40*cos(theta)**33 - 1.11734165306297e+40*cos(theta)**31 + 2.22035841313795e+39*cos(theta)**29 - 3.7327764626667e+38*cos(theta)**27 + 5.27033201285605e+37*cos(theta)**25 - 6.1931045979507e+36*cos(theta)**23 + 5.98950865168779e+35*cos(theta)**21 - 4.70204417515677e+34*cos(theta)**19 + 2.94523646136194e+33*cos(theta)**17 - 1.44031700375844e+32*cos(theta)**15 + 5.34771164761798e+30*cos(theta)**13 - 1.45287881753467e+29*cos(theta)**11 + 2.74599089224765e+27*cos(theta)**9 - 3.35672910427557e+25*cos(theta)**7 + 2.36865965019445e+23*cos(theta)**5 - 7.88764452279205e+20*cos(theta)**3 + 7.81987229622477e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl78_m_minus_8(theta, phi):
    return 3.51488997694576e-15*(1.0 - cos(theta)**2)**4*(1.82233011697215e+37*cos(theta)**70 - 2.83930789192757e+38*cos(theta)**68 + 2.11370698621275e+39*cos(theta)**66 - 1.000861255061e+40*cos(theta)**64 + 3.38546357416608e+40*cos(theta)**62 - 8.71008383503137e+40*cos(theta)**60 + 1.77205153885121e+41*cos(theta)**58 - 2.92627491880225e+41*cos(theta)**56 + 3.99509164446406e+41*cos(theta)**54 - 4.56992497460278e+41*cos(theta)**52 + 4.42315366154984e+41*cos(theta)**50 - 3.64872945144684e+41*cos(theta)**48 + 2.57880126643611e+41*cos(theta)**46 - 1.56726911964849e+41*cos(theta)**44 + 8.20950491244446e+40*cos(theta)**42 - 3.71043765334104e+40*cos(theta)**40 + 1.44707068480301e+40*cos(theta)**38 - 4.86509178104501e+39*cos(theta)**36 + 1.40725795319484e+39*cos(theta)**34 - 3.49169266582178e+38*cos(theta)**32 + 7.40119471045984e+37*cos(theta)**30 - 1.33313445095239e+37*cos(theta)**28 + 2.0270507741754e+36*cos(theta)**26 - 2.58046024914613e+35*cos(theta)**24 + 2.72250393258536e+34*cos(theta)**22 - 2.35102208757839e+33*cos(theta)**20 + 1.63624247853441e+32*cos(theta)**18 - 9.00198127349027e+30*cos(theta)**16 + 3.81979403401285e+29*cos(theta)**14 - 1.21073234794556e+28*cos(theta)**12 + 2.74599089224765e+26*cos(theta)**10 - 4.19591138034446e+24*cos(theta)**8 + 3.94776608365742e+22*cos(theta)**6 - 1.97191113069801e+20*cos(theta)**4 + 3.90993614811238e+17*cos(theta)**2 - 128405128016827.0)*sin(8*phi)

#@torch.jit.script
def Yl78_m_minus_7(theta, phi):
    return 2.74656660513642e-13*(1.0 - cos(theta)**2)**3.5*(2.56666213658049e+35*cos(theta)**71 - 4.11493897380808e+36*cos(theta)**69 + 3.15478654658619e+37*cos(theta)**67 - 1.5397865462477e+38*cos(theta)**65 + 5.37375170502552e+38*cos(theta)**63 - 1.42788259590678e+39*cos(theta)**61 + 3.00347718449358e+39*cos(theta)**59 - 5.13381564702149e+39*cos(theta)**57 + 7.26380298993466e+39*cos(theta)**55 - 8.62249995208071e+39*cos(theta)**53 + 8.67285031676439e+39*cos(theta)**51 - 7.44638663560579e+39*cos(theta)**49 + 5.48681120518321e+39*cos(theta)**47 - 3.48282026588553e+39*cos(theta)**45 + 1.90918718894057e+39*cos(theta)**43 - 9.04984793497814e+38*cos(theta)**41 + 3.71043765334104e+38*cos(theta)**39 - 1.31488967055271e+38*cos(theta)**37 + 4.02073700912811e+37*cos(theta)**35 - 1.05808868661266e+37*cos(theta)**33 + 2.38748216466447e+36*cos(theta)**31 - 4.5970153481117e+35*cos(theta)**29 + 7.5075954599089e+34*cos(theta)**27 - 1.03218409965845e+34*cos(theta)**25 + 1.18369736199364e+33*cos(theta)**23 - 1.11953432741828e+32*cos(theta)**21 + 8.61180251860215e+30*cos(theta)**19 - 5.2952831020531e+29*cos(theta)**17 + 2.54652935600856e+28*cos(theta)**15 - 9.31332575342735e+26*cos(theta)**13 + 2.49635535658877e+25*cos(theta)**11 - 4.66212375593829e+23*cos(theta)**9 + 5.63966583379632e+21*cos(theta)**7 - 3.94382226139602e+19*cos(theta)**5 + 1.30331204937079e+17*cos(theta)**3 - 128405128016827.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl78_m_minus_6(theta, phi):
    return 2.14865083419056e-11*(1.0 - cos(theta)**2)**3*(3.56480852302846e+33*cos(theta)**72 - 5.87848424829725e+34*cos(theta)**70 + 4.63939198027381e+35*cos(theta)**68 - 2.33300991855712e+36*cos(theta)**66 + 8.39648703910238e+36*cos(theta)**64 - 2.30303644501094e+37*cos(theta)**62 + 5.00579530748929e+37*cos(theta)**60 - 8.85140628796808e+37*cos(theta)**58 + 1.29710767677405e+38*cos(theta)**56 - 1.59675925038532e+38*cos(theta)**54 + 1.667855830147e+38*cos(theta)**52 - 1.48927732712116e+38*cos(theta)**50 + 1.1430856677465e+38*cos(theta)**48 - 7.57134840409897e+37*cos(theta)**46 + 4.33906179304675e+37*cos(theta)**44 - 2.15472569880432e+37*cos(theta)**42 + 9.2760941333526e+36*cos(theta)**40 - 3.4602359751387e+36*cos(theta)**38 + 1.11687139142448e+36*cos(theta)**36 - 3.11202554886077e+35*cos(theta)**34 + 7.46088176457645e+34*cos(theta)**32 - 1.53233844937057e+34*cos(theta)**30 + 2.68128409282461e+33*cos(theta)**28 - 3.96993884484019e+32*cos(theta)**26 + 4.93207234164015e+31*cos(theta)**24 - 5.08879239735582e+30*cos(theta)**22 + 4.30590125930107e+29*cos(theta)**20 - 2.94182394558506e+28*cos(theta)**18 + 1.59158084750535e+27*cos(theta)**16 - 6.65237553816239e+25*cos(theta)**14 + 2.08029613049064e+24*cos(theta)**12 - 4.66212375593829e+22*cos(theta)**10 + 7.04958229224539e+20*cos(theta)**8 - 6.57303710232671e+18*cos(theta)**6 + 3.25828012342699e+16*cos(theta)**4 - 64202564008413.5*cos(theta)**2 + 20981230068.109)*sin(6*phi)

#@torch.jit.script
def Yl78_m_minus_5(theta, phi):
    return 1.68254589528387e-9*(1.0 - cos(theta)**2)**2.5*(4.88329934661433e+31*cos(theta)**73 - 8.27955527929191e+32*cos(theta)**71 + 6.72375649315045e+33*cos(theta)**69 - 3.4821043560554e+34*cos(theta)**67 + 1.29176723678498e+35*cos(theta)**65 - 3.65561340477927e+35*cos(theta)**63 + 8.20622181555622e+35*cos(theta)**61 - 1.50023835389289e+36*cos(theta)**59 + 2.27562750311236e+36*cos(theta)**57 - 2.90319863706421e+36*cos(theta)**55 + 3.14689779273019e+36*cos(theta)**53 - 2.92015162180619e+36*cos(theta)**51 + 2.33282789336021e+36*cos(theta)**49 - 1.61092519236148e+36*cos(theta)**47 + 9.6423595401039e+35*cos(theta)**45 - 5.01098999721935e+35*cos(theta)**43 + 2.26246198374454e+35*cos(theta)**41 - 8.87239993625308e+34*cos(theta)**39 + 3.01857132817426e+34*cos(theta)**37 - 8.89150156817362e+33*cos(theta)**35 + 2.26087326199287e+33*cos(theta)**33 - 4.94302725603409e+32*cos(theta)**31 + 9.24580721663657e+31*cos(theta)**29 - 1.47034772031118e+31*cos(theta)**27 + 1.97282893665606e+30*cos(theta)**25 - 2.21251843363296e+29*cos(theta)**23 + 2.05042917109575e+28*cos(theta)**21 - 1.54832839241319e+27*cos(theta)**19 + 9.36224027944325e+25*cos(theta)**17 - 4.43491702544159e+24*cos(theta)**15 + 1.60022779268511e+23*cos(theta)**13 - 4.23829432358026e+21*cos(theta)**11 + 7.83286921360599e+19*cos(theta)**9 - 9.39005300332387e+17*cos(theta)**7 + 6.51656024685397e+15*cos(theta)**5 - 21400854669471.2*cos(theta)**3 + 20981230068.109*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl78_m_minus_4(theta, phi):
    return 1.31862657929992e-7*(1.0 - cos(theta)**2)**2*(6.59905317110044e+29*cos(theta)**74 - 1.14993823323499e+31*cos(theta)**72 + 9.60536641878636e+31*cos(theta)**70 - 5.12074170008147e+32*cos(theta)**68 + 1.95722308603785e+33*cos(theta)**66 - 5.71189594496761e+33*cos(theta)**64 + 1.32358416379939e+34*cos(theta)**62 - 2.50039725648816e+34*cos(theta)**60 + 3.92349569502131e+34*cos(theta)**58 - 5.18428328047181e+34*cos(theta)**56 + 5.8275885050559e+34*cos(theta)**54 - 5.61567619578114e+34*cos(theta)**52 + 4.66565578672042e+34*cos(theta)**50 - 3.35609415075309e+34*cos(theta)**48 + 2.09616511741389e+34*cos(theta)**46 - 1.1388613630044e+34*cos(theta)**44 + 5.3868142470108e+33*cos(theta)**42 - 2.21809998406327e+33*cos(theta)**40 + 7.94360875835331e+32*cos(theta)**38 - 2.46986154671489e+32*cos(theta)**36 + 6.64962724115549e+31*cos(theta)**34 - 1.54469601751065e+31*cos(theta)**32 + 3.08193573887886e+30*cos(theta)**30 - 5.25124185825422e+29*cos(theta)**28 + 7.5878036025233e+28*cos(theta)**26 - 9.21882680680401e+27*cos(theta)**24 + 9.32013259588977e+26*cos(theta)**22 - 7.74164196206594e+25*cos(theta)**20 + 5.20124459969069e+24*cos(theta)**18 - 2.771823140901e+23*cos(theta)**16 + 1.14301985191794e+22*cos(theta)**14 - 3.53191193631688e+20*cos(theta)**12 + 7.83286921360599e+18*cos(theta)**10 - 1.17375662541548e+17*cos(theta)**8 + 1.08609337447566e+15*cos(theta)**6 - 5350213667367.79*cos(theta)**4 + 10490615034.0545*cos(theta)**2 - 3416025.73560876)*sin(4*phi)

#@torch.jit.script
def Yl78_m_minus_3(theta, phi):
    return 1.03409248823124e-5*(1.0 - cos(theta)**2)**1.5*(8.79873756146726e+27*cos(theta)**75 - 1.57525785374656e+29*cos(theta)**73 + 1.35286850968822e+30*cos(theta)**71 - 7.42136478272677e+30*cos(theta)**69 + 2.92122848662366e+31*cos(theta)**67 - 8.78753222302709e+31*cos(theta)**65 + 2.10092724412602e+32*cos(theta)**63 - 4.09901189588223e+32*cos(theta)**61 + 6.64999270342595e+32*cos(theta)**59 - 9.09523382538913e+32*cos(theta)**57 + 1.0595615463738e+33*cos(theta)**55 - 1.0595615463738e+33*cos(theta)**53 + 9.14834467984396e+32*cos(theta)**51 - 6.8491717362308e+32*cos(theta)**49 + 4.45992578173168e+32*cos(theta)**47 - 2.53080302889866e+32*cos(theta)**45 + 1.25274749930484e+32*cos(theta)**43 - 5.40999996112993e+31*cos(theta)**41 + 2.03682275855213e+31*cos(theta)**39 - 6.67530147760782e+30*cos(theta)**37 + 1.899893497473e+30*cos(theta)**35 - 4.68089702275955e+29*cos(theta)**33 + 9.9417281899318e+28*cos(theta)**31 - 1.81077305457042e+28*cos(theta)**29 + 2.81029763056419e+27*cos(theta)**27 - 3.68753072272161e+26*cos(theta)**25 + 4.05223156343034e+25*cos(theta)**23 - 3.68649617241235e+24*cos(theta)**21 + 2.73749715773194e+23*cos(theta)**19 - 1.63048420053e+22*cos(theta)**17 + 7.62013234611958e+20*cos(theta)**15 - 2.71685533562837e+19*cos(theta)**13 + 7.12079019418727e+17*cos(theta)**11 - 1.30417402823943e+16*cos(theta)**9 + 155156196353666.0*cos(theta)**7 - 1070042733473.56*cos(theta)**5 + 3496871678.01817*cos(theta)**3 - 3416025.73560876*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl78_m_minus_2(theta, phi):
    return 0.000811350837805408*(1.0 - cos(theta)**2)*(1.15772862650885e+26*cos(theta)**76 - 2.12872682938724e+27*cos(theta)**74 + 1.87898404123364e+28*cos(theta)**72 - 1.06019496896097e+29*cos(theta)**70 + 4.29592424503479e+29*cos(theta)**68 - 1.33144427621622e+30*cos(theta)**66 + 3.2826988189469e+30*cos(theta)**64 - 6.61130950948746e+30*cos(theta)**62 + 1.10833211723766e+31*cos(theta)**60 - 1.56814376299813e+31*cos(theta)**58 + 1.89207418995321e+31*cos(theta)**56 - 1.96215101180333e+31*cos(theta)**54 + 1.75929705381615e+31*cos(theta)**52 - 1.36983434724616e+31*cos(theta)**50 + 9.29151204527434e+30*cos(theta)**48 - 5.50174571499709e+30*cos(theta)**46 + 2.84715340751099e+30*cos(theta)**44 - 1.28809522884046e+30*cos(theta)**42 + 5.09205689638033e+29*cos(theta)**40 - 1.75665828358101e+29*cos(theta)**38 + 5.27748193742499e+28*cos(theta)**36 - 1.37673441845869e+28*cos(theta)**34 + 3.10679005935369e+27*cos(theta)**32 - 6.03591018190141e+26*cos(theta)**30 + 1.0036777252015e+26*cos(theta)**28 - 1.41828104720062e+25*cos(theta)**26 + 1.68842981809597e+24*cos(theta)**24 - 1.67568007836925e+23*cos(theta)**22 + 1.36874857886597e+22*cos(theta)**20 - 9.05824555849999e+20*cos(theta)**18 + 4.76258271632474e+19*cos(theta)**16 - 1.94061095402027e+18*cos(theta)**14 + 5.93399182848939e+16*cos(theta)**12 - 1.30417402823943e+15*cos(theta)**10 + 19394524544208.3*cos(theta)**8 - 178340455578.926*cos(theta)**6 + 874217919.504542*cos(theta)**4 - 1708012.86780438*cos(theta)**2 + 554.909963549181)*sin(2*phi)

#@torch.jit.script
def Yl78_m_minus_1(theta, phi):
    return 0.063679412066746*(1.0 - cos(theta)**2)**0.5*(1.50354367079071e+24*cos(theta)**77 - 2.83830243918299e+25*cos(theta)**75 + 2.57395074141594e+26*cos(theta)**73 - 1.49323235064925e+27*cos(theta)**71 + 6.22597716671709e+27*cos(theta)**69 - 1.98723026300929e+28*cos(theta)**67 + 5.05030587530292e+28*cos(theta)**65 - 1.04941420785515e+29*cos(theta)**63 + 1.81693789711092e+29*cos(theta)**61 - 2.65787078474259e+29*cos(theta)**59 + 3.31942840342669e+29*cos(theta)**57 - 3.56754729418788e+29*cos(theta)**55 + 3.31942840342669e+29*cos(theta)**53 - 2.68594970048267e+29*cos(theta)**51 + 1.89622694801517e+29*cos(theta)**49 - 1.17058419468023e+29*cos(theta)**47 + 6.32700757224665e+28*cos(theta)**45 - 2.99557029962897e+28*cos(theta)**43 + 1.24196509667813e+28*cos(theta)**41 - 4.50425200918207e+27*cos(theta)**39 + 1.42634646957432e+27*cos(theta)**37 - 3.93352690988198e+26*cos(theta)**35 + 9.41451533137481e+25*cos(theta)**33 - 1.94706780061336e+25*cos(theta)**31 + 3.4609576731086e+24*cos(theta)**29 - 5.25289276740969e+23*cos(theta)**27 + 6.75371927238389e+22*cos(theta)**25 - 7.28556555812718e+21*cos(theta)**23 + 6.51785037555225e+20*cos(theta)**21 - 4.76749766236841e+19*cos(theta)**19 + 2.8015192448969e+18*cos(theta)**17 - 1.29374063601351e+17*cos(theta)**15 + 4.56460909883799e+15*cos(theta)**13 - 118561275294493.0*cos(theta)**11 + 2154947171578.69*cos(theta)**9 - 25477207939.8466*cos(theta)**7 + 174843583.900908*cos(theta)**5 - 569337.62260146*cos(theta)**3 + 554.909963549181*cos(theta))*sin(phi)

#@torch.jit.script
def Yl78_m0(theta, phi):
    return 2.14050482437434e+23*cos(theta)**78 - 4.14705547586848e+24*cos(theta)**76 + 3.86245362948535e+25*cos(theta)**74 - 2.30297731859601e+26*cos(theta)**72 + 9.87652688981778e+26*cos(theta)**70 - 3.24514454951156e+27*cos(theta)**68 + 8.49705664803141e+27*cos(theta)**66 - 1.82079785314959e+28*cos(theta)**64 + 3.25419190775671e+28*cos(theta)**62 - 4.91900631300395e+28*cos(theta)**60 + 6.35521253577882e+28*cos(theta)**58 - 7.07418607518007e+28*cos(theta)**56 + 6.82596901991059e+28*cos(theta)**54 - 5.73573791397067e+28*cos(theta)**52 + 4.21128929896186e+28*cos(theta)**50 - 2.70804692452928e+28*cos(theta)**48 + 1.52733846543451e+28*cos(theta)**46 - 7.55999670839177e+27*cos(theta)**44 + 3.28363493394794e+27*cos(theta)**42 - 1.25042444853126e+27*cos(theta)**40 + 4.1680814951042e+26*cos(theta)**38 - 1.21331730478603e+26*cos(theta)**36 + 3.07477836691551e+25*cos(theta)**34 - 6.75656350896828e+24*cos(theta)**32 + 1.28106097111937e+24*cos(theta)**30 - 2.08322064462402e+23*cos(theta)**28 + 2.8844593540948e+22*cos(theta)**26 - 3.37090719194825e+21*cos(theta)**24 + 3.28985284645586e+20*cos(theta)**22 - 2.64700803737828e+19*cos(theta)**20 + 1.72828703471434e+18*cos(theta)**18 - 8.97887661498452e+16*cos(theta)**16 + 3.62051476410666e+15*cos(theta)**14 - 109712568609293.0*cos(theta)**12 + 2392937715866.93*cos(theta)**10 - 35363611564.5359*cos(theta)**8 + 323588602.551309*cos(theta)**6 - 1580536.97110701*cos(theta)**4 + 3080.96875459456*cos(theta)**2 - 0.999989858680481

#@torch.jit.script
def Yl78_m1(theta, phi):
    return 0.063679412066746*(1.0 - cos(theta)**2)**0.5*(1.50354367079071e+24*cos(theta)**77 - 2.83830243918299e+25*cos(theta)**75 + 2.57395074141594e+26*cos(theta)**73 - 1.49323235064925e+27*cos(theta)**71 + 6.22597716671709e+27*cos(theta)**69 - 1.98723026300929e+28*cos(theta)**67 + 5.05030587530292e+28*cos(theta)**65 - 1.04941420785515e+29*cos(theta)**63 + 1.81693789711092e+29*cos(theta)**61 - 2.65787078474259e+29*cos(theta)**59 + 3.31942840342669e+29*cos(theta)**57 - 3.56754729418788e+29*cos(theta)**55 + 3.31942840342669e+29*cos(theta)**53 - 2.68594970048267e+29*cos(theta)**51 + 1.89622694801517e+29*cos(theta)**49 - 1.17058419468023e+29*cos(theta)**47 + 6.32700757224665e+28*cos(theta)**45 - 2.99557029962897e+28*cos(theta)**43 + 1.24196509667813e+28*cos(theta)**41 - 4.50425200918207e+27*cos(theta)**39 + 1.42634646957432e+27*cos(theta)**37 - 3.93352690988198e+26*cos(theta)**35 + 9.41451533137481e+25*cos(theta)**33 - 1.94706780061336e+25*cos(theta)**31 + 3.4609576731086e+24*cos(theta)**29 - 5.25289276740969e+23*cos(theta)**27 + 6.75371927238389e+22*cos(theta)**25 - 7.28556555812718e+21*cos(theta)**23 + 6.51785037555225e+20*cos(theta)**21 - 4.76749766236841e+19*cos(theta)**19 + 2.8015192448969e+18*cos(theta)**17 - 1.29374063601351e+17*cos(theta)**15 + 4.56460909883799e+15*cos(theta)**13 - 118561275294493.0*cos(theta)**11 + 2154947171578.69*cos(theta)**9 - 25477207939.8466*cos(theta)**7 + 174843583.900908*cos(theta)**5 - 569337.62260146*cos(theta)**3 + 554.909963549181*cos(theta))*cos(phi)

#@torch.jit.script
def Yl78_m2(theta, phi):
    return 0.000811350837805408*(1.0 - cos(theta)**2)*(1.15772862650885e+26*cos(theta)**76 - 2.12872682938724e+27*cos(theta)**74 + 1.87898404123364e+28*cos(theta)**72 - 1.06019496896097e+29*cos(theta)**70 + 4.29592424503479e+29*cos(theta)**68 - 1.33144427621622e+30*cos(theta)**66 + 3.2826988189469e+30*cos(theta)**64 - 6.61130950948746e+30*cos(theta)**62 + 1.10833211723766e+31*cos(theta)**60 - 1.56814376299813e+31*cos(theta)**58 + 1.89207418995321e+31*cos(theta)**56 - 1.96215101180333e+31*cos(theta)**54 + 1.75929705381615e+31*cos(theta)**52 - 1.36983434724616e+31*cos(theta)**50 + 9.29151204527434e+30*cos(theta)**48 - 5.50174571499709e+30*cos(theta)**46 + 2.84715340751099e+30*cos(theta)**44 - 1.28809522884046e+30*cos(theta)**42 + 5.09205689638033e+29*cos(theta)**40 - 1.75665828358101e+29*cos(theta)**38 + 5.27748193742499e+28*cos(theta)**36 - 1.37673441845869e+28*cos(theta)**34 + 3.10679005935369e+27*cos(theta)**32 - 6.03591018190141e+26*cos(theta)**30 + 1.0036777252015e+26*cos(theta)**28 - 1.41828104720062e+25*cos(theta)**26 + 1.68842981809597e+24*cos(theta)**24 - 1.67568007836925e+23*cos(theta)**22 + 1.36874857886597e+22*cos(theta)**20 - 9.05824555849999e+20*cos(theta)**18 + 4.76258271632474e+19*cos(theta)**16 - 1.94061095402027e+18*cos(theta)**14 + 5.93399182848939e+16*cos(theta)**12 - 1.30417402823943e+15*cos(theta)**10 + 19394524544208.3*cos(theta)**8 - 178340455578.926*cos(theta)**6 + 874217919.504542*cos(theta)**4 - 1708012.86780438*cos(theta)**2 + 554.909963549181)*cos(2*phi)

#@torch.jit.script
def Yl78_m3(theta, phi):
    return 1.03409248823124e-5*(1.0 - cos(theta)**2)**1.5*(8.79873756146726e+27*cos(theta)**75 - 1.57525785374656e+29*cos(theta)**73 + 1.35286850968822e+30*cos(theta)**71 - 7.42136478272677e+30*cos(theta)**69 + 2.92122848662366e+31*cos(theta)**67 - 8.78753222302709e+31*cos(theta)**65 + 2.10092724412602e+32*cos(theta)**63 - 4.09901189588223e+32*cos(theta)**61 + 6.64999270342595e+32*cos(theta)**59 - 9.09523382538913e+32*cos(theta)**57 + 1.0595615463738e+33*cos(theta)**55 - 1.0595615463738e+33*cos(theta)**53 + 9.14834467984396e+32*cos(theta)**51 - 6.8491717362308e+32*cos(theta)**49 + 4.45992578173168e+32*cos(theta)**47 - 2.53080302889866e+32*cos(theta)**45 + 1.25274749930484e+32*cos(theta)**43 - 5.40999996112993e+31*cos(theta)**41 + 2.03682275855213e+31*cos(theta)**39 - 6.67530147760782e+30*cos(theta)**37 + 1.899893497473e+30*cos(theta)**35 - 4.68089702275955e+29*cos(theta)**33 + 9.9417281899318e+28*cos(theta)**31 - 1.81077305457042e+28*cos(theta)**29 + 2.81029763056419e+27*cos(theta)**27 - 3.68753072272161e+26*cos(theta)**25 + 4.05223156343034e+25*cos(theta)**23 - 3.68649617241235e+24*cos(theta)**21 + 2.73749715773194e+23*cos(theta)**19 - 1.63048420053e+22*cos(theta)**17 + 7.62013234611958e+20*cos(theta)**15 - 2.71685533562837e+19*cos(theta)**13 + 7.12079019418727e+17*cos(theta)**11 - 1.30417402823943e+16*cos(theta)**9 + 155156196353666.0*cos(theta)**7 - 1070042733473.56*cos(theta)**5 + 3496871678.01817*cos(theta)**3 - 3416025.73560876*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl78_m4(theta, phi):
    return 1.31862657929992e-7*(1.0 - cos(theta)**2)**2*(6.59905317110044e+29*cos(theta)**74 - 1.14993823323499e+31*cos(theta)**72 + 9.60536641878636e+31*cos(theta)**70 - 5.12074170008147e+32*cos(theta)**68 + 1.95722308603785e+33*cos(theta)**66 - 5.71189594496761e+33*cos(theta)**64 + 1.32358416379939e+34*cos(theta)**62 - 2.50039725648816e+34*cos(theta)**60 + 3.92349569502131e+34*cos(theta)**58 - 5.18428328047181e+34*cos(theta)**56 + 5.8275885050559e+34*cos(theta)**54 - 5.61567619578114e+34*cos(theta)**52 + 4.66565578672042e+34*cos(theta)**50 - 3.35609415075309e+34*cos(theta)**48 + 2.09616511741389e+34*cos(theta)**46 - 1.1388613630044e+34*cos(theta)**44 + 5.3868142470108e+33*cos(theta)**42 - 2.21809998406327e+33*cos(theta)**40 + 7.94360875835331e+32*cos(theta)**38 - 2.46986154671489e+32*cos(theta)**36 + 6.64962724115549e+31*cos(theta)**34 - 1.54469601751065e+31*cos(theta)**32 + 3.08193573887886e+30*cos(theta)**30 - 5.25124185825422e+29*cos(theta)**28 + 7.5878036025233e+28*cos(theta)**26 - 9.21882680680401e+27*cos(theta)**24 + 9.32013259588977e+26*cos(theta)**22 - 7.74164196206594e+25*cos(theta)**20 + 5.20124459969069e+24*cos(theta)**18 - 2.771823140901e+23*cos(theta)**16 + 1.14301985191794e+22*cos(theta)**14 - 3.53191193631688e+20*cos(theta)**12 + 7.83286921360599e+18*cos(theta)**10 - 1.17375662541548e+17*cos(theta)**8 + 1.08609337447566e+15*cos(theta)**6 - 5350213667367.79*cos(theta)**4 + 10490615034.0545*cos(theta)**2 - 3416025.73560876)*cos(4*phi)

#@torch.jit.script
def Yl78_m5(theta, phi):
    return 1.68254589528387e-9*(1.0 - cos(theta)**2)**2.5*(4.88329934661433e+31*cos(theta)**73 - 8.27955527929191e+32*cos(theta)**71 + 6.72375649315045e+33*cos(theta)**69 - 3.4821043560554e+34*cos(theta)**67 + 1.29176723678498e+35*cos(theta)**65 - 3.65561340477927e+35*cos(theta)**63 + 8.20622181555622e+35*cos(theta)**61 - 1.50023835389289e+36*cos(theta)**59 + 2.27562750311236e+36*cos(theta)**57 - 2.90319863706421e+36*cos(theta)**55 + 3.14689779273019e+36*cos(theta)**53 - 2.92015162180619e+36*cos(theta)**51 + 2.33282789336021e+36*cos(theta)**49 - 1.61092519236148e+36*cos(theta)**47 + 9.6423595401039e+35*cos(theta)**45 - 5.01098999721935e+35*cos(theta)**43 + 2.26246198374454e+35*cos(theta)**41 - 8.87239993625308e+34*cos(theta)**39 + 3.01857132817426e+34*cos(theta)**37 - 8.89150156817362e+33*cos(theta)**35 + 2.26087326199287e+33*cos(theta)**33 - 4.94302725603409e+32*cos(theta)**31 + 9.24580721663657e+31*cos(theta)**29 - 1.47034772031118e+31*cos(theta)**27 + 1.97282893665606e+30*cos(theta)**25 - 2.21251843363296e+29*cos(theta)**23 + 2.05042917109575e+28*cos(theta)**21 - 1.54832839241319e+27*cos(theta)**19 + 9.36224027944325e+25*cos(theta)**17 - 4.43491702544159e+24*cos(theta)**15 + 1.60022779268511e+23*cos(theta)**13 - 4.23829432358026e+21*cos(theta)**11 + 7.83286921360599e+19*cos(theta)**9 - 9.39005300332387e+17*cos(theta)**7 + 6.51656024685397e+15*cos(theta)**5 - 21400854669471.2*cos(theta)**3 + 20981230068.109*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl78_m6(theta, phi):
    return 2.14865083419056e-11*(1.0 - cos(theta)**2)**3*(3.56480852302846e+33*cos(theta)**72 - 5.87848424829725e+34*cos(theta)**70 + 4.63939198027381e+35*cos(theta)**68 - 2.33300991855712e+36*cos(theta)**66 + 8.39648703910238e+36*cos(theta)**64 - 2.30303644501094e+37*cos(theta)**62 + 5.00579530748929e+37*cos(theta)**60 - 8.85140628796808e+37*cos(theta)**58 + 1.29710767677405e+38*cos(theta)**56 - 1.59675925038532e+38*cos(theta)**54 + 1.667855830147e+38*cos(theta)**52 - 1.48927732712116e+38*cos(theta)**50 + 1.1430856677465e+38*cos(theta)**48 - 7.57134840409897e+37*cos(theta)**46 + 4.33906179304675e+37*cos(theta)**44 - 2.15472569880432e+37*cos(theta)**42 + 9.2760941333526e+36*cos(theta)**40 - 3.4602359751387e+36*cos(theta)**38 + 1.11687139142448e+36*cos(theta)**36 - 3.11202554886077e+35*cos(theta)**34 + 7.46088176457645e+34*cos(theta)**32 - 1.53233844937057e+34*cos(theta)**30 + 2.68128409282461e+33*cos(theta)**28 - 3.96993884484019e+32*cos(theta)**26 + 4.93207234164015e+31*cos(theta)**24 - 5.08879239735582e+30*cos(theta)**22 + 4.30590125930107e+29*cos(theta)**20 - 2.94182394558506e+28*cos(theta)**18 + 1.59158084750535e+27*cos(theta)**16 - 6.65237553816239e+25*cos(theta)**14 + 2.08029613049064e+24*cos(theta)**12 - 4.66212375593829e+22*cos(theta)**10 + 7.04958229224539e+20*cos(theta)**8 - 6.57303710232671e+18*cos(theta)**6 + 3.25828012342699e+16*cos(theta)**4 - 64202564008413.5*cos(theta)**2 + 20981230068.109)*cos(6*phi)

#@torch.jit.script
def Yl78_m7(theta, phi):
    return 2.74656660513642e-13*(1.0 - cos(theta)**2)**3.5*(2.56666213658049e+35*cos(theta)**71 - 4.11493897380808e+36*cos(theta)**69 + 3.15478654658619e+37*cos(theta)**67 - 1.5397865462477e+38*cos(theta)**65 + 5.37375170502552e+38*cos(theta)**63 - 1.42788259590678e+39*cos(theta)**61 + 3.00347718449358e+39*cos(theta)**59 - 5.13381564702149e+39*cos(theta)**57 + 7.26380298993466e+39*cos(theta)**55 - 8.62249995208071e+39*cos(theta)**53 + 8.67285031676439e+39*cos(theta)**51 - 7.44638663560579e+39*cos(theta)**49 + 5.48681120518321e+39*cos(theta)**47 - 3.48282026588553e+39*cos(theta)**45 + 1.90918718894057e+39*cos(theta)**43 - 9.04984793497814e+38*cos(theta)**41 + 3.71043765334104e+38*cos(theta)**39 - 1.31488967055271e+38*cos(theta)**37 + 4.02073700912811e+37*cos(theta)**35 - 1.05808868661266e+37*cos(theta)**33 + 2.38748216466447e+36*cos(theta)**31 - 4.5970153481117e+35*cos(theta)**29 + 7.5075954599089e+34*cos(theta)**27 - 1.03218409965845e+34*cos(theta)**25 + 1.18369736199364e+33*cos(theta)**23 - 1.11953432741828e+32*cos(theta)**21 + 8.61180251860215e+30*cos(theta)**19 - 5.2952831020531e+29*cos(theta)**17 + 2.54652935600856e+28*cos(theta)**15 - 9.31332575342735e+26*cos(theta)**13 + 2.49635535658877e+25*cos(theta)**11 - 4.66212375593829e+23*cos(theta)**9 + 5.63966583379632e+21*cos(theta)**7 - 3.94382226139602e+19*cos(theta)**5 + 1.30331204937079e+17*cos(theta)**3 - 128405128016827.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl78_m8(theta, phi):
    return 3.51488997694576e-15*(1.0 - cos(theta)**2)**4*(1.82233011697215e+37*cos(theta)**70 - 2.83930789192757e+38*cos(theta)**68 + 2.11370698621275e+39*cos(theta)**66 - 1.000861255061e+40*cos(theta)**64 + 3.38546357416608e+40*cos(theta)**62 - 8.71008383503137e+40*cos(theta)**60 + 1.77205153885121e+41*cos(theta)**58 - 2.92627491880225e+41*cos(theta)**56 + 3.99509164446406e+41*cos(theta)**54 - 4.56992497460278e+41*cos(theta)**52 + 4.42315366154984e+41*cos(theta)**50 - 3.64872945144684e+41*cos(theta)**48 + 2.57880126643611e+41*cos(theta)**46 - 1.56726911964849e+41*cos(theta)**44 + 8.20950491244446e+40*cos(theta)**42 - 3.71043765334104e+40*cos(theta)**40 + 1.44707068480301e+40*cos(theta)**38 - 4.86509178104501e+39*cos(theta)**36 + 1.40725795319484e+39*cos(theta)**34 - 3.49169266582178e+38*cos(theta)**32 + 7.40119471045984e+37*cos(theta)**30 - 1.33313445095239e+37*cos(theta)**28 + 2.0270507741754e+36*cos(theta)**26 - 2.58046024914613e+35*cos(theta)**24 + 2.72250393258536e+34*cos(theta)**22 - 2.35102208757839e+33*cos(theta)**20 + 1.63624247853441e+32*cos(theta)**18 - 9.00198127349027e+30*cos(theta)**16 + 3.81979403401285e+29*cos(theta)**14 - 1.21073234794556e+28*cos(theta)**12 + 2.74599089224765e+26*cos(theta)**10 - 4.19591138034446e+24*cos(theta)**8 + 3.94776608365742e+22*cos(theta)**6 - 1.97191113069801e+20*cos(theta)**4 + 3.90993614811238e+17*cos(theta)**2 - 128405128016827.0)*cos(8*phi)

#@torch.jit.script
def Yl78_m9(theta, phi):
    return 4.50404881714018e-17*(1.0 - cos(theta)**2)**4.5*(1.2756310818805e+39*cos(theta)**69 - 1.93072936651075e+40*cos(theta)**67 + 1.39504661090041e+41*cos(theta)**65 - 6.40551203239042e+41*cos(theta)**63 + 2.09898741598297e+42*cos(theta)**61 - 5.22605030101882e+42*cos(theta)**59 + 1.0277898925337e+43*cos(theta)**57 - 1.63871395452926e+43*cos(theta)**55 + 2.15734948801059e+43*cos(theta)**53 - 2.37636098679344e+43*cos(theta)**51 + 2.21157683077492e+43*cos(theta)**49 - 1.75139013669448e+43*cos(theta)**47 + 1.18624858256061e+43*cos(theta)**45 - 6.89598412645334e+42*cos(theta)**43 + 3.44799206322667e+42*cos(theta)**41 - 1.48417506133642e+42*cos(theta)**39 + 5.49886860225142e+41*cos(theta)**37 - 1.75143304117621e+41*cos(theta)**35 + 4.78467704086245e+40*cos(theta)**33 - 1.11734165306297e+40*cos(theta)**31 + 2.22035841313795e+39*cos(theta)**29 - 3.7327764626667e+38*cos(theta)**27 + 5.27033201285605e+37*cos(theta)**25 - 6.1931045979507e+36*cos(theta)**23 + 5.98950865168779e+35*cos(theta)**21 - 4.70204417515677e+34*cos(theta)**19 + 2.94523646136194e+33*cos(theta)**17 - 1.44031700375844e+32*cos(theta)**15 + 5.34771164761798e+30*cos(theta)**13 - 1.45287881753467e+29*cos(theta)**11 + 2.74599089224765e+27*cos(theta)**9 - 3.35672910427557e+25*cos(theta)**7 + 2.36865965019445e+23*cos(theta)**5 - 7.88764452279205e+20*cos(theta)**3 + 7.81987229622477e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl78_m10(theta, phi):
    return 5.78012469423161e-19*(1.0 - cos(theta)**2)**5*(8.80185446497548e+40*cos(theta)**68 - 1.2935886755622e+42*cos(theta)**66 + 9.06780297085269e+42*cos(theta)**64 - 4.03547258040597e+43*cos(theta)**62 + 1.28038232374961e+44*cos(theta)**60 - 3.0833696776011e+44*cos(theta)**58 + 5.8584023874421e+44*cos(theta)**56 - 9.01292674991092e+44*cos(theta)**54 + 1.14339522864561e+45*cos(theta)**52 - 1.21194410326466e+45*cos(theta)**50 + 1.08367264707971e+45*cos(theta)**48 - 8.23153364246406e+44*cos(theta)**46 + 5.33811862152275e+44*cos(theta)**44 - 2.96527317437494e+44*cos(theta)**42 + 1.41367674592294e+44*cos(theta)**40 - 5.78828273921202e+43*cos(theta)**38 + 2.03458138283303e+43*cos(theta)**36 - 6.13001564411672e+42*cos(theta)**34 + 1.57894342348461e+42*cos(theta)**32 - 3.46375912449521e+41*cos(theta)**30 + 6.43903939810006e+40*cos(theta)**28 - 1.00784964492001e+40*cos(theta)**26 + 1.31758300321401e+39*cos(theta)**24 - 1.42441405752866e+38*cos(theta)**22 + 1.25779681685444e+37*cos(theta)**20 - 8.93388393279787e+35*cos(theta)**18 + 5.00690198431529e+34*cos(theta)**16 - 2.16047550563767e+33*cos(theta)**14 + 6.95202514190338e+31*cos(theta)**12 - 1.59816669928813e+30*cos(theta)**10 + 2.47139180302289e+28*cos(theta)**8 - 2.3497103729929e+26*cos(theta)**6 + 1.18432982509723e+24*cos(theta)**4 - 2.36629335683761e+21*cos(theta)**2 + 7.81987229622477e+17)*cos(10*phi)

#@torch.jit.script
def Yl78_m11(theta, phi):
    return 7.42998176421938e-21*(1.0 - cos(theta)**2)**5.5*(5.98526103618333e+42*cos(theta)**67 - 8.53768525871054e+43*cos(theta)**65 + 5.80339390134572e+44*cos(theta)**63 - 2.5019929998517e+45*cos(theta)**61 + 7.68229394249767e+45*cos(theta)**59 - 1.78835441300864e+46*cos(theta)**57 + 3.28070533696758e+46*cos(theta)**55 - 4.8669804449519e+46*cos(theta)**53 + 5.94565518895719e+46*cos(theta)**51 - 6.05972051632328e+46*cos(theta)**49 + 5.20162870598261e+46*cos(theta)**47 - 3.78650547553347e+46*cos(theta)**45 + 2.34877219347001e+46*cos(theta)**43 - 1.24541473323747e+46*cos(theta)**41 + 5.65470698369174e+45*cos(theta)**39 - 2.19954744090057e+45*cos(theta)**37 + 7.32449297819889e+44*cos(theta)**35 - 2.08420531899968e+44*cos(theta)**33 + 5.05261895515075e+43*cos(theta)**31 - 1.03912773734856e+43*cos(theta)**29 + 1.80293103146802e+42*cos(theta)**27 - 2.62040907679203e+41*cos(theta)**25 + 3.16219920771363e+40*cos(theta)**23 - 3.13371092656305e+39*cos(theta)**21 + 2.51559363370887e+38*cos(theta)**19 - 1.60809910790362e+37*cos(theta)**17 + 8.01104317490446e+35*cos(theta)**15 - 3.02466570789273e+34*cos(theta)**13 + 8.34243017028405e+32*cos(theta)**11 - 1.59816669928813e+31*cos(theta)**9 + 1.97711344241831e+29*cos(theta)**7 - 1.40982622379574e+27*cos(theta)**5 + 4.7373193003889e+24*cos(theta)**3 - 4.73258671367523e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl78_m12(theta, phi):
    return 9.56817460133919e-23*(1.0 - cos(theta)**2)**6*(4.01012489424283e+44*cos(theta)**66 - 5.54949541816185e+45*cos(theta)**64 + 3.65613815784781e+46*cos(theta)**62 - 1.52621572990954e+47*cos(theta)**60 + 4.53255342607362e+47*cos(theta)**58 - 1.01936201541493e+48*cos(theta)**56 + 1.80438793533217e+48*cos(theta)**54 - 2.57949963582451e+48*cos(theta)**52 + 3.03228414636817e+48*cos(theta)**50 - 2.96926305299841e+48*cos(theta)**48 + 2.44476549181183e+48*cos(theta)**46 - 1.70392746399006e+48*cos(theta)**44 + 1.0099720431921e+48*cos(theta)**42 - 5.10620040627364e+47*cos(theta)**40 + 2.20533572363978e+47*cos(theta)**38 - 8.1383255313321e+46*cos(theta)**36 + 2.56357254236961e+46*cos(theta)**34 - 6.87787755269896e+45*cos(theta)**32 + 1.56631187609673e+45*cos(theta)**30 - 3.01347043831083e+44*cos(theta)**28 + 4.86791378496365e+43*cos(theta)**26 - 6.55102269198006e+42*cos(theta)**24 + 7.27305817774134e+41*cos(theta)**22 - 6.58079294578241e+40*cos(theta)**20 + 4.77962790404686e+39*cos(theta)**18 - 2.73376848343615e+38*cos(theta)**16 + 1.20165647623567e+37*cos(theta)**14 - 3.93206542026055e+35*cos(theta)**12 + 9.17667318731246e+33*cos(theta)**10 - 1.43835002935932e+32*cos(theta)**8 + 1.38397940969282e+30*cos(theta)**6 - 7.04913111897869e+27*cos(theta)**4 + 1.42119579011667e+25*cos(theta)**2 - 4.73258671367523e+21)*cos(12*phi)

#@torch.jit.script
def Yl78_m13(theta, phi):
    return 1.23462886930322e-24*(1.0 - cos(theta)**2)**6.5*(2.64668243020027e+46*cos(theta)**65 - 3.55167706762358e+47*cos(theta)**63 + 2.26680565786564e+48*cos(theta)**61 - 9.15729437945722e+48*cos(theta)**59 + 2.6288809871227e+49*cos(theta)**57 - 5.70842728632358e+49*cos(theta)**55 + 9.7436948507937e+49*cos(theta)**53 - 1.34133981062874e+50*cos(theta)**51 + 1.51614207318408e+50*cos(theta)**49 - 1.42524626543924e+50*cos(theta)**47 + 1.12459212623344e+50*cos(theta)**45 - 7.49728084155627e+49*cos(theta)**43 + 4.24188258140684e+49*cos(theta)**41 - 2.04248016250946e+49*cos(theta)**39 + 8.38027574983116e+48*cos(theta)**37 - 2.92979719127956e+48*cos(theta)**35 + 8.71614664405668e+47*cos(theta)**33 - 2.20092081686367e+47*cos(theta)**31 + 4.6989356282902e+46*cos(theta)**29 - 8.43771722727032e+45*cos(theta)**27 + 1.26565758409055e+45*cos(theta)**25 - 1.57224544607522e+44*cos(theta)**23 + 1.6000727991031e+43*cos(theta)**21 - 1.31615858915648e+42*cos(theta)**19 + 8.60333022728435e+40*cos(theta)**17 - 4.37402957349784e+39*cos(theta)**15 + 1.68231906672994e+38*cos(theta)**13 - 4.71847850431266e+36*cos(theta)**11 + 9.17667318731246e+34*cos(theta)**9 - 1.15068002348746e+33*cos(theta)**7 + 8.3038764581569e+30*cos(theta)**5 - 2.81965244759148e+28*cos(theta)**3 + 2.84239158023334e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl78_m14(theta, phi):
    return 1.59656217462807e-26*(1.0 - cos(theta)**2)**7*(1.72034357963017e+48*cos(theta)**64 - 2.23755655260286e+49*cos(theta)**62 + 1.38275145129804e+50*cos(theta)**60 - 5.40280368387976e+50*cos(theta)**58 + 1.49846216265994e+51*cos(theta)**56 - 3.13963500747797e+51*cos(theta)**54 + 5.16415827092066e+51*cos(theta)**52 - 6.84083303420659e+51*cos(theta)**50 + 7.42909615860201e+51*cos(theta)**48 - 6.69865744756441e+51*cos(theta)**46 + 5.06066456805048e+51*cos(theta)**44 - 3.2238307618692e+51*cos(theta)**42 + 1.7391718583768e+51*cos(theta)**40 - 7.96567263378688e+50*cos(theta)**38 + 3.10070202743753e+50*cos(theta)**36 - 1.02542901694784e+50*cos(theta)**34 + 2.8763283925387e+49*cos(theta)**32 - 6.82285453227737e+48*cos(theta)**30 + 1.36269133220416e+48*cos(theta)**28 - 2.27818365136299e+47*cos(theta)**26 + 3.16414396022637e+46*cos(theta)**24 - 3.616164525973e+45*cos(theta)**22 + 3.3601528781165e+44*cos(theta)**20 - 2.50070131939732e+43*cos(theta)**18 + 1.46256613863834e+42*cos(theta)**16 - 6.56104436024676e+40*cos(theta)**14 + 2.18701478674892e+39*cos(theta)**12 - 5.19032635474393e+37*cos(theta)**10 + 8.25900586858121e+35*cos(theta)**8 - 8.05476016441219e+33*cos(theta)**6 + 4.15193822907845e+31*cos(theta)**4 - 8.45895734277443e+28*cos(theta)**2 + 2.84239158023334e+25)*cos(14*phi)

#@torch.jit.script
def Yl78_m15(theta, phi):
    return 2.06944731590383e-28*(1.0 - cos(theta)**2)**7.5*(1.10101989096331e+50*cos(theta)**63 - 1.38728506261377e+51*cos(theta)**61 + 8.29650870778824e+51*cos(theta)**59 - 3.13362613665026e+52*cos(theta)**57 + 8.39138811089566e+52*cos(theta)**55 - 1.6954029040381e+53*cos(theta)**53 + 2.68536230087874e+53*cos(theta)**51 - 3.42041651710329e+53*cos(theta)**49 + 3.56596615612897e+53*cos(theta)**47 - 3.08138242587963e+53*cos(theta)**45 + 2.22669240994221e+53*cos(theta)**43 - 1.35400891998506e+53*cos(theta)**41 + 6.95668743350721e+52*cos(theta)**39 - 3.02695560083902e+52*cos(theta)**37 + 1.11625272987751e+52*cos(theta)**35 - 3.48645865762267e+51*cos(theta)**33 + 9.20425085612385e+50*cos(theta)**31 - 2.04685635968321e+50*cos(theta)**29 + 3.81553573017164e+49*cos(theta)**27 - 5.92327749354377e+48*cos(theta)**25 + 7.59394550454329e+47*cos(theta)**23 - 7.95556195714059e+46*cos(theta)**21 + 6.720305756233e+45*cos(theta)**19 - 4.50126237491517e+44*cos(theta)**17 + 2.34010582182134e+43*cos(theta)**15 - 9.18546210434546e+41*cos(theta)**13 + 2.6244177440987e+40*cos(theta)**11 - 5.19032635474393e+38*cos(theta)**9 + 6.60720469486497e+36*cos(theta)**7 - 4.83285609864731e+34*cos(theta)**5 + 1.66077529163138e+32*cos(theta)**3 - 1.69179146855489e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl78_m16(theta, phi):
    return 2.68918186012676e-30*(1.0 - cos(theta)**2)**8*(6.93642531306886e+51*cos(theta)**62 - 8.46243888194401e+52*cos(theta)**60 + 4.89494013759506e+53*cos(theta)**58 - 1.78616689789065e+54*cos(theta)**56 + 4.61526346099262e+54*cos(theta)**54 - 8.98563539140195e+54*cos(theta)**52 + 1.36953477344816e+55*cos(theta)**50 - 1.67600409338061e+55*cos(theta)**48 + 1.67600409338061e+55*cos(theta)**46 - 1.38662209164583e+55*cos(theta)**44 + 9.57477736275151e+54*cos(theta)**42 - 5.55143657193876e+54*cos(theta)**40 + 2.71310809906781e+54*cos(theta)**38 - 1.11997357231044e+54*cos(theta)**36 + 3.90688455457129e+53*cos(theta)**34 - 1.15053135701548e+53*cos(theta)**32 + 2.85331776539839e+52*cos(theta)**30 - 5.93588344308131e+51*cos(theta)**28 + 1.03019464714634e+51*cos(theta)**26 - 1.48081937338594e+50*cos(theta)**24 + 1.74660746604496e+49*cos(theta)**22 - 1.67066801099952e+48*cos(theta)**20 + 1.27685809368427e+47*cos(theta)**18 - 7.65214603735579e+45*cos(theta)**16 + 3.51015873273201e+44*cos(theta)**14 - 1.19411007356491e+43*cos(theta)**12 + 2.88685951850857e+41*cos(theta)**10 - 4.67129371926953e+39*cos(theta)**8 + 4.62504328640548e+37*cos(theta)**6 - 2.41642804932366e+35*cos(theta)**4 + 4.98232587489414e+32*cos(theta)**2 - 1.69179146855489e+29)*cos(16*phi)

#@torch.jit.script
def Yl78_m17(theta, phi):
    return 3.50398731809295e-32*(1.0 - cos(theta)**2)**8.5*(4.30058369410269e+53*cos(theta)**61 - 5.0774633291664e+54*cos(theta)**59 + 2.83906527980514e+55*cos(theta)**57 - 1.00025346281876e+56*cos(theta)**55 + 2.49224226893601e+56*cos(theta)**53 - 4.67253040352901e+56*cos(theta)**51 + 6.8476738672408e+56*cos(theta)**49 - 8.04481964822695e+56*cos(theta)**47 + 7.70961882955083e+56*cos(theta)**45 - 6.10113720324166e+56*cos(theta)**43 + 4.02140649235563e+56*cos(theta)**41 - 2.2205746287755e+56*cos(theta)**39 + 1.03098107764577e+56*cos(theta)**37 - 4.03190486031757e+55*cos(theta)**35 + 1.32834074855424e+55*cos(theta)**33 - 3.68170034244954e+54*cos(theta)**31 + 8.55995329619518e+53*cos(theta)**29 - 1.66204736406277e+53*cos(theta)**27 + 2.67850608258049e+52*cos(theta)**25 - 3.55396649612626e+51*cos(theta)**23 + 3.8425364252989e+50*cos(theta)**21 - 3.34133602199905e+49*cos(theta)**19 + 2.29834456863169e+48*cos(theta)**17 - 1.22434336597693e+47*cos(theta)**15 + 4.91422222582482e+45*cos(theta)**13 - 1.43293208827789e+44*cos(theta)**11 + 2.88685951850857e+42*cos(theta)**9 - 3.73703497541563e+40*cos(theta)**7 + 2.77502597184329e+38*cos(theta)**5 - 9.66571219729463e+35*cos(theta)**3 + 9.96465174978828e+32*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl78_m18(theta, phi):
    return 4.5789087794189e-34*(1.0 - cos(theta)**2)**9*(2.62335605340264e+55*cos(theta)**60 - 2.99570336420818e+56*cos(theta)**58 + 1.61826720948893e+57*cos(theta)**56 - 5.5013940455032e+57*cos(theta)**54 + 1.32088840253609e+58*cos(theta)**52 - 2.3829905057998e+58*cos(theta)**50 + 3.35536019494799e+58*cos(theta)**48 - 3.78106523466667e+58*cos(theta)**46 + 3.46932847329787e+58*cos(theta)**44 - 2.62348899739391e+58*cos(theta)**42 + 1.64877666186581e+58*cos(theta)**40 - 8.66024105222446e+57*cos(theta)**38 + 3.81462998728934e+57*cos(theta)**36 - 1.41116670111115e+57*cos(theta)**34 + 4.38352447022898e+56*cos(theta)**32 - 1.14132710615936e+56*cos(theta)**30 + 2.4823864558966e+55*cos(theta)**28 - 4.48752788296947e+54*cos(theta)**26 + 6.69626520645123e+53*cos(theta)**24 - 8.1741229410904e+52*cos(theta)**22 + 8.0693264931277e+51*cos(theta)**20 - 6.34853844179819e+50*cos(theta)**18 + 3.90718576667387e+49*cos(theta)**16 - 1.83651504896539e+48*cos(theta)**14 + 6.38848889357227e+46*cos(theta)**12 - 1.57622529710568e+45*cos(theta)**10 + 2.59817356665771e+43*cos(theta)**8 - 2.61592448279094e+41*cos(theta)**6 + 1.38751298592164e+39*cos(theta)**4 - 2.89971365918839e+36*cos(theta)**2 + 9.96465174978828e+32)*cos(18*phi)

#@torch.jit.script
def Yl78_m19(theta, phi):
    return 6.00206230454399e-36*(1.0 - cos(theta)**2)**9.5*(1.57401363204159e+57*cos(theta)**59 - 1.73750795124074e+58*cos(theta)**57 + 9.06229637313799e+58*cos(theta)**55 - 2.97075278457173e+59*cos(theta)**53 + 6.86861969318765e+59*cos(theta)**51 - 1.1914952528999e+60*cos(theta)**49 + 1.61057289357504e+60*cos(theta)**47 - 1.73929000794667e+60*cos(theta)**45 + 1.52650452825106e+60*cos(theta)**43 - 1.10186537890544e+60*cos(theta)**41 + 6.59510664746324e+59*cos(theta)**39 - 3.29089159984529e+59*cos(theta)**37 + 1.37326679542416e+59*cos(theta)**35 - 4.79796678377791e+58*cos(theta)**33 + 1.40272783047328e+58*cos(theta)**31 - 3.42398131847807e+57*cos(theta)**29 + 6.95068207651049e+56*cos(theta)**27 - 1.16675724957206e+56*cos(theta)**25 + 1.60710364954829e+55*cos(theta)**23 - 1.79830704703989e+54*cos(theta)**21 + 1.61386529862554e+53*cos(theta)**19 - 1.14273691952367e+52*cos(theta)**17 + 6.25149722667819e+50*cos(theta)**15 - 2.57112106855155e+49*cos(theta)**13 + 7.66618667228672e+47*cos(theta)**11 - 1.57622529710568e+46*cos(theta)**9 + 2.07853885332617e+44*cos(theta)**7 - 1.56955468967456e+42*cos(theta)**5 + 5.55005194368658e+39*cos(theta)**3 - 5.79942731837678e+36*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl78_m20(theta, phi):
    return 7.89335173229645e-38*(1.0 - cos(theta)**2)**10*(9.28668042904535e+58*cos(theta)**58 - 9.90379532207224e+59*cos(theta)**56 + 4.9842630052259e+60*cos(theta)**54 - 1.57449897582302e+61*cos(theta)**52 + 3.5029960435257e+61*cos(theta)**50 - 5.8383267392095e+61*cos(theta)**48 + 7.56969259980266e+61*cos(theta)**46 - 7.82680503576e+61*cos(theta)**44 + 6.56396947147957e+61*cos(theta)**42 - 4.51764805351232e+61*cos(theta)**40 + 2.57209159251066e+61*cos(theta)**38 - 1.21762989194276e+61*cos(theta)**36 + 4.80643378398457e+60*cos(theta)**34 - 1.58332903864671e+60*cos(theta)**32 + 4.34845627446715e+59*cos(theta)**30 - 9.92954582358641e+58*cos(theta)**28 + 1.87668416065783e+58*cos(theta)**26 - 2.91689312393016e+57*cos(theta)**24 + 3.69633839396108e+56*cos(theta)**22 - 3.77644479878376e+55*cos(theta)**20 + 3.06634406738853e+54*cos(theta)**18 - 1.94265276319025e+53*cos(theta)**16 + 9.37724584001728e+51*cos(theta)**14 - 3.34245738911701e+50*cos(theta)**12 + 8.43280533951539e+48*cos(theta)**10 - 1.41860276739511e+47*cos(theta)**8 + 1.45497719732832e+45*cos(theta)**6 - 7.84777344837282e+42*cos(theta)**4 + 1.66501558310597e+40*cos(theta)**2 - 5.79942731837678e+36)*cos(20*phi)

#@torch.jit.script
def Yl78_m21(theta, phi):
    return 1.04166929211579e-39*(1.0 - cos(theta)**2)**10.5*(5.3862746488463e+60*cos(theta)**57 - 5.54612538036045e+61*cos(theta)**55 + 2.69150202282198e+62*cos(theta)**53 - 8.18739467427968e+62*cos(theta)**51 + 1.75149802176285e+63*cos(theta)**49 - 2.80239683482056e+63*cos(theta)**47 + 3.48205859590923e+63*cos(theta)**45 - 3.4437942157344e+63*cos(theta)**43 + 2.75686717802142e+63*cos(theta)**41 - 1.80705922140493e+63*cos(theta)**39 + 9.77394805154052e+62*cos(theta)**37 - 4.38346761099393e+62*cos(theta)**35 + 1.63418748655476e+62*cos(theta)**33 - 5.06665292366947e+61*cos(theta)**31 + 1.30453688234015e+61*cos(theta)**29 - 2.7802728306042e+60*cos(theta)**27 + 4.87937881771036e+59*cos(theta)**25 - 7.00054349743237e+58*cos(theta)**23 + 8.13194446671437e+57*cos(theta)**21 - 7.55288959756753e+56*cos(theta)**19 + 5.51941932129935e+55*cos(theta)**17 - 3.10824442110439e+54*cos(theta)**15 + 1.31281441760242e+53*cos(theta)**13 - 4.01094886694041e+51*cos(theta)**11 + 8.43280533951539e+49*cos(theta)**9 - 1.13488221391609e+48*cos(theta)**7 + 8.72986318396992e+45*cos(theta)**5 - 3.13910937934913e+43*cos(theta)**3 + 3.33003116621195e+40*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl78_m22(theta, phi):
    return 1.37972468276841e-41*(1.0 - cos(theta)**2)**11*(3.07017654984239e+62*cos(theta)**56 - 3.05036895919825e+63*cos(theta)**54 + 1.42649607209565e+64*cos(theta)**52 - 4.17557128388264e+64*cos(theta)**50 + 8.58234030663797e+64*cos(theta)**48 - 1.31712651236566e+65*cos(theta)**46 + 1.56692636815915e+65*cos(theta)**44 - 1.48083151276579e+65*cos(theta)**42 + 1.13031554298878e+65*cos(theta)**40 - 7.04753096347922e+64*cos(theta)**38 + 3.61636077906999e+64*cos(theta)**36 - 1.53421366384788e+64*cos(theta)**34 + 5.39281870563069e+63*cos(theta)**32 - 1.57066240633754e+63*cos(theta)**30 + 3.78315695878642e+62*cos(theta)**28 - 7.50673664263133e+61*cos(theta)**26 + 1.21984470442759e+61*cos(theta)**24 - 1.61012500440945e+60*cos(theta)**22 + 1.70770833801002e+59*cos(theta)**20 - 1.43504902353783e+58*cos(theta)**18 + 9.38301284620889e+56*cos(theta)**16 - 4.66236663165659e+55*cos(theta)**14 + 1.70665874288314e+54*cos(theta)**12 - 4.41204375363445e+52*cos(theta)**10 + 7.58952480556385e+50*cos(theta)**8 - 7.94417549741263e+48*cos(theta)**6 + 4.36493159198496e+46*cos(theta)**4 - 9.41732813804738e+43*cos(theta)**2 + 3.33003116621195e+40)*cos(22*phi)

#@torch.jit.script
def Yl78_m23(theta, phi):
    return 1.83458455664341e-43*(1.0 - cos(theta)**2)**11.5*(1.71929886791174e+64*cos(theta)**55 - 1.64719923796705e+65*cos(theta)**53 + 7.41777957489739e+65*cos(theta)**51 - 2.08778564194132e+66*cos(theta)**49 + 4.11952334718622e+66*cos(theta)**47 - 6.05878195688205e+66*cos(theta)**45 + 6.89447601990027e+66*cos(theta)**43 - 6.21949235361633e+66*cos(theta)**41 + 4.52126217195513e+66*cos(theta)**39 - 2.6780617661221e+66*cos(theta)**37 + 1.3018898804652e+66*cos(theta)**35 - 5.21632645708278e+65*cos(theta)**33 + 1.72570198580182e+65*cos(theta)**31 - 4.71198721901261e+64*cos(theta)**29 + 1.0592839484602e+64*cos(theta)**27 - 1.95175152708415e+63*cos(theta)**25 + 2.92762729062622e+62*cos(theta)**23 - 3.54227500970078e+61*cos(theta)**21 + 3.41541667602004e+60*cos(theta)**19 - 2.58308824236809e+59*cos(theta)**17 + 1.50128205539342e+58*cos(theta)**15 - 6.52731328431923e+56*cos(theta)**13 + 2.04799049145977e+55*cos(theta)**11 - 4.41204375363445e+53*cos(theta)**9 + 6.07161984445108e+51*cos(theta)**7 - 4.76650529844758e+49*cos(theta)**5 + 1.74597263679398e+47*cos(theta)**3 - 1.88346562760948e+44*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl78_m24(theta, phi):
    return 2.44938076334417e-45*(1.0 - cos(theta)**2)**12*(9.45614377351457e+65*cos(theta)**54 - 8.73015596122539e+66*cos(theta)**52 + 3.78306758319767e+67*cos(theta)**50 - 1.02301496455125e+68*cos(theta)**48 + 1.93617597317753e+68*cos(theta)**46 - 2.72645188059692e+68*cos(theta)**44 + 2.96462468855712e+68*cos(theta)**42 - 2.54999186498269e+68*cos(theta)**40 + 1.7632922470625e+68*cos(theta)**38 - 9.90882853465178e+67*cos(theta)**36 + 4.55661458162819e+67*cos(theta)**34 - 1.72138773083732e+67*cos(theta)**32 + 5.34967615598565e+66*cos(theta)**30 - 1.36647629351366e+66*cos(theta)**28 + 2.86006666084254e+65*cos(theta)**26 - 4.87937881771036e+64*cos(theta)**24 + 6.7335427684403e+63*cos(theta)**22 - 7.43877752037164e+62*cos(theta)**20 + 6.48929168443807e+61*cos(theta)**18 - 4.39125001202576e+60*cos(theta)**16 + 2.25192308309013e+59*cos(theta)**14 - 8.485507269615e+57*cos(theta)**12 + 2.25278954060575e+56*cos(theta)**10 - 3.97083937827101e+54*cos(theta)**8 + 4.25013389111576e+52*cos(theta)**6 - 2.38325264922379e+50*cos(theta)**4 + 5.23791791038195e+47*cos(theta)**2 - 1.88346562760948e+44)*cos(24*phi)

#@torch.jit.script
def Yl78_m25(theta, phi):
    return 3.28428480068287e-47*(1.0 - cos(theta)**2)**12.5*(5.10631763769787e+67*cos(theta)**53 - 4.5396810998372e+68*cos(theta)**51 + 1.89153379159883e+69*cos(theta)**49 - 4.91047182984598e+69*cos(theta)**47 + 8.90640947661662e+69*cos(theta)**45 - 1.19963882746265e+70*cos(theta)**43 + 1.24514236919399e+70*cos(theta)**41 - 1.01999674599308e+70*cos(theta)**39 + 6.7005105388375e+69*cos(theta)**37 - 3.56717827247464e+69*cos(theta)**35 + 1.54924895775359e+69*cos(theta)**33 - 5.50844073867941e+68*cos(theta)**31 + 1.60490284679569e+68*cos(theta)**29 - 3.82613362183824e+67*cos(theta)**27 + 7.43617331819059e+66*cos(theta)**25 - 1.17105091625049e+66*cos(theta)**23 + 1.48137940905687e+65*cos(theta)**21 - 1.48775550407433e+64*cos(theta)**19 + 1.16807250319885e+63*cos(theta)**17 - 7.02600001924122e+61*cos(theta)**15 + 3.15269231632619e+60*cos(theta)**13 - 1.0182608723538e+59*cos(theta)**11 + 2.25278954060575e+57*cos(theta)**9 - 3.17667150261681e+55*cos(theta)**7 + 2.55008033466945e+53*cos(theta)**5 - 9.53301059689516e+50*cos(theta)**3 + 1.04758358207639e+48*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl78_m26(theta, phi):
    return 4.42370549070559e-49*(1.0 - cos(theta)**2)**13*(2.70634834797987e+69*cos(theta)**52 - 2.31523736091697e+70*cos(theta)**50 + 9.26851557883429e+70*cos(theta)**48 - 2.30792176002761e+71*cos(theta)**46 + 4.00788426447748e+71*cos(theta)**44 - 5.15844695808938e+71*cos(theta)**42 + 5.10508371369535e+71*cos(theta)**40 - 3.977987309373e+71*cos(theta)**38 + 2.47918889936988e+71*cos(theta)**36 - 1.24851239536612e+71*cos(theta)**34 + 5.11252156058683e+70*cos(theta)**32 - 1.70761662899062e+70*cos(theta)**30 + 4.65421825570751e+69*cos(theta)**28 - 1.03305607789632e+69*cos(theta)**26 + 1.85904332954765e+68*cos(theta)**24 - 2.69341710737612e+67*cos(theta)**22 + 3.11089675901942e+66*cos(theta)**20 - 2.82673545774122e+65*cos(theta)**18 + 1.98572325543805e+64*cos(theta)**16 - 1.05390000288618e+63*cos(theta)**14 + 4.09850001122404e+61*cos(theta)**12 - 1.12008695958918e+60*cos(theta)**10 + 2.02751058654518e+58*cos(theta)**8 - 2.22367005183176e+56*cos(theta)**6 + 1.27504016733473e+54*cos(theta)**4 - 2.85990317906855e+51*cos(theta)**2 + 1.04758358207639e+48)*cos(26*phi)

#@torch.jit.script
def Yl78_m27(theta, phi):
    return 5.98673293105068e-51*(1.0 - cos(theta)**2)**13.5*(1.40730114094953e+71*cos(theta)**51 - 1.15761868045849e+72*cos(theta)**49 + 4.44888747784046e+72*cos(theta)**47 - 1.0616440096127e+73*cos(theta)**45 + 1.76346907637009e+73*cos(theta)**43 - 2.16654772239754e+73*cos(theta)**41 + 2.04203348547814e+73*cos(theta)**39 - 1.51163517756174e+73*cos(theta)**37 + 8.92508003773155e+72*cos(theta)**35 - 4.24494214424482e+72*cos(theta)**33 + 1.63600689938779e+72*cos(theta)**31 - 5.12284988697186e+71*cos(theta)**29 + 1.3031811115981e+71*cos(theta)**27 - 2.68594580253044e+70*cos(theta)**25 + 4.46170399091436e+69*cos(theta)**23 - 5.92551763622747e+68*cos(theta)**21 + 6.22179351803884e+67*cos(theta)**19 - 5.0881238239342e+66*cos(theta)**17 + 3.17715720870088e+65*cos(theta)**15 - 1.47546000404066e+64*cos(theta)**13 + 4.91820001346885e+62*cos(theta)**11 - 1.12008695958918e+61*cos(theta)**9 + 1.62200846923614e+59*cos(theta)**7 - 1.33420203109906e+57*cos(theta)**5 + 5.10016066933891e+54*cos(theta)**3 - 5.71980635813709e+51*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl78_m28(theta, phi):
    return 8.14238932143812e-53*(1.0 - cos(theta)**2)**14*(7.17723581884262e+72*cos(theta)**50 - 5.67233153424658e+73*cos(theta)**48 + 2.09097711458502e+74*cos(theta)**46 - 4.77739804325715e+74*cos(theta)**44 + 7.58291702839139e+74*cos(theta)**42 - 8.88284566182991e+74*cos(theta)**40 + 7.96393059336475e+74*cos(theta)**38 - 5.59305015697844e+74*cos(theta)**36 + 3.12377801320604e+74*cos(theta)**34 - 1.40083090760079e+74*cos(theta)**32 + 5.07162138810214e+73*cos(theta)**30 - 1.48562646722184e+73*cos(theta)**28 + 3.51858900131488e+72*cos(theta)**26 - 6.71486450632611e+71*cos(theta)**24 + 1.0261919179103e+71*cos(theta)**22 - 1.24435870360777e+70*cos(theta)**20 + 1.18214076842738e+69*cos(theta)**18 - 8.64981050068814e+67*cos(theta)**16 + 4.76573581305132e+66*cos(theta)**14 - 1.91809800525285e+65*cos(theta)**12 + 5.41002001481574e+63*cos(theta)**10 - 1.00807826363026e+62*cos(theta)**8 + 1.1354059284653e+60*cos(theta)**6 - 6.67101015549529e+57*cos(theta)**4 + 1.53004820080167e+55*cos(theta)**2 - 5.71980635813709e+51)*cos(28*phi)

#@torch.jit.script
def Yl78_m29(theta, phi):
    return 1.1132045504982e-54*(1.0 - cos(theta)**2)**14.5*(3.58861790942131e+74*cos(theta)**49 - 2.72271913643836e+75*cos(theta)**47 + 9.61849472709107e+75*cos(theta)**45 - 2.10205513903315e+76*cos(theta)**43 + 3.18482515192438e+76*cos(theta)**41 - 3.55313826473196e+76*cos(theta)**39 + 3.0262936254786e+76*cos(theta)**37 - 2.01349805651224e+76*cos(theta)**35 + 1.06208452449005e+76*cos(theta)**33 - 4.48265890432253e+75*cos(theta)**31 + 1.52148641643064e+75*cos(theta)**29 - 4.15975410822115e+74*cos(theta)**27 + 9.14833140341869e+73*cos(theta)**25 - 1.61156748151827e+73*cos(theta)**23 + 2.25762221940266e+72*cos(theta)**21 - 2.48871740721554e+71*cos(theta)**19 + 2.12785338316928e+70*cos(theta)**17 - 1.3839696801101e+69*cos(theta)**15 + 6.67203013827184e+67*cos(theta)**13 - 2.30171760630342e+66*cos(theta)**11 + 5.41002001481574e+64*cos(theta)**9 - 8.06462610904209e+62*cos(theta)**7 + 6.81243557079179e+60*cos(theta)**5 - 2.66840406219812e+58*cos(theta)**3 + 3.06009640160334e+55*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl78_m30(theta, phi):
    return 1.53025939736489e-56*(1.0 - cos(theta)**2)**15*(1.75842277561644e+76*cos(theta)**48 - 1.27967799412603e+77*cos(theta)**46 + 4.32832262719098e+77*cos(theta)**44 - 9.03883709784254e+77*cos(theta)**42 + 1.305778312289e+78*cos(theta)**40 - 1.38572392324547e+78*cos(theta)**38 + 1.11972864142708e+78*cos(theta)**36 - 7.04724319779284e+77*cos(theta)**34 + 3.50487893081718e+77*cos(theta)**32 - 1.38962426033999e+77*cos(theta)**30 + 4.41231060764886e+76*cos(theta)**28 - 1.12313360921971e+76*cos(theta)**26 + 2.28708285085467e+75*cos(theta)**24 - 3.70660520749201e+74*cos(theta)**22 + 4.7410066607456e+73*cos(theta)**20 - 4.72856307370952e+72*cos(theta)**18 + 3.61735075138778e+71*cos(theta)**16 - 2.07595452016515e+70*cos(theta)**14 + 8.6736391797534e+68*cos(theta)**12 - 2.53188936693377e+67*cos(theta)**10 + 4.86901801333416e+65*cos(theta)**8 - 5.64523827632946e+63*cos(theta)**6 + 3.4062177853959e+61*cos(theta)**4 - 8.00521218659435e+58*cos(theta)**2 + 3.06009640160334e+55)*cos(30*phi)

#@torch.jit.script
def Yl78_m31(theta, phi):
    return 2.11558845098209e-58*(1.0 - cos(theta)**2)**15.5*(8.44042932295892e+77*cos(theta)**47 - 5.88651877297974e+78*cos(theta)**45 + 1.90446195596403e+79*cos(theta)**43 - 3.79631158109386e+79*cos(theta)**41 + 5.22311324915599e+79*cos(theta)**39 - 5.26575090833277e+79*cos(theta)**37 + 4.0310231091375e+79*cos(theta)**35 - 2.39606268724956e+79*cos(theta)**33 + 1.1215612578615e+79*cos(theta)**31 - 4.16887278101996e+78*cos(theta)**29 + 1.23544697014168e+78*cos(theta)**27 - 2.92014738397124e+77*cos(theta)**25 + 5.48899884205121e+76*cos(theta)**23 - 8.15453145648242e+75*cos(theta)**21 + 9.48201332149119e+74*cos(theta)**19 - 8.51141353267713e+73*cos(theta)**17 + 5.78776120222045e+72*cos(theta)**15 - 2.90633632823122e+71*cos(theta)**13 + 1.04083670157041e+70*cos(theta)**11 - 2.53188936693377e+68*cos(theta)**9 + 3.89521441066733e+66*cos(theta)**7 - 3.38714296579768e+64*cos(theta)**5 + 1.36248711415836e+62*cos(theta)**3 - 1.60104243731887e+59*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl78_m32(theta, phi):
    return 2.94229298269119e-60*(1.0 - cos(theta)**2)**16*(3.96700178179069e+79*cos(theta)**46 - 2.64893344784088e+80*cos(theta)**44 + 8.18918641064534e+80*cos(theta)**42 - 1.55648774824848e+81*cos(theta)**40 + 2.03701416717084e+81*cos(theta)**38 - 1.94832783608313e+81*cos(theta)**36 + 1.41085808819813e+81*cos(theta)**34 - 7.90700686792356e+80*cos(theta)**32 + 3.47683989937064e+80*cos(theta)**30 - 1.20897310649579e+80*cos(theta)**28 + 3.33570681938254e+79*cos(theta)**26 - 7.30036845992811e+78*cos(theta)**24 + 1.26246973367178e+78*cos(theta)**22 - 1.71245160586131e+77*cos(theta)**20 + 1.80158253108333e+76*cos(theta)**18 - 1.44694030055511e+75*cos(theta)**16 + 8.68164180333067e+73*cos(theta)**14 - 3.77823722670058e+72*cos(theta)**12 + 1.14492037172745e+71*cos(theta)**10 - 2.27870043024039e+69*cos(theta)**8 + 2.72665008746713e+67*cos(theta)**6 - 1.69357148289884e+65*cos(theta)**4 + 4.08746134247508e+62*cos(theta)**2 - 1.60104243731887e+59)*cos(32*phi)

#@torch.jit.script
def Yl78_m33(theta, phi):
    return 4.11761285180192e-62*(1.0 - cos(theta)**2)**16.5*(1.82482081962372e+81*cos(theta)**45 - 1.16553071704999e+82*cos(theta)**43 + 3.43945829247104e+82*cos(theta)**41 - 6.22595099299394e+82*cos(theta)**39 + 7.74065383524918e+82*cos(theta)**37 - 7.01398020989925e+82*cos(theta)**35 + 4.79691749987363e+82*cos(theta)**33 - 2.53024219773554e+82*cos(theta)**31 + 1.04305196981119e+82*cos(theta)**29 - 3.3851246981882e+81*cos(theta)**27 + 8.6728377303946e+80*cos(theta)**25 - 1.75208843038275e+80*cos(theta)**23 + 2.77743341407791e+79*cos(theta)**21 - 3.42490321172262e+78*cos(theta)**19 + 3.24284855594999e+77*cos(theta)**17 - 2.31510448088818e+76*cos(theta)**15 + 1.21542985246629e+75*cos(theta)**13 - 4.5338846720407e+73*cos(theta)**11 + 1.14492037172745e+72*cos(theta)**9 - 1.82296034419231e+70*cos(theta)**7 + 1.63599005248028e+68*cos(theta)**5 - 6.77428593159536e+65*cos(theta)**3 + 8.17492268495015e+62*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl78_m34(theta, phi):
    return 5.80003003504202e-64*(1.0 - cos(theta)**2)**17*(8.21169368830673e+82*cos(theta)**44 - 5.01178208331495e+83*cos(theta)**42 + 1.41017789991313e+84*cos(theta)**40 - 2.42812088726764e+84*cos(theta)**38 + 2.86404191904219e+84*cos(theta)**36 - 2.45489307346474e+84*cos(theta)**34 + 1.5829827749583e+84*cos(theta)**32 - 7.84375081298017e+83*cos(theta)**30 + 3.02485071245246e+83*cos(theta)**28 - 9.13983668510815e+82*cos(theta)**26 + 2.16820943259865e+82*cos(theta)**24 - 4.02980338988032e+81*cos(theta)**22 + 5.83261016956362e+80*cos(theta)**20 - 6.50731610227297e+79*cos(theta)**18 + 5.51284254511498e+78*cos(theta)**16 - 3.47265672133227e+77*cos(theta)**14 + 1.58005880820618e+76*cos(theta)**12 - 4.98727313924477e+74*cos(theta)**10 + 1.0304283345547e+73*cos(theta)**8 - 1.27607224093462e+71*cos(theta)**6 + 8.17995026240139e+68*cos(theta)**4 - 2.03228577947861e+66*cos(theta)**2 + 8.17492268495015e+62)*cos(34*phi)

#@torch.jit.script
def Yl78_m35(theta, phi):
    return 8.22554499846062e-66*(1.0 - cos(theta)**2)**17.5*(3.61314522285496e+84*cos(theta)**43 - 2.10494847499228e+85*cos(theta)**41 + 5.64071159965251e+85*cos(theta)**39 - 9.22685937161702e+85*cos(theta)**37 + 1.03105509085519e+86*cos(theta)**35 - 8.34663644978011e+85*cos(theta)**33 + 5.06554487986655e+85*cos(theta)**31 - 2.35312524389405e+85*cos(theta)**29 + 8.46958199486689e+84*cos(theta)**27 - 2.37635753812812e+84*cos(theta)**25 + 5.20370263823676e+83*cos(theta)**23 - 8.8655674577367e+82*cos(theta)**21 + 1.16652203391272e+82*cos(theta)**19 - 1.17131689840914e+81*cos(theta)**17 + 8.82054807218396e+79*cos(theta)**15 - 4.86171940986518e+78*cos(theta)**13 + 1.89607056984742e+77*cos(theta)**11 - 4.98727313924477e+75*cos(theta)**9 + 8.24342667643763e+73*cos(theta)**7 - 7.65643344560771e+71*cos(theta)**5 + 3.27198010496056e+69*cos(theta)**3 - 4.06457155895721e+66*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl78_m36(theta, phi):
    return 1.17483811850223e-67*(1.0 - cos(theta)**2)**18*(1.55365244582763e+86*cos(theta)**42 - 8.63028874746834e+86*cos(theta)**40 + 2.19987752386448e+87*cos(theta)**38 - 3.4139379674983e+87*cos(theta)**36 + 3.60869281799317e+87*cos(theta)**34 - 2.75439002842744e+87*cos(theta)**32 + 1.57031891275863e+87*cos(theta)**30 - 6.82406320729275e+86*cos(theta)**28 + 2.28678713861406e+86*cos(theta)**26 - 5.9408938453203e+85*cos(theta)**24 + 1.19685160679445e+85*cos(theta)**22 - 1.86176916612471e+84*cos(theta)**20 + 2.21639186443417e+83*cos(theta)**18 - 1.99123872729553e+82*cos(theta)**16 + 1.32308221082759e+81*cos(theta)**14 - 6.32023523282473e+79*cos(theta)**12 + 2.08567762683216e+78*cos(theta)**10 - 4.48854582532029e+76*cos(theta)**8 + 5.77039867350634e+74*cos(theta)**6 - 3.82821672280385e+72*cos(theta)**4 + 9.81594031488167e+69*cos(theta)**2 - 4.06457155895721e+66)*cos(36*phi)

#@torch.jit.script
def Yl78_m37(theta, phi):
    return 1.69045830621872e-69*(1.0 - cos(theta)**2)**18.5*(6.52534027247606e+87*cos(theta)**41 - 3.45211549898734e+88*cos(theta)**39 + 8.35953459068502e+88*cos(theta)**37 - 1.22901766829939e+89*cos(theta)**35 + 1.22695555811768e+89*cos(theta)**33 - 8.8140480909678e+88*cos(theta)**31 + 4.71095673827589e+88*cos(theta)**29 - 1.91073769804197e+88*cos(theta)**27 + 5.94564656039656e+87*cos(theta)**25 - 1.42581452287687e+87*cos(theta)**23 + 2.6330735349478e+86*cos(theta)**21 - 3.72353833224941e+85*cos(theta)**19 + 3.98950535598152e+84*cos(theta)**17 - 3.18598196367285e+83*cos(theta)**15 + 1.85231509515863e+82*cos(theta)**13 - 7.58428227938968e+80*cos(theta)**11 + 2.08567762683216e+79*cos(theta)**9 - 3.59083666025623e+77*cos(theta)**7 + 3.4622392041038e+75*cos(theta)**5 - 1.53128668912154e+73*cos(theta)**3 + 1.96318806297633e+70*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl78_m38(theta, phi):
    return 2.45122705110393e-71*(1.0 - cos(theta)**2)**19*(2.67538951171518e+89*cos(theta)**40 - 1.34632504460506e+90*cos(theta)**38 + 3.09302779855346e+90*cos(theta)**36 - 4.30156183904785e+90*cos(theta)**34 + 4.04895334178833e+90*cos(theta)**32 - 2.73235490820002e+90*cos(theta)**30 + 1.36617745410001e+90*cos(theta)**28 - 5.15899178471332e+89*cos(theta)**26 + 1.48641164009914e+89*cos(theta)**24 - 3.27937340261681e+88*cos(theta)**22 + 5.52945442339038e+87*cos(theta)**20 - 7.07472283127389e+86*cos(theta)**18 + 6.78215910516858e+85*cos(theta)**16 - 4.77897294550927e+84*cos(theta)**14 + 2.40800962370622e+83*cos(theta)**12 - 8.34271050732864e+81*cos(theta)**10 + 1.87710986414895e+80*cos(theta)**8 - 2.51358566217936e+78*cos(theta)**6 + 1.7311196020519e+76*cos(theta)**4 - 4.59386006736462e+73*cos(theta)**2 + 1.96318806297633e+70)*cos(38*phi)

#@torch.jit.script
def Yl78_m39(theta, phi):
    return 3.58311390385504e-73*(1.0 - cos(theta)**2)**19.5*(1.07015580468607e+91*cos(theta)**39 - 5.11603516949923e+91*cos(theta)**37 + 1.11349000747924e+92*cos(theta)**35 - 1.46253102527627e+92*cos(theta)**33 + 1.29566506937227e+92*cos(theta)**31 - 8.19706472460005e+91*cos(theta)**29 + 3.82529687148002e+91*cos(theta)**27 - 1.34133786402546e+91*cos(theta)**25 + 3.56738793623793e+90*cos(theta)**23 - 7.21462148575697e+89*cos(theta)**21 + 1.10589088467808e+89*cos(theta)**19 - 1.2734501096293e+88*cos(theta)**17 + 1.08514545682697e+87*cos(theta)**15 - 6.69056212371298e+85*cos(theta)**13 + 2.88961154844747e+84*cos(theta)**11 - 8.34271050732864e+82*cos(theta)**9 + 1.50168789131916e+81*cos(theta)**7 - 1.50815139730762e+79*cos(theta)**5 + 6.92447840820761e+76*cos(theta)**3 - 9.18772013472925e+73*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl78_m40(theta, phi):
    return 5.28186512433385e-75*(1.0 - cos(theta)**2)**20*(4.17360763827569e+92*cos(theta)**38 - 1.89293301271472e+93*cos(theta)**36 + 3.89721502617736e+93*cos(theta)**34 - 4.82635238341169e+93*cos(theta)**32 + 4.01656171505403e+93*cos(theta)**30 - 2.37714877013401e+93*cos(theta)**28 + 1.03283015529961e+93*cos(theta)**26 - 3.35334466006366e+92*cos(theta)**24 + 8.20499225334725e+91*cos(theta)**22 - 1.51507051200896e+91*cos(theta)**20 + 2.10119268088834e+90*cos(theta)**18 - 2.16486518636981e+89*cos(theta)**16 + 1.62771818524046e+88*cos(theta)**14 - 8.69773076082688e+86*cos(theta)**12 + 3.17857270329221e+85*cos(theta)**10 - 7.50843945659578e+83*cos(theta)**8 + 1.05118152392341e+82*cos(theta)**6 - 7.54075698653809e+79*cos(theta)**4 + 2.07734352246228e+77*cos(theta)**2 - 9.18772013472925e+73)*cos(40*phi)

#@torch.jit.script
def Yl78_m41(theta, phi):
    return 7.85456301061312e-77*(1.0 - cos(theta)**2)**20.5*(1.58597090254476e+94*cos(theta)**37 - 6.81455884577298e+94*cos(theta)**35 + 1.3250531089003e+95*cos(theta)**33 - 1.54443276269174e+95*cos(theta)**31 + 1.20496851451621e+95*cos(theta)**29 - 6.65601655637524e+94*cos(theta)**27 + 2.68535840377898e+94*cos(theta)**25 - 8.04802718415278e+93*cos(theta)**23 + 1.80509829573639e+93*cos(theta)**21 - 3.03014102401793e+92*cos(theta)**19 + 3.78214682559902e+91*cos(theta)**17 - 3.46378429819169e+90*cos(theta)**15 + 2.27880545933664e+89*cos(theta)**13 - 1.04372769129923e+88*cos(theta)**11 + 3.17857270329221e+86*cos(theta)**9 - 6.00675156527662e+84*cos(theta)**7 + 6.30708914354045e+82*cos(theta)**5 - 3.01630279461523e+80*cos(theta)**3 + 4.15468704492457e+77*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl78_m42(theta, phi):
    return 1.17877398600544e-78*(1.0 - cos(theta)**2)**21*(5.86809233941562e+95*cos(theta)**36 - 2.38509559602054e+96*cos(theta)**34 + 4.37267525937099e+96*cos(theta)**32 - 4.7877415643444e+96*cos(theta)**30 + 3.494408692097e+96*cos(theta)**28 - 1.79712447022132e+96*cos(theta)**26 + 6.71339600944744e+95*cos(theta)**24 - 1.85104625235514e+95*cos(theta)**22 + 3.79070642104643e+94*cos(theta)**20 - 5.75726794563406e+93*cos(theta)**18 + 6.42964960351833e+92*cos(theta)**16 - 5.19567644728754e+91*cos(theta)**14 + 2.96244709713763e+90*cos(theta)**12 - 1.14810046042915e+89*cos(theta)**10 + 2.86071543296299e+87*cos(theta)**8 - 4.20472609569364e+85*cos(theta)**6 + 3.15354457177023e+83*cos(theta)**4 - 9.0489083838457e+80*cos(theta)**2 + 4.15468704492457e+77)*cos(42*phi)

#@torch.jit.script
def Yl78_m43(theta, phi):
    return 1.78602119091733e-80*(1.0 - cos(theta)**2)**21.5*(2.11251324218962e+97*cos(theta)**35 - 8.10932502646984e+97*cos(theta)**33 + 1.39925608299872e+98*cos(theta)**31 - 1.43632246930332e+98*cos(theta)**29 + 9.7843443378716e+97*cos(theta)**27 - 4.67252362257542e+97*cos(theta)**25 + 1.61121504226739e+97*cos(theta)**23 - 4.07230175518131e+96*cos(theta)**21 + 7.58141284209286e+95*cos(theta)**19 - 1.03630823021413e+95*cos(theta)**17 + 1.02874393656293e+94*cos(theta)**15 - 7.27394702620256e+92*cos(theta)**13 + 3.55493651656516e+91*cos(theta)**11 - 1.14810046042915e+90*cos(theta)**9 + 2.28857234637039e+88*cos(theta)**7 - 2.52283565741618e+86*cos(theta)**5 + 1.26141782870809e+84*cos(theta)**3 - 1.80978167676914e+81*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl78_m44(theta, phi):
    return 2.73320791631936e-82*(1.0 - cos(theta)**2)**22*(7.39379634766368e+98*cos(theta)**34 - 2.67607725873505e+99*cos(theta)**32 + 4.33769385729602e+99*cos(theta)**30 - 4.16533516097963e+99*cos(theta)**28 + 2.64177297122533e+99*cos(theta)**26 - 1.16813090564385e+99*cos(theta)**24 + 3.70579459721499e+98*cos(theta)**22 - 8.55183368588074e+97*cos(theta)**20 + 1.44046843999764e+97*cos(theta)**18 - 1.76172399136402e+96*cos(theta)**16 + 1.5431159048444e+95*cos(theta)**14 - 9.45613113406333e+93*cos(theta)**12 + 3.91043016822168e+92*cos(theta)**10 - 1.03329041438623e+91*cos(theta)**8 + 1.60200064245928e+89*cos(theta)**6 - 1.26141782870809e+87*cos(theta)**4 + 3.78425348612427e+84*cos(theta)**2 - 1.80978167676914e+81)*cos(44*phi)

#@torch.jit.script
def Yl78_m45(theta, phi):
    return 4.22649788202925e-84*(1.0 - cos(theta)**2)**22.5*(2.51389075820565e+100*cos(theta)**33 - 8.56344722795215e+100*cos(theta)**31 + 1.30130815718881e+101*cos(theta)**29 - 1.1662938450743e+101*cos(theta)**27 + 6.86860972518587e+100*cos(theta)**25 - 2.80351417354525e+100*cos(theta)**23 + 8.15274811387297e+99*cos(theta)**21 - 1.71036673717615e+99*cos(theta)**19 + 2.59284319199576e+98*cos(theta)**17 - 2.81875838618244e+97*cos(theta)**15 + 2.16036226678216e+96*cos(theta)**13 - 1.1347357360876e+95*cos(theta)**11 + 3.91043016822168e+93*cos(theta)**9 - 8.26632331508986e+91*cos(theta)**7 + 9.61200385475565e+89*cos(theta)**5 - 5.04567131483236e+87*cos(theta)**3 + 7.56850697224855e+84*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl78_m46(theta, phi):
    return 6.60712986631682e-86*(1.0 - cos(theta)**2)**23*(8.29583950207865e+101*cos(theta)**32 - 2.65466864066517e+102*cos(theta)**30 + 3.77379365584754e+102*cos(theta)**28 - 3.1489933817006e+102*cos(theta)**26 + 1.71715243129647e+102*cos(theta)**24 - 6.44808259915408e+101*cos(theta)**22 + 1.71207710391332e+101*cos(theta)**20 - 3.24969680063468e+100*cos(theta)**18 + 4.40783342639279e+99*cos(theta)**16 - 4.22813757927366e+98*cos(theta)**14 + 2.80847094681681e+97*cos(theta)**12 - 1.24820930969636e+96*cos(theta)**10 + 3.51938715139951e+94*cos(theta)**8 - 5.7864263205629e+92*cos(theta)**6 + 4.80600192737783e+90*cos(theta)**4 - 1.51370139444971e+88*cos(theta)**2 + 7.56850697224855e+84)*cos(46*phi)

#@torch.jit.script
def Yl78_m47(theta, phi):
    return 1.04467895870425e-87*(1.0 - cos(theta)**2)**23.5*(2.65466864066517e+103*cos(theta)**31 - 7.9640059219955e+103*cos(theta)**29 + 1.05666222363731e+104*cos(theta)**27 - 8.18738279242155e+103*cos(theta)**25 + 4.12116583511152e+103*cos(theta)**23 - 1.4185781718139e+103*cos(theta)**21 + 3.42415420782665e+102*cos(theta)**19 - 5.84945424114243e+101*cos(theta)**17 + 7.05253348222846e+100*cos(theta)**15 - 5.91939261098312e+99*cos(theta)**13 + 3.37016513618017e+98*cos(theta)**11 - 1.24820930969636e+97*cos(theta)**9 + 2.81550972111961e+95*cos(theta)**7 - 3.47185579233774e+93*cos(theta)**5 + 1.92240077095113e+91*cos(theta)**3 - 3.02740278889942e+88*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl78_m48(theta, phi):
    return 1.67153982405702e-89*(1.0 - cos(theta)**2)**24*(8.22947278606202e+104*cos(theta)**30 - 2.3095617173787e+105*cos(theta)**28 + 2.85298800382074e+105*cos(theta)**26 - 2.04684569810539e+105*cos(theta)**24 + 9.4786814207565e+104*cos(theta)**22 - 2.97901416080918e+104*cos(theta)**20 + 6.50589299487063e+103*cos(theta)**18 - 9.94407220994213e+102*cos(theta)**16 + 1.05788002233427e+102*cos(theta)**14 - 7.69521039427805e+100*cos(theta)**12 + 3.70718164979819e+99*cos(theta)**10 - 1.12338837872672e+98*cos(theta)**8 + 1.97085680478372e+96*cos(theta)**6 - 1.73592789616887e+94*cos(theta)**4 + 5.76720231285339e+91*cos(theta)**2 - 3.02740278889942e+88)*cos(48*phi)

#@torch.jit.script
def Yl78_m49(theta, phi):
    return 2.70803479480809e-91*(1.0 - cos(theta)**2)**24.5*(2.46884183581861e+106*cos(theta)**29 - 6.46677280866035e+106*cos(theta)**27 + 7.41776880993393e+106*cos(theta)**25 - 4.91242967545293e+106*cos(theta)**23 + 2.08530991256643e+106*cos(theta)**21 - 5.95802832161837e+105*cos(theta)**19 + 1.17106073907671e+105*cos(theta)**17 - 1.59105155359074e+104*cos(theta)**15 + 1.48103203126798e+103*cos(theta)**13 - 9.23425247313366e+101*cos(theta)**11 + 3.70718164979819e+100*cos(theta)**9 - 8.98710702981379e+98*cos(theta)**7 + 1.18251408287024e+97*cos(theta)**5 - 6.94371158467548e+94*cos(theta)**3 + 1.15344046257068e+92*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl78_m50(theta, phi):
    return 4.44477986207826e-93*(1.0 - cos(theta)**2)**25*(7.15964132387396e+107*cos(theta)**28 - 1.74602865833829e+108*cos(theta)**26 + 1.85444220248348e+108*cos(theta)**24 - 1.12985882535417e+108*cos(theta)**22 + 4.3791508163895e+107*cos(theta)**20 - 1.13202538110749e+107*cos(theta)**18 + 1.99080325643041e+106*cos(theta)**16 - 2.38657733038611e+105*cos(theta)**14 + 1.92534164064837e+104*cos(theta)**12 - 1.0157677720447e+103*cos(theta)**10 + 3.33646348481837e+101*cos(theta)**8 - 6.29097492086965e+99*cos(theta)**6 + 5.91257041435118e+97*cos(theta)**4 - 2.08311347540265e+95*cos(theta)**2 + 1.15344046257068e+92)*cos(50*phi)

#@torch.jit.script
def Yl78_m51(theta, phi):
    return 7.39565060710491e-95*(1.0 - cos(theta)**2)**25.5*(2.00469957068471e+109*cos(theta)**27 - 4.53967451167956e+109*cos(theta)**25 + 4.45066128596036e+109*cos(theta)**23 - 2.48568941577918e+109*cos(theta)**21 + 8.758301632779e+108*cos(theta)**19 - 2.03764568599348e+108*cos(theta)**17 + 3.18528521028866e+107*cos(theta)**15 - 3.34120826254055e+106*cos(theta)**13 + 2.31040996877804e+105*cos(theta)**11 - 1.0157677720447e+104*cos(theta)**9 + 2.66917078785469e+102*cos(theta)**7 - 3.77458495252179e+100*cos(theta)**5 + 2.36502816574047e+98*cos(theta)**3 - 4.16622695080529e+95*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl78_m52(theta, phi):
    return 1.24831108583523e-96*(1.0 - cos(theta)**2)**26*(5.41268884084871e+110*cos(theta)**26 - 1.13491862791989e+111*cos(theta)**24 + 1.02365209577088e+111*cos(theta)**22 - 5.21994777313629e+110*cos(theta)**20 + 1.66407731022801e+110*cos(theta)**18 - 3.46399766618892e+109*cos(theta)**16 + 4.77792781543299e+108*cos(theta)**14 - 4.34357074130272e+107*cos(theta)**12 + 2.54145096565585e+106*cos(theta)**10 - 9.14190994840233e+104*cos(theta)**8 + 1.86841955149829e+103*cos(theta)**6 - 1.8872924762609e+101*cos(theta)**4 + 7.09508449722141e+98*cos(theta)**2 - 4.16622695080529e+95)*cos(52*phi)

#@torch.jit.script
def Yl78_m53(theta, phi):
    return 2.13894937401544e-98*(1.0 - cos(theta)**2)**26.5*(1.40729909862066e+112*cos(theta)**25 - 2.72380470700774e+112*cos(theta)**23 + 2.25203461069594e+112*cos(theta)**21 - 1.04398955462726e+112*cos(theta)**19 + 2.99533915841042e+111*cos(theta)**17 - 5.54239626590227e+110*cos(theta)**15 + 6.68909894160619e+109*cos(theta)**13 - 5.21228488956326e+108*cos(theta)**11 + 2.54145096565585e+107*cos(theta)**9 - 7.31352795872186e+105*cos(theta)**7 + 1.12105173089897e+104*cos(theta)**5 - 7.54916990504358e+101*cos(theta)**3 + 1.41901689944428e+99*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl78_m54(theta, phi):
    return 3.72343293236516e-100*(1.0 - cos(theta)**2)**27*(3.51824774655166e+113*cos(theta)**24 - 6.2647508261178e+113*cos(theta)**22 + 4.72927268246147e+113*cos(theta)**20 - 1.98358015379179e+113*cos(theta)**18 + 5.09207656929771e+112*cos(theta)**16 - 8.31359439885341e+111*cos(theta)**14 + 8.69582862408805e+110*cos(theta)**12 - 5.73351337851959e+109*cos(theta)**10 + 2.28730586909026e+108*cos(theta)**8 - 5.1194695711053e+106*cos(theta)**6 + 5.60525865449486e+104*cos(theta)**4 - 2.26475097151307e+102*cos(theta)**2 + 1.41901689944428e+99)*cos(54*phi)

#@torch.jit.script
def Yl78_m55(theta, phi):
    return 6.59040485068495e-102*(1.0 - cos(theta)**2)**27.5*(8.44379459172399e+114*cos(theta)**23 - 1.37824518174592e+115*cos(theta)**21 + 9.45854536492295e+114*cos(theta)**19 - 3.57044427682522e+114*cos(theta)**17 + 8.14732251087634e+113*cos(theta)**15 - 1.16390321583948e+113*cos(theta)**13 + 1.04349943489057e+112*cos(theta)**11 - 5.73351337851959e+110*cos(theta)**9 + 1.82984469527221e+109*cos(theta)**7 - 3.07168174266318e+107*cos(theta)**5 + 2.24210346179794e+105*cos(theta)**3 - 4.52950194302615e+102*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl78_m56(theta, phi):
    return 1.18712315781526e-103*(1.0 - cos(theta)**2)**28*(1.94207275609652e+116*cos(theta)**22 - 2.89431488166642e+116*cos(theta)**20 + 1.79712361933536e+116*cos(theta)**18 - 6.06975527060287e+115*cos(theta)**16 + 1.22209837663145e+115*cos(theta)**14 - 1.51307418059132e+114*cos(theta)**12 + 1.14784937837962e+113*cos(theta)**10 - 5.16016204066763e+111*cos(theta)**8 + 1.28089128669055e+110*cos(theta)**6 - 1.53584087133159e+108*cos(theta)**4 + 6.72631038539383e+105*cos(theta)**2 - 4.52950194302615e+102)*cos(56*phi)

#@torch.jit.script
def Yl78_m57(theta, phi):
    return 2.17829930249497e-105*(1.0 - cos(theta)**2)**28.5*(4.27256006341234e+117*cos(theta)**21 - 5.78862976333285e+117*cos(theta)**19 + 3.23482251480365e+117*cos(theta)**17 - 9.7116084329646e+116*cos(theta)**15 + 1.71093772728403e+116*cos(theta)**13 - 1.81568901670958e+115*cos(theta)**11 + 1.14784937837962e+114*cos(theta)**9 - 4.12812963253411e+112*cos(theta)**7 + 7.68534772014328e+110*cos(theta)**5 - 6.14336348532636e+108*cos(theta)**3 + 1.34526207707877e+106*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl78_m58(theta, phi):
    return 4.07604012745502e-107*(1.0 - cos(theta)**2)**29*(8.97237613316591e+118*cos(theta)**20 - 1.09983965503324e+119*cos(theta)**18 + 5.4991982751662e+118*cos(theta)**16 - 1.45674126494469e+118*cos(theta)**14 + 2.22421904546924e+117*cos(theta)**12 - 1.99725791838054e+116*cos(theta)**10 + 1.03306444054166e+115*cos(theta)**8 - 2.88969074277387e+113*cos(theta)**6 + 3.84267386007164e+111*cos(theta)**4 - 1.84300904559791e+109*cos(theta)**2 + 1.34526207707877e+106)*cos(58*phi)

#@torch.jit.script
def Yl78_m59(theta, phi):
    return 7.78687439535216e-109*(1.0 - cos(theta)**2)**29.5*(1.79447522663318e+120*cos(theta)**19 - 1.97971137905983e+120*cos(theta)**17 + 8.79871724026592e+119*cos(theta)**15 - 2.03943777092257e+119*cos(theta)**13 + 2.66906285456309e+118*cos(theta)**11 - 1.99725791838054e+117*cos(theta)**9 + 8.26451552433328e+115*cos(theta)**7 - 1.73381444566432e+114*cos(theta)**5 + 1.53706954402866e+112*cos(theta)**3 - 3.68601809119582e+109*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl78_m60(theta, phi):
    return 1.52071148450559e-110*(1.0 - cos(theta)**2)**30*(3.40950293060305e+121*cos(theta)**18 - 3.36550934440172e+121*cos(theta)**16 + 1.31980758603989e+121*cos(theta)**14 - 2.65126910219933e+120*cos(theta)**12 + 2.9359691400194e+119*cos(theta)**10 - 1.79753212654249e+118*cos(theta)**8 + 5.7851608670333e+116*cos(theta)**6 - 8.66907222832162e+114*cos(theta)**4 + 4.61120863208597e+112*cos(theta)**2 - 3.68601809119582e+109)*cos(60*phi)

#@torch.jit.script
def Yl78_m61(theta, phi):
    return 3.04020712927881e-112*(1.0 - cos(theta)**2)**30.5*(6.13710527508548e+122*cos(theta)**17 - 5.38481495104275e+122*cos(theta)**15 + 1.84773062045584e+122*cos(theta)**13 - 3.1815229226392e+121*cos(theta)**11 + 2.9359691400194e+120*cos(theta)**9 - 1.43802570123399e+119*cos(theta)**7 + 3.47109652021998e+117*cos(theta)**5 - 3.46762889132865e+115*cos(theta)**3 + 9.22241726417194e+112*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl78_m62(theta, phi):
    return 6.23181704247764e-114*(1.0 - cos(theta)**2)**31*(1.04330789676453e+124*cos(theta)**16 - 8.07722242656412e+123*cos(theta)**14 + 2.4020498065926e+123*cos(theta)**12 - 3.49967521490312e+122*cos(theta)**10 + 2.64237222601746e+121*cos(theta)**8 - 1.00661799086379e+120*cos(theta)**6 + 1.73554826010999e+118*cos(theta)**4 - 1.04028866739859e+116*cos(theta)**2 + 9.22241726417194e+112)*cos(62*phi)

#@torch.jit.script
def Yl78_m63(theta, phi):
    return 1.3120341735144e-115*(1.0 - cos(theta)**2)**31.5*(1.66929263482325e+125*cos(theta)**15 - 1.13081113971898e+125*cos(theta)**13 + 2.88245976791112e+124*cos(theta)**11 - 3.49967521490312e+123*cos(theta)**9 + 2.11389778081397e+122*cos(theta)**7 - 6.03970794518276e+120*cos(theta)**5 + 6.94219304043996e+118*cos(theta)**3 - 2.08057733479719e+116*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl78_m64(theta, phi):
    return 2.84285916421425e-117*(1.0 - cos(theta)**2)**32*(2.50393895223488e+126*cos(theta)**14 - 1.47005448163467e+126*cos(theta)**12 + 3.17070574470223e+125*cos(theta)**10 - 3.14970769341281e+124*cos(theta)**8 + 1.47972844656978e+123*cos(theta)**6 - 3.01985397259138e+121*cos(theta)**4 + 2.08265791213199e+119*cos(theta)**2 - 2.08057733479719e+116)*cos(64*phi)

#@torch.jit.script
def Yl78_m65(theta, phi):
    return 6.35365031029558e-119*(1.0 - cos(theta)**2)**32.5*(3.50551453312883e+127*cos(theta)**13 - 1.7640653779616e+127*cos(theta)**11 + 3.17070574470223e+126*cos(theta)**9 - 2.51976615473025e+125*cos(theta)**7 + 8.87837067941866e+123*cos(theta)**5 - 1.20794158903655e+122*cos(theta)**3 + 4.16531582426397e+119*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl78_m66(theta, phi):
    return 1.46848794744477e-120*(1.0 - cos(theta)**2)**33*(4.55716889306748e+128*cos(theta)**12 - 1.94047191575776e+128*cos(theta)**10 + 2.85363517023201e+127*cos(theta)**8 - 1.76383630831117e+126*cos(theta)**6 + 4.43918533970933e+124*cos(theta)**4 - 3.62382476710966e+122*cos(theta)**2 + 4.16531582426397e+119)*cos(66*phi)

#@torch.jit.script
def Yl78_m67(theta, phi):
    return 3.52043039736682e-122*(1.0 - cos(theta)**2)**33.5*(5.46860267168097e+129*cos(theta)**11 - 1.94047191575776e+129*cos(theta)**9 + 2.2829081361856e+128*cos(theta)**7 - 1.0583017849867e+127*cos(theta)**5 + 1.77567413588373e+125*cos(theta)**3 - 7.24764953421931e+122*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl78_m68(theta, phi):
    return 8.78462024329062e-124*(1.0 - cos(theta)**2)**34*(6.01546293884907e+130*cos(theta)**10 - 1.74642472418199e+130*cos(theta)**8 + 1.59803569532992e+129*cos(theta)**6 - 5.29150892493352e+127*cos(theta)**4 + 5.3270224076512e+125*cos(theta)**2 - 7.24764953421931e+122)*cos(68*phi)

#@torch.jit.script
def Yl78_m69(theta, phi):
    return 2.29120698398419e-125*(1.0 - cos(theta)**2)**34.5*(6.01546293884907e+131*cos(theta)**9 - 1.39713977934559e+131*cos(theta)**7 + 9.58821417197954e+129*cos(theta)**5 - 2.11660356997341e+128*cos(theta)**3 + 1.06540448153024e+126*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl78_m70(theta, phi):
    return 6.27786846456604e-127*(1.0 - cos(theta)**2)**35*(5.41391664496416e+132*cos(theta)**8 - 9.77997845541913e+131*cos(theta)**6 + 4.79410708598977e+130*cos(theta)**4 - 6.34981070992022e+128*cos(theta)**2 + 1.06540448153024e+126)*cos(70*phi)

#@torch.jit.script
def Yl78_m71(theta, phi):
    return 1.81833577891948e-128*(1.0 - cos(theta)**2)**35.5*(4.33113331597133e+133*cos(theta)**7 - 5.86798707325148e+132*cos(theta)**5 + 1.91764283439591e+131*cos(theta)**3 - 1.26996214198404e+129*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl78_m72(theta, phi):
    return 5.61150604086412e-130*(1.0 - cos(theta)**2)**36*(3.03179332117993e+134*cos(theta)**6 - 2.93399353662574e+133*cos(theta)**4 + 5.75292850318772e+131*cos(theta)**2 - 1.26996214198404e+129)*cos(72*phi)

#@torch.jit.script
def Yl78_m73(theta, phi):
    return 1.86429800975251e-131*(1.0 - cos(theta)**2)**36.5*(1.81907599270796e+135*cos(theta)**5 - 1.1735974146503e+134*cos(theta)**3 + 1.15058570063754e+132*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl78_m74(theta, phi):
    return 6.76251964601404e-133*(1.0 - cos(theta)**2)**37*(9.09537996353979e+135*cos(theta)**4 - 3.52079224395089e+134*cos(theta)**2 + 1.15058570063754e+132)*cos(74*phi)

#@torch.jit.script
def Yl78_m75(theta, phi):
    return 2.73358654861083e-134*(1.0 - cos(theta)**2)**37.5*(3.63815198541592e+136*cos(theta)**3 - 7.04158448790177e+134*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl78_m76(theta, phi):
    return 1.27177956062001e-135*(1.0 - cos(theta)**2)**38*(1.09144559562477e+137*cos(theta)**2 - 7.04158448790177e+134)*cos(76*phi)

#@torch.jit.script
def Yl78_m77(theta, phi):
    return 15.7675088115108*(1.0 - cos(theta)**2)**38.5*cos(77*phi)*cos(theta)

#@torch.jit.script
def Yl78_m78(theta, phi):
    return 1.26241103804633*(1.0 - cos(theta)**2)**39*cos(78*phi)

#@torch.jit.script
def Yl79_m_minus_79(theta, phi):
    return 1.26639970845295*(1.0 - cos(theta)**2)**39.5*sin(79*phi)

#@torch.jit.script
def Yl79_m_minus_78(theta, phi):
    return 15.9183975012566*(1.0 - cos(theta)**2)**39*sin(78*phi)*cos(theta)

#@torch.jit.script
def Yl79_m_minus_77(theta, phi):
    return 8.23061767764012e-138*(1.0 - cos(theta)**2)**38.5*(1.7135695851309e+139*cos(theta)**2 - 1.09144559562477e+137)*sin(77*phi)

#@torch.jit.script
def Yl79_m_minus_76(theta, phi):
    return 1.78055484392831e-136*(1.0 - cos(theta)**2)**38*(5.71189861710299e+138*cos(theta)**3 - 1.09144559562477e+137*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl79_m_minus_75(theta, phi):
    return 4.43354580712399e-135*(1.0 - cos(theta)**2)**37.5*(1.42797465427575e+138*cos(theta)**4 - 5.45722797812387e+136*cos(theta)**2 + 1.76039612197544e+134)*sin(75*phi)

#@torch.jit.script
def Yl79_m_minus_74(theta, phi):
    return 1.23025903314616e-133*(1.0 - cos(theta)**2)**37*(2.85594930855149e+137*cos(theta)**5 - 1.81907599270796e+136*cos(theta)**3 + 1.76039612197544e+134*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl79_m_minus_73(theta, phi):
    return 3.72750215421727e-132*(1.0 - cos(theta)**2)**36.5*(4.75991551425249e+136*cos(theta)**6 - 4.5476899817699e+135*cos(theta)**4 + 8.80198060987722e+133*cos(theta)**2 - 1.91764283439591e+131)*sin(73*phi)

#@torch.jit.script
def Yl79_m_minus_72(theta, phi):
    return 1.21587440706328e-130*(1.0 - cos(theta)**2)**36*(6.79987930607499e+135*cos(theta)**7 - 9.09537996353979e+134*cos(theta)**5 + 2.93399353662574e+133*cos(theta)**3 - 1.91764283439591e+131*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl79_m_minus_71(theta, phi):
    return 4.22592888379797e-129*(1.0 - cos(theta)**2)**35.5*(8.49984913259373e+134*cos(theta)**8 - 1.51589666058997e+134*cos(theta)**6 + 7.33498384156435e+132*cos(theta)**4 - 9.58821417197954e+130*cos(theta)**2 + 1.58745267748006e+128)*sin(71*phi)

#@torch.jit.script
def Yl79_m_minus_70(theta, phi):
    return 1.55270541818914e-127*(1.0 - cos(theta)**2)**35*(9.44427681399304e+133*cos(theta)**9 - 2.16556665798566e+133*cos(theta)**7 + 1.46699676831287e+132*cos(theta)**5 - 3.19607139065985e+130*cos(theta)**3 + 1.58745267748006e+128*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl79_m_minus_69(theta, phi):
    return 5.99352336472808e-126*(1.0 - cos(theta)**2)**34.5*(9.44427681399304e+132*cos(theta)**10 - 2.70695832248208e+132*cos(theta)**8 + 2.44499461385478e+131*cos(theta)**6 - 7.99017847664962e+129*cos(theta)**4 + 7.93726338740028e+127*cos(theta)**2 - 1.06540448153024e+125)*sin(69*phi)

#@torch.jit.script
def Yl79_m_minus_68(theta, phi):
    return 2.41829569620271e-124*(1.0 - cos(theta)**2)**34*(8.58570619453912e+131*cos(theta)**11 - 3.00773146942453e+131*cos(theta)**9 + 3.49284944836398e+130*cos(theta)**7 - 1.59803569532992e+129*cos(theta)**5 + 2.64575446246676e+127*cos(theta)**3 - 1.06540448153024e+125*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl79_m_minus_67(theta, phi):
    return 1.01568419240514e-122*(1.0 - cos(theta)**2)**33.5*(7.15475516211594e+130*cos(theta)**12 - 3.00773146942453e+130*cos(theta)**10 + 4.36606181045497e+129*cos(theta)**8 - 2.66339282554987e+128*cos(theta)**6 + 6.6143861561669e+126*cos(theta)**4 - 5.32702240765119e+124*cos(theta)**2 + 6.03970794518276e+121)*sin(67*phi)

#@torch.jit.script
def Yl79_m_minus_66(theta, phi):
    return 4.42493400038439e-121*(1.0 - cos(theta)**2)**33*(5.50365781701226e+129*cos(theta)**13 - 2.73430133584049e+129*cos(theta)**11 + 4.85117978939441e+128*cos(theta)**9 - 3.80484689364267e+127*cos(theta)**7 + 1.32287723123338e+126*cos(theta)**5 - 1.77567413588373e+124*cos(theta)**3 + 6.03970794518276e+121*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl79_m_minus_65(theta, phi):
    return 1.99367708124331e-119*(1.0 - cos(theta)**2)**32.5*(3.93118415500876e+128*cos(theta)**14 - 2.27858444653374e+128*cos(theta)**12 + 4.85117978939441e+127*cos(theta)**10 - 4.75605861705334e+126*cos(theta)**8 + 2.20479538538897e+125*cos(theta)**6 - 4.43918533970933e+123*cos(theta)**4 + 3.01985397259138e+121*cos(theta)**2 - 2.97522558875998e+118)*sin(65*phi)

#@torch.jit.script
def Yl79_m_minus_64(theta, phi):
    return 9.26577376004489e-118*(1.0 - cos(theta)**2)**32*(2.6207894366725e+127*cos(theta)**15 - 1.75275726656441e+127*cos(theta)**13 + 4.41016344490401e+126*cos(theta)**11 - 5.28450957450371e+125*cos(theta)**9 + 3.14970769341281e+124*cos(theta)**7 - 8.87837067941866e+122*cos(theta)**5 + 1.00661799086379e+121*cos(theta)**3 - 2.97522558875998e+118*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl79_m_minus_63(theta, phi):
    return 4.43210154436816e-116*(1.0 - cos(theta)**2)**31.5*(1.63799339792032e+126*cos(theta)**16 - 1.25196947611744e+126*cos(theta)**14 + 3.67513620408667e+125*cos(theta)**12 - 5.28450957450371e+124*cos(theta)**10 + 3.93713461676601e+123*cos(theta)**8 - 1.47972844656978e+122*cos(theta)**6 + 2.51654497715948e+120*cos(theta)**4 - 1.48761279437999e+118*cos(theta)**2 + 1.30036083424824e+115)*sin(63*phi)

#@torch.jit.script
def Yl79_m_minus_62(theta, phi):
    return 2.17760113832657e-114*(1.0 - cos(theta)**2)**31*(9.63525528188421e+124*cos(theta)**17 - 8.34646317411626e+124*cos(theta)**15 + 2.82702784929744e+124*cos(theta)**13 - 4.80409961318519e+123*cos(theta)**11 + 4.3745940186289e+122*cos(theta)**9 - 2.11389778081397e+121*cos(theta)**7 + 5.03308995431897e+119*cos(theta)**5 - 4.95870931459997e+117*cos(theta)**3 + 1.30036083424824e+115*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl79_m_minus_61(theta, phi):
    return 1.09704424566073e-112*(1.0 - cos(theta)**2)**30.5*(5.35291960104678e+123*cos(theta)**18 - 5.21653948382266e+123*cos(theta)**16 + 2.01930560664103e+123*cos(theta)**14 - 4.003416344321e+122*cos(theta)**12 + 4.3745940186289e+121*cos(theta)**10 - 2.64237222601746e+120*cos(theta)**8 + 8.38848325719828e+118*cos(theta)**6 - 1.23967732864999e+117*cos(theta)**4 + 6.50180417124122e+114*cos(theta)**2 - 5.12356514676219e+111)*sin(61*phi)

#@torch.jit.script
def Yl79_m_minus_60(theta, phi):
    return 5.6580263030966e-111*(1.0 - cos(theta)**2)**30*(2.8173261058141e+122*cos(theta)**19 - 3.06855263754274e+122*cos(theta)**17 + 1.34620373776069e+122*cos(theta)**15 - 3.07955103409307e+121*cos(theta)**13 + 3.976903653299e+120*cos(theta)**11 - 2.9359691400194e+119*cos(theta)**9 + 1.19835475102833e+118*cos(theta)**7 - 2.47935465729998e+116*cos(theta)**5 + 2.16726805708041e+114*cos(theta)**3 - 5.12356514676219e+111*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl79_m_minus_59(theta, phi):
    return 2.98323427469855e-109*(1.0 - cos(theta)**2)**29.5*(1.40866305290705e+121*cos(theta)**20 - 1.70475146530152e+121*cos(theta)**18 + 8.41377336100429e+120*cos(theta)**16 - 2.19967931006648e+120*cos(theta)**14 + 3.31408637774917e+119*cos(theta)**12 - 2.9359691400194e+118*cos(theta)**10 + 1.49794343878541e+117*cos(theta)**8 - 4.13225776216664e+115*cos(theta)**6 + 5.41817014270101e+113*cos(theta)**4 - 2.56178257338109e+111*cos(theta)**2 + 1.84300904559791e+108)*sin(59*phi)

#@torch.jit.script
def Yl79_m_minus_58(theta, phi):
    return 1.60596675451142e-107*(1.0 - cos(theta)**2)**29*(6.70791929955737e+119*cos(theta)**21 - 8.97237613316591e+119*cos(theta)**19 + 4.94927844764958e+119*cos(theta)**17 - 1.46645287337765e+119*cos(theta)**15 + 2.54929721365321e+118*cos(theta)**13 - 2.66906285456309e+117*cos(theta)**11 + 1.66438159865045e+116*cos(theta)**9 - 5.90322537452377e+114*cos(theta)**7 + 1.0836340285402e+113*cos(theta)**5 - 8.53927524460365e+110*cos(theta)**3 + 1.84300904559791e+108*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl79_m_minus_57(theta, phi):
    return 8.81674285596453e-106*(1.0 - cos(theta)**2)**28.5*(3.04905422707153e+118*cos(theta)**22 - 4.48618806658295e+118*cos(theta)**20 + 2.7495991375831e+118*cos(theta)**18 - 9.16533045861034e+117*cos(theta)**16 + 1.82092658118086e+117*cos(theta)**14 - 2.22421904546924e+116*cos(theta)**12 + 1.66438159865045e+115*cos(theta)**10 - 7.37903171815471e+113*cos(theta)**8 + 1.80605671423367e+112*cos(theta)**6 - 2.13481881115091e+110*cos(theta)**4 + 9.21504522798955e+107*cos(theta)**2 - 6.1148276230853e+104)*sin(57*phi)

#@torch.jit.script
def Yl79_m_minus_56(theta, phi):
    return 4.9310743043671e-104*(1.0 - cos(theta)**2)**28*(1.32567575090067e+117*cos(theta)**23 - 2.13628003170617e+117*cos(theta)**21 + 1.44715744083321e+117*cos(theta)**19 - 5.39137085800608e+116*cos(theta)**17 + 1.21395105412057e+116*cos(theta)**15 - 1.71093772728403e+115*cos(theta)**13 + 1.51307418059132e+114*cos(theta)**11 - 8.19892413128302e+112*cos(theta)**9 + 2.58008102033382e+111*cos(theta)**7 - 4.26963762230182e+109*cos(theta)**5 + 3.07168174266318e+107*cos(theta)**3 - 6.1148276230853e+104*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl79_m_minus_55(theta, phi):
    return 2.80681670039947e-102*(1.0 - cos(theta)**2)**27.5*(5.52364896208611e+115*cos(theta)**24 - 9.71036378048259e+115*cos(theta)**22 + 7.23578720416606e+115*cos(theta)**20 - 2.9952060322256e+115*cos(theta)**18 + 7.58719408825359e+114*cos(theta)**16 - 1.22209837663145e+114*cos(theta)**14 + 1.26089515049277e+113*cos(theta)**12 - 8.19892413128302e+111*cos(theta)**10 + 3.22510127541727e+110*cos(theta)**8 - 7.11606270383637e+108*cos(theta)**6 + 7.67920435665796e+106*cos(theta)**4 - 3.05741381154265e+104*cos(theta)**2 + 1.8872924762609e+101)*sin(55*phi)

#@torch.jit.script
def Yl79_m_minus_54(theta, phi):
    return 1.62456261699261e-100*(1.0 - cos(theta)**2)**27*(2.20945958483444e+114*cos(theta)**25 - 4.22189729586199e+114*cos(theta)**23 + 3.44561295436479e+114*cos(theta)**21 - 1.57642422748716e+114*cos(theta)**19 + 4.46305534603152e+113*cos(theta)**17 - 8.14732251087634e+112*cos(theta)**15 + 9.69919346532898e+111*cos(theta)**13 - 7.45356739207547e+110*cos(theta)**11 + 3.58344586157474e+109*cos(theta)**9 - 1.01658038626234e+108*cos(theta)**7 + 1.53584087133159e+106*cos(theta)**5 - 1.01913793718088e+104*cos(theta)**3 + 1.8872924762609e+101*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl79_m_minus_53(theta, phi):
    return 9.55320175784028e-99*(1.0 - cos(theta)**2)**26.5*(8.49792148013247e+112*cos(theta)**26 - 1.75912387327583e+113*cos(theta)**24 + 1.56618770652945e+113*cos(theta)**22 - 7.88212113743579e+112*cos(theta)**20 + 2.47947519223974e+112*cos(theta)**18 - 5.09207656929771e+111*cos(theta)**16 + 6.92799533237784e+110*cos(theta)**14 - 6.21130616006289e+109*cos(theta)**12 + 3.58344586157474e+108*cos(theta)**10 - 1.27072548282792e+107*cos(theta)**8 + 2.55973478555265e+105*cos(theta)**6 - 2.54784484295221e+103*cos(theta)**4 + 9.43646238130448e+100*cos(theta)**2 - 5.45775730555493e+97)*sin(53*phi)

#@torch.jit.script
def Yl79_m_minus_52(theta, phi):
    return 5.70318943991758e-97*(1.0 - cos(theta)**2)**26*(3.14737832597499e+111*cos(theta)**27 - 7.03649549310332e+111*cos(theta)**25 + 6.80951176751934e+111*cos(theta)**23 - 3.75339101782657e+111*cos(theta)**21 + 1.30498694328407e+111*cos(theta)**19 - 2.99533915841042e+110*cos(theta)**17 + 4.61866355491856e+109*cos(theta)**15 - 4.77792781543299e+108*cos(theta)**13 + 3.25767805597704e+107*cos(theta)**11 - 1.41191720314214e+106*cos(theta)**9 + 3.65676397936093e+104*cos(theta)**7 - 5.09568968590442e+102*cos(theta)**5 + 3.14548746043483e+100*cos(theta)**3 - 5.45775730555493e+97*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl79_m_minus_51(theta, phi):
    return 3.45408054887072e-95*(1.0 - cos(theta)**2)**25.5*(1.12406368784821e+110*cos(theta)**28 - 2.70634442042436e+110*cos(theta)**26 + 2.83729656979973e+110*cos(theta)**24 - 1.7060868262848e+110*cos(theta)**22 + 6.52493471642036e+109*cos(theta)**20 - 1.66407731022801e+109*cos(theta)**18 + 2.8866647218241e+108*cos(theta)**16 - 3.41280558245214e+107*cos(theta)**14 + 2.7147317133142e+106*cos(theta)**12 - 1.41191720314214e+105*cos(theta)**10 + 4.57095497420116e+103*cos(theta)**8 - 8.49281614317403e+101*cos(theta)**6 + 7.86371865108706e+99*cos(theta)**4 - 2.72887865277747e+97*cos(theta)**2 + 1.48793819671618e+94)*sin(51*phi)

#@torch.jit.script
def Yl79_m_minus_50(theta, phi):
    return 2.12081670805348e-93*(1.0 - cos(theta)**2)**25*(3.87608168223521e+108*cos(theta)**29 - 1.00234978534235e+109*cos(theta)**27 + 1.13491862791989e+109*cos(theta)**25 - 7.41776880993393e+108*cos(theta)**23 + 3.10711176972398e+108*cos(theta)**21 - 8.758301632779e+107*cos(theta)**19 + 1.69803807166124e+107*cos(theta)**17 - 2.27520372163476e+106*cos(theta)**15 + 2.08825516408785e+105*cos(theta)**13 - 1.28356109376558e+104*cos(theta)**11 + 5.07883886022352e+102*cos(theta)**9 - 1.21325944902486e+101*cos(theta)**7 + 1.57274373021741e+99*cos(theta)**5 - 9.09626217592488e+96*cos(theta)**3 + 1.48793819671618e+94*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl79_m_minus_49(theta, phi):
    return 1.31934573863126e-91*(1.0 - cos(theta)**2)**24.5*(1.29202722741174e+107*cos(theta)**30 - 3.57982066193698e+107*cos(theta)**28 + 4.36507164584573e+107*cos(theta)**26 - 3.09073700413914e+107*cos(theta)**24 + 1.41232353169272e+107*cos(theta)**22 - 4.3791508163895e+106*cos(theta)**20 + 9.43354484256242e+105*cos(theta)**18 - 1.42200232602172e+105*cos(theta)**16 + 1.49161083149132e+104*cos(theta)**14 - 1.06963424480465e+103*cos(theta)**12 + 5.07883886022352e+101*cos(theta)**10 - 1.51657431128108e+100*cos(theta)**8 + 2.62123955036235e+98*cos(theta)**6 - 2.27406554398122e+96*cos(theta)**4 + 7.43969098358088e+93*cos(theta)**2 - 3.84480154190226e+90)*sin(49*phi)

#@torch.jit.script
def Yl79_m_minus_48(theta, phi):
    return 8.31083098762117e-90*(1.0 - cos(theta)**2)**24*(4.16782976584431e+105*cos(theta)**31 - 1.2344209179093e+106*cos(theta)**29 + 1.61669320216509e+106*cos(theta)**27 - 1.23629480165565e+106*cos(theta)**25 + 6.14053709431616e+105*cos(theta)**23 - 2.08530991256643e+105*cos(theta)**21 + 4.96502360134864e+104*cos(theta)**19 - 8.36471956483367e+103*cos(theta)**17 + 9.94407220994213e+102*cos(theta)**15 - 8.22795572926653e+101*cos(theta)**13 + 4.61712623656683e+100*cos(theta)**11 - 1.68508256809008e+99*cos(theta)**9 + 3.74462792908908e+97*cos(theta)**7 - 4.54813108796244e+95*cos(theta)**5 + 2.47989699452696e+93*cos(theta)**3 - 3.84480154190226e+90*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl79_m_minus_47(theta, phi):
    return 5.29811401508428e-88*(1.0 - cos(theta)**2)**23.5*(1.30244680182635e+104*cos(theta)**32 - 4.11473639303101e+104*cos(theta)**30 + 5.77390429344674e+104*cos(theta)**28 - 4.7549800063679e+104*cos(theta)**26 + 2.55855712263174e+104*cos(theta)**24 - 9.4786814207565e+103*cos(theta)**22 + 2.48251180067432e+103*cos(theta)**20 - 4.6470664249076e+102*cos(theta)**18 + 6.21504513121383e+101*cos(theta)**16 - 5.87711123519038e+100*cos(theta)**14 + 3.84760519713903e+99*cos(theta)**12 - 1.68508256809008e+98*cos(theta)**10 + 4.68078491136135e+96*cos(theta)**8 - 7.5802184799374e+94*cos(theta)**6 + 6.1997424863174e+92*cos(theta)**4 - 1.92240077095113e+90*cos(theta)**2 + 9.46063371531068e+86)*sin(47*phi)

#@torch.jit.script
def Yl79_m_minus_46(theta, phi):
    return 3.41635932509725e-86*(1.0 - cos(theta)**2)**23*(3.94680849038287e+102*cos(theta)**33 - 1.32733432033258e+103*cos(theta)**31 + 1.99100148049888e+103*cos(theta)**29 - 1.76110370606219e+103*cos(theta)**27 + 1.02342284905269e+103*cos(theta)**25 - 4.12116583511152e+102*cos(theta)**23 + 1.18214847651158e+102*cos(theta)**21 - 2.44582443416189e+101*cos(theta)**19 + 3.65590890071402e+100*cos(theta)**17 - 3.91807415679359e+99*cos(theta)**15 + 2.95969630549156e+98*cos(theta)**13 - 1.53189324371826e+97*cos(theta)**11 + 5.20087212373483e+95*cos(theta)**9 - 1.08288835427677e+94*cos(theta)**7 + 1.23994849726348e+92*cos(theta)**5 - 6.4080025698371e+89*cos(theta)**3 + 9.46063371531068e+86*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl79_m_minus_45(theta, phi):
    return 2.22719379292105e-84*(1.0 - cos(theta)**2)**22.5*(1.1608260265832e+101*cos(theta)**34 - 4.14791975103932e+101*cos(theta)**32 + 6.63667160166292e+101*cos(theta)**30 - 6.28965609307924e+101*cos(theta)**28 + 3.93624172712575e+101*cos(theta)**26 - 1.71715243129647e+101*cos(theta)**24 + 5.37340216596173e+100*cos(theta)**22 - 1.22291221708095e+100*cos(theta)**20 + 2.03106050039668e+99*cos(theta)**18 - 2.44879634799599e+98*cos(theta)**16 + 2.11406878963683e+97*cos(theta)**14 - 1.27657770309855e+96*cos(theta)**12 + 5.20087212373483e+94*cos(theta)**10 - 1.35361044284596e+93*cos(theta)**8 + 2.06658082877247e+91*cos(theta)**6 - 1.60200064245928e+89*cos(theta)**4 + 4.73031685765534e+86*cos(theta)**2 - 2.22603146242604e+83)*sin(45*phi)

#@torch.jit.script
def Yl79_m_minus_44(theta, phi):
    return 1.46724579092669e-82*(1.0 - cos(theta)**2)**22*(3.31664579023771e+99*cos(theta)**35 - 1.25694537910283e+100*cos(theta)**33 + 2.14086180698804e+100*cos(theta)**31 - 2.16884692864801e+100*cos(theta)**29 + 1.45786730634287e+100*cos(theta)**27 - 6.86860972518587e+99*cos(theta)**25 + 2.33626181128771e+99*cos(theta)**23 - 5.82339150990927e+98*cos(theta)**21 + 1.06897921073509e+98*cos(theta)**19 - 1.44046843999764e+97*cos(theta)**17 + 1.40937919309122e+96*cos(theta)**15 - 9.81982848537345e+94*cos(theta)**13 + 4.72806556703166e+93*cos(theta)**11 - 1.50401160316218e+92*cos(theta)**9 + 2.95225832681781e+90*cos(theta)**7 - 3.20400128491855e+88*cos(theta)**5 + 1.57677228588511e+86*cos(theta)**3 - 2.22603146242604e+83*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl79_m_minus_43(theta, phi):
    return 9.76352580488884e-81*(1.0 - cos(theta)**2)**21.5*(9.21290497288252e+97*cos(theta)**36 - 3.69689817383184e+98*cos(theta)**34 + 6.69019314683762e+98*cos(theta)**32 - 7.22948976216004e+98*cos(theta)**30 + 5.20666895122453e+98*cos(theta)**28 - 2.64177297122533e+98*cos(theta)**26 + 9.73442421369879e+97*cos(theta)**24 - 2.64699614086785e+97*cos(theta)**22 + 5.34489605367546e+96*cos(theta)**20 - 8.00260244443135e+95*cos(theta)**18 + 8.80861995682012e+94*cos(theta)**16 - 7.01416320383818e+93*cos(theta)**14 + 3.94005463919305e+92*cos(theta)**12 - 1.50401160316218e+91*cos(theta)**10 + 3.69032290852226e+89*cos(theta)**8 - 5.34000214153092e+87*cos(theta)**6 + 3.94193071471278e+85*cos(theta)**4 - 1.11301573121302e+83*cos(theta)**2 + 5.02717132435872e+79)*sin(43*phi)

#@torch.jit.script
def Yl79_m_minus_42(theta, phi):
    return 6.55975253152346e-79*(1.0 - cos(theta)**2)**21*(2.48997431699528e+96*cos(theta)**37 - 1.05625662109481e+97*cos(theta)**35 + 2.02733125661746e+97*cos(theta)**33 - 2.33209347166453e+97*cos(theta)**31 + 1.79540308662915e+97*cos(theta)**29 - 9.78434433787161e+96*cos(theta)**27 + 3.89376968547952e+96*cos(theta)**25 - 1.15086788733385e+96*cos(theta)**23 + 2.54518859698832e+95*cos(theta)**21 - 4.21189602338492e+94*cos(theta)**19 + 5.18154115107066e+93*cos(theta)**17 - 4.67610880255879e+92*cos(theta)**15 + 3.03081126091773e+91*cos(theta)**13 - 1.36728327560198e+90*cos(theta)**11 + 4.10035878724696e+88*cos(theta)**9 - 7.62857448790131e+86*cos(theta)**7 + 7.88386142942557e+84*cos(theta)**5 - 3.71005243737674e+82*cos(theta)**3 + 5.02717132435872e+79*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl79_m_minus_41(theta, phi):
    return 4.44807333974679e-77*(1.0 - cos(theta)**2)**20.5*(6.55256399209283e+94*cos(theta)**38 - 2.93404616970781e+95*cos(theta)**36 + 5.96273899005135e+95*cos(theta)**34 - 7.28779209895165e+95*cos(theta)**32 + 5.9846769554305e+95*cos(theta)**30 - 3.494408692097e+95*cos(theta)**28 + 1.49760372518443e+95*cos(theta)**26 - 4.79528286389103e+94*cos(theta)**24 + 1.15690390772196e+94*cos(theta)**22 - 2.10594801169246e+93*cos(theta)**20 + 2.87863397281703e+92*cos(theta)**18 - 2.92256800159924e+91*cos(theta)**16 + 2.16486518636981e+90*cos(theta)**14 - 1.13940272966832e+89*cos(theta)**12 + 4.10035878724696e+87*cos(theta)**10 - 9.53571810987664e+85*cos(theta)**8 + 1.31397690490426e+84*cos(theta)**6 - 9.27513109344185e+81*cos(theta)**4 + 2.51358566217936e+79*cos(theta)**2 - 1.09333869603278e+76)*sin(41*phi)

#@torch.jit.script
def Yl79_m_minus_40(theta, phi):
    return 3.04295034661076e-75*(1.0 - cos(theta)**2)**20*(1.68014461335714e+93*cos(theta)**39 - 7.92985451272381e+93*cos(theta)**37 + 1.70363971144324e+94*cos(theta)**35 - 2.20842184816717e+94*cos(theta)**33 + 1.93054095336468e+94*cos(theta)**31 - 1.20496851451621e+94*cos(theta)**29 + 5.54668046364603e+93*cos(theta)**27 - 1.91811314555641e+93*cos(theta)**25 + 5.03001699009549e+92*cos(theta)**23 - 1.00283238652022e+92*cos(theta)**21 + 1.51507051200896e+91*cos(theta)**19 - 1.71915764799955e+90*cos(theta)**17 + 1.44324345757987e+89*cos(theta)**15 - 8.76463638206401e+87*cos(theta)**13 + 3.72759889749723e+86*cos(theta)**11 - 1.05952423443074e+85*cos(theta)**9 + 1.87710986414895e+83*cos(theta)**7 - 1.85502621868837e+81*cos(theta)**5 + 8.37861887393121e+78*cos(theta)**3 - 1.09333869603278e+76*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl79_m_minus_39(theta, phi):
    return 2.09941522393326e-73*(1.0 - cos(theta)**2)**19.5*(4.20036153339284e+91*cos(theta)**40 - 2.08680381913784e+92*cos(theta)**38 + 4.73233253178679e+92*cos(theta)**36 - 6.49535837696226e+92*cos(theta)**34 + 6.03294047926461e+92*cos(theta)**32 - 4.01656171505403e+92*cos(theta)**30 + 1.98095730844501e+92*cos(theta)**28 - 7.37735825214005e+91*cos(theta)**26 + 2.09584041253979e+91*cos(theta)**24 - 4.55832902963736e+90*cos(theta)**22 + 7.57535256004482e+89*cos(theta)**20 - 9.55087582221975e+88*cos(theta)**18 + 9.0202716098742e+87*cos(theta)**16 - 6.26045455861715e+86*cos(theta)**14 + 3.10633241458103e+85*cos(theta)**12 - 1.05952423443074e+84*cos(theta)**10 + 2.34638733018618e+82*cos(theta)**8 - 3.09171036448062e+80*cos(theta)**6 + 2.0946547184828e+78*cos(theta)**4 - 5.4666934801639e+75*cos(theta)**2 + 2.29693003368231e+72)*sin(39*phi)

#@torch.jit.script
def Yl79_m_minus_38(theta, phi):
    return 1.46026364875154e-71*(1.0 - cos(theta)**2)**19*(1.02447842277874e+90*cos(theta)**41 - 5.35077902343037e+90*cos(theta)**39 + 1.27900879237481e+91*cos(theta)**37 - 1.85581667913207e+91*cos(theta)**35 + 1.82816378159534e+91*cos(theta)**33 - 1.29566506937227e+91*cos(theta)**31 + 6.83088727050004e+90*cos(theta)**29 - 2.73235490820002e+90*cos(theta)**27 + 8.38336165015914e+89*cos(theta)**25 - 1.98188218679885e+89*cos(theta)**23 + 3.60731074287849e+88*cos(theta)**21 - 5.02677674853671e+87*cos(theta)**19 + 5.30604212345541e+86*cos(theta)**17 - 4.17363637241143e+85*cos(theta)**15 + 2.38948647275464e+84*cos(theta)**13 - 9.63203849482489e+82*cos(theta)**11 + 2.6070970335402e+81*cos(theta)**9 - 4.41672909211516e+79*cos(theta)**7 + 4.1893094369656e+77*cos(theta)**5 - 1.82223116005463e+75*cos(theta)**3 + 2.29693003368231e+72*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl79_m_minus_37(theta, phi):
    return 1.02364377621677e-69*(1.0 - cos(theta)**2)**18.5*(2.43923433994938e+88*cos(theta)**42 - 1.33769475585759e+89*cos(theta)**40 + 3.36581261151265e+89*cos(theta)**38 - 5.15504633092243e+89*cos(theta)**36 + 5.37695229880982e+89*cos(theta)**34 - 4.04895334178833e+89*cos(theta)**32 + 2.27696242350001e+89*cos(theta)**30 - 9.75841038642863e+88*cos(theta)**28 + 3.22436986544582e+88*cos(theta)**26 - 8.25784244499522e+87*cos(theta)**24 + 1.6396867013084e+87*cos(theta)**22 - 2.51338837426835e+86*cos(theta)**20 + 2.94780117969745e+85*cos(theta)**18 - 2.60852273275714e+84*cos(theta)**16 + 1.7067760519676e+83*cos(theta)**14 - 8.02669874568741e+81*cos(theta)**12 + 2.6070970335402e+80*cos(theta)**10 - 5.52091136514396e+78*cos(theta)**8 + 6.98218239494267e+76*cos(theta)**6 - 4.55557790013658e+74*cos(theta)**4 + 1.14846501684116e+72*cos(theta)**2 - 4.6742572928008e+68)*sin(37*phi)

#@torch.jit.script
def Yl79_m_minus_36(theta, phi):
    return 7.22956343354814e-68*(1.0 - cos(theta)**2)**18*(5.67263799988229e+86*cos(theta)**43 - 3.26267013623803e+87*cos(theta)**41 + 8.63028874746834e+87*cos(theta)**39 - 1.39325576511417e+88*cos(theta)**37 + 1.53627208537423e+88*cos(theta)**35 - 1.22695555811768e+88*cos(theta)**33 + 7.3450400758065e+87*cos(theta)**31 - 3.36496909876849e+87*cos(theta)**29 + 1.19421106127623e+87*cos(theta)**27 - 3.30313697799809e+86*cos(theta)**25 + 7.12907261438436e+85*cos(theta)**23 - 1.19685160679445e+85*cos(theta)**21 + 1.55147430510392e+84*cos(theta)**19 - 1.53442513691597e+83*cos(theta)**17 + 1.13785070131173e+82*cos(theta)**15 - 6.17438365052878e+80*cos(theta)**13 + 2.37008821230927e+79*cos(theta)**11 - 6.13434596127106e+77*cos(theta)**9 + 9.97454627848953e+75*cos(theta)**7 - 9.11115580027317e+73*cos(theta)**5 + 3.82821672280385e+71*cos(theta)**3 - 4.6742572928008e+68*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl79_m_minus_35(theta, phi):
    return 5.14265429953116e-66*(1.0 - cos(theta)**2)**17.5*(1.28923590906416e+85*cos(theta)**44 - 7.76826222913817e+85*cos(theta)**42 + 2.15757218686708e+86*cos(theta)**40 - 3.66646253977413e+86*cos(theta)**38 + 4.26742245937287e+86*cos(theta)**36 - 3.60869281799317e+86*cos(theta)**34 + 2.29532502368953e+86*cos(theta)**32 - 1.12165636625616e+86*cos(theta)**30 + 4.26503950455797e+85*cos(theta)**28 - 1.27043729923003e+85*cos(theta)**26 + 2.97044692266015e+84*cos(theta)**24 - 5.44023457633843e+83*cos(theta)**22 + 7.75737152551961e+82*cos(theta)**20 - 8.5245840939776e+81*cos(theta)**18 + 7.11156688319832e+80*cos(theta)**16 - 4.41027403609198e+79*cos(theta)**14 + 1.97507351025773e+78*cos(theta)**12 - 6.13434596127106e+76*cos(theta)**10 + 1.24681828481119e+75*cos(theta)**8 - 1.51852596671219e+73*cos(theta)**6 + 9.57054180700963e+70*cos(theta)**4 - 2.3371286464004e+68*cos(theta)**2 + 9.23766263399367e+64)*sin(35*phi)

#@torch.jit.script
def Yl79_m_minus_34(theta, phi):
    return 3.68337565752144e-64*(1.0 - cos(theta)**2)**17*(2.86496868680924e+83*cos(theta)**45 - 1.80657261142748e+84*cos(theta)**43 + 5.26237118748069e+84*cos(theta)**41 - 9.40118599942085e+84*cos(theta)**39 + 1.15335742145213e+85*cos(theta)**37 - 1.03105509085519e+85*cos(theta)**35 + 6.95553037481676e+84*cos(theta)**33 - 3.61824634276182e+84*cos(theta)**31 + 1.47070327743378e+84*cos(theta)**29 - 4.7053233304816e+83*cos(theta)**27 + 1.18817876906406e+83*cos(theta)**25 - 2.36531938101671e+82*cos(theta)**23 + 3.69398644072362e+81*cos(theta)**21 - 4.48662320735663e+80*cos(theta)**19 + 4.18327463717548e+79*cos(theta)**17 - 2.94018269072799e+78*cos(theta)**15 + 1.51928731558287e+77*cos(theta)**13 - 5.57667814661006e+75*cos(theta)**11 + 1.38535364979021e+74*cos(theta)**9 - 2.16932280958885e+72*cos(theta)**7 + 1.91410836140193e+70*cos(theta)**5 - 7.79042882133466e+67*cos(theta)**3 + 9.23766263399367e+64*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl79_m_minus_33(theta, phi):
    return 2.6556091185738e-62*(1.0 - cos(theta)**2)**16.5*(6.22819279741139e+81*cos(theta)**46 - 4.10584684415337e+82*cos(theta)**44 + 1.25294552082874e+83*cos(theta)**42 - 2.35029649985521e+83*cos(theta)**40 + 3.03515110908455e+83*cos(theta)**38 - 2.86404191904219e+83*cos(theta)**36 + 2.04574422788728e+83*cos(theta)**34 - 1.13070198211307e+83*cos(theta)**32 + 4.90234425811261e+82*cos(theta)**30 - 1.68047261802914e+82*cos(theta)**28 + 4.56991834255408e+81*cos(theta)**26 - 9.85549742090295e+80*cos(theta)**24 + 1.67908474578347e+80*cos(theta)**22 - 2.24331160367831e+79*cos(theta)**20 + 2.32404146509749e+78*cos(theta)**18 - 1.83761418170499e+77*cos(theta)**16 + 1.08520522541633e+76*cos(theta)**14 - 4.64723178884171e+74*cos(theta)**12 + 1.38535364979021e+73*cos(theta)**10 - 2.71165351198606e+71*cos(theta)**8 + 3.19018060233654e+69*cos(theta)**6 - 1.94760720533367e+67*cos(theta)**4 + 4.61883131699684e+64*cos(theta)**2 - 1.77715710542395e+61)*sin(33*phi)

#@torch.jit.script
def Yl79_m_minus_32(theta, phi):
    return 1.92673546544391e-60*(1.0 - cos(theta)**2)**16*(1.32514740370455e+80*cos(theta)**47 - 9.12410409811859e+80*cos(theta)**45 + 2.91382679262497e+81*cos(theta)**43 - 5.73243048745174e+81*cos(theta)**41 + 7.78243874124242e+81*cos(theta)**39 - 7.74065383524918e+81*cos(theta)**37 + 5.84498350824938e+81*cos(theta)**35 - 3.42636964276688e+81*cos(theta)**33 + 1.58140137358471e+81*cos(theta)**31 - 5.79473316561774e+80*cos(theta)**29 + 1.6925623490941e+80*cos(theta)**27 - 3.94219896836118e+79*cos(theta)**25 + 7.30036845992811e+78*cos(theta)**23 - 1.0682436207992e+78*cos(theta)**21 + 1.22317971847236e+77*cos(theta)**19 - 1.08094951865e+76*cos(theta)**17 + 7.23470150277556e+74*cos(theta)**15 - 3.5747936837244e+73*cos(theta)**13 + 1.25941240890019e+72*cos(theta)**11 - 3.01294834665118e+70*cos(theta)**9 + 4.55740086048078e+68*cos(theta)**7 - 3.89521441066733e+66*cos(theta)**5 + 1.53961043899895e+64*cos(theta)**3 - 1.77715710542395e+61*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl79_m_minus_31(theta, phi):
    return 1.40638491539987e-58*(1.0 - cos(theta)**2)**15.5*(2.76072375771781e+78*cos(theta)**48 - 1.98350089089535e+79*cos(theta)**46 + 6.6223336196022e+79*cos(theta)**44 - 1.36486440177422e+80*cos(theta)**42 + 1.94560968531061e+80*cos(theta)**40 - 2.03701416717084e+80*cos(theta)**38 + 1.62360653006927e+80*cos(theta)**36 - 1.00775577728438e+80*cos(theta)**34 + 4.94187929245223e+79*cos(theta)**32 - 1.93157772187258e+79*cos(theta)**30 + 6.04486553247894e+78*cos(theta)**28 - 1.51623037244661e+78*cos(theta)**26 + 3.04182019163671e+77*cos(theta)**24 - 4.85565282181453e+76*cos(theta)**22 + 6.11589859236182e+75*cos(theta)**20 - 6.00527510361109e+74*cos(theta)**18 + 4.52168843923473e+73*cos(theta)**16 - 2.55342405980314e+72*cos(theta)**14 + 1.04951034075016e+71*cos(theta)**12 - 3.01294834665118e+69*cos(theta)**10 + 5.69675107560097e+67*cos(theta)**8 - 6.49202401777888e+65*cos(theta)**6 + 3.84902609749736e+63*cos(theta)**4 - 8.88578552711973e+60*cos(theta)**2 + 3.33550507774765e+57)*sin(31*phi)

#@torch.jit.script
def Yl79_m_minus_30(theta, phi):
    return 1.03252026024309e-56*(1.0 - cos(theta)**2)**15*(5.63413011779145e+76*cos(theta)**49 - 4.22021466147946e+77*cos(theta)**47 + 1.47162969324493e+78*cos(theta)**45 - 3.17410325994005e+78*cos(theta)**43 + 4.74538947636733e+78*cos(theta)**41 - 5.22311324915599e+78*cos(theta)**39 + 4.38812575694398e+78*cos(theta)**37 - 2.8793022208125e+78*cos(theta)**35 + 1.49753917953098e+78*cos(theta)**33 - 6.23089587700832e+77*cos(theta)**31 + 2.08443639050998e+77*cos(theta)**29 - 5.61566804609855e+76*cos(theta)**27 + 1.21672807665469e+76*cos(theta)**25 - 2.11115340078893e+75*cos(theta)**23 + 2.91233266302944e+74*cos(theta)**21 - 3.16067110716373e+73*cos(theta)**19 + 2.6598167289616e+72*cos(theta)**17 - 1.70228270653543e+71*cos(theta)**15 + 8.07315646730893e+69*cos(theta)**13 - 2.73904395150107e+68*cos(theta)**11 + 6.32972341733441e+66*cos(theta)**9 - 9.27432002539841e+64*cos(theta)**7 + 7.69805219499472e+62*cos(theta)**5 - 2.96192850903991e+60*cos(theta)**3 + 3.33550507774765e+57*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl79_m_minus_29(theta, phi):
    return 7.62248947429769e-55*(1.0 - cos(theta)**2)**14.5*(1.12682602355829e+75*cos(theta)**50 - 8.79211387808221e+75*cos(theta)**48 + 3.19919498531507e+76*cos(theta)**46 - 7.2138710453183e+76*cos(theta)**44 + 1.12985463723032e+77*cos(theta)**42 - 1.305778312289e+77*cos(theta)**40 + 1.15476993603789e+77*cos(theta)**38 - 7.99806172447917e+76*cos(theta)**36 + 4.40452699862052e+76*cos(theta)**34 - 1.9471549615651e+76*cos(theta)**32 + 6.94812130169993e+75*cos(theta)**30 - 2.00559573074948e+75*cos(theta)**28 + 4.67972337174879e+74*cos(theta)**26 - 8.7964725032872e+73*cos(theta)**24 + 1.32378757410429e+73*cos(theta)**22 - 1.58033555358187e+72*cos(theta)**20 + 1.47767596053422e+71*cos(theta)**18 - 1.06392669158464e+70*cos(theta)**16 + 5.76654033379209e+68*cos(theta)**14 - 2.28253662625089e+67*cos(theta)**12 + 6.32972341733441e+65*cos(theta)**10 - 1.1592900031748e+64*cos(theta)**8 + 1.28300869916579e+62*cos(theta)**6 - 7.40482127259977e+59*cos(theta)**4 + 1.66775253887382e+57*cos(theta)**2 - 6.12019280320669e+53)*sin(29*phi)

#@torch.jit.script
def Yl79_m_minus_28(theta, phi):
    return 5.65709926188388e-53*(1.0 - cos(theta)**2)**14*(2.20946279129077e+73*cos(theta)**51 - 1.79430895471065e+74*cos(theta)**49 + 6.8067978410959e+74*cos(theta)**47 - 1.60308245451518e+75*cos(theta)**45 + 2.62756892379143e+75*cos(theta)**43 - 3.18482515192438e+75*cos(theta)**41 + 2.9609485539433e+75*cos(theta)**39 - 2.16163830391329e+75*cos(theta)**37 + 1.25843628532015e+75*cos(theta)**35 - 5.9004695805003e+74*cos(theta)**33 + 2.24132945216127e+74*cos(theta)**31 - 6.91584734741201e+73*cos(theta)**29 + 1.73323087842548e+73*cos(theta)**27 - 3.51858900131488e+72*cos(theta)**25 + 5.75559814827952e+71*cos(theta)**23 - 7.52540739800888e+70*cos(theta)**21 + 7.77724189754855e+69*cos(theta)**19 - 6.25839230343907e+68*cos(theta)**17 + 3.84436022252806e+67*cos(theta)**15 - 1.75579740480838e+66*cos(theta)**13 + 5.75429401575856e+64*cos(theta)**11 - 1.28810000352756e+63*cos(theta)**9 + 1.83286957023684e+61*cos(theta)**7 - 1.48096425451995e+59*cos(theta)**5 + 5.55917512957941e+56*cos(theta)**3 - 6.12019280320669e+53*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl79_m_minus_27(theta, phi):
    return 4.21975619835083e-51*(1.0 - cos(theta)**2)**13.5*(4.2489669063284e+71*cos(theta)**52 - 3.58861790942131e+72*cos(theta)**50 + 1.41808288356165e+73*cos(theta)**48 - 3.48496185764169e+73*cos(theta)**46 + 5.97174755407144e+73*cos(theta)**44 - 7.58291702839139e+73*cos(theta)**42 + 7.40237138485826e+73*cos(theta)**40 - 5.68852185240339e+73*cos(theta)**38 + 3.49565634811153e+73*cos(theta)**36 - 1.73543222955891e+73*cos(theta)**34 + 7.00415453800396e+72*cos(theta)**32 - 2.30528244913733e+72*cos(theta)**30 + 6.19011028009099e+71*cos(theta)**28 - 1.35330346204418e+71*cos(theta)**26 + 2.39816589511647e+70*cos(theta)**24 - 3.42063972636767e+69*cos(theta)**22 + 3.88862094877427e+68*cos(theta)**20 - 3.4768846130217e+67*cos(theta)**18 + 2.40272513908004e+66*cos(theta)**16 - 1.25414100343456e+65*cos(theta)**14 + 4.79524501313213e+63*cos(theta)**12 - 1.28810000352756e+62*cos(theta)**10 + 2.29108696279605e+60*cos(theta)**8 - 2.46827375753326e+58*cos(theta)**6 + 1.38979378239485e+56*cos(theta)**4 - 3.06009640160334e+53*cos(theta)**2 + 1.09996276118021e+50)*sin(27*phi)

#@torch.jit.script
def Yl79_m_minus_26(theta, phi):
    return 3.16284731617631e-49*(1.0 - cos(theta)**2)**13*(8.01691869118565e+69*cos(theta)**53 - 7.03650570474766e+70*cos(theta)**51 + 2.89404670114622e+71*cos(theta)**49 - 7.41481246306743e+71*cos(theta)**47 + 1.32705501201588e+72*cos(theta)**45 - 1.76346907637009e+72*cos(theta)**43 + 1.80545643533128e+72*cos(theta)**41 - 1.4585953467701e+72*cos(theta)**39 + 9.44771985976088e+71*cos(theta)**37 - 4.95837779873975e+71*cos(theta)**35 + 2.12247107212241e+71*cos(theta)**33 - 7.43639499721721e+70*cos(theta)**31 + 2.13452078623827e+70*cos(theta)**29 - 5.01223504460809e+69*cos(theta)**27 + 9.59266358046587e+68*cos(theta)**25 - 1.48723466363812e+68*cos(theta)**23 + 1.85172426132108e+67*cos(theta)**21 - 1.82993927001142e+66*cos(theta)**19 + 1.41336772887061e+65*cos(theta)**17 - 8.36094002289705e+63*cos(theta)**15 + 3.68865001010164e+62*cos(theta)**13 - 1.17100000320687e+61*cos(theta)**11 + 2.5456521808845e+59*cos(theta)**9 - 3.52610536790465e+57*cos(theta)**7 + 2.7795875647897e+55*cos(theta)**5 - 1.02003213386778e+53*cos(theta)**3 + 1.09996276118021e+50*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl79_m_minus_25(theta, phi):
    return 2.38160512752777e-47*(1.0 - cos(theta)**2)**12.5*(1.48461457244179e+68*cos(theta)**54 - 1.35317417398994e+69*cos(theta)**52 + 5.78809340229243e+69*cos(theta)**50 - 1.54475259647238e+70*cos(theta)**48 + 2.88490220003451e+70*cos(theta)**46 - 4.00788426447748e+70*cos(theta)**44 + 4.29870579840782e+70*cos(theta)**42 - 3.64648836692525e+70*cos(theta)**40 + 2.48624206835813e+70*cos(theta)**38 - 1.3773271663166e+70*cos(theta)**36 + 6.24256197683062e+69*cos(theta)**34 - 2.32387343663038e+69*cos(theta)**32 + 7.11506928746091e+68*cos(theta)**30 - 1.79008394450289e+68*cos(theta)**28 + 3.68948599248687e+67*cos(theta)**26 - 6.19681109849216e+66*cos(theta)**24 + 8.41692846055038e+65*cos(theta)**22 - 9.14969635005712e+64*cos(theta)**20 + 7.85204293817006e+63*cos(theta)**18 - 5.22558751431065e+62*cos(theta)**16 + 2.63475000721546e+61*cos(theta)**14 - 9.75833336005725e+59*cos(theta)**12 + 2.5456521808845e+58*cos(theta)**10 - 4.40763170988082e+56*cos(theta)**8 + 4.63264594131617e+54*cos(theta)**6 - 2.55008033466945e+52*cos(theta)**4 + 5.49981380590105e+49*cos(theta)**2 - 1.93996959643776e+46)*sin(25*phi)

#@torch.jit.script
def Yl79_m_minus_24(theta, phi):
    return 1.80122419108307e-45*(1.0 - cos(theta)**2)**12*(2.69929922262143e+66*cos(theta)**55 - 2.55315881884893e+67*cos(theta)**53 + 1.1349202749593e+68*cos(theta)**51 - 3.15255631933139e+68*cos(theta)**49 + 6.13808978730748e+68*cos(theta)**47 - 8.90640947661662e+68*cos(theta)**45 + 9.99699022885539e+68*cos(theta)**43 - 8.89387406567135e+68*cos(theta)**41 + 6.37497966245673e+68*cos(theta)**39 - 3.72250585490972e+68*cos(theta)**37 + 1.78358913623732e+68*cos(theta)**35 - 7.04204071706175e+67*cos(theta)**33 + 2.29518364111642e+67*cos(theta)**31 - 6.17270325690652e+66*cos(theta)**29 + 1.36647629351366e+66*cos(theta)**27 - 2.47872443939686e+65*cos(theta)**25 + 3.65953411328277e+64*cos(theta)**23 - 4.35699826193196e+63*cos(theta)**21 + 4.13265417798424e+62*cos(theta)**19 - 3.07387500841803e+61*cos(theta)**17 + 1.7565000048103e+60*cos(theta)**15 - 7.50641027696711e+58*cos(theta)**13 + 2.31422925534954e+57*cos(theta)**11 - 4.89736856653424e+55*cos(theta)**9 + 6.61806563045168e+53*cos(theta)**7 - 5.10016066933891e+51*cos(theta)**5 + 1.83327126863368e+49*cos(theta)**3 - 1.93996959643776e+46*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl79_m_minus_23(theta, phi):
    return 1.36798204400421e-43*(1.0 - cos(theta)**2)**11.5*(4.82017718325256e+64*cos(theta)**56 - 4.72807188675729e+65*cos(theta)**54 + 2.18253899030635e+66*cos(theta)**52 - 6.30511263866278e+66*cos(theta)**50 + 1.27876870568906e+67*cos(theta)**48 - 1.93617597317753e+67*cos(theta)**46 + 2.27204323383077e+67*cos(theta)**44 - 2.11758906325508e+67*cos(theta)**42 + 1.59374491561418e+67*cos(theta)**40 - 9.79606803923612e+66*cos(theta)**38 + 4.95441426732589e+66*cos(theta)**36 - 2.07118844619463e+66*cos(theta)**34 + 7.17244887848882e+65*cos(theta)**32 - 2.05756775230217e+65*cos(theta)**30 + 4.88027247683449e+64*cos(theta)**28 - 9.53355553614179e+63*cos(theta)**26 + 1.52480588053449e+63*cos(theta)**24 - 1.98045375542362e+62*cos(theta)**22 + 2.06632708899212e+61*cos(theta)**20 - 1.70770833801002e+60*cos(theta)**18 + 1.09781250300644e+59*cos(theta)**16 - 5.36172162640508e+57*cos(theta)**14 + 1.92852437945795e+56*cos(theta)**12 - 4.89736856653424e+54*cos(theta)**10 + 8.2725820380646e+52*cos(theta)**8 - 8.50026778223151e+50*cos(theta)**6 + 4.58317817158421e+48*cos(theta)**4 - 9.6998479821888e+45*cos(theta)**2 + 3.36333147787406e+42)*sin(23*phi)

#@torch.jit.script
def Yl79_m_minus_22(theta, phi):
    return 1.04308070205435e-41*(1.0 - cos(theta)**2)**11*(8.4564511986887e+62*cos(theta)**57 - 8.5964943395587e+63*cos(theta)**55 + 4.11799809491764e+64*cos(theta)**53 - 1.23629659581623e+65*cos(theta)**51 + 2.60973205242665e+65*cos(theta)**49 - 4.11952334718623e+65*cos(theta)**47 + 5.04898496406838e+65*cos(theta)**45 - 4.92462572850019e+65*cos(theta)**43 + 3.8871827210102e+65*cos(theta)**41 - 2.51181231775285e+65*cos(theta)**39 + 1.33903088306105e+65*cos(theta)**37 - 5.91768127484181e+64*cos(theta)**35 + 2.17346935711782e+64*cos(theta)**33 - 6.63731533000701e+63*cos(theta)**31 + 1.68285257821879e+63*cos(theta)**29 - 3.53094649486733e+62*cos(theta)**27 + 6.09922352213795e+61*cos(theta)**25 - 8.61066850184182e+60*cos(theta)**23 + 9.83965280472439e+59*cos(theta)**21 - 8.98793862110536e+58*cos(theta)**19 + 6.45772060592024e+57*cos(theta)**17 - 3.57448108427005e+56*cos(theta)**15 + 1.48348029189073e+55*cos(theta)**13 - 4.45215324230386e+53*cos(theta)**11 + 9.19175782007178e+51*cos(theta)**9 - 1.21432396889022e+50*cos(theta)**7 + 9.16635634316842e+47*cos(theta)**5 - 3.2332826607296e+45*cos(theta)**3 + 3.36333147787406e+42*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl79_m_minus_21(theta, phi):
    return 7.98348648282659e-40*(1.0 - cos(theta)**2)**10.5*(1.45800882736012e+61*cos(theta)**58 - 1.5350882749212e+62*cos(theta)**56 + 7.62592239799562e+62*cos(theta)**54 - 2.37749345349275e+63*cos(theta)**52 + 5.2194641048533e+63*cos(theta)**50 - 8.58234030663797e+63*cos(theta)**48 + 1.09760542697139e+64*cos(theta)**46 - 1.11923312011368e+64*cos(theta)**44 + 9.2551969547862e+63*cos(theta)**42 - 6.27953079438213e+63*cos(theta)**40 + 3.52376548173961e+63*cos(theta)**38 - 1.64380035412272e+63*cos(theta)**36 + 6.39255693269948e+62*cos(theta)**34 - 2.07416104062719e+62*cos(theta)**32 + 5.60950859406263e+61*cos(theta)**30 - 1.26105231959547e+61*cos(theta)**28 + 2.34585520082229e+60*cos(theta)**26 - 3.58777854243409e+59*cos(theta)**24 + 4.4725694566929e+58*cos(theta)**22 - 4.49396931055268e+57*cos(theta)**20 + 3.58762255884458e+56*cos(theta)**18 - 2.23405067766878e+55*cos(theta)**16 + 1.05962877992195e+54*cos(theta)**14 - 3.71012770191988e+52*cos(theta)**12 + 9.19175782007178e+50*cos(theta)**10 - 1.51790496111277e+49*cos(theta)**8 + 1.52772605719474e+47*cos(theta)**6 - 8.083206651824e+44*cos(theta)**4 + 1.68166573893703e+42*cos(theta)**2 - 5.74143304519301e+38)*sin(21*phi)

#@torch.jit.script
def Yl79_m_minus_20(theta, phi):
    return 6.132232325073e-38*(1.0 - cos(theta)**2)**10*(2.47120140230529e+59*cos(theta)**59 - 2.69313732442315e+60*cos(theta)**57 + 1.38653134509011e+61*cos(theta)**55 - 4.48583670470331e+61*cos(theta)**53 + 1.02342433428496e+62*cos(theta)**51 - 1.75149802176285e+62*cos(theta)**49 + 2.3353306956838e+62*cos(theta)**47 - 2.48718471136373e+62*cos(theta)**45 + 2.152371384834e+62*cos(theta)**43 - 1.53159287667857e+62*cos(theta)**41 + 9.03529610702464e+61*cos(theta)**39 - 4.44270365979115e+61*cos(theta)**37 + 1.82644483791414e+61*cos(theta)**35 - 6.28533648674906e+60*cos(theta)**33 + 1.80951890131053e+60*cos(theta)**31 - 4.34845627446715e+59*cos(theta)**29 + 8.68835259563811e+58*cos(theta)**27 - 1.43511141697364e+58*cos(theta)**25 + 1.94459541595344e+57*cos(theta)**23 - 2.13998538597747e+56*cos(theta)**21 + 1.88822239939188e+55*cos(theta)**19 - 1.31414745745223e+54*cos(theta)**17 + 7.06419186614635e+52*cos(theta)**15 - 2.85394438609222e+51*cos(theta)**13 + 8.35614347279252e+49*cos(theta)**11 - 1.68656106790308e+48*cos(theta)**9 + 2.18246579599248e+46*cos(theta)**7 - 1.6166413303648e+44*cos(theta)**5 + 5.60555246312344e+41*cos(theta)**3 - 5.74143304519301e+38*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl79_m_minus_19(theta, phi):
    return 4.72619702651827e-36*(1.0 - cos(theta)**2)**9.5*(4.11866900384215e+57*cos(theta)**60 - 4.64334021452268e+58*cos(theta)**58 + 2.47594883051806e+59*cos(theta)**56 - 8.30710500870983e+59*cos(theta)**54 + 1.96812371977877e+60*cos(theta)**52 - 3.5029960435257e+60*cos(theta)**50 + 4.86527228267459e+60*cos(theta)**48 - 5.40692328557333e+60*cos(theta)**46 + 4.89175314735e+60*cos(theta)**44 - 3.64664970637754e+60*cos(theta)**42 + 2.25882402675616e+60*cos(theta)**40 - 1.1691325420503e+60*cos(theta)**38 + 5.07345788309483e+59*cos(theta)**36 - 1.84862837845561e+59*cos(theta)**34 + 5.65474656659539e+58*cos(theta)**32 - 1.44948542482238e+58*cos(theta)**30 + 3.10298306987075e+57*cos(theta)**28 - 5.51965929605245e+56*cos(theta)**26 + 8.10248089980599e+55*cos(theta)**24 - 9.72720629989757e+54*cos(theta)**22 + 9.44111199695941e+53*cos(theta)**20 - 7.30081920806792e+52*cos(theta)**18 + 4.41511991634147e+51*cos(theta)**16 - 2.03853170435158e+50*cos(theta)**14 + 6.96345289399377e+48*cos(theta)**12 - 1.68656106790308e+47*cos(theta)**10 + 2.7280822449906e+45*cos(theta)**8 - 2.69440221727467e+43*cos(theta)**6 + 1.40138811578086e+41*cos(theta)**4 - 2.8707165225965e+38*cos(theta)**2 + 9.66571219729463e+34)*sin(19*phi)

#@torch.jit.script
def Yl79_m_minus_18(theta, phi):
    return 3.65417866773758e-34*(1.0 - cos(theta)**2)**9*(6.75191639974123e+55*cos(theta)**61 - 7.87006816020793e+56*cos(theta)**59 + 4.34376987810186e+57*cos(theta)**57 - 1.51038272885633e+58*cos(theta)**55 + 3.71344098071466e+58*cos(theta)**53 - 6.86861969318765e+58*cos(theta)**51 + 9.92912710749915e+58*cos(theta)**49 - 1.15040920969645e+59*cos(theta)**47 + 1.08705625496667e+59*cos(theta)**45 - 8.48058071250591e+58*cos(theta)**43 + 5.50932689452722e+58*cos(theta)**41 - 2.99777574884693e+58*cos(theta)**39 + 1.37120483326887e+58*cos(theta)**37 - 5.28179536701602e+57*cos(theta)**35 + 1.71355956563497e+57*cos(theta)**33 - 4.67575943491092e+56*cos(theta)**31 + 1.0699941620244e+56*cos(theta)**29 - 2.0443182577972e+55*cos(theta)**27 + 3.24099235992239e+54*cos(theta)**25 - 4.22922013039025e+53*cos(theta)**23 + 4.49576761759972e+52*cos(theta)**21 - 3.84253642529891e+51*cos(theta)**19 + 2.59712936255381e+50*cos(theta)**17 - 1.35902113623439e+49*cos(theta)**15 + 5.35650222614905e+47*cos(theta)**13 - 1.53323733445734e+46*cos(theta)**11 + 3.031202494434e+44*cos(theta)**9 - 3.8491460246781e+42*cos(theta)**7 + 2.80277623156172e+40*cos(theta)**5 - 9.56905507532168e+37*cos(theta)**3 + 9.66571219729463e+34*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl79_m_minus_17(theta, phi):
    return 2.83381496782678e-32*(1.0 - cos(theta)**2)**8.5*(1.08901877415181e+54*cos(theta)**62 - 1.31167802670132e+55*cos(theta)**60 + 7.48925841052045e+55*cos(theta)**58 - 2.69711201581488e+56*cos(theta)**56 + 6.876742556879e+56*cos(theta)**54 - 1.32088840253609e+57*cos(theta)**52 + 1.98582542149983e+57*cos(theta)**50 - 2.39668585353428e+57*cos(theta)**48 + 2.36316577166667e+57*cos(theta)**46 - 1.92740470738771e+57*cos(theta)**44 + 1.31174449869696e+57*cos(theta)**42 - 7.49443937211732e+56*cos(theta)**40 + 3.60843377176019e+56*cos(theta)**38 - 1.46716537972667e+56*cos(theta)**36 + 5.03988107539696e+55*cos(theta)**34 - 1.46117482340966e+55*cos(theta)**32 + 3.56664720674799e+54*cos(theta)**30 - 7.30113663499001e+53*cos(theta)**28 + 1.24653552304707e+53*cos(theta)**26 - 1.76217505432927e+52*cos(theta)**24 + 2.0435307352726e+51*cos(theta)**22 - 1.92126821264945e+50*cos(theta)**20 + 1.44284964586323e+49*cos(theta)**18 - 8.49388210146493e+47*cos(theta)**16 + 3.8260730186779e+46*cos(theta)**14 - 1.27769777871445e+45*cos(theta)**12 + 3.031202494434e+43*cos(theta)**10 - 4.81143253084762e+41*cos(theta)**8 + 4.67129371926953e+39*cos(theta)**6 - 2.39226376883042e+37*cos(theta)**4 + 4.83285609864731e+34*cos(theta)**2 - 1.60720189512714e+31)*sin(17*phi)

#@torch.jit.script
def Yl79_m_minus_16(theta, phi):
    return 2.20382639925029e-30*(1.0 - cos(theta)**2)**8*(1.7286012288124e+52*cos(theta)**63 - 2.15029184705135e+53*cos(theta)**61 + 1.2693658322916e+54*cos(theta)**59 - 4.73177546634189e+54*cos(theta)**57 + 1.25031682852345e+55*cos(theta)**55 - 2.49224226893601e+55*cos(theta)**53 + 3.89377533627418e+55*cos(theta)**51 - 4.89119561945771e+55*cos(theta)**49 + 5.02801228014184e+55*cos(theta)**47 - 4.28312157197268e+55*cos(theta)**45 + 3.05056860162083e+55*cos(theta)**43 - 1.82791204197983e+55*cos(theta)**41 + 9.25239428656459e+54*cos(theta)**39 - 3.96531183709911e+54*cos(theta)**37 + 1.43996602154199e+54*cos(theta)**35 - 4.42780249518079e+53*cos(theta)**33 + 1.15053135701548e+53*cos(theta)**31 - 2.51763332241035e+52*cos(theta)**29 + 4.61679823350768e+51*cos(theta)**27 - 7.04870021731708e+50*cos(theta)**25 + 8.88491624031565e+49*cos(theta)**23 - 9.14889625071168e+48*cos(theta)**21 + 7.59394550454329e+47*cos(theta)**19 - 4.99640123615584e+46*cos(theta)**17 + 2.55071534578526e+45*cos(theta)**15 - 9.82844445164964e+43*cos(theta)**13 + 2.75563863130364e+42*cos(theta)**11 - 5.34603614538624e+40*cos(theta)**9 + 6.67327674181362e+38*cos(theta)**7 - 4.78452753766084e+36*cos(theta)**5 + 1.61095203288244e+34*cos(theta)**3 - 1.60720189512714e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl79_m_minus_15(theta, phi):
    return 1.71841941481227e-28*(1.0 - cos(theta)**2)**7.5*(2.70093942001937e+50*cos(theta)**64 - 3.46821265653443e+51*cos(theta)**62 + 2.115609720486e+52*cos(theta)**60 - 8.15823356265844e+52*cos(theta)**58 + 2.23270862236331e+53*cos(theta)**56 - 4.61526346099262e+53*cos(theta)**54 + 7.48802949283496e+53*cos(theta)**52 - 9.78239123891542e+53*cos(theta)**50 + 1.04750255836288e+54*cos(theta)**48 - 9.31113385211452e+53*cos(theta)**46 + 6.93311045822916e+53*cos(theta)**44 - 4.35217152852341e+53*cos(theta)**42 + 2.31309857164115e+53*cos(theta)**40 - 1.04350311502608e+53*cos(theta)**38 + 3.99990561539441e+52*cos(theta)**36 - 1.30229485152376e+52*cos(theta)**34 + 3.59541049067338e+51*cos(theta)**32 - 8.39211107470116e+50*cos(theta)**30 + 1.64885651196703e+50*cos(theta)**28 - 2.71103854512195e+49*cos(theta)**26 + 3.70204843346485e+48*cos(theta)**24 - 4.15858920486894e+47*cos(theta)**22 + 3.79697275227165e+46*cos(theta)**20 - 2.77577846453102e+45*cos(theta)**18 + 1.59419709111579e+44*cos(theta)**16 - 7.02031746546403e+42*cos(theta)**14 + 2.29636552608636e+41*cos(theta)**12 - 5.34603614538624e+39*cos(theta)**10 + 8.34159592726703e+37*cos(theta)**8 - 7.97421256276807e+35*cos(theta)**6 + 4.02738008220609e+33*cos(theta)**4 - 8.03600947563571e+30*cos(theta)**2 + 2.64342416961701e+27)*sin(15*phi)

#@torch.jit.script
def Yl79_m_minus_14(theta, phi):
    return 1.34322812256872e-26*(1.0 - cos(theta)**2)**7*(4.15529141541442e+48*cos(theta)**65 - 5.50509945481655e+49*cos(theta)**63 + 3.46821265653443e+50*cos(theta)**61 - 1.38275145129804e+51*cos(theta)**59 + 3.91703267081283e+51*cos(theta)**57 - 8.39138811089566e+51*cos(theta)**55 + 1.41283575336509e+52*cos(theta)**53 - 1.9181159291991e+52*cos(theta)**51 + 2.13776032318956e+52*cos(theta)**49 - 1.98109230896054e+52*cos(theta)**47 + 1.54069121293981e+52*cos(theta)**45 - 1.0121329136101e+52*cos(theta)**43 + 5.64170383327109e+51*cos(theta)**41 - 2.67564901288739e+51*cos(theta)**39 + 1.08105557172822e+51*cos(theta)**37 - 3.72084243292504e+50*cos(theta)**35 + 1.08951833050708e+50*cos(theta)**33 - 2.70713260474231e+49*cos(theta)**31 + 5.68571211023114e+48*cos(theta)**29 - 1.00408835004517e+48*cos(theta)**27 + 1.48081937338594e+47*cos(theta)**25 - 1.8080822629865e+46*cos(theta)**23 + 1.8080822629865e+45*cos(theta)**21 - 1.4609360339637e+44*cos(theta)**19 + 9.37762994773994e+42*cos(theta)**17 - 4.68021164364269e+41*cos(theta)**15 + 1.76643502006643e+40*cos(theta)**13 - 4.86003285944204e+38*cos(theta)**11 + 9.26843991918558e+36*cos(theta)**9 - 1.13917322325258e+35*cos(theta)**7 + 8.05476016441219e+32*cos(theta)**5 - 2.6786698252119e+30*cos(theta)**3 + 2.64342416961701e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl79_m_minus_13(theta, phi):
    return 1.05235729970741e-24*(1.0 - cos(theta)**2)**6.5*(6.29589608396124e+46*cos(theta)**66 - 8.60171789815087e+47*cos(theta)**64 + 5.59389138150714e+48*cos(theta)**62 - 2.3045857521634e+49*cos(theta)**60 + 6.7535046048497e+49*cos(theta)**58 - 1.49846216265994e+50*cos(theta)**56 + 2.61636250623164e+50*cos(theta)**54 - 3.68868447922904e+50*cos(theta)**52 + 4.27552064637912e+50*cos(theta)**50 - 4.12727564366779e+50*cos(theta)**48 + 3.3493287237822e+50*cos(theta)**46 - 2.30030207638658e+50*cos(theta)**44 + 1.3432628174455e+50*cos(theta)**42 - 6.68912253221847e+49*cos(theta)**40 + 2.84488308349532e+49*cos(theta)**38 - 1.03356734247918e+49*cos(theta)**36 + 3.20446567796201e+48*cos(theta)**34 - 8.45978938981972e+47*cos(theta)**32 + 1.89523737007705e+47*cos(theta)**30 - 3.58602982158989e+46*cos(theta)**28 + 5.69545912840747e+45*cos(theta)**26 - 7.53367609577707e+44*cos(theta)**24 + 8.21855574084772e+43*cos(theta)**22 - 7.30468016981848e+42*cos(theta)**20 + 5.20979441541108e+41*cos(theta)**18 - 2.92513227727668e+40*cos(theta)**16 + 1.26173930004745e+39*cos(theta)**14 - 4.05002738286837e+37*cos(theta)**12 + 9.26843991918558e+35*cos(theta)**10 - 1.42396652906573e+34*cos(theta)**8 + 1.34246002740203e+32*cos(theta)**6 - 6.69667456302976e+29*cos(theta)**4 + 1.3217120848085e+27*cos(theta)**2 - 4.30665390944446e+23)*sin(13*phi)

#@torch.jit.script
def Yl79_m_minus_12(theta, phi):
    return 8.26217772916405e-23*(1.0 - cos(theta)**2)**6*(9.39685982680782e+44*cos(theta)**67 - 1.32334121510013e+46*cos(theta)**65 + 8.87919266905896e+46*cos(theta)**63 - 3.77800942977607e+47*cos(theta)**61 + 1.14466179743215e+48*cos(theta)**59 - 2.6288809871227e+48*cos(theta)**57 + 4.75702273860298e+48*cos(theta)**55 - 6.95978203628121e+48*cos(theta)**53 + 8.38337381642964e+48*cos(theta)**51 - 8.42301151768936e+48*cos(theta)**49 + 7.12623132719618e+48*cos(theta)**47 - 5.11178239197018e+48*cos(theta)**45 + 3.12386701731511e+48*cos(theta)**43 - 1.63149330054109e+48*cos(theta)**41 + 7.29457200896235e+47*cos(theta)**39 - 2.79342524994372e+47*cos(theta)**37 + 9.15561622274861e+46*cos(theta)**35 - 2.56357254236961e+46*cos(theta)**33 + 6.11366893573241e+45*cos(theta)**31 - 1.23656200744479e+45*cos(theta)**29 + 2.10942930681758e+44*cos(theta)**27 - 3.01347043831083e+43*cos(theta)**25 + 3.5732851047164e+42*cos(theta)**23 - 3.47841912848499e+41*cos(theta)**21 + 2.74199706074267e+40*cos(theta)**19 - 1.72066604545687e+39*cos(theta)**17 + 8.41159533364969e+37*cos(theta)**15 - 3.11540567912951e+36*cos(theta)**13 + 8.42585447198689e+34*cos(theta)**11 - 1.58218503229525e+33*cos(theta)**9 + 1.91780003914576e+31*cos(theta)**7 - 1.33933491260595e+29*cos(theta)**5 + 4.40570694936168e+26*cos(theta)**3 - 4.30665390944446e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl79_m_minus_11(theta, phi):
    return 6.49934641456728e-21*(1.0 - cos(theta)**2)**5.5*(1.38189115100115e+43*cos(theta)**68 - 2.00506244712141e+44*cos(theta)**66 + 1.38737385454046e+45*cos(theta)**64 - 6.09356359641301e+45*cos(theta)**62 + 1.90776966238692e+46*cos(theta)**60 - 4.53255342607362e+46*cos(theta)**58 + 8.49468346179104e+46*cos(theta)**56 - 1.28884852523726e+47*cos(theta)**54 + 1.61218727239032e+47*cos(theta)**52 - 1.68460230353787e+47*cos(theta)**50 + 1.4846315264992e+47*cos(theta)**48 - 1.11125704173265e+47*cos(theta)**46 + 7.09969776662525e+46*cos(theta)**44 - 3.88450785843117e+46*cos(theta)**42 + 1.82364300224059e+46*cos(theta)**40 - 7.35111907879927e+45*cos(theta)**38 + 2.54322672854128e+45*cos(theta)**36 - 7.53991924226356e+44*cos(theta)**34 + 1.91052154241638e+44*cos(theta)**32 - 4.1218733581493e+43*cos(theta)**30 + 7.53367609577707e+42*cos(theta)**28 - 1.15902709165801e+42*cos(theta)**26 + 1.48886879363183e+41*cos(theta)**24 - 1.58109960385681e+40*cos(theta)**22 + 1.37099853037134e+39*cos(theta)**20 - 9.55925580809372e+37*cos(theta)**18 + 5.25724708353105e+36*cos(theta)**16 - 2.2252897708068e+35*cos(theta)**14 + 7.02154539332241e+33*cos(theta)**12 - 1.58218503229525e+32*cos(theta)**10 + 2.3972500489322e+30*cos(theta)**8 - 2.23222485434325e+28*cos(theta)**6 + 1.10142673734042e+26*cos(theta)**4 - 2.15332695472223e+23*cos(theta)**2 + 6.95968634364004e+19)*sin(11*phi)

#@torch.jit.script
def Yl79_m_minus_10(theta, phi):
    return 5.12171591071553e-19*(1.0 - cos(theta)**2)**5*(2.00274079855239e+41*cos(theta)**69 - 2.99263051809166e+42*cos(theta)**67 + 2.13442131467763e+43*cos(theta)**65 - 9.67232316890954e+43*cos(theta)**63 + 3.12749124981462e+44*cos(theta)**61 - 7.68229394249767e+44*cos(theta)**59 + 1.49029534417387e+45*cos(theta)**57 - 2.34336095497684e+45*cos(theta)**55 + 3.04186277809494e+45*cos(theta)**53 - 3.30314177164289e+45*cos(theta)**51 + 3.02986025816164e+45*cos(theta)**49 - 2.36437668453755e+45*cos(theta)**47 + 1.57771061480561e+45*cos(theta)**45 - 9.03373920565388e+44*cos(theta)**43 + 4.44790976156241e+44*cos(theta)**41 - 1.88490232789725e+44*cos(theta)**39 + 6.87358575281427e+43*cos(theta)**37 - 2.15426264064673e+43*cos(theta)**35 + 5.78945921944357e+42*cos(theta)**33 - 1.32963656714493e+42*cos(theta)**31 + 2.5978193433714e+41*cos(theta)**29 - 4.29269293206671e+40*cos(theta)**27 + 5.95547517452733e+39*cos(theta)**25 - 6.87434610372528e+38*cos(theta)**23 + 6.5285644303397e+37*cos(theta)**21 - 5.03118726741775e+36*cos(theta)**19 + 3.09249828443003e+35*cos(theta)**17 - 1.4835265138712e+34*cos(theta)**15 + 5.40118876409416e+32*cos(theta)**13 - 1.43835002935932e+31*cos(theta)**11 + 2.66361116548022e+29*cos(theta)**9 - 3.18889264906179e+27*cos(theta)**7 + 2.20285347468084e+25*cos(theta)**5 - 7.17775651574076e+22*cos(theta)**3 + 6.95968634364004e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl79_m_minus_9(theta, phi):
    return 4.04258824530248e-17*(1.0 - cos(theta)**2)**4.5*(2.86105828364627e+39*cos(theta)**70 - 4.40092723248774e+40*cos(theta)**68 + 3.23397168890551e+41*cos(theta)**66 - 1.51130049514212e+42*cos(theta)**64 + 5.04434072550746e+42*cos(theta)**62 - 1.28038232374961e+43*cos(theta)**60 + 2.56947473133425e+43*cos(theta)**58 - 4.18457313388721e+43*cos(theta)**56 + 5.63307921869433e+43*cos(theta)**54 - 6.35219571469786e+43*cos(theta)**52 + 6.05972051632328e+43*cos(theta)**50 - 4.92578475945323e+43*cos(theta)**48 + 3.42980568436003e+43*cos(theta)**46 - 2.05312254673952e+43*cos(theta)**44 + 1.05902613370534e+43*cos(theta)**42 - 4.71225581974312e+42*cos(theta)**40 + 1.80883835600376e+42*cos(theta)**38 - 5.98406289068537e+41*cos(theta)**36 + 1.70278212336576e+41*cos(theta)**34 - 4.15511427232792e+40*cos(theta)**32 + 8.65939781123802e+39*cos(theta)**30 - 1.53310461859525e+39*cos(theta)**28 + 2.2905673748182e+38*cos(theta)**26 - 2.8643108765522e+37*cos(theta)**24 + 2.96752928651804e+36*cos(theta)**22 - 2.51559363370887e+35*cos(theta)**20 + 1.71805460246113e+34*cos(theta)**18 - 9.27204071169498e+32*cos(theta)**16 + 3.85799197435297e+31*cos(theta)**14 - 1.1986250244661e+30*cos(theta)**12 + 2.66361116548022e+28*cos(theta)**10 - 3.98611581132724e+26*cos(theta)**8 + 3.6714224578014e+24*cos(theta)**6 - 1.79443912893519e+22*cos(theta)**4 + 3.47984317182002e+19*cos(theta)**2 - 1.1171246137464e+16)*sin(9*phi)

#@torch.jit.script
def Yl79_m_minus_8(theta, phi):
    return 3.19543523197027e-15*(1.0 - cos(theta)**2)**4*(4.02965955443137e+37*cos(theta)**71 - 6.37815540940252e+38*cos(theta)**69 + 4.82682341627687e+39*cos(theta)**67 - 2.32507768483402e+40*cos(theta)**65 + 8.00689004048803e+40*cos(theta)**63 - 2.09898741598297e+41*cos(theta)**61 + 4.35504191751568e+41*cos(theta)**59 - 7.34135637524073e+41*cos(theta)**57 + 1.02419622158079e+42*cos(theta)**55 - 1.19852749333922e+42*cos(theta)**53 + 1.18818049339672e+42*cos(theta)**51 - 1.00526219580678e+42*cos(theta)**49 + 7.29745890289367e+41*cos(theta)**47 - 4.56249454831004e+41*cos(theta)**45 + 2.46285147373334e+41*cos(theta)**43 - 1.14933068774222e+41*cos(theta)**41 + 4.6380470666763e+40*cos(theta)**39 - 1.61731429477983e+40*cos(theta)**37 + 4.86509178104501e+39*cos(theta)**35 - 1.25912553706907e+39*cos(theta)**33 + 2.79335413265742e+38*cos(theta)**31 - 5.28656765032846e+37*cos(theta)**29 + 8.48358286969705e+36*cos(theta)**27 - 1.14572435062088e+36*cos(theta)**25 + 1.29023012457306e+35*cos(theta)**23 - 1.19790173033756e+34*cos(theta)**21 + 9.04239264453226e+32*cos(theta)**19 - 5.45414159511469e+31*cos(theta)**17 + 2.57199464956865e+30*cos(theta)**15 - 9.22019249589307e+28*cos(theta)**13 + 2.42146469589111e+27*cos(theta)**11 - 4.42901756814137e+25*cos(theta)**9 + 5.24488922543057e+23*cos(theta)**7 - 3.58887825787038e+21*cos(theta)**5 + 1.15994772394001e+19*cos(theta)**3 - 1.1171246137464e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl79_m_minus_7(theta, phi):
    return 2.52904113844031e-13*(1.0 - cos(theta)**2)**3.5*(5.59674938115468e+35*cos(theta)**72 - 9.11165058486074e+36*cos(theta)**70 + 7.09826972981893e+37*cos(theta)**68 - 3.52284497702125e+38*cos(theta)**66 + 1.25107656882625e+39*cos(theta)**64 - 3.38546357416608e+39*cos(theta)**62 + 7.25840319585947e+39*cos(theta)**60 - 1.26575109917944e+40*cos(theta)**58 + 1.8289218242514e+40*cos(theta)**56 - 2.21949535803559e+40*cos(theta)**54 + 2.28496248730139e+40*cos(theta)**52 - 2.01052439161356e+40*cos(theta)**50 + 1.52030393810285e+40*cos(theta)**48 - 9.91846640936965e+39*cos(theta)**46 + 5.59738971303031e+39*cos(theta)**44 - 2.73650163748149e+39*cos(theta)**42 + 1.15951176666907e+39*cos(theta)**40 - 4.2560902494206e+38*cos(theta)**38 + 1.35141438362362e+38*cos(theta)**36 - 3.70331040314431e+37*cos(theta)**34 + 8.72923166455445e+36*cos(theta)**32 - 1.76218921677615e+36*cos(theta)**30 + 3.0298510248918e+35*cos(theta)**28 - 4.40663211777261e+34*cos(theta)**26 + 5.37595885238776e+33*cos(theta)**24 - 5.44500786517072e+32*cos(theta)**22 + 4.52119632226613e+31*cos(theta)**20 - 3.03007866395261e+30*cos(theta)**18 + 1.60749665598041e+29*cos(theta)**16 - 6.58585178278077e+27*cos(theta)**14 + 2.01788724657593e+26*cos(theta)**12 - 4.42901756814137e+24*cos(theta)**10 + 6.55611153178822e+22*cos(theta)**8 - 5.9814637631173e+20*cos(theta)**6 + 2.89986930985002e+18*cos(theta)**4 - 5.58562306873198e+15*cos(theta)**2 + 1783404555789.26)*sin(7*phi)

#@torch.jit.script
def Yl79_m_minus_6(theta, phi):
    return 2.00385618555223e-11*(1.0 - cos(theta)**2)**3*(7.66677997418449e+33*cos(theta)**73 - 1.28333106829025e+35*cos(theta)**71 + 1.02873474345202e+36*cos(theta)**69 - 5.25797757764365e+36*cos(theta)**67 + 1.92473318280962e+37*cos(theta)**65 - 5.37375170502552e+37*cos(theta)**63 + 1.18990216325565e+38*cos(theta)**61 - 2.14534084606684e+38*cos(theta)**59 + 3.20863477938843e+38*cos(theta)**57 - 4.03544610551925e+38*cos(theta)**55 + 4.31124997604035e+38*cos(theta)**53 - 3.94220468943836e+38*cos(theta)**51 + 3.10266109816908e+38*cos(theta)**49 - 2.11031200199354e+38*cos(theta)**47 + 1.2438643806734e+38*cos(theta)**45 - 6.36395729646857e+37*cos(theta)**43 + 2.82807747968067e+37*cos(theta)**41 - 1.09130519215913e+37*cos(theta)**39 + 3.65247130709085e+36*cos(theta)**37 - 1.05808868661266e+36*cos(theta)**35 + 2.64522171653165e+35*cos(theta)**33 - 5.6844813444392e+34*cos(theta)**31 + 1.04477621547993e+34*cos(theta)**29 - 1.63208596954541e+33*cos(theta)**27 + 2.1503835409551e+32*cos(theta)**25 - 2.36739472398727e+31*cos(theta)**23 + 2.15295062965054e+30*cos(theta)**21 - 1.59477824418558e+29*cos(theta)**19 + 9.45586268223768e+27*cos(theta)**17 - 4.39056785518718e+26*cos(theta)**15 + 1.55222095890456e+25*cos(theta)**13 - 4.02637960740125e+23*cos(theta)**11 + 7.28456836865357e+21*cos(theta)**9 - 8.54494823302472e+19*cos(theta)**7 + 5.79973861970004e+17*cos(theta)**5 - 1.86187435624399e+15*cos(theta)**3 + 1783404555789.26*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl79_m_minus_5(theta, phi):
    return 1.58924872697274e-9*(1.0 - cos(theta)**2)**2.5*(1.03605134786277e+32*cos(theta)**74 - 1.78240426151423e+33*cos(theta)**72 + 1.46962106207431e+34*cos(theta)**70 - 7.73231996712302e+34*cos(theta)**68 + 2.9162623981964e+35*cos(theta)**66 - 8.39648703910238e+35*cos(theta)**64 + 1.91919703750912e+36*cos(theta)**62 - 3.57556807677807e+36*cos(theta)**60 + 5.53212892998005e+36*cos(theta)**58 - 7.20615375985581e+36*cos(theta)**56 + 7.98379625192658e+36*cos(theta)**54 - 7.58116286430454e+36*cos(theta)**52 + 6.20532219633816e+36*cos(theta)**50 - 4.39648333748655e+36*cos(theta)**48 + 2.70405300146392e+36*cos(theta)**46 - 1.44635393101558e+36*cos(theta)**44 + 6.7335178087635e+35*cos(theta)**42 - 2.72826298039782e+35*cos(theta)**40 + 9.6117665976075e+34*cos(theta)**38 - 2.93913524059072e+34*cos(theta)**36 + 7.78006387215192e+33*cos(theta)**34 - 1.77640042013725e+33*cos(theta)**32 + 3.48258738493311e+32*cos(theta)**30 - 5.82887846266219e+31*cos(theta)**28 + 8.2707059267504e+30*cos(theta)**26 - 9.86414468328029e+29*cos(theta)**24 + 9.78613922568426e+28*cos(theta)**22 - 7.97389122092792e+27*cos(theta)**20 + 5.2532570456876e+26*cos(theta)**18 - 2.74410490949199e+25*cos(theta)**16 + 1.1087292563604e+24*cos(theta)**14 - 3.35531633950104e+22*cos(theta)**12 + 7.28456836865357e+20*cos(theta)**10 - 1.06811852912809e+19*cos(theta)**8 + 9.66623103283339e+16*cos(theta)**6 - 465468589060998.0*cos(theta)**4 + 891702277894.632*cos(theta)**2 - 283530136.055527)*sin(5*phi)

#@torch.jit.script
def Yl79_m_minus_4(theta, phi):
    return 1.26142707089876e-7*(1.0 - cos(theta)**2)**2*(1.38140179715036e+30*cos(theta)**75 - 2.44164967330716e+31*cos(theta)**73 + 2.06988881982298e+32*cos(theta)**71 - 1.12062608219174e+33*cos(theta)**69 + 4.35263044506925e+33*cos(theta)**67 - 1.29176723678498e+34*cos(theta)**65 + 3.04634450398272e+34*cos(theta)**63 - 5.86158701111158e+34*cos(theta)**61 + 9.37648971183059e+34*cos(theta)**59 - 1.26423750172909e+35*cos(theta)**57 + 1.45159931853211e+35*cos(theta)**55 - 1.43040808760463e+35*cos(theta)**53 + 1.21672984241925e+35*cos(theta)**51 - 8.97241497446234e+34*cos(theta)**49 + 5.75330425843387e+34*cos(theta)**47 - 3.2141198467013e+34*cos(theta)**45 + 1.56593437413105e+34*cos(theta)**43 - 6.65429995218981e+33*cos(theta)**41 + 2.46455553784808e+33*cos(theta)**39 - 7.94360875835331e+32*cos(theta)**37 + 2.22287539204341e+32*cos(theta)**35 - 5.38303157617349e+31*cos(theta)**33 + 1.12341528546229e+31*cos(theta)**31 - 2.00995809057317e+30*cos(theta)**29 + 3.06322441731496e+29*cos(theta)**27 - 3.94565787331212e+28*cos(theta)**25 + 4.25484314160185e+27*cos(theta)**23 - 3.79709105758472e+26*cos(theta)**21 + 2.76487212930926e+25*cos(theta)**19 - 1.6141793585247e+24*cos(theta)**17 + 7.39152837573599e+22*cos(theta)**15 - 2.58101256884695e+21*cos(theta)**13 + 6.62233488059416e+19*cos(theta)**11 - 1.18679836569788e+18*cos(theta)**9 + 1.38089014754763e+16*cos(theta)**7 - 93093717812199.6*cos(theta)**5 + 297234092631.544*cos(theta)**3 - 283530136.055527*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl79_m_minus_3(theta, phi):
    return 1.00186219580228e-5*(1.0 - cos(theta)**2)**1.5*(1.81763394361889e+28*cos(theta)**76 - 3.29952658555022e+29*cos(theta)**74 + 2.87484558308747e+30*cos(theta)**72 - 1.60089440313106e+31*cos(theta)**70 + 6.40092712510184e+31*cos(theta)**68 - 1.95722308603785e+32*cos(theta)**66 + 4.759913287473e+32*cos(theta)**64 - 9.45417259856707e+32*cos(theta)**62 + 1.5627482853051e+33*cos(theta)**60 - 2.1797198305674e+33*cos(theta)**58 + 2.5921416402359e+33*cos(theta)**56 - 2.6489038659345e+33*cos(theta)**54 + 2.33986508157547e+33*cos(theta)**52 - 1.79448299489247e+33*cos(theta)**50 + 1.19860505384039e+33*cos(theta)**48 - 6.9872170580463e+32*cos(theta)**46 + 3.55894175938874e+32*cos(theta)**44 - 1.58435713147376e+32*cos(theta)**42 + 6.1613888446202e+31*cos(theta)**40 - 2.0904233574614e+31*cos(theta)**38 + 6.17465386678724e+30*cos(theta)**36 - 1.5832445812275e+30*cos(theta)**34 + 3.51067276706967e+29*cos(theta)**32 - 6.69986030191056e+28*cos(theta)**30 + 1.09400872046963e+28*cos(theta)**28 - 1.51756072050466e+27*cos(theta)**26 + 1.77285130900077e+26*cos(theta)**24 - 1.72595048072033e+25*cos(theta)**22 + 1.38243606465463e+24*cos(theta)**20 - 8.96766310291499e+22*cos(theta)**18 + 4.61970523483499e+21*cos(theta)**16 - 1.84358040631925e+20*cos(theta)**14 + 5.51861240049513e+18*cos(theta)**12 - 1.18679836569788e+17*cos(theta)**10 + 1.72611268443453e+15*cos(theta)**8 - 15515619635366.6*cos(theta)**6 + 74308523157.886*cos(theta)**4 - 141765068.027763*cos(theta)**2 + 44947.7070474837)*sin(3*phi)

#@torch.jit.script
def Yl79_m_minus_2(theta, phi):
    return 0.000796086534499313*(1.0 - cos(theta)**2)*(2.36056356314142e+26*cos(theta)**77 - 4.39936878073363e+27*cos(theta)**75 + 3.93814463436639e+28*cos(theta)**73 - 2.25478084948037e+29*cos(theta)**71 + 9.27670597840846e+29*cos(theta)**69 - 2.92122848662366e+30*cos(theta)**67 + 7.32294351918924e+30*cos(theta)**65 - 1.50066231723287e+31*cos(theta)**63 + 2.56188243492639e+31*cos(theta)**61 - 3.6944403907922e+31*cos(theta)**59 + 4.54761691269457e+31*cos(theta)**57 - 4.81618884715363e+31*cos(theta)**55 + 4.4148397765575e+31*cos(theta)**53 - 3.51859410763229e+31*cos(theta)**51 + 2.44613276293957e+31*cos(theta)**49 - 1.48664192724389e+31*cos(theta)**47 + 7.90875946530831e+30*cos(theta)**45 - 3.68455146854364e+30*cos(theta)**43 + 1.50277776698054e+30*cos(theta)**41 - 5.36005989092666e+29*cos(theta)**39 + 1.66882536940196e+29*cos(theta)**37 - 4.52355594636428e+28*cos(theta)**35 + 1.06384023244535e+28*cos(theta)**33 - 2.16124525868083e+27*cos(theta)**31 + 3.77244386368838e+26*cos(theta)**29 - 5.62059526112837e+25*cos(theta)**27 + 7.09140523600309e+24*cos(theta)**25 - 7.50413252487099e+23*cos(theta)**23 + 6.58302887930777e+22*cos(theta)**21 - 4.71982268574473e+21*cos(theta)**19 + 2.71747366755e+20*cos(theta)**17 - 1.22905360421284e+19*cos(theta)**15 + 4.24508646191933e+17*cos(theta)**13 - 1.07890760517989e+16*cos(theta)**11 + 191790298270504.0*cos(theta)**9 - 2216517090766.66*cos(theta)**7 + 14861704631.5772*cos(theta)**5 - 47255022.6759212*cos(theta)**3 + 44947.7070474837*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl79_m_minus_1(theta, phi):
    return 0.0632776131144143*(1.0 - cos(theta)**2)**0.5*(3.026363542489e+24*cos(theta)**78 - 5.78864313254425e+25*cos(theta)**76 + 5.3218170734681e+26*cos(theta)**74 - 3.13164006872273e+27*cos(theta)**72 + 1.32524371120121e+28*cos(theta)**70 - 4.29592424503479e+28*cos(theta)**68 + 1.10953689684685e+29*cos(theta)**66 - 2.34478487067636e+29*cos(theta)**64 + 4.13206844342966e+29*cos(theta)**62 - 6.15740065132033e+29*cos(theta)**60 + 7.84071881499063e+29*cos(theta)**58 - 8.60033722706006e+29*cos(theta)**56 + 8.17562921584722e+29*cos(theta)**54 - 6.7665271300621e+29*cos(theta)**52 + 4.89226552587914e+29*cos(theta)**50 - 3.09717068175811e+29*cos(theta)**48 + 1.71929553593659e+29*cos(theta)**46 - 8.37398061032645e+28*cos(theta)**44 + 3.57804230233461e+28*cos(theta)**42 - 1.34001497273166e+28*cos(theta)**40 + 4.39164570895252e+27*cos(theta)**38 - 1.25654331843452e+27*cos(theta)**36 + 3.12894186013339e+26*cos(theta)**34 - 6.75389143337758e+25*cos(theta)**32 + 1.25748128789613e+25*cos(theta)**30 - 2.00735545040299e+24*cos(theta)**28 + 2.72746355230888e+23*cos(theta)**26 - 3.12672188536291e+22*cos(theta)**24 + 2.9922858542308e+21*cos(theta)**22 - 2.35991134287237e+20*cos(theta)**20 + 1.50970759308333e+19*cos(theta)**18 - 7.68158502633022e+17*cos(theta)**16 + 3.03220461565667e+16*cos(theta)**14 - 899089670983241.0*cos(theta)**12 + 19179029827050.4*cos(theta)**10 - 277064636345.832*cos(theta)**8 + 2476950771.92953*cos(theta)**6 - 11813755.6689803*cos(theta)**4 + 22473.8535237418*cos(theta)**2 - 7.11423030191258)*sin(phi)

#@torch.jit.script
def Yl79_m0(theta, phi):
    return 4.28092390422614e+23*cos(theta)**79 - 8.40097232415333e+24*cos(theta)**77 + 7.92943387757182e+25*cos(theta)**75 - 4.79393878219211e+26*cos(theta)**73 + 2.08583958933789e+27*cos(theta)**71 - 6.95746493893243e+27*cos(theta)**69 + 1.8505910143691e+28*cos(theta)**67 - 4.03118889928087e+28*cos(theta)**65 + 7.32943436232886e+28*cos(theta)**63 - 1.12800514654281e+29*cos(theta)**61 + 1.48507152386571e+29*cos(theta)**59 - 1.68610310373871e+29*cos(theta)**57 + 1.66112379849814e+29*cos(theta)**55 - 1.42670262624045e+29*cos(theta)**53 + 1.07197176606289e+29*cos(theta)**51 - 7.06337985390275e+28*cos(theta)**49 + 4.08786156899096e+28*cos(theta)**47 - 2.07951922639023e+28*cos(theta)**45 + 9.29866320743597e+27*cos(theta)**43 - 3.65232400013688e+27*cos(theta)**41 + 1.2583637311396e+27*cos(theta)**39 - 3.7950652208972e+26*cos(theta)**37 + 9.99017168821159e+25*cos(theta)**35 - 2.28709201788607e+25*cos(theta)**33 + 4.53297517058501e+24*cos(theta)**31 - 7.73516863971386e+23*cos(theta)**29 + 1.12885638667284e+23*cos(theta)**27 - 1.39763171683303e+22*cos(theta)**25 + 1.4538471395628e+21*cos(theta)**23 - 1.25579831447384e+20*cos(theta)**21 + 8.87938202153219e+18*cos(theta)**19 - 5.04946566572e+17*cos(theta)**17 + 2.25897148203263e+16*cos(theta)**15 - 772864143412924.0*cos(theta)**13 + 19483970002006.5*cos(theta)**11 - 344018731977.643*cos(theta)**9 + 3954238298.59359*cos(theta)**7 - 26403498.973121*cos(theta)**5 + 83714.3277524445*cos(theta)**3 - 79.5007860896908*cos(theta)

#@torch.jit.script
def Yl79_m1(theta, phi):
    return 0.0632776131144143*(1.0 - cos(theta)**2)**0.5*(3.026363542489e+24*cos(theta)**78 - 5.78864313254425e+25*cos(theta)**76 + 5.3218170734681e+26*cos(theta)**74 - 3.13164006872273e+27*cos(theta)**72 + 1.32524371120121e+28*cos(theta)**70 - 4.29592424503479e+28*cos(theta)**68 + 1.10953689684685e+29*cos(theta)**66 - 2.34478487067636e+29*cos(theta)**64 + 4.13206844342966e+29*cos(theta)**62 - 6.15740065132033e+29*cos(theta)**60 + 7.84071881499063e+29*cos(theta)**58 - 8.60033722706006e+29*cos(theta)**56 + 8.17562921584722e+29*cos(theta)**54 - 6.7665271300621e+29*cos(theta)**52 + 4.89226552587914e+29*cos(theta)**50 - 3.09717068175811e+29*cos(theta)**48 + 1.71929553593659e+29*cos(theta)**46 - 8.37398061032645e+28*cos(theta)**44 + 3.57804230233461e+28*cos(theta)**42 - 1.34001497273166e+28*cos(theta)**40 + 4.39164570895252e+27*cos(theta)**38 - 1.25654331843452e+27*cos(theta)**36 + 3.12894186013339e+26*cos(theta)**34 - 6.75389143337758e+25*cos(theta)**32 + 1.25748128789613e+25*cos(theta)**30 - 2.00735545040299e+24*cos(theta)**28 + 2.72746355230888e+23*cos(theta)**26 - 3.12672188536291e+22*cos(theta)**24 + 2.9922858542308e+21*cos(theta)**22 - 2.35991134287237e+20*cos(theta)**20 + 1.50970759308333e+19*cos(theta)**18 - 7.68158502633022e+17*cos(theta)**16 + 3.03220461565667e+16*cos(theta)**14 - 899089670983241.0*cos(theta)**12 + 19179029827050.4*cos(theta)**10 - 277064636345.832*cos(theta)**8 + 2476950771.92953*cos(theta)**6 - 11813755.6689803*cos(theta)**4 + 22473.8535237418*cos(theta)**2 - 7.11423030191258)*cos(phi)

#@torch.jit.script
def Yl79_m2(theta, phi):
    return 0.000796086534499313*(1.0 - cos(theta)**2)*(2.36056356314142e+26*cos(theta)**77 - 4.39936878073363e+27*cos(theta)**75 + 3.93814463436639e+28*cos(theta)**73 - 2.25478084948037e+29*cos(theta)**71 + 9.27670597840846e+29*cos(theta)**69 - 2.92122848662366e+30*cos(theta)**67 + 7.32294351918924e+30*cos(theta)**65 - 1.50066231723287e+31*cos(theta)**63 + 2.56188243492639e+31*cos(theta)**61 - 3.6944403907922e+31*cos(theta)**59 + 4.54761691269457e+31*cos(theta)**57 - 4.81618884715363e+31*cos(theta)**55 + 4.4148397765575e+31*cos(theta)**53 - 3.51859410763229e+31*cos(theta)**51 + 2.44613276293957e+31*cos(theta)**49 - 1.48664192724389e+31*cos(theta)**47 + 7.90875946530831e+30*cos(theta)**45 - 3.68455146854364e+30*cos(theta)**43 + 1.50277776698054e+30*cos(theta)**41 - 5.36005989092666e+29*cos(theta)**39 + 1.66882536940196e+29*cos(theta)**37 - 4.52355594636428e+28*cos(theta)**35 + 1.06384023244535e+28*cos(theta)**33 - 2.16124525868083e+27*cos(theta)**31 + 3.77244386368838e+26*cos(theta)**29 - 5.62059526112837e+25*cos(theta)**27 + 7.09140523600309e+24*cos(theta)**25 - 7.50413252487099e+23*cos(theta)**23 + 6.58302887930777e+22*cos(theta)**21 - 4.71982268574473e+21*cos(theta)**19 + 2.71747366755e+20*cos(theta)**17 - 1.22905360421284e+19*cos(theta)**15 + 4.24508646191933e+17*cos(theta)**13 - 1.07890760517989e+16*cos(theta)**11 + 191790298270504.0*cos(theta)**9 - 2216517090766.66*cos(theta)**7 + 14861704631.5772*cos(theta)**5 - 47255022.6759212*cos(theta)**3 + 44947.7070474837*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl79_m3(theta, phi):
    return 1.00186219580228e-5*(1.0 - cos(theta)**2)**1.5*(1.81763394361889e+28*cos(theta)**76 - 3.29952658555022e+29*cos(theta)**74 + 2.87484558308747e+30*cos(theta)**72 - 1.60089440313106e+31*cos(theta)**70 + 6.40092712510184e+31*cos(theta)**68 - 1.95722308603785e+32*cos(theta)**66 + 4.759913287473e+32*cos(theta)**64 - 9.45417259856707e+32*cos(theta)**62 + 1.5627482853051e+33*cos(theta)**60 - 2.1797198305674e+33*cos(theta)**58 + 2.5921416402359e+33*cos(theta)**56 - 2.6489038659345e+33*cos(theta)**54 + 2.33986508157547e+33*cos(theta)**52 - 1.79448299489247e+33*cos(theta)**50 + 1.19860505384039e+33*cos(theta)**48 - 6.9872170580463e+32*cos(theta)**46 + 3.55894175938874e+32*cos(theta)**44 - 1.58435713147376e+32*cos(theta)**42 + 6.1613888446202e+31*cos(theta)**40 - 2.0904233574614e+31*cos(theta)**38 + 6.17465386678724e+30*cos(theta)**36 - 1.5832445812275e+30*cos(theta)**34 + 3.51067276706967e+29*cos(theta)**32 - 6.69986030191056e+28*cos(theta)**30 + 1.09400872046963e+28*cos(theta)**28 - 1.51756072050466e+27*cos(theta)**26 + 1.77285130900077e+26*cos(theta)**24 - 1.72595048072033e+25*cos(theta)**22 + 1.38243606465463e+24*cos(theta)**20 - 8.96766310291499e+22*cos(theta)**18 + 4.61970523483499e+21*cos(theta)**16 - 1.84358040631925e+20*cos(theta)**14 + 5.51861240049513e+18*cos(theta)**12 - 1.18679836569788e+17*cos(theta)**10 + 1.72611268443453e+15*cos(theta)**8 - 15515619635366.6*cos(theta)**6 + 74308523157.886*cos(theta)**4 - 141765068.027763*cos(theta)**2 + 44947.7070474837)*cos(3*phi)

#@torch.jit.script
def Yl79_m4(theta, phi):
    return 1.26142707089876e-7*(1.0 - cos(theta)**2)**2*(1.38140179715036e+30*cos(theta)**75 - 2.44164967330716e+31*cos(theta)**73 + 2.06988881982298e+32*cos(theta)**71 - 1.12062608219174e+33*cos(theta)**69 + 4.35263044506925e+33*cos(theta)**67 - 1.29176723678498e+34*cos(theta)**65 + 3.04634450398272e+34*cos(theta)**63 - 5.86158701111158e+34*cos(theta)**61 + 9.37648971183059e+34*cos(theta)**59 - 1.26423750172909e+35*cos(theta)**57 + 1.45159931853211e+35*cos(theta)**55 - 1.43040808760463e+35*cos(theta)**53 + 1.21672984241925e+35*cos(theta)**51 - 8.97241497446234e+34*cos(theta)**49 + 5.75330425843387e+34*cos(theta)**47 - 3.2141198467013e+34*cos(theta)**45 + 1.56593437413105e+34*cos(theta)**43 - 6.65429995218981e+33*cos(theta)**41 + 2.46455553784808e+33*cos(theta)**39 - 7.94360875835331e+32*cos(theta)**37 + 2.22287539204341e+32*cos(theta)**35 - 5.38303157617349e+31*cos(theta)**33 + 1.12341528546229e+31*cos(theta)**31 - 2.00995809057317e+30*cos(theta)**29 + 3.06322441731496e+29*cos(theta)**27 - 3.94565787331212e+28*cos(theta)**25 + 4.25484314160185e+27*cos(theta)**23 - 3.79709105758472e+26*cos(theta)**21 + 2.76487212930926e+25*cos(theta)**19 - 1.6141793585247e+24*cos(theta)**17 + 7.39152837573599e+22*cos(theta)**15 - 2.58101256884695e+21*cos(theta)**13 + 6.62233488059416e+19*cos(theta)**11 - 1.18679836569788e+18*cos(theta)**9 + 1.38089014754763e+16*cos(theta)**7 - 93093717812199.6*cos(theta)**5 + 297234092631.544*cos(theta)**3 - 283530136.055527*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl79_m5(theta, phi):
    return 1.58924872697274e-9*(1.0 - cos(theta)**2)**2.5*(1.03605134786277e+32*cos(theta)**74 - 1.78240426151423e+33*cos(theta)**72 + 1.46962106207431e+34*cos(theta)**70 - 7.73231996712302e+34*cos(theta)**68 + 2.9162623981964e+35*cos(theta)**66 - 8.39648703910238e+35*cos(theta)**64 + 1.91919703750912e+36*cos(theta)**62 - 3.57556807677807e+36*cos(theta)**60 + 5.53212892998005e+36*cos(theta)**58 - 7.20615375985581e+36*cos(theta)**56 + 7.98379625192658e+36*cos(theta)**54 - 7.58116286430454e+36*cos(theta)**52 + 6.20532219633816e+36*cos(theta)**50 - 4.39648333748655e+36*cos(theta)**48 + 2.70405300146392e+36*cos(theta)**46 - 1.44635393101558e+36*cos(theta)**44 + 6.7335178087635e+35*cos(theta)**42 - 2.72826298039782e+35*cos(theta)**40 + 9.6117665976075e+34*cos(theta)**38 - 2.93913524059072e+34*cos(theta)**36 + 7.78006387215192e+33*cos(theta)**34 - 1.77640042013725e+33*cos(theta)**32 + 3.48258738493311e+32*cos(theta)**30 - 5.82887846266219e+31*cos(theta)**28 + 8.2707059267504e+30*cos(theta)**26 - 9.86414468328029e+29*cos(theta)**24 + 9.78613922568426e+28*cos(theta)**22 - 7.97389122092792e+27*cos(theta)**20 + 5.2532570456876e+26*cos(theta)**18 - 2.74410490949199e+25*cos(theta)**16 + 1.1087292563604e+24*cos(theta)**14 - 3.35531633950104e+22*cos(theta)**12 + 7.28456836865357e+20*cos(theta)**10 - 1.06811852912809e+19*cos(theta)**8 + 9.66623103283339e+16*cos(theta)**6 - 465468589060998.0*cos(theta)**4 + 891702277894.632*cos(theta)**2 - 283530136.055527)*cos(5*phi)

#@torch.jit.script
def Yl79_m6(theta, phi):
    return 2.00385618555223e-11*(1.0 - cos(theta)**2)**3*(7.66677997418449e+33*cos(theta)**73 - 1.28333106829025e+35*cos(theta)**71 + 1.02873474345202e+36*cos(theta)**69 - 5.25797757764365e+36*cos(theta)**67 + 1.92473318280962e+37*cos(theta)**65 - 5.37375170502552e+37*cos(theta)**63 + 1.18990216325565e+38*cos(theta)**61 - 2.14534084606684e+38*cos(theta)**59 + 3.20863477938843e+38*cos(theta)**57 - 4.03544610551925e+38*cos(theta)**55 + 4.31124997604035e+38*cos(theta)**53 - 3.94220468943836e+38*cos(theta)**51 + 3.10266109816908e+38*cos(theta)**49 - 2.11031200199354e+38*cos(theta)**47 + 1.2438643806734e+38*cos(theta)**45 - 6.36395729646857e+37*cos(theta)**43 + 2.82807747968067e+37*cos(theta)**41 - 1.09130519215913e+37*cos(theta)**39 + 3.65247130709085e+36*cos(theta)**37 - 1.05808868661266e+36*cos(theta)**35 + 2.64522171653165e+35*cos(theta)**33 - 5.6844813444392e+34*cos(theta)**31 + 1.04477621547993e+34*cos(theta)**29 - 1.63208596954541e+33*cos(theta)**27 + 2.1503835409551e+32*cos(theta)**25 - 2.36739472398727e+31*cos(theta)**23 + 2.15295062965054e+30*cos(theta)**21 - 1.59477824418558e+29*cos(theta)**19 + 9.45586268223768e+27*cos(theta)**17 - 4.39056785518718e+26*cos(theta)**15 + 1.55222095890456e+25*cos(theta)**13 - 4.02637960740125e+23*cos(theta)**11 + 7.28456836865357e+21*cos(theta)**9 - 8.54494823302472e+19*cos(theta)**7 + 5.79973861970004e+17*cos(theta)**5 - 1.86187435624399e+15*cos(theta)**3 + 1783404555789.26*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl79_m7(theta, phi):
    return 2.52904113844031e-13*(1.0 - cos(theta)**2)**3.5*(5.59674938115468e+35*cos(theta)**72 - 9.11165058486074e+36*cos(theta)**70 + 7.09826972981893e+37*cos(theta)**68 - 3.52284497702125e+38*cos(theta)**66 + 1.25107656882625e+39*cos(theta)**64 - 3.38546357416608e+39*cos(theta)**62 + 7.25840319585947e+39*cos(theta)**60 - 1.26575109917944e+40*cos(theta)**58 + 1.8289218242514e+40*cos(theta)**56 - 2.21949535803559e+40*cos(theta)**54 + 2.28496248730139e+40*cos(theta)**52 - 2.01052439161356e+40*cos(theta)**50 + 1.52030393810285e+40*cos(theta)**48 - 9.91846640936965e+39*cos(theta)**46 + 5.59738971303031e+39*cos(theta)**44 - 2.73650163748149e+39*cos(theta)**42 + 1.15951176666907e+39*cos(theta)**40 - 4.2560902494206e+38*cos(theta)**38 + 1.35141438362362e+38*cos(theta)**36 - 3.70331040314431e+37*cos(theta)**34 + 8.72923166455445e+36*cos(theta)**32 - 1.76218921677615e+36*cos(theta)**30 + 3.0298510248918e+35*cos(theta)**28 - 4.40663211777261e+34*cos(theta)**26 + 5.37595885238776e+33*cos(theta)**24 - 5.44500786517072e+32*cos(theta)**22 + 4.52119632226613e+31*cos(theta)**20 - 3.03007866395261e+30*cos(theta)**18 + 1.60749665598041e+29*cos(theta)**16 - 6.58585178278077e+27*cos(theta)**14 + 2.01788724657593e+26*cos(theta)**12 - 4.42901756814137e+24*cos(theta)**10 + 6.55611153178822e+22*cos(theta)**8 - 5.9814637631173e+20*cos(theta)**6 + 2.89986930985002e+18*cos(theta)**4 - 5.58562306873198e+15*cos(theta)**2 + 1783404555789.26)*cos(7*phi)

#@torch.jit.script
def Yl79_m8(theta, phi):
    return 3.19543523197027e-15*(1.0 - cos(theta)**2)**4*(4.02965955443137e+37*cos(theta)**71 - 6.37815540940252e+38*cos(theta)**69 + 4.82682341627687e+39*cos(theta)**67 - 2.32507768483402e+40*cos(theta)**65 + 8.00689004048803e+40*cos(theta)**63 - 2.09898741598297e+41*cos(theta)**61 + 4.35504191751568e+41*cos(theta)**59 - 7.34135637524073e+41*cos(theta)**57 + 1.02419622158079e+42*cos(theta)**55 - 1.19852749333922e+42*cos(theta)**53 + 1.18818049339672e+42*cos(theta)**51 - 1.00526219580678e+42*cos(theta)**49 + 7.29745890289367e+41*cos(theta)**47 - 4.56249454831004e+41*cos(theta)**45 + 2.46285147373334e+41*cos(theta)**43 - 1.14933068774222e+41*cos(theta)**41 + 4.6380470666763e+40*cos(theta)**39 - 1.61731429477983e+40*cos(theta)**37 + 4.86509178104501e+39*cos(theta)**35 - 1.25912553706907e+39*cos(theta)**33 + 2.79335413265742e+38*cos(theta)**31 - 5.28656765032846e+37*cos(theta)**29 + 8.48358286969705e+36*cos(theta)**27 - 1.14572435062088e+36*cos(theta)**25 + 1.29023012457306e+35*cos(theta)**23 - 1.19790173033756e+34*cos(theta)**21 + 9.04239264453226e+32*cos(theta)**19 - 5.45414159511469e+31*cos(theta)**17 + 2.57199464956865e+30*cos(theta)**15 - 9.22019249589307e+28*cos(theta)**13 + 2.42146469589111e+27*cos(theta)**11 - 4.42901756814137e+25*cos(theta)**9 + 5.24488922543057e+23*cos(theta)**7 - 3.58887825787038e+21*cos(theta)**5 + 1.15994772394001e+19*cos(theta)**3 - 1.1171246137464e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl79_m9(theta, phi):
    return 4.04258824530248e-17*(1.0 - cos(theta)**2)**4.5*(2.86105828364627e+39*cos(theta)**70 - 4.40092723248774e+40*cos(theta)**68 + 3.23397168890551e+41*cos(theta)**66 - 1.51130049514212e+42*cos(theta)**64 + 5.04434072550746e+42*cos(theta)**62 - 1.28038232374961e+43*cos(theta)**60 + 2.56947473133425e+43*cos(theta)**58 - 4.18457313388721e+43*cos(theta)**56 + 5.63307921869433e+43*cos(theta)**54 - 6.35219571469786e+43*cos(theta)**52 + 6.05972051632328e+43*cos(theta)**50 - 4.92578475945323e+43*cos(theta)**48 + 3.42980568436003e+43*cos(theta)**46 - 2.05312254673952e+43*cos(theta)**44 + 1.05902613370534e+43*cos(theta)**42 - 4.71225581974312e+42*cos(theta)**40 + 1.80883835600376e+42*cos(theta)**38 - 5.98406289068537e+41*cos(theta)**36 + 1.70278212336576e+41*cos(theta)**34 - 4.15511427232792e+40*cos(theta)**32 + 8.65939781123802e+39*cos(theta)**30 - 1.53310461859525e+39*cos(theta)**28 + 2.2905673748182e+38*cos(theta)**26 - 2.8643108765522e+37*cos(theta)**24 + 2.96752928651804e+36*cos(theta)**22 - 2.51559363370887e+35*cos(theta)**20 + 1.71805460246113e+34*cos(theta)**18 - 9.27204071169498e+32*cos(theta)**16 + 3.85799197435297e+31*cos(theta)**14 - 1.1986250244661e+30*cos(theta)**12 + 2.66361116548022e+28*cos(theta)**10 - 3.98611581132724e+26*cos(theta)**8 + 3.6714224578014e+24*cos(theta)**6 - 1.79443912893519e+22*cos(theta)**4 + 3.47984317182002e+19*cos(theta)**2 - 1.1171246137464e+16)*cos(9*phi)

#@torch.jit.script
def Yl79_m10(theta, phi):
    return 5.12171591071553e-19*(1.0 - cos(theta)**2)**5*(2.00274079855239e+41*cos(theta)**69 - 2.99263051809166e+42*cos(theta)**67 + 2.13442131467763e+43*cos(theta)**65 - 9.67232316890954e+43*cos(theta)**63 + 3.12749124981462e+44*cos(theta)**61 - 7.68229394249767e+44*cos(theta)**59 + 1.49029534417387e+45*cos(theta)**57 - 2.34336095497684e+45*cos(theta)**55 + 3.04186277809494e+45*cos(theta)**53 - 3.30314177164289e+45*cos(theta)**51 + 3.02986025816164e+45*cos(theta)**49 - 2.36437668453755e+45*cos(theta)**47 + 1.57771061480561e+45*cos(theta)**45 - 9.03373920565388e+44*cos(theta)**43 + 4.44790976156241e+44*cos(theta)**41 - 1.88490232789725e+44*cos(theta)**39 + 6.87358575281427e+43*cos(theta)**37 - 2.15426264064673e+43*cos(theta)**35 + 5.78945921944357e+42*cos(theta)**33 - 1.32963656714493e+42*cos(theta)**31 + 2.5978193433714e+41*cos(theta)**29 - 4.29269293206671e+40*cos(theta)**27 + 5.95547517452733e+39*cos(theta)**25 - 6.87434610372528e+38*cos(theta)**23 + 6.5285644303397e+37*cos(theta)**21 - 5.03118726741775e+36*cos(theta)**19 + 3.09249828443003e+35*cos(theta)**17 - 1.4835265138712e+34*cos(theta)**15 + 5.40118876409416e+32*cos(theta)**13 - 1.43835002935932e+31*cos(theta)**11 + 2.66361116548022e+29*cos(theta)**9 - 3.18889264906179e+27*cos(theta)**7 + 2.20285347468084e+25*cos(theta)**5 - 7.17775651574076e+22*cos(theta)**3 + 6.95968634364004e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl79_m11(theta, phi):
    return 6.49934641456728e-21*(1.0 - cos(theta)**2)**5.5*(1.38189115100115e+43*cos(theta)**68 - 2.00506244712141e+44*cos(theta)**66 + 1.38737385454046e+45*cos(theta)**64 - 6.09356359641301e+45*cos(theta)**62 + 1.90776966238692e+46*cos(theta)**60 - 4.53255342607362e+46*cos(theta)**58 + 8.49468346179104e+46*cos(theta)**56 - 1.28884852523726e+47*cos(theta)**54 + 1.61218727239032e+47*cos(theta)**52 - 1.68460230353787e+47*cos(theta)**50 + 1.4846315264992e+47*cos(theta)**48 - 1.11125704173265e+47*cos(theta)**46 + 7.09969776662525e+46*cos(theta)**44 - 3.88450785843117e+46*cos(theta)**42 + 1.82364300224059e+46*cos(theta)**40 - 7.35111907879927e+45*cos(theta)**38 + 2.54322672854128e+45*cos(theta)**36 - 7.53991924226356e+44*cos(theta)**34 + 1.91052154241638e+44*cos(theta)**32 - 4.1218733581493e+43*cos(theta)**30 + 7.53367609577707e+42*cos(theta)**28 - 1.15902709165801e+42*cos(theta)**26 + 1.48886879363183e+41*cos(theta)**24 - 1.58109960385681e+40*cos(theta)**22 + 1.37099853037134e+39*cos(theta)**20 - 9.55925580809372e+37*cos(theta)**18 + 5.25724708353105e+36*cos(theta)**16 - 2.2252897708068e+35*cos(theta)**14 + 7.02154539332241e+33*cos(theta)**12 - 1.58218503229525e+32*cos(theta)**10 + 2.3972500489322e+30*cos(theta)**8 - 2.23222485434325e+28*cos(theta)**6 + 1.10142673734042e+26*cos(theta)**4 - 2.15332695472223e+23*cos(theta)**2 + 6.95968634364004e+19)*cos(11*phi)

#@torch.jit.script
def Yl79_m12(theta, phi):
    return 8.26217772916405e-23*(1.0 - cos(theta)**2)**6*(9.39685982680782e+44*cos(theta)**67 - 1.32334121510013e+46*cos(theta)**65 + 8.87919266905896e+46*cos(theta)**63 - 3.77800942977607e+47*cos(theta)**61 + 1.14466179743215e+48*cos(theta)**59 - 2.6288809871227e+48*cos(theta)**57 + 4.75702273860298e+48*cos(theta)**55 - 6.95978203628121e+48*cos(theta)**53 + 8.38337381642964e+48*cos(theta)**51 - 8.42301151768936e+48*cos(theta)**49 + 7.12623132719618e+48*cos(theta)**47 - 5.11178239197018e+48*cos(theta)**45 + 3.12386701731511e+48*cos(theta)**43 - 1.63149330054109e+48*cos(theta)**41 + 7.29457200896235e+47*cos(theta)**39 - 2.79342524994372e+47*cos(theta)**37 + 9.15561622274861e+46*cos(theta)**35 - 2.56357254236961e+46*cos(theta)**33 + 6.11366893573241e+45*cos(theta)**31 - 1.23656200744479e+45*cos(theta)**29 + 2.10942930681758e+44*cos(theta)**27 - 3.01347043831083e+43*cos(theta)**25 + 3.5732851047164e+42*cos(theta)**23 - 3.47841912848499e+41*cos(theta)**21 + 2.74199706074267e+40*cos(theta)**19 - 1.72066604545687e+39*cos(theta)**17 + 8.41159533364969e+37*cos(theta)**15 - 3.11540567912951e+36*cos(theta)**13 + 8.42585447198689e+34*cos(theta)**11 - 1.58218503229525e+33*cos(theta)**9 + 1.91780003914576e+31*cos(theta)**7 - 1.33933491260595e+29*cos(theta)**5 + 4.40570694936168e+26*cos(theta)**3 - 4.30665390944446e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl79_m13(theta, phi):
    return 1.05235729970741e-24*(1.0 - cos(theta)**2)**6.5*(6.29589608396124e+46*cos(theta)**66 - 8.60171789815087e+47*cos(theta)**64 + 5.59389138150714e+48*cos(theta)**62 - 2.3045857521634e+49*cos(theta)**60 + 6.7535046048497e+49*cos(theta)**58 - 1.49846216265994e+50*cos(theta)**56 + 2.61636250623164e+50*cos(theta)**54 - 3.68868447922904e+50*cos(theta)**52 + 4.27552064637912e+50*cos(theta)**50 - 4.12727564366779e+50*cos(theta)**48 + 3.3493287237822e+50*cos(theta)**46 - 2.30030207638658e+50*cos(theta)**44 + 1.3432628174455e+50*cos(theta)**42 - 6.68912253221847e+49*cos(theta)**40 + 2.84488308349532e+49*cos(theta)**38 - 1.03356734247918e+49*cos(theta)**36 + 3.20446567796201e+48*cos(theta)**34 - 8.45978938981972e+47*cos(theta)**32 + 1.89523737007705e+47*cos(theta)**30 - 3.58602982158989e+46*cos(theta)**28 + 5.69545912840747e+45*cos(theta)**26 - 7.53367609577707e+44*cos(theta)**24 + 8.21855574084772e+43*cos(theta)**22 - 7.30468016981848e+42*cos(theta)**20 + 5.20979441541108e+41*cos(theta)**18 - 2.92513227727668e+40*cos(theta)**16 + 1.26173930004745e+39*cos(theta)**14 - 4.05002738286837e+37*cos(theta)**12 + 9.26843991918558e+35*cos(theta)**10 - 1.42396652906573e+34*cos(theta)**8 + 1.34246002740203e+32*cos(theta)**6 - 6.69667456302976e+29*cos(theta)**4 + 1.3217120848085e+27*cos(theta)**2 - 4.30665390944446e+23)*cos(13*phi)

#@torch.jit.script
def Yl79_m14(theta, phi):
    return 1.34322812256872e-26*(1.0 - cos(theta)**2)**7*(4.15529141541442e+48*cos(theta)**65 - 5.50509945481655e+49*cos(theta)**63 + 3.46821265653443e+50*cos(theta)**61 - 1.38275145129804e+51*cos(theta)**59 + 3.91703267081283e+51*cos(theta)**57 - 8.39138811089566e+51*cos(theta)**55 + 1.41283575336509e+52*cos(theta)**53 - 1.9181159291991e+52*cos(theta)**51 + 2.13776032318956e+52*cos(theta)**49 - 1.98109230896054e+52*cos(theta)**47 + 1.54069121293981e+52*cos(theta)**45 - 1.0121329136101e+52*cos(theta)**43 + 5.64170383327109e+51*cos(theta)**41 - 2.67564901288739e+51*cos(theta)**39 + 1.08105557172822e+51*cos(theta)**37 - 3.72084243292504e+50*cos(theta)**35 + 1.08951833050708e+50*cos(theta)**33 - 2.70713260474231e+49*cos(theta)**31 + 5.68571211023114e+48*cos(theta)**29 - 1.00408835004517e+48*cos(theta)**27 + 1.48081937338594e+47*cos(theta)**25 - 1.8080822629865e+46*cos(theta)**23 + 1.8080822629865e+45*cos(theta)**21 - 1.4609360339637e+44*cos(theta)**19 + 9.37762994773994e+42*cos(theta)**17 - 4.68021164364269e+41*cos(theta)**15 + 1.76643502006643e+40*cos(theta)**13 - 4.86003285944204e+38*cos(theta)**11 + 9.26843991918558e+36*cos(theta)**9 - 1.13917322325258e+35*cos(theta)**7 + 8.05476016441219e+32*cos(theta)**5 - 2.6786698252119e+30*cos(theta)**3 + 2.64342416961701e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl79_m15(theta, phi):
    return 1.71841941481227e-28*(1.0 - cos(theta)**2)**7.5*(2.70093942001937e+50*cos(theta)**64 - 3.46821265653443e+51*cos(theta)**62 + 2.115609720486e+52*cos(theta)**60 - 8.15823356265844e+52*cos(theta)**58 + 2.23270862236331e+53*cos(theta)**56 - 4.61526346099262e+53*cos(theta)**54 + 7.48802949283496e+53*cos(theta)**52 - 9.78239123891542e+53*cos(theta)**50 + 1.04750255836288e+54*cos(theta)**48 - 9.31113385211452e+53*cos(theta)**46 + 6.93311045822916e+53*cos(theta)**44 - 4.35217152852341e+53*cos(theta)**42 + 2.31309857164115e+53*cos(theta)**40 - 1.04350311502608e+53*cos(theta)**38 + 3.99990561539441e+52*cos(theta)**36 - 1.30229485152376e+52*cos(theta)**34 + 3.59541049067338e+51*cos(theta)**32 - 8.39211107470116e+50*cos(theta)**30 + 1.64885651196703e+50*cos(theta)**28 - 2.71103854512195e+49*cos(theta)**26 + 3.70204843346485e+48*cos(theta)**24 - 4.15858920486894e+47*cos(theta)**22 + 3.79697275227165e+46*cos(theta)**20 - 2.77577846453102e+45*cos(theta)**18 + 1.59419709111579e+44*cos(theta)**16 - 7.02031746546403e+42*cos(theta)**14 + 2.29636552608636e+41*cos(theta)**12 - 5.34603614538624e+39*cos(theta)**10 + 8.34159592726703e+37*cos(theta)**8 - 7.97421256276807e+35*cos(theta)**6 + 4.02738008220609e+33*cos(theta)**4 - 8.03600947563571e+30*cos(theta)**2 + 2.64342416961701e+27)*cos(15*phi)

#@torch.jit.script
def Yl79_m16(theta, phi):
    return 2.20382639925029e-30*(1.0 - cos(theta)**2)**8*(1.7286012288124e+52*cos(theta)**63 - 2.15029184705135e+53*cos(theta)**61 + 1.2693658322916e+54*cos(theta)**59 - 4.73177546634189e+54*cos(theta)**57 + 1.25031682852345e+55*cos(theta)**55 - 2.49224226893601e+55*cos(theta)**53 + 3.89377533627418e+55*cos(theta)**51 - 4.89119561945771e+55*cos(theta)**49 + 5.02801228014184e+55*cos(theta)**47 - 4.28312157197268e+55*cos(theta)**45 + 3.05056860162083e+55*cos(theta)**43 - 1.82791204197983e+55*cos(theta)**41 + 9.25239428656459e+54*cos(theta)**39 - 3.96531183709911e+54*cos(theta)**37 + 1.43996602154199e+54*cos(theta)**35 - 4.42780249518079e+53*cos(theta)**33 + 1.15053135701548e+53*cos(theta)**31 - 2.51763332241035e+52*cos(theta)**29 + 4.61679823350768e+51*cos(theta)**27 - 7.04870021731708e+50*cos(theta)**25 + 8.88491624031565e+49*cos(theta)**23 - 9.14889625071168e+48*cos(theta)**21 + 7.59394550454329e+47*cos(theta)**19 - 4.99640123615584e+46*cos(theta)**17 + 2.55071534578526e+45*cos(theta)**15 - 9.82844445164964e+43*cos(theta)**13 + 2.75563863130364e+42*cos(theta)**11 - 5.34603614538624e+40*cos(theta)**9 + 6.67327674181362e+38*cos(theta)**7 - 4.78452753766084e+36*cos(theta)**5 + 1.61095203288244e+34*cos(theta)**3 - 1.60720189512714e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl79_m17(theta, phi):
    return 2.83381496782678e-32*(1.0 - cos(theta)**2)**8.5*(1.08901877415181e+54*cos(theta)**62 - 1.31167802670132e+55*cos(theta)**60 + 7.48925841052045e+55*cos(theta)**58 - 2.69711201581488e+56*cos(theta)**56 + 6.876742556879e+56*cos(theta)**54 - 1.32088840253609e+57*cos(theta)**52 + 1.98582542149983e+57*cos(theta)**50 - 2.39668585353428e+57*cos(theta)**48 + 2.36316577166667e+57*cos(theta)**46 - 1.92740470738771e+57*cos(theta)**44 + 1.31174449869696e+57*cos(theta)**42 - 7.49443937211732e+56*cos(theta)**40 + 3.60843377176019e+56*cos(theta)**38 - 1.46716537972667e+56*cos(theta)**36 + 5.03988107539696e+55*cos(theta)**34 - 1.46117482340966e+55*cos(theta)**32 + 3.56664720674799e+54*cos(theta)**30 - 7.30113663499001e+53*cos(theta)**28 + 1.24653552304707e+53*cos(theta)**26 - 1.76217505432927e+52*cos(theta)**24 + 2.0435307352726e+51*cos(theta)**22 - 1.92126821264945e+50*cos(theta)**20 + 1.44284964586323e+49*cos(theta)**18 - 8.49388210146493e+47*cos(theta)**16 + 3.8260730186779e+46*cos(theta)**14 - 1.27769777871445e+45*cos(theta)**12 + 3.031202494434e+43*cos(theta)**10 - 4.81143253084762e+41*cos(theta)**8 + 4.67129371926953e+39*cos(theta)**6 - 2.39226376883042e+37*cos(theta)**4 + 4.83285609864731e+34*cos(theta)**2 - 1.60720189512714e+31)*cos(17*phi)

#@torch.jit.script
def Yl79_m18(theta, phi):
    return 3.65417866773758e-34*(1.0 - cos(theta)**2)**9*(6.75191639974123e+55*cos(theta)**61 - 7.87006816020793e+56*cos(theta)**59 + 4.34376987810186e+57*cos(theta)**57 - 1.51038272885633e+58*cos(theta)**55 + 3.71344098071466e+58*cos(theta)**53 - 6.86861969318765e+58*cos(theta)**51 + 9.92912710749915e+58*cos(theta)**49 - 1.15040920969645e+59*cos(theta)**47 + 1.08705625496667e+59*cos(theta)**45 - 8.48058071250591e+58*cos(theta)**43 + 5.50932689452722e+58*cos(theta)**41 - 2.99777574884693e+58*cos(theta)**39 + 1.37120483326887e+58*cos(theta)**37 - 5.28179536701602e+57*cos(theta)**35 + 1.71355956563497e+57*cos(theta)**33 - 4.67575943491092e+56*cos(theta)**31 + 1.0699941620244e+56*cos(theta)**29 - 2.0443182577972e+55*cos(theta)**27 + 3.24099235992239e+54*cos(theta)**25 - 4.22922013039025e+53*cos(theta)**23 + 4.49576761759972e+52*cos(theta)**21 - 3.84253642529891e+51*cos(theta)**19 + 2.59712936255381e+50*cos(theta)**17 - 1.35902113623439e+49*cos(theta)**15 + 5.35650222614905e+47*cos(theta)**13 - 1.53323733445734e+46*cos(theta)**11 + 3.031202494434e+44*cos(theta)**9 - 3.8491460246781e+42*cos(theta)**7 + 2.80277623156172e+40*cos(theta)**5 - 9.56905507532168e+37*cos(theta)**3 + 9.66571219729463e+34*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl79_m19(theta, phi):
    return 4.72619702651827e-36*(1.0 - cos(theta)**2)**9.5*(4.11866900384215e+57*cos(theta)**60 - 4.64334021452268e+58*cos(theta)**58 + 2.47594883051806e+59*cos(theta)**56 - 8.30710500870983e+59*cos(theta)**54 + 1.96812371977877e+60*cos(theta)**52 - 3.5029960435257e+60*cos(theta)**50 + 4.86527228267459e+60*cos(theta)**48 - 5.40692328557333e+60*cos(theta)**46 + 4.89175314735e+60*cos(theta)**44 - 3.64664970637754e+60*cos(theta)**42 + 2.25882402675616e+60*cos(theta)**40 - 1.1691325420503e+60*cos(theta)**38 + 5.07345788309483e+59*cos(theta)**36 - 1.84862837845561e+59*cos(theta)**34 + 5.65474656659539e+58*cos(theta)**32 - 1.44948542482238e+58*cos(theta)**30 + 3.10298306987075e+57*cos(theta)**28 - 5.51965929605245e+56*cos(theta)**26 + 8.10248089980599e+55*cos(theta)**24 - 9.72720629989757e+54*cos(theta)**22 + 9.44111199695941e+53*cos(theta)**20 - 7.30081920806792e+52*cos(theta)**18 + 4.41511991634147e+51*cos(theta)**16 - 2.03853170435158e+50*cos(theta)**14 + 6.96345289399377e+48*cos(theta)**12 - 1.68656106790308e+47*cos(theta)**10 + 2.7280822449906e+45*cos(theta)**8 - 2.69440221727467e+43*cos(theta)**6 + 1.40138811578086e+41*cos(theta)**4 - 2.8707165225965e+38*cos(theta)**2 + 9.66571219729463e+34)*cos(19*phi)

#@torch.jit.script
def Yl79_m20(theta, phi):
    return 6.132232325073e-38*(1.0 - cos(theta)**2)**10*(2.47120140230529e+59*cos(theta)**59 - 2.69313732442315e+60*cos(theta)**57 + 1.38653134509011e+61*cos(theta)**55 - 4.48583670470331e+61*cos(theta)**53 + 1.02342433428496e+62*cos(theta)**51 - 1.75149802176285e+62*cos(theta)**49 + 2.3353306956838e+62*cos(theta)**47 - 2.48718471136373e+62*cos(theta)**45 + 2.152371384834e+62*cos(theta)**43 - 1.53159287667857e+62*cos(theta)**41 + 9.03529610702464e+61*cos(theta)**39 - 4.44270365979115e+61*cos(theta)**37 + 1.82644483791414e+61*cos(theta)**35 - 6.28533648674906e+60*cos(theta)**33 + 1.80951890131053e+60*cos(theta)**31 - 4.34845627446715e+59*cos(theta)**29 + 8.68835259563811e+58*cos(theta)**27 - 1.43511141697364e+58*cos(theta)**25 + 1.94459541595344e+57*cos(theta)**23 - 2.13998538597747e+56*cos(theta)**21 + 1.88822239939188e+55*cos(theta)**19 - 1.31414745745223e+54*cos(theta)**17 + 7.06419186614635e+52*cos(theta)**15 - 2.85394438609222e+51*cos(theta)**13 + 8.35614347279252e+49*cos(theta)**11 - 1.68656106790308e+48*cos(theta)**9 + 2.18246579599248e+46*cos(theta)**7 - 1.6166413303648e+44*cos(theta)**5 + 5.60555246312344e+41*cos(theta)**3 - 5.74143304519301e+38*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl79_m21(theta, phi):
    return 7.98348648282659e-40*(1.0 - cos(theta)**2)**10.5*(1.45800882736012e+61*cos(theta)**58 - 1.5350882749212e+62*cos(theta)**56 + 7.62592239799562e+62*cos(theta)**54 - 2.37749345349275e+63*cos(theta)**52 + 5.2194641048533e+63*cos(theta)**50 - 8.58234030663797e+63*cos(theta)**48 + 1.09760542697139e+64*cos(theta)**46 - 1.11923312011368e+64*cos(theta)**44 + 9.2551969547862e+63*cos(theta)**42 - 6.27953079438213e+63*cos(theta)**40 + 3.52376548173961e+63*cos(theta)**38 - 1.64380035412272e+63*cos(theta)**36 + 6.39255693269948e+62*cos(theta)**34 - 2.07416104062719e+62*cos(theta)**32 + 5.60950859406263e+61*cos(theta)**30 - 1.26105231959547e+61*cos(theta)**28 + 2.34585520082229e+60*cos(theta)**26 - 3.58777854243409e+59*cos(theta)**24 + 4.4725694566929e+58*cos(theta)**22 - 4.49396931055268e+57*cos(theta)**20 + 3.58762255884458e+56*cos(theta)**18 - 2.23405067766878e+55*cos(theta)**16 + 1.05962877992195e+54*cos(theta)**14 - 3.71012770191988e+52*cos(theta)**12 + 9.19175782007178e+50*cos(theta)**10 - 1.51790496111277e+49*cos(theta)**8 + 1.52772605719474e+47*cos(theta)**6 - 8.083206651824e+44*cos(theta)**4 + 1.68166573893703e+42*cos(theta)**2 - 5.74143304519301e+38)*cos(21*phi)

#@torch.jit.script
def Yl79_m22(theta, phi):
    return 1.04308070205435e-41*(1.0 - cos(theta)**2)**11*(8.4564511986887e+62*cos(theta)**57 - 8.5964943395587e+63*cos(theta)**55 + 4.11799809491764e+64*cos(theta)**53 - 1.23629659581623e+65*cos(theta)**51 + 2.60973205242665e+65*cos(theta)**49 - 4.11952334718623e+65*cos(theta)**47 + 5.04898496406838e+65*cos(theta)**45 - 4.92462572850019e+65*cos(theta)**43 + 3.8871827210102e+65*cos(theta)**41 - 2.51181231775285e+65*cos(theta)**39 + 1.33903088306105e+65*cos(theta)**37 - 5.91768127484181e+64*cos(theta)**35 + 2.17346935711782e+64*cos(theta)**33 - 6.63731533000701e+63*cos(theta)**31 + 1.68285257821879e+63*cos(theta)**29 - 3.53094649486733e+62*cos(theta)**27 + 6.09922352213795e+61*cos(theta)**25 - 8.61066850184182e+60*cos(theta)**23 + 9.83965280472439e+59*cos(theta)**21 - 8.98793862110536e+58*cos(theta)**19 + 6.45772060592024e+57*cos(theta)**17 - 3.57448108427005e+56*cos(theta)**15 + 1.48348029189073e+55*cos(theta)**13 - 4.45215324230386e+53*cos(theta)**11 + 9.19175782007178e+51*cos(theta)**9 - 1.21432396889022e+50*cos(theta)**7 + 9.16635634316842e+47*cos(theta)**5 - 3.2332826607296e+45*cos(theta)**3 + 3.36333147787406e+42*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl79_m23(theta, phi):
    return 1.36798204400421e-43*(1.0 - cos(theta)**2)**11.5*(4.82017718325256e+64*cos(theta)**56 - 4.72807188675729e+65*cos(theta)**54 + 2.18253899030635e+66*cos(theta)**52 - 6.30511263866278e+66*cos(theta)**50 + 1.27876870568906e+67*cos(theta)**48 - 1.93617597317753e+67*cos(theta)**46 + 2.27204323383077e+67*cos(theta)**44 - 2.11758906325508e+67*cos(theta)**42 + 1.59374491561418e+67*cos(theta)**40 - 9.79606803923612e+66*cos(theta)**38 + 4.95441426732589e+66*cos(theta)**36 - 2.07118844619463e+66*cos(theta)**34 + 7.17244887848882e+65*cos(theta)**32 - 2.05756775230217e+65*cos(theta)**30 + 4.88027247683449e+64*cos(theta)**28 - 9.53355553614179e+63*cos(theta)**26 + 1.52480588053449e+63*cos(theta)**24 - 1.98045375542362e+62*cos(theta)**22 + 2.06632708899212e+61*cos(theta)**20 - 1.70770833801002e+60*cos(theta)**18 + 1.09781250300644e+59*cos(theta)**16 - 5.36172162640508e+57*cos(theta)**14 + 1.92852437945795e+56*cos(theta)**12 - 4.89736856653424e+54*cos(theta)**10 + 8.2725820380646e+52*cos(theta)**8 - 8.50026778223151e+50*cos(theta)**6 + 4.58317817158421e+48*cos(theta)**4 - 9.6998479821888e+45*cos(theta)**2 + 3.36333147787406e+42)*cos(23*phi)

#@torch.jit.script
def Yl79_m24(theta, phi):
    return 1.80122419108307e-45*(1.0 - cos(theta)**2)**12*(2.69929922262143e+66*cos(theta)**55 - 2.55315881884893e+67*cos(theta)**53 + 1.1349202749593e+68*cos(theta)**51 - 3.15255631933139e+68*cos(theta)**49 + 6.13808978730748e+68*cos(theta)**47 - 8.90640947661662e+68*cos(theta)**45 + 9.99699022885539e+68*cos(theta)**43 - 8.89387406567135e+68*cos(theta)**41 + 6.37497966245673e+68*cos(theta)**39 - 3.72250585490972e+68*cos(theta)**37 + 1.78358913623732e+68*cos(theta)**35 - 7.04204071706175e+67*cos(theta)**33 + 2.29518364111642e+67*cos(theta)**31 - 6.17270325690652e+66*cos(theta)**29 + 1.36647629351366e+66*cos(theta)**27 - 2.47872443939686e+65*cos(theta)**25 + 3.65953411328277e+64*cos(theta)**23 - 4.35699826193196e+63*cos(theta)**21 + 4.13265417798424e+62*cos(theta)**19 - 3.07387500841803e+61*cos(theta)**17 + 1.7565000048103e+60*cos(theta)**15 - 7.50641027696711e+58*cos(theta)**13 + 2.31422925534954e+57*cos(theta)**11 - 4.89736856653424e+55*cos(theta)**9 + 6.61806563045168e+53*cos(theta)**7 - 5.10016066933891e+51*cos(theta)**5 + 1.83327126863368e+49*cos(theta)**3 - 1.93996959643776e+46*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl79_m25(theta, phi):
    return 2.38160512752777e-47*(1.0 - cos(theta)**2)**12.5*(1.48461457244179e+68*cos(theta)**54 - 1.35317417398994e+69*cos(theta)**52 + 5.78809340229243e+69*cos(theta)**50 - 1.54475259647238e+70*cos(theta)**48 + 2.88490220003451e+70*cos(theta)**46 - 4.00788426447748e+70*cos(theta)**44 + 4.29870579840782e+70*cos(theta)**42 - 3.64648836692525e+70*cos(theta)**40 + 2.48624206835813e+70*cos(theta)**38 - 1.3773271663166e+70*cos(theta)**36 + 6.24256197683062e+69*cos(theta)**34 - 2.32387343663038e+69*cos(theta)**32 + 7.11506928746091e+68*cos(theta)**30 - 1.79008394450289e+68*cos(theta)**28 + 3.68948599248687e+67*cos(theta)**26 - 6.19681109849216e+66*cos(theta)**24 + 8.41692846055038e+65*cos(theta)**22 - 9.14969635005712e+64*cos(theta)**20 + 7.85204293817006e+63*cos(theta)**18 - 5.22558751431065e+62*cos(theta)**16 + 2.63475000721546e+61*cos(theta)**14 - 9.75833336005725e+59*cos(theta)**12 + 2.5456521808845e+58*cos(theta)**10 - 4.40763170988082e+56*cos(theta)**8 + 4.63264594131617e+54*cos(theta)**6 - 2.55008033466945e+52*cos(theta)**4 + 5.49981380590105e+49*cos(theta)**2 - 1.93996959643776e+46)*cos(25*phi)

#@torch.jit.script
def Yl79_m26(theta, phi):
    return 3.16284731617631e-49*(1.0 - cos(theta)**2)**13*(8.01691869118565e+69*cos(theta)**53 - 7.03650570474766e+70*cos(theta)**51 + 2.89404670114622e+71*cos(theta)**49 - 7.41481246306743e+71*cos(theta)**47 + 1.32705501201588e+72*cos(theta)**45 - 1.76346907637009e+72*cos(theta)**43 + 1.80545643533128e+72*cos(theta)**41 - 1.4585953467701e+72*cos(theta)**39 + 9.44771985976088e+71*cos(theta)**37 - 4.95837779873975e+71*cos(theta)**35 + 2.12247107212241e+71*cos(theta)**33 - 7.43639499721721e+70*cos(theta)**31 + 2.13452078623827e+70*cos(theta)**29 - 5.01223504460809e+69*cos(theta)**27 + 9.59266358046587e+68*cos(theta)**25 - 1.48723466363812e+68*cos(theta)**23 + 1.85172426132108e+67*cos(theta)**21 - 1.82993927001142e+66*cos(theta)**19 + 1.41336772887061e+65*cos(theta)**17 - 8.36094002289705e+63*cos(theta)**15 + 3.68865001010164e+62*cos(theta)**13 - 1.17100000320687e+61*cos(theta)**11 + 2.5456521808845e+59*cos(theta)**9 - 3.52610536790465e+57*cos(theta)**7 + 2.7795875647897e+55*cos(theta)**5 - 1.02003213386778e+53*cos(theta)**3 + 1.09996276118021e+50*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl79_m27(theta, phi):
    return 4.21975619835083e-51*(1.0 - cos(theta)**2)**13.5*(4.2489669063284e+71*cos(theta)**52 - 3.58861790942131e+72*cos(theta)**50 + 1.41808288356165e+73*cos(theta)**48 - 3.48496185764169e+73*cos(theta)**46 + 5.97174755407144e+73*cos(theta)**44 - 7.58291702839139e+73*cos(theta)**42 + 7.40237138485826e+73*cos(theta)**40 - 5.68852185240339e+73*cos(theta)**38 + 3.49565634811153e+73*cos(theta)**36 - 1.73543222955891e+73*cos(theta)**34 + 7.00415453800396e+72*cos(theta)**32 - 2.30528244913733e+72*cos(theta)**30 + 6.19011028009099e+71*cos(theta)**28 - 1.35330346204418e+71*cos(theta)**26 + 2.39816589511647e+70*cos(theta)**24 - 3.42063972636767e+69*cos(theta)**22 + 3.88862094877427e+68*cos(theta)**20 - 3.4768846130217e+67*cos(theta)**18 + 2.40272513908004e+66*cos(theta)**16 - 1.25414100343456e+65*cos(theta)**14 + 4.79524501313213e+63*cos(theta)**12 - 1.28810000352756e+62*cos(theta)**10 + 2.29108696279605e+60*cos(theta)**8 - 2.46827375753326e+58*cos(theta)**6 + 1.38979378239485e+56*cos(theta)**4 - 3.06009640160334e+53*cos(theta)**2 + 1.09996276118021e+50)*cos(27*phi)

#@torch.jit.script
def Yl79_m28(theta, phi):
    return 5.65709926188388e-53*(1.0 - cos(theta)**2)**14*(2.20946279129077e+73*cos(theta)**51 - 1.79430895471065e+74*cos(theta)**49 + 6.8067978410959e+74*cos(theta)**47 - 1.60308245451518e+75*cos(theta)**45 + 2.62756892379143e+75*cos(theta)**43 - 3.18482515192438e+75*cos(theta)**41 + 2.9609485539433e+75*cos(theta)**39 - 2.16163830391329e+75*cos(theta)**37 + 1.25843628532015e+75*cos(theta)**35 - 5.9004695805003e+74*cos(theta)**33 + 2.24132945216127e+74*cos(theta)**31 - 6.91584734741201e+73*cos(theta)**29 + 1.73323087842548e+73*cos(theta)**27 - 3.51858900131488e+72*cos(theta)**25 + 5.75559814827952e+71*cos(theta)**23 - 7.52540739800888e+70*cos(theta)**21 + 7.77724189754855e+69*cos(theta)**19 - 6.25839230343907e+68*cos(theta)**17 + 3.84436022252806e+67*cos(theta)**15 - 1.75579740480838e+66*cos(theta)**13 + 5.75429401575856e+64*cos(theta)**11 - 1.28810000352756e+63*cos(theta)**9 + 1.83286957023684e+61*cos(theta)**7 - 1.48096425451995e+59*cos(theta)**5 + 5.55917512957941e+56*cos(theta)**3 - 6.12019280320669e+53*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl79_m29(theta, phi):
    return 7.62248947429769e-55*(1.0 - cos(theta)**2)**14.5*(1.12682602355829e+75*cos(theta)**50 - 8.79211387808221e+75*cos(theta)**48 + 3.19919498531507e+76*cos(theta)**46 - 7.2138710453183e+76*cos(theta)**44 + 1.12985463723032e+77*cos(theta)**42 - 1.305778312289e+77*cos(theta)**40 + 1.15476993603789e+77*cos(theta)**38 - 7.99806172447917e+76*cos(theta)**36 + 4.40452699862052e+76*cos(theta)**34 - 1.9471549615651e+76*cos(theta)**32 + 6.94812130169993e+75*cos(theta)**30 - 2.00559573074948e+75*cos(theta)**28 + 4.67972337174879e+74*cos(theta)**26 - 8.7964725032872e+73*cos(theta)**24 + 1.32378757410429e+73*cos(theta)**22 - 1.58033555358187e+72*cos(theta)**20 + 1.47767596053422e+71*cos(theta)**18 - 1.06392669158464e+70*cos(theta)**16 + 5.76654033379209e+68*cos(theta)**14 - 2.28253662625089e+67*cos(theta)**12 + 6.32972341733441e+65*cos(theta)**10 - 1.1592900031748e+64*cos(theta)**8 + 1.28300869916579e+62*cos(theta)**6 - 7.40482127259977e+59*cos(theta)**4 + 1.66775253887382e+57*cos(theta)**2 - 6.12019280320669e+53)*cos(29*phi)

#@torch.jit.script
def Yl79_m30(theta, phi):
    return 1.03252026024309e-56*(1.0 - cos(theta)**2)**15*(5.63413011779145e+76*cos(theta)**49 - 4.22021466147946e+77*cos(theta)**47 + 1.47162969324493e+78*cos(theta)**45 - 3.17410325994005e+78*cos(theta)**43 + 4.74538947636733e+78*cos(theta)**41 - 5.22311324915599e+78*cos(theta)**39 + 4.38812575694398e+78*cos(theta)**37 - 2.8793022208125e+78*cos(theta)**35 + 1.49753917953098e+78*cos(theta)**33 - 6.23089587700832e+77*cos(theta)**31 + 2.08443639050998e+77*cos(theta)**29 - 5.61566804609855e+76*cos(theta)**27 + 1.21672807665469e+76*cos(theta)**25 - 2.11115340078893e+75*cos(theta)**23 + 2.91233266302944e+74*cos(theta)**21 - 3.16067110716373e+73*cos(theta)**19 + 2.6598167289616e+72*cos(theta)**17 - 1.70228270653543e+71*cos(theta)**15 + 8.07315646730893e+69*cos(theta)**13 - 2.73904395150107e+68*cos(theta)**11 + 6.32972341733441e+66*cos(theta)**9 - 9.27432002539841e+64*cos(theta)**7 + 7.69805219499472e+62*cos(theta)**5 - 2.96192850903991e+60*cos(theta)**3 + 3.33550507774765e+57*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl79_m31(theta, phi):
    return 1.40638491539987e-58*(1.0 - cos(theta)**2)**15.5*(2.76072375771781e+78*cos(theta)**48 - 1.98350089089535e+79*cos(theta)**46 + 6.6223336196022e+79*cos(theta)**44 - 1.36486440177422e+80*cos(theta)**42 + 1.94560968531061e+80*cos(theta)**40 - 2.03701416717084e+80*cos(theta)**38 + 1.62360653006927e+80*cos(theta)**36 - 1.00775577728438e+80*cos(theta)**34 + 4.94187929245223e+79*cos(theta)**32 - 1.93157772187258e+79*cos(theta)**30 + 6.04486553247894e+78*cos(theta)**28 - 1.51623037244661e+78*cos(theta)**26 + 3.04182019163671e+77*cos(theta)**24 - 4.85565282181453e+76*cos(theta)**22 + 6.11589859236182e+75*cos(theta)**20 - 6.00527510361109e+74*cos(theta)**18 + 4.52168843923473e+73*cos(theta)**16 - 2.55342405980314e+72*cos(theta)**14 + 1.04951034075016e+71*cos(theta)**12 - 3.01294834665118e+69*cos(theta)**10 + 5.69675107560097e+67*cos(theta)**8 - 6.49202401777888e+65*cos(theta)**6 + 3.84902609749736e+63*cos(theta)**4 - 8.88578552711973e+60*cos(theta)**2 + 3.33550507774765e+57)*cos(31*phi)

#@torch.jit.script
def Yl79_m32(theta, phi):
    return 1.92673546544391e-60*(1.0 - cos(theta)**2)**16*(1.32514740370455e+80*cos(theta)**47 - 9.12410409811859e+80*cos(theta)**45 + 2.91382679262497e+81*cos(theta)**43 - 5.73243048745174e+81*cos(theta)**41 + 7.78243874124242e+81*cos(theta)**39 - 7.74065383524918e+81*cos(theta)**37 + 5.84498350824938e+81*cos(theta)**35 - 3.42636964276688e+81*cos(theta)**33 + 1.58140137358471e+81*cos(theta)**31 - 5.79473316561774e+80*cos(theta)**29 + 1.6925623490941e+80*cos(theta)**27 - 3.94219896836118e+79*cos(theta)**25 + 7.30036845992811e+78*cos(theta)**23 - 1.0682436207992e+78*cos(theta)**21 + 1.22317971847236e+77*cos(theta)**19 - 1.08094951865e+76*cos(theta)**17 + 7.23470150277556e+74*cos(theta)**15 - 3.5747936837244e+73*cos(theta)**13 + 1.25941240890019e+72*cos(theta)**11 - 3.01294834665118e+70*cos(theta)**9 + 4.55740086048078e+68*cos(theta)**7 - 3.89521441066733e+66*cos(theta)**5 + 1.53961043899895e+64*cos(theta)**3 - 1.77715710542395e+61*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl79_m33(theta, phi):
    return 2.6556091185738e-62*(1.0 - cos(theta)**2)**16.5*(6.22819279741139e+81*cos(theta)**46 - 4.10584684415337e+82*cos(theta)**44 + 1.25294552082874e+83*cos(theta)**42 - 2.35029649985521e+83*cos(theta)**40 + 3.03515110908455e+83*cos(theta)**38 - 2.86404191904219e+83*cos(theta)**36 + 2.04574422788728e+83*cos(theta)**34 - 1.13070198211307e+83*cos(theta)**32 + 4.90234425811261e+82*cos(theta)**30 - 1.68047261802914e+82*cos(theta)**28 + 4.56991834255408e+81*cos(theta)**26 - 9.85549742090295e+80*cos(theta)**24 + 1.67908474578347e+80*cos(theta)**22 - 2.24331160367831e+79*cos(theta)**20 + 2.32404146509749e+78*cos(theta)**18 - 1.83761418170499e+77*cos(theta)**16 + 1.08520522541633e+76*cos(theta)**14 - 4.64723178884171e+74*cos(theta)**12 + 1.38535364979021e+73*cos(theta)**10 - 2.71165351198606e+71*cos(theta)**8 + 3.19018060233654e+69*cos(theta)**6 - 1.94760720533367e+67*cos(theta)**4 + 4.61883131699684e+64*cos(theta)**2 - 1.77715710542395e+61)*cos(33*phi)

#@torch.jit.script
def Yl79_m34(theta, phi):
    return 3.68337565752144e-64*(1.0 - cos(theta)**2)**17*(2.86496868680924e+83*cos(theta)**45 - 1.80657261142748e+84*cos(theta)**43 + 5.26237118748069e+84*cos(theta)**41 - 9.40118599942085e+84*cos(theta)**39 + 1.15335742145213e+85*cos(theta)**37 - 1.03105509085519e+85*cos(theta)**35 + 6.95553037481676e+84*cos(theta)**33 - 3.61824634276182e+84*cos(theta)**31 + 1.47070327743378e+84*cos(theta)**29 - 4.7053233304816e+83*cos(theta)**27 + 1.18817876906406e+83*cos(theta)**25 - 2.36531938101671e+82*cos(theta)**23 + 3.69398644072362e+81*cos(theta)**21 - 4.48662320735663e+80*cos(theta)**19 + 4.18327463717548e+79*cos(theta)**17 - 2.94018269072799e+78*cos(theta)**15 + 1.51928731558287e+77*cos(theta)**13 - 5.57667814661006e+75*cos(theta)**11 + 1.38535364979021e+74*cos(theta)**9 - 2.16932280958885e+72*cos(theta)**7 + 1.91410836140193e+70*cos(theta)**5 - 7.79042882133466e+67*cos(theta)**3 + 9.23766263399367e+64*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl79_m35(theta, phi):
    return 5.14265429953116e-66*(1.0 - cos(theta)**2)**17.5*(1.28923590906416e+85*cos(theta)**44 - 7.76826222913817e+85*cos(theta)**42 + 2.15757218686708e+86*cos(theta)**40 - 3.66646253977413e+86*cos(theta)**38 + 4.26742245937287e+86*cos(theta)**36 - 3.60869281799317e+86*cos(theta)**34 + 2.29532502368953e+86*cos(theta)**32 - 1.12165636625616e+86*cos(theta)**30 + 4.26503950455797e+85*cos(theta)**28 - 1.27043729923003e+85*cos(theta)**26 + 2.97044692266015e+84*cos(theta)**24 - 5.44023457633843e+83*cos(theta)**22 + 7.75737152551961e+82*cos(theta)**20 - 8.5245840939776e+81*cos(theta)**18 + 7.11156688319832e+80*cos(theta)**16 - 4.41027403609198e+79*cos(theta)**14 + 1.97507351025773e+78*cos(theta)**12 - 6.13434596127106e+76*cos(theta)**10 + 1.24681828481119e+75*cos(theta)**8 - 1.51852596671219e+73*cos(theta)**6 + 9.57054180700963e+70*cos(theta)**4 - 2.3371286464004e+68*cos(theta)**2 + 9.23766263399367e+64)*cos(35*phi)

#@torch.jit.script
def Yl79_m36(theta, phi):
    return 7.22956343354814e-68*(1.0 - cos(theta)**2)**18*(5.67263799988229e+86*cos(theta)**43 - 3.26267013623803e+87*cos(theta)**41 + 8.63028874746834e+87*cos(theta)**39 - 1.39325576511417e+88*cos(theta)**37 + 1.53627208537423e+88*cos(theta)**35 - 1.22695555811768e+88*cos(theta)**33 + 7.3450400758065e+87*cos(theta)**31 - 3.36496909876849e+87*cos(theta)**29 + 1.19421106127623e+87*cos(theta)**27 - 3.30313697799809e+86*cos(theta)**25 + 7.12907261438436e+85*cos(theta)**23 - 1.19685160679445e+85*cos(theta)**21 + 1.55147430510392e+84*cos(theta)**19 - 1.53442513691597e+83*cos(theta)**17 + 1.13785070131173e+82*cos(theta)**15 - 6.17438365052878e+80*cos(theta)**13 + 2.37008821230927e+79*cos(theta)**11 - 6.13434596127106e+77*cos(theta)**9 + 9.97454627848953e+75*cos(theta)**7 - 9.11115580027317e+73*cos(theta)**5 + 3.82821672280385e+71*cos(theta)**3 - 4.6742572928008e+68*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl79_m37(theta, phi):
    return 1.02364377621677e-69*(1.0 - cos(theta)**2)**18.5*(2.43923433994938e+88*cos(theta)**42 - 1.33769475585759e+89*cos(theta)**40 + 3.36581261151265e+89*cos(theta)**38 - 5.15504633092243e+89*cos(theta)**36 + 5.37695229880982e+89*cos(theta)**34 - 4.04895334178833e+89*cos(theta)**32 + 2.27696242350001e+89*cos(theta)**30 - 9.75841038642863e+88*cos(theta)**28 + 3.22436986544582e+88*cos(theta)**26 - 8.25784244499522e+87*cos(theta)**24 + 1.6396867013084e+87*cos(theta)**22 - 2.51338837426835e+86*cos(theta)**20 + 2.94780117969745e+85*cos(theta)**18 - 2.60852273275714e+84*cos(theta)**16 + 1.7067760519676e+83*cos(theta)**14 - 8.02669874568741e+81*cos(theta)**12 + 2.6070970335402e+80*cos(theta)**10 - 5.52091136514396e+78*cos(theta)**8 + 6.98218239494267e+76*cos(theta)**6 - 4.55557790013658e+74*cos(theta)**4 + 1.14846501684116e+72*cos(theta)**2 - 4.6742572928008e+68)*cos(37*phi)

#@torch.jit.script
def Yl79_m38(theta, phi):
    return 1.46026364875154e-71*(1.0 - cos(theta)**2)**19*(1.02447842277874e+90*cos(theta)**41 - 5.35077902343037e+90*cos(theta)**39 + 1.27900879237481e+91*cos(theta)**37 - 1.85581667913207e+91*cos(theta)**35 + 1.82816378159534e+91*cos(theta)**33 - 1.29566506937227e+91*cos(theta)**31 + 6.83088727050004e+90*cos(theta)**29 - 2.73235490820002e+90*cos(theta)**27 + 8.38336165015914e+89*cos(theta)**25 - 1.98188218679885e+89*cos(theta)**23 + 3.60731074287849e+88*cos(theta)**21 - 5.02677674853671e+87*cos(theta)**19 + 5.30604212345541e+86*cos(theta)**17 - 4.17363637241143e+85*cos(theta)**15 + 2.38948647275464e+84*cos(theta)**13 - 9.63203849482489e+82*cos(theta)**11 + 2.6070970335402e+81*cos(theta)**9 - 4.41672909211516e+79*cos(theta)**7 + 4.1893094369656e+77*cos(theta)**5 - 1.82223116005463e+75*cos(theta)**3 + 2.29693003368231e+72*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl79_m39(theta, phi):
    return 2.09941522393326e-73*(1.0 - cos(theta)**2)**19.5*(4.20036153339284e+91*cos(theta)**40 - 2.08680381913784e+92*cos(theta)**38 + 4.73233253178679e+92*cos(theta)**36 - 6.49535837696226e+92*cos(theta)**34 + 6.03294047926461e+92*cos(theta)**32 - 4.01656171505403e+92*cos(theta)**30 + 1.98095730844501e+92*cos(theta)**28 - 7.37735825214005e+91*cos(theta)**26 + 2.09584041253979e+91*cos(theta)**24 - 4.55832902963736e+90*cos(theta)**22 + 7.57535256004482e+89*cos(theta)**20 - 9.55087582221975e+88*cos(theta)**18 + 9.0202716098742e+87*cos(theta)**16 - 6.26045455861715e+86*cos(theta)**14 + 3.10633241458103e+85*cos(theta)**12 - 1.05952423443074e+84*cos(theta)**10 + 2.34638733018618e+82*cos(theta)**8 - 3.09171036448062e+80*cos(theta)**6 + 2.0946547184828e+78*cos(theta)**4 - 5.4666934801639e+75*cos(theta)**2 + 2.29693003368231e+72)*cos(39*phi)

#@torch.jit.script
def Yl79_m40(theta, phi):
    return 3.04295034661076e-75*(1.0 - cos(theta)**2)**20*(1.68014461335714e+93*cos(theta)**39 - 7.92985451272381e+93*cos(theta)**37 + 1.70363971144324e+94*cos(theta)**35 - 2.20842184816717e+94*cos(theta)**33 + 1.93054095336468e+94*cos(theta)**31 - 1.20496851451621e+94*cos(theta)**29 + 5.54668046364603e+93*cos(theta)**27 - 1.91811314555641e+93*cos(theta)**25 + 5.03001699009549e+92*cos(theta)**23 - 1.00283238652022e+92*cos(theta)**21 + 1.51507051200896e+91*cos(theta)**19 - 1.71915764799955e+90*cos(theta)**17 + 1.44324345757987e+89*cos(theta)**15 - 8.76463638206401e+87*cos(theta)**13 + 3.72759889749723e+86*cos(theta)**11 - 1.05952423443074e+85*cos(theta)**9 + 1.87710986414895e+83*cos(theta)**7 - 1.85502621868837e+81*cos(theta)**5 + 8.37861887393121e+78*cos(theta)**3 - 1.09333869603278e+76*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl79_m41(theta, phi):
    return 4.44807333974679e-77*(1.0 - cos(theta)**2)**20.5*(6.55256399209283e+94*cos(theta)**38 - 2.93404616970781e+95*cos(theta)**36 + 5.96273899005135e+95*cos(theta)**34 - 7.28779209895165e+95*cos(theta)**32 + 5.9846769554305e+95*cos(theta)**30 - 3.494408692097e+95*cos(theta)**28 + 1.49760372518443e+95*cos(theta)**26 - 4.79528286389103e+94*cos(theta)**24 + 1.15690390772196e+94*cos(theta)**22 - 2.10594801169246e+93*cos(theta)**20 + 2.87863397281703e+92*cos(theta)**18 - 2.92256800159924e+91*cos(theta)**16 + 2.16486518636981e+90*cos(theta)**14 - 1.13940272966832e+89*cos(theta)**12 + 4.10035878724696e+87*cos(theta)**10 - 9.53571810987664e+85*cos(theta)**8 + 1.31397690490426e+84*cos(theta)**6 - 9.27513109344185e+81*cos(theta)**4 + 2.51358566217936e+79*cos(theta)**2 - 1.09333869603278e+76)*cos(41*phi)

#@torch.jit.script
def Yl79_m42(theta, phi):
    return 6.55975253152346e-79*(1.0 - cos(theta)**2)**21*(2.48997431699528e+96*cos(theta)**37 - 1.05625662109481e+97*cos(theta)**35 + 2.02733125661746e+97*cos(theta)**33 - 2.33209347166453e+97*cos(theta)**31 + 1.79540308662915e+97*cos(theta)**29 - 9.78434433787161e+96*cos(theta)**27 + 3.89376968547952e+96*cos(theta)**25 - 1.15086788733385e+96*cos(theta)**23 + 2.54518859698832e+95*cos(theta)**21 - 4.21189602338492e+94*cos(theta)**19 + 5.18154115107066e+93*cos(theta)**17 - 4.67610880255879e+92*cos(theta)**15 + 3.03081126091773e+91*cos(theta)**13 - 1.36728327560198e+90*cos(theta)**11 + 4.10035878724696e+88*cos(theta)**9 - 7.62857448790131e+86*cos(theta)**7 + 7.88386142942557e+84*cos(theta)**5 - 3.71005243737674e+82*cos(theta)**3 + 5.02717132435872e+79*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl79_m43(theta, phi):
    return 9.76352580488884e-81*(1.0 - cos(theta)**2)**21.5*(9.21290497288252e+97*cos(theta)**36 - 3.69689817383184e+98*cos(theta)**34 + 6.69019314683762e+98*cos(theta)**32 - 7.22948976216004e+98*cos(theta)**30 + 5.20666895122453e+98*cos(theta)**28 - 2.64177297122533e+98*cos(theta)**26 + 9.73442421369879e+97*cos(theta)**24 - 2.64699614086785e+97*cos(theta)**22 + 5.34489605367546e+96*cos(theta)**20 - 8.00260244443135e+95*cos(theta)**18 + 8.80861995682012e+94*cos(theta)**16 - 7.01416320383818e+93*cos(theta)**14 + 3.94005463919305e+92*cos(theta)**12 - 1.50401160316218e+91*cos(theta)**10 + 3.69032290852226e+89*cos(theta)**8 - 5.34000214153092e+87*cos(theta)**6 + 3.94193071471278e+85*cos(theta)**4 - 1.11301573121302e+83*cos(theta)**2 + 5.02717132435872e+79)*cos(43*phi)

#@torch.jit.script
def Yl79_m44(theta, phi):
    return 1.46724579092669e-82*(1.0 - cos(theta)**2)**22*(3.31664579023771e+99*cos(theta)**35 - 1.25694537910283e+100*cos(theta)**33 + 2.14086180698804e+100*cos(theta)**31 - 2.16884692864801e+100*cos(theta)**29 + 1.45786730634287e+100*cos(theta)**27 - 6.86860972518587e+99*cos(theta)**25 + 2.33626181128771e+99*cos(theta)**23 - 5.82339150990927e+98*cos(theta)**21 + 1.06897921073509e+98*cos(theta)**19 - 1.44046843999764e+97*cos(theta)**17 + 1.40937919309122e+96*cos(theta)**15 - 9.81982848537345e+94*cos(theta)**13 + 4.72806556703166e+93*cos(theta)**11 - 1.50401160316218e+92*cos(theta)**9 + 2.95225832681781e+90*cos(theta)**7 - 3.20400128491855e+88*cos(theta)**5 + 1.57677228588511e+86*cos(theta)**3 - 2.22603146242604e+83*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl79_m45(theta, phi):
    return 2.22719379292105e-84*(1.0 - cos(theta)**2)**22.5*(1.1608260265832e+101*cos(theta)**34 - 4.14791975103932e+101*cos(theta)**32 + 6.63667160166292e+101*cos(theta)**30 - 6.28965609307924e+101*cos(theta)**28 + 3.93624172712575e+101*cos(theta)**26 - 1.71715243129647e+101*cos(theta)**24 + 5.37340216596173e+100*cos(theta)**22 - 1.22291221708095e+100*cos(theta)**20 + 2.03106050039668e+99*cos(theta)**18 - 2.44879634799599e+98*cos(theta)**16 + 2.11406878963683e+97*cos(theta)**14 - 1.27657770309855e+96*cos(theta)**12 + 5.20087212373483e+94*cos(theta)**10 - 1.35361044284596e+93*cos(theta)**8 + 2.06658082877247e+91*cos(theta)**6 - 1.60200064245928e+89*cos(theta)**4 + 4.73031685765534e+86*cos(theta)**2 - 2.22603146242604e+83)*cos(45*phi)

#@torch.jit.script
def Yl79_m46(theta, phi):
    return 3.41635932509725e-86*(1.0 - cos(theta)**2)**23*(3.94680849038287e+102*cos(theta)**33 - 1.32733432033258e+103*cos(theta)**31 + 1.99100148049888e+103*cos(theta)**29 - 1.76110370606219e+103*cos(theta)**27 + 1.02342284905269e+103*cos(theta)**25 - 4.12116583511152e+102*cos(theta)**23 + 1.18214847651158e+102*cos(theta)**21 - 2.44582443416189e+101*cos(theta)**19 + 3.65590890071402e+100*cos(theta)**17 - 3.91807415679359e+99*cos(theta)**15 + 2.95969630549156e+98*cos(theta)**13 - 1.53189324371826e+97*cos(theta)**11 + 5.20087212373483e+95*cos(theta)**9 - 1.08288835427677e+94*cos(theta)**7 + 1.23994849726348e+92*cos(theta)**5 - 6.4080025698371e+89*cos(theta)**3 + 9.46063371531068e+86*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl79_m47(theta, phi):
    return 5.29811401508428e-88*(1.0 - cos(theta)**2)**23.5*(1.30244680182635e+104*cos(theta)**32 - 4.11473639303101e+104*cos(theta)**30 + 5.77390429344674e+104*cos(theta)**28 - 4.7549800063679e+104*cos(theta)**26 + 2.55855712263174e+104*cos(theta)**24 - 9.4786814207565e+103*cos(theta)**22 + 2.48251180067432e+103*cos(theta)**20 - 4.6470664249076e+102*cos(theta)**18 + 6.21504513121383e+101*cos(theta)**16 - 5.87711123519038e+100*cos(theta)**14 + 3.84760519713903e+99*cos(theta)**12 - 1.68508256809008e+98*cos(theta)**10 + 4.68078491136135e+96*cos(theta)**8 - 7.5802184799374e+94*cos(theta)**6 + 6.1997424863174e+92*cos(theta)**4 - 1.92240077095113e+90*cos(theta)**2 + 9.46063371531068e+86)*cos(47*phi)

#@torch.jit.script
def Yl79_m48(theta, phi):
    return 8.31083098762117e-90*(1.0 - cos(theta)**2)**24*(4.16782976584431e+105*cos(theta)**31 - 1.2344209179093e+106*cos(theta)**29 + 1.61669320216509e+106*cos(theta)**27 - 1.23629480165565e+106*cos(theta)**25 + 6.14053709431616e+105*cos(theta)**23 - 2.08530991256643e+105*cos(theta)**21 + 4.96502360134864e+104*cos(theta)**19 - 8.36471956483367e+103*cos(theta)**17 + 9.94407220994213e+102*cos(theta)**15 - 8.22795572926653e+101*cos(theta)**13 + 4.61712623656683e+100*cos(theta)**11 - 1.68508256809008e+99*cos(theta)**9 + 3.74462792908908e+97*cos(theta)**7 - 4.54813108796244e+95*cos(theta)**5 + 2.47989699452696e+93*cos(theta)**3 - 3.84480154190226e+90*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl79_m49(theta, phi):
    return 1.31934573863126e-91*(1.0 - cos(theta)**2)**24.5*(1.29202722741174e+107*cos(theta)**30 - 3.57982066193698e+107*cos(theta)**28 + 4.36507164584573e+107*cos(theta)**26 - 3.09073700413914e+107*cos(theta)**24 + 1.41232353169272e+107*cos(theta)**22 - 4.3791508163895e+106*cos(theta)**20 + 9.43354484256242e+105*cos(theta)**18 - 1.42200232602172e+105*cos(theta)**16 + 1.49161083149132e+104*cos(theta)**14 - 1.06963424480465e+103*cos(theta)**12 + 5.07883886022352e+101*cos(theta)**10 - 1.51657431128108e+100*cos(theta)**8 + 2.62123955036235e+98*cos(theta)**6 - 2.27406554398122e+96*cos(theta)**4 + 7.43969098358088e+93*cos(theta)**2 - 3.84480154190226e+90)*cos(49*phi)

#@torch.jit.script
def Yl79_m50(theta, phi):
    return 2.12081670805348e-93*(1.0 - cos(theta)**2)**25*(3.87608168223521e+108*cos(theta)**29 - 1.00234978534235e+109*cos(theta)**27 + 1.13491862791989e+109*cos(theta)**25 - 7.41776880993393e+108*cos(theta)**23 + 3.10711176972398e+108*cos(theta)**21 - 8.758301632779e+107*cos(theta)**19 + 1.69803807166124e+107*cos(theta)**17 - 2.27520372163476e+106*cos(theta)**15 + 2.08825516408785e+105*cos(theta)**13 - 1.28356109376558e+104*cos(theta)**11 + 5.07883886022352e+102*cos(theta)**9 - 1.21325944902486e+101*cos(theta)**7 + 1.57274373021741e+99*cos(theta)**5 - 9.09626217592488e+96*cos(theta)**3 + 1.48793819671618e+94*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl79_m51(theta, phi):
    return 3.45408054887072e-95*(1.0 - cos(theta)**2)**25.5*(1.12406368784821e+110*cos(theta)**28 - 2.70634442042436e+110*cos(theta)**26 + 2.83729656979973e+110*cos(theta)**24 - 1.7060868262848e+110*cos(theta)**22 + 6.52493471642036e+109*cos(theta)**20 - 1.66407731022801e+109*cos(theta)**18 + 2.8866647218241e+108*cos(theta)**16 - 3.41280558245214e+107*cos(theta)**14 + 2.7147317133142e+106*cos(theta)**12 - 1.41191720314214e+105*cos(theta)**10 + 4.57095497420116e+103*cos(theta)**8 - 8.49281614317403e+101*cos(theta)**6 + 7.86371865108706e+99*cos(theta)**4 - 2.72887865277747e+97*cos(theta)**2 + 1.48793819671618e+94)*cos(51*phi)

#@torch.jit.script
def Yl79_m52(theta, phi):
    return 5.70318943991758e-97*(1.0 - cos(theta)**2)**26*(3.14737832597499e+111*cos(theta)**27 - 7.03649549310332e+111*cos(theta)**25 + 6.80951176751934e+111*cos(theta)**23 - 3.75339101782657e+111*cos(theta)**21 + 1.30498694328407e+111*cos(theta)**19 - 2.99533915841042e+110*cos(theta)**17 + 4.61866355491856e+109*cos(theta)**15 - 4.77792781543299e+108*cos(theta)**13 + 3.25767805597704e+107*cos(theta)**11 - 1.41191720314214e+106*cos(theta)**9 + 3.65676397936093e+104*cos(theta)**7 - 5.09568968590442e+102*cos(theta)**5 + 3.14548746043483e+100*cos(theta)**3 - 5.45775730555493e+97*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl79_m53(theta, phi):
    return 9.55320175784028e-99*(1.0 - cos(theta)**2)**26.5*(8.49792148013247e+112*cos(theta)**26 - 1.75912387327583e+113*cos(theta)**24 + 1.56618770652945e+113*cos(theta)**22 - 7.88212113743579e+112*cos(theta)**20 + 2.47947519223974e+112*cos(theta)**18 - 5.09207656929771e+111*cos(theta)**16 + 6.92799533237784e+110*cos(theta)**14 - 6.21130616006289e+109*cos(theta)**12 + 3.58344586157474e+108*cos(theta)**10 - 1.27072548282792e+107*cos(theta)**8 + 2.55973478555265e+105*cos(theta)**6 - 2.54784484295221e+103*cos(theta)**4 + 9.43646238130448e+100*cos(theta)**2 - 5.45775730555493e+97)*cos(53*phi)

#@torch.jit.script
def Yl79_m54(theta, phi):
    return 1.62456261699261e-100*(1.0 - cos(theta)**2)**27*(2.20945958483444e+114*cos(theta)**25 - 4.22189729586199e+114*cos(theta)**23 + 3.44561295436479e+114*cos(theta)**21 - 1.57642422748716e+114*cos(theta)**19 + 4.46305534603152e+113*cos(theta)**17 - 8.14732251087634e+112*cos(theta)**15 + 9.69919346532898e+111*cos(theta)**13 - 7.45356739207547e+110*cos(theta)**11 + 3.58344586157474e+109*cos(theta)**9 - 1.01658038626234e+108*cos(theta)**7 + 1.53584087133159e+106*cos(theta)**5 - 1.01913793718088e+104*cos(theta)**3 + 1.8872924762609e+101*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl79_m55(theta, phi):
    return 2.80681670039947e-102*(1.0 - cos(theta)**2)**27.5*(5.52364896208611e+115*cos(theta)**24 - 9.71036378048259e+115*cos(theta)**22 + 7.23578720416606e+115*cos(theta)**20 - 2.9952060322256e+115*cos(theta)**18 + 7.58719408825359e+114*cos(theta)**16 - 1.22209837663145e+114*cos(theta)**14 + 1.26089515049277e+113*cos(theta)**12 - 8.19892413128302e+111*cos(theta)**10 + 3.22510127541727e+110*cos(theta)**8 - 7.11606270383637e+108*cos(theta)**6 + 7.67920435665796e+106*cos(theta)**4 - 3.05741381154265e+104*cos(theta)**2 + 1.8872924762609e+101)*cos(55*phi)

#@torch.jit.script
def Yl79_m56(theta, phi):
    return 4.9310743043671e-104*(1.0 - cos(theta)**2)**28*(1.32567575090067e+117*cos(theta)**23 - 2.13628003170617e+117*cos(theta)**21 + 1.44715744083321e+117*cos(theta)**19 - 5.39137085800608e+116*cos(theta)**17 + 1.21395105412057e+116*cos(theta)**15 - 1.71093772728403e+115*cos(theta)**13 + 1.51307418059132e+114*cos(theta)**11 - 8.19892413128302e+112*cos(theta)**9 + 2.58008102033382e+111*cos(theta)**7 - 4.26963762230182e+109*cos(theta)**5 + 3.07168174266318e+107*cos(theta)**3 - 6.1148276230853e+104*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl79_m57(theta, phi):
    return 8.81674285596453e-106*(1.0 - cos(theta)**2)**28.5*(3.04905422707153e+118*cos(theta)**22 - 4.48618806658295e+118*cos(theta)**20 + 2.7495991375831e+118*cos(theta)**18 - 9.16533045861034e+117*cos(theta)**16 + 1.82092658118086e+117*cos(theta)**14 - 2.22421904546924e+116*cos(theta)**12 + 1.66438159865045e+115*cos(theta)**10 - 7.37903171815471e+113*cos(theta)**8 + 1.80605671423367e+112*cos(theta)**6 - 2.13481881115091e+110*cos(theta)**4 + 9.21504522798955e+107*cos(theta)**2 - 6.1148276230853e+104)*cos(57*phi)

#@torch.jit.script
def Yl79_m58(theta, phi):
    return 1.60596675451142e-107*(1.0 - cos(theta)**2)**29*(6.70791929955737e+119*cos(theta)**21 - 8.97237613316591e+119*cos(theta)**19 + 4.94927844764958e+119*cos(theta)**17 - 1.46645287337765e+119*cos(theta)**15 + 2.54929721365321e+118*cos(theta)**13 - 2.66906285456309e+117*cos(theta)**11 + 1.66438159865045e+116*cos(theta)**9 - 5.90322537452377e+114*cos(theta)**7 + 1.0836340285402e+113*cos(theta)**5 - 8.53927524460365e+110*cos(theta)**3 + 1.84300904559791e+108*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl79_m59(theta, phi):
    return 2.98323427469855e-109*(1.0 - cos(theta)**2)**29.5*(1.40866305290705e+121*cos(theta)**20 - 1.70475146530152e+121*cos(theta)**18 + 8.41377336100429e+120*cos(theta)**16 - 2.19967931006648e+120*cos(theta)**14 + 3.31408637774917e+119*cos(theta)**12 - 2.9359691400194e+118*cos(theta)**10 + 1.49794343878541e+117*cos(theta)**8 - 4.13225776216664e+115*cos(theta)**6 + 5.41817014270101e+113*cos(theta)**4 - 2.56178257338109e+111*cos(theta)**2 + 1.84300904559791e+108)*cos(59*phi)

#@torch.jit.script
def Yl79_m60(theta, phi):
    return 5.6580263030966e-111*(1.0 - cos(theta)**2)**30*(2.8173261058141e+122*cos(theta)**19 - 3.06855263754274e+122*cos(theta)**17 + 1.34620373776069e+122*cos(theta)**15 - 3.07955103409307e+121*cos(theta)**13 + 3.976903653299e+120*cos(theta)**11 - 2.9359691400194e+119*cos(theta)**9 + 1.19835475102833e+118*cos(theta)**7 - 2.47935465729998e+116*cos(theta)**5 + 2.16726805708041e+114*cos(theta)**3 - 5.12356514676219e+111*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl79_m61(theta, phi):
    return 1.09704424566073e-112*(1.0 - cos(theta)**2)**30.5*(5.35291960104678e+123*cos(theta)**18 - 5.21653948382266e+123*cos(theta)**16 + 2.01930560664103e+123*cos(theta)**14 - 4.003416344321e+122*cos(theta)**12 + 4.3745940186289e+121*cos(theta)**10 - 2.64237222601746e+120*cos(theta)**8 + 8.38848325719828e+118*cos(theta)**6 - 1.23967732864999e+117*cos(theta)**4 + 6.50180417124122e+114*cos(theta)**2 - 5.12356514676219e+111)*cos(61*phi)

#@torch.jit.script
def Yl79_m62(theta, phi):
    return 2.17760113832657e-114*(1.0 - cos(theta)**2)**31*(9.63525528188421e+124*cos(theta)**17 - 8.34646317411626e+124*cos(theta)**15 + 2.82702784929744e+124*cos(theta)**13 - 4.80409961318519e+123*cos(theta)**11 + 4.3745940186289e+122*cos(theta)**9 - 2.11389778081397e+121*cos(theta)**7 + 5.03308995431897e+119*cos(theta)**5 - 4.95870931459997e+117*cos(theta)**3 + 1.30036083424824e+115*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl79_m63(theta, phi):
    return 4.43210154436816e-116*(1.0 - cos(theta)**2)**31.5*(1.63799339792032e+126*cos(theta)**16 - 1.25196947611744e+126*cos(theta)**14 + 3.67513620408667e+125*cos(theta)**12 - 5.28450957450371e+124*cos(theta)**10 + 3.93713461676601e+123*cos(theta)**8 - 1.47972844656978e+122*cos(theta)**6 + 2.51654497715948e+120*cos(theta)**4 - 1.48761279437999e+118*cos(theta)**2 + 1.30036083424824e+115)*cos(63*phi)

#@torch.jit.script
def Yl79_m64(theta, phi):
    return 9.26577376004489e-118*(1.0 - cos(theta)**2)**32*(2.6207894366725e+127*cos(theta)**15 - 1.75275726656441e+127*cos(theta)**13 + 4.41016344490401e+126*cos(theta)**11 - 5.28450957450371e+125*cos(theta)**9 + 3.14970769341281e+124*cos(theta)**7 - 8.87837067941866e+122*cos(theta)**5 + 1.00661799086379e+121*cos(theta)**3 - 2.97522558875998e+118*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl79_m65(theta, phi):
    return 1.99367708124331e-119*(1.0 - cos(theta)**2)**32.5*(3.93118415500876e+128*cos(theta)**14 - 2.27858444653374e+128*cos(theta)**12 + 4.85117978939441e+127*cos(theta)**10 - 4.75605861705334e+126*cos(theta)**8 + 2.20479538538897e+125*cos(theta)**6 - 4.43918533970933e+123*cos(theta)**4 + 3.01985397259138e+121*cos(theta)**2 - 2.97522558875998e+118)*cos(65*phi)

#@torch.jit.script
def Yl79_m66(theta, phi):
    return 4.42493400038439e-121*(1.0 - cos(theta)**2)**33*(5.50365781701226e+129*cos(theta)**13 - 2.73430133584049e+129*cos(theta)**11 + 4.85117978939441e+128*cos(theta)**9 - 3.80484689364267e+127*cos(theta)**7 + 1.32287723123338e+126*cos(theta)**5 - 1.77567413588373e+124*cos(theta)**3 + 6.03970794518276e+121*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl79_m67(theta, phi):
    return 1.01568419240514e-122*(1.0 - cos(theta)**2)**33.5*(7.15475516211594e+130*cos(theta)**12 - 3.00773146942453e+130*cos(theta)**10 + 4.36606181045497e+129*cos(theta)**8 - 2.66339282554987e+128*cos(theta)**6 + 6.6143861561669e+126*cos(theta)**4 - 5.32702240765119e+124*cos(theta)**2 + 6.03970794518276e+121)*cos(67*phi)

#@torch.jit.script
def Yl79_m68(theta, phi):
    return 2.41829569620271e-124*(1.0 - cos(theta)**2)**34*(8.58570619453912e+131*cos(theta)**11 - 3.00773146942453e+131*cos(theta)**9 + 3.49284944836398e+130*cos(theta)**7 - 1.59803569532992e+129*cos(theta)**5 + 2.64575446246676e+127*cos(theta)**3 - 1.06540448153024e+125*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl79_m69(theta, phi):
    return 5.99352336472808e-126*(1.0 - cos(theta)**2)**34.5*(9.44427681399304e+132*cos(theta)**10 - 2.70695832248208e+132*cos(theta)**8 + 2.44499461385478e+131*cos(theta)**6 - 7.99017847664962e+129*cos(theta)**4 + 7.93726338740028e+127*cos(theta)**2 - 1.06540448153024e+125)*cos(69*phi)

#@torch.jit.script
def Yl79_m70(theta, phi):
    return 1.55270541818914e-127*(1.0 - cos(theta)**2)**35*(9.44427681399304e+133*cos(theta)**9 - 2.16556665798566e+133*cos(theta)**7 + 1.46699676831287e+132*cos(theta)**5 - 3.19607139065985e+130*cos(theta)**3 + 1.58745267748006e+128*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl79_m71(theta, phi):
    return 4.22592888379797e-129*(1.0 - cos(theta)**2)**35.5*(8.49984913259373e+134*cos(theta)**8 - 1.51589666058997e+134*cos(theta)**6 + 7.33498384156435e+132*cos(theta)**4 - 9.58821417197954e+130*cos(theta)**2 + 1.58745267748006e+128)*cos(71*phi)

#@torch.jit.script
def Yl79_m72(theta, phi):
    return 1.21587440706328e-130*(1.0 - cos(theta)**2)**36*(6.79987930607499e+135*cos(theta)**7 - 9.09537996353979e+134*cos(theta)**5 + 2.93399353662574e+133*cos(theta)**3 - 1.91764283439591e+131*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl79_m73(theta, phi):
    return 3.72750215421727e-132*(1.0 - cos(theta)**2)**36.5*(4.75991551425249e+136*cos(theta)**6 - 4.5476899817699e+135*cos(theta)**4 + 8.80198060987722e+133*cos(theta)**2 - 1.91764283439591e+131)*cos(73*phi)

#@torch.jit.script
def Yl79_m74(theta, phi):
    return 1.23025903314616e-133*(1.0 - cos(theta)**2)**37*(2.85594930855149e+137*cos(theta)**5 - 1.81907599270796e+136*cos(theta)**3 + 1.76039612197544e+134*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl79_m75(theta, phi):
    return 4.43354580712399e-135*(1.0 - cos(theta)**2)**37.5*(1.42797465427575e+138*cos(theta)**4 - 5.45722797812387e+136*cos(theta)**2 + 1.76039612197544e+134)*cos(75*phi)

#@torch.jit.script
def Yl79_m76(theta, phi):
    return 1.78055484392831e-136*(1.0 - cos(theta)**2)**38*(5.71189861710299e+138*cos(theta)**3 - 1.09144559562477e+137*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl79_m77(theta, phi):
    return 8.23061767764012e-138*(1.0 - cos(theta)**2)**38.5*(1.7135695851309e+139*cos(theta)**2 - 1.09144559562477e+137)*cos(77*phi)

#@torch.jit.script
def Yl79_m78(theta, phi):
    return 15.9183975012566*(1.0 - cos(theta)**2)**39*cos(78*phi)*cos(theta)

#@torch.jit.script
def Yl79_m79(theta, phi):
    return 1.26639970845295*(1.0 - cos(theta)**2)**39.5*cos(79*phi)

#@torch.jit.script
def Yl80_m_minus_80(theta, phi):
    return 1.27035104319811*(1.0 - cos(theta)**2)**40*sin(80*phi)

#@torch.jit.script
def Yl80_m_minus_79(theta, phi):
    return 16.0688108979079*(1.0 - cos(theta)**2)**39.5*sin(79*phi)*cos(theta)

#@torch.jit.script
def Yl80_m_minus_78(theta, phi):
    return 5.2585793883761e-140*(1.0 - cos(theta)**2)**39*(2.72457564035813e+141*cos(theta)**2 - 1.7135695851309e+139)*sin(78*phi)

#@torch.jit.script
def Yl80_m_minus_77(theta, phi):
    return 1.1448737705593e-138*(1.0 - cos(theta)**2)**38.5*(9.08191880119375e+140*cos(theta)**3 - 1.7135695851309e+139*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl80_m_minus_76(theta, phi):
    return 2.86904544565473e-137*(1.0 - cos(theta)**2)**38*(2.27047970029844e+140*cos(theta)**4 - 8.56784792565448e+138*cos(theta)**2 + 2.72861398906194e+136)*sin(76*phi)

#@torch.jit.script
def Yl80_m_minus_75(theta, phi):
    return 8.01280785992094e-136*(1.0 - cos(theta)**2)**37.5*(4.54095940059688e+139*cos(theta)**5 - 2.85594930855149e+138*cos(theta)**3 + 2.72861398906194e+136*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl80_m_minus_74(theta, phi):
    return 2.44357798144463e-134*(1.0 - cos(theta)**2)**37*(7.56826566766146e+138*cos(theta)**6 - 7.13987327137874e+137*cos(theta)**4 + 1.36430699453097e+136*cos(theta)**2 - 2.93399353662574e+133)*sin(74*phi)

#@torch.jit.script
def Yl80_m_minus_73(theta, phi):
    return 8.02297767216779e-133*(1.0 - cos(theta)**2)**36.5*(1.08118080966592e+138*cos(theta)**7 - 1.42797465427575e+137*cos(theta)**5 + 4.5476899817699e+135*cos(theta)**3 - 2.93399353662574e+133*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl80_m_minus_72(theta, phi):
    return 2.8068958115897e-131*(1.0 - cos(theta)**2)**36*(1.3514760120824e+137*cos(theta)**8 - 2.37995775712625e+136*cos(theta)**6 + 1.13692249544247e+135*cos(theta)**4 - 1.46699676831287e+133*cos(theta)**2 + 2.39705354299488e+130)*sin(72*phi)

#@torch.jit.script
def Yl80_m_minus_71(theta, phi):
    return 1.03817207075031e-129*(1.0 - cos(theta)**2)**35.5*(1.50164001342489e+136*cos(theta)**9 - 3.39993965303749e+135*cos(theta)**7 + 2.27384499088495e+134*cos(theta)**5 - 4.88998922770956e+132*cos(theta)**3 + 2.39705354299488e+130*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl80_m_minus_70(theta, phi):
    return 4.03420362055988e-128*(1.0 - cos(theta)**2)**35*(1.50164001342489e+135*cos(theta)**10 - 4.24992456629687e+134*cos(theta)**8 + 3.78974165147491e+133*cos(theta)**6 - 1.22249730692739e+132*cos(theta)**4 + 1.19852677149744e+130*cos(theta)**2 - 1.58745267748006e+127)*sin(70*phi)

#@torch.jit.script
def Yl80_m_minus_69(theta, phi):
    return 1.63870125727749e-126*(1.0 - cos(theta)**2)**34.5*(1.36512728493172e+134*cos(theta)**11 - 4.72213840699652e+133*cos(theta)**9 + 5.41391664496416e+132*cos(theta)**7 - 2.44499461385478e+131*cos(theta)**5 + 3.99508923832481e+129*cos(theta)**3 - 1.58745267748006e+127*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl80_m_minus_68(theta, phi):
    return 6.92920713888528e-125*(1.0 - cos(theta)**2)**34*(1.13760607077643e+133*cos(theta)**12 - 4.72213840699652e+132*cos(theta)**10 + 6.7673958062052e+131*cos(theta)**8 - 4.0749910230913e+130*cos(theta)**6 + 9.98772309581202e+128*cos(theta)**4 - 7.93726338740028e+126*cos(theta)**2 + 8.87837067941866e+123)*sin(68*phi)

#@torch.jit.script
def Yl80_m_minus_67(theta, phi):
    return 3.03938753480969e-123*(1.0 - cos(theta)**2)**33.5*(8.75081592904949e+131*cos(theta)**13 - 4.29285309726956e+131*cos(theta)**11 + 7.51932867356133e+130*cos(theta)**9 - 5.82141574727329e+129*cos(theta)**7 + 1.9975446191624e+128*cos(theta)**5 - 2.64575446246676e+126*cos(theta)**3 + 8.87837067941866e+123*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl80_m_minus_66(theta, phi):
    return 1.37882377465523e-121*(1.0 - cos(theta)**2)**33*(6.25058280646392e+130*cos(theta)**14 - 3.57737758105797e+130*cos(theta)**12 + 7.51932867356133e+129*cos(theta)**10 - 7.27676968409161e+128*cos(theta)**8 + 3.32924103193734e+127*cos(theta)**6 - 6.6143861561669e+125*cos(theta)**4 + 4.43918533970933e+123*cos(theta)**2 - 4.31407710370197e+120)*sin(66*phi)

#@torch.jit.script
def Yl80_m_minus_65(theta, phi):
    return 6.45254171114326e-120*(1.0 - cos(theta)**2)**32.5*(4.16705520430928e+129*cos(theta)**15 - 2.75182890850613e+129*cos(theta)**13 + 6.83575333960121e+128*cos(theta)**11 - 8.08529964899068e+127*cos(theta)**9 + 4.75605861705334e+126*cos(theta)**7 - 1.32287723123338e+125*cos(theta)**5 + 1.47972844656978e+123*cos(theta)**3 - 4.31407710370197e+120*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl80_m_minus_64(theta, phi):
    return 3.10795565153335e-118*(1.0 - cos(theta)**2)**32*(2.6044095026933e+128*cos(theta)**16 - 1.96559207750438e+128*cos(theta)**14 + 5.69646111633434e+127*cos(theta)**12 - 8.08529964899068e+126*cos(theta)**10 + 5.94507327131668e+125*cos(theta)**8 - 2.20479538538897e+124*cos(theta)**6 + 3.69932111642444e+122*cos(theta)**4 - 2.15703855185099e+120*cos(theta)**2 + 1.85951599297499e+117)*sin(64*phi)

#@torch.jit.script
def Yl80_m_minus_63(theta, phi):
    return 1.53773153172088e-116*(1.0 - cos(theta)**2)**31.5*(1.53200558981959e+127*cos(theta)**17 - 1.31039471833625e+127*cos(theta)**15 + 4.38189316641103e+126*cos(theta)**13 - 7.35027240817335e+125*cos(theta)**11 + 6.60563696812964e+124*cos(theta)**9 - 3.14970769341281e+123*cos(theta)**7 + 7.39864223284888e+121*cos(theta)**5 - 7.19012850616995e+119*cos(theta)**3 + 1.85951599297499e+117*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl80_m_minus_62(theta, phi):
    return 7.80161996679641e-115*(1.0 - cos(theta)**2)**31*(8.51114216566438e+125*cos(theta)**18 - 8.18996698960158e+125*cos(theta)**16 + 3.1299236902936e+125*cos(theta)**14 - 6.12522700681112e+124*cos(theta)**12 + 6.60563696812964e+123*cos(theta)**10 - 3.93713461676601e+122*cos(theta)**8 + 1.23310703880815e+121*cos(theta)**6 - 1.79753212654249e+119*cos(theta)**4 + 9.29757996487494e+116*cos(theta)**2 - 7.22422685693469e+113)*sin(62*phi)

#@torch.jit.script
def Yl80_m_minus_61(theta, phi):
    return 4.05233894854369e-113*(1.0 - cos(theta)**2)**30.5*(4.47954850824441e+124*cos(theta)**19 - 4.8176276409421e+124*cos(theta)**17 + 2.08661579352906e+124*cos(theta)**15 - 4.7117130821624e+123*cos(theta)**13 + 6.00512451648149e+122*cos(theta)**11 - 4.3745940186289e+121*cos(theta)**9 + 1.76158148401164e+120*cos(theta)**7 - 3.59506425308498e+118*cos(theta)**5 + 3.09919332162498e+116*cos(theta)**3 - 7.22422685693469e+113*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl80_m_minus_60(theta, phi):
    return 2.1519407912383e-111*(1.0 - cos(theta)**2)**30*(2.23977425412221e+123*cos(theta)**20 - 2.67645980052339e+123*cos(theta)**18 + 1.30413487095567e+123*cos(theta)**16 - 3.36550934440172e+122*cos(theta)**14 + 5.00427043040124e+121*cos(theta)**12 - 4.3745940186289e+120*cos(theta)**10 + 2.20197685501455e+119*cos(theta)**8 - 5.99177375514163e+117*cos(theta)**6 + 7.74798330406245e+115*cos(theta)**4 - 3.61211342846734e+113*cos(theta)**2 + 2.56178257338109e+110)*sin(60*phi)

#@torch.jit.script
def Yl80_m_minus_59(theta, phi):
    return 1.16682031850865e-109*(1.0 - cos(theta)**2)**29.5*(1.06655916862962e+122*cos(theta)**21 - 1.40866305290705e+122*cos(theta)**19 + 7.67138159385685e+121*cos(theta)**17 - 2.24367289626781e+121*cos(theta)**15 + 3.84943879261634e+120*cos(theta)**13 - 3.976903653299e+119*cos(theta)**11 + 2.44664095001616e+118*cos(theta)**9 - 8.55967679305947e+116*cos(theta)**7 + 1.54959666081249e+115*cos(theta)**5 - 1.20403780948911e+113*cos(theta)**3 + 2.56178257338109e+110*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl80_m_minus_58(theta, phi):
    return 6.45242141144206e-108*(1.0 - cos(theta)**2)**29*(4.84799622104374e+120*cos(theta)**22 - 7.04331526453524e+120*cos(theta)**20 + 4.26187866325381e+120*cos(theta)**18 - 1.40229556016738e+120*cos(theta)**16 + 2.7495991375831e+119*cos(theta)**14 - 3.31408637774917e+118*cos(theta)**12 + 2.44664095001616e+117*cos(theta)**10 - 1.06995959913243e+116*cos(theta)**8 + 2.58266110135415e+114*cos(theta)**6 - 3.01009452372279e+112*cos(theta)**4 + 1.28089128669055e+110*cos(theta)**2 - 8.37731384362686e+106)*sin(58*phi)

#@torch.jit.script
def Yl80_m_minus_57(theta, phi):
    return 3.63518221459163e-106*(1.0 - cos(theta)**2)**28.5*(2.10782444393206e+119*cos(theta)**23 - 3.35395964977869e+119*cos(theta)**21 + 2.24309403329148e+119*cos(theta)**19 - 8.2487974127493e+118*cos(theta)**17 + 1.83306609172207e+118*cos(theta)**15 - 2.54929721365321e+117*cos(theta)**13 + 2.22421904546924e+116*cos(theta)**11 - 1.18884399903604e+115*cos(theta)**9 + 3.68951585907736e+113*cos(theta)**7 - 6.02018904744557e+111*cos(theta)**5 + 4.26963762230182e+109*cos(theta)**3 - 8.37731384362686e+106*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl80_m_minus_56(theta, phi):
    return 2.0844529143887e-104*(1.0 - cos(theta)**2)**28*(8.78260184971691e+117*cos(theta)**24 - 1.52452711353577e+118*cos(theta)**22 + 1.12154701664574e+118*cos(theta)**20 - 4.58266522930517e+117*cos(theta)**18 + 1.14566630732629e+117*cos(theta)**16 - 1.82092658118086e+116*cos(theta)**14 + 1.85351587122437e+115*cos(theta)**12 - 1.18884399903604e+114*cos(theta)**10 + 4.6118948238467e+112*cos(theta)**8 - 1.00336484124093e+111*cos(theta)**6 + 1.06740940557546e+109*cos(theta)**4 - 4.18865692181343e+106*cos(theta)**2 + 2.54784484295221e+103)*sin(56*phi)

#@torch.jit.script
def Yl80_m_minus_55(theta, phi):
    return 1.21543446708706e-102*(1.0 - cos(theta)**2)**27.5*(3.51304073988677e+116*cos(theta)**25 - 6.62837875450333e+116*cos(theta)**23 + 5.34070007926542e+116*cos(theta)**21 - 2.41192906805535e+116*cos(theta)**19 + 6.7392135725076e+115*cos(theta)**17 - 1.21395105412057e+115*cos(theta)**15 + 1.42578143940336e+114*cos(theta)**13 - 1.08076727185094e+113*cos(theta)**11 + 5.12432758205188e+111*cos(theta)**9 - 1.4333783446299e+110*cos(theta)**7 + 2.13481881115091e+108*cos(theta)**5 - 1.39621897393781e+106*cos(theta)**3 + 2.54784484295221e+103*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl80_m_minus_54(theta, phi):
    return 7.20087224763713e-101*(1.0 - cos(theta)**2)**27*(1.35116951534106e+115*cos(theta)**26 - 2.76182448104305e+115*cos(theta)**24 + 2.42759094512065e+115*cos(theta)**22 - 1.20596453402768e+115*cos(theta)**20 + 3.744007540282e+114*cos(theta)**18 - 7.58719408825359e+113*cos(theta)**16 + 1.01841531385954e+113*cos(theta)**14 - 9.00639393209119e+111*cos(theta)**12 + 5.12432758205188e+110*cos(theta)**10 - 1.79172293078737e+109*cos(theta)**8 + 3.55803135191819e+107*cos(theta)**6 - 3.49054743484453e+105*cos(theta)**4 + 1.2739224214761e+103*cos(theta)**2 - 7.25881721638806e+99)*sin(54*phi)

#@torch.jit.script
def Yl80_m_minus_53(theta, phi):
    return 4.33131118896724e-99*(1.0 - cos(theta)**2)**26.5*(5.00433153830024e+113*cos(theta)**27 - 1.10472979241722e+114*cos(theta)**25 + 1.0554743239655e+114*cos(theta)**23 - 5.74268825727465e+113*cos(theta)**21 + 1.97053028435895e+113*cos(theta)**19 - 4.46305534603152e+112*cos(theta)**17 + 6.78943542573028e+111*cos(theta)**15 - 6.92799533237784e+110*cos(theta)**13 + 4.65847962004717e+109*cos(theta)**11 - 1.99080325643041e+108*cos(theta)**9 + 5.08290193131169e+106*cos(theta)**7 - 6.98109486968905e+104*cos(theta)**5 + 4.24640807158701e+102*cos(theta)**3 - 7.25881721638806e+99*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl80_m_minus_52(theta, phi):
    return 2.64316468720293e-97*(1.0 - cos(theta)**2)**26*(1.78726126367866e+112*cos(theta)**28 - 4.24896074006624e+112*cos(theta)**26 + 4.39780968318958e+112*cos(theta)**24 - 2.61031284421575e+112*cos(theta)**22 + 9.85265142179474e+111*cos(theta)**20 - 2.47947519223974e+111*cos(theta)**18 + 4.24339714108143e+110*cos(theta)**16 - 4.9485680945556e+109*cos(theta)**14 + 3.88206635003931e+108*cos(theta)**12 - 1.99080325643041e+107*cos(theta)**10 + 6.35362741413962e+105*cos(theta)**8 - 1.16351581161484e+104*cos(theta)**6 + 1.06160201789675e+102*cos(theta)**4 - 3.62940860819403e+99*cos(theta)**2 + 1.94919903769819e+96)*sin(52*phi)

#@torch.jit.script
def Yl80_m_minus_51(theta, phi):
    return 1.63534801463645e-95*(1.0 - cos(theta)**2)**25.5*(6.16296987475398e+110*cos(theta)**29 - 1.5736891629875e+111*cos(theta)**27 + 1.75912387327583e+111*cos(theta)**25 - 1.13491862791989e+111*cos(theta)**23 + 4.69173877228321e+110*cos(theta)**21 - 1.30498694328407e+110*cos(theta)**19 + 2.49611596534202e+109*cos(theta)**17 - 3.2990453963704e+108*cos(theta)**15 + 2.98620488464562e+107*cos(theta)**13 - 1.80982114220947e+106*cos(theta)**11 + 7.05958601571069e+104*cos(theta)**9 - 1.66216544516406e+103*cos(theta)**7 + 2.12320403579351e+101*cos(theta)**5 - 1.20980286939801e+99*cos(theta)**3 + 1.94919903769819e+96*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl80_m_minus_50(theta, phi):
    return 1.02519496179377e-93*(1.0 - cos(theta)**2)**25*(2.05432329158466e+109*cos(theta)**30 - 5.62031843924105e+109*cos(theta)**28 + 6.76586105106089e+109*cos(theta)**26 - 4.72882761633288e+109*cos(theta)**24 + 2.132608532856e+109*cos(theta)**22 - 6.52493471642036e+108*cos(theta)**20 + 1.38673109185668e+108*cos(theta)**18 - 2.0619033727315e+107*cos(theta)**16 + 2.13300348903259e+106*cos(theta)**14 - 1.50818428517456e+105*cos(theta)**12 + 7.05958601571069e+103*cos(theta)**10 - 2.07770680645507e+102*cos(theta)**8 + 3.53867339298918e+100*cos(theta)**6 - 3.02450717349502e+98*cos(theta)**4 + 9.74599518849095e+95*cos(theta)**2 - 4.95979398905392e+92)*sin(50*phi)

#@torch.jit.script
def Yl80_m_minus_49(theta, phi):
    return 6.50817146366008e-92*(1.0 - cos(theta)**2)**24.5*(6.62684932769246e+107*cos(theta)**31 - 1.93804084111761e+108*cos(theta)**29 + 2.50587446335588e+108*cos(theta)**27 - 1.89153104653315e+108*cos(theta)**25 + 9.27221101241741e+107*cos(theta)**23 - 3.10711176972398e+107*cos(theta)**21 + 7.2985846939825e+106*cos(theta)**19 - 1.21288433690088e+106*cos(theta)**17 + 1.42200232602172e+105*cos(theta)**15 - 1.16014175782658e+104*cos(theta)**13 + 6.4178054688279e+102*cos(theta)**11 - 2.30856311828342e+101*cos(theta)**9 + 5.05524770427025e+99*cos(theta)**7 - 6.04901434699005e+97*cos(theta)**5 + 3.24866506283032e+95*cos(theta)**3 - 4.95979398905392e+92*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl80_m_minus_48(theta, phi):
    return 4.18146851075132e-90*(1.0 - cos(theta)**2)**24*(2.07089041490389e+106*cos(theta)**32 - 6.46013613705868e+106*cos(theta)**30 + 8.94955165484244e+106*cos(theta)**28 - 7.27511940974289e+106*cos(theta)**26 + 3.86342125517392e+106*cos(theta)**24 - 1.41232353169272e+106*cos(theta)**22 + 3.64929234699125e+105*cos(theta)**20 - 6.73824631611601e+104*cos(theta)**18 + 8.88751453763577e+103*cos(theta)**16 - 8.28672684161844e+102*cos(theta)**14 + 5.34817122402325e+101*cos(theta)**12 - 2.30856311828342e+100*cos(theta)**10 + 6.31905963033782e+98*cos(theta)**8 - 1.00816905783167e+97*cos(theta)**6 + 8.12166265707579e+94*cos(theta)**4 - 2.47989699452696e+92*cos(theta)**2 + 1.20150048184446e+89)*sin(48*phi)

#@torch.jit.script
def Yl80_m_minus_47(theta, phi):
    return 2.71763286152957e-88*(1.0 - cos(theta)**2)**23.5*(6.27542549970877e+104*cos(theta)**33 - 2.08391488292216e+105*cos(theta)**31 + 3.08605229477326e+105*cos(theta)**29 - 2.69448867027514e+105*cos(theta)**27 + 1.54536850206957e+105*cos(theta)**25 - 6.14053709431616e+104*cos(theta)**23 + 1.73775826047202e+104*cos(theta)**21 - 3.54644542953474e+103*cos(theta)**19 + 5.22794972802104e+102*cos(theta)**17 - 5.52448456107896e+101*cos(theta)**15 + 4.11397786463327e+100*cos(theta)**13 - 2.09869374389401e+99*cos(theta)**11 + 7.02117736704202e+97*cos(theta)**9 - 1.44024151118811e+96*cos(theta)**7 + 1.62433253141516e+94*cos(theta)**5 - 8.26632331508986e+91*cos(theta)**3 + 1.20150048184446e+89*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl80_m_minus_46(theta, phi):
    return 1.78579706299295e-86*(1.0 - cos(theta)**2)**23*(1.84571338226728e+103*cos(theta)**34 - 6.51223400913174e+103*cos(theta)**32 + 1.02868409825775e+104*cos(theta)**30 - 9.62317382241123e+103*cos(theta)**28 + 5.94372500795988e+103*cos(theta)**26 - 2.55855712263174e+103*cos(theta)**24 + 7.89890118396375e+102*cos(theta)**22 - 1.77322271476737e+102*cos(theta)**20 + 2.90441651556725e+101*cos(theta)**18 - 3.45280285067435e+100*cos(theta)**16 + 2.93855561759519e+99*cos(theta)**14 - 1.74891145324501e+98*cos(theta)**12 + 7.02117736704202e+96*cos(theta)**10 - 1.80030188898513e+95*cos(theta)**8 + 2.70722088569193e+93*cos(theta)**6 - 2.06658082877247e+91*cos(theta)**4 + 6.00750240922228e+88*cos(theta)**2 - 2.78253932803255e+85)*sin(46*phi)

#@torch.jit.script
def Yl80_m_minus_45(theta, phi):
    return 1.18590909315835e-84*(1.0 - cos(theta)**2)**22.5*(5.27346680647795e+101*cos(theta)**35 - 1.97340424519144e+102*cos(theta)**33 + 3.31833580083146e+102*cos(theta)**31 - 3.31833580083146e+102*cos(theta)**29 + 2.20137963257773e+102*cos(theta)**27 - 1.02342284905269e+102*cos(theta)**25 + 3.43430486259293e+101*cos(theta)**23 - 8.44391768936844e+100*cos(theta)**21 + 1.52864027135118e+100*cos(theta)**19 - 2.03106050039668e+99*cos(theta)**17 + 1.95903707839679e+98*cos(theta)**15 - 1.34531650249616e+97*cos(theta)**13 + 6.38288851549275e+95*cos(theta)**11 - 2.0003354322057e+94*cos(theta)**9 + 3.86745840813133e+92*cos(theta)**7 - 4.13316165754493e+90*cos(theta)**5 + 2.00250080307409e+88*cos(theta)**3 - 2.78253932803255e+85*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl80_m_minus_44(theta, phi):
    return 7.95532004231161e-83*(1.0 - cos(theta)**2)**22*(1.46485189068832e+100*cos(theta)**36 - 5.80413013291599e+100*cos(theta)**34 + 1.03697993775983e+101*cos(theta)**32 - 1.10611193361049e+101*cos(theta)**30 + 7.86207011634904e+100*cos(theta)**28 - 3.93624172712575e+100*cos(theta)**26 + 1.43096035941372e+100*cos(theta)**24 - 3.83814440425838e+99*cos(theta)**22 + 7.64320135675591e+98*cos(theta)**20 - 1.12836694466482e+98*cos(theta)**18 + 1.224398173998e+97*cos(theta)**16 - 9.60940358925831e+95*cos(theta)**14 + 5.31907376291062e+94*cos(theta)**12 - 2.0003354322057e+93*cos(theta)**10 + 4.83432301016416e+91*cos(theta)**8 - 6.88860276257489e+89*cos(theta)**6 + 5.00625200768524e+87*cos(theta)**4 - 1.39126966401628e+85*cos(theta)**2 + 6.18342072896123e+81)*sin(44*phi)

#@torch.jit.script
def Yl80_m_minus_43(theta, phi):
    return 5.38851828134669e-81*(1.0 - cos(theta)**2)**21.5*(3.95905916402249e+98*cos(theta)**37 - 1.65832289511885e+99*cos(theta)**35 + 3.14236344775706e+99*cos(theta)**33 - 3.56810301164673e+99*cos(theta)**31 + 2.71105866081002e+99*cos(theta)**29 - 1.45786730634287e+99*cos(theta)**27 + 5.72384143765489e+98*cos(theta)**25 - 1.66875843663408e+98*cos(theta)**23 + 3.63961969369329e+97*cos(theta)**21 - 5.93877339297274e+96*cos(theta)**19 + 7.20234219998821e+95*cos(theta)**17 - 6.40626905950554e+94*cos(theta)**15 + 4.09159520223894e+93*cos(theta)**13 - 1.81848675655064e+92*cos(theta)**11 + 5.37147001129351e+90*cos(theta)**9 - 9.84086108939269e+88*cos(theta)**7 + 1.00125040153705e+87*cos(theta)**5 - 4.63756554672092e+84*cos(theta)**3 + 6.18342072896123e+81*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl80_m_minus_42(theta, phi):
    return 3.68394989380334e-79*(1.0 - cos(theta)**2)**21*(1.04185767474276e+97*cos(theta)**38 - 4.60645248644126e+97*cos(theta)**36 + 9.2422454345796e+97*cos(theta)**34 - 1.1150321911396e+98*cos(theta)**32 + 9.03686220270005e+97*cos(theta)**30 - 5.20666895122453e+97*cos(theta)**28 + 2.20147747602111e+97*cos(theta)**26 - 6.95316015264199e+96*cos(theta)**24 + 1.65437258804241e+96*cos(theta)**22 - 2.96938669648637e+95*cos(theta)**20 + 4.00130122221567e+94*cos(theta)**18 - 4.00391816219096e+93*cos(theta)**16 + 2.92256800159924e+92*cos(theta)**14 - 1.51540563045887e+91*cos(theta)**12 + 5.37147001129351e+89*cos(theta)**10 - 1.23010763617409e+88*cos(theta)**8 + 1.66875066922841e+86*cos(theta)**6 - 1.15939138668023e+84*cos(theta)**4 + 3.09171036448062e+81*cos(theta)**2 - 1.32293982219966e+78)*sin(42*phi)

#@torch.jit.script
def Yl80_m_minus_41(theta, phi):
    return 2.54112444185276e-77*(1.0 - cos(theta)**2)**20.5*(2.67142993523785e+95*cos(theta)**39 - 1.24498715849764e+96*cos(theta)**37 + 2.64064155273703e+96*cos(theta)**35 - 3.37888542769577e+96*cos(theta)**33 + 2.91511683958066e+96*cos(theta)**31 - 1.79540308662915e+96*cos(theta)**29 + 8.15362028155967e+95*cos(theta)**27 - 2.7812640610568e+95*cos(theta)**25 + 7.19292429583655e+94*cos(theta)**23 - 1.41399366499351e+94*cos(theta)**21 + 2.10594801169246e+93*cos(theta)**19 - 2.35524597775939e+92*cos(theta)**17 + 1.94837866773283e+91*cos(theta)**15 - 1.16569663881451e+90*cos(theta)**13 + 4.88315455572137e+88*cos(theta)**11 - 1.36678626241565e+87*cos(theta)**9 + 2.38392952746916e+85*cos(theta)**7 - 2.31878277336046e+83*cos(theta)**5 + 1.03057012149354e+81*cos(theta)**3 - 1.32293982219966e+78*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl80_m_minus_40(theta, phi):
    return 1.76786303191934e-75*(1.0 - cos(theta)**2)**20*(6.67857483809462e+93*cos(theta)**40 - 3.27628199604642e+94*cos(theta)**38 + 7.33511542426952e+94*cos(theta)**36 - 9.93789831675226e+94*cos(theta)**34 + 9.10974012368957e+94*cos(theta)**32 - 5.9846769554305e+94*cos(theta)**30 + 2.91200724341417e+94*cos(theta)**28 - 1.06971694656031e+94*cos(theta)**26 + 2.99705178993189e+93*cos(theta)**24 - 6.42724393178868e+92*cos(theta)**22 + 1.05297400584623e+92*cos(theta)**20 - 1.30846998764411e+91*cos(theta)**18 + 1.21773666733302e+90*cos(theta)**16 - 8.3264045629608e+88*cos(theta)**14 + 4.06929546310114e+87*cos(theta)**12 - 1.36678626241565e+86*cos(theta)**10 + 2.97991190933645e+84*cos(theta)**8 - 3.86463795560077e+82*cos(theta)**6 + 2.57642530373385e+80*cos(theta)**4 - 6.61469911099832e+77*cos(theta)**2 + 2.73334674008195e+74)*sin(40*phi)

#@torch.jit.script
def Yl80_m_minus_39(theta, phi):
    return 1.24002706914668e-73*(1.0 - cos(theta)**2)**19.5*(1.6289206922182e+92*cos(theta)**41 - 8.40072306678568e+92*cos(theta)**39 + 1.98246362818095e+93*cos(theta)**37 - 2.83939951907207e+93*cos(theta)**35 + 2.76052731020896e+93*cos(theta)**33 - 1.93054095336468e+93*cos(theta)**31 + 1.00414042876351e+93*cos(theta)**29 - 3.96191461689002e+92*cos(theta)**27 + 1.19882071597276e+92*cos(theta)**25 - 2.79445388338638e+91*cos(theta)**23 + 5.01416193260109e+90*cos(theta)**21 - 6.88668414549529e+89*cos(theta)**19 + 7.16315686666481e+88*cos(theta)**17 - 5.5509363753072e+87*cos(theta)**15 + 3.13022727930857e+86*cos(theta)**13 - 1.24253296583241e+85*cos(theta)**11 + 3.31101323259606e+83*cos(theta)**9 - 5.52091136514396e+81*cos(theta)**7 + 5.15285060746769e+79*cos(theta)**5 - 2.20489970366611e+77*cos(theta)**3 + 2.73334674008195e+74*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl80_m_minus_38(theta, phi):
    return 8.7665616559847e-72*(1.0 - cos(theta)**2)**19*(3.87838260051952e+90*cos(theta)**42 - 2.10018076669642e+91*cos(theta)**40 + 5.21700954784461e+91*cos(theta)**38 - 7.88722088631131e+91*cos(theta)**36 + 8.11919797120282e+91*cos(theta)**34 - 6.03294047926461e+91*cos(theta)**32 + 3.34713476254502e+91*cos(theta)**30 - 1.41496950603215e+91*cos(theta)**28 + 4.61084890758753e+90*cos(theta)**26 - 1.16435578474433e+90*cos(theta)**24 + 2.27916451481868e+89*cos(theta)**22 - 3.44334207274765e+88*cos(theta)**20 + 3.97953159259156e+87*cos(theta)**18 - 3.469335234567e+86*cos(theta)**16 + 2.23587662807755e+85*cos(theta)**14 - 1.03544413819368e+84*cos(theta)**12 + 3.31101323259606e+82*cos(theta)**10 - 6.90113920642995e+80*cos(theta)**8 + 8.58808434577949e+78*cos(theta)**6 - 5.51224925916527e+76*cos(theta)**4 + 1.36667337004098e+74*cos(theta)**2 - 5.46888103257693e+70)*sin(38*phi)

#@torch.jit.script
def Yl80_m_minus_37(theta, phi):
    return 6.2445985377985e-70*(1.0 - cos(theta)**2)**18.5*(9.01949441981284e+88*cos(theta)**43 - 5.12239211389371e+89*cos(theta)**41 + 1.33769475585759e+90*cos(theta)**39 - 2.13168132062468e+90*cos(theta)**37 + 2.31977084891509e+90*cos(theta)**35 - 1.82816378159534e+90*cos(theta)**33 + 1.07972089114356e+90*cos(theta)**31 - 4.87920519321432e+89*cos(theta)**29 + 1.70772181762501e+89*cos(theta)**27 - 4.6574231389773e+88*cos(theta)**25 + 9.90941093399426e+87*cos(theta)**23 - 1.6396867013084e+87*cos(theta)**21 + 2.0944903118903e+86*cos(theta)**19 - 2.04078543209824e+85*cos(theta)**17 + 1.49058441871837e+84*cos(theta)**15 - 7.96495490918212e+82*cos(theta)**13 + 3.01001202963278e+81*cos(theta)**11 - 7.66793245158883e+79*cos(theta)**9 + 1.22686919225421e+78*cos(theta)**7 - 1.10244985183305e+76*cos(theta)**5 + 4.55557790013658e+73*cos(theta)**3 - 5.46888103257693e+70*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl80_m_minus_36(theta, phi):
    return 4.48047225305905e-68*(1.0 - cos(theta)**2)**18*(2.04988509541201e+87*cos(theta)**44 - 1.21961716997469e+88*cos(theta)**42 + 3.34423688964398e+88*cos(theta)**40 - 5.60968768585442e+88*cos(theta)**38 + 6.44380791365303e+88*cos(theta)**36 - 5.37695229880982e+88*cos(theta)**34 + 3.37412778482361e+88*cos(theta)**32 - 1.62640173107144e+88*cos(theta)**30 + 6.0990064915179e+87*cos(theta)**28 - 1.79131659191435e+87*cos(theta)**26 + 4.12892122249761e+86*cos(theta)**24 - 7.45312136958365e+85*cos(theta)**22 + 1.04724515594515e+85*cos(theta)**20 - 1.13376968449902e+84*cos(theta)**18 + 9.3161526169898e+82*cos(theta)**16 - 5.68925350655866e+81*cos(theta)**14 + 2.50834335802731e+80*cos(theta)**12 - 7.66793245158883e+78*cos(theta)**10 + 1.53358649031777e+77*cos(theta)**8 - 1.83741641972176e+75*cos(theta)**6 + 1.13889447503415e+73*cos(theta)**4 - 2.73444051628847e+70*cos(theta)**2 + 1.06233120290927e+67)*sin(36*phi)

#@torch.jit.script
def Yl80_m_minus_35(theta, phi):
    return 3.23712182357191e-66*(1.0 - cos(theta)**2)**17.5*(4.55530021202669e+85*cos(theta)**45 - 2.83631899994114e+86*cos(theta)**43 + 8.15667534059508e+86*cos(theta)**41 - 1.43838145791139e+87*cos(theta)**39 + 1.74156970639271e+87*cos(theta)**37 - 1.53627208537423e+87*cos(theta)**35 + 1.02246296509806e+87*cos(theta)**33 - 5.24645719700464e+86*cos(theta)**31 + 2.10310568673031e+86*cos(theta)**29 - 6.63450589597906e+85*cos(theta)**27 + 1.65156848899904e+85*cos(theta)**25 - 3.24048755199289e+84*cos(theta)**23 + 4.98688169497689e+83*cos(theta)**21 - 5.96720886578432e+82*cos(theta)**19 + 5.48008977469988e+81*cos(theta)**17 - 3.7928356710391e+80*cos(theta)**15 + 1.92949489079024e+79*cos(theta)**13 - 6.97084768326257e+77*cos(theta)**11 + 1.70398498924196e+76*cos(theta)**9 - 2.62488059960251e+74*cos(theta)**7 + 2.27778895006829e+72*cos(theta)**5 - 9.11480172096155e+69*cos(theta)**3 + 1.06233120290927e+67*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl80_m_minus_34(theta, phi):
    return 2.35443594596275e-64*(1.0 - cos(theta)**2)**17*(9.9028265478841e+83*cos(theta)**46 - 6.44617954532078e+84*cos(theta)**44 + 1.94206555728454e+85*cos(theta)**42 - 3.59595364477847e+85*cos(theta)**40 + 4.58307817471766e+85*cos(theta)**38 - 4.26742245937287e+85*cos(theta)**36 + 3.0072440149943e+85*cos(theta)**34 - 1.63951787406395e+85*cos(theta)**32 + 7.01035228910103e+84*cos(theta)**30 - 2.36946639142109e+84*cos(theta)**28 + 6.35218649615017e+83*cos(theta)**26 - 1.3502031466637e+83*cos(theta)**24 + 2.26676440680768e+82*cos(theta)**22 - 2.98360443289216e+81*cos(theta)**20 + 3.04449431927771e+80*cos(theta)**18 - 2.37052229439944e+79*cos(theta)**16 + 1.37821063627874e+78*cos(theta)**14 - 5.80903973605214e+76*cos(theta)**12 + 1.70398498924196e+75*cos(theta)**10 - 3.28110074950314e+73*cos(theta)**8 + 3.79631491678049e+71*cos(theta)**6 - 2.27870043024039e+69*cos(theta)**4 + 5.31165601454636e+66*cos(theta)**2 - 2.00818752912906e+63)*sin(34*phi)

#@torch.jit.script
def Yl80_m_minus_33(theta, phi):
    return 1.72340851470193e-62*(1.0 - cos(theta)**2)**16.5*(2.10698437189023e+82*cos(theta)**47 - 1.43248434340462e+83*cos(theta)**45 + 4.5164315285687e+83*cos(theta)**43 - 8.77061864580116e+83*cos(theta)**41 + 1.17514824992761e+84*cos(theta)**39 - 1.15335742145213e+84*cos(theta)**37 + 8.59212575712658e+83*cos(theta)**35 - 4.96823598201197e+83*cos(theta)**33 + 2.26140396422614e+83*cos(theta)**31 - 8.17057376352101e+82*cos(theta)**29 + 2.3526616652408e+82*cos(theta)**27 - 5.40081258665482e+81*cos(theta)**25 + 9.85549742090295e+80*cos(theta)**23 - 1.42076401566293e+80*cos(theta)**21 + 1.6023654311988e+79*cos(theta)**19 - 1.39442487905849e+78*cos(theta)**17 + 9.18807090852496e+76*cos(theta)**15 - 4.46849210465549e+75*cos(theta)**13 + 1.54907726294724e+74*cos(theta)**11 - 3.64566749944793e+72*cos(theta)**9 + 5.42330702397212e+70*cos(theta)**7 - 4.55740086048078e+68*cos(theta)**5 + 1.77055200484879e+66*cos(theta)**3 - 2.00818752912906e+63*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl80_m_minus_32(theta, phi):
    return 1.26925263804963e-60*(1.0 - cos(theta)**2)**16*(4.38955077477132e+80*cos(theta)**48 - 3.11409639870569e+81*cos(theta)**46 + 1.02646171103834e+82*cos(theta)**44 - 2.08824253471456e+82*cos(theta)**42 + 2.93787062481901e+82*cos(theta)**40 - 3.03515110908455e+82*cos(theta)**38 + 2.38670159920183e+82*cos(theta)**36 - 1.46124587706234e+82*cos(theta)**34 + 7.06688738820668e+81*cos(theta)**32 - 2.72352458784034e+81*cos(theta)**30 + 8.40236309014572e+80*cos(theta)**28 - 2.07723561025185e+80*cos(theta)**26 + 4.10645725870956e+79*cos(theta)**24 - 6.45801825301333e+78*cos(theta)**22 + 8.01182715599398e+77*cos(theta)**20 - 7.7468048836583e+76*cos(theta)**18 + 5.7425443178281e+75*cos(theta)**16 - 3.19178007475392e+74*cos(theta)**14 + 1.2908977191227e+73*cos(theta)**12 - 3.64566749944793e+71*cos(theta)**10 + 6.77913377996516e+69*cos(theta)**8 - 7.59566810080129e+67*cos(theta)**6 + 4.42638001212197e+65*cos(theta)**4 - 1.00409376456453e+63*cos(theta)**2 + 3.70241063629989e+59)*sin(32*phi)

#@torch.jit.script
def Yl80_m_minus_31(theta, phi):
    return 9.40275512733762e-59*(1.0 - cos(theta)**2)**15.5*(8.95826688728841e+78*cos(theta)**49 - 6.62573701852275e+79*cos(theta)**47 + 2.28102602452965e+80*cos(theta)**45 - 4.85637798770828e+80*cos(theta)**43 + 7.16553810931467e+80*cos(theta)**41 - 7.78243874124242e+80*cos(theta)**39 + 6.45054486270765e+80*cos(theta)**37 - 4.17498822017813e+80*cos(theta)**35 + 2.1414810267293e+80*cos(theta)**33 - 8.78556318658173e+79*cos(theta)**31 + 2.89736658280887e+79*cos(theta)**29 - 7.69346522315501e+78*cos(theta)**27 + 1.64258290348383e+78*cos(theta)**25 - 2.80783402304927e+77*cos(theta)**23 + 3.81515578856856e+76*cos(theta)**21 - 4.07726572824121e+75*cos(theta)**19 + 3.37796724578124e+74*cos(theta)**17 - 2.12785338316928e+73*cos(theta)**15 + 9.92998245478999e+71*cos(theta)**13 - 3.3142431813163e+70*cos(theta)**11 + 7.53237086662795e+68*cos(theta)**9 - 1.08509544297161e+67*cos(theta)**7 + 8.85276002424393e+64*cos(theta)**5 - 3.3469792152151e+62*cos(theta)**3 + 3.70241063629989e+59*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl80_m_minus_30(theta, phi):
    return 7.00489480374217e-57*(1.0 - cos(theta)**2)**15*(1.79165337745768e+77*cos(theta)**50 - 1.38036187885891e+78*cos(theta)**48 + 4.95875222723836e+78*cos(theta)**46 - 1.1037222699337e+79*cos(theta)**44 + 1.70608050221778e+79*cos(theta)**42 - 1.94560968531061e+79*cos(theta)**40 + 1.6975118059757e+79*cos(theta)**38 - 1.15971895004948e+79*cos(theta)**36 + 6.29847360802735e+78*cos(theta)**34 - 2.74548849580679e+78*cos(theta)**32 + 9.6578886093629e+77*cos(theta)**30 - 2.74766615112679e+77*cos(theta)**28 + 6.31762655186087e+76*cos(theta)**26 - 1.1699308429372e+76*cos(theta)**24 + 1.73416172207662e+75*cos(theta)**22 - 2.03863286412061e+74*cos(theta)**20 + 1.87664846987846e+73*cos(theta)**18 - 1.3299083644808e+72*cos(theta)**16 + 7.09284461056428e+70*cos(theta)**14 - 2.76186931776358e+69*cos(theta)**12 + 7.53237086662795e+67*cos(theta)**10 - 1.35636930371452e+66*cos(theta)**8 + 1.47546000404066e+64*cos(theta)**6 - 8.36744803803774e+61*cos(theta)**4 + 1.85120531814994e+59*cos(theta)**2 - 6.67101015549529e+55)*sin(30*phi)

#@torch.jit.script
def Yl80_m_minus_29(theta, phi):
    return 5.24666153183604e-55*(1.0 - cos(theta)**2)**14.5*(3.51304583815232e+75*cos(theta)**51 - 2.81706505889573e+76*cos(theta)**49 + 1.05505366536986e+77*cos(theta)**47 - 2.45271615540822e+77*cos(theta)**45 + 3.96762907492507e+77*cos(theta)**43 - 4.74538947636733e+77*cos(theta)**41 + 4.35259437429666e+77*cos(theta)**39 - 3.13437554067427e+77*cos(theta)**37 + 1.79956388800781e+77*cos(theta)**35 - 8.31966210850543e+76*cos(theta)**33 + 3.11544793850416e+76*cos(theta)**31 - 9.47471086595445e+75*cos(theta)**29 + 2.33986168587439e+75*cos(theta)**27 - 4.67972337174879e+74*cos(theta)**25 + 7.53983357424617e+73*cos(theta)**23 - 9.70777554343146e+72*cos(theta)**21 + 9.87709720988666e+71*cos(theta)**19 - 7.82299037929883e+70*cos(theta)**17 + 4.72856307370952e+69*cos(theta)**15 - 2.12451485981814e+68*cos(theta)**13 + 6.84760987875268e+66*cos(theta)**11 - 1.50707700412724e+65*cos(theta)**9 + 2.10780000577237e+63*cos(theta)**7 - 1.67348960760755e+61*cos(theta)**5 + 6.17068439383314e+58*cos(theta)**3 - 6.67101015549529e+55*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl80_m_minus_28(theta, phi):
    return 3.95000794401284e-53*(1.0 - cos(theta)**2)**14*(6.75585738106215e+73*cos(theta)**52 - 5.63413011779145e+74*cos(theta)**50 + 2.19802846952055e+75*cos(theta)**48 - 5.33199164219179e+75*cos(theta)**46 + 9.01733880664788e+75*cos(theta)**44 - 1.12985463723032e+76*cos(theta)**42 + 1.08814859357416e+76*cos(theta)**40 - 8.24835668598492e+75*cos(theta)**38 + 4.99878857779948e+75*cos(theta)**36 - 2.44695944367807e+75*cos(theta)**34 + 9.7357748078255e+74*cos(theta)**32 - 3.15823695531815e+74*cos(theta)**30 + 8.35664887812284e+73*cos(theta)**28 - 1.79989360451877e+73*cos(theta)**26 + 3.14159732260257e+72*cos(theta)**24 - 4.4126252470143e+71*cos(theta)**22 + 4.93854860494333e+70*cos(theta)**20 - 4.34610576627713e+69*cos(theta)**18 + 2.95535192106845e+68*cos(theta)**16 - 1.51751061415581e+67*cos(theta)**14 + 5.70634156562724e+65*cos(theta)**12 - 1.50707700412724e+64*cos(theta)**10 + 2.63475000721546e+62*cos(theta)**8 - 2.78914934601258e+60*cos(theta)**6 + 1.54267109845829e+58*cos(theta)**4 - 3.33550507774765e+55*cos(theta)**2 + 1.17696015446282e+52)*sin(28*phi)

#@torch.jit.script
def Yl80_m_minus_27(theta, phi):
    return 2.98846230067311e-51*(1.0 - cos(theta)**2)**13.5*(1.27469007189852e+72*cos(theta)**53 - 1.10473139564538e+73*cos(theta)**51 + 4.48577238677664e+73*cos(theta)**49 - 1.13446630684932e+74*cos(theta)**47 + 2.00385306814397e+74*cos(theta)**45 - 2.62756892379143e+74*cos(theta)**43 + 2.65402095993699e+74*cos(theta)**41 - 2.11496325281665e+74*cos(theta)**39 + 1.35102393994581e+74*cos(theta)**37 - 6.99131269622305e+73*cos(theta)**35 + 2.95023479025015e+73*cos(theta)**33 - 1.01878611461876e+73*cos(theta)**31 + 2.88160306142167e+72*cos(theta)**29 - 6.66627260932876e+71*cos(theta)**27 + 1.25663892904103e+71*cos(theta)**25 - 1.91853271609317e+70*cos(theta)**23 + 2.35168981187778e+69*cos(theta)**21 - 2.28742408751428e+68*cos(theta)**19 + 1.73844230651085e+67*cos(theta)**17 - 1.01167374277054e+66*cos(theta)**15 + 4.38949351202095e+64*cos(theta)**13 - 1.37007000375204e+63*cos(theta)**11 + 2.92750000801717e+61*cos(theta)**9 - 3.98449906573226e+59*cos(theta)**7 + 3.08534219691657e+57*cos(theta)**5 - 1.11183502591588e+55*cos(theta)**3 + 1.17696015446282e+52*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl80_m_minus_26(theta, phi):
    return 2.27162453320221e-49*(1.0 - cos(theta)**2)**13*(2.36053717018244e+70*cos(theta)**54 - 2.1244834531642e+71*cos(theta)**52 + 8.97154477355327e+71*cos(theta)**50 - 2.36347147260274e+72*cos(theta)**48 + 4.35620232205211e+72*cos(theta)**46 - 5.97174755407144e+72*cos(theta)**44 + 6.31909752365949e+72*cos(theta)**42 - 5.28740813204162e+72*cos(theta)**40 + 3.55532615775212e+72*cos(theta)**38 - 1.9420313045064e+72*cos(theta)**36 + 8.67716114779457e+71*cos(theta)**34 - 3.18370660818362e+71*cos(theta)**32 + 9.60534353807223e+70*cos(theta)**30 - 2.38081164618884e+70*cos(theta)**28 + 4.8332266501578e+69*cos(theta)**26 - 7.99388631705489e+68*cos(theta)**24 + 1.0689499144899e+68*cos(theta)**22 - 1.14371204375714e+67*cos(theta)**20 + 9.65801281394918e+65*cos(theta)**18 - 6.32296089231589e+64*cos(theta)**16 + 3.13535250858639e+63*cos(theta)**14 - 1.1417250031267e+62*cos(theta)**12 + 2.92750000801717e+60*cos(theta)**10 - 4.98062383216532e+58*cos(theta)**8 + 5.14223699486095e+56*cos(theta)**6 - 2.7795875647897e+54*cos(theta)**4 + 5.88480077231412e+51*cos(theta)**2 - 2.03696807625965e+48)*sin(26*phi)

#@torch.jit.script
def Yl80_m_minus_25(theta, phi):
    return 1.73448611570411e-47*(1.0 - cos(theta)**2)**12.5*(4.29188576396808e+68*cos(theta)**55 - 4.00845934559283e+69*cos(theta)**53 + 1.75912642618692e+70*cos(theta)**51 - 4.82341116857703e+70*cos(theta)**49 + 9.26851557883429e+70*cos(theta)**47 - 1.32705501201588e+71*cos(theta)**45 + 1.46955756364174e+71*cos(theta)**43 - 1.28961173952234e+71*cos(theta)**41 + 9.11622091731313e+70*cos(theta)**39 - 5.24873325542271e+70*cos(theta)**37 + 2.47918889936988e+70*cos(theta)**35 - 9.6475957823746e+69*cos(theta)**33 + 3.09849791550717e+69*cos(theta)**31 - 8.20969533168567e+68*cos(theta)**29 + 1.79008394450289e+68*cos(theta)**27 - 3.19755452682196e+67*cos(theta)**25 + 4.64760832386912e+66*cos(theta)**23 - 5.44624782741495e+65*cos(theta)**21 + 5.08316463892062e+64*cos(theta)**19 - 3.71938876018582e+63*cos(theta)**17 + 2.09023500572426e+62*cos(theta)**15 - 8.78250002405152e+60*cos(theta)**13 + 2.66136364365198e+59*cos(theta)**11 - 5.53402648018369e+57*cos(theta)**9 + 7.34605284980136e+55*cos(theta)**7 - 5.55917512957941e+53*cos(theta)**5 + 1.96160025743804e+51*cos(theta)**3 - 2.03696807625965e+48*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl80_m_minus_24(theta, phi):
    return 1.33002403975092e-45*(1.0 - cos(theta)**2)**12*(7.66408172137157e+66*cos(theta)**56 - 7.42307286220894e+67*cos(theta)**54 + 3.38293543497484e+68*cos(theta)**52 - 9.64682233715406e+68*cos(theta)**50 + 1.93094074559048e+69*cos(theta)**48 - 2.88490220003451e+69*cos(theta)**46 + 3.33990355373123e+69*cos(theta)**44 - 3.07050414171987e+69*cos(theta)**42 + 2.27905522932828e+69*cos(theta)**40 - 1.38124559353229e+69*cos(theta)**38 + 6.88663583158299e+68*cos(theta)**36 - 2.83752817128665e+68*cos(theta)**34 + 9.68280598595991e+67*cos(theta)**32 - 2.73656511056189e+67*cos(theta)**30 + 6.39315694465318e+66*cos(theta)**28 - 1.22982866416229e+66*cos(theta)**26 + 1.9365034682788e+65*cos(theta)**24 - 2.47556719427952e+64*cos(theta)**22 + 2.54158231946031e+63*cos(theta)**20 - 2.06632708899212e+62*cos(theta)**18 + 1.30639687857766e+61*cos(theta)**16 - 6.27321430289394e+59*cos(theta)**14 + 2.21780303637665e+58*cos(theta)**12 - 5.53402648018369e+56*cos(theta)**10 + 9.1825660622517e+54*cos(theta)**8 - 9.26529188263235e+52*cos(theta)**6 + 4.9040006435951e+50*cos(theta)**4 - 1.01848403812982e+48*cos(theta)**2 + 3.46423142221029e+44)*sin(24*phi)

#@torch.jit.script
def Yl80_m_minus_23(theta, phi):
    return 1.02403214176887e-43*(1.0 - cos(theta)**2)**11.5*(1.3445757405915e+65*cos(theta)**57 - 1.34964961131072e+66*cos(theta)**55 + 6.38289704712234e+66*cos(theta)**53 - 1.89153379159883e+67*cos(theta)**51 + 3.94069539916424e+67*cos(theta)**49 - 6.13808978730747e+67*cos(theta)**47 + 7.42200789718052e+67*cos(theta)**45 - 7.14070730632528e+67*cos(theta)**43 + 5.55867129104459e+67*cos(theta)**41 - 3.54165536803152e+67*cos(theta)**39 + 1.86125292745486e+67*cos(theta)**37 - 8.10722334653328e+66*cos(theta)**35 + 2.93418363210906e+66*cos(theta)**33 - 8.82762938890932e+65*cos(theta)**31 + 2.20453687746661e+65*cos(theta)**29 - 4.55492097837885e+64*cos(theta)**27 + 7.7460138731152e+63*cos(theta)**25 - 1.07633356273023e+63*cos(theta)**23 + 1.2102772949811e+62*cos(theta)**21 - 1.08754057315375e+61*cos(theta)**19 + 7.68468752104508e+59*cos(theta)**17 - 4.18214286859596e+58*cos(theta)**15 + 1.70600233567434e+57*cos(theta)**13 - 5.03093316380336e+55*cos(theta)**11 + 1.02028511802797e+54*cos(theta)**9 - 1.32361312609034e+52*cos(theta)**7 + 9.80800128719021e+49*cos(theta)**5 - 3.39494679376608e+47*cos(theta)**3 + 3.46423142221029e+44*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl80_m_minus_22(theta, phi):
    return 7.91491394567412e-42*(1.0 - cos(theta)**2)**11*(2.31823403550259e+63*cos(theta)**58 - 2.41008859162628e+64*cos(theta)**56 + 1.18201797168932e+65*cos(theta)**54 - 3.63756498384391e+65*cos(theta)**52 + 7.88139079832848e+65*cos(theta)**50 - 1.27876870568906e+66*cos(theta)**48 + 1.61347997764794e+66*cos(theta)**46 - 1.62288802416484e+66*cos(theta)**44 + 1.32349316453443e+66*cos(theta)**42 - 8.8541384200788e+65*cos(theta)**40 + 4.89803401961806e+65*cos(theta)**38 - 2.25200648514813e+65*cos(theta)**36 + 8.6299518591443e+64*cos(theta)**34 - 2.75863418403416e+64*cos(theta)**32 + 7.34845625822204e+63*cos(theta)**30 - 1.62675749227816e+63*cos(theta)**28 + 2.97923610504431e+62*cos(theta)**26 - 4.48472317804261e+61*cos(theta)**24 + 5.50126043173227e+60*cos(theta)**22 - 5.43770286576874e+59*cos(theta)**20 + 4.26927084502505e+58*cos(theta)**18 - 2.61383929287248e+57*cos(theta)**16 + 1.21857309691025e+56*cos(theta)**14 - 4.19244430316946e+54*cos(theta)**12 + 1.02028511802797e+53*cos(theta)**10 - 1.65451640761292e+51*cos(theta)**8 + 1.63466688119837e+49*cos(theta)**6 - 8.4873669844152e+46*cos(theta)**4 + 1.73211571110514e+44*cos(theta)**2 - 5.79884737564494e+40)*sin(22*phi)

#@torch.jit.script
def Yl80_m_minus_21(theta, phi):
    return 6.14005539172387e-40*(1.0 - cos(theta)**2)**10.5*(3.92921022966541e+61*cos(theta)**59 - 4.22822559934435e+62*cos(theta)**57 + 2.14912358488968e+63*cos(theta)**55 - 6.86333015819606e+63*cos(theta)**53 + 1.54537074477029e+64*cos(theta)**51 - 2.60973205242665e+64*cos(theta)**49 + 3.43293612265519e+64*cos(theta)**47 - 3.60641783147741e+64*cos(theta)**45 + 3.07789108031262e+64*cos(theta)**43 - 2.15954595611678e+64*cos(theta)**41 + 1.25590615887643e+64*cos(theta)**39 - 6.08650401391387e+63*cos(theta)**37 + 2.46570053118409e+63*cos(theta)**35 - 8.35949752737625e+62*cos(theta)**33 + 2.37046976071679e+62*cos(theta)**31 - 5.60950859406263e+61*cos(theta)**29 + 1.10342077964604e+61*cos(theta)**27 - 1.79388927121705e+60*cos(theta)**25 + 2.39185236162273e+59*cos(theta)**23 - 2.58938231703273e+58*cos(theta)**21 + 2.24698465527634e+57*cos(theta)**19 - 1.5375525252191e+56*cos(theta)**17 + 8.1238206460683e+54*cos(theta)**15 - 3.2249571562842e+53*cos(theta)**13 + 9.2753192547997e+51*cos(theta)**11 - 1.83835156401436e+50*cos(theta)**9 + 2.33523840171195e+48*cos(theta)**7 - 1.69747339688304e+46*cos(theta)**5 + 5.77371903701714e+43*cos(theta)**3 - 5.79884737564494e+40*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl80_m_minus_20(theta, phi):
    return 4.77978763224299e-38*(1.0 - cos(theta)**2)**10*(6.54868371610901e+59*cos(theta)**60 - 7.2900441368006e+60*cos(theta)**58 + 3.83772068730299e+61*cos(theta)**56 - 1.2709870663326e+62*cos(theta)**54 + 2.97186681686594e+62*cos(theta)**52 - 5.2194641048533e+62*cos(theta)**50 + 7.15195025553164e+62*cos(theta)**48 - 7.84003876408133e+62*cos(theta)**46 + 6.9952070007105e+62*cos(theta)**44 - 5.14177608599233e+62*cos(theta)**42 + 3.13976539719106e+62*cos(theta)**40 - 1.60171158260891e+62*cos(theta)**38 + 6.84916814217802e+61*cos(theta)**36 - 2.45867574334596e+61*cos(theta)**34 + 7.40771800223996e+60*cos(theta)**32 - 1.86983619802088e+60*cos(theta)**30 + 3.94078849873586e+59*cos(theta)**28 - 6.89957412006556e+58*cos(theta)**26 + 9.96605150676136e+57*cos(theta)**24 - 1.17699196228761e+57*cos(theta)**22 + 1.12349232763817e+56*cos(theta)**20 - 8.54195847343947e+54*cos(theta)**18 + 5.07738790379269e+53*cos(theta)**16 - 2.30354082591729e+52*cos(theta)**14 + 7.72943271233308e+50*cos(theta)**12 - 1.83835156401436e+49*cos(theta)**10 + 2.91904800213994e+47*cos(theta)**8 - 2.8291223281384e+45*cos(theta)**6 + 1.44342975925429e+43*cos(theta)**4 - 2.89942368782247e+40*cos(theta)**2 + 9.56905507532168e+36)*sin(20*phi)

#@torch.jit.script
def Yl80_m_minus_19(theta, phi):
    return 3.73313348056284e-36*(1.0 - cos(theta)**2)**9.5*(1.07355470755885e+58*cos(theta)**61 - 1.23560070115264e+59*cos(theta)**59 + 6.73284331105788e+59*cos(theta)**57 - 2.31088557515019e+60*cos(theta)**55 + 5.60729588087913e+60*cos(theta)**53 - 1.02342433428496e+61*cos(theta)**51 + 1.45958168480238e+61*cos(theta)**49 - 1.66809335405986e+61*cos(theta)**47 + 1.55449044460233e+61*cos(theta)**45 - 1.19576188046333e+61*cos(theta)**43 + 7.65796438339284e+60*cos(theta)**41 - 4.10695277592029e+60*cos(theta)**39 + 1.85112652491298e+60*cos(theta)**37 - 7.0247878381313e+59*cos(theta)**35 + 2.24476303098181e+59*cos(theta)**33 - 6.03172967103508e+58*cos(theta)**31 + 1.35889258577099e+58*cos(theta)**29 - 2.5553978222465e+57*cos(theta)**27 + 3.98642060270454e+56*cos(theta)**25 - 5.1173563577722e+55*cos(theta)**23 + 5.34996346494367e+54*cos(theta)**21 - 4.49576761759972e+53*cos(theta)**19 + 2.98669876693688e+52*cos(theta)**17 - 1.53569388394486e+51*cos(theta)**15 + 5.94571747102545e+49*cos(theta)**13 - 1.6712286945585e+48*cos(theta)**11 + 3.24338666904438e+46*cos(theta)**9 - 4.041603325912e+44*cos(theta)**7 + 2.88685951850857e+42*cos(theta)**5 - 9.6647456260749e+39*cos(theta)**3 + 9.56905507532168e+36*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl80_m_minus_18(theta, phi):
    return 2.92473795258218e-34*(1.0 - cos(theta)**2)**9*(1.73153985090138e+56*cos(theta)**62 - 2.05933450192107e+57*cos(theta)**60 + 1.16083505363067e+58*cos(theta)**58 - 4.12658138419677e+58*cos(theta)**56 + 1.03838812608873e+59*cos(theta)**54 - 1.96812371977877e+59*cos(theta)**52 + 2.91916336960475e+59*cos(theta)**50 - 3.4751944876247e+59*cos(theta)**48 + 3.37932705348333e+59*cos(theta)**46 - 2.71764063741667e+59*cos(theta)**44 + 1.82332485318877e+59*cos(theta)**42 - 1.02673819398007e+59*cos(theta)**40 + 4.87138559187626e+58*cos(theta)**38 - 1.95132995503647e+58*cos(theta)**36 + 6.60224420877002e+57*cos(theta)**34 - 1.88491552219846e+57*cos(theta)**32 + 4.52964195256995e+56*cos(theta)**30 - 9.12642079373751e+55*cos(theta)**28 + 1.5332386933479e+55*cos(theta)**26 - 2.13223181573842e+54*cos(theta)**24 + 2.43180157497439e+53*cos(theta)**22 - 2.24788380879986e+52*cos(theta)**20 + 1.65927709274271e+51*cos(theta)**18 - 9.59808677465537e+49*cos(theta)**16 + 4.24694105073246e+48*cos(theta)**14 - 1.39269057879875e+47*cos(theta)**12 + 3.24338666904438e+45*cos(theta)**10 - 5.05200415739e+43*cos(theta)**8 + 4.81143253084762e+41*cos(theta)**6 - 2.41618640651872e+39*cos(theta)**4 + 4.78452753766084e+36*cos(theta)**2 - 1.55898583827333e+33)*sin(18*phi)

#@torch.jit.script
def Yl80_m_minus_17(theta, phi):
    return 2.29810714657801e-32*(1.0 - cos(theta)**2)**8.5*(2.74847595381171e+54*cos(theta)**63 - 3.37595819987061e+55*cos(theta)**61 + 1.96751704005198e+56*cos(theta)**59 - 7.2396164635031e+56*cos(theta)**57 + 1.88797841107042e+57*cos(theta)**55 - 3.71344098071466e+57*cos(theta)**53 + 5.72384974432304e+57*cos(theta)**51 - 7.09223364821368e+57*cos(theta)**49 + 7.19005756060284e+57*cos(theta)**47 - 6.03920141648148e+57*cos(theta)**45 + 4.24029035625295e+57*cos(theta)**43 - 2.50423949751237e+57*cos(theta)**41 + 1.24907322868622e+57*cos(theta)**39 - 5.27386474334182e+56*cos(theta)**37 + 1.88635548822001e+56*cos(theta)**35 - 5.71186521878322e+55*cos(theta)**33 + 1.46117482340966e+55*cos(theta)**31 - 3.14704165301294e+54*cos(theta)**29 + 5.67866182721445e+53*cos(theta)**27 - 8.52892726295367e+52*cos(theta)**25 + 1.05730503259756e+52*cos(theta)**23 - 1.07042086133327e+51*cos(theta)**21 + 8.73303733022478e+49*cos(theta)**19 - 5.6459333968561e+48*cos(theta)**17 + 2.83129403382164e+47*cos(theta)**15 - 1.07130044522981e+46*cos(theta)**13 + 2.94853333549489e+44*cos(theta)**11 - 5.61333795265556e+42*cos(theta)**9 + 6.87347504406803e+40*cos(theta)**7 - 4.83237281303745e+38*cos(theta)**5 + 1.59484251255361e+36*cos(theta)**3 - 1.55898583827333e+33*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl80_m_minus_16(theta, phi):
    return 1.81069843999506e-30*(1.0 - cos(theta)**2)**8*(4.2944936778308e+52*cos(theta)**64 - 5.44509387075905e+53*cos(theta)**62 + 3.2791950667533e+54*cos(theta)**60 - 1.24820973508674e+55*cos(theta)**58 + 3.3713900197686e+55*cos(theta)**56 - 6.876742556879e+55*cos(theta)**54 + 1.10074033544674e+56*cos(theta)**52 - 1.41844672964274e+56*cos(theta)**50 + 1.49792865845892e+56*cos(theta)**48 - 1.31286987314815e+56*cos(theta)**46 + 9.63702353693853e+55*cos(theta)**44 - 5.96247499407708e+55*cos(theta)**42 + 3.12268307171555e+55*cos(theta)**40 - 1.38785914298469e+55*cos(theta)**38 + 5.23987635616668e+54*cos(theta)**36 - 1.67996035846565e+54*cos(theta)**34 + 4.56617132315519e+53*cos(theta)**32 - 1.04901388433765e+53*cos(theta)**30 + 2.02809350971945e+52*cos(theta)**28 - 3.28035663959757e+51*cos(theta)**26 + 4.40543763582318e+50*cos(theta)**24 - 4.86554936969667e+49*cos(theta)**22 + 4.36651866511239e+48*cos(theta)**20 - 3.13662966492005e+47*cos(theta)**18 + 1.76955877113853e+46*cos(theta)**16 - 7.65214603735579e+44*cos(theta)**14 + 2.45711111291241e+43*cos(theta)**12 - 5.61333795265556e+41*cos(theta)**10 + 8.59184380508504e+39*cos(theta)**8 - 8.05395468839575e+37*cos(theta)**6 + 3.98710628138403e+35*cos(theta)**4 - 7.79492919136664e+32*cos(theta)**2 + 2.51125296113616e+29)*sin(16*phi)

#@torch.jit.script
def Yl80_m_minus_15(theta, phi):
    return 1.43033716183798e-28*(1.0 - cos(theta)**2)**7.5*(6.60691335050892e+50*cos(theta)**65 - 8.64300614406199e+51*cos(theta)**63 + 5.37572961762836e+52*cos(theta)**61 - 2.115609720486e+53*cos(theta)**59 + 5.91471933292737e+53*cos(theta)**57 - 1.25031682852345e+54*cos(theta)**55 + 2.07686855744668e+54*cos(theta)**53 - 2.7812680973387e+54*cos(theta)**51 + 3.05699726216107e+54*cos(theta)**49 - 2.79334015563436e+54*cos(theta)**47 + 2.14156078598634e+54*cos(theta)**45 - 1.38662209164583e+54*cos(theta)**43 + 7.61630017491598e+53*cos(theta)**41 - 3.55861318714023e+53*cos(theta)**39 + 1.41618279896397e+53*cos(theta)**37 - 4.7998867384733e+52*cos(theta)**35 + 1.383688279744e+52*cos(theta)**33 - 3.38391575592789e+51*cos(theta)**31 + 6.9934258955843e+50*cos(theta)**29 - 1.21494690355465e+50*cos(theta)**27 + 1.76217505432927e+49*cos(theta)**25 - 2.1154562476942e+48*cos(theta)**23 + 2.07929460243447e+47*cos(theta)**21 - 1.65085771837898e+46*cos(theta)**19 + 1.04091692419913e+45*cos(theta)**17 - 5.10143069157053e+43*cos(theta)**15 + 1.89008547147108e+42*cos(theta)**13 - 5.10303450241414e+40*cos(theta)**11 + 9.54649311676115e+38*cos(theta)**9 - 1.15056495548511e+37*cos(theta)**7 + 7.97421256276807e+34*cos(theta)**5 - 2.59830973045555e+32*cos(theta)**3 + 2.51125296113616e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl80_m_minus_14(theta, phi):
    return 1.13258861756036e-26*(1.0 - cos(theta)**2)**7*(1.00104747734984e+49*cos(theta)**66 - 1.35046971000969e+50*cos(theta)**64 + 8.67053164133607e+50*cos(theta)**62 - 3.52601620081e+51*cos(theta)**60 + 1.0197791953323e+52*cos(theta)**58 - 2.23270862236331e+52*cos(theta)**56 + 3.84605288416051e+52*cos(theta)**54 - 5.34859249488211e+52*cos(theta)**52 + 6.11399452432214e+52*cos(theta)**50 - 5.81945865757158e+52*cos(theta)**48 + 4.65556692605726e+52*cos(theta)**46 - 3.15141384464962e+52*cos(theta)**44 + 1.81340480355142e+52*cos(theta)**42 - 8.89653296785057e+51*cos(theta)**40 + 3.72679683937886e+51*cos(theta)**38 - 1.33330187179814e+51*cos(theta)**36 + 4.06967141101176e+50*cos(theta)**34 - 1.05747367372746e+50*cos(theta)**32 + 2.33114196519477e+49*cos(theta)**30 - 4.33909608412376e+48*cos(theta)**28 + 6.77759636280489e+47*cos(theta)**26 - 8.81440103205918e+46*cos(theta)**24 + 9.45133910197488e+45*cos(theta)**22 - 8.25428859189488e+44*cos(theta)**20 + 5.7828718011063e+43*cos(theta)**18 - 3.18839418223158e+42*cos(theta)**16 + 1.35006105105077e+41*cos(theta)**14 - 4.25252875201179e+39*cos(theta)**12 + 9.54649311676115e+37*cos(theta)**10 - 1.43820619435638e+36*cos(theta)**8 + 1.32903542712801e+34*cos(theta)**6 - 6.49577432613886e+31*cos(theta)**4 + 1.25562648056808e+29*cos(theta)**2 - 4.00518813578335e+25)*sin(14*phi)

#@torch.jit.script
def Yl80_m_minus_13(theta, phi):
    return 8.988216418622e-25*(1.0 - cos(theta)**2)**6.5*(1.49410071246244e+47*cos(theta)**67 - 2.07764570770721e+48*cos(theta)**65 + 1.37627486370414e+49*cos(theta)**63 - 5.78035442755738e+49*cos(theta)**61 + 1.72843931412255e+50*cos(theta)**59 - 3.91703267081283e+50*cos(theta)**57 + 6.99282342574639e+50*cos(theta)**55 - 1.00916839526078e+51*cos(theta)**53 + 1.19882245574944e+51*cos(theta)**51 - 1.1876446239942e+51*cos(theta)**49 + 9.90546154480269e+50*cos(theta)**47 - 7.00314187699915e+50*cos(theta)**45 + 4.2172204733754e+50*cos(theta)**43 - 2.16988608971965e+50*cos(theta)**41 + 9.55588933174068e+49*cos(theta)**39 - 3.6035185724274e+49*cos(theta)**37 + 1.16276326028907e+49*cos(theta)**35 - 3.20446567796201e+48*cos(theta)**33 + 7.51981279095086e+47*cos(theta)**31 - 1.49624002900819e+47*cos(theta)**29 + 2.51022087511292e+46*cos(theta)**27 - 3.52576041282367e+45*cos(theta)**25 + 4.10927787042386e+44*cos(theta)**23 - 3.93061361518804e+43*cos(theta)**21 + 3.04361673742437e+42*cos(theta)**19 - 1.87552598954799e+41*cos(theta)**17 + 9.00040700700516e+39*cos(theta)**15 - 3.27117596308599e+38*cos(theta)**13 + 8.6786301061465e+36*cos(theta)**11 - 1.5980068826182e+35*cos(theta)**9 + 1.8986220387543e+33*cos(theta)**7 - 1.29915486522777e+31*cos(theta)**5 + 4.1854216018936e+28*cos(theta)**3 - 4.00518813578335e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl80_m_minus_12(theta, phi):
    return 7.14775160081563e-23*(1.0 - cos(theta)**2)**6*(2.19720693009183e+45*cos(theta)**68 - 3.14794804198062e+46*cos(theta)**66 + 2.15042947453772e+47*cos(theta)**64 - 9.32315230251191e+47*cos(theta)**62 + 2.88073219020425e+48*cos(theta)**60 - 6.7535046048497e+48*cos(theta)**58 + 1.24871846888328e+49*cos(theta)**56 - 1.86883036159403e+49*cos(theta)**54 + 2.30542779951815e+49*cos(theta)**52 - 2.3752892479884e+49*cos(theta)**50 + 2.06363782183389e+49*cos(theta)**48 - 1.52242214717373e+49*cos(theta)**46 + 9.5845919849441e+48*cos(theta)**44 - 5.16639545171345e+48*cos(theta)**42 + 2.38897233293517e+48*cos(theta)**40 - 9.48294361165105e+47*cos(theta)**38 + 3.22989794524743e+47*cos(theta)**36 - 9.42489905282946e+46*cos(theta)**34 + 2.34994149717214e+46*cos(theta)**32 - 4.98746676336065e+45*cos(theta)**30 + 8.96507455397472e+44*cos(theta)**28 - 1.35606169723987e+44*cos(theta)**26 + 1.71219911267661e+43*cos(theta)**24 - 1.7866425523582e+42*cos(theta)**22 + 1.52180836871218e+41*cos(theta)**20 - 1.04195888308222e+40*cos(theta)**18 + 5.62525437937823e+38*cos(theta)**16 - 2.33655425934713e+37*cos(theta)**14 + 7.23219175512208e+35*cos(theta)**12 - 1.5980068826182e+34*cos(theta)**10 + 2.37327754844288e+32*cos(theta)**8 - 2.16525810871295e+30*cos(theta)**6 + 1.0463554004734e+28*cos(theta)**4 - 2.00259406789167e+25*cos(theta)**2 + 6.33331457271244e+21)*sin(12*phi)

#@torch.jit.script
def Yl80_m_minus_11(theta, phi):
    return 5.69492370894745e-21*(1.0 - cos(theta)**2)**5.5*(3.1843578696983e+43*cos(theta)**69 - 4.69842991340391e+44*cos(theta)**67 + 3.30835303775033e+45*cos(theta)**65 - 1.47986544484316e+46*cos(theta)**63 + 4.72251178722008e+46*cos(theta)**61 - 1.14466179743215e+47*cos(theta)**59 + 2.19073415593558e+47*cos(theta)**57 - 3.39787338471642e+47*cos(theta)**55 + 4.34986377267576e+47*cos(theta)**53 - 4.65742989801647e+47*cos(theta)**51 + 4.21150575884468e+47*cos(theta)**49 - 3.23919605781644e+47*cos(theta)**47 + 2.12990932998758e+47*cos(theta)**45 - 1.20148731435197e+47*cos(theta)**43 + 5.82676178764675e+46*cos(theta)**41 - 2.43152400298745e+46*cos(theta)**39 + 8.72945390607413e+45*cos(theta)**37 - 2.69282830080842e+45*cos(theta)**35 + 7.12103483991559e+44*cos(theta)**33 - 1.60886024624537e+44*cos(theta)**31 + 3.09140501861197e+43*cos(theta)**29 - 5.02245073051805e+42*cos(theta)**27 + 6.84879645070643e+41*cos(theta)**25 - 7.76801109720956e+40*cos(theta)**23 + 7.24670651767706e+39*cos(theta)**21 - 5.48399412148534e+38*cos(theta)**19 + 3.30897316434013e+37*cos(theta)**17 - 1.55770283956476e+36*cos(theta)**15 + 5.56322442701699e+34*cos(theta)**13 - 1.45273352965291e+33*cos(theta)**11 + 2.63697505382542e+31*cos(theta)**9 - 3.09322586958993e+29*cos(theta)**7 + 2.0927108009468e+27*cos(theta)**5 - 6.67531355963891e+24*cos(theta)**3 + 6.33331457271244e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl80_m_minus_10(theta, phi):
    return 4.54524844252942e-19*(1.0 - cos(theta)**2)**5*(4.54908267099757e+41*cos(theta)**70 - 6.90945575500575e+42*cos(theta)**68 + 5.01265611780353e+43*cos(theta)**66 - 2.31228975756744e+44*cos(theta)**64 + 7.61695449551626e+44*cos(theta)**62 - 1.90776966238692e+45*cos(theta)**60 + 3.77712785506135e+45*cos(theta)**58 - 6.06763104413646e+45*cos(theta)**56 + 8.05530328273289e+45*cos(theta)**54 - 8.95659595772398e+45*cos(theta)**52 + 8.42301151768936e+45*cos(theta)**50 - 6.74832512045092e+45*cos(theta)**48 + 4.63023767388604e+45*cos(theta)**46 - 2.73065298716356e+45*cos(theta)**44 + 1.38732423515399e+45*cos(theta)**42 - 6.07881000746862e+44*cos(theta)**40 + 2.29722471212477e+44*cos(theta)**38 - 7.48007861335671e+43*cos(theta)**36 + 2.09442201173988e+43*cos(theta)**34 - 5.02768826951678e+42*cos(theta)**32 + 1.03046833953732e+42*cos(theta)**30 - 1.79373240375645e+41*cos(theta)**28 + 2.63415248104094e+40*cos(theta)**26 - 3.23667129050398e+39*cos(theta)**24 + 3.29395750803503e+38*cos(theta)**22 - 2.74199706074267e+37*cos(theta)**20 + 1.83831842463341e+36*cos(theta)**18 - 9.73564274727973e+34*cos(theta)**16 + 3.97373173358356e+33*cos(theta)**14 - 1.21061127471076e+32*cos(theta)**12 + 2.63697505382542e+30*cos(theta)**10 - 3.86653233698742e+28*cos(theta)**8 + 3.48785133491133e+26*cos(theta)**6 - 1.66882838990973e+24*cos(theta)**4 + 3.16665728635622e+21*cos(theta)**2 - 9.94240906234292e+17)*sin(10*phi)

#@torch.jit.script
def Yl80_m_minus_9(theta, phi):
    return 3.63335686319938e-17*(1.0 - cos(theta)**2)**4.5*(6.40715869154588e+39*cos(theta)**71 - 1.0013703992762e+41*cos(theta)**69 + 7.48157629522916e+41*cos(theta)**67 - 3.55736885779606e+42*cos(theta)**65 + 1.20904039611369e+43*cos(theta)**63 - 3.12749124981462e+43*cos(theta)**61 + 6.40191161874806e+43*cos(theta)**59 - 1.06449667440991e+44*cos(theta)**57 + 1.46460059686052e+44*cos(theta)**55 - 1.6899237656083e+44*cos(theta)**53 + 1.65157088582144e+44*cos(theta)**51 - 1.37720920825529e+44*cos(theta)**49 + 9.85156951890646e+43*cos(theta)**47 - 6.06811774925236e+43*cos(theta)**45 + 3.22633543059067e+43*cos(theta)**43 - 1.48263658718747e+43*cos(theta)**41 + 5.8903197746789e+42*cos(theta)**39 - 2.02164286847479e+42*cos(theta)**37 + 5.98406289068537e+41*cos(theta)**35 - 1.52354189985357e+41*cos(theta)**33 + 3.32409141786234e+40*cos(theta)**31 - 6.1852841508843e+39*cos(theta)**29 + 9.75612030015161e+38*cos(theta)**27 - 1.29466851620159e+38*cos(theta)**25 + 1.4321554382761e+37*cos(theta)**23 - 1.30571288606794e+36*cos(theta)**21 + 9.67536012964951e+34*cos(theta)**19 - 5.72684867487043e+33*cos(theta)**17 + 2.64915448905571e+32*cos(theta)**15 - 9.31239442085201e+30*cos(theta)**13 + 2.3972500489322e+29*cos(theta)**11 - 4.29614704109713e+27*cos(theta)**9 + 4.98264476415904e+25*cos(theta)**7 - 3.33765677981946e+23*cos(theta)**5 + 1.05555242878541e+21*cos(theta)**3 - 9.94240906234292e+17*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl80_m_minus_8(theta, phi):
    return 2.90850160163363e-15*(1.0 - cos(theta)**2)**4*(8.89883151603594e+37*cos(theta)**72 - 1.43052914182314e+39*cos(theta)**70 + 1.10023180812193e+40*cos(theta)**68 - 5.38995281484251e+40*cos(theta)**66 + 1.88912561892764e+41*cos(theta)**64 - 5.04434072550746e+41*cos(theta)**62 + 1.06698526979134e+42*cos(theta)**60 - 1.83533909381018e+42*cos(theta)**58 + 2.61535820867951e+42*cos(theta)**56 - 3.12948845483018e+42*cos(theta)**54 + 3.17609785734893e+42*cos(theta)**52 - 2.75441841651058e+42*cos(theta)**50 + 2.05241031643885e+42*cos(theta)**48 - 1.31915603244616e+42*cos(theta)**46 + 7.33258052406971e+41*cos(theta)**44 - 3.53008711235112e+41*cos(theta)**42 + 1.47257994366972e+41*cos(theta)**40 - 5.32011281177575e+40*cos(theta)**38 + 1.66223969185705e+40*cos(theta)**36 - 4.48100558780462e+39*cos(theta)**34 + 1.03877856808198e+39*cos(theta)**32 - 2.0617613836281e+38*cos(theta)**30 + 3.48432867862558e+37*cos(theta)**28 - 4.97949429308305e+36*cos(theta)**26 + 5.96731432615041e+35*cos(theta)**24 - 5.93505857303609e+34*cos(theta)**22 + 4.83768006482476e+33*cos(theta)**20 - 3.18158259715024e+32*cos(theta)**18 + 1.65572155565982e+31*cos(theta)**16 - 6.65171030060858e+29*cos(theta)**14 + 1.99770837411017e+28*cos(theta)**12 - 4.29614704109713e+26*cos(theta)**10 + 6.22830595519881e+24*cos(theta)**8 - 5.56276129969909e+22*cos(theta)**6 + 2.63888107196352e+20*cos(theta)**4 - 4.97120453117146e+17*cos(theta)**2 + 155156196353666.0)*sin(8*phi)

#@torch.jit.script
def Yl80_m_minus_7(theta, phi):
    return 2.33115995127995e-13*(1.0 - cos(theta)**2)**3.5*(1.21901801589533e+36*cos(theta)**73 - 2.01482977721569e+37*cos(theta)**71 + 1.59453885235063e+38*cos(theta)**69 - 8.04470569379479e+38*cos(theta)**67 + 2.90634710604253e+39*cos(theta)**65 - 8.00689004048803e+39*cos(theta)**63 + 1.74915617998581e+40*cos(theta)**61 - 3.11074422679692e+40*cos(theta)**59 + 4.58834773452545e+40*cos(theta)**57 - 5.68997900878215e+40*cos(theta)**55 + 5.99263746669609e+40*cos(theta)**53 - 5.40082042453055e+40*cos(theta)**51 + 4.18859248252826e+40*cos(theta)**49 - 2.80671496265141e+40*cos(theta)**47 + 1.62946233868216e+40*cos(theta)**45 - 8.20950491244446e+39*cos(theta)**43 + 3.59165839919445e+39*cos(theta)**41 - 1.36413149019891e+39*cos(theta)**39 + 4.49253970772175e+38*cos(theta)**37 - 1.28028731080132e+38*cos(theta)**35 + 3.14781384267267e+37*cos(theta)**33 - 6.65084317299387e+36*cos(theta)**31 + 1.20149264780192e+36*cos(theta)**29 - 1.84425714558632e+35*cos(theta)**27 + 2.38692573046017e+34*cos(theta)**25 - 2.58046024914612e+33*cos(theta)**23 + 2.30365717372607e+32*cos(theta)**21 - 1.67451715639486e+31*cos(theta)**19 + 9.73953856270481e+29*cos(theta)**17 - 4.43447353373905e+28*cos(theta)**15 + 1.53669874931551e+27*cos(theta)**13 - 3.90558821917921e+25*cos(theta)**11 + 6.92033995022089e+23*cos(theta)**9 - 7.94680185671299e+21*cos(theta)**7 + 5.27776214392703e+19*cos(theta)**5 - 1.65706817705715e+17*cos(theta)**3 + 155156196353666.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl80_m_minus_6(theta, phi):
    return 1.87045627196658e-11*(1.0 - cos(theta)**2)**3*(1.6473216431018e+34*cos(theta)**74 - 2.79837469057734e+35*cos(theta)**72 + 2.27791264621519e+36*cos(theta)**70 - 1.18304495496982e+37*cos(theta)**68 + 4.40355622127656e+37*cos(theta)**66 - 1.25107656882625e+38*cos(theta)**64 + 2.8212196451384e+38*cos(theta)**62 - 5.1845737113282e+38*cos(theta)**60 + 7.91094436987147e+38*cos(theta)**58 - 1.01606768013967e+39*cos(theta)**56 + 1.10974767901779e+39*cos(theta)**54 - 1.03861931240972e+39*cos(theta)**52 + 8.37718496505651e+38*cos(theta)**50 - 5.84732283885711e+38*cos(theta)**48 + 3.54230943191773e+38*cos(theta)**46 - 1.8657965710101e+38*cos(theta)**44 + 8.55156761712964e+37*cos(theta)**42 - 3.41032872549728e+37*cos(theta)**40 + 1.18224729150572e+37*cos(theta)**38 - 3.55635364111478e+36*cos(theta)**36 + 9.25827600786078e+35*cos(theta)**34 - 2.07838849156058e+35*cos(theta)**32 + 4.00497549267308e+34*cos(theta)**30 - 6.58663266280827e+33*cos(theta)**28 + 9.18048357869294e+32*cos(theta)**26 - 1.07519177047755e+32*cos(theta)**24 + 1.04711689714822e+31*cos(theta)**22 - 8.37258578197431e+29*cos(theta)**20 + 5.41085475705823e+28*cos(theta)**18 - 2.77154595858691e+27*cos(theta)**16 + 1.09764196379679e+26*cos(theta)**14 - 3.25465684931601e+24*cos(theta)**12 + 6.9203399502209e+22*cos(theta)**10 - 9.93350232089124e+20*cos(theta)**8 + 8.79627023987839e+18*cos(theta)**6 - 4.14267044264288e+16*cos(theta)**4 + 77578098176833.0*cos(theta)**2 - 24100061564.7198)*sin(6*phi)

#@torch.jit.script
def Yl80_m_minus_5(theta, phi):
    return 1.50219882144266e-9*(1.0 - cos(theta)**2)**2.5*(2.19642885746907e+32*cos(theta)**75 - 3.83338998709225e+33*cos(theta)**73 + 3.20832767072561e+34*cos(theta)**71 - 1.71455790575337e+35*cos(theta)**69 + 6.57247197205457e+35*cos(theta)**67 - 1.92473318280962e+36*cos(theta)**65 + 4.4781264208546e+36*cos(theta)**63 - 8.4993011661118e+36*cos(theta)**61 + 1.34083802879177e+37*cos(theta)**59 - 1.78257487743802e+37*cos(theta)**57 + 2.01772305275963e+37*cos(theta)**55 - 1.95965908001834e+37*cos(theta)**53 + 1.64258528726598e+37*cos(theta)**51 - 1.19333119160349e+37*cos(theta)**49 + 7.53682857854837e+36*cos(theta)**47 - 4.14621460224468e+36*cos(theta)**45 + 1.98873665514643e+36*cos(theta)**43 - 8.31787494023726e+35*cos(theta)**41 + 3.03140331155314e+35*cos(theta)**39 - 9.6117665976075e+34*cos(theta)**37 + 2.64522171653165e+34*cos(theta)**35 - 6.29814694412298e+33*cos(theta)**33 + 1.29192757828164e+33*cos(theta)**31 - 2.27125264234768e+32*cos(theta)**29 + 3.40017910321961e+31*cos(theta)**27 - 4.30076708191021e+30*cos(theta)**25 + 4.55268216151398e+29*cos(theta)**23 - 3.98694561046396e+28*cos(theta)**21 + 2.84781829318854e+27*cos(theta)**19 - 1.63032115210995e+26*cos(theta)**17 + 7.31761309197863e+24*cos(theta)**15 - 2.50358219178155e+23*cos(theta)**13 + 6.29121813656445e+21*cos(theta)**11 - 1.10372248009903e+20*cos(theta)**9 + 1.25661003426834e+18*cos(theta)**7 - 8.28534088528577e+15*cos(theta)**5 + 25859366058944.3*cos(theta)**3 - 24100061564.7198*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl80_m_minus_4(theta, phi):
    return 1.20737916134363e-7*(1.0 - cos(theta)**2)**2*(2.89003797035404e+30*cos(theta)**76 - 5.18025673931385e+31*cos(theta)**74 + 4.45601065378557e+32*cos(theta)**72 - 2.44936843679052e+33*cos(theta)**70 + 9.66539995890378e+33*cos(theta)**68 - 2.9162623981964e+34*cos(theta)**66 + 6.99707253258532e+34*cos(theta)**64 - 1.37085502679223e+35*cos(theta)**62 + 2.23473004798629e+35*cos(theta)**60 - 3.07340496110003e+35*cos(theta)**58 + 3.6030768799279e+35*cos(theta)**56 - 3.62899829633026e+35*cos(theta)**54 + 3.15881786012689e+35*cos(theta)**52 - 2.38666238320698e+35*cos(theta)**50 + 1.57017262053091e+35*cos(theta)**48 - 9.01351000487973e+34*cos(theta)**46 + 4.5198560344237e+34*cos(theta)**44 - 1.98044641434221e+34*cos(theta)**42 + 7.57850827888284e+33*cos(theta)**40 - 2.52941226252829e+33*cos(theta)**38 + 7.34783810147681e+32*cos(theta)**36 - 1.85239616003617e+32*cos(theta)**34 + 4.03727368213012e+31*cos(theta)**32 - 7.57084214115893e+30*cos(theta)**30 + 1.21434967972129e+30*cos(theta)**28 - 1.65414118535008e+29*cos(theta)**26 + 1.89695090063083e+28*cos(theta)**24 - 1.81224800475634e+27*cos(theta)**22 + 1.42390914659427e+26*cos(theta)**20 - 9.05733973394414e+24*cos(theta)**18 + 4.57350818248664e+23*cos(theta)**16 - 1.78827299412968e+22*cos(theta)**14 + 5.24268178047037e+20*cos(theta)**12 - 1.10372248009903e+19*cos(theta)**10 + 1.57076254283543e+17*cos(theta)**8 - 1.38089014754763e+15*cos(theta)**6 + 6464841514736.08*cos(theta)**4 - 12050030782.3599*cos(theta)**2 + 3730659.68494114)*sin(4*phi)

#@torch.jit.script
def Yl80_m_minus_3(theta, phi):
    return 9.71021132264824e-6*(1.0 - cos(theta)**2)**1.5*(3.75329606539486e+28*cos(theta)**77 - 6.9070089857518e+29*cos(theta)**75 + 6.10412418326791e+30*cos(theta)**73 - 3.44981469970496e+31*cos(theta)**71 + 1.40078260273968e+32*cos(theta)**69 - 4.35263044506925e+32*cos(theta)**67 + 1.07647269732082e+33*cos(theta)**65 - 2.17596035998766e+33*cos(theta)**63 + 3.66349188194474e+33*cos(theta)**61 - 5.209160951017e+33*cos(theta)**59 + 6.32118750864545e+33*cos(theta)**57 - 6.59817872060048e+33*cos(theta)**55 + 5.96003369835262e+33*cos(theta)**53 - 4.67973016315095e+33*cos(theta)**51 + 3.20443391945084e+33*cos(theta)**49 - 1.91776808614462e+33*cos(theta)**47 + 1.00441245209416e+33*cos(theta)**45 - 4.60568933567955e+32*cos(theta)**43 + 1.84841665338606e+32*cos(theta)**41 - 6.48567246802126e+31*cos(theta)**39 + 1.98590218958833e+31*cos(theta)**37 - 5.2925604572462e+30*cos(theta)**35 + 1.22341626731216e+30*cos(theta)**33 - 2.44220714230933e+29*cos(theta)**31 + 4.1874126886941e+28*cos(theta)**29 - 6.12644883462993e+27*cos(theta)**27 + 7.5878036025233e+26*cos(theta)**25 - 7.87933915111454e+25*cos(theta)**23 + 6.780519745687e+24*cos(theta)**21 - 4.76702091260218e+23*cos(theta)**19 + 2.6902989308745e+22*cos(theta)**17 - 1.19218199608645e+21*cos(theta)**15 + 4.03283213882337e+19*cos(theta)**13 - 1.0033840728173e+18*cos(theta)**11 + 1.74529171426159e+16*cos(theta)**9 - 197270021078233.0*cos(theta)**7 + 1292968302947.22*cos(theta)**5 - 4016676927.4533*cos(theta)**3 + 3730659.68494114*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl80_m_minus_2(theta, phi):
    return 0.000781294971343069*(1.0 - cos(theta)**2)*(4.81191803255751e+26*cos(theta)**78 - 9.08816971809447e+27*cos(theta)**76 + 8.24881646387556e+28*cos(theta)**74 - 4.79140930514578e+29*cos(theta)**72 + 2.00111800391383e+30*cos(theta)**70 - 6.40092712510184e+30*cos(theta)**68 + 1.63101923836488e+31*cos(theta)**66 - 3.39993806248072e+31*cos(theta)**64 + 5.90885787410442e+31*cos(theta)**62 - 8.68193491836166e+31*cos(theta)**60 + 1.0898599152837e+32*cos(theta)**58 - 1.17824620010723e+32*cos(theta)**56 + 1.10370994413937e+32*cos(theta)**54 - 8.99948108298259e+31*cos(theta)**52 + 6.40886783890167e+31*cos(theta)**50 - 3.99535017946797e+31*cos(theta)**48 + 2.18350533063947e+31*cos(theta)**46 - 1.04674757629081e+31*cos(theta)**44 + 4.40099203187157e+30*cos(theta)**42 - 1.62141811700531e+30*cos(theta)**40 + 5.22605839365349e+29*cos(theta)**38 - 1.47015568256839e+29*cos(theta)**36 + 3.5982831391534e+28*cos(theta)**34 - 7.63189731971667e+27*cos(theta)**32 + 1.3958042295647e+27*cos(theta)**30 - 2.18801744093926e+26*cos(theta)**28 + 2.9183860009705e+25*cos(theta)**26 - 3.28305797963106e+24*cos(theta)**24 + 3.08205442985773e+23*cos(theta)**22 - 2.38351045630109e+22*cos(theta)**20 + 1.4946105171525e+21*cos(theta)**18 - 7.45113747554031e+19*cos(theta)**16 + 2.88059438487383e+18*cos(theta)**14 - 8.36153394014414e+16*cos(theta)**12 + 1.74529171426159e+15*cos(theta)**10 - 24658752634779.1*cos(theta)**8 + 215494717157.869*cos(theta)**6 - 1004169231.86332*cos(theta)**4 + 1865329.84247057*cos(theta)**2 - 576.252654454919)*sin(2*phi)

#@torch.jit.script
def Yl80_m_minus_1(theta, phi):
    return 0.06288332552664*(1.0 - cos(theta)**2)**0.5*(6.09103548425002e+24*cos(theta)**79 - 1.18028178157071e+26*cos(theta)**77 + 1.09984219518341e+27*cos(theta)**75 - 6.56357439061066e+27*cos(theta)**73 + 2.81847606185046e+28*cos(theta)**71 - 9.27670597840846e+28*cos(theta)**69 + 2.43435707218638e+29*cos(theta)**67 - 5.23067394227803e+29*cos(theta)**65 + 9.37913948270543e+29*cos(theta)**63 - 1.42326801940355e+30*cos(theta)**61 + 1.8472201953961e+30*cos(theta)**59 - 2.06709859667935e+30*cos(theta)**57 + 2.00674535298068e+30*cos(theta)**55 - 1.69801529867596e+30*cos(theta)**53 + 1.25664075272582e+30*cos(theta)**51 - 8.15377587646524e+29*cos(theta)**49 + 4.64575602263717e+29*cos(theta)**47 - 2.32610572509068e+29*cos(theta)**45 + 1.0234865190399e+29*cos(theta)**43 - 3.9546783341593e+28*cos(theta)**41 + 1.34001497273166e+28*cos(theta)**39 - 3.97339373667132e+27*cos(theta)**37 + 1.02808089690097e+27*cos(theta)**35 - 2.3126961574899e+26*cos(theta)**33 + 4.50259428891839e+25*cos(theta)**31 - 7.54488772737676e+24*cos(theta)**29 + 1.08088370406315e+24*cos(theta)**27 - 1.31322319185242e+23*cos(theta)**25 + 1.34002366515553e+22*cos(theta)**23 - 1.13500497919099e+21*cos(theta)**21 + 7.86637114290788e+19*cos(theta)**19 - 4.38302204443548e+18*cos(theta)**17 + 1.92039625658255e+17*cos(theta)**15 - 6.43194918472626e+15*cos(theta)**13 + 158662883114690.0*cos(theta)**11 - 2739861403864.34*cos(theta)**9 + 30784959593.9814*cos(theta)**7 - 200833846.372665*cos(theta)**5 + 621776.614156857*cos(theta)**3 - 576.252654454919*cos(theta))*sin(phi)

#@torch.jit.script
def Yl80_m0(theta, phi):
    return 8.56168058322919e+23*cos(theta)**80 - 1.70156670710718e+25*cos(theta)**78 + 1.62732637625569e+26*cos(theta)**76 - 9.97393585447038e+26*cos(theta)**74 + 4.40189554622949e+27*cos(theta)**72 - 1.49023112796855e+28*cos(theta)**70 + 4.02562435575398e+28*cos(theta)**68 - 8.91192641633388e+28*cos(theta)**66 + 1.64793811750312e+29*cos(theta)**64 - 2.58138558266223e+29*cos(theta)**62 + 3.46198591263424e+29*cos(theta)**60 - 4.00766191325219e+29*cos(theta)**58 + 4.02960166825174e+29*cos(theta)**56 - 3.53594676302432e+29*cos(theta)**54 + 2.71747573463362e+29*cos(theta)**52 - 1.83377751863826e+29*cos(theta)**50 + 1.08836117264141e+29*cos(theta)**48 - 5.68629644622284e+28*cos(theta)**46 + 2.61569636526251e+28*cos(theta)**44 - 1.05881418978962e+28*cos(theta)**42 + 3.76710337772256e+27*cos(theta)**40 - 1.17580657648003e+27*cos(theta)**38 + 3.21131322169954e+26*cos(theta)**36 - 7.64887459232782e+25*cos(theta)**34 + 1.58223401412091e+25*cos(theta)**32 - 2.82806512073503e+24*cos(theta)**30 + 4.34089035822067e+23*cos(theta)**28 - 5.67966962757845e+22*cos(theta)**26 + 6.27854635701699e+21*cos(theta)**24 - 5.80140205737091e+20*cos(theta)**22 + 4.42285107344119e+19*cos(theta)**20 - 2.73816130320569e+18*cos(theta)**18 + 1.34967358051054e+17*cos(theta)**16 - 5.16621466224128e+15*cos(theta)**14 + 148679802107513.0*cos(theta)**12 - 3080962932212.21*cos(theta)**10 + 43271951295.1152*cos(theta)**8 - 376394730.122158*cos(theta)**6 + 1747963.14298216*cos(theta)**4 - 3239.96875436915*cos(theta)**2 + 0.999990356286776

#@torch.jit.script
def Yl80_m1(theta, phi):
    return 0.06288332552664*(1.0 - cos(theta)**2)**0.5*(6.09103548425002e+24*cos(theta)**79 - 1.18028178157071e+26*cos(theta)**77 + 1.09984219518341e+27*cos(theta)**75 - 6.56357439061066e+27*cos(theta)**73 + 2.81847606185046e+28*cos(theta)**71 - 9.27670597840846e+28*cos(theta)**69 + 2.43435707218638e+29*cos(theta)**67 - 5.23067394227803e+29*cos(theta)**65 + 9.37913948270543e+29*cos(theta)**63 - 1.42326801940355e+30*cos(theta)**61 + 1.8472201953961e+30*cos(theta)**59 - 2.06709859667935e+30*cos(theta)**57 + 2.00674535298068e+30*cos(theta)**55 - 1.69801529867596e+30*cos(theta)**53 + 1.25664075272582e+30*cos(theta)**51 - 8.15377587646524e+29*cos(theta)**49 + 4.64575602263717e+29*cos(theta)**47 - 2.32610572509068e+29*cos(theta)**45 + 1.0234865190399e+29*cos(theta)**43 - 3.9546783341593e+28*cos(theta)**41 + 1.34001497273166e+28*cos(theta)**39 - 3.97339373667132e+27*cos(theta)**37 + 1.02808089690097e+27*cos(theta)**35 - 2.3126961574899e+26*cos(theta)**33 + 4.50259428891839e+25*cos(theta)**31 - 7.54488772737676e+24*cos(theta)**29 + 1.08088370406315e+24*cos(theta)**27 - 1.31322319185242e+23*cos(theta)**25 + 1.34002366515553e+22*cos(theta)**23 - 1.13500497919099e+21*cos(theta)**21 + 7.86637114290788e+19*cos(theta)**19 - 4.38302204443548e+18*cos(theta)**17 + 1.92039625658255e+17*cos(theta)**15 - 6.43194918472626e+15*cos(theta)**13 + 158662883114690.0*cos(theta)**11 - 2739861403864.34*cos(theta)**9 + 30784959593.9814*cos(theta)**7 - 200833846.372665*cos(theta)**5 + 621776.614156857*cos(theta)**3 - 576.252654454919*cos(theta))*cos(phi)

#@torch.jit.script
def Yl80_m2(theta, phi):
    return 0.000781294971343069*(1.0 - cos(theta)**2)*(4.81191803255751e+26*cos(theta)**78 - 9.08816971809447e+27*cos(theta)**76 + 8.24881646387556e+28*cos(theta)**74 - 4.79140930514578e+29*cos(theta)**72 + 2.00111800391383e+30*cos(theta)**70 - 6.40092712510184e+30*cos(theta)**68 + 1.63101923836488e+31*cos(theta)**66 - 3.39993806248072e+31*cos(theta)**64 + 5.90885787410442e+31*cos(theta)**62 - 8.68193491836166e+31*cos(theta)**60 + 1.0898599152837e+32*cos(theta)**58 - 1.17824620010723e+32*cos(theta)**56 + 1.10370994413937e+32*cos(theta)**54 - 8.99948108298259e+31*cos(theta)**52 + 6.40886783890167e+31*cos(theta)**50 - 3.99535017946797e+31*cos(theta)**48 + 2.18350533063947e+31*cos(theta)**46 - 1.04674757629081e+31*cos(theta)**44 + 4.40099203187157e+30*cos(theta)**42 - 1.62141811700531e+30*cos(theta)**40 + 5.22605839365349e+29*cos(theta)**38 - 1.47015568256839e+29*cos(theta)**36 + 3.5982831391534e+28*cos(theta)**34 - 7.63189731971667e+27*cos(theta)**32 + 1.3958042295647e+27*cos(theta)**30 - 2.18801744093926e+26*cos(theta)**28 + 2.9183860009705e+25*cos(theta)**26 - 3.28305797963106e+24*cos(theta)**24 + 3.08205442985773e+23*cos(theta)**22 - 2.38351045630109e+22*cos(theta)**20 + 1.4946105171525e+21*cos(theta)**18 - 7.45113747554031e+19*cos(theta)**16 + 2.88059438487383e+18*cos(theta)**14 - 8.36153394014414e+16*cos(theta)**12 + 1.74529171426159e+15*cos(theta)**10 - 24658752634779.1*cos(theta)**8 + 215494717157.869*cos(theta)**6 - 1004169231.86332*cos(theta)**4 + 1865329.84247057*cos(theta)**2 - 576.252654454919)*cos(2*phi)

#@torch.jit.script
def Yl80_m3(theta, phi):
    return 9.71021132264824e-6*(1.0 - cos(theta)**2)**1.5*(3.75329606539486e+28*cos(theta)**77 - 6.9070089857518e+29*cos(theta)**75 + 6.10412418326791e+30*cos(theta)**73 - 3.44981469970496e+31*cos(theta)**71 + 1.40078260273968e+32*cos(theta)**69 - 4.35263044506925e+32*cos(theta)**67 + 1.07647269732082e+33*cos(theta)**65 - 2.17596035998766e+33*cos(theta)**63 + 3.66349188194474e+33*cos(theta)**61 - 5.209160951017e+33*cos(theta)**59 + 6.32118750864545e+33*cos(theta)**57 - 6.59817872060048e+33*cos(theta)**55 + 5.96003369835262e+33*cos(theta)**53 - 4.67973016315095e+33*cos(theta)**51 + 3.20443391945084e+33*cos(theta)**49 - 1.91776808614462e+33*cos(theta)**47 + 1.00441245209416e+33*cos(theta)**45 - 4.60568933567955e+32*cos(theta)**43 + 1.84841665338606e+32*cos(theta)**41 - 6.48567246802126e+31*cos(theta)**39 + 1.98590218958833e+31*cos(theta)**37 - 5.2925604572462e+30*cos(theta)**35 + 1.22341626731216e+30*cos(theta)**33 - 2.44220714230933e+29*cos(theta)**31 + 4.1874126886941e+28*cos(theta)**29 - 6.12644883462993e+27*cos(theta)**27 + 7.5878036025233e+26*cos(theta)**25 - 7.87933915111454e+25*cos(theta)**23 + 6.780519745687e+24*cos(theta)**21 - 4.76702091260218e+23*cos(theta)**19 + 2.6902989308745e+22*cos(theta)**17 - 1.19218199608645e+21*cos(theta)**15 + 4.03283213882337e+19*cos(theta)**13 - 1.0033840728173e+18*cos(theta)**11 + 1.74529171426159e+16*cos(theta)**9 - 197270021078233.0*cos(theta)**7 + 1292968302947.22*cos(theta)**5 - 4016676927.4533*cos(theta)**3 + 3730659.68494114*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl80_m4(theta, phi):
    return 1.20737916134363e-7*(1.0 - cos(theta)**2)**2*(2.89003797035404e+30*cos(theta)**76 - 5.18025673931385e+31*cos(theta)**74 + 4.45601065378557e+32*cos(theta)**72 - 2.44936843679052e+33*cos(theta)**70 + 9.66539995890378e+33*cos(theta)**68 - 2.9162623981964e+34*cos(theta)**66 + 6.99707253258532e+34*cos(theta)**64 - 1.37085502679223e+35*cos(theta)**62 + 2.23473004798629e+35*cos(theta)**60 - 3.07340496110003e+35*cos(theta)**58 + 3.6030768799279e+35*cos(theta)**56 - 3.62899829633026e+35*cos(theta)**54 + 3.15881786012689e+35*cos(theta)**52 - 2.38666238320698e+35*cos(theta)**50 + 1.57017262053091e+35*cos(theta)**48 - 9.01351000487973e+34*cos(theta)**46 + 4.5198560344237e+34*cos(theta)**44 - 1.98044641434221e+34*cos(theta)**42 + 7.57850827888284e+33*cos(theta)**40 - 2.52941226252829e+33*cos(theta)**38 + 7.34783810147681e+32*cos(theta)**36 - 1.85239616003617e+32*cos(theta)**34 + 4.03727368213012e+31*cos(theta)**32 - 7.57084214115893e+30*cos(theta)**30 + 1.21434967972129e+30*cos(theta)**28 - 1.65414118535008e+29*cos(theta)**26 + 1.89695090063083e+28*cos(theta)**24 - 1.81224800475634e+27*cos(theta)**22 + 1.42390914659427e+26*cos(theta)**20 - 9.05733973394414e+24*cos(theta)**18 + 4.57350818248664e+23*cos(theta)**16 - 1.78827299412968e+22*cos(theta)**14 + 5.24268178047037e+20*cos(theta)**12 - 1.10372248009903e+19*cos(theta)**10 + 1.57076254283543e+17*cos(theta)**8 - 1.38089014754763e+15*cos(theta)**6 + 6464841514736.08*cos(theta)**4 - 12050030782.3599*cos(theta)**2 + 3730659.68494114)*cos(4*phi)

#@torch.jit.script
def Yl80_m5(theta, phi):
    return 1.50219882144266e-9*(1.0 - cos(theta)**2)**2.5*(2.19642885746907e+32*cos(theta)**75 - 3.83338998709225e+33*cos(theta)**73 + 3.20832767072561e+34*cos(theta)**71 - 1.71455790575337e+35*cos(theta)**69 + 6.57247197205457e+35*cos(theta)**67 - 1.92473318280962e+36*cos(theta)**65 + 4.4781264208546e+36*cos(theta)**63 - 8.4993011661118e+36*cos(theta)**61 + 1.34083802879177e+37*cos(theta)**59 - 1.78257487743802e+37*cos(theta)**57 + 2.01772305275963e+37*cos(theta)**55 - 1.95965908001834e+37*cos(theta)**53 + 1.64258528726598e+37*cos(theta)**51 - 1.19333119160349e+37*cos(theta)**49 + 7.53682857854837e+36*cos(theta)**47 - 4.14621460224468e+36*cos(theta)**45 + 1.98873665514643e+36*cos(theta)**43 - 8.31787494023726e+35*cos(theta)**41 + 3.03140331155314e+35*cos(theta)**39 - 9.6117665976075e+34*cos(theta)**37 + 2.64522171653165e+34*cos(theta)**35 - 6.29814694412298e+33*cos(theta)**33 + 1.29192757828164e+33*cos(theta)**31 - 2.27125264234768e+32*cos(theta)**29 + 3.40017910321961e+31*cos(theta)**27 - 4.30076708191021e+30*cos(theta)**25 + 4.55268216151398e+29*cos(theta)**23 - 3.98694561046396e+28*cos(theta)**21 + 2.84781829318854e+27*cos(theta)**19 - 1.63032115210995e+26*cos(theta)**17 + 7.31761309197863e+24*cos(theta)**15 - 2.50358219178155e+23*cos(theta)**13 + 6.29121813656445e+21*cos(theta)**11 - 1.10372248009903e+20*cos(theta)**9 + 1.25661003426834e+18*cos(theta)**7 - 8.28534088528577e+15*cos(theta)**5 + 25859366058944.3*cos(theta)**3 - 24100061564.7198*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl80_m6(theta, phi):
    return 1.87045627196658e-11*(1.0 - cos(theta)**2)**3*(1.6473216431018e+34*cos(theta)**74 - 2.79837469057734e+35*cos(theta)**72 + 2.27791264621519e+36*cos(theta)**70 - 1.18304495496982e+37*cos(theta)**68 + 4.40355622127656e+37*cos(theta)**66 - 1.25107656882625e+38*cos(theta)**64 + 2.8212196451384e+38*cos(theta)**62 - 5.1845737113282e+38*cos(theta)**60 + 7.91094436987147e+38*cos(theta)**58 - 1.01606768013967e+39*cos(theta)**56 + 1.10974767901779e+39*cos(theta)**54 - 1.03861931240972e+39*cos(theta)**52 + 8.37718496505651e+38*cos(theta)**50 - 5.84732283885711e+38*cos(theta)**48 + 3.54230943191773e+38*cos(theta)**46 - 1.8657965710101e+38*cos(theta)**44 + 8.55156761712964e+37*cos(theta)**42 - 3.41032872549728e+37*cos(theta)**40 + 1.18224729150572e+37*cos(theta)**38 - 3.55635364111478e+36*cos(theta)**36 + 9.25827600786078e+35*cos(theta)**34 - 2.07838849156058e+35*cos(theta)**32 + 4.00497549267308e+34*cos(theta)**30 - 6.58663266280827e+33*cos(theta)**28 + 9.18048357869294e+32*cos(theta)**26 - 1.07519177047755e+32*cos(theta)**24 + 1.04711689714822e+31*cos(theta)**22 - 8.37258578197431e+29*cos(theta)**20 + 5.41085475705823e+28*cos(theta)**18 - 2.77154595858691e+27*cos(theta)**16 + 1.09764196379679e+26*cos(theta)**14 - 3.25465684931601e+24*cos(theta)**12 + 6.9203399502209e+22*cos(theta)**10 - 9.93350232089124e+20*cos(theta)**8 + 8.79627023987839e+18*cos(theta)**6 - 4.14267044264288e+16*cos(theta)**4 + 77578098176833.0*cos(theta)**2 - 24100061564.7198)*cos(6*phi)

#@torch.jit.script
def Yl80_m7(theta, phi):
    return 2.33115995127995e-13*(1.0 - cos(theta)**2)**3.5*(1.21901801589533e+36*cos(theta)**73 - 2.01482977721569e+37*cos(theta)**71 + 1.59453885235063e+38*cos(theta)**69 - 8.04470569379479e+38*cos(theta)**67 + 2.90634710604253e+39*cos(theta)**65 - 8.00689004048803e+39*cos(theta)**63 + 1.74915617998581e+40*cos(theta)**61 - 3.11074422679692e+40*cos(theta)**59 + 4.58834773452545e+40*cos(theta)**57 - 5.68997900878215e+40*cos(theta)**55 + 5.99263746669609e+40*cos(theta)**53 - 5.40082042453055e+40*cos(theta)**51 + 4.18859248252826e+40*cos(theta)**49 - 2.80671496265141e+40*cos(theta)**47 + 1.62946233868216e+40*cos(theta)**45 - 8.20950491244446e+39*cos(theta)**43 + 3.59165839919445e+39*cos(theta)**41 - 1.36413149019891e+39*cos(theta)**39 + 4.49253970772175e+38*cos(theta)**37 - 1.28028731080132e+38*cos(theta)**35 + 3.14781384267267e+37*cos(theta)**33 - 6.65084317299387e+36*cos(theta)**31 + 1.20149264780192e+36*cos(theta)**29 - 1.84425714558632e+35*cos(theta)**27 + 2.38692573046017e+34*cos(theta)**25 - 2.58046024914612e+33*cos(theta)**23 + 2.30365717372607e+32*cos(theta)**21 - 1.67451715639486e+31*cos(theta)**19 + 9.73953856270481e+29*cos(theta)**17 - 4.43447353373905e+28*cos(theta)**15 + 1.53669874931551e+27*cos(theta)**13 - 3.90558821917921e+25*cos(theta)**11 + 6.92033995022089e+23*cos(theta)**9 - 7.94680185671299e+21*cos(theta)**7 + 5.27776214392703e+19*cos(theta)**5 - 1.65706817705715e+17*cos(theta)**3 + 155156196353666.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl80_m8(theta, phi):
    return 2.90850160163363e-15*(1.0 - cos(theta)**2)**4*(8.89883151603594e+37*cos(theta)**72 - 1.43052914182314e+39*cos(theta)**70 + 1.10023180812193e+40*cos(theta)**68 - 5.38995281484251e+40*cos(theta)**66 + 1.88912561892764e+41*cos(theta)**64 - 5.04434072550746e+41*cos(theta)**62 + 1.06698526979134e+42*cos(theta)**60 - 1.83533909381018e+42*cos(theta)**58 + 2.61535820867951e+42*cos(theta)**56 - 3.12948845483018e+42*cos(theta)**54 + 3.17609785734893e+42*cos(theta)**52 - 2.75441841651058e+42*cos(theta)**50 + 2.05241031643885e+42*cos(theta)**48 - 1.31915603244616e+42*cos(theta)**46 + 7.33258052406971e+41*cos(theta)**44 - 3.53008711235112e+41*cos(theta)**42 + 1.47257994366972e+41*cos(theta)**40 - 5.32011281177575e+40*cos(theta)**38 + 1.66223969185705e+40*cos(theta)**36 - 4.48100558780462e+39*cos(theta)**34 + 1.03877856808198e+39*cos(theta)**32 - 2.0617613836281e+38*cos(theta)**30 + 3.48432867862558e+37*cos(theta)**28 - 4.97949429308305e+36*cos(theta)**26 + 5.96731432615041e+35*cos(theta)**24 - 5.93505857303609e+34*cos(theta)**22 + 4.83768006482476e+33*cos(theta)**20 - 3.18158259715024e+32*cos(theta)**18 + 1.65572155565982e+31*cos(theta)**16 - 6.65171030060858e+29*cos(theta)**14 + 1.99770837411017e+28*cos(theta)**12 - 4.29614704109713e+26*cos(theta)**10 + 6.22830595519881e+24*cos(theta)**8 - 5.56276129969909e+22*cos(theta)**6 + 2.63888107196352e+20*cos(theta)**4 - 4.97120453117146e+17*cos(theta)**2 + 155156196353666.0)*cos(8*phi)

#@torch.jit.script
def Yl80_m9(theta, phi):
    return 3.63335686319938e-17*(1.0 - cos(theta)**2)**4.5*(6.40715869154588e+39*cos(theta)**71 - 1.0013703992762e+41*cos(theta)**69 + 7.48157629522916e+41*cos(theta)**67 - 3.55736885779606e+42*cos(theta)**65 + 1.20904039611369e+43*cos(theta)**63 - 3.12749124981462e+43*cos(theta)**61 + 6.40191161874806e+43*cos(theta)**59 - 1.06449667440991e+44*cos(theta)**57 + 1.46460059686052e+44*cos(theta)**55 - 1.6899237656083e+44*cos(theta)**53 + 1.65157088582144e+44*cos(theta)**51 - 1.37720920825529e+44*cos(theta)**49 + 9.85156951890646e+43*cos(theta)**47 - 6.06811774925236e+43*cos(theta)**45 + 3.22633543059067e+43*cos(theta)**43 - 1.48263658718747e+43*cos(theta)**41 + 5.8903197746789e+42*cos(theta)**39 - 2.02164286847479e+42*cos(theta)**37 + 5.98406289068537e+41*cos(theta)**35 - 1.52354189985357e+41*cos(theta)**33 + 3.32409141786234e+40*cos(theta)**31 - 6.1852841508843e+39*cos(theta)**29 + 9.75612030015161e+38*cos(theta)**27 - 1.29466851620159e+38*cos(theta)**25 + 1.4321554382761e+37*cos(theta)**23 - 1.30571288606794e+36*cos(theta)**21 + 9.67536012964951e+34*cos(theta)**19 - 5.72684867487043e+33*cos(theta)**17 + 2.64915448905571e+32*cos(theta)**15 - 9.31239442085201e+30*cos(theta)**13 + 2.3972500489322e+29*cos(theta)**11 - 4.29614704109713e+27*cos(theta)**9 + 4.98264476415904e+25*cos(theta)**7 - 3.33765677981946e+23*cos(theta)**5 + 1.05555242878541e+21*cos(theta)**3 - 9.94240906234292e+17*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl80_m10(theta, phi):
    return 4.54524844252942e-19*(1.0 - cos(theta)**2)**5*(4.54908267099757e+41*cos(theta)**70 - 6.90945575500575e+42*cos(theta)**68 + 5.01265611780353e+43*cos(theta)**66 - 2.31228975756744e+44*cos(theta)**64 + 7.61695449551626e+44*cos(theta)**62 - 1.90776966238692e+45*cos(theta)**60 + 3.77712785506135e+45*cos(theta)**58 - 6.06763104413646e+45*cos(theta)**56 + 8.05530328273289e+45*cos(theta)**54 - 8.95659595772398e+45*cos(theta)**52 + 8.42301151768936e+45*cos(theta)**50 - 6.74832512045092e+45*cos(theta)**48 + 4.63023767388604e+45*cos(theta)**46 - 2.73065298716356e+45*cos(theta)**44 + 1.38732423515399e+45*cos(theta)**42 - 6.07881000746862e+44*cos(theta)**40 + 2.29722471212477e+44*cos(theta)**38 - 7.48007861335671e+43*cos(theta)**36 + 2.09442201173988e+43*cos(theta)**34 - 5.02768826951678e+42*cos(theta)**32 + 1.03046833953732e+42*cos(theta)**30 - 1.79373240375645e+41*cos(theta)**28 + 2.63415248104094e+40*cos(theta)**26 - 3.23667129050398e+39*cos(theta)**24 + 3.29395750803503e+38*cos(theta)**22 - 2.74199706074267e+37*cos(theta)**20 + 1.83831842463341e+36*cos(theta)**18 - 9.73564274727973e+34*cos(theta)**16 + 3.97373173358356e+33*cos(theta)**14 - 1.21061127471076e+32*cos(theta)**12 + 2.63697505382542e+30*cos(theta)**10 - 3.86653233698742e+28*cos(theta)**8 + 3.48785133491133e+26*cos(theta)**6 - 1.66882838990973e+24*cos(theta)**4 + 3.16665728635622e+21*cos(theta)**2 - 9.94240906234292e+17)*cos(10*phi)

#@torch.jit.script
def Yl80_m11(theta, phi):
    return 5.69492370894745e-21*(1.0 - cos(theta)**2)**5.5*(3.1843578696983e+43*cos(theta)**69 - 4.69842991340391e+44*cos(theta)**67 + 3.30835303775033e+45*cos(theta)**65 - 1.47986544484316e+46*cos(theta)**63 + 4.72251178722008e+46*cos(theta)**61 - 1.14466179743215e+47*cos(theta)**59 + 2.19073415593558e+47*cos(theta)**57 - 3.39787338471642e+47*cos(theta)**55 + 4.34986377267576e+47*cos(theta)**53 - 4.65742989801647e+47*cos(theta)**51 + 4.21150575884468e+47*cos(theta)**49 - 3.23919605781644e+47*cos(theta)**47 + 2.12990932998758e+47*cos(theta)**45 - 1.20148731435197e+47*cos(theta)**43 + 5.82676178764675e+46*cos(theta)**41 - 2.43152400298745e+46*cos(theta)**39 + 8.72945390607413e+45*cos(theta)**37 - 2.69282830080842e+45*cos(theta)**35 + 7.12103483991559e+44*cos(theta)**33 - 1.60886024624537e+44*cos(theta)**31 + 3.09140501861197e+43*cos(theta)**29 - 5.02245073051805e+42*cos(theta)**27 + 6.84879645070643e+41*cos(theta)**25 - 7.76801109720956e+40*cos(theta)**23 + 7.24670651767706e+39*cos(theta)**21 - 5.48399412148534e+38*cos(theta)**19 + 3.30897316434013e+37*cos(theta)**17 - 1.55770283956476e+36*cos(theta)**15 + 5.56322442701699e+34*cos(theta)**13 - 1.45273352965291e+33*cos(theta)**11 + 2.63697505382542e+31*cos(theta)**9 - 3.09322586958993e+29*cos(theta)**7 + 2.0927108009468e+27*cos(theta)**5 - 6.67531355963891e+24*cos(theta)**3 + 6.33331457271244e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl80_m12(theta, phi):
    return 7.14775160081563e-23*(1.0 - cos(theta)**2)**6*(2.19720693009183e+45*cos(theta)**68 - 3.14794804198062e+46*cos(theta)**66 + 2.15042947453772e+47*cos(theta)**64 - 9.32315230251191e+47*cos(theta)**62 + 2.88073219020425e+48*cos(theta)**60 - 6.7535046048497e+48*cos(theta)**58 + 1.24871846888328e+49*cos(theta)**56 - 1.86883036159403e+49*cos(theta)**54 + 2.30542779951815e+49*cos(theta)**52 - 2.3752892479884e+49*cos(theta)**50 + 2.06363782183389e+49*cos(theta)**48 - 1.52242214717373e+49*cos(theta)**46 + 9.5845919849441e+48*cos(theta)**44 - 5.16639545171345e+48*cos(theta)**42 + 2.38897233293517e+48*cos(theta)**40 - 9.48294361165105e+47*cos(theta)**38 + 3.22989794524743e+47*cos(theta)**36 - 9.42489905282946e+46*cos(theta)**34 + 2.34994149717214e+46*cos(theta)**32 - 4.98746676336065e+45*cos(theta)**30 + 8.96507455397472e+44*cos(theta)**28 - 1.35606169723987e+44*cos(theta)**26 + 1.71219911267661e+43*cos(theta)**24 - 1.7866425523582e+42*cos(theta)**22 + 1.52180836871218e+41*cos(theta)**20 - 1.04195888308222e+40*cos(theta)**18 + 5.62525437937823e+38*cos(theta)**16 - 2.33655425934713e+37*cos(theta)**14 + 7.23219175512208e+35*cos(theta)**12 - 1.5980068826182e+34*cos(theta)**10 + 2.37327754844288e+32*cos(theta)**8 - 2.16525810871295e+30*cos(theta)**6 + 1.0463554004734e+28*cos(theta)**4 - 2.00259406789167e+25*cos(theta)**2 + 6.33331457271244e+21)*cos(12*phi)

#@torch.jit.script
def Yl80_m13(theta, phi):
    return 8.988216418622e-25*(1.0 - cos(theta)**2)**6.5*(1.49410071246244e+47*cos(theta)**67 - 2.07764570770721e+48*cos(theta)**65 + 1.37627486370414e+49*cos(theta)**63 - 5.78035442755738e+49*cos(theta)**61 + 1.72843931412255e+50*cos(theta)**59 - 3.91703267081283e+50*cos(theta)**57 + 6.99282342574639e+50*cos(theta)**55 - 1.00916839526078e+51*cos(theta)**53 + 1.19882245574944e+51*cos(theta)**51 - 1.1876446239942e+51*cos(theta)**49 + 9.90546154480269e+50*cos(theta)**47 - 7.00314187699915e+50*cos(theta)**45 + 4.2172204733754e+50*cos(theta)**43 - 2.16988608971965e+50*cos(theta)**41 + 9.55588933174068e+49*cos(theta)**39 - 3.6035185724274e+49*cos(theta)**37 + 1.16276326028907e+49*cos(theta)**35 - 3.20446567796201e+48*cos(theta)**33 + 7.51981279095086e+47*cos(theta)**31 - 1.49624002900819e+47*cos(theta)**29 + 2.51022087511292e+46*cos(theta)**27 - 3.52576041282367e+45*cos(theta)**25 + 4.10927787042386e+44*cos(theta)**23 - 3.93061361518804e+43*cos(theta)**21 + 3.04361673742437e+42*cos(theta)**19 - 1.87552598954799e+41*cos(theta)**17 + 9.00040700700516e+39*cos(theta)**15 - 3.27117596308599e+38*cos(theta)**13 + 8.6786301061465e+36*cos(theta)**11 - 1.5980068826182e+35*cos(theta)**9 + 1.8986220387543e+33*cos(theta)**7 - 1.29915486522777e+31*cos(theta)**5 + 4.1854216018936e+28*cos(theta)**3 - 4.00518813578335e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl80_m14(theta, phi):
    return 1.13258861756036e-26*(1.0 - cos(theta)**2)**7*(1.00104747734984e+49*cos(theta)**66 - 1.35046971000969e+50*cos(theta)**64 + 8.67053164133607e+50*cos(theta)**62 - 3.52601620081e+51*cos(theta)**60 + 1.0197791953323e+52*cos(theta)**58 - 2.23270862236331e+52*cos(theta)**56 + 3.84605288416051e+52*cos(theta)**54 - 5.34859249488211e+52*cos(theta)**52 + 6.11399452432214e+52*cos(theta)**50 - 5.81945865757158e+52*cos(theta)**48 + 4.65556692605726e+52*cos(theta)**46 - 3.15141384464962e+52*cos(theta)**44 + 1.81340480355142e+52*cos(theta)**42 - 8.89653296785057e+51*cos(theta)**40 + 3.72679683937886e+51*cos(theta)**38 - 1.33330187179814e+51*cos(theta)**36 + 4.06967141101176e+50*cos(theta)**34 - 1.05747367372746e+50*cos(theta)**32 + 2.33114196519477e+49*cos(theta)**30 - 4.33909608412376e+48*cos(theta)**28 + 6.77759636280489e+47*cos(theta)**26 - 8.81440103205918e+46*cos(theta)**24 + 9.45133910197488e+45*cos(theta)**22 - 8.25428859189488e+44*cos(theta)**20 + 5.7828718011063e+43*cos(theta)**18 - 3.18839418223158e+42*cos(theta)**16 + 1.35006105105077e+41*cos(theta)**14 - 4.25252875201179e+39*cos(theta)**12 + 9.54649311676115e+37*cos(theta)**10 - 1.43820619435638e+36*cos(theta)**8 + 1.32903542712801e+34*cos(theta)**6 - 6.49577432613886e+31*cos(theta)**4 + 1.25562648056808e+29*cos(theta)**2 - 4.00518813578335e+25)*cos(14*phi)

#@torch.jit.script
def Yl80_m15(theta, phi):
    return 1.43033716183798e-28*(1.0 - cos(theta)**2)**7.5*(6.60691335050892e+50*cos(theta)**65 - 8.64300614406199e+51*cos(theta)**63 + 5.37572961762836e+52*cos(theta)**61 - 2.115609720486e+53*cos(theta)**59 + 5.91471933292737e+53*cos(theta)**57 - 1.25031682852345e+54*cos(theta)**55 + 2.07686855744668e+54*cos(theta)**53 - 2.7812680973387e+54*cos(theta)**51 + 3.05699726216107e+54*cos(theta)**49 - 2.79334015563436e+54*cos(theta)**47 + 2.14156078598634e+54*cos(theta)**45 - 1.38662209164583e+54*cos(theta)**43 + 7.61630017491598e+53*cos(theta)**41 - 3.55861318714023e+53*cos(theta)**39 + 1.41618279896397e+53*cos(theta)**37 - 4.7998867384733e+52*cos(theta)**35 + 1.383688279744e+52*cos(theta)**33 - 3.38391575592789e+51*cos(theta)**31 + 6.9934258955843e+50*cos(theta)**29 - 1.21494690355465e+50*cos(theta)**27 + 1.76217505432927e+49*cos(theta)**25 - 2.1154562476942e+48*cos(theta)**23 + 2.07929460243447e+47*cos(theta)**21 - 1.65085771837898e+46*cos(theta)**19 + 1.04091692419913e+45*cos(theta)**17 - 5.10143069157053e+43*cos(theta)**15 + 1.89008547147108e+42*cos(theta)**13 - 5.10303450241414e+40*cos(theta)**11 + 9.54649311676115e+38*cos(theta)**9 - 1.15056495548511e+37*cos(theta)**7 + 7.97421256276807e+34*cos(theta)**5 - 2.59830973045555e+32*cos(theta)**3 + 2.51125296113616e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl80_m16(theta, phi):
    return 1.81069843999506e-30*(1.0 - cos(theta)**2)**8*(4.2944936778308e+52*cos(theta)**64 - 5.44509387075905e+53*cos(theta)**62 + 3.2791950667533e+54*cos(theta)**60 - 1.24820973508674e+55*cos(theta)**58 + 3.3713900197686e+55*cos(theta)**56 - 6.876742556879e+55*cos(theta)**54 + 1.10074033544674e+56*cos(theta)**52 - 1.41844672964274e+56*cos(theta)**50 + 1.49792865845892e+56*cos(theta)**48 - 1.31286987314815e+56*cos(theta)**46 + 9.63702353693853e+55*cos(theta)**44 - 5.96247499407708e+55*cos(theta)**42 + 3.12268307171555e+55*cos(theta)**40 - 1.38785914298469e+55*cos(theta)**38 + 5.23987635616668e+54*cos(theta)**36 - 1.67996035846565e+54*cos(theta)**34 + 4.56617132315519e+53*cos(theta)**32 - 1.04901388433765e+53*cos(theta)**30 + 2.02809350971945e+52*cos(theta)**28 - 3.28035663959757e+51*cos(theta)**26 + 4.40543763582318e+50*cos(theta)**24 - 4.86554936969667e+49*cos(theta)**22 + 4.36651866511239e+48*cos(theta)**20 - 3.13662966492005e+47*cos(theta)**18 + 1.76955877113853e+46*cos(theta)**16 - 7.65214603735579e+44*cos(theta)**14 + 2.45711111291241e+43*cos(theta)**12 - 5.61333795265556e+41*cos(theta)**10 + 8.59184380508504e+39*cos(theta)**8 - 8.05395468839575e+37*cos(theta)**6 + 3.98710628138403e+35*cos(theta)**4 - 7.79492919136664e+32*cos(theta)**2 + 2.51125296113616e+29)*cos(16*phi)

#@torch.jit.script
def Yl80_m17(theta, phi):
    return 2.29810714657801e-32*(1.0 - cos(theta)**2)**8.5*(2.74847595381171e+54*cos(theta)**63 - 3.37595819987061e+55*cos(theta)**61 + 1.96751704005198e+56*cos(theta)**59 - 7.2396164635031e+56*cos(theta)**57 + 1.88797841107042e+57*cos(theta)**55 - 3.71344098071466e+57*cos(theta)**53 + 5.72384974432304e+57*cos(theta)**51 - 7.09223364821368e+57*cos(theta)**49 + 7.19005756060284e+57*cos(theta)**47 - 6.03920141648148e+57*cos(theta)**45 + 4.24029035625295e+57*cos(theta)**43 - 2.50423949751237e+57*cos(theta)**41 + 1.24907322868622e+57*cos(theta)**39 - 5.27386474334182e+56*cos(theta)**37 + 1.88635548822001e+56*cos(theta)**35 - 5.71186521878322e+55*cos(theta)**33 + 1.46117482340966e+55*cos(theta)**31 - 3.14704165301294e+54*cos(theta)**29 + 5.67866182721445e+53*cos(theta)**27 - 8.52892726295367e+52*cos(theta)**25 + 1.05730503259756e+52*cos(theta)**23 - 1.07042086133327e+51*cos(theta)**21 + 8.73303733022478e+49*cos(theta)**19 - 5.6459333968561e+48*cos(theta)**17 + 2.83129403382164e+47*cos(theta)**15 - 1.07130044522981e+46*cos(theta)**13 + 2.94853333549489e+44*cos(theta)**11 - 5.61333795265556e+42*cos(theta)**9 + 6.87347504406803e+40*cos(theta)**7 - 4.83237281303745e+38*cos(theta)**5 + 1.59484251255361e+36*cos(theta)**3 - 1.55898583827333e+33*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl80_m18(theta, phi):
    return 2.92473795258218e-34*(1.0 - cos(theta)**2)**9*(1.73153985090138e+56*cos(theta)**62 - 2.05933450192107e+57*cos(theta)**60 + 1.16083505363067e+58*cos(theta)**58 - 4.12658138419677e+58*cos(theta)**56 + 1.03838812608873e+59*cos(theta)**54 - 1.96812371977877e+59*cos(theta)**52 + 2.91916336960475e+59*cos(theta)**50 - 3.4751944876247e+59*cos(theta)**48 + 3.37932705348333e+59*cos(theta)**46 - 2.71764063741667e+59*cos(theta)**44 + 1.82332485318877e+59*cos(theta)**42 - 1.02673819398007e+59*cos(theta)**40 + 4.87138559187626e+58*cos(theta)**38 - 1.95132995503647e+58*cos(theta)**36 + 6.60224420877002e+57*cos(theta)**34 - 1.88491552219846e+57*cos(theta)**32 + 4.52964195256995e+56*cos(theta)**30 - 9.12642079373751e+55*cos(theta)**28 + 1.5332386933479e+55*cos(theta)**26 - 2.13223181573842e+54*cos(theta)**24 + 2.43180157497439e+53*cos(theta)**22 - 2.24788380879986e+52*cos(theta)**20 + 1.65927709274271e+51*cos(theta)**18 - 9.59808677465537e+49*cos(theta)**16 + 4.24694105073246e+48*cos(theta)**14 - 1.39269057879875e+47*cos(theta)**12 + 3.24338666904438e+45*cos(theta)**10 - 5.05200415739e+43*cos(theta)**8 + 4.81143253084762e+41*cos(theta)**6 - 2.41618640651872e+39*cos(theta)**4 + 4.78452753766084e+36*cos(theta)**2 - 1.55898583827333e+33)*cos(18*phi)

#@torch.jit.script
def Yl80_m19(theta, phi):
    return 3.73313348056284e-36*(1.0 - cos(theta)**2)**9.5*(1.07355470755885e+58*cos(theta)**61 - 1.23560070115264e+59*cos(theta)**59 + 6.73284331105788e+59*cos(theta)**57 - 2.31088557515019e+60*cos(theta)**55 + 5.60729588087913e+60*cos(theta)**53 - 1.02342433428496e+61*cos(theta)**51 + 1.45958168480238e+61*cos(theta)**49 - 1.66809335405986e+61*cos(theta)**47 + 1.55449044460233e+61*cos(theta)**45 - 1.19576188046333e+61*cos(theta)**43 + 7.65796438339284e+60*cos(theta)**41 - 4.10695277592029e+60*cos(theta)**39 + 1.85112652491298e+60*cos(theta)**37 - 7.0247878381313e+59*cos(theta)**35 + 2.24476303098181e+59*cos(theta)**33 - 6.03172967103508e+58*cos(theta)**31 + 1.35889258577099e+58*cos(theta)**29 - 2.5553978222465e+57*cos(theta)**27 + 3.98642060270454e+56*cos(theta)**25 - 5.1173563577722e+55*cos(theta)**23 + 5.34996346494367e+54*cos(theta)**21 - 4.49576761759972e+53*cos(theta)**19 + 2.98669876693688e+52*cos(theta)**17 - 1.53569388394486e+51*cos(theta)**15 + 5.94571747102545e+49*cos(theta)**13 - 1.6712286945585e+48*cos(theta)**11 + 3.24338666904438e+46*cos(theta)**9 - 4.041603325912e+44*cos(theta)**7 + 2.88685951850857e+42*cos(theta)**5 - 9.6647456260749e+39*cos(theta)**3 + 9.56905507532168e+36*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl80_m20(theta, phi):
    return 4.77978763224299e-38*(1.0 - cos(theta)**2)**10*(6.54868371610901e+59*cos(theta)**60 - 7.2900441368006e+60*cos(theta)**58 + 3.83772068730299e+61*cos(theta)**56 - 1.2709870663326e+62*cos(theta)**54 + 2.97186681686594e+62*cos(theta)**52 - 5.2194641048533e+62*cos(theta)**50 + 7.15195025553164e+62*cos(theta)**48 - 7.84003876408133e+62*cos(theta)**46 + 6.9952070007105e+62*cos(theta)**44 - 5.14177608599233e+62*cos(theta)**42 + 3.13976539719106e+62*cos(theta)**40 - 1.60171158260891e+62*cos(theta)**38 + 6.84916814217802e+61*cos(theta)**36 - 2.45867574334596e+61*cos(theta)**34 + 7.40771800223996e+60*cos(theta)**32 - 1.86983619802088e+60*cos(theta)**30 + 3.94078849873586e+59*cos(theta)**28 - 6.89957412006556e+58*cos(theta)**26 + 9.96605150676136e+57*cos(theta)**24 - 1.17699196228761e+57*cos(theta)**22 + 1.12349232763817e+56*cos(theta)**20 - 8.54195847343947e+54*cos(theta)**18 + 5.07738790379269e+53*cos(theta)**16 - 2.30354082591729e+52*cos(theta)**14 + 7.72943271233308e+50*cos(theta)**12 - 1.83835156401436e+49*cos(theta)**10 + 2.91904800213994e+47*cos(theta)**8 - 2.8291223281384e+45*cos(theta)**6 + 1.44342975925429e+43*cos(theta)**4 - 2.89942368782247e+40*cos(theta)**2 + 9.56905507532168e+36)*cos(20*phi)

#@torch.jit.script
def Yl80_m21(theta, phi):
    return 6.14005539172387e-40*(1.0 - cos(theta)**2)**10.5*(3.92921022966541e+61*cos(theta)**59 - 4.22822559934435e+62*cos(theta)**57 + 2.14912358488968e+63*cos(theta)**55 - 6.86333015819606e+63*cos(theta)**53 + 1.54537074477029e+64*cos(theta)**51 - 2.60973205242665e+64*cos(theta)**49 + 3.43293612265519e+64*cos(theta)**47 - 3.60641783147741e+64*cos(theta)**45 + 3.07789108031262e+64*cos(theta)**43 - 2.15954595611678e+64*cos(theta)**41 + 1.25590615887643e+64*cos(theta)**39 - 6.08650401391387e+63*cos(theta)**37 + 2.46570053118409e+63*cos(theta)**35 - 8.35949752737625e+62*cos(theta)**33 + 2.37046976071679e+62*cos(theta)**31 - 5.60950859406263e+61*cos(theta)**29 + 1.10342077964604e+61*cos(theta)**27 - 1.79388927121705e+60*cos(theta)**25 + 2.39185236162273e+59*cos(theta)**23 - 2.58938231703273e+58*cos(theta)**21 + 2.24698465527634e+57*cos(theta)**19 - 1.5375525252191e+56*cos(theta)**17 + 8.1238206460683e+54*cos(theta)**15 - 3.2249571562842e+53*cos(theta)**13 + 9.2753192547997e+51*cos(theta)**11 - 1.83835156401436e+50*cos(theta)**9 + 2.33523840171195e+48*cos(theta)**7 - 1.69747339688304e+46*cos(theta)**5 + 5.77371903701714e+43*cos(theta)**3 - 5.79884737564494e+40*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl80_m22(theta, phi):
    return 7.91491394567412e-42*(1.0 - cos(theta)**2)**11*(2.31823403550259e+63*cos(theta)**58 - 2.41008859162628e+64*cos(theta)**56 + 1.18201797168932e+65*cos(theta)**54 - 3.63756498384391e+65*cos(theta)**52 + 7.88139079832848e+65*cos(theta)**50 - 1.27876870568906e+66*cos(theta)**48 + 1.61347997764794e+66*cos(theta)**46 - 1.62288802416484e+66*cos(theta)**44 + 1.32349316453443e+66*cos(theta)**42 - 8.8541384200788e+65*cos(theta)**40 + 4.89803401961806e+65*cos(theta)**38 - 2.25200648514813e+65*cos(theta)**36 + 8.6299518591443e+64*cos(theta)**34 - 2.75863418403416e+64*cos(theta)**32 + 7.34845625822204e+63*cos(theta)**30 - 1.62675749227816e+63*cos(theta)**28 + 2.97923610504431e+62*cos(theta)**26 - 4.48472317804261e+61*cos(theta)**24 + 5.50126043173227e+60*cos(theta)**22 - 5.43770286576874e+59*cos(theta)**20 + 4.26927084502505e+58*cos(theta)**18 - 2.61383929287248e+57*cos(theta)**16 + 1.21857309691025e+56*cos(theta)**14 - 4.19244430316946e+54*cos(theta)**12 + 1.02028511802797e+53*cos(theta)**10 - 1.65451640761292e+51*cos(theta)**8 + 1.63466688119837e+49*cos(theta)**6 - 8.4873669844152e+46*cos(theta)**4 + 1.73211571110514e+44*cos(theta)**2 - 5.79884737564494e+40)*cos(22*phi)

#@torch.jit.script
def Yl80_m23(theta, phi):
    return 1.02403214176887e-43*(1.0 - cos(theta)**2)**11.5*(1.3445757405915e+65*cos(theta)**57 - 1.34964961131072e+66*cos(theta)**55 + 6.38289704712234e+66*cos(theta)**53 - 1.89153379159883e+67*cos(theta)**51 + 3.94069539916424e+67*cos(theta)**49 - 6.13808978730747e+67*cos(theta)**47 + 7.42200789718052e+67*cos(theta)**45 - 7.14070730632528e+67*cos(theta)**43 + 5.55867129104459e+67*cos(theta)**41 - 3.54165536803152e+67*cos(theta)**39 + 1.86125292745486e+67*cos(theta)**37 - 8.10722334653328e+66*cos(theta)**35 + 2.93418363210906e+66*cos(theta)**33 - 8.82762938890932e+65*cos(theta)**31 + 2.20453687746661e+65*cos(theta)**29 - 4.55492097837885e+64*cos(theta)**27 + 7.7460138731152e+63*cos(theta)**25 - 1.07633356273023e+63*cos(theta)**23 + 1.2102772949811e+62*cos(theta)**21 - 1.08754057315375e+61*cos(theta)**19 + 7.68468752104508e+59*cos(theta)**17 - 4.18214286859596e+58*cos(theta)**15 + 1.70600233567434e+57*cos(theta)**13 - 5.03093316380336e+55*cos(theta)**11 + 1.02028511802797e+54*cos(theta)**9 - 1.32361312609034e+52*cos(theta)**7 + 9.80800128719021e+49*cos(theta)**5 - 3.39494679376608e+47*cos(theta)**3 + 3.46423142221029e+44*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl80_m24(theta, phi):
    return 1.33002403975092e-45*(1.0 - cos(theta)**2)**12*(7.66408172137157e+66*cos(theta)**56 - 7.42307286220894e+67*cos(theta)**54 + 3.38293543497484e+68*cos(theta)**52 - 9.64682233715406e+68*cos(theta)**50 + 1.93094074559048e+69*cos(theta)**48 - 2.88490220003451e+69*cos(theta)**46 + 3.33990355373123e+69*cos(theta)**44 - 3.07050414171987e+69*cos(theta)**42 + 2.27905522932828e+69*cos(theta)**40 - 1.38124559353229e+69*cos(theta)**38 + 6.88663583158299e+68*cos(theta)**36 - 2.83752817128665e+68*cos(theta)**34 + 9.68280598595991e+67*cos(theta)**32 - 2.73656511056189e+67*cos(theta)**30 + 6.39315694465318e+66*cos(theta)**28 - 1.22982866416229e+66*cos(theta)**26 + 1.9365034682788e+65*cos(theta)**24 - 2.47556719427952e+64*cos(theta)**22 + 2.54158231946031e+63*cos(theta)**20 - 2.06632708899212e+62*cos(theta)**18 + 1.30639687857766e+61*cos(theta)**16 - 6.27321430289394e+59*cos(theta)**14 + 2.21780303637665e+58*cos(theta)**12 - 5.53402648018369e+56*cos(theta)**10 + 9.1825660622517e+54*cos(theta)**8 - 9.26529188263235e+52*cos(theta)**6 + 4.9040006435951e+50*cos(theta)**4 - 1.01848403812982e+48*cos(theta)**2 + 3.46423142221029e+44)*cos(24*phi)

#@torch.jit.script
def Yl80_m25(theta, phi):
    return 1.73448611570411e-47*(1.0 - cos(theta)**2)**12.5*(4.29188576396808e+68*cos(theta)**55 - 4.00845934559283e+69*cos(theta)**53 + 1.75912642618692e+70*cos(theta)**51 - 4.82341116857703e+70*cos(theta)**49 + 9.26851557883429e+70*cos(theta)**47 - 1.32705501201588e+71*cos(theta)**45 + 1.46955756364174e+71*cos(theta)**43 - 1.28961173952234e+71*cos(theta)**41 + 9.11622091731313e+70*cos(theta)**39 - 5.24873325542271e+70*cos(theta)**37 + 2.47918889936988e+70*cos(theta)**35 - 9.6475957823746e+69*cos(theta)**33 + 3.09849791550717e+69*cos(theta)**31 - 8.20969533168567e+68*cos(theta)**29 + 1.79008394450289e+68*cos(theta)**27 - 3.19755452682196e+67*cos(theta)**25 + 4.64760832386912e+66*cos(theta)**23 - 5.44624782741495e+65*cos(theta)**21 + 5.08316463892062e+64*cos(theta)**19 - 3.71938876018582e+63*cos(theta)**17 + 2.09023500572426e+62*cos(theta)**15 - 8.78250002405152e+60*cos(theta)**13 + 2.66136364365198e+59*cos(theta)**11 - 5.53402648018369e+57*cos(theta)**9 + 7.34605284980136e+55*cos(theta)**7 - 5.55917512957941e+53*cos(theta)**5 + 1.96160025743804e+51*cos(theta)**3 - 2.03696807625965e+48*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl80_m26(theta, phi):
    return 2.27162453320221e-49*(1.0 - cos(theta)**2)**13*(2.36053717018244e+70*cos(theta)**54 - 2.1244834531642e+71*cos(theta)**52 + 8.97154477355327e+71*cos(theta)**50 - 2.36347147260274e+72*cos(theta)**48 + 4.35620232205211e+72*cos(theta)**46 - 5.97174755407144e+72*cos(theta)**44 + 6.31909752365949e+72*cos(theta)**42 - 5.28740813204162e+72*cos(theta)**40 + 3.55532615775212e+72*cos(theta)**38 - 1.9420313045064e+72*cos(theta)**36 + 8.67716114779457e+71*cos(theta)**34 - 3.18370660818362e+71*cos(theta)**32 + 9.60534353807223e+70*cos(theta)**30 - 2.38081164618884e+70*cos(theta)**28 + 4.8332266501578e+69*cos(theta)**26 - 7.99388631705489e+68*cos(theta)**24 + 1.0689499144899e+68*cos(theta)**22 - 1.14371204375714e+67*cos(theta)**20 + 9.65801281394918e+65*cos(theta)**18 - 6.32296089231589e+64*cos(theta)**16 + 3.13535250858639e+63*cos(theta)**14 - 1.1417250031267e+62*cos(theta)**12 + 2.92750000801717e+60*cos(theta)**10 - 4.98062383216532e+58*cos(theta)**8 + 5.14223699486095e+56*cos(theta)**6 - 2.7795875647897e+54*cos(theta)**4 + 5.88480077231412e+51*cos(theta)**2 - 2.03696807625965e+48)*cos(26*phi)

#@torch.jit.script
def Yl80_m27(theta, phi):
    return 2.98846230067311e-51*(1.0 - cos(theta)**2)**13.5*(1.27469007189852e+72*cos(theta)**53 - 1.10473139564538e+73*cos(theta)**51 + 4.48577238677664e+73*cos(theta)**49 - 1.13446630684932e+74*cos(theta)**47 + 2.00385306814397e+74*cos(theta)**45 - 2.62756892379143e+74*cos(theta)**43 + 2.65402095993699e+74*cos(theta)**41 - 2.11496325281665e+74*cos(theta)**39 + 1.35102393994581e+74*cos(theta)**37 - 6.99131269622305e+73*cos(theta)**35 + 2.95023479025015e+73*cos(theta)**33 - 1.01878611461876e+73*cos(theta)**31 + 2.88160306142167e+72*cos(theta)**29 - 6.66627260932876e+71*cos(theta)**27 + 1.25663892904103e+71*cos(theta)**25 - 1.91853271609317e+70*cos(theta)**23 + 2.35168981187778e+69*cos(theta)**21 - 2.28742408751428e+68*cos(theta)**19 + 1.73844230651085e+67*cos(theta)**17 - 1.01167374277054e+66*cos(theta)**15 + 4.38949351202095e+64*cos(theta)**13 - 1.37007000375204e+63*cos(theta)**11 + 2.92750000801717e+61*cos(theta)**9 - 3.98449906573226e+59*cos(theta)**7 + 3.08534219691657e+57*cos(theta)**5 - 1.11183502591588e+55*cos(theta)**3 + 1.17696015446282e+52*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl80_m28(theta, phi):
    return 3.95000794401284e-53*(1.0 - cos(theta)**2)**14*(6.75585738106215e+73*cos(theta)**52 - 5.63413011779145e+74*cos(theta)**50 + 2.19802846952055e+75*cos(theta)**48 - 5.33199164219179e+75*cos(theta)**46 + 9.01733880664788e+75*cos(theta)**44 - 1.12985463723032e+76*cos(theta)**42 + 1.08814859357416e+76*cos(theta)**40 - 8.24835668598492e+75*cos(theta)**38 + 4.99878857779948e+75*cos(theta)**36 - 2.44695944367807e+75*cos(theta)**34 + 9.7357748078255e+74*cos(theta)**32 - 3.15823695531815e+74*cos(theta)**30 + 8.35664887812284e+73*cos(theta)**28 - 1.79989360451877e+73*cos(theta)**26 + 3.14159732260257e+72*cos(theta)**24 - 4.4126252470143e+71*cos(theta)**22 + 4.93854860494333e+70*cos(theta)**20 - 4.34610576627713e+69*cos(theta)**18 + 2.95535192106845e+68*cos(theta)**16 - 1.51751061415581e+67*cos(theta)**14 + 5.70634156562724e+65*cos(theta)**12 - 1.50707700412724e+64*cos(theta)**10 + 2.63475000721546e+62*cos(theta)**8 - 2.78914934601258e+60*cos(theta)**6 + 1.54267109845829e+58*cos(theta)**4 - 3.33550507774765e+55*cos(theta)**2 + 1.17696015446282e+52)*cos(28*phi)

#@torch.jit.script
def Yl80_m29(theta, phi):
    return 5.24666153183604e-55*(1.0 - cos(theta)**2)**14.5*(3.51304583815232e+75*cos(theta)**51 - 2.81706505889573e+76*cos(theta)**49 + 1.05505366536986e+77*cos(theta)**47 - 2.45271615540822e+77*cos(theta)**45 + 3.96762907492507e+77*cos(theta)**43 - 4.74538947636733e+77*cos(theta)**41 + 4.35259437429666e+77*cos(theta)**39 - 3.13437554067427e+77*cos(theta)**37 + 1.79956388800781e+77*cos(theta)**35 - 8.31966210850543e+76*cos(theta)**33 + 3.11544793850416e+76*cos(theta)**31 - 9.47471086595445e+75*cos(theta)**29 + 2.33986168587439e+75*cos(theta)**27 - 4.67972337174879e+74*cos(theta)**25 + 7.53983357424617e+73*cos(theta)**23 - 9.70777554343146e+72*cos(theta)**21 + 9.87709720988666e+71*cos(theta)**19 - 7.82299037929883e+70*cos(theta)**17 + 4.72856307370952e+69*cos(theta)**15 - 2.12451485981814e+68*cos(theta)**13 + 6.84760987875268e+66*cos(theta)**11 - 1.50707700412724e+65*cos(theta)**9 + 2.10780000577237e+63*cos(theta)**7 - 1.67348960760755e+61*cos(theta)**5 + 6.17068439383314e+58*cos(theta)**3 - 6.67101015549529e+55*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl80_m30(theta, phi):
    return 7.00489480374217e-57*(1.0 - cos(theta)**2)**15*(1.79165337745768e+77*cos(theta)**50 - 1.38036187885891e+78*cos(theta)**48 + 4.95875222723836e+78*cos(theta)**46 - 1.1037222699337e+79*cos(theta)**44 + 1.70608050221778e+79*cos(theta)**42 - 1.94560968531061e+79*cos(theta)**40 + 1.6975118059757e+79*cos(theta)**38 - 1.15971895004948e+79*cos(theta)**36 + 6.29847360802735e+78*cos(theta)**34 - 2.74548849580679e+78*cos(theta)**32 + 9.6578886093629e+77*cos(theta)**30 - 2.74766615112679e+77*cos(theta)**28 + 6.31762655186087e+76*cos(theta)**26 - 1.1699308429372e+76*cos(theta)**24 + 1.73416172207662e+75*cos(theta)**22 - 2.03863286412061e+74*cos(theta)**20 + 1.87664846987846e+73*cos(theta)**18 - 1.3299083644808e+72*cos(theta)**16 + 7.09284461056428e+70*cos(theta)**14 - 2.76186931776358e+69*cos(theta)**12 + 7.53237086662795e+67*cos(theta)**10 - 1.35636930371452e+66*cos(theta)**8 + 1.47546000404066e+64*cos(theta)**6 - 8.36744803803774e+61*cos(theta)**4 + 1.85120531814994e+59*cos(theta)**2 - 6.67101015549529e+55)*cos(30*phi)

#@torch.jit.script
def Yl80_m31(theta, phi):
    return 9.40275512733762e-59*(1.0 - cos(theta)**2)**15.5*(8.95826688728841e+78*cos(theta)**49 - 6.62573701852275e+79*cos(theta)**47 + 2.28102602452965e+80*cos(theta)**45 - 4.85637798770828e+80*cos(theta)**43 + 7.16553810931467e+80*cos(theta)**41 - 7.78243874124242e+80*cos(theta)**39 + 6.45054486270765e+80*cos(theta)**37 - 4.17498822017813e+80*cos(theta)**35 + 2.1414810267293e+80*cos(theta)**33 - 8.78556318658173e+79*cos(theta)**31 + 2.89736658280887e+79*cos(theta)**29 - 7.69346522315501e+78*cos(theta)**27 + 1.64258290348383e+78*cos(theta)**25 - 2.80783402304927e+77*cos(theta)**23 + 3.81515578856856e+76*cos(theta)**21 - 4.07726572824121e+75*cos(theta)**19 + 3.37796724578124e+74*cos(theta)**17 - 2.12785338316928e+73*cos(theta)**15 + 9.92998245478999e+71*cos(theta)**13 - 3.3142431813163e+70*cos(theta)**11 + 7.53237086662795e+68*cos(theta)**9 - 1.08509544297161e+67*cos(theta)**7 + 8.85276002424393e+64*cos(theta)**5 - 3.3469792152151e+62*cos(theta)**3 + 3.70241063629989e+59*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl80_m32(theta, phi):
    return 1.26925263804963e-60*(1.0 - cos(theta)**2)**16*(4.38955077477132e+80*cos(theta)**48 - 3.11409639870569e+81*cos(theta)**46 + 1.02646171103834e+82*cos(theta)**44 - 2.08824253471456e+82*cos(theta)**42 + 2.93787062481901e+82*cos(theta)**40 - 3.03515110908455e+82*cos(theta)**38 + 2.38670159920183e+82*cos(theta)**36 - 1.46124587706234e+82*cos(theta)**34 + 7.06688738820668e+81*cos(theta)**32 - 2.72352458784034e+81*cos(theta)**30 + 8.40236309014572e+80*cos(theta)**28 - 2.07723561025185e+80*cos(theta)**26 + 4.10645725870956e+79*cos(theta)**24 - 6.45801825301333e+78*cos(theta)**22 + 8.01182715599398e+77*cos(theta)**20 - 7.7468048836583e+76*cos(theta)**18 + 5.7425443178281e+75*cos(theta)**16 - 3.19178007475392e+74*cos(theta)**14 + 1.2908977191227e+73*cos(theta)**12 - 3.64566749944793e+71*cos(theta)**10 + 6.77913377996516e+69*cos(theta)**8 - 7.59566810080129e+67*cos(theta)**6 + 4.42638001212197e+65*cos(theta)**4 - 1.00409376456453e+63*cos(theta)**2 + 3.70241063629989e+59)*cos(32*phi)

#@torch.jit.script
def Yl80_m33(theta, phi):
    return 1.72340851470193e-62*(1.0 - cos(theta)**2)**16.5*(2.10698437189023e+82*cos(theta)**47 - 1.43248434340462e+83*cos(theta)**45 + 4.5164315285687e+83*cos(theta)**43 - 8.77061864580116e+83*cos(theta)**41 + 1.17514824992761e+84*cos(theta)**39 - 1.15335742145213e+84*cos(theta)**37 + 8.59212575712658e+83*cos(theta)**35 - 4.96823598201197e+83*cos(theta)**33 + 2.26140396422614e+83*cos(theta)**31 - 8.17057376352101e+82*cos(theta)**29 + 2.3526616652408e+82*cos(theta)**27 - 5.40081258665482e+81*cos(theta)**25 + 9.85549742090295e+80*cos(theta)**23 - 1.42076401566293e+80*cos(theta)**21 + 1.6023654311988e+79*cos(theta)**19 - 1.39442487905849e+78*cos(theta)**17 + 9.18807090852496e+76*cos(theta)**15 - 4.46849210465549e+75*cos(theta)**13 + 1.54907726294724e+74*cos(theta)**11 - 3.64566749944793e+72*cos(theta)**9 + 5.42330702397212e+70*cos(theta)**7 - 4.55740086048078e+68*cos(theta)**5 + 1.77055200484879e+66*cos(theta)**3 - 2.00818752912906e+63*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl80_m34(theta, phi):
    return 2.35443594596275e-64*(1.0 - cos(theta)**2)**17*(9.9028265478841e+83*cos(theta)**46 - 6.44617954532078e+84*cos(theta)**44 + 1.94206555728454e+85*cos(theta)**42 - 3.59595364477847e+85*cos(theta)**40 + 4.58307817471766e+85*cos(theta)**38 - 4.26742245937287e+85*cos(theta)**36 + 3.0072440149943e+85*cos(theta)**34 - 1.63951787406395e+85*cos(theta)**32 + 7.01035228910103e+84*cos(theta)**30 - 2.36946639142109e+84*cos(theta)**28 + 6.35218649615017e+83*cos(theta)**26 - 1.3502031466637e+83*cos(theta)**24 + 2.26676440680768e+82*cos(theta)**22 - 2.98360443289216e+81*cos(theta)**20 + 3.04449431927771e+80*cos(theta)**18 - 2.37052229439944e+79*cos(theta)**16 + 1.37821063627874e+78*cos(theta)**14 - 5.80903973605214e+76*cos(theta)**12 + 1.70398498924196e+75*cos(theta)**10 - 3.28110074950314e+73*cos(theta)**8 + 3.79631491678049e+71*cos(theta)**6 - 2.27870043024039e+69*cos(theta)**4 + 5.31165601454636e+66*cos(theta)**2 - 2.00818752912906e+63)*cos(34*phi)

#@torch.jit.script
def Yl80_m35(theta, phi):
    return 3.23712182357191e-66*(1.0 - cos(theta)**2)**17.5*(4.55530021202669e+85*cos(theta)**45 - 2.83631899994114e+86*cos(theta)**43 + 8.15667534059508e+86*cos(theta)**41 - 1.43838145791139e+87*cos(theta)**39 + 1.74156970639271e+87*cos(theta)**37 - 1.53627208537423e+87*cos(theta)**35 + 1.02246296509806e+87*cos(theta)**33 - 5.24645719700464e+86*cos(theta)**31 + 2.10310568673031e+86*cos(theta)**29 - 6.63450589597906e+85*cos(theta)**27 + 1.65156848899904e+85*cos(theta)**25 - 3.24048755199289e+84*cos(theta)**23 + 4.98688169497689e+83*cos(theta)**21 - 5.96720886578432e+82*cos(theta)**19 + 5.48008977469988e+81*cos(theta)**17 - 3.7928356710391e+80*cos(theta)**15 + 1.92949489079024e+79*cos(theta)**13 - 6.97084768326257e+77*cos(theta)**11 + 1.70398498924196e+76*cos(theta)**9 - 2.62488059960251e+74*cos(theta)**7 + 2.27778895006829e+72*cos(theta)**5 - 9.11480172096155e+69*cos(theta)**3 + 1.06233120290927e+67*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl80_m36(theta, phi):
    return 4.48047225305905e-68*(1.0 - cos(theta)**2)**18*(2.04988509541201e+87*cos(theta)**44 - 1.21961716997469e+88*cos(theta)**42 + 3.34423688964398e+88*cos(theta)**40 - 5.60968768585442e+88*cos(theta)**38 + 6.44380791365303e+88*cos(theta)**36 - 5.37695229880982e+88*cos(theta)**34 + 3.37412778482361e+88*cos(theta)**32 - 1.62640173107144e+88*cos(theta)**30 + 6.0990064915179e+87*cos(theta)**28 - 1.79131659191435e+87*cos(theta)**26 + 4.12892122249761e+86*cos(theta)**24 - 7.45312136958365e+85*cos(theta)**22 + 1.04724515594515e+85*cos(theta)**20 - 1.13376968449902e+84*cos(theta)**18 + 9.3161526169898e+82*cos(theta)**16 - 5.68925350655866e+81*cos(theta)**14 + 2.50834335802731e+80*cos(theta)**12 - 7.66793245158883e+78*cos(theta)**10 + 1.53358649031777e+77*cos(theta)**8 - 1.83741641972176e+75*cos(theta)**6 + 1.13889447503415e+73*cos(theta)**4 - 2.73444051628847e+70*cos(theta)**2 + 1.06233120290927e+67)*cos(36*phi)

#@torch.jit.script
def Yl80_m37(theta, phi):
    return 6.2445985377985e-70*(1.0 - cos(theta)**2)**18.5*(9.01949441981284e+88*cos(theta)**43 - 5.12239211389371e+89*cos(theta)**41 + 1.33769475585759e+90*cos(theta)**39 - 2.13168132062468e+90*cos(theta)**37 + 2.31977084891509e+90*cos(theta)**35 - 1.82816378159534e+90*cos(theta)**33 + 1.07972089114356e+90*cos(theta)**31 - 4.87920519321432e+89*cos(theta)**29 + 1.70772181762501e+89*cos(theta)**27 - 4.6574231389773e+88*cos(theta)**25 + 9.90941093399426e+87*cos(theta)**23 - 1.6396867013084e+87*cos(theta)**21 + 2.0944903118903e+86*cos(theta)**19 - 2.04078543209824e+85*cos(theta)**17 + 1.49058441871837e+84*cos(theta)**15 - 7.96495490918212e+82*cos(theta)**13 + 3.01001202963278e+81*cos(theta)**11 - 7.66793245158883e+79*cos(theta)**9 + 1.22686919225421e+78*cos(theta)**7 - 1.10244985183305e+76*cos(theta)**5 + 4.55557790013658e+73*cos(theta)**3 - 5.46888103257693e+70*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl80_m38(theta, phi):
    return 8.7665616559847e-72*(1.0 - cos(theta)**2)**19*(3.87838260051952e+90*cos(theta)**42 - 2.10018076669642e+91*cos(theta)**40 + 5.21700954784461e+91*cos(theta)**38 - 7.88722088631131e+91*cos(theta)**36 + 8.11919797120282e+91*cos(theta)**34 - 6.03294047926461e+91*cos(theta)**32 + 3.34713476254502e+91*cos(theta)**30 - 1.41496950603215e+91*cos(theta)**28 + 4.61084890758753e+90*cos(theta)**26 - 1.16435578474433e+90*cos(theta)**24 + 2.27916451481868e+89*cos(theta)**22 - 3.44334207274765e+88*cos(theta)**20 + 3.97953159259156e+87*cos(theta)**18 - 3.469335234567e+86*cos(theta)**16 + 2.23587662807755e+85*cos(theta)**14 - 1.03544413819368e+84*cos(theta)**12 + 3.31101323259606e+82*cos(theta)**10 - 6.90113920642995e+80*cos(theta)**8 + 8.58808434577949e+78*cos(theta)**6 - 5.51224925916527e+76*cos(theta)**4 + 1.36667337004098e+74*cos(theta)**2 - 5.46888103257693e+70)*cos(38*phi)

#@torch.jit.script
def Yl80_m39(theta, phi):
    return 1.24002706914668e-73*(1.0 - cos(theta)**2)**19.5*(1.6289206922182e+92*cos(theta)**41 - 8.40072306678568e+92*cos(theta)**39 + 1.98246362818095e+93*cos(theta)**37 - 2.83939951907207e+93*cos(theta)**35 + 2.76052731020896e+93*cos(theta)**33 - 1.93054095336468e+93*cos(theta)**31 + 1.00414042876351e+93*cos(theta)**29 - 3.96191461689002e+92*cos(theta)**27 + 1.19882071597276e+92*cos(theta)**25 - 2.79445388338638e+91*cos(theta)**23 + 5.01416193260109e+90*cos(theta)**21 - 6.88668414549529e+89*cos(theta)**19 + 7.16315686666481e+88*cos(theta)**17 - 5.5509363753072e+87*cos(theta)**15 + 3.13022727930857e+86*cos(theta)**13 - 1.24253296583241e+85*cos(theta)**11 + 3.31101323259606e+83*cos(theta)**9 - 5.52091136514396e+81*cos(theta)**7 + 5.15285060746769e+79*cos(theta)**5 - 2.20489970366611e+77*cos(theta)**3 + 2.73334674008195e+74*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl80_m40(theta, phi):
    return 1.76786303191934e-75*(1.0 - cos(theta)**2)**20*(6.67857483809462e+93*cos(theta)**40 - 3.27628199604642e+94*cos(theta)**38 + 7.33511542426952e+94*cos(theta)**36 - 9.93789831675226e+94*cos(theta)**34 + 9.10974012368957e+94*cos(theta)**32 - 5.9846769554305e+94*cos(theta)**30 + 2.91200724341417e+94*cos(theta)**28 - 1.06971694656031e+94*cos(theta)**26 + 2.99705178993189e+93*cos(theta)**24 - 6.42724393178868e+92*cos(theta)**22 + 1.05297400584623e+92*cos(theta)**20 - 1.30846998764411e+91*cos(theta)**18 + 1.21773666733302e+90*cos(theta)**16 - 8.3264045629608e+88*cos(theta)**14 + 4.06929546310114e+87*cos(theta)**12 - 1.36678626241565e+86*cos(theta)**10 + 2.97991190933645e+84*cos(theta)**8 - 3.86463795560077e+82*cos(theta)**6 + 2.57642530373385e+80*cos(theta)**4 - 6.61469911099832e+77*cos(theta)**2 + 2.73334674008195e+74)*cos(40*phi)

#@torch.jit.script
def Yl80_m41(theta, phi):
    return 2.54112444185276e-77*(1.0 - cos(theta)**2)**20.5*(2.67142993523785e+95*cos(theta)**39 - 1.24498715849764e+96*cos(theta)**37 + 2.64064155273703e+96*cos(theta)**35 - 3.37888542769577e+96*cos(theta)**33 + 2.91511683958066e+96*cos(theta)**31 - 1.79540308662915e+96*cos(theta)**29 + 8.15362028155967e+95*cos(theta)**27 - 2.7812640610568e+95*cos(theta)**25 + 7.19292429583655e+94*cos(theta)**23 - 1.41399366499351e+94*cos(theta)**21 + 2.10594801169246e+93*cos(theta)**19 - 2.35524597775939e+92*cos(theta)**17 + 1.94837866773283e+91*cos(theta)**15 - 1.16569663881451e+90*cos(theta)**13 + 4.88315455572137e+88*cos(theta)**11 - 1.36678626241565e+87*cos(theta)**9 + 2.38392952746916e+85*cos(theta)**7 - 2.31878277336046e+83*cos(theta)**5 + 1.03057012149354e+81*cos(theta)**3 - 1.32293982219966e+78*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl80_m42(theta, phi):
    return 3.68394989380334e-79*(1.0 - cos(theta)**2)**21*(1.04185767474276e+97*cos(theta)**38 - 4.60645248644126e+97*cos(theta)**36 + 9.2422454345796e+97*cos(theta)**34 - 1.1150321911396e+98*cos(theta)**32 + 9.03686220270005e+97*cos(theta)**30 - 5.20666895122453e+97*cos(theta)**28 + 2.20147747602111e+97*cos(theta)**26 - 6.95316015264199e+96*cos(theta)**24 + 1.65437258804241e+96*cos(theta)**22 - 2.96938669648637e+95*cos(theta)**20 + 4.00130122221567e+94*cos(theta)**18 - 4.00391816219096e+93*cos(theta)**16 + 2.92256800159924e+92*cos(theta)**14 - 1.51540563045887e+91*cos(theta)**12 + 5.37147001129351e+89*cos(theta)**10 - 1.23010763617409e+88*cos(theta)**8 + 1.66875066922841e+86*cos(theta)**6 - 1.15939138668023e+84*cos(theta)**4 + 3.09171036448062e+81*cos(theta)**2 - 1.32293982219966e+78)*cos(42*phi)

#@torch.jit.script
def Yl80_m43(theta, phi):
    return 5.38851828134669e-81*(1.0 - cos(theta)**2)**21.5*(3.95905916402249e+98*cos(theta)**37 - 1.65832289511885e+99*cos(theta)**35 + 3.14236344775706e+99*cos(theta)**33 - 3.56810301164673e+99*cos(theta)**31 + 2.71105866081002e+99*cos(theta)**29 - 1.45786730634287e+99*cos(theta)**27 + 5.72384143765489e+98*cos(theta)**25 - 1.66875843663408e+98*cos(theta)**23 + 3.63961969369329e+97*cos(theta)**21 - 5.93877339297274e+96*cos(theta)**19 + 7.20234219998821e+95*cos(theta)**17 - 6.40626905950554e+94*cos(theta)**15 + 4.09159520223894e+93*cos(theta)**13 - 1.81848675655064e+92*cos(theta)**11 + 5.37147001129351e+90*cos(theta)**9 - 9.84086108939269e+88*cos(theta)**7 + 1.00125040153705e+87*cos(theta)**5 - 4.63756554672092e+84*cos(theta)**3 + 6.18342072896123e+81*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl80_m44(theta, phi):
    return 7.95532004231161e-83*(1.0 - cos(theta)**2)**22*(1.46485189068832e+100*cos(theta)**36 - 5.80413013291599e+100*cos(theta)**34 + 1.03697993775983e+101*cos(theta)**32 - 1.10611193361049e+101*cos(theta)**30 + 7.86207011634904e+100*cos(theta)**28 - 3.93624172712575e+100*cos(theta)**26 + 1.43096035941372e+100*cos(theta)**24 - 3.83814440425838e+99*cos(theta)**22 + 7.64320135675591e+98*cos(theta)**20 - 1.12836694466482e+98*cos(theta)**18 + 1.224398173998e+97*cos(theta)**16 - 9.60940358925831e+95*cos(theta)**14 + 5.31907376291062e+94*cos(theta)**12 - 2.0003354322057e+93*cos(theta)**10 + 4.83432301016416e+91*cos(theta)**8 - 6.88860276257489e+89*cos(theta)**6 + 5.00625200768524e+87*cos(theta)**4 - 1.39126966401628e+85*cos(theta)**2 + 6.18342072896123e+81)*cos(44*phi)

#@torch.jit.script
def Yl80_m45(theta, phi):
    return 1.18590909315835e-84*(1.0 - cos(theta)**2)**22.5*(5.27346680647795e+101*cos(theta)**35 - 1.97340424519144e+102*cos(theta)**33 + 3.31833580083146e+102*cos(theta)**31 - 3.31833580083146e+102*cos(theta)**29 + 2.20137963257773e+102*cos(theta)**27 - 1.02342284905269e+102*cos(theta)**25 + 3.43430486259293e+101*cos(theta)**23 - 8.44391768936844e+100*cos(theta)**21 + 1.52864027135118e+100*cos(theta)**19 - 2.03106050039668e+99*cos(theta)**17 + 1.95903707839679e+98*cos(theta)**15 - 1.34531650249616e+97*cos(theta)**13 + 6.38288851549275e+95*cos(theta)**11 - 2.0003354322057e+94*cos(theta)**9 + 3.86745840813133e+92*cos(theta)**7 - 4.13316165754493e+90*cos(theta)**5 + 2.00250080307409e+88*cos(theta)**3 - 2.78253932803255e+85*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl80_m46(theta, phi):
    return 1.78579706299295e-86*(1.0 - cos(theta)**2)**23*(1.84571338226728e+103*cos(theta)**34 - 6.51223400913174e+103*cos(theta)**32 + 1.02868409825775e+104*cos(theta)**30 - 9.62317382241123e+103*cos(theta)**28 + 5.94372500795988e+103*cos(theta)**26 - 2.55855712263174e+103*cos(theta)**24 + 7.89890118396375e+102*cos(theta)**22 - 1.77322271476737e+102*cos(theta)**20 + 2.90441651556725e+101*cos(theta)**18 - 3.45280285067435e+100*cos(theta)**16 + 2.93855561759519e+99*cos(theta)**14 - 1.74891145324501e+98*cos(theta)**12 + 7.02117736704202e+96*cos(theta)**10 - 1.80030188898513e+95*cos(theta)**8 + 2.70722088569193e+93*cos(theta)**6 - 2.06658082877247e+91*cos(theta)**4 + 6.00750240922228e+88*cos(theta)**2 - 2.78253932803255e+85)*cos(46*phi)

#@torch.jit.script
def Yl80_m47(theta, phi):
    return 2.71763286152957e-88*(1.0 - cos(theta)**2)**23.5*(6.27542549970877e+104*cos(theta)**33 - 2.08391488292216e+105*cos(theta)**31 + 3.08605229477326e+105*cos(theta)**29 - 2.69448867027514e+105*cos(theta)**27 + 1.54536850206957e+105*cos(theta)**25 - 6.14053709431616e+104*cos(theta)**23 + 1.73775826047202e+104*cos(theta)**21 - 3.54644542953474e+103*cos(theta)**19 + 5.22794972802104e+102*cos(theta)**17 - 5.52448456107896e+101*cos(theta)**15 + 4.11397786463327e+100*cos(theta)**13 - 2.09869374389401e+99*cos(theta)**11 + 7.02117736704202e+97*cos(theta)**9 - 1.44024151118811e+96*cos(theta)**7 + 1.62433253141516e+94*cos(theta)**5 - 8.26632331508986e+91*cos(theta)**3 + 1.20150048184446e+89*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl80_m48(theta, phi):
    return 4.18146851075132e-90*(1.0 - cos(theta)**2)**24*(2.07089041490389e+106*cos(theta)**32 - 6.46013613705868e+106*cos(theta)**30 + 8.94955165484244e+106*cos(theta)**28 - 7.27511940974289e+106*cos(theta)**26 + 3.86342125517392e+106*cos(theta)**24 - 1.41232353169272e+106*cos(theta)**22 + 3.64929234699125e+105*cos(theta)**20 - 6.73824631611601e+104*cos(theta)**18 + 8.88751453763577e+103*cos(theta)**16 - 8.28672684161844e+102*cos(theta)**14 + 5.34817122402325e+101*cos(theta)**12 - 2.30856311828342e+100*cos(theta)**10 + 6.31905963033782e+98*cos(theta)**8 - 1.00816905783167e+97*cos(theta)**6 + 8.12166265707579e+94*cos(theta)**4 - 2.47989699452696e+92*cos(theta)**2 + 1.20150048184446e+89)*cos(48*phi)

#@torch.jit.script
def Yl80_m49(theta, phi):
    return 6.50817146366008e-92*(1.0 - cos(theta)**2)**24.5*(6.62684932769246e+107*cos(theta)**31 - 1.93804084111761e+108*cos(theta)**29 + 2.50587446335588e+108*cos(theta)**27 - 1.89153104653315e+108*cos(theta)**25 + 9.27221101241741e+107*cos(theta)**23 - 3.10711176972398e+107*cos(theta)**21 + 7.2985846939825e+106*cos(theta)**19 - 1.21288433690088e+106*cos(theta)**17 + 1.42200232602172e+105*cos(theta)**15 - 1.16014175782658e+104*cos(theta)**13 + 6.4178054688279e+102*cos(theta)**11 - 2.30856311828342e+101*cos(theta)**9 + 5.05524770427025e+99*cos(theta)**7 - 6.04901434699005e+97*cos(theta)**5 + 3.24866506283032e+95*cos(theta)**3 - 4.95979398905392e+92*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl80_m50(theta, phi):
    return 1.02519496179377e-93*(1.0 - cos(theta)**2)**25*(2.05432329158466e+109*cos(theta)**30 - 5.62031843924105e+109*cos(theta)**28 + 6.76586105106089e+109*cos(theta)**26 - 4.72882761633288e+109*cos(theta)**24 + 2.132608532856e+109*cos(theta)**22 - 6.52493471642036e+108*cos(theta)**20 + 1.38673109185668e+108*cos(theta)**18 - 2.0619033727315e+107*cos(theta)**16 + 2.13300348903259e+106*cos(theta)**14 - 1.50818428517456e+105*cos(theta)**12 + 7.05958601571069e+103*cos(theta)**10 - 2.07770680645507e+102*cos(theta)**8 + 3.53867339298918e+100*cos(theta)**6 - 3.02450717349502e+98*cos(theta)**4 + 9.74599518849095e+95*cos(theta)**2 - 4.95979398905392e+92)*cos(50*phi)

#@torch.jit.script
def Yl80_m51(theta, phi):
    return 1.63534801463645e-95*(1.0 - cos(theta)**2)**25.5*(6.16296987475398e+110*cos(theta)**29 - 1.5736891629875e+111*cos(theta)**27 + 1.75912387327583e+111*cos(theta)**25 - 1.13491862791989e+111*cos(theta)**23 + 4.69173877228321e+110*cos(theta)**21 - 1.30498694328407e+110*cos(theta)**19 + 2.49611596534202e+109*cos(theta)**17 - 3.2990453963704e+108*cos(theta)**15 + 2.98620488464562e+107*cos(theta)**13 - 1.80982114220947e+106*cos(theta)**11 + 7.05958601571069e+104*cos(theta)**9 - 1.66216544516406e+103*cos(theta)**7 + 2.12320403579351e+101*cos(theta)**5 - 1.20980286939801e+99*cos(theta)**3 + 1.94919903769819e+96*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl80_m52(theta, phi):
    return 2.64316468720293e-97*(1.0 - cos(theta)**2)**26*(1.78726126367866e+112*cos(theta)**28 - 4.24896074006624e+112*cos(theta)**26 + 4.39780968318958e+112*cos(theta)**24 - 2.61031284421575e+112*cos(theta)**22 + 9.85265142179474e+111*cos(theta)**20 - 2.47947519223974e+111*cos(theta)**18 + 4.24339714108143e+110*cos(theta)**16 - 4.9485680945556e+109*cos(theta)**14 + 3.88206635003931e+108*cos(theta)**12 - 1.99080325643041e+107*cos(theta)**10 + 6.35362741413962e+105*cos(theta)**8 - 1.16351581161484e+104*cos(theta)**6 + 1.06160201789675e+102*cos(theta)**4 - 3.62940860819403e+99*cos(theta)**2 + 1.94919903769819e+96)*cos(52*phi)

#@torch.jit.script
def Yl80_m53(theta, phi):
    return 4.33131118896724e-99*(1.0 - cos(theta)**2)**26.5*(5.00433153830024e+113*cos(theta)**27 - 1.10472979241722e+114*cos(theta)**25 + 1.0554743239655e+114*cos(theta)**23 - 5.74268825727465e+113*cos(theta)**21 + 1.97053028435895e+113*cos(theta)**19 - 4.46305534603152e+112*cos(theta)**17 + 6.78943542573028e+111*cos(theta)**15 - 6.92799533237784e+110*cos(theta)**13 + 4.65847962004717e+109*cos(theta)**11 - 1.99080325643041e+108*cos(theta)**9 + 5.08290193131169e+106*cos(theta)**7 - 6.98109486968905e+104*cos(theta)**5 + 4.24640807158701e+102*cos(theta)**3 - 7.25881721638806e+99*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl80_m54(theta, phi):
    return 7.20087224763713e-101*(1.0 - cos(theta)**2)**27*(1.35116951534106e+115*cos(theta)**26 - 2.76182448104305e+115*cos(theta)**24 + 2.42759094512065e+115*cos(theta)**22 - 1.20596453402768e+115*cos(theta)**20 + 3.744007540282e+114*cos(theta)**18 - 7.58719408825359e+113*cos(theta)**16 + 1.01841531385954e+113*cos(theta)**14 - 9.00639393209119e+111*cos(theta)**12 + 5.12432758205188e+110*cos(theta)**10 - 1.79172293078737e+109*cos(theta)**8 + 3.55803135191819e+107*cos(theta)**6 - 3.49054743484453e+105*cos(theta)**4 + 1.2739224214761e+103*cos(theta)**2 - 7.25881721638806e+99)*cos(54*phi)

#@torch.jit.script
def Yl80_m55(theta, phi):
    return 1.21543446708706e-102*(1.0 - cos(theta)**2)**27.5*(3.51304073988677e+116*cos(theta)**25 - 6.62837875450333e+116*cos(theta)**23 + 5.34070007926542e+116*cos(theta)**21 - 2.41192906805535e+116*cos(theta)**19 + 6.7392135725076e+115*cos(theta)**17 - 1.21395105412057e+115*cos(theta)**15 + 1.42578143940336e+114*cos(theta)**13 - 1.08076727185094e+113*cos(theta)**11 + 5.12432758205188e+111*cos(theta)**9 - 1.4333783446299e+110*cos(theta)**7 + 2.13481881115091e+108*cos(theta)**5 - 1.39621897393781e+106*cos(theta)**3 + 2.54784484295221e+103*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl80_m56(theta, phi):
    return 2.0844529143887e-104*(1.0 - cos(theta)**2)**28*(8.78260184971691e+117*cos(theta)**24 - 1.52452711353577e+118*cos(theta)**22 + 1.12154701664574e+118*cos(theta)**20 - 4.58266522930517e+117*cos(theta)**18 + 1.14566630732629e+117*cos(theta)**16 - 1.82092658118086e+116*cos(theta)**14 + 1.85351587122437e+115*cos(theta)**12 - 1.18884399903604e+114*cos(theta)**10 + 4.6118948238467e+112*cos(theta)**8 - 1.00336484124093e+111*cos(theta)**6 + 1.06740940557546e+109*cos(theta)**4 - 4.18865692181343e+106*cos(theta)**2 + 2.54784484295221e+103)*cos(56*phi)

#@torch.jit.script
def Yl80_m57(theta, phi):
    return 3.63518221459163e-106*(1.0 - cos(theta)**2)**28.5*(2.10782444393206e+119*cos(theta)**23 - 3.35395964977869e+119*cos(theta)**21 + 2.24309403329148e+119*cos(theta)**19 - 8.2487974127493e+118*cos(theta)**17 + 1.83306609172207e+118*cos(theta)**15 - 2.54929721365321e+117*cos(theta)**13 + 2.22421904546924e+116*cos(theta)**11 - 1.18884399903604e+115*cos(theta)**9 + 3.68951585907736e+113*cos(theta)**7 - 6.02018904744557e+111*cos(theta)**5 + 4.26963762230182e+109*cos(theta)**3 - 8.37731384362686e+106*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl80_m58(theta, phi):
    return 6.45242141144206e-108*(1.0 - cos(theta)**2)**29*(4.84799622104374e+120*cos(theta)**22 - 7.04331526453524e+120*cos(theta)**20 + 4.26187866325381e+120*cos(theta)**18 - 1.40229556016738e+120*cos(theta)**16 + 2.7495991375831e+119*cos(theta)**14 - 3.31408637774917e+118*cos(theta)**12 + 2.44664095001616e+117*cos(theta)**10 - 1.06995959913243e+116*cos(theta)**8 + 2.58266110135415e+114*cos(theta)**6 - 3.01009452372279e+112*cos(theta)**4 + 1.28089128669055e+110*cos(theta)**2 - 8.37731384362686e+106)*cos(58*phi)

#@torch.jit.script
def Yl80_m59(theta, phi):
    return 1.16682031850865e-109*(1.0 - cos(theta)**2)**29.5*(1.06655916862962e+122*cos(theta)**21 - 1.40866305290705e+122*cos(theta)**19 + 7.67138159385685e+121*cos(theta)**17 - 2.24367289626781e+121*cos(theta)**15 + 3.84943879261634e+120*cos(theta)**13 - 3.976903653299e+119*cos(theta)**11 + 2.44664095001616e+118*cos(theta)**9 - 8.55967679305947e+116*cos(theta)**7 + 1.54959666081249e+115*cos(theta)**5 - 1.20403780948911e+113*cos(theta)**3 + 2.56178257338109e+110*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl80_m60(theta, phi):
    return 2.1519407912383e-111*(1.0 - cos(theta)**2)**30*(2.23977425412221e+123*cos(theta)**20 - 2.67645980052339e+123*cos(theta)**18 + 1.30413487095567e+123*cos(theta)**16 - 3.36550934440172e+122*cos(theta)**14 + 5.00427043040124e+121*cos(theta)**12 - 4.3745940186289e+120*cos(theta)**10 + 2.20197685501455e+119*cos(theta)**8 - 5.99177375514163e+117*cos(theta)**6 + 7.74798330406245e+115*cos(theta)**4 - 3.61211342846734e+113*cos(theta)**2 + 2.56178257338109e+110)*cos(60*phi)

#@torch.jit.script
def Yl80_m61(theta, phi):
    return 4.05233894854369e-113*(1.0 - cos(theta)**2)**30.5*(4.47954850824441e+124*cos(theta)**19 - 4.8176276409421e+124*cos(theta)**17 + 2.08661579352906e+124*cos(theta)**15 - 4.7117130821624e+123*cos(theta)**13 + 6.00512451648149e+122*cos(theta)**11 - 4.3745940186289e+121*cos(theta)**9 + 1.76158148401164e+120*cos(theta)**7 - 3.59506425308498e+118*cos(theta)**5 + 3.09919332162498e+116*cos(theta)**3 - 7.22422685693469e+113*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl80_m62(theta, phi):
    return 7.80161996679641e-115*(1.0 - cos(theta)**2)**31*(8.51114216566438e+125*cos(theta)**18 - 8.18996698960158e+125*cos(theta)**16 + 3.1299236902936e+125*cos(theta)**14 - 6.12522700681112e+124*cos(theta)**12 + 6.60563696812964e+123*cos(theta)**10 - 3.93713461676601e+122*cos(theta)**8 + 1.23310703880815e+121*cos(theta)**6 - 1.79753212654249e+119*cos(theta)**4 + 9.29757996487494e+116*cos(theta)**2 - 7.22422685693469e+113)*cos(62*phi)

#@torch.jit.script
def Yl80_m63(theta, phi):
    return 1.53773153172088e-116*(1.0 - cos(theta)**2)**31.5*(1.53200558981959e+127*cos(theta)**17 - 1.31039471833625e+127*cos(theta)**15 + 4.38189316641103e+126*cos(theta)**13 - 7.35027240817335e+125*cos(theta)**11 + 6.60563696812964e+124*cos(theta)**9 - 3.14970769341281e+123*cos(theta)**7 + 7.39864223284888e+121*cos(theta)**5 - 7.19012850616995e+119*cos(theta)**3 + 1.85951599297499e+117*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl80_m64(theta, phi):
    return 3.10795565153335e-118*(1.0 - cos(theta)**2)**32*(2.6044095026933e+128*cos(theta)**16 - 1.96559207750438e+128*cos(theta)**14 + 5.69646111633434e+127*cos(theta)**12 - 8.08529964899068e+126*cos(theta)**10 + 5.94507327131668e+125*cos(theta)**8 - 2.20479538538897e+124*cos(theta)**6 + 3.69932111642444e+122*cos(theta)**4 - 2.15703855185099e+120*cos(theta)**2 + 1.85951599297499e+117)*cos(64*phi)

#@torch.jit.script
def Yl80_m65(theta, phi):
    return 6.45254171114326e-120*(1.0 - cos(theta)**2)**32.5*(4.16705520430928e+129*cos(theta)**15 - 2.75182890850613e+129*cos(theta)**13 + 6.83575333960121e+128*cos(theta)**11 - 8.08529964899068e+127*cos(theta)**9 + 4.75605861705334e+126*cos(theta)**7 - 1.32287723123338e+125*cos(theta)**5 + 1.47972844656978e+123*cos(theta)**3 - 4.31407710370197e+120*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl80_m66(theta, phi):
    return 1.37882377465523e-121*(1.0 - cos(theta)**2)**33*(6.25058280646392e+130*cos(theta)**14 - 3.57737758105797e+130*cos(theta)**12 + 7.51932867356133e+129*cos(theta)**10 - 7.27676968409161e+128*cos(theta)**8 + 3.32924103193734e+127*cos(theta)**6 - 6.6143861561669e+125*cos(theta)**4 + 4.43918533970933e+123*cos(theta)**2 - 4.31407710370197e+120)*cos(66*phi)

#@torch.jit.script
def Yl80_m67(theta, phi):
    return 3.03938753480969e-123*(1.0 - cos(theta)**2)**33.5*(8.75081592904949e+131*cos(theta)**13 - 4.29285309726956e+131*cos(theta)**11 + 7.51932867356133e+130*cos(theta)**9 - 5.82141574727329e+129*cos(theta)**7 + 1.9975446191624e+128*cos(theta)**5 - 2.64575446246676e+126*cos(theta)**3 + 8.87837067941866e+123*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl80_m68(theta, phi):
    return 6.92920713888528e-125*(1.0 - cos(theta)**2)**34*(1.13760607077643e+133*cos(theta)**12 - 4.72213840699652e+132*cos(theta)**10 + 6.7673958062052e+131*cos(theta)**8 - 4.0749910230913e+130*cos(theta)**6 + 9.98772309581202e+128*cos(theta)**4 - 7.93726338740028e+126*cos(theta)**2 + 8.87837067941866e+123)*cos(68*phi)

#@torch.jit.script
def Yl80_m69(theta, phi):
    return 1.63870125727749e-126*(1.0 - cos(theta)**2)**34.5*(1.36512728493172e+134*cos(theta)**11 - 4.72213840699652e+133*cos(theta)**9 + 5.41391664496416e+132*cos(theta)**7 - 2.44499461385478e+131*cos(theta)**5 + 3.99508923832481e+129*cos(theta)**3 - 1.58745267748006e+127*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl80_m70(theta, phi):
    return 4.03420362055988e-128*(1.0 - cos(theta)**2)**35*(1.50164001342489e+135*cos(theta)**10 - 4.24992456629687e+134*cos(theta)**8 + 3.78974165147491e+133*cos(theta)**6 - 1.22249730692739e+132*cos(theta)**4 + 1.19852677149744e+130*cos(theta)**2 - 1.58745267748006e+127)*cos(70*phi)

#@torch.jit.script
def Yl80_m71(theta, phi):
    return 1.03817207075031e-129*(1.0 - cos(theta)**2)**35.5*(1.50164001342489e+136*cos(theta)**9 - 3.39993965303749e+135*cos(theta)**7 + 2.27384499088495e+134*cos(theta)**5 - 4.88998922770956e+132*cos(theta)**3 + 2.39705354299488e+130*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl80_m72(theta, phi):
    return 2.8068958115897e-131*(1.0 - cos(theta)**2)**36*(1.3514760120824e+137*cos(theta)**8 - 2.37995775712625e+136*cos(theta)**6 + 1.13692249544247e+135*cos(theta)**4 - 1.46699676831287e+133*cos(theta)**2 + 2.39705354299488e+130)*cos(72*phi)

#@torch.jit.script
def Yl80_m73(theta, phi):
    return 8.02297767216779e-133*(1.0 - cos(theta)**2)**36.5*(1.08118080966592e+138*cos(theta)**7 - 1.42797465427575e+137*cos(theta)**5 + 4.5476899817699e+135*cos(theta)**3 - 2.93399353662574e+133*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl80_m74(theta, phi):
    return 2.44357798144463e-134*(1.0 - cos(theta)**2)**37*(7.56826566766146e+138*cos(theta)**6 - 7.13987327137874e+137*cos(theta)**4 + 1.36430699453097e+136*cos(theta)**2 - 2.93399353662574e+133)*cos(74*phi)

#@torch.jit.script
def Yl80_m75(theta, phi):
    return 8.01280785992094e-136*(1.0 - cos(theta)**2)**37.5*(4.54095940059688e+139*cos(theta)**5 - 2.85594930855149e+138*cos(theta)**3 + 2.72861398906194e+136*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl80_m76(theta, phi):
    return 2.86904544565473e-137*(1.0 - cos(theta)**2)**38*(2.27047970029844e+140*cos(theta)**4 - 8.56784792565448e+138*cos(theta)**2 + 2.72861398906194e+136)*cos(76*phi)

#@torch.jit.script
def Yl80_m77(theta, phi):
    return 1.1448737705593e-138*(1.0 - cos(theta)**2)**38.5*(9.08191880119375e+140*cos(theta)**3 - 1.7135695851309e+139*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl80_m78(theta, phi):
    return 5.2585793883761e-140*(1.0 - cos(theta)**2)**39*(2.72457564035813e+141*cos(theta)**2 - 1.7135695851309e+139)*cos(78*phi)

#@torch.jit.script
def Yl80_m79(theta, phi):
    return 16.0688108979079*(1.0 - cos(theta)**2)**39.5*cos(79*phi)*cos(theta)

#@torch.jit.script
def Yl80_m80(theta, phi):
    return 1.27035104319811*(1.0 - cos(theta)**2)**40*cos(80*phi)

#@torch.jit.script
def Yl81_m_minus_81(theta, phi):
    return 1.27426584768067*(1.0 - cos(theta)**2)**40.5*sin(81*phi)

#@torch.jit.script
def Yl81_m_minus_80(theta, phi):
    return 16.2187563947297*(1.0 - cos(theta)**2)**40*sin(80*phi)*cos(theta)

#@torch.jit.script
def Yl81_m_minus_79(theta, phi):
    return 3.31734580606543e-142*(1.0 - cos(theta)**2)**39.5*(4.38656678097658e+143*cos(theta)**2 - 2.72457564035813e+141)*sin(79*phi)

#@torch.jit.script
def Yl81_m_minus_78(theta, phi):
    return 7.26794051610877e-141*(1.0 - cos(theta)**2)**39*(1.46218892699219e+143*cos(theta)**3 - 2.72457564035813e+141*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl81_m_minus_77(theta, phi):
    return 1.83290485688326e-139*(1.0 - cos(theta)**2)**38.5*(3.65547231748049e+142*cos(theta)**4 - 1.36228782017906e+141*cos(theta)**2 + 4.28392396282724e+138)*sin(77*phi)

#@torch.jit.script
def Yl81_m_minus_76(theta, phi):
    return 5.15173443547425e-138*(1.0 - cos(theta)**2)**38*(7.31094463496097e+141*cos(theta)**5 - 4.54095940059688e+140*cos(theta)**3 + 4.28392396282724e+138*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl81_m_minus_75(theta, phi):
    return 1.58117128633869e-136*(1.0 - cos(theta)**2)**37.5*(1.21849077249349e+141*cos(theta)**6 - 1.13523985014922e+140*cos(theta)**4 + 2.14196198141362e+138*cos(theta)**2 - 4.5476899817699e+135)*sin(75*phi)

#@torch.jit.script
def Yl81_m_minus_74(theta, phi):
    return 5.22504744411206e-135*(1.0 - cos(theta)**2)**37*(1.74070110356214e+140*cos(theta)**7 - 2.27047970029844e+139*cos(theta)**5 + 7.13987327137874e+137*cos(theta)**3 - 4.5476899817699e+135*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl81_m_minus_73(theta, phi):
    return 1.83992906883921e-133*(1.0 - cos(theta)**2)**36.5*(2.17587637945267e+139*cos(theta)**8 - 3.78413283383073e+138*cos(theta)**6 + 1.78496831784468e+137*cos(theta)**4 - 2.27384499088495e+135*cos(theta)**2 + 3.66749192078217e+132)*sin(73*phi)

#@torch.jit.script
def Yl81_m_minus_72(theta, phi):
    return 6.84987578281994e-132*(1.0 - cos(theta)**2)**36*(2.41764042161408e+138*cos(theta)**9 - 5.40590404832961e+137*cos(theta)**7 + 3.56993663568937e+136*cos(theta)**5 - 7.57948330294983e+134*cos(theta)**3 + 3.66749192078217e+132*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl81_m_minus_71(theta, phi):
    return 2.67934360072195e-130*(1.0 - cos(theta)**2)**35.5*(2.41764042161408e+137*cos(theta)**10 - 6.75738006041202e+136*cos(theta)**8 + 5.94989439281561e+135*cos(theta)**6 - 1.89487082573746e+134*cos(theta)**4 + 1.83374596039109e+132*cos(theta)**2 - 2.39705354299488e+129)*sin(71*phi)

#@torch.jit.script
def Yl81_m_minus_70(theta, phi):
    return 1.0955861865951e-128*(1.0 - cos(theta)**2)**35*(2.19785492874007e+136*cos(theta)**11 - 7.50820006712446e+135*cos(theta)**9 + 8.49984913259373e+134*cos(theta)**7 - 3.78974165147491e+133*cos(theta)**5 + 6.11248653463696e+131*cos(theta)**3 - 2.39705354299488e+129*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl81_m_minus_69(theta, phi):
    return 4.66364672243888e-127*(1.0 - cos(theta)**2)**34.5*(1.83154577395006e+135*cos(theta)**12 - 7.50820006712446e+134*cos(theta)**10 + 1.06248114157422e+134*cos(theta)**8 - 6.31623608579152e+132*cos(theta)**6 + 1.52812163365924e+131*cos(theta)**4 - 1.19852677149744e+129*cos(theta)**2 + 1.32287723123338e+126)*sin(69*phi)

#@torch.jit.script
def Yl81_m_minus_68(theta, phi):
    return 2.05941063088069e-125*(1.0 - cos(theta)**2)**34*(1.40888136457697e+134*cos(theta)**13 - 6.8256364246586e+133*cos(theta)**11 + 1.18053460174913e+133*cos(theta)**9 - 9.0231944082736e+131*cos(theta)**7 + 3.05624326731848e+130*cos(theta)**5 - 3.99508923832481e+128*cos(theta)**3 + 1.32287723123338e+126*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl81_m_minus_67(theta, phi):
    return 9.40589448047078e-124*(1.0 - cos(theta)**2)**33.5*(1.00634383184069e+133*cos(theta)**14 - 5.68803035388217e+132*cos(theta)**12 + 1.18053460174913e+132*cos(theta)**10 - 1.1278993010342e+131*cos(theta)**8 + 5.09373877886413e+129*cos(theta)**6 - 9.98772309581202e+127*cos(theta)**4 + 6.6143861561669e+125*cos(theta)**2 - 6.3416933424419e+122)*sin(67*phi)

#@torch.jit.script
def Yl81_m_minus_66(theta, phi):
    return 4.43176363506231e-122*(1.0 - cos(theta)**2)**33*(6.70895887893794e+131*cos(theta)**15 - 4.37540796452475e+131*cos(theta)**13 + 1.07321327431739e+131*cos(theta)**11 - 1.25322144559356e+130*cos(theta)**9 + 7.27676968409161e+128*cos(theta)**7 - 1.9975446191624e+127*cos(theta)**5 + 2.20479538538897e+125*cos(theta)**3 - 6.3416933424419e+122*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl81_m_minus_65(theta, phi):
    return 2.14929113925793e-120*(1.0 - cos(theta)**2)**32.5*(4.19309929933622e+130*cos(theta)**16 - 3.12529140323196e+130*cos(theta)**14 + 8.94344395264492e+129*cos(theta)**12 - 1.25322144559356e+129*cos(theta)**10 + 9.09596210511452e+127*cos(theta)**8 - 3.32924103193734e+126*cos(theta)**6 + 5.51198846347242e+124*cos(theta)**4 - 3.17084667122095e+122*cos(theta)**2 + 2.69629818981373e+119)*sin(65*phi)

#@torch.jit.script
def Yl81_m_minus_64(theta, phi):
    return 1.0707698566923e-118*(1.0 - cos(theta)**2)**32*(2.46652899960954e+129*cos(theta)**17 - 2.08352760215464e+129*cos(theta)**15 + 6.87957227126532e+128*cos(theta)**13 - 1.13929222326687e+128*cos(theta)**11 + 1.01066245612384e+127*cos(theta)**9 - 4.75605861705334e+125*cos(theta)**7 + 1.10239769269448e+124*cos(theta)**5 - 1.05694889040698e+122*cos(theta)**3 + 2.69629818981373e+119*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl81_m_minus_63(theta, phi):
    return 5.47036607958023e-117*(1.0 - cos(theta)**2)**31.5*(1.37029388867197e+128*cos(theta)**18 - 1.30220475134665e+128*cos(theta)**16 + 4.91398019376095e+127*cos(theta)**14 - 9.49410186055724e+126*cos(theta)**12 + 1.01066245612384e+126*cos(theta)**10 - 5.94507327131668e+124*cos(theta)**8 + 1.83732948782414e+123*cos(theta)**6 - 2.64237222601746e+121*cos(theta)**4 + 1.34814909490687e+119*cos(theta)**2 - 1.03306444054166e+116)*sin(63*phi)

#@torch.jit.script
def Yl81_m_minus_62(theta, phi):
    return 2.86137275100756e-115*(1.0 - cos(theta)**2)**31*(7.2120730982735e+126*cos(theta)**19 - 7.66002794909794e+126*cos(theta)**17 + 3.27598679584063e+126*cos(theta)**15 - 7.30315527735172e+125*cos(theta)**13 + 9.18784051021668e+124*cos(theta)**11 - 6.60563696812964e+123*cos(theta)**9 + 2.62475641117734e+122*cos(theta)**7 - 5.28474445203492e+120*cos(theta)**5 + 4.49383031635622e+118*cos(theta)**3 - 1.03306444054166e+116*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl81_m_minus_61(theta, phi):
    return 1.53023261296433e-113*(1.0 - cos(theta)**2)**30.5*(3.60603654913675e+125*cos(theta)**20 - 4.25557108283219e+125*cos(theta)**18 + 2.04749174740039e+125*cos(theta)**16 - 5.21653948382266e+124*cos(theta)**14 + 7.6565337585139e+123*cos(theta)**12 - 6.60563696812964e+122*cos(theta)**10 + 3.28094551397168e+121*cos(theta)**8 - 8.80790742005819e+119*cos(theta)**6 + 1.12345757908906e+118*cos(theta)**4 - 5.1653222027083e+115*cos(theta)**2 + 3.61211342846734e+112)*sin(61*phi)

#@torch.jit.script
def Yl81_m_minus_60(theta, phi):
    return 8.35624708588904e-112*(1.0 - cos(theta)**2)**30*(1.71716026149369e+124*cos(theta)**21 - 2.23977425412221e+124*cos(theta)**19 + 1.20440691023553e+124*cos(theta)**17 - 3.47769298921511e+123*cos(theta)**15 + 5.889641352703e+122*cos(theta)**13 - 6.00512451648149e+121*cos(theta)**11 + 3.64549501552409e+120*cos(theta)**9 - 1.25827248857974e+119*cos(theta)**7 + 2.24691515817811e+117*cos(theta)**5 - 1.72177406756943e+115*cos(theta)**3 + 3.61211342846734e+112*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl81_m_minus_59(theta, phi):
    return 4.6540620574725e-110*(1.0 - cos(theta)**2)**29.5*(7.80527391588041e+122*cos(theta)**22 - 1.1198871270611e+123*cos(theta)**20 + 6.69114950130848e+122*cos(theta)**18 - 2.17355811825944e+122*cos(theta)**16 + 4.20688668050214e+121*cos(theta)**14 - 5.00427043040124e+120*cos(theta)**12 + 3.64549501552409e+119*cos(theta)**10 - 1.57284061072468e+118*cos(theta)**8 + 3.74485859696352e+116*cos(theta)**6 - 4.30443516892358e+114*cos(theta)**4 + 1.80605671423367e+112*cos(theta)**2 - 1.16444662426413e+109)*sin(59*phi)

#@torch.jit.script
def Yl81_m_minus_58(theta, phi):
    return 2.6409495546881e-108*(1.0 - cos(theta)**2)**29*(3.39359735473062e+121*cos(theta)**23 - 5.33279584314811e+121*cos(theta)**21 + 3.52165763226762e+121*cos(theta)**19 - 1.27856359897614e+121*cos(theta)**17 + 2.80459112033476e+120*cos(theta)**15 - 3.84943879261634e+119*cos(theta)**13 + 3.31408637774917e+118*cos(theta)**11 - 1.74760067858297e+117*cos(theta)**9 + 5.34979799566217e+115*cos(theta)**7 - 8.60887033784717e+113*cos(theta)**5 + 6.02018904744557e+111*cos(theta)**3 - 1.16444662426413e+109*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl81_m_minus_57(theta, phi):
    return 1.52536271555845e-106*(1.0 - cos(theta)**2)**28.5*(1.41399889780442e+120*cos(theta)**24 - 2.42399811052187e+120*cos(theta)**22 + 1.76082881613381e+120*cos(theta)**20 - 7.10313110542301e+119*cos(theta)**18 + 1.75286945020923e+119*cos(theta)**16 - 2.7495991375831e+118*cos(theta)**14 + 2.76173864812431e+117*cos(theta)**12 - 1.74760067858297e+116*cos(theta)**10 + 6.68724749457771e+114*cos(theta)**8 - 1.43481172297453e+113*cos(theta)**6 + 1.50504726186139e+111*cos(theta)**4 - 5.82223312132067e+108*cos(theta)**2 + 3.49054743484453e+105)*sin(57*phi)

#@torch.jit.script
def Yl81_m_minus_56(theta, phi):
    return 8.95947731642572e-105*(1.0 - cos(theta)**2)**28*(5.65599559121769e+118*cos(theta)**25 - 1.05391222196603e+119*cos(theta)**23 + 8.38489912444671e+118*cos(theta)**21 - 3.7384900554858e+118*cos(theta)**19 + 1.03109967659366e+118*cos(theta)**17 - 1.83306609172207e+117*cos(theta)**15 + 2.12441434471101e+116*cos(theta)**13 - 1.58872788962089e+115*cos(theta)**11 + 7.43027499397523e+113*cos(theta)**9 - 2.04973103282075e+112*cos(theta)**7 + 3.01009452372279e+110*cos(theta)**5 - 1.94074437377356e+108*cos(theta)**3 + 3.49054743484453e+105*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl81_m_minus_55(theta, phi):
    return 5.34723944420852e-103*(1.0 - cos(theta)**2)**27.5*(2.17538291969911e+117*cos(theta)**26 - 4.39130092485846e+117*cos(theta)**24 + 3.81131778383941e+117*cos(theta)**22 - 1.8692450277429e+117*cos(theta)**20 + 5.72833153663146e+116*cos(theta)**18 - 1.14566630732629e+116*cos(theta)**16 + 1.51743881765072e+115*cos(theta)**14 - 1.32393990801741e+114*cos(theta)**12 + 7.43027499397523e+112*cos(theta)**10 - 2.56216379102594e+111*cos(theta)**8 + 5.01682420620464e+109*cos(theta)**6 - 4.85186093443389e+107*cos(theta)**4 + 1.74527371742226e+105*cos(theta)**2 - 9.79940324212388e+101)*sin(55*phi)

#@torch.jit.script
def Yl81_m_minus_54(theta, phi):
    return 3.24026827040331e-101*(1.0 - cos(theta)**2)**27*(8.05697377666338e+115*cos(theta)**27 - 1.75652036994338e+116*cos(theta)**25 + 1.65709468862583e+116*cos(theta)**23 - 8.9011667987757e+115*cos(theta)**21 + 3.01491133506919e+115*cos(theta)**19 - 6.7392135725076e+114*cos(theta)**17 + 1.01162587843381e+114*cos(theta)**15 - 1.01841531385954e+113*cos(theta)**13 + 6.75479544906839e+111*cos(theta)**11 - 2.84684865669549e+110*cos(theta)**9 + 7.16689172314949e+108*cos(theta)**7 - 9.70372186886778e+106*cos(theta)**5 + 5.81757905807421e+104*cos(theta)**3 - 9.79940324212388e+101*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl81_m_minus_53(theta, phi):
    return 1.99217216611943e-99*(1.0 - cos(theta)**2)**26.5*(2.87749063452264e+114*cos(theta)**28 - 6.75584757670532e+114*cos(theta)**26 + 6.90456120260764e+114*cos(theta)**24 - 4.04598490853441e+114*cos(theta)**22 + 1.5074556675346e+114*cos(theta)**20 - 3.744007540282e+113*cos(theta)**18 + 6.32266174021133e+112*cos(theta)**16 - 7.27439509899673e+111*cos(theta)**14 + 5.62899620755699e+110*cos(theta)**12 - 2.84684865669549e+109*cos(theta)**10 + 8.95861465393686e+107*cos(theta)**8 - 1.61728697814463e+106*cos(theta)**6 + 1.45439476451855e+104*cos(theta)**4 - 4.89970162106194e+101*cos(theta)**2 + 2.59243472013859e+98)*sin(53*phi)

#@torch.jit.script
def Yl81_m_minus_52(theta, phi):
    return 1.24187609143365e-97*(1.0 - cos(theta)**2)**26*(9.92238149835392e+112*cos(theta)**29 - 2.50216576915012e+113*cos(theta)**27 + 2.76182448104305e+113*cos(theta)**25 - 1.75912387327583e+113*cos(theta)**23 + 7.17836032159331e+112*cos(theta)**21 - 1.97053028435895e+112*cos(theta)**19 + 3.7192127883596e+111*cos(theta)**17 - 4.84959673266449e+110*cos(theta)**15 + 4.32999708273615e+109*cos(theta)**13 - 2.58804423335954e+108*cos(theta)**11 + 9.95401628215207e+106*cos(theta)**9 - 2.31040996877804e+105*cos(theta)**7 + 2.9087895290371e+103*cos(theta)**5 - 1.63323387368731e+101*cos(theta)**3 + 2.59243472013859e+98*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl81_m_minus_51(theta, phi):
    return 7.84449000485907e-96*(1.0 - cos(theta)**2)**25.5*(3.3074604994513e+111*cos(theta)**30 - 8.93630631839328e+111*cos(theta)**28 + 1.06224018501656e+112*cos(theta)**26 - 7.32968280531596e+111*cos(theta)**24 + 3.26289105526969e+111*cos(theta)**22 - 9.85265142179474e+110*cos(theta)**20 + 2.06622932686645e+110*cos(theta)**18 - 3.0309979579153e+109*cos(theta)**16 + 3.09285505909725e+108*cos(theta)**14 - 2.15670352779961e+107*cos(theta)**12 + 9.95401628215207e+105*cos(theta)**10 - 2.88801246097255e+104*cos(theta)**8 + 4.84798254839517e+102*cos(theta)**6 - 4.08308468421828e+100*cos(theta)**4 + 1.2962173600693e+98*cos(theta)**2 - 6.49733012566063e+94)*sin(51*phi)

#@torch.jit.script
def Yl81_m_minus_50(theta, phi):
    return 5.01802160120378e-94*(1.0 - cos(theta)**2)**25*(1.06692274175849e+110*cos(theta)**31 - 3.08148493737699e+110*cos(theta)**29 + 3.93422290746874e+110*cos(theta)**27 - 2.93187312212638e+110*cos(theta)**25 + 1.41864828489986e+110*cos(theta)**23 - 4.69173877228321e+109*cos(theta)**21 + 1.08748911940339e+109*cos(theta)**19 - 1.7829399752443e+108*cos(theta)**17 + 2.0619033727315e+107*cos(theta)**15 - 1.65900271369201e+106*cos(theta)**13 + 9.04910571104733e+104*cos(theta)**11 - 3.20890273441395e+103*cos(theta)**9 + 6.92568935485025e+101*cos(theta)**7 - 8.16616936843656e+99*cos(theta)**5 + 4.32072453356432e+97*cos(theta)**3 - 6.49733012566063e+94*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl81_m_minus_49(theta, phi):
    return 3.24895101520936e-92*(1.0 - cos(theta)**2)**24.5*(3.33413356799527e+108*cos(theta)**32 - 1.02716164579233e+109*cos(theta)**30 + 1.40507960981026e+109*cos(theta)**28 - 1.12764350851015e+109*cos(theta)**26 + 5.9110345204161e+108*cos(theta)**24 - 2.132608532856e+108*cos(theta)**22 + 5.43744559701696e+107*cos(theta)**20 - 9.90522208469054e+106*cos(theta)**18 + 1.28868960795719e+106*cos(theta)**16 - 1.18500193835144e+105*cos(theta)**14 + 7.54092142587278e+103*cos(theta)**12 - 3.20890273441395e+102*cos(theta)**10 + 8.65711169356281e+100*cos(theta)**8 - 1.36102822807276e+99*cos(theta)**6 + 1.08018113339108e+97*cos(theta)**4 - 3.24866506283032e+94*cos(theta)**2 + 1.54993562157935e+91)*sin(49*phi)

#@torch.jit.script
def Yl81_m_minus_48(theta, phi):
    return 2.12800091117688e-90*(1.0 - cos(theta)**2)**24*(1.01034350545311e+107*cos(theta)**33 - 3.31342466384623e+107*cos(theta)**31 + 4.84510210279401e+107*cos(theta)**29 - 4.17645743892647e+107*cos(theta)**27 + 2.36441380816644e+107*cos(theta)**25 - 9.27221101241741e+106*cos(theta)**23 + 2.58925980810332e+106*cos(theta)**21 - 5.21327478141607e+105*cos(theta)**19 + 7.58052710563051e+104*cos(theta)**17 - 7.90001292234291e+103*cos(theta)**15 + 5.80070878913291e+102*cos(theta)**13 - 2.91718430401268e+101*cos(theta)**11 + 9.61901299284757e+99*cos(theta)**9 - 1.94432604010394e+98*cos(theta)**7 + 2.16036226678216e+96*cos(theta)**5 - 1.08288835427677e+94*cos(theta)**3 + 1.54993562157935e+91*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl81_m_minus_47(theta, phi):
    return 1.40930866855969e-88*(1.0 - cos(theta)**2)**23.5*(2.97159854545033e+105*cos(theta)**34 - 1.03544520745195e+106*cos(theta)**32 + 1.61503403426467e+106*cos(theta)**30 - 1.49159194247374e+106*cos(theta)**28 + 9.09389926217861e+105*cos(theta)**26 - 3.86342125517392e+105*cos(theta)**24 + 1.1769362764106e+105*cos(theta)**22 - 2.60663739070804e+104*cos(theta)**20 + 4.21140394757251e+103*cos(theta)**18 - 4.93750807646432e+102*cos(theta)**16 + 4.14336342080922e+101*cos(theta)**14 - 2.43098692001057e+100*cos(theta)**12 + 9.61901299284757e+98*cos(theta)**10 - 2.43040755012993e+97*cos(theta)**8 + 3.60060377797027e+95*cos(theta)**6 - 2.70722088569193e+93*cos(theta)**4 + 7.74967810789675e+90*cos(theta)**2 - 3.53382494660134e+87)*sin(47*phi)

#@torch.jit.script
def Yl81_m_minus_46(theta, phi):
    return 9.43289782425483e-87*(1.0 - cos(theta)**2)**23*(8.49028155842951e+103*cos(theta)**35 - 3.13771274985438e+104*cos(theta)**33 + 5.20978720730539e+104*cos(theta)**31 - 5.14342049128876e+104*cos(theta)**29 + 3.36811083784393e+104*cos(theta)**27 - 1.54536850206957e+104*cos(theta)**25 + 5.11711424526347e+103*cos(theta)**23 - 1.24125590033716e+103*cos(theta)**21 + 2.21652839345921e+102*cos(theta)**19 - 2.90441651556725e+101*cos(theta)**17 + 2.76224228053948e+100*cos(theta)**15 - 1.86998993846967e+99*cos(theta)**13 + 8.74455726622506e+97*cos(theta)**11 - 2.7004528334777e+96*cos(theta)**9 + 5.14371968281467e+94*cos(theta)**7 - 5.41444177138386e+92*cos(theta)**5 + 2.58322603596558e+90*cos(theta)**3 - 3.53382494660134e+87*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl81_m_minus_45(theta, phi):
    return 6.37820158470133e-85*(1.0 - cos(theta)**2)**22.5*(2.3584115440082e+102*cos(theta)**36 - 9.22856691133642e+102*cos(theta)**34 + 1.62805850228293e+103*cos(theta)**32 - 1.71447349709625e+103*cos(theta)**30 + 1.2028967278014e+103*cos(theta)**28 - 5.94372500795988e+102*cos(theta)**26 + 2.13213093552645e+102*cos(theta)**24 - 5.64207227425982e+101*cos(theta)**22 + 1.10826419672961e+101*cos(theta)**20 - 1.61356473087069e+100*cos(theta)**18 + 1.72640142533717e+99*cos(theta)**16 - 1.3357070989069e+98*cos(theta)**14 + 7.28713105518755e+96*cos(theta)**12 - 2.7004528334777e+95*cos(theta)**10 + 6.42964960351833e+93*cos(theta)**8 - 9.0240696189731e+91*cos(theta)**6 + 6.45806508991396e+89*cos(theta)**4 - 1.76691247330067e+87*cos(theta)**2 + 7.72927591120154e+83)*sin(45*phi)

#@torch.jit.script
def Yl81_m_minus_44(theta, phi):
    return 4.35496205875107e-83*(1.0 - cos(theta)**2)**22*(6.37408525407621e+100*cos(theta)**37 - 2.63673340323898e+101*cos(theta)**35 + 4.93351061297859e+101*cos(theta)**33 - 5.53055966805243e+101*cos(theta)**31 + 4.14791975103932e+101*cos(theta)**29 - 2.20137963257773e+101*cos(theta)**27 + 8.52852374210578e+100*cos(theta)**25 - 2.4530749018521e+100*cos(theta)**23 + 5.27744855585527e+99*cos(theta)**21 - 8.49244595195101e+98*cos(theta)**19 + 1.01553025019834e+98*cos(theta)**17 - 8.9047139927127e+96*cos(theta)**15 + 5.60548542706735e+95*cos(theta)**13 - 2.45495712134336e+94*cos(theta)**11 + 7.14405511502037e+92*cos(theta)**9 - 1.28915280271044e+91*cos(theta)**7 + 1.29161301798279e+89*cos(theta)**5 - 5.88970824433557e+86*cos(theta)**3 + 7.72927591120154e+83*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl81_m_minus_43(theta, phi):
    return 3.0014504665664e-81*(1.0 - cos(theta)**2)**21.5*(1.67739085633584e+99*cos(theta)**38 - 7.3242594534416e+99*cos(theta)**36 + 1.451032533229e+100*cos(theta)**34 - 1.72829989626638e+100*cos(theta)**32 + 1.38263991701311e+100*cos(theta)**30 - 7.86207011634904e+99*cos(theta)**28 + 3.28020143927146e+99*cos(theta)**26 - 1.02211454243837e+99*cos(theta)**24 + 2.39884025266149e+98*cos(theta)**22 - 4.24622297597551e+97*cos(theta)**20 + 5.6418347233241e+96*cos(theta)**18 - 5.56544624544544e+95*cos(theta)**16 + 4.00391816219096e+94*cos(theta)**14 - 2.04579760111947e+93*cos(theta)**12 + 7.14405511502037e+91*cos(theta)**10 - 1.61144100338805e+90*cos(theta)**8 + 2.15268836330465e+88*cos(theta)**6 - 1.47242706108389e+86*cos(theta)**4 + 3.86463795560077e+83*cos(theta)**2 - 1.62721598130559e+80)*sin(43*phi)

#@torch.jit.script
def Yl81_m_minus_42(theta, phi):
    return 2.08724931218398e-79*(1.0 - cos(theta)**2)**21*(4.30100219573293e+97*cos(theta)**39 - 1.97952958201124e+98*cos(theta)**37 + 4.14580723779713e+98*cos(theta)**35 - 5.23727241292844e+98*cos(theta)**33 + 4.46012876455841e+98*cos(theta)**31 - 2.71105866081002e+98*cos(theta)**29 + 1.21488942195239e+98*cos(theta)**27 - 4.08845816975349e+97*cos(theta)**25 + 1.0429740228963e+97*cos(theta)**23 - 2.02201094094072e+96*cos(theta)**21 + 2.96938669648637e+95*cos(theta)**19 - 3.27379190908555e+94*cos(theta)**17 + 2.66927877479397e+93*cos(theta)**15 - 1.57369046239959e+92*cos(theta)**13 + 6.49459555910943e+90*cos(theta)**11 - 1.7904900037645e+89*cos(theta)**9 + 3.07526909043522e+87*cos(theta)**7 - 2.94485412216779e+85*cos(theta)**5 + 1.28821265186692e+83*cos(theta)**3 - 1.62721598130559e+80*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl81_m_minus_41(theta, phi):
    return 1.46405326681666e-77*(1.0 - cos(theta)**2)**20.5*(1.07525054893323e+96*cos(theta)**40 - 5.2092883737138e+96*cos(theta)**38 + 1.15161312161031e+97*cos(theta)**36 - 1.5403742390966e+97*cos(theta)**34 + 1.3937902389245e+97*cos(theta)**32 - 9.03686220270005e+96*cos(theta)**30 + 4.33889079268711e+96*cos(theta)**28 - 1.57248391144365e+96*cos(theta)**26 + 4.34572509540125e+95*cos(theta)**24 - 9.19095882245781e+94*cos(theta)**22 + 1.48469334824318e+94*cos(theta)**20 - 1.81877328282531e+93*cos(theta)**18 + 1.66829923424623e+92*cos(theta)**16 - 1.12406461599971e+91*cos(theta)**14 + 5.41216296592452e+89*cos(theta)**12 - 1.7904900037645e+88*cos(theta)**10 + 3.84408636304402e+86*cos(theta)**8 - 4.90809020361298e+84*cos(theta)**6 + 3.22053162966731e+82*cos(theta)**4 - 8.13607990652794e+79*cos(theta)**2 + 3.30734955549916e+76)*sin(41*phi)

#@torch.jit.script
def Yl81_m_minus_40(theta, phi):
    return 1.03544902068228e-75*(1.0 - cos(theta)**2)**20*(2.6225623144713e+94*cos(theta)**41 - 1.33571496761892e+95*cos(theta)**39 + 3.11246789624409e+95*cos(theta)**37 - 4.40106925456171e+95*cos(theta)**35 + 4.22360678461971e+95*cos(theta)**33 - 2.91511683958066e+95*cos(theta)**31 + 1.49616923885762e+95*cos(theta)**29 - 5.82401448682834e+94*cos(theta)**27 + 1.7382900381605e+94*cos(theta)**25 - 3.99606905324253e+93*cos(theta)**23 + 7.06996832496754e+92*cos(theta)**21 - 9.57249096223845e+91*cos(theta)**19 + 9.81352490733079e+90*cos(theta)**17 - 7.49376410666472e+89*cos(theta)**15 + 4.1632022814804e+88*cos(theta)**13 - 1.62771818524046e+87*cos(theta)**11 + 4.27120707004891e+85*cos(theta)**9 - 7.01155743373282e+83*cos(theta)**7 + 6.44106325933462e+81*cos(theta)**5 - 2.71202663550931e+79*cos(theta)**3 + 3.30734955549916e+76*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl81_m_minus_39(theta, phi):
    return 7.38152427040842e-74*(1.0 - cos(theta)**2)**19.5*(6.24419598683643e+92*cos(theta)**42 - 3.33928741904731e+93*cos(theta)**40 + 8.19070499011604e+93*cos(theta)**38 - 1.22251923737825e+94*cos(theta)**36 + 1.24223728959403e+94*cos(theta)**34 - 9.10974012368957e+93*cos(theta)**32 + 4.98723079619208e+93*cos(theta)**30 - 2.08000517386726e+93*cos(theta)**28 + 6.68573091600192e+92*cos(theta)**26 - 1.66502877218439e+92*cos(theta)**24 + 3.21362196589434e+91*cos(theta)**22 - 4.78624548111923e+90*cos(theta)**20 + 5.45195828185044e+89*cos(theta)**18 - 4.68360256666545e+88*cos(theta)**16 + 2.97371591534314e+87*cos(theta)**14 - 1.35643182103372e+86*cos(theta)**12 + 4.27120707004891e+84*cos(theta)**10 - 8.76444679216603e+82*cos(theta)**8 + 1.07351054322244e+81*cos(theta)**6 - 6.78006658877328e+78*cos(theta)**4 + 1.65367477774958e+76*cos(theta)**2 - 6.50796842876655e+72)*sin(39*phi)

#@torch.jit.script
def Yl81_m_minus_38(theta, phi):
    return 5.30238066213549e-72*(1.0 - cos(theta)**2)**19*(1.45213860158987e+91*cos(theta)**43 - 8.14460346109099e+91*cos(theta)**41 + 2.10018076669642e+92*cos(theta)**39 - 3.30410604696825e+92*cos(theta)**37 + 3.54924939884009e+92*cos(theta)**35 - 2.76052731020896e+92*cos(theta)**33 + 1.6087841278039e+92*cos(theta)**31 - 7.17243163402505e+91*cos(theta)**29 + 2.47619663555627e+91*cos(theta)**27 - 6.66011508873754e+90*cos(theta)**25 + 1.39722694169319e+90*cos(theta)**23 - 2.27916451481868e+89*cos(theta)**21 + 2.8694517272897e+88*cos(theta)**19 - 2.75506033333262e+87*cos(theta)**17 + 1.98247727689543e+86*cos(theta)**15 - 1.04340909310286e+85*cos(theta)**13 + 3.88291551822628e+83*cos(theta)**11 - 9.73827421351781e+81*cos(theta)**9 + 1.53358649031777e+80*cos(theta)**7 - 1.35601331775466e+78*cos(theta)**5 + 5.51224925916527e+75*cos(theta)**3 - 6.50796842876655e+72*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl81_m_minus_37(theta, phi):
    return 3.83681378532868e-70*(1.0 - cos(theta)**2)**18.5*(3.30031500361333e+89*cos(theta)**44 - 1.93919130025976e+90*cos(theta)**42 + 5.25045191674105e+90*cos(theta)**40 - 8.69501591307435e+90*cos(theta)**38 + 9.85902610788914e+90*cos(theta)**36 - 8.11919797120282e+90*cos(theta)**34 + 5.02745039938718e+90*cos(theta)**32 - 2.39081054467501e+90*cos(theta)**30 + 8.84355941270095e+89*cos(theta)**28 - 2.56158272643752e+89*cos(theta)**26 + 5.82177892372163e+88*cos(theta)**24 - 1.03598387037213e+88*cos(theta)**22 + 1.43472586364485e+87*cos(theta)**20 - 1.53058907407368e+86*cos(theta)**18 + 1.23904829805964e+85*cos(theta)**16 - 7.45292209359184e+83*cos(theta)**14 + 3.23576293185524e+82*cos(theta)**12 - 9.73827421351781e+80*cos(theta)**10 + 1.91698311289721e+79*cos(theta)**8 - 2.26002219625776e+77*cos(theta)**6 + 1.37806231479132e+75*cos(theta)**4 - 3.25398421438327e+72*cos(theta)**2 + 1.24292750740385e+69)*sin(37*phi)

#@torch.jit.script
def Yl81_m_minus_36(theta, phi):
    return 2.79587649089978e-68*(1.0 - cos(theta)**2)**18*(7.33403334136297e+87*cos(theta)**45 - 4.50974720990642e+88*cos(theta)**43 + 1.28059802847343e+89*cos(theta)**41 - 2.22949125976265e+89*cos(theta)**39 + 2.66460165078085e+89*cos(theta)**37 - 2.31977084891509e+89*cos(theta)**35 + 1.52346981799611e+89*cos(theta)**33 - 7.71229207959682e+88*cos(theta)**31 + 3.04950324575895e+88*cos(theta)**29 - 9.48734343125006e+87*cos(theta)**27 + 2.32871156948865e+87*cos(theta)**25 - 4.50427769727012e+86*cos(theta)**23 + 6.83202792211834e+85*cos(theta)**21 - 8.05573196880883e+84*cos(theta)**19 + 7.28851940035084e+83*cos(theta)**17 - 4.96861472906123e+82*cos(theta)**15 + 2.48904840911941e+81*cos(theta)**13 - 8.85297655774346e+79*cos(theta)**11 + 2.12998123655245e+78*cos(theta)**9 - 3.22860313751109e+76*cos(theta)**7 + 2.75612462958263e+74*cos(theta)**5 - 1.08466140479442e+72*cos(theta)**3 + 1.24292750740385e+69*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl81_m_minus_35(theta, phi):
    return 2.05111414227571e-66*(1.0 - cos(theta)**2)**17.5*(1.59435507420934e+86*cos(theta)**46 - 1.024942547706e+87*cos(theta)**44 + 3.04904292493673e+87*cos(theta)**42 - 5.57372814940663e+87*cos(theta)**40 + 7.01210960731802e+87*cos(theta)**38 - 6.44380791365303e+87*cos(theta)**36 + 4.48079358234151e+87*cos(theta)**34 - 2.41009127487401e+87*cos(theta)**32 + 1.01650108191965e+87*cos(theta)**30 - 3.38833693973216e+86*cos(theta)**28 + 8.95658295957173e+85*cos(theta)**26 - 1.87678237386255e+85*cos(theta)**24 + 3.10546723732652e+84*cos(theta)**22 - 4.02786598440441e+83*cos(theta)**20 + 4.04917744463936e+82*cos(theta)**18 - 3.10538420566327e+81*cos(theta)**16 + 1.77789172079958e+80*cos(theta)**14 - 7.37748046478622e+78*cos(theta)**12 + 2.12998123655245e+77*cos(theta)**10 - 4.03575392188886e+75*cos(theta)**8 + 4.59354104930439e+73*cos(theta)**6 - 2.71165351198606e+71*cos(theta)**4 + 6.21463753701924e+68*cos(theta)**2 - 2.30941565849842e+65)*sin(35*phi)

#@torch.jit.script
def Yl81_m_minus_34(theta, phi):
    return 1.51449468182479e-64*(1.0 - cos(theta)**2)**17*(3.39224483874328e+84*cos(theta)**47 - 2.27765010601334e+85*cos(theta)**45 + 7.09079749985286e+85*cos(theta)**43 - 1.35944589009918e+86*cos(theta)**41 + 1.79797682238924e+86*cos(theta)**39 - 1.74156970639271e+86*cos(theta)**37 + 1.28022673781186e+86*cos(theta)**35 - 7.3033068935576e+85*cos(theta)**33 + 3.2790357481279e+85*cos(theta)**31 - 1.1683920481835e+85*cos(theta)**29 + 3.31725294798953e+84*cos(theta)**27 - 7.5071294954502e+83*cos(theta)**25 + 1.3502031466637e+83*cos(theta)**23 - 1.91803142114496e+82*cos(theta)**21 + 2.1311460234944e+81*cos(theta)**19 - 1.82669659156663e+80*cos(theta)**17 + 1.18526114719972e+79*cos(theta)**15 - 5.67498497291248e+77*cos(theta)**13 + 1.93634657868405e+76*cos(theta)**11 - 4.48417102432095e+74*cos(theta)**9 + 6.56220149900627e+72*cos(theta)**7 - 5.42330702397212e+70*cos(theta)**5 + 2.07154584567308e+68*cos(theta)**3 - 2.30941565849842e+65*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl81_m_minus_33(theta, phi):
    return 1.12521960789178e-62*(1.0 - cos(theta)**2)**16.5*(7.06717674738183e+82*cos(theta)**48 - 4.95141327394205e+83*cos(theta)**46 + 1.6115448863302e+84*cos(theta)**44 - 3.23677592880757e+84*cos(theta)**42 + 4.49494205597309e+84*cos(theta)**40 - 4.58307817471766e+84*cos(theta)**38 + 3.55618538281073e+84*cos(theta)**36 - 2.14803143928165e+84*cos(theta)**34 + 1.02469867128997e+84*cos(theta)**32 - 3.89464016061168e+83*cos(theta)**30 + 1.18473319571055e+83*cos(theta)**28 - 2.88735749825008e+82*cos(theta)**26 + 5.6258464444321e+81*cos(theta)**24 - 8.718324641568e+80*cos(theta)**22 + 1.0655730117472e+80*cos(theta)**20 - 1.01483143975924e+79*cos(theta)**18 + 7.40788216999825e+77*cos(theta)**16 - 4.05356069493748e+76*cos(theta)**14 + 1.61362214890337e+75*cos(theta)**12 - 4.48417102432095e+73*cos(theta)**10 + 8.20275187375784e+71*cos(theta)**8 - 9.03884503995354e+69*cos(theta)**6 + 5.1788646141827e+67*cos(theta)**4 - 1.15470782924921e+65*cos(theta)**2 + 4.18372401901887e+61)*sin(33*phi)

#@torch.jit.script
def Yl81_m_minus_32(theta, phi):
    return 8.40984046292634e-61*(1.0 - cos(theta)**2)**16*(1.44228096885343e+81*cos(theta)**49 - 1.05349218594512e+82*cos(theta)**47 + 3.58121085851155e+82*cos(theta)**45 - 7.52738588094784e+82*cos(theta)**43 + 1.09632733072514e+83*cos(theta)**41 - 1.17514824992761e+83*cos(theta)**39 + 9.61131184543439e+82*cos(theta)**37 - 6.13723268366185e+82*cos(theta)**35 + 3.10514748875748e+82*cos(theta)**33 - 1.25633553568119e+82*cos(theta)**31 + 4.08528688176051e+81*cos(theta)**29 - 1.06939166601855e+81*cos(theta)**27 + 2.25033857777284e+80*cos(theta)**25 - 3.79057593111652e+79*cos(theta)**23 + 5.07415719879619e+78*cos(theta)**21 - 5.34121810399599e+77*cos(theta)**19 + 4.35757774705779e+76*cos(theta)**17 - 2.70237379662499e+75*cos(theta)**15 + 1.24124780684875e+74*cos(theta)**13 - 4.07651911301905e+72*cos(theta)**11 + 9.11416874861982e+70*cos(theta)**9 - 1.29126357713622e+69*cos(theta)**7 + 1.03577292283654e+67*cos(theta)**5 - 3.84902609749736e+64*cos(theta)**3 + 4.18372401901887e+61*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl81_m_minus_31(theta, phi):
    return 6.32138120870022e-59*(1.0 - cos(theta)**2)**15.5*(2.88456193770687e+79*cos(theta)**50 - 2.19477538738566e+80*cos(theta)**48 + 7.78524099676423e+80*cos(theta)**46 - 1.71076951839724e+81*cos(theta)**44 + 2.6103031683932e+81*cos(theta)**42 - 2.93787062481901e+81*cos(theta)**40 + 2.52929259090379e+81*cos(theta)**38 - 1.70478685657274e+81*cos(theta)**36 + 9.13278673163965e+80*cos(theta)**34 - 3.92604854900371e+80*cos(theta)**32 + 1.36176229392017e+80*cos(theta)**30 - 3.81925595006624e+79*cos(theta)**28 + 8.65514837604939e+78*cos(theta)**26 - 1.57940663796522e+78*cos(theta)**24 + 2.3064350903619e+77*cos(theta)**22 - 2.67060905199799e+76*cos(theta)**20 + 2.42087652614322e+75*cos(theta)**18 - 1.68898362289062e+74*cos(theta)**16 + 8.86605576320534e+72*cos(theta)**14 - 3.39709926084921e+71*cos(theta)**12 + 9.11416874861982e+69*cos(theta)**10 - 1.61407947142028e+68*cos(theta)**8 + 1.72628820472757e+66*cos(theta)**6 - 9.62256524374341e+63*cos(theta)**4 + 2.09186200950944e+61*cos(theta)**2 - 7.40482127259977e+57)*sin(31*phi)

#@torch.jit.script
def Yl81_m_minus_30(theta, phi):
    return 4.77755923587731e-57*(1.0 - cos(theta)**2)**15*(5.65600379942523e+77*cos(theta)**51 - 4.47913344364421e+78*cos(theta)**49 + 1.65643425463069e+79*cos(theta)**47 - 3.80171004088275e+79*cos(theta)**45 + 6.07047248463535e+79*cos(theta)**43 - 7.16553810931467e+79*cos(theta)**41 + 6.48536561770202e+79*cos(theta)**39 - 4.60753204479118e+79*cos(theta)**37 + 2.60936763761133e+79*cos(theta)**35 - 1.18971168151628e+79*cos(theta)**33 + 4.39278159329087e+78*cos(theta)**31 - 1.31698481036767e+78*cos(theta)**29 + 3.20561050964792e+77*cos(theta)**27 - 6.31762655186087e+76*cos(theta)**25 + 1.00279786537474e+76*cos(theta)**23 - 1.27171859618952e+75*cos(theta)**21 + 1.27414554007538e+74*cos(theta)**19 - 9.93519778170952e+72*cos(theta)**17 + 5.9107038421369e+71*cos(theta)**15 - 2.61315327757631e+70*cos(theta)**13 + 8.28560795329075e+68*cos(theta)**11 - 1.79342163491142e+67*cos(theta)**9 + 2.46612600675367e+65*cos(theta)**7 - 1.92451304874868e+63*cos(theta)**5 + 6.97287336503145e+60*cos(theta)**3 - 7.40482127259977e+57*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl81_m_minus_29(theta, phi):
    return 3.6296875490925e-55*(1.0 - cos(theta)**2)**14.5*(1.08769303835101e+76*cos(theta)**52 - 8.95826688728841e+76*cos(theta)**50 + 3.45090469714727e+77*cos(theta)**48 - 8.26458704539727e+77*cos(theta)**46 + 1.37965283741713e+78*cos(theta)**44 - 1.70608050221778e+78*cos(theta)**42 + 1.6213414044255e+78*cos(theta)**40 - 1.21250843283978e+78*cos(theta)**38 + 7.24824343780925e+77*cos(theta)**36 - 3.49915200445964e+77*cos(theta)**34 + 1.3727442479034e+77*cos(theta)**32 - 4.38994936789223e+76*cos(theta)**30 + 1.14486089630283e+76*cos(theta)**28 - 2.42985636610033e+75*cos(theta)**26 + 4.17832443906142e+74*cos(theta)**24 - 5.78053907358873e+73*cos(theta)**22 + 6.37072770037689e+72*cos(theta)**20 - 5.51955432317195e+71*cos(theta)**18 + 3.69418990133556e+70*cos(theta)**16 - 1.86653805541165e+69*cos(theta)**14 + 6.90467329440895e+67*cos(theta)**12 - 1.79342163491142e+66*cos(theta)**10 + 3.08265750844208e+64*cos(theta)**8 - 3.20752174791447e+62*cos(theta)**6 + 1.74321834125786e+60*cos(theta)**4 - 3.70241063629989e+57*cos(theta)**2 + 1.28288656836448e+54)*sin(29*phi)

#@torch.jit.script
def Yl81_m_minus_28(theta, phi):
    return 2.77142748118251e-53*(1.0 - cos(theta)**2)**14*(2.05225101575662e+74*cos(theta)**53 - 1.75652291907616e+75*cos(theta)**51 + 7.04266264723932e+75*cos(theta)**49 - 1.75842277561644e+76*cos(theta)**47 + 3.06589519426028e+76*cos(theta)**45 - 3.96762907492507e+76*cos(theta)**43 + 3.95449123030611e+76*cos(theta)**41 - 3.10899598164047e+76*cos(theta)**39 + 1.95898471292142e+76*cos(theta)**37 - 9.99757715559896e+75*cos(theta)**35 + 4.15983105425271e+75*cos(theta)**33 - 1.41611269932007e+75*cos(theta)**31 + 3.94779619414769e+74*cos(theta)**29 - 8.99946802259383e+73*cos(theta)**27 + 1.67132977562457e+73*cos(theta)**25 - 2.51327785808206e+72*cos(theta)**23 + 3.03367985732233e+71*cos(theta)**21 - 2.90502859114313e+70*cos(theta)**19 + 2.17305288313856e+69*cos(theta)**17 - 1.24435870360777e+68*cos(theta)**15 + 5.31128714954535e+66*cos(theta)**13 - 1.63038330446492e+65*cos(theta)**11 + 3.42517500938009e+63*cos(theta)**9 - 4.5821739255921e+61*cos(theta)**7 + 3.48643668251573e+59*cos(theta)**5 - 1.23413687876663e+57*cos(theta)**3 + 1.28288656836448e+54*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl81_m_minus_27(theta, phi):
    return 2.12624667732623e-51*(1.0 - cos(theta)**2)**13.5*(3.80046484399373e+72*cos(theta)**54 - 3.37792869053108e+73*cos(theta)**52 + 1.40853252944786e+74*cos(theta)**50 - 3.66338078253425e+74*cos(theta)**48 + 6.66498955273974e+74*cos(theta)**46 - 9.01733880664788e+74*cos(theta)**44 + 9.41545531025264e+74*cos(theta)**42 - 7.77248995410117e+74*cos(theta)**40 + 5.15522292874057e+74*cos(theta)**38 - 2.77710476544416e+74*cos(theta)**36 + 1.22347972183903e+74*cos(theta)**34 - 4.42535218537523e+73*cos(theta)**32 + 1.3159320647159e+73*cos(theta)**30 - 3.21409572235494e+72*cos(theta)**28 + 6.42819144470988e+71*cos(theta)**26 - 1.04719910753419e+71*cos(theta)**24 + 1.37894538969197e+70*cos(theta)**22 - 1.45251429557157e+69*cos(theta)**20 + 1.20725160174365e+68*cos(theta)**18 - 7.77724189754855e+66*cos(theta)**16 + 3.79377653538954e+65*cos(theta)**14 - 1.35865275372077e+64*cos(theta)**12 + 3.42517500938009e+62*cos(theta)**10 - 5.72771740699012e+60*cos(theta)**8 + 5.81072780419288e+58*cos(theta)**6 - 3.08534219691657e+56*cos(theta)**4 + 6.4144328418224e+53*cos(theta)**2 - 2.17955584159782e+50)*sin(27*phi)

#@torch.jit.script
def Yl81_m_minus_26(theta, phi):
    return 1.63872798539216e-49*(1.0 - cos(theta)**2)**13*(6.90993607998861e+70*cos(theta)**55 - 6.3734503594926e+71*cos(theta)**53 + 2.76182848911346e+72*cos(theta)**51 - 7.47628731129439e+72*cos(theta)**49 + 1.41808288356165e+73*cos(theta)**47 - 2.00385306814397e+73*cos(theta)**45 + 2.1896407698262e+73*cos(theta)**43 - 1.89572925709785e+73*cos(theta)**41 + 1.3218520330104e+73*cos(theta)**39 - 7.50568855525448e+72*cos(theta)**37 + 3.49565634811153e+72*cos(theta)**35 - 1.34101581375007e+72*cos(theta)**33 + 4.24494214424482e+71*cos(theta)**31 - 1.10830886977756e+71*cos(theta)**29 + 2.38081164618884e+70*cos(theta)**27 - 4.18879643013676e+69*cos(theta)**25 + 5.99541473779117e+68*cos(theta)**23 - 6.91673474081699e+67*cos(theta)**21 + 6.35395579865077e+66*cos(theta)**19 - 4.57484817502856e+65*cos(theta)**17 + 2.52918435692636e+64*cos(theta)**15 - 1.04511750286213e+63*cos(theta)**13 + 3.11379546307281e+61*cos(theta)**11 - 6.36413045221125e+59*cos(theta)**9 + 8.30103972027554e+57*cos(theta)**7 - 6.17068439383314e+55*cos(theta)**5 + 2.13814428060747e+53*cos(theta)**3 - 2.17955584159782e+50*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl81_m_minus_25(theta, phi):
    return 1.26850672151801e-47*(1.0 - cos(theta)**2)**12.5*(1.23391715714082e+69*cos(theta)**56 - 1.18026858509122e+70*cos(theta)**54 + 5.3112086329105e+70*cos(theta)**52 - 1.49525746225888e+71*cos(theta)**50 + 2.95433934075343e+71*cos(theta)**48 - 4.35620232205212e+71*cos(theta)**46 + 4.97645629505954e+71*cos(theta)**44 - 4.51364108832821e+71*cos(theta)**42 + 3.30463008252601e+71*cos(theta)**40 - 1.97518119875118e+71*cos(theta)**38 + 9.71015652253201e+70*cos(theta)**36 - 3.94416415808844e+70*cos(theta)**34 + 1.32654442007651e+70*cos(theta)**32 - 3.69436289925855e+69*cos(theta)**30 + 8.50289873638873e+68*cos(theta)**28 - 1.6110755500526e+68*cos(theta)**26 + 2.49808947407965e+67*cos(theta)**24 - 3.14397033673499e+66*cos(theta)**22 + 3.17697789932539e+65*cos(theta)**20 - 2.54158231946031e+64*cos(theta)**18 + 1.58074022307897e+63*cos(theta)**16 - 7.46512502044379e+61*cos(theta)**14 + 2.59482955256068e+60*cos(theta)**12 - 6.36413045221125e+58*cos(theta)**10 + 1.03762996503444e+57*cos(theta)**8 - 1.02844739897219e+55*cos(theta)**6 + 5.34536070151866e+52*cos(theta)**4 - 1.08977792079891e+50*cos(theta)**2 + 3.6374429933208e+46)*sin(25*phi)

#@torch.jit.script
def Yl81_m_minus_24(theta, phi):
    return 9.86014117846434e-46*(1.0 - cos(theta)**2)**12*(2.16476694235232e+67*cos(theta)**57 - 2.14594288198404e+68*cos(theta)**55 + 1.00211483639821e+69*cos(theta)**53 - 2.93187737697819e+69*cos(theta)**51 + 6.02926396072128e+69*cos(theta)**49 - 9.26851557883429e+69*cos(theta)**47 + 1.1058791766799e+70*cos(theta)**45 - 1.04968397402982e+70*cos(theta)**43 + 8.06007337201466e+69*cos(theta)**41 - 5.06456717628507e+69*cos(theta)**39 + 2.62436662771136e+69*cos(theta)**37 - 1.12690404516813e+69*cos(theta)**35 + 4.01983157598942e+68*cos(theta)**33 - 1.19172996750276e+68*cos(theta)**31 + 2.93203404703059e+67*cos(theta)**29 - 5.9669464816763e+66*cos(theta)**27 + 9.99235789631861e+65*cos(theta)**25 - 1.36694362466739e+65*cos(theta)**23 + 1.51284661872637e+64*cos(theta)**21 - 1.33767490497911e+63*cos(theta)**19 + 9.29847190046455e+61*cos(theta)**17 - 4.9767500136292e+60*cos(theta)**15 + 1.99602273273898e+59*cos(theta)**13 - 5.78557313837386e+57*cos(theta)**11 + 1.1529221833716e+56*cos(theta)**9 - 1.46921056996027e+54*cos(theta)**7 + 1.06907214030373e+52*cos(theta)**5 - 3.63259306932971e+49*cos(theta)**3 + 3.6374429933208e+46*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl81_m_minus_23(theta, phi):
    return 7.69470154665417e-44*(1.0 - cos(theta)**2)**11.5*(3.73235679715917e+65*cos(theta)**58 - 3.83204086068578e+66*cos(theta)**56 + 1.85576821555223e+67*cos(theta)**54 - 5.63822572495806e+67*cos(theta)**52 + 1.20585279214426e+68*cos(theta)**50 - 1.93094074559048e+68*cos(theta)**48 + 2.40408516669543e+68*cos(theta)**46 - 2.38564539552231e+68*cos(theta)**44 + 1.91906508857492e+68*cos(theta)**42 - 1.26614179407127e+68*cos(theta)**40 + 6.90622796766146e+67*cos(theta)**38 - 3.1302890143559e+67*cos(theta)**36 + 1.18230340470277e+67*cos(theta)**34 - 3.72415614844612e+66*cos(theta)**32 + 9.77344682343532e+65*cos(theta)**30 - 2.13105231488439e+65*cos(theta)**28 + 3.84321457550716e+64*cos(theta)**26 - 5.69559843611412e+63*cos(theta)**24 + 6.87657553966534e+62*cos(theta)**22 - 6.68837452489555e+61*cos(theta)**20 + 5.1658177224803e+60*cos(theta)**18 - 3.11046875851825e+59*cos(theta)**16 + 1.42573052338499e+58*cos(theta)**14 - 4.82131094864488e+56*cos(theta)**12 + 1.1529221833716e+55*cos(theta)**10 - 1.83651321245034e+53*cos(theta)**8 + 1.78178690050622e+51*cos(theta)**6 - 9.08148267332427e+48*cos(theta)**4 + 1.8187214966604e+46*cos(theta)**2 - 5.97281279691429e+42)*sin(23*phi)

#@torch.jit.script
def Yl81_m_minus_22(theta, phi):
    return 6.02746163894733e-42*(1.0 - cos(theta)**2)**11*(6.32602846976131e+63*cos(theta)**59 - 6.72287870295751e+64*cos(theta)**57 + 3.37412402827679e+65*cos(theta)**55 - 1.06381617452039e+66*cos(theta)**53 + 2.36441723949854e+66*cos(theta)**51 - 3.94069539916424e+66*cos(theta)**49 + 5.11507482275623e+66*cos(theta)**47 - 5.3014342122718e+66*cos(theta)**45 + 4.4629420664533e+66*cos(theta)**43 - 3.08815071724699e+66*cos(theta)**41 + 1.77082768401576e+66*cos(theta)**39 - 8.46024057934028e+65*cos(theta)**37 + 3.3780097277222e+65*cos(theta)**35 - 1.12853216619579e+65*cos(theta)**33 + 3.15272478175333e+64*cos(theta)**31 - 7.34845625822204e+63*cos(theta)**29 + 1.42341280574339e+63*cos(theta)**27 - 2.27823937444565e+62*cos(theta)**25 + 2.98981545202841e+61*cos(theta)**23 - 3.18494024995026e+60*cos(theta)**21 + 2.71885143288437e+59*cos(theta)**19 - 1.82968750501073e+58*cos(theta)**17 + 9.50487015589992e+56*cos(theta)**15 - 3.70870072972683e+55*cos(theta)**13 + 1.04811107579237e+54*cos(theta)**11 - 2.04057023605593e+52*cos(theta)**9 + 2.54540985786603e+50*cos(theta)**7 - 1.81629653466485e+48*cos(theta)**5 + 6.062404988868e+45*cos(theta)**3 - 5.97281279691429e+42*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl81_m_minus_21(theta, phi):
    return 4.73836697333064e-40*(1.0 - cos(theta)**2)**10.5*(1.05433807829355e+62*cos(theta)**60 - 1.1591170177513e+63*cos(theta)**58 + 6.0252214790657e+63*cos(theta)**56 - 1.97002995281554e+64*cos(theta)**54 + 4.54695622980489e+64*cos(theta)**52 - 7.88139079832848e+64*cos(theta)**50 + 1.06564058807421e+65*cos(theta)**48 - 1.15248569831996e+65*cos(theta)**46 + 1.01430501510302e+65*cos(theta)**44 - 7.35273980296904e+64*cos(theta)**42 + 4.4270692100394e+64*cos(theta)**40 - 2.22637909982639e+64*cos(theta)**38 + 9.38336035478389e+63*cos(theta)**36 - 3.31921225351704e+63*cos(theta)**34 + 9.85226494297915e+62*cos(theta)**32 - 2.44948541940735e+62*cos(theta)**30 + 5.08361716336926e+61*cos(theta)**28 - 8.76245913248326e+60*cos(theta)**26 + 1.24575643834517e+60*cos(theta)**24 - 1.44770011361376e+59*cos(theta)**22 + 1.35942571644219e+58*cos(theta)**20 - 1.0164930583393e+57*cos(theta)**18 + 5.94054384743745e+55*cos(theta)**16 - 2.64907194980488e+54*cos(theta)**14 + 8.73425896493638e+52*cos(theta)**12 - 2.04057023605593e+51*cos(theta)**10 + 3.18176232233254e+49*cos(theta)**8 - 3.02716089110809e+47*cos(theta)**6 + 1.515601247217e+45*cos(theta)**4 - 2.98640639845714e+42*cos(theta)**2 + 9.6647456260749e+38)*sin(21*phi)

#@torch.jit.script
def Yl81_m_minus_20(theta, phi):
    return 3.73760752933104e-38*(1.0 - cos(theta)**2)**10*(1.72842307916976e+60*cos(theta)**61 - 1.9646051148327e+61*cos(theta)**59 + 1.05705639983609e+62*cos(theta)**57 - 3.58187264148279e+62*cos(theta)**55 + 8.57916269774508e+62*cos(theta)**53 - 1.54537074477029e+63*cos(theta)**51 + 2.17477671035554e+63*cos(theta)**49 - 2.45209723046799e+63*cos(theta)**47 + 2.25401114467338e+63*cos(theta)**45 - 1.70993948906257e+63*cos(theta)**43 + 1.07977297805839e+63*cos(theta)**41 - 5.7086643585292e+62*cos(theta)**39 + 2.53604333913078e+62*cos(theta)**37 - 9.48346358147726e+61*cos(theta)**35 + 2.9855348312058e+61*cos(theta)**33 - 7.90156586905596e+60*cos(theta)**31 + 1.75297143564457e+60*cos(theta)**29 - 3.24535523425306e+59*cos(theta)**27 + 4.98302575338068e+58*cos(theta)**25 - 6.29434832005981e+57*cos(theta)**23 + 6.47345579258184e+56*cos(theta)**21 - 5.34996346494367e+55*cos(theta)**19 + 3.49443755731615e+54*cos(theta)**17 - 1.76604796653659e+53*cos(theta)**15 + 6.71866074225876e+51*cos(theta)**13 - 1.85506385095994e+50*cos(theta)**11 + 3.53529146925837e+48*cos(theta)**9 - 4.32451555872584e+46*cos(theta)**7 + 3.031202494434e+44*cos(theta)**5 - 9.95468799485715e+41*cos(theta)**3 + 9.6647456260749e+38*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl81_m_minus_19(theta, phi):
    return 2.95767348250648e-36*(1.0 - cos(theta)**2)**9.5*(2.78777915995122e+58*cos(theta)**62 - 3.27434185805451e+59*cos(theta)**60 + 1.82251103420015e+60*cos(theta)**58 - 6.39620114550499e+60*cos(theta)**56 + 1.58873383291575e+61*cos(theta)**54 - 2.97186681686594e+61*cos(theta)**52 + 4.34955342071108e+61*cos(theta)**50 - 5.10853589680831e+61*cos(theta)**48 + 4.90002422755083e+61*cos(theta)**46 - 3.88622611150583e+61*cos(theta)**44 + 2.57088804299617e+61*cos(theta)**42 - 1.4271660896323e+61*cos(theta)**40 + 6.67379826087047e+60*cos(theta)**38 - 2.63429543929924e+60*cos(theta)**36 + 8.78098479766413e+59*cos(theta)**34 - 2.46923933407999e+59*cos(theta)**32 + 5.84323811881524e+58*cos(theta)**30 - 1.15905544080466e+58*cos(theta)**28 + 1.91654836668488e+57*cos(theta)**26 - 2.62264513335825e+56*cos(theta)**24 + 2.94247990571902e+55*cos(theta)**22 - 2.67498173247183e+54*cos(theta)**20 + 1.94135419850897e+53*cos(theta)**18 - 1.10377997908537e+52*cos(theta)**16 + 4.79904338732768e+50*cos(theta)**14 - 1.54588654246662e+49*cos(theta)**12 + 3.53529146925838e+47*cos(theta)**10 - 5.4056444484073e+45*cos(theta)**8 + 5.05200415739e+43*cos(theta)**6 - 2.48867199871429e+41*cos(theta)**4 + 4.83237281303745e+38*cos(theta)**2 - 1.54339597989059e+35)*sin(19*phi)

#@torch.jit.script
def Yl81_m_minus_18(theta, phi):
    return 2.34758054821275e-34*(1.0 - cos(theta)**2)**9*(4.42504628563686e+56*cos(theta)**63 - 5.36777353779427e+57*cos(theta)**61 + 3.08900175288161e+58*cos(theta)**59 - 1.12214055184298e+59*cos(theta)**57 + 2.88860696893774e+59*cos(theta)**55 - 5.60729588087913e+59*cos(theta)**53 + 8.52853611904133e+59*cos(theta)**51 - 1.04255834628741e+60*cos(theta)**49 + 1.04255834628741e+60*cos(theta)**47 - 8.63605802556852e+59*cos(theta)**45 + 5.97880940231667e+59*cos(theta)**43 - 3.4808929015422e+59*cos(theta)**41 + 1.71123032330012e+59*cos(theta)**39 - 7.11971740351145e+58*cos(theta)**37 + 2.50885279933261e+58*cos(theta)**35 - 7.48254343660602e+57*cos(theta)**33 + 1.88491552219846e+57*cos(theta)**31 - 3.99674289932643e+56*cos(theta)**29 + 7.09832728401807e+55*cos(theta)**27 - 1.0490580533433e+55*cos(theta)**25 + 1.27933908944305e+54*cos(theta)**23 - 1.27380082498659e+53*cos(theta)**21 + 1.0217653676363e+52*cos(theta)**19 - 6.49282340638451e+50*cos(theta)**17 + 3.19936225821846e+49*cos(theta)**15 - 1.18914349420509e+48*cos(theta)**13 + 3.21390133568943e+46*cos(theta)**11 - 6.00627160934145e+44*cos(theta)**9 + 7.21714879627143e+42*cos(theta)**7 - 4.97734399742857e+40*cos(theta)**5 + 1.61079093767915e+38*cos(theta)**3 - 1.54339597989059e+35*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl81_m_minus_17(theta, phi):
    return 1.86865052245405e-32*(1.0 - cos(theta)**2)**8.5*(6.91413482130759e+54*cos(theta)**64 - 8.65769925450689e+55*cos(theta)**62 + 5.14833625480268e+56*cos(theta)**60 - 1.93472508938445e+57*cos(theta)**58 + 5.15822673024596e+57*cos(theta)**56 - 1.03838812608873e+58*cos(theta)**54 + 1.64010309981564e+58*cos(theta)**52 - 2.08511669257482e+58*cos(theta)**50 + 2.17199655476544e+58*cos(theta)**48 - 1.87740391860185e+58*cos(theta)**46 + 1.35882031870833e+58*cos(theta)**44 - 8.28784024176714e+57*cos(theta)**42 + 4.2780758082503e+57*cos(theta)**40 - 1.87360984302933e+57*cos(theta)**38 + 6.96903555370169e+56*cos(theta)**36 - 2.20074806959001e+56*cos(theta)**34 + 5.8903610068702e+55*cos(theta)**32 - 1.33224763310881e+55*cos(theta)**30 + 2.53511688714931e+54*cos(theta)**28 - 4.03483866670501e+53*cos(theta)**26 + 5.33057953934604e+52*cos(theta)**24 - 5.79000374993903e+51*cos(theta)**22 + 5.1088268381815e+50*cos(theta)**20 - 3.60712411465806e+49*cos(theta)**18 + 1.99960141138653e+48*cos(theta)**16 - 8.49388210146493e+46*cos(theta)**14 + 2.67825111307453e+45*cos(theta)**12 - 6.00627160934145e+43*cos(theta)**10 + 9.02143599533929e+41*cos(theta)**8 - 8.29557332904762e+39*cos(theta)**6 + 4.02697734419787e+37*cos(theta)**4 - 7.71697989945297e+34*cos(theta)**2 + 2.43591537230207e+31)*sin(17*phi)

#@torch.jit.script
def Yl81_m_minus_16(theta, phi):
    return 1.49141258266054e-30*(1.0 - cos(theta)**2)**8*(1.06371304943194e+53*cos(theta)**65 - 1.37423797690586e+54*cos(theta)**63 + 8.43989549967653e+54*cos(theta)**61 - 3.2791950667533e+55*cos(theta)**59 + 9.04952057937887e+55*cos(theta)**57 - 1.88797841107042e+56*cos(theta)**55 + 3.09453415059555e+56*cos(theta)**53 - 4.08846410308789e+56*cos(theta)**51 + 4.43264603013355e+56*cos(theta)**49 - 3.99447642255713e+56*cos(theta)**47 + 3.01960070824074e+56*cos(theta)**45 - 1.92740470738771e+56*cos(theta)**43 + 1.04343312396349e+56*cos(theta)**41 - 4.80412780263931e+55*cos(theta)**39 + 1.88352312262208e+55*cos(theta)**37 - 6.28785162740002e+54*cos(theta)**35 + 1.78495788086976e+54*cos(theta)**33 - 4.29757301002842e+53*cos(theta)**31 + 8.74178236948038e+52*cos(theta)**29 - 1.49438469137222e+52*cos(theta)**27 + 2.13223181573842e+51*cos(theta)**25 - 2.5173929347561e+50*cos(theta)**23 + 2.43277468484833e+49*cos(theta)**21 - 1.89848637613582e+48*cos(theta)**19 + 1.17623612434502e+47*cos(theta)**17 - 5.66258806764329e+45*cos(theta)**15 + 2.06019316390348e+44*cos(theta)**13 - 5.46024691758313e+42*cos(theta)**11 + 1.00238177725992e+41*cos(theta)**9 - 1.18508190414966e+39*cos(theta)**7 + 8.05395468839575e+36*cos(theta)**5 - 2.57232663315099e+34*cos(theta)**3 + 2.43591537230207e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl81_m_minus_15(theta, phi):
    return 1.19331647813896e-28*(1.0 - cos(theta)**2)**7.5*(1.61168643853324e+51*cos(theta)**66 - 2.1472468389154e+52*cos(theta)**64 + 1.36127346768976e+53*cos(theta)**62 - 5.4653251112555e+53*cos(theta)**60 + 1.56026216885843e+54*cos(theta)**58 - 3.3713900197686e+54*cos(theta)**56 + 5.73061879739916e+54*cos(theta)**54 - 7.86243096747671e+54*cos(theta)**52 + 8.8652920602671e+54*cos(theta)**50 - 8.32182588032736e+54*cos(theta)**48 + 6.56434936574074e+54*cos(theta)**46 - 4.38046524406297e+54*cos(theta)**44 + 2.48436458086545e+54*cos(theta)**42 - 1.20103195065983e+54*cos(theta)**40 + 4.95663979637389e+53*cos(theta)**38 - 1.74662545205556e+53*cos(theta)**36 + 5.24987612020517e+52*cos(theta)**34 - 1.34299156563388e+52*cos(theta)**32 + 2.91392745649346e+51*cos(theta)**30 - 5.33708818347223e+50*cos(theta)**28 + 8.20089159899391e+49*cos(theta)**26 - 1.04891372281504e+49*cos(theta)**24 + 1.10580667493106e+48*cos(theta)**22 - 9.49243188067911e+46*cos(theta)**20 + 6.53464513525011e+45*cos(theta)**18 - 3.53911754227705e+44*cos(theta)**16 + 1.47156654564534e+43*cos(theta)**14 - 4.55020576465261e+41*cos(theta)**12 + 1.00238177725992e+40*cos(theta)**10 - 1.48135238018708e+38*cos(theta)**8 + 1.34232578139929e+36*cos(theta)**6 - 6.43081658287747e+33*cos(theta)**4 + 1.21795768615104e+31*cos(theta)**2 - 3.80492872899418e+27)*sin(15*phi)

#@torch.jit.script
def Yl81_m_minus_14(theta, phi):
    return 9.57036839611255e-27*(1.0 - cos(theta)**2)**7*(2.40550214706453e+49*cos(theta)**67 - 3.30345667525446e+50*cos(theta)**65 + 2.1607515360155e+51*cos(theta)**63 - 8.95954936271394e+51*cos(theta)**61 + 2.6445121506075e+52*cos(theta)**59 - 5.91471933292737e+52*cos(theta)**57 + 1.04193069043621e+53*cos(theta)**55 - 1.48347754103334e+53*cos(theta)**53 + 1.73829256083669e+53*cos(theta)**51 - 1.69833181231171e+53*cos(theta)**49 + 1.39667007781718e+53*cos(theta)**47 - 9.73436720902882e+52*cos(theta)**45 + 5.7775920485243e+52*cos(theta)**43 - 2.92934622112153e+52*cos(theta)**41 + 1.27093328112151e+52*cos(theta)**39 - 4.72060932987989e+51*cos(theta)**37 + 1.49996460577291e+51*cos(theta)**35 - 4.06967141101176e+50*cos(theta)**33 + 9.39976598868858e+49*cos(theta)**31 - 1.84037523568008e+49*cos(theta)**29 + 3.03736725888663e+48*cos(theta)**27 - 4.19565489126017e+47*cos(theta)**25 + 4.80785510839591e+46*cos(theta)**23 - 4.52020565746624e+45*cos(theta)**21 + 3.43928691328953e+44*cos(theta)**19 - 2.08183384839827e+43*cos(theta)**17 + 9.81044363763563e+41*cos(theta)**15 - 3.50015828050201e+40*cos(theta)**13 + 9.11256161145383e+38*cos(theta)**11 - 1.64594708909675e+37*cos(theta)**9 + 1.91760825914184e+35*cos(theta)**7 - 1.28616331657549e+33*cos(theta)**5 + 4.05985895383679e+30*cos(theta)**3 - 3.80492872899418e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl81_m_minus_13(theta, phi):
    return 7.69209987580128e-25*(1.0 - cos(theta)**2)**6.5*(3.53750315744784e+47*cos(theta)**68 - 5.00523738674919e+48*cos(theta)**66 + 3.37617427502421e+49*cos(theta)**64 - 1.44508860688935e+50*cos(theta)**62 + 4.4075202510125e+50*cos(theta)**60 - 1.0197791953323e+51*cos(theta)**58 + 1.86059051863609e+51*cos(theta)**56 - 2.74718063154322e+51*cos(theta)**54 + 3.34287030930132e+51*cos(theta)**52 - 3.39666362462341e+51*cos(theta)**50 + 2.90972932878579e+51*cos(theta)**48 - 2.11616678457148e+51*cos(theta)**46 + 1.31308910193734e+51*cos(theta)**44 - 6.97463385981316e+50*cos(theta)**42 + 3.17733320280377e+50*cos(theta)**40 - 1.24226561312629e+50*cos(theta)**38 + 4.16656834936918e+49*cos(theta)**36 - 1.19696217970934e+49*cos(theta)**34 + 2.93742687146518e+48*cos(theta)**32 - 6.1345841189336e+47*cos(theta)**30 + 1.08477402103094e+47*cos(theta)**28 - 1.61371341971545e+46*cos(theta)**26 + 2.00327296183163e+45*cos(theta)**24 - 2.05463893521193e+44*cos(theta)**22 + 1.71964345664477e+43*cos(theta)**20 - 1.15657436022126e+42*cos(theta)**18 + 6.13152727352227e+40*cos(theta)**16 - 2.50011305750143e+39*cos(theta)**14 + 7.59380134287819e+37*cos(theta)**12 - 1.64594708909675e+36*cos(theta)**10 + 2.39701032392731e+34*cos(theta)**8 - 2.14360552762582e+32*cos(theta)**6 + 1.0149647384592e+30*cos(theta)**4 - 1.90246436449709e+27*cos(theta)**2 + 5.88998255262257e+23)*sin(13*phi)

#@torch.jit.script
def Yl81_m_minus_12(theta, phi):
    return 6.19488696941658e-23*(1.0 - cos(theta)**2)**6*(5.12681617021427e+45*cos(theta)**69 - 7.47050356231222e+46*cos(theta)**67 + 5.19411426926802e+47*cos(theta)**65 - 2.2937914395069e+48*cos(theta)**63 + 7.22544303444673e+48*cos(theta)**61 - 1.72843931412255e+49*cos(theta)**59 + 3.26419389234402e+49*cos(theta)**57 - 4.99487387553313e+49*cos(theta)**55 + 6.30730247037985e+49*cos(theta)**53 - 6.66012475416355e+49*cos(theta)**51 + 5.938223119971e+49*cos(theta)**49 - 4.50248252036486e+49*cos(theta)**47 + 2.91797578208298e+49*cos(theta)**45 - 1.62200787437515e+49*cos(theta)**43 + 7.74959317757018e+48*cos(theta)**41 - 3.18529644391356e+48*cos(theta)**39 + 1.12609955388356e+48*cos(theta)**37 - 3.41989194202669e+47*cos(theta)**35 + 8.90129354989448e+46*cos(theta)**33 - 1.97889810288181e+46*cos(theta)**31 + 3.74060007252049e+45*cos(theta)**29 - 5.97671636931648e+44*cos(theta)**27 + 8.01309184732652e+43*cos(theta)**25 - 8.933212761791e+42*cos(theta)**23 + 8.18877836497508e+41*cos(theta)**21 - 6.08723347484873e+40*cos(theta)**19 + 3.60678074913075e+39*cos(theta)**17 - 1.66674203833429e+38*cos(theta)**15 + 5.84138564836784e+36*cos(theta)**13 - 1.4963155355425e+35*cos(theta)**11 + 2.66334480436367e+33*cos(theta)**9 - 3.06229361089404e+31*cos(theta)**7 + 2.02992947691839e+29*cos(theta)**5 - 6.34154788165697e+26*cos(theta)**3 + 5.88998255262257e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl81_m_minus_11(theta, phi):
    return 4.99831797618605e-21*(1.0 - cos(theta)**2)**5.5*(7.32402310030609e+43*cos(theta)**70 - 1.09860346504591e+45*cos(theta)**68 + 7.86987010495155e+45*cos(theta)**66 - 3.58404912422953e+46*cos(theta)**64 + 1.16539403781399e+47*cos(theta)**62 - 2.88073219020425e+47*cos(theta)**60 + 5.62792050404142e+47*cos(theta)**58 - 8.9194176348806e+47*cos(theta)**56 + 1.16801897599627e+48*cos(theta)**54 - 1.28079322195453e+48*cos(theta)**52 + 1.1876446239942e+48*cos(theta)**50 - 9.38017191742679e+47*cos(theta)**48 + 6.34342561322387e+47*cos(theta)**46 - 3.68638153267081e+47*cos(theta)**44 + 1.84514123275481e+47*cos(theta)**42 - 7.9632411097839e+46*cos(theta)**40 + 2.96341987864095e+46*cos(theta)**38 - 9.49969983896302e+45*cos(theta)**36 + 2.61802751467485e+45*cos(theta)**34 - 6.18405657150564e+44*cos(theta)**32 + 1.24686669084016e+44*cos(theta)**30 - 2.13454156047017e+43*cos(theta)**28 + 3.08195840281789e+42*cos(theta)**26 - 3.72217198407958e+41*cos(theta)**24 + 3.72217198407958e+40*cos(theta)**22 - 3.04361673742437e+39*cos(theta)**20 + 2.00376708285041e+38*cos(theta)**18 - 1.04171377395893e+37*cos(theta)**16 + 4.17241832026274e+35*cos(theta)**14 - 1.24692961295208e+34*cos(theta)**12 + 2.66334480436367e+32*cos(theta)**10 - 3.82786701361754e+30*cos(theta)**8 + 3.38321579486399e+28*cos(theta)**6 - 1.58538697041424e+26*cos(theta)**4 + 2.94499127631128e+23*cos(theta)**2 - 9.04759224673206e+19)*sin(11*phi)

#@torch.jit.script
def Yl81_m_minus_10(theta, phi):
    return 4.03968004531094e-19*(1.0 - cos(theta)**2)**5*(1.03155254933889e+42*cos(theta)**71 - 1.59217893484915e+43*cos(theta)**69 + 1.17460747835098e+44*cos(theta)**67 - 5.51392172958389e+44*cos(theta)**65 + 1.84983180605395e+45*cos(theta)**63 - 4.72251178722008e+45*cos(theta)**61 + 9.5388483119346e+45*cos(theta)**59 - 1.56481011138256e+46*cos(theta)**57 + 2.12367086544776e+46*cos(theta)**55 - 2.41659098481987e+46*cos(theta)**53 + 2.32871494900823e+46*cos(theta)**51 - 1.91432079947485e+46*cos(theta)**49 + 1.34966502409018e+46*cos(theta)**47 - 8.19195896149068e+45*cos(theta)**45 + 4.29102612268559e+45*cos(theta)**43 - 1.94225392921558e+45*cos(theta)**41 + 7.59851250933578e+44*cos(theta)**39 - 2.56748644296298e+44*cos(theta)**37 + 7.48007861335671e+43*cos(theta)**35 - 1.87395653681989e+43*cos(theta)**33 + 4.02215061561343e+42*cos(theta)**31 - 7.36048813955231e+41*cos(theta)**29 + 1.14146607511774e+41*cos(theta)**27 - 1.48886879363183e+40*cos(theta)**25 + 1.61833564525199e+39*cos(theta)**23 - 1.44934130353541e+38*cos(theta)**21 + 1.0546142541318e+37*cos(theta)**19 - 6.12772808211136e+35*cos(theta)**17 + 2.78161221350849e+34*cos(theta)**15 - 9.59176625347757e+32*cos(theta)**13 + 2.42122254942152e+31*cos(theta)**11 - 4.25318557068616e+29*cos(theta)**9 + 4.83316542123427e+27*cos(theta)**7 - 3.17077394082848e+25*cos(theta)**5 + 9.81663758770428e+22*cos(theta)**3 - 9.04759224673206e+19*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl81_m_minus_9(theta, phi):
    return 3.26989579984291e-17*(1.0 - cos(theta)**2)**4.5*(1.43271187408179e+40*cos(theta)**72 - 2.27454133549879e+41*cos(theta)**70 + 1.72736393875144e+42*cos(theta)**68 - 8.35442686300589e+42*cos(theta)**66 + 2.8903621969593e+43*cos(theta)**64 - 7.61695449551626e+43*cos(theta)**62 + 1.5898080519891e+44*cos(theta)**60 - 2.69794846790097e+44*cos(theta)**58 + 3.79226940258529e+44*cos(theta)**56 - 4.47516849040716e+44*cos(theta)**54 + 4.47829797886199e+44*cos(theta)**52 - 3.82864159894971e+44*cos(theta)**50 + 2.81180213352122e+44*cos(theta)**48 - 1.78086064380232e+44*cos(theta)**46 + 9.75233209701271e+43*cos(theta)**44 - 4.62441411717996e+43*cos(theta)**42 + 1.89962812733394e+43*cos(theta)**40 - 6.75654327095521e+42*cos(theta)**38 + 2.07779961482131e+42*cos(theta)**36 - 5.51163687299968e+41*cos(theta)**34 + 1.2569220673792e+41*cos(theta)**32 - 2.45349604651744e+40*cos(theta)**30 + 4.07666455399192e+39*cos(theta)**28 - 5.72641843704551e+38*cos(theta)**26 + 6.74306518854997e+37*cos(theta)**24 - 6.58791501607006e+36*cos(theta)**22 + 5.27307127065899e+35*cos(theta)**20 - 3.40429337895075e+34*cos(theta)**18 + 1.73850763344281e+33*cos(theta)**16 - 6.85126160962683e+31*cos(theta)**14 + 2.01768545785127e+30*cos(theta)**12 - 4.25318557068616e+28*cos(theta)**10 + 6.04145677654284e+26*cos(theta)**8 - 5.28462323471414e+24*cos(theta)**6 + 2.45415939692607e+22*cos(theta)**4 - 4.52379612336603e+19*cos(theta)**2 + 1.38089014754763e+16)*sin(9*phi)

#@torch.jit.script
def Yl81_m_minus_8(theta, phi):
    return 2.65043158409768e-15*(1.0 - cos(theta)**2)**4*(1.96261900559149e+38*cos(theta)**73 - 3.20357934577294e+39*cos(theta)**71 + 2.50342599819049e+40*cos(theta)**69 - 1.24692938253819e+41*cos(theta)**67 + 4.44671107224507e+41*cos(theta)**65 - 1.20904039611369e+42*cos(theta)**63 + 2.60624270817885e+42*cos(theta)**61 - 4.57279401339147e+42*cos(theta)**59 + 6.65310421506191e+42*cos(theta)**57 - 8.13666998255847e+42*cos(theta)**55 + 8.44961882804149e+42*cos(theta)**53 - 7.50714039009747e+42*cos(theta)**51 + 5.73837170106371e+42*cos(theta)**49 - 3.78906519957941e+42*cos(theta)**47 + 2.16718491044727e+42*cos(theta)**45 - 1.07544514353022e+42*cos(theta)**43 + 4.63323933496084e+41*cos(theta)**41 - 1.73244699255262e+41*cos(theta)**39 + 5.61567463465218e+40*cos(theta)**37 - 1.57475339228562e+40*cos(theta)**35 + 3.80885474963393e+39*cos(theta)**33 - 7.9145033758627e+38*cos(theta)**31 + 1.40574639792825e+38*cos(theta)**29 - 2.12089571742426e+37*cos(theta)**27 + 2.69722607541999e+36*cos(theta)**25 - 2.8643108765522e+35*cos(theta)**23 + 2.51098631936142e+34*cos(theta)**21 - 1.7917333573425e+33*cos(theta)**19 + 1.02265154908401e+32*cos(theta)**17 - 4.56750773975122e+30*cos(theta)**15 + 1.55206573680867e+29*cos(theta)**13 - 3.86653233698742e+27*cos(theta)**11 + 6.71272975171427e+25*cos(theta)**9 - 7.54946176387734e+23*cos(theta)**7 + 4.90831879385214e+21*cos(theta)**5 - 1.50793204112201e+19*cos(theta)**3 + 1.38089014754763e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl81_m_minus_7(theta, phi):
    return 2.1509358664297e-13*(1.0 - cos(theta)**2)**3.5*(2.6521878453939e+36*cos(theta)**74 - 4.44941575801797e+37*cos(theta)**72 + 3.57632285455784e+38*cos(theta)**70 - 1.83371968020322e+39*cos(theta)**68 + 6.73744101855314e+39*cos(theta)**66 - 1.88912561892764e+40*cos(theta)**64 + 4.20361727125622e+40*cos(theta)**62 - 7.62132335565245e+40*cos(theta)**60 + 1.14708693363136e+41*cos(theta)**58 - 1.45297678259973e+41*cos(theta)**56 + 1.56474422741509e+41*cos(theta)**54 - 1.44368084424951e+41*cos(theta)**52 + 1.14767434021274e+41*cos(theta)**50 - 7.8938858324571e+40*cos(theta)**48 + 4.71127154445059e+40*cos(theta)**46 - 2.44419350802324e+40*cos(theta)**44 + 1.10315222260972e+40*cos(theta)**42 - 4.33111748138154e+39*cos(theta)**40 + 1.47780911438215e+39*cos(theta)**38 - 4.37431497857118e+38*cos(theta)**36 + 1.12025139695115e+38*cos(theta)**34 - 2.47328230495709e+37*cos(theta)**32 + 4.6858213264275e+36*cos(theta)**30 - 7.57462756222951e+35*cos(theta)**28 + 1.0373946443923e+35*cos(theta)**26 - 1.19346286523008e+34*cos(theta)**24 + 1.14135741789156e+33*cos(theta)**22 - 8.95866678671251e+31*cos(theta)**20 + 5.68139749491114e+30*cos(theta)**18 - 2.85469233734451e+29*cos(theta)**16 + 1.10861838343476e+28*cos(theta)**14 - 3.22211028082285e+26*cos(theta)**12 + 6.71272975171427e+24*cos(theta)**10 - 9.43682720484668e+22*cos(theta)**8 + 8.1805313230869e+20*cos(theta)**6 - 3.76983010280502e+18*cos(theta)**4 + 6.90445073773814e+15*cos(theta)**2 - 2096705356130.62)*sin(7*phi)

#@torch.jit.script
def Yl81_m_minus_6(theta, phi):
    return 1.74742855847838e-11*(1.0 - cos(theta)**2)**3*(3.53625046052521e+34*cos(theta)**75 - 6.09509007947667e+35*cos(theta)**73 + 5.03707444303921e+36*cos(theta)**71 - 2.65756475391772e+37*cos(theta)**69 + 1.00558821172435e+38*cos(theta)**67 - 2.90634710604253e+38*cos(theta)**65 + 6.67240836707336e+38*cos(theta)**63 - 1.24939727141843e+39*cos(theta)**61 + 1.94421514174807e+39*cos(theta)**59 - 2.54908207473636e+39*cos(theta)**57 + 2.84498950439107e+39*cos(theta)**55 - 2.7239261212255e+39*cos(theta)**53 + 2.2503418435544e+39*cos(theta)**51 - 1.61099710866471e+39*cos(theta)**49 + 1.00239820094693e+39*cos(theta)**47 - 5.43154112894053e+38*cos(theta)**45 + 2.56547028513889e+38*cos(theta)**43 - 1.05637011741013e+38*cos(theta)**41 + 3.78925413944142e+37*cos(theta)**39 - 1.18224729150572e+37*cos(theta)**37 + 3.2007182770033e+36*cos(theta)**35 - 7.49479486350635e+35*cos(theta)**33 + 1.51155526658952e+35*cos(theta)**31 - 2.61194053869983e+34*cos(theta)**29 + 3.84220238663816e+33*cos(theta)**27 - 4.77385146092033e+32*cos(theta)**25 + 4.96242355605024e+31*cos(theta)**23 - 4.26603180319643e+30*cos(theta)**21 + 2.99020920784797e+29*cos(theta)**19 - 1.67923078667324e+28*cos(theta)**17 + 7.39078922289842e+26*cos(theta)**15 - 2.47854636986373e+25*cos(theta)**13 + 6.10248159246752e+23*cos(theta)**11 - 1.04853635609408e+22*cos(theta)**9 + 1.16864733186956e+20*cos(theta)**7 - 7.53966020561005e+17*cos(theta)**5 + 2.30148357924605e+15*cos(theta)**3 - 2096705356130.62*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl81_m_minus_5(theta, phi):
    return 1.42090764727727e-9*(1.0 - cos(theta)**2)**2.5*(4.65296113227001e+32*cos(theta)**76 - 8.23660821550902e+33*cos(theta)**74 + 6.99593672644335e+34*cos(theta)**72 - 3.79652107702531e+35*cos(theta)**70 + 1.47880619371228e+36*cos(theta)**68 - 4.40355622127656e+36*cos(theta)**66 + 1.04256380735521e+37*cos(theta)**64 - 2.01515688938457e+37*cos(theta)**62 + 3.24035856958012e+37*cos(theta)**60 - 4.39496909437304e+37*cos(theta)**58 + 5.08033840069835e+37*cos(theta)**56 - 5.04430763189907e+37*cos(theta)**54 + 4.32758046837384e+37*cos(theta)**52 - 3.22199421732943e+37*cos(theta)**50 + 2.08832958530611e+37*cos(theta)**48 - 1.18076981063924e+37*cos(theta)**46 + 5.83061428440658e+36*cos(theta)**44 - 2.5151669462146e+36*cos(theta)**42 + 9.47313534860355e+35*cos(theta)**40 - 3.1111770829098e+35*cos(theta)**38 + 8.89088410278694e+34*cos(theta)**36 - 2.20435143044304e+34*cos(theta)**34 + 4.72361020809224e+33*cos(theta)**32 - 8.70646846233277e+32*cos(theta)**30 + 1.37221513808506e+32*cos(theta)**28 - 1.83609671573859e+31*cos(theta)**26 + 2.0676764816876e+30*cos(theta)**24 - 1.93910536508929e+29*cos(theta)**22 + 1.49510460392398e+28*cos(theta)**20 - 9.32905992596246e+26*cos(theta)**18 + 4.61924326431151e+25*cos(theta)**16 - 1.77039026418838e+24*cos(theta)**14 + 5.08540132705626e+22*cos(theta)**12 - 1.04853635609407e+21*cos(theta)**10 + 1.46080916483695e+19*cos(theta)**8 - 1.25661003426834e+17*cos(theta)**6 + 575370894811512.0*cos(theta)**4 - 1048352678065.31*cos(theta)**2 + 317106073.219997)*sin(5*phi)

#@torch.jit.script
def Yl81_m_minus_4(theta, phi):
    return 1.15627314704298e-7*(1.0 - cos(theta)**2)**2*(6.04280666528572e+30*cos(theta)**77 - 1.09821442873454e+32*cos(theta)**75 + 9.58347496773062e+32*cos(theta)**73 - 5.34721278454269e+33*cos(theta)**71 + 2.14319738219171e+34*cos(theta)**69 - 6.57247197205457e+34*cos(theta)**67 + 1.60394431900802e+35*cos(theta)**65 - 3.19866172918186e+35*cos(theta)**63 + 5.31206322881987e+35*cos(theta)**61 - 7.4491001599543e+35*cos(theta)**59 + 8.91287438719008e+35*cos(theta)**57 - 9.17146842163467e+35*cos(theta)**55 + 8.16524616674309e+35*cos(theta)**53 - 6.31763572025378e+35*cos(theta)**51 + 4.26189711286961e+35*cos(theta)**49 - 2.51227619284946e+35*cos(theta)**47 + 1.29569206320146e+35*cos(theta)**45 - 5.84922545631303e+34*cos(theta)**43 + 2.31052081673257e+34*cos(theta)**41 - 7.97737713566615e+33*cos(theta)**39 + 2.40294164940188e+33*cos(theta)**37 - 6.29814694412298e+32*cos(theta)**35 + 1.43139703275522e+32*cos(theta)**33 - 2.80853821365573e+31*cos(theta)**31 + 4.73177633822433e+30*cos(theta)**29 - 6.80035820643922e+29*cos(theta)**27 + 8.2707059267504e+28*cos(theta)**25 - 8.43089289169256e+27*cos(theta)**23 + 7.11954573297135e+26*cos(theta)**21 - 4.91003153998024e+25*cos(theta)**19 + 2.71720192018324e+24*cos(theta)**17 - 1.18026017612559e+23*cos(theta)**15 + 3.91184717465866e+21*cos(theta)**13 - 9.53214869176432e+19*cos(theta)**11 + 1.62312129426327e+18*cos(theta)**9 - 1.79515719181192e+16*cos(theta)**7 + 115074178962302.0*cos(theta)**5 - 349450892688.437*cos(theta)**3 + 317106073.219997*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl81_m_minus_3(theta, phi):
    return 9.414932355305e-6*(1.0 - cos(theta)**2)**1.5*(7.74718803241759e+28*cos(theta)**78 - 1.44501898517702e+30*cos(theta)**76 + 1.29506418482846e+31*cos(theta)**74 - 7.42668442297596e+31*cos(theta)**72 + 3.06171054598815e+32*cos(theta)**70 - 9.66539995890378e+32*cos(theta)**68 + 2.43021866516366e+33*cos(theta)**66 - 4.99790895184666e+33*cos(theta)**64 + 8.56784391745141e+33*cos(theta)**62 - 1.24151669332572e+34*cos(theta)**60 + 1.53670248055001e+34*cos(theta)**58 - 1.63776221814905e+34*cos(theta)**56 + 1.51208262347094e+34*cos(theta)**54 - 1.21492994620265e+34*cos(theta)**52 + 8.52379422573923e+33*cos(theta)**50 - 5.23390873510303e+33*cos(theta)**48 + 2.81672187652492e+33*cos(theta)**46 - 1.32936942188932e+33*cos(theta)**44 + 5.50124003983946e+32*cos(theta)**42 - 1.99434428391654e+32*cos(theta)**40 + 6.32353065632073e+31*cos(theta)**38 - 1.74948526225638e+31*cos(theta)**36 + 4.20999127280948e+30*cos(theta)**34 - 8.77668191767417e+29*cos(theta)**32 + 1.57725877940811e+29*cos(theta)**30 - 2.42869935944258e+28*cos(theta)**28 + 3.18104074105785e+27*cos(theta)**26 - 3.51287203820523e+26*cos(theta)**24 + 3.23615715135062e+25*cos(theta)**22 - 2.45501576999012e+24*cos(theta)**20 + 1.50955662232402e+23*cos(theta)**18 - 7.37662610078491e+21*cos(theta)**16 + 2.79417655332762e+20*cos(theta)**14 - 7.94345724313693e+18*cos(theta)**12 + 1.62312129426327e+17*cos(theta)**10 - 2.2439464897649e+15*cos(theta)**8 + 19179029827050.4*cos(theta)**6 - 87362723172.1093*cos(theta)**4 + 158553036.609999*cos(theta)**2 - 47828.9703197583)*sin(3*phi)

#@torch.jit.script
def Yl81_m_minus_2(theta, phi):
    return 0.000766955899989024*(1.0 - cos(theta)**2)*(9.80656712964252e+26*cos(theta)**79 - 1.87664803269743e+28*cos(theta)**77 + 1.72675224643795e+29*cos(theta)**75 - 1.01735403054465e+30*cos(theta)**73 + 4.3122683746312e+30*cos(theta)**71 - 1.40078260273968e+31*cos(theta)**69 + 3.62719203755771e+31*cos(theta)**67 - 7.6890906951487e+31*cos(theta)**65 + 1.35997522499229e+32*cos(theta)**63 - 2.03527326774708e+32*cos(theta)**61 + 2.6045804755085e+32*cos(theta)**59 - 2.87326704938429e+32*cos(theta)**57 + 2.74924113358353e+32*cos(theta)**55 - 2.29232065321255e+32*cos(theta)**53 + 1.67133220112534e+32*cos(theta)**51 - 1.06814463981695e+32*cos(theta)**49 + 5.99302526920195e+31*cos(theta)**47 - 2.95415427086516e+31*cos(theta)**45 + 1.27935814879987e+31*cos(theta)**43 - 4.86425435101594e+30*cos(theta)**41 + 1.62141811700531e+30*cos(theta)**39 - 4.72833854663887e+29*cos(theta)**37 + 1.20285464937414e+29*cos(theta)**35 - 2.65960058111338e+28*cos(theta)**33 + 5.08793154647778e+27*cos(theta)**31 - 8.3748253773882e+26*cos(theta)**29 + 1.17816323742883e+26*cos(theta)**27 - 1.40514881528209e+25*cos(theta)**25 + 1.40702484841331e+24*cos(theta)**23 - 1.16905512856672e+23*cos(theta)**21 + 7.94503485433696e+21*cos(theta)**19 - 4.33919182399112e+20*cos(theta)**17 + 1.86278436888508e+19*cos(theta)**15 - 6.11035172548995e+17*cos(theta)**13 + 1.47556481296661e+16*cos(theta)**11 - 249327387751655.0*cos(theta)**9 + 2739861403864.34*cos(theta)**7 - 17472544634.4218*cos(theta)**5 + 52851012.2033329*cos(theta)**3 - 47828.9703197583*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl81_m_minus_1(theta, phi):
    return 0.0624963181378371*(1.0 - cos(theta)**2)**0.5*(1.22582089120532e+25*cos(theta)**80 - 2.40595901627876e+26*cos(theta)**78 + 2.27204242952362e+27*cos(theta)**76 - 1.37480274397926e+28*cos(theta)**74 + 5.98926163143222e+28*cos(theta)**72 - 2.00111800391383e+29*cos(theta)**70 + 5.33410593758487e+29*cos(theta)**68 - 1.1650137416892e+30*cos(theta)**66 + 2.12496128905045e+30*cos(theta)**64 - 3.2826988189469e+30*cos(theta)**62 + 4.34096745918083e+30*cos(theta)**60 - 4.95390870583499e+30*cos(theta)**58 + 4.90935916711345e+30*cos(theta)**56 - 4.2450382466899e+30*cos(theta)**54 + 3.2141003867795e+30*cos(theta)**52 - 2.13628927963389e+30*cos(theta)**50 + 1.24854693108374e+30*cos(theta)**48 - 6.42207450188079e+29*cos(theta)**46 + 2.90763215636335e+29*cos(theta)**44 - 1.15815579786094e+29*cos(theta)**42 + 4.05354529251329e+28*cos(theta)**40 - 1.24429961753655e+28*cos(theta)**38 + 3.34126291492816e+27*cos(theta)**36 - 7.82235465033348e+26*cos(theta)**34 + 1.58997860827431e+26*cos(theta)**32 - 2.7916084591294e+25*cos(theta)**30 + 4.20772584796011e+24*cos(theta)**28 - 5.40441852031574e+23*cos(theta)**26 + 5.86260353505546e+22*cos(theta)**24 - 5.31388694803057e+21*cos(theta)**22 + 3.97251742716848e+20*cos(theta)**20 - 2.41066212443951e+19*cos(theta)**18 + 1.16424023055317e+18*cos(theta)**16 - 4.36453694677853e+16*cos(theta)**14 + 1.22963734413884e+15*cos(theta)**12 - 24932738775165.5*cos(theta)**10 + 342482675483.043*cos(theta)**8 - 2912090772.40364*cos(theta)**6 + 13212753.0508332*cos(theta)**4 - 23914.4851598791*cos(theta)**2 + 7.20315818068649)*sin(phi)

#@torch.jit.script
def Yl81_m0(theta, phi):
    return 1.71230349295226e+24*cos(theta)**81 - 3.44587783674864e+25*cos(theta)**79 + 3.33860050786873e+26*cos(theta)**77 - 2.07404354268024e+27*cos(theta)**75 + 9.28301746925428e+27*cos(theta)**73 - 3.18898953061441e+28*cos(theta)**71 + 8.74684214522827e+28*cos(theta)**69 - 1.96741051512038e+29*cos(theta)**67 + 3.69893252460132e+29*cos(theta)**65 - 5.89561659093544e+29*cos(theta)**63 + 8.05184559587196e+29*cos(theta)**61 - 9.50024335296305e+29*cos(theta)**59 + 9.74515370318932e+29*cos(theta)**57 - 8.73288338590126e+29*cos(theta)**55 + 6.86155123177956e+29*cos(theta)**53 - 4.73945744230187e+29*cos(theta)**51 + 2.88301919796512e+29*cos(theta)**49 - 1.54602397483218e+29*cos(theta)**47 + 7.31081328431142e+28*cos(theta)**45 - 3.04745480061824e+28*cos(theta)**43 + 1.1186388963245e+28*cos(theta)**41 - 3.60993268392794e+27*cos(theta)**39 + 1.02175711183751e+27*cos(theta)**37 - 2.5287634206012e+26*cos(theta)**35 + 5.45150085238301e+25*cos(theta)**33 - 1.0188999823215e+25*cos(theta)**31 + 1.64167876569472e+24*cos(theta)**29 - 2.26476921125401e+23*cos(theta)**27 + 2.65331773414606e+22*cos(theta)**25 - 2.61410614201582e+21*cos(theta)**23 + 2.14035227809062e+20*cos(theta)**21 - 1.43556045480368e+19*cos(theta)**19 + 7.74876381854257e+17*cos(theta)**17 - 3.29219581168944e+16*cos(theta)**15 + 1.07021845271638e+15*cos(theta)**13 - 25645787807028.5*cos(theta)**11 + 430561150606.4*cos(theta)**9 - 4707015311.82217*cos(theta)**7 + 29899371.3092152*cos(theta)**5 - 90194.1819282511*cos(theta)**3 + 81.5007668026365*cos(theta)

#@torch.jit.script
def Yl81_m1(theta, phi):
    return 0.0624963181378371*(1.0 - cos(theta)**2)**0.5*(1.22582089120532e+25*cos(theta)**80 - 2.40595901627876e+26*cos(theta)**78 + 2.27204242952362e+27*cos(theta)**76 - 1.37480274397926e+28*cos(theta)**74 + 5.98926163143222e+28*cos(theta)**72 - 2.00111800391383e+29*cos(theta)**70 + 5.33410593758487e+29*cos(theta)**68 - 1.1650137416892e+30*cos(theta)**66 + 2.12496128905045e+30*cos(theta)**64 - 3.2826988189469e+30*cos(theta)**62 + 4.34096745918083e+30*cos(theta)**60 - 4.95390870583499e+30*cos(theta)**58 + 4.90935916711345e+30*cos(theta)**56 - 4.2450382466899e+30*cos(theta)**54 + 3.2141003867795e+30*cos(theta)**52 - 2.13628927963389e+30*cos(theta)**50 + 1.24854693108374e+30*cos(theta)**48 - 6.42207450188079e+29*cos(theta)**46 + 2.90763215636335e+29*cos(theta)**44 - 1.15815579786094e+29*cos(theta)**42 + 4.05354529251329e+28*cos(theta)**40 - 1.24429961753655e+28*cos(theta)**38 + 3.34126291492816e+27*cos(theta)**36 - 7.82235465033348e+26*cos(theta)**34 + 1.58997860827431e+26*cos(theta)**32 - 2.7916084591294e+25*cos(theta)**30 + 4.20772584796011e+24*cos(theta)**28 - 5.40441852031574e+23*cos(theta)**26 + 5.86260353505546e+22*cos(theta)**24 - 5.31388694803057e+21*cos(theta)**22 + 3.97251742716848e+20*cos(theta)**20 - 2.41066212443951e+19*cos(theta)**18 + 1.16424023055317e+18*cos(theta)**16 - 4.36453694677853e+16*cos(theta)**14 + 1.22963734413884e+15*cos(theta)**12 - 24932738775165.5*cos(theta)**10 + 342482675483.043*cos(theta)**8 - 2912090772.40364*cos(theta)**6 + 13212753.0508332*cos(theta)**4 - 23914.4851598791*cos(theta)**2 + 7.20315818068649)*cos(phi)

#@torch.jit.script
def Yl81_m2(theta, phi):
    return 0.000766955899989024*(1.0 - cos(theta)**2)*(9.80656712964252e+26*cos(theta)**79 - 1.87664803269743e+28*cos(theta)**77 + 1.72675224643795e+29*cos(theta)**75 - 1.01735403054465e+30*cos(theta)**73 + 4.3122683746312e+30*cos(theta)**71 - 1.40078260273968e+31*cos(theta)**69 + 3.62719203755771e+31*cos(theta)**67 - 7.6890906951487e+31*cos(theta)**65 + 1.35997522499229e+32*cos(theta)**63 - 2.03527326774708e+32*cos(theta)**61 + 2.6045804755085e+32*cos(theta)**59 - 2.87326704938429e+32*cos(theta)**57 + 2.74924113358353e+32*cos(theta)**55 - 2.29232065321255e+32*cos(theta)**53 + 1.67133220112534e+32*cos(theta)**51 - 1.06814463981695e+32*cos(theta)**49 + 5.99302526920195e+31*cos(theta)**47 - 2.95415427086516e+31*cos(theta)**45 + 1.27935814879987e+31*cos(theta)**43 - 4.86425435101594e+30*cos(theta)**41 + 1.62141811700531e+30*cos(theta)**39 - 4.72833854663887e+29*cos(theta)**37 + 1.20285464937414e+29*cos(theta)**35 - 2.65960058111338e+28*cos(theta)**33 + 5.08793154647778e+27*cos(theta)**31 - 8.3748253773882e+26*cos(theta)**29 + 1.17816323742883e+26*cos(theta)**27 - 1.40514881528209e+25*cos(theta)**25 + 1.40702484841331e+24*cos(theta)**23 - 1.16905512856672e+23*cos(theta)**21 + 7.94503485433696e+21*cos(theta)**19 - 4.33919182399112e+20*cos(theta)**17 + 1.86278436888508e+19*cos(theta)**15 - 6.11035172548995e+17*cos(theta)**13 + 1.47556481296661e+16*cos(theta)**11 - 249327387751655.0*cos(theta)**9 + 2739861403864.34*cos(theta)**7 - 17472544634.4218*cos(theta)**5 + 52851012.2033329*cos(theta)**3 - 47828.9703197583*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl81_m3(theta, phi):
    return 9.414932355305e-6*(1.0 - cos(theta)**2)**1.5*(7.74718803241759e+28*cos(theta)**78 - 1.44501898517702e+30*cos(theta)**76 + 1.29506418482846e+31*cos(theta)**74 - 7.42668442297596e+31*cos(theta)**72 + 3.06171054598815e+32*cos(theta)**70 - 9.66539995890378e+32*cos(theta)**68 + 2.43021866516366e+33*cos(theta)**66 - 4.99790895184666e+33*cos(theta)**64 + 8.56784391745141e+33*cos(theta)**62 - 1.24151669332572e+34*cos(theta)**60 + 1.53670248055001e+34*cos(theta)**58 - 1.63776221814905e+34*cos(theta)**56 + 1.51208262347094e+34*cos(theta)**54 - 1.21492994620265e+34*cos(theta)**52 + 8.52379422573923e+33*cos(theta)**50 - 5.23390873510303e+33*cos(theta)**48 + 2.81672187652492e+33*cos(theta)**46 - 1.32936942188932e+33*cos(theta)**44 + 5.50124003983946e+32*cos(theta)**42 - 1.99434428391654e+32*cos(theta)**40 + 6.32353065632073e+31*cos(theta)**38 - 1.74948526225638e+31*cos(theta)**36 + 4.20999127280948e+30*cos(theta)**34 - 8.77668191767417e+29*cos(theta)**32 + 1.57725877940811e+29*cos(theta)**30 - 2.42869935944258e+28*cos(theta)**28 + 3.18104074105785e+27*cos(theta)**26 - 3.51287203820523e+26*cos(theta)**24 + 3.23615715135062e+25*cos(theta)**22 - 2.45501576999012e+24*cos(theta)**20 + 1.50955662232402e+23*cos(theta)**18 - 7.37662610078491e+21*cos(theta)**16 + 2.79417655332762e+20*cos(theta)**14 - 7.94345724313693e+18*cos(theta)**12 + 1.62312129426327e+17*cos(theta)**10 - 2.2439464897649e+15*cos(theta)**8 + 19179029827050.4*cos(theta)**6 - 87362723172.1093*cos(theta)**4 + 158553036.609999*cos(theta)**2 - 47828.9703197583)*cos(3*phi)

#@torch.jit.script
def Yl81_m4(theta, phi):
    return 1.15627314704298e-7*(1.0 - cos(theta)**2)**2*(6.04280666528572e+30*cos(theta)**77 - 1.09821442873454e+32*cos(theta)**75 + 9.58347496773062e+32*cos(theta)**73 - 5.34721278454269e+33*cos(theta)**71 + 2.14319738219171e+34*cos(theta)**69 - 6.57247197205457e+34*cos(theta)**67 + 1.60394431900802e+35*cos(theta)**65 - 3.19866172918186e+35*cos(theta)**63 + 5.31206322881987e+35*cos(theta)**61 - 7.4491001599543e+35*cos(theta)**59 + 8.91287438719008e+35*cos(theta)**57 - 9.17146842163467e+35*cos(theta)**55 + 8.16524616674309e+35*cos(theta)**53 - 6.31763572025378e+35*cos(theta)**51 + 4.26189711286961e+35*cos(theta)**49 - 2.51227619284946e+35*cos(theta)**47 + 1.29569206320146e+35*cos(theta)**45 - 5.84922545631303e+34*cos(theta)**43 + 2.31052081673257e+34*cos(theta)**41 - 7.97737713566615e+33*cos(theta)**39 + 2.40294164940188e+33*cos(theta)**37 - 6.29814694412298e+32*cos(theta)**35 + 1.43139703275522e+32*cos(theta)**33 - 2.80853821365573e+31*cos(theta)**31 + 4.73177633822433e+30*cos(theta)**29 - 6.80035820643922e+29*cos(theta)**27 + 8.2707059267504e+28*cos(theta)**25 - 8.43089289169256e+27*cos(theta)**23 + 7.11954573297135e+26*cos(theta)**21 - 4.91003153998024e+25*cos(theta)**19 + 2.71720192018324e+24*cos(theta)**17 - 1.18026017612559e+23*cos(theta)**15 + 3.91184717465866e+21*cos(theta)**13 - 9.53214869176432e+19*cos(theta)**11 + 1.62312129426327e+18*cos(theta)**9 - 1.79515719181192e+16*cos(theta)**7 + 115074178962302.0*cos(theta)**5 - 349450892688.437*cos(theta)**3 + 317106073.219997*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl81_m5(theta, phi):
    return 1.42090764727727e-9*(1.0 - cos(theta)**2)**2.5*(4.65296113227001e+32*cos(theta)**76 - 8.23660821550902e+33*cos(theta)**74 + 6.99593672644335e+34*cos(theta)**72 - 3.79652107702531e+35*cos(theta)**70 + 1.47880619371228e+36*cos(theta)**68 - 4.40355622127656e+36*cos(theta)**66 + 1.04256380735521e+37*cos(theta)**64 - 2.01515688938457e+37*cos(theta)**62 + 3.24035856958012e+37*cos(theta)**60 - 4.39496909437304e+37*cos(theta)**58 + 5.08033840069835e+37*cos(theta)**56 - 5.04430763189907e+37*cos(theta)**54 + 4.32758046837384e+37*cos(theta)**52 - 3.22199421732943e+37*cos(theta)**50 + 2.08832958530611e+37*cos(theta)**48 - 1.18076981063924e+37*cos(theta)**46 + 5.83061428440658e+36*cos(theta)**44 - 2.5151669462146e+36*cos(theta)**42 + 9.47313534860355e+35*cos(theta)**40 - 3.1111770829098e+35*cos(theta)**38 + 8.89088410278694e+34*cos(theta)**36 - 2.20435143044304e+34*cos(theta)**34 + 4.72361020809224e+33*cos(theta)**32 - 8.70646846233277e+32*cos(theta)**30 + 1.37221513808506e+32*cos(theta)**28 - 1.83609671573859e+31*cos(theta)**26 + 2.0676764816876e+30*cos(theta)**24 - 1.93910536508929e+29*cos(theta)**22 + 1.49510460392398e+28*cos(theta)**20 - 9.32905992596246e+26*cos(theta)**18 + 4.61924326431151e+25*cos(theta)**16 - 1.77039026418838e+24*cos(theta)**14 + 5.08540132705626e+22*cos(theta)**12 - 1.04853635609407e+21*cos(theta)**10 + 1.46080916483695e+19*cos(theta)**8 - 1.25661003426834e+17*cos(theta)**6 + 575370894811512.0*cos(theta)**4 - 1048352678065.31*cos(theta)**2 + 317106073.219997)*cos(5*phi)

#@torch.jit.script
def Yl81_m6(theta, phi):
    return 1.74742855847838e-11*(1.0 - cos(theta)**2)**3*(3.53625046052521e+34*cos(theta)**75 - 6.09509007947667e+35*cos(theta)**73 + 5.03707444303921e+36*cos(theta)**71 - 2.65756475391772e+37*cos(theta)**69 + 1.00558821172435e+38*cos(theta)**67 - 2.90634710604253e+38*cos(theta)**65 + 6.67240836707336e+38*cos(theta)**63 - 1.24939727141843e+39*cos(theta)**61 + 1.94421514174807e+39*cos(theta)**59 - 2.54908207473636e+39*cos(theta)**57 + 2.84498950439107e+39*cos(theta)**55 - 2.7239261212255e+39*cos(theta)**53 + 2.2503418435544e+39*cos(theta)**51 - 1.61099710866471e+39*cos(theta)**49 + 1.00239820094693e+39*cos(theta)**47 - 5.43154112894053e+38*cos(theta)**45 + 2.56547028513889e+38*cos(theta)**43 - 1.05637011741013e+38*cos(theta)**41 + 3.78925413944142e+37*cos(theta)**39 - 1.18224729150572e+37*cos(theta)**37 + 3.2007182770033e+36*cos(theta)**35 - 7.49479486350635e+35*cos(theta)**33 + 1.51155526658952e+35*cos(theta)**31 - 2.61194053869983e+34*cos(theta)**29 + 3.84220238663816e+33*cos(theta)**27 - 4.77385146092033e+32*cos(theta)**25 + 4.96242355605024e+31*cos(theta)**23 - 4.26603180319643e+30*cos(theta)**21 + 2.99020920784797e+29*cos(theta)**19 - 1.67923078667324e+28*cos(theta)**17 + 7.39078922289842e+26*cos(theta)**15 - 2.47854636986373e+25*cos(theta)**13 + 6.10248159246752e+23*cos(theta)**11 - 1.04853635609408e+22*cos(theta)**9 + 1.16864733186956e+20*cos(theta)**7 - 7.53966020561005e+17*cos(theta)**5 + 2.30148357924605e+15*cos(theta)**3 - 2096705356130.62*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl81_m7(theta, phi):
    return 2.1509358664297e-13*(1.0 - cos(theta)**2)**3.5*(2.6521878453939e+36*cos(theta)**74 - 4.44941575801797e+37*cos(theta)**72 + 3.57632285455784e+38*cos(theta)**70 - 1.83371968020322e+39*cos(theta)**68 + 6.73744101855314e+39*cos(theta)**66 - 1.88912561892764e+40*cos(theta)**64 + 4.20361727125622e+40*cos(theta)**62 - 7.62132335565245e+40*cos(theta)**60 + 1.14708693363136e+41*cos(theta)**58 - 1.45297678259973e+41*cos(theta)**56 + 1.56474422741509e+41*cos(theta)**54 - 1.44368084424951e+41*cos(theta)**52 + 1.14767434021274e+41*cos(theta)**50 - 7.8938858324571e+40*cos(theta)**48 + 4.71127154445059e+40*cos(theta)**46 - 2.44419350802324e+40*cos(theta)**44 + 1.10315222260972e+40*cos(theta)**42 - 4.33111748138154e+39*cos(theta)**40 + 1.47780911438215e+39*cos(theta)**38 - 4.37431497857118e+38*cos(theta)**36 + 1.12025139695115e+38*cos(theta)**34 - 2.47328230495709e+37*cos(theta)**32 + 4.6858213264275e+36*cos(theta)**30 - 7.57462756222951e+35*cos(theta)**28 + 1.0373946443923e+35*cos(theta)**26 - 1.19346286523008e+34*cos(theta)**24 + 1.14135741789156e+33*cos(theta)**22 - 8.95866678671251e+31*cos(theta)**20 + 5.68139749491114e+30*cos(theta)**18 - 2.85469233734451e+29*cos(theta)**16 + 1.10861838343476e+28*cos(theta)**14 - 3.22211028082285e+26*cos(theta)**12 + 6.71272975171427e+24*cos(theta)**10 - 9.43682720484668e+22*cos(theta)**8 + 8.1805313230869e+20*cos(theta)**6 - 3.76983010280502e+18*cos(theta)**4 + 6.90445073773814e+15*cos(theta)**2 - 2096705356130.62)*cos(7*phi)

#@torch.jit.script
def Yl81_m8(theta, phi):
    return 2.65043158409768e-15*(1.0 - cos(theta)**2)**4*(1.96261900559149e+38*cos(theta)**73 - 3.20357934577294e+39*cos(theta)**71 + 2.50342599819049e+40*cos(theta)**69 - 1.24692938253819e+41*cos(theta)**67 + 4.44671107224507e+41*cos(theta)**65 - 1.20904039611369e+42*cos(theta)**63 + 2.60624270817885e+42*cos(theta)**61 - 4.57279401339147e+42*cos(theta)**59 + 6.65310421506191e+42*cos(theta)**57 - 8.13666998255847e+42*cos(theta)**55 + 8.44961882804149e+42*cos(theta)**53 - 7.50714039009747e+42*cos(theta)**51 + 5.73837170106371e+42*cos(theta)**49 - 3.78906519957941e+42*cos(theta)**47 + 2.16718491044727e+42*cos(theta)**45 - 1.07544514353022e+42*cos(theta)**43 + 4.63323933496084e+41*cos(theta)**41 - 1.73244699255262e+41*cos(theta)**39 + 5.61567463465218e+40*cos(theta)**37 - 1.57475339228562e+40*cos(theta)**35 + 3.80885474963393e+39*cos(theta)**33 - 7.9145033758627e+38*cos(theta)**31 + 1.40574639792825e+38*cos(theta)**29 - 2.12089571742426e+37*cos(theta)**27 + 2.69722607541999e+36*cos(theta)**25 - 2.8643108765522e+35*cos(theta)**23 + 2.51098631936142e+34*cos(theta)**21 - 1.7917333573425e+33*cos(theta)**19 + 1.02265154908401e+32*cos(theta)**17 - 4.56750773975122e+30*cos(theta)**15 + 1.55206573680867e+29*cos(theta)**13 - 3.86653233698742e+27*cos(theta)**11 + 6.71272975171427e+25*cos(theta)**9 - 7.54946176387734e+23*cos(theta)**7 + 4.90831879385214e+21*cos(theta)**5 - 1.50793204112201e+19*cos(theta)**3 + 1.38089014754763e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl81_m9(theta, phi):
    return 3.26989579984291e-17*(1.0 - cos(theta)**2)**4.5*(1.43271187408179e+40*cos(theta)**72 - 2.27454133549879e+41*cos(theta)**70 + 1.72736393875144e+42*cos(theta)**68 - 8.35442686300589e+42*cos(theta)**66 + 2.8903621969593e+43*cos(theta)**64 - 7.61695449551626e+43*cos(theta)**62 + 1.5898080519891e+44*cos(theta)**60 - 2.69794846790097e+44*cos(theta)**58 + 3.79226940258529e+44*cos(theta)**56 - 4.47516849040716e+44*cos(theta)**54 + 4.47829797886199e+44*cos(theta)**52 - 3.82864159894971e+44*cos(theta)**50 + 2.81180213352122e+44*cos(theta)**48 - 1.78086064380232e+44*cos(theta)**46 + 9.75233209701271e+43*cos(theta)**44 - 4.62441411717996e+43*cos(theta)**42 + 1.89962812733394e+43*cos(theta)**40 - 6.75654327095521e+42*cos(theta)**38 + 2.07779961482131e+42*cos(theta)**36 - 5.51163687299968e+41*cos(theta)**34 + 1.2569220673792e+41*cos(theta)**32 - 2.45349604651744e+40*cos(theta)**30 + 4.07666455399192e+39*cos(theta)**28 - 5.72641843704551e+38*cos(theta)**26 + 6.74306518854997e+37*cos(theta)**24 - 6.58791501607006e+36*cos(theta)**22 + 5.27307127065899e+35*cos(theta)**20 - 3.40429337895075e+34*cos(theta)**18 + 1.73850763344281e+33*cos(theta)**16 - 6.85126160962683e+31*cos(theta)**14 + 2.01768545785127e+30*cos(theta)**12 - 4.25318557068616e+28*cos(theta)**10 + 6.04145677654284e+26*cos(theta)**8 - 5.28462323471414e+24*cos(theta)**6 + 2.45415939692607e+22*cos(theta)**4 - 4.52379612336603e+19*cos(theta)**2 + 1.38089014754763e+16)*cos(9*phi)

#@torch.jit.script
def Yl81_m10(theta, phi):
    return 4.03968004531094e-19*(1.0 - cos(theta)**2)**5*(1.03155254933889e+42*cos(theta)**71 - 1.59217893484915e+43*cos(theta)**69 + 1.17460747835098e+44*cos(theta)**67 - 5.51392172958389e+44*cos(theta)**65 + 1.84983180605395e+45*cos(theta)**63 - 4.72251178722008e+45*cos(theta)**61 + 9.5388483119346e+45*cos(theta)**59 - 1.56481011138256e+46*cos(theta)**57 + 2.12367086544776e+46*cos(theta)**55 - 2.41659098481987e+46*cos(theta)**53 + 2.32871494900823e+46*cos(theta)**51 - 1.91432079947485e+46*cos(theta)**49 + 1.34966502409018e+46*cos(theta)**47 - 8.19195896149068e+45*cos(theta)**45 + 4.29102612268559e+45*cos(theta)**43 - 1.94225392921558e+45*cos(theta)**41 + 7.59851250933578e+44*cos(theta)**39 - 2.56748644296298e+44*cos(theta)**37 + 7.48007861335671e+43*cos(theta)**35 - 1.87395653681989e+43*cos(theta)**33 + 4.02215061561343e+42*cos(theta)**31 - 7.36048813955231e+41*cos(theta)**29 + 1.14146607511774e+41*cos(theta)**27 - 1.48886879363183e+40*cos(theta)**25 + 1.61833564525199e+39*cos(theta)**23 - 1.44934130353541e+38*cos(theta)**21 + 1.0546142541318e+37*cos(theta)**19 - 6.12772808211136e+35*cos(theta)**17 + 2.78161221350849e+34*cos(theta)**15 - 9.59176625347757e+32*cos(theta)**13 + 2.42122254942152e+31*cos(theta)**11 - 4.25318557068616e+29*cos(theta)**9 + 4.83316542123427e+27*cos(theta)**7 - 3.17077394082848e+25*cos(theta)**5 + 9.81663758770428e+22*cos(theta)**3 - 9.04759224673206e+19*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl81_m11(theta, phi):
    return 4.99831797618605e-21*(1.0 - cos(theta)**2)**5.5*(7.32402310030609e+43*cos(theta)**70 - 1.09860346504591e+45*cos(theta)**68 + 7.86987010495155e+45*cos(theta)**66 - 3.58404912422953e+46*cos(theta)**64 + 1.16539403781399e+47*cos(theta)**62 - 2.88073219020425e+47*cos(theta)**60 + 5.62792050404142e+47*cos(theta)**58 - 8.9194176348806e+47*cos(theta)**56 + 1.16801897599627e+48*cos(theta)**54 - 1.28079322195453e+48*cos(theta)**52 + 1.1876446239942e+48*cos(theta)**50 - 9.38017191742679e+47*cos(theta)**48 + 6.34342561322387e+47*cos(theta)**46 - 3.68638153267081e+47*cos(theta)**44 + 1.84514123275481e+47*cos(theta)**42 - 7.9632411097839e+46*cos(theta)**40 + 2.96341987864095e+46*cos(theta)**38 - 9.49969983896302e+45*cos(theta)**36 + 2.61802751467485e+45*cos(theta)**34 - 6.18405657150564e+44*cos(theta)**32 + 1.24686669084016e+44*cos(theta)**30 - 2.13454156047017e+43*cos(theta)**28 + 3.08195840281789e+42*cos(theta)**26 - 3.72217198407958e+41*cos(theta)**24 + 3.72217198407958e+40*cos(theta)**22 - 3.04361673742437e+39*cos(theta)**20 + 2.00376708285041e+38*cos(theta)**18 - 1.04171377395893e+37*cos(theta)**16 + 4.17241832026274e+35*cos(theta)**14 - 1.24692961295208e+34*cos(theta)**12 + 2.66334480436367e+32*cos(theta)**10 - 3.82786701361754e+30*cos(theta)**8 + 3.38321579486399e+28*cos(theta)**6 - 1.58538697041424e+26*cos(theta)**4 + 2.94499127631128e+23*cos(theta)**2 - 9.04759224673206e+19)*cos(11*phi)

#@torch.jit.script
def Yl81_m12(theta, phi):
    return 6.19488696941658e-23*(1.0 - cos(theta)**2)**6*(5.12681617021427e+45*cos(theta)**69 - 7.47050356231222e+46*cos(theta)**67 + 5.19411426926802e+47*cos(theta)**65 - 2.2937914395069e+48*cos(theta)**63 + 7.22544303444673e+48*cos(theta)**61 - 1.72843931412255e+49*cos(theta)**59 + 3.26419389234402e+49*cos(theta)**57 - 4.99487387553313e+49*cos(theta)**55 + 6.30730247037985e+49*cos(theta)**53 - 6.66012475416355e+49*cos(theta)**51 + 5.938223119971e+49*cos(theta)**49 - 4.50248252036486e+49*cos(theta)**47 + 2.91797578208298e+49*cos(theta)**45 - 1.62200787437515e+49*cos(theta)**43 + 7.74959317757018e+48*cos(theta)**41 - 3.18529644391356e+48*cos(theta)**39 + 1.12609955388356e+48*cos(theta)**37 - 3.41989194202669e+47*cos(theta)**35 + 8.90129354989448e+46*cos(theta)**33 - 1.97889810288181e+46*cos(theta)**31 + 3.74060007252049e+45*cos(theta)**29 - 5.97671636931648e+44*cos(theta)**27 + 8.01309184732652e+43*cos(theta)**25 - 8.933212761791e+42*cos(theta)**23 + 8.18877836497508e+41*cos(theta)**21 - 6.08723347484873e+40*cos(theta)**19 + 3.60678074913075e+39*cos(theta)**17 - 1.66674203833429e+38*cos(theta)**15 + 5.84138564836784e+36*cos(theta)**13 - 1.4963155355425e+35*cos(theta)**11 + 2.66334480436367e+33*cos(theta)**9 - 3.06229361089404e+31*cos(theta)**7 + 2.02992947691839e+29*cos(theta)**5 - 6.34154788165697e+26*cos(theta)**3 + 5.88998255262257e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl81_m13(theta, phi):
    return 7.69209987580128e-25*(1.0 - cos(theta)**2)**6.5*(3.53750315744784e+47*cos(theta)**68 - 5.00523738674919e+48*cos(theta)**66 + 3.37617427502421e+49*cos(theta)**64 - 1.44508860688935e+50*cos(theta)**62 + 4.4075202510125e+50*cos(theta)**60 - 1.0197791953323e+51*cos(theta)**58 + 1.86059051863609e+51*cos(theta)**56 - 2.74718063154322e+51*cos(theta)**54 + 3.34287030930132e+51*cos(theta)**52 - 3.39666362462341e+51*cos(theta)**50 + 2.90972932878579e+51*cos(theta)**48 - 2.11616678457148e+51*cos(theta)**46 + 1.31308910193734e+51*cos(theta)**44 - 6.97463385981316e+50*cos(theta)**42 + 3.17733320280377e+50*cos(theta)**40 - 1.24226561312629e+50*cos(theta)**38 + 4.16656834936918e+49*cos(theta)**36 - 1.19696217970934e+49*cos(theta)**34 + 2.93742687146518e+48*cos(theta)**32 - 6.1345841189336e+47*cos(theta)**30 + 1.08477402103094e+47*cos(theta)**28 - 1.61371341971545e+46*cos(theta)**26 + 2.00327296183163e+45*cos(theta)**24 - 2.05463893521193e+44*cos(theta)**22 + 1.71964345664477e+43*cos(theta)**20 - 1.15657436022126e+42*cos(theta)**18 + 6.13152727352227e+40*cos(theta)**16 - 2.50011305750143e+39*cos(theta)**14 + 7.59380134287819e+37*cos(theta)**12 - 1.64594708909675e+36*cos(theta)**10 + 2.39701032392731e+34*cos(theta)**8 - 2.14360552762582e+32*cos(theta)**6 + 1.0149647384592e+30*cos(theta)**4 - 1.90246436449709e+27*cos(theta)**2 + 5.88998255262257e+23)*cos(13*phi)

#@torch.jit.script
def Yl81_m14(theta, phi):
    return 9.57036839611255e-27*(1.0 - cos(theta)**2)**7*(2.40550214706453e+49*cos(theta)**67 - 3.30345667525446e+50*cos(theta)**65 + 2.1607515360155e+51*cos(theta)**63 - 8.95954936271394e+51*cos(theta)**61 + 2.6445121506075e+52*cos(theta)**59 - 5.91471933292737e+52*cos(theta)**57 + 1.04193069043621e+53*cos(theta)**55 - 1.48347754103334e+53*cos(theta)**53 + 1.73829256083669e+53*cos(theta)**51 - 1.69833181231171e+53*cos(theta)**49 + 1.39667007781718e+53*cos(theta)**47 - 9.73436720902882e+52*cos(theta)**45 + 5.7775920485243e+52*cos(theta)**43 - 2.92934622112153e+52*cos(theta)**41 + 1.27093328112151e+52*cos(theta)**39 - 4.72060932987989e+51*cos(theta)**37 + 1.49996460577291e+51*cos(theta)**35 - 4.06967141101176e+50*cos(theta)**33 + 9.39976598868858e+49*cos(theta)**31 - 1.84037523568008e+49*cos(theta)**29 + 3.03736725888663e+48*cos(theta)**27 - 4.19565489126017e+47*cos(theta)**25 + 4.80785510839591e+46*cos(theta)**23 - 4.52020565746624e+45*cos(theta)**21 + 3.43928691328953e+44*cos(theta)**19 - 2.08183384839827e+43*cos(theta)**17 + 9.81044363763563e+41*cos(theta)**15 - 3.50015828050201e+40*cos(theta)**13 + 9.11256161145383e+38*cos(theta)**11 - 1.64594708909675e+37*cos(theta)**9 + 1.91760825914184e+35*cos(theta)**7 - 1.28616331657549e+33*cos(theta)**5 + 4.05985895383679e+30*cos(theta)**3 - 3.80492872899418e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl81_m15(theta, phi):
    return 1.19331647813896e-28*(1.0 - cos(theta)**2)**7.5*(1.61168643853324e+51*cos(theta)**66 - 2.1472468389154e+52*cos(theta)**64 + 1.36127346768976e+53*cos(theta)**62 - 5.4653251112555e+53*cos(theta)**60 + 1.56026216885843e+54*cos(theta)**58 - 3.3713900197686e+54*cos(theta)**56 + 5.73061879739916e+54*cos(theta)**54 - 7.86243096747671e+54*cos(theta)**52 + 8.8652920602671e+54*cos(theta)**50 - 8.32182588032736e+54*cos(theta)**48 + 6.56434936574074e+54*cos(theta)**46 - 4.38046524406297e+54*cos(theta)**44 + 2.48436458086545e+54*cos(theta)**42 - 1.20103195065983e+54*cos(theta)**40 + 4.95663979637389e+53*cos(theta)**38 - 1.74662545205556e+53*cos(theta)**36 + 5.24987612020517e+52*cos(theta)**34 - 1.34299156563388e+52*cos(theta)**32 + 2.91392745649346e+51*cos(theta)**30 - 5.33708818347223e+50*cos(theta)**28 + 8.20089159899391e+49*cos(theta)**26 - 1.04891372281504e+49*cos(theta)**24 + 1.10580667493106e+48*cos(theta)**22 - 9.49243188067911e+46*cos(theta)**20 + 6.53464513525011e+45*cos(theta)**18 - 3.53911754227705e+44*cos(theta)**16 + 1.47156654564534e+43*cos(theta)**14 - 4.55020576465261e+41*cos(theta)**12 + 1.00238177725992e+40*cos(theta)**10 - 1.48135238018708e+38*cos(theta)**8 + 1.34232578139929e+36*cos(theta)**6 - 6.43081658287747e+33*cos(theta)**4 + 1.21795768615104e+31*cos(theta)**2 - 3.80492872899418e+27)*cos(15*phi)

#@torch.jit.script
def Yl81_m16(theta, phi):
    return 1.49141258266054e-30*(1.0 - cos(theta)**2)**8*(1.06371304943194e+53*cos(theta)**65 - 1.37423797690586e+54*cos(theta)**63 + 8.43989549967653e+54*cos(theta)**61 - 3.2791950667533e+55*cos(theta)**59 + 9.04952057937887e+55*cos(theta)**57 - 1.88797841107042e+56*cos(theta)**55 + 3.09453415059555e+56*cos(theta)**53 - 4.08846410308789e+56*cos(theta)**51 + 4.43264603013355e+56*cos(theta)**49 - 3.99447642255713e+56*cos(theta)**47 + 3.01960070824074e+56*cos(theta)**45 - 1.92740470738771e+56*cos(theta)**43 + 1.04343312396349e+56*cos(theta)**41 - 4.80412780263931e+55*cos(theta)**39 + 1.88352312262208e+55*cos(theta)**37 - 6.28785162740002e+54*cos(theta)**35 + 1.78495788086976e+54*cos(theta)**33 - 4.29757301002842e+53*cos(theta)**31 + 8.74178236948038e+52*cos(theta)**29 - 1.49438469137222e+52*cos(theta)**27 + 2.13223181573842e+51*cos(theta)**25 - 2.5173929347561e+50*cos(theta)**23 + 2.43277468484833e+49*cos(theta)**21 - 1.89848637613582e+48*cos(theta)**19 + 1.17623612434502e+47*cos(theta)**17 - 5.66258806764329e+45*cos(theta)**15 + 2.06019316390348e+44*cos(theta)**13 - 5.46024691758313e+42*cos(theta)**11 + 1.00238177725992e+41*cos(theta)**9 - 1.18508190414966e+39*cos(theta)**7 + 8.05395468839575e+36*cos(theta)**5 - 2.57232663315099e+34*cos(theta)**3 + 2.43591537230207e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl81_m17(theta, phi):
    return 1.86865052245405e-32*(1.0 - cos(theta)**2)**8.5*(6.91413482130759e+54*cos(theta)**64 - 8.65769925450689e+55*cos(theta)**62 + 5.14833625480268e+56*cos(theta)**60 - 1.93472508938445e+57*cos(theta)**58 + 5.15822673024596e+57*cos(theta)**56 - 1.03838812608873e+58*cos(theta)**54 + 1.64010309981564e+58*cos(theta)**52 - 2.08511669257482e+58*cos(theta)**50 + 2.17199655476544e+58*cos(theta)**48 - 1.87740391860185e+58*cos(theta)**46 + 1.35882031870833e+58*cos(theta)**44 - 8.28784024176714e+57*cos(theta)**42 + 4.2780758082503e+57*cos(theta)**40 - 1.87360984302933e+57*cos(theta)**38 + 6.96903555370169e+56*cos(theta)**36 - 2.20074806959001e+56*cos(theta)**34 + 5.8903610068702e+55*cos(theta)**32 - 1.33224763310881e+55*cos(theta)**30 + 2.53511688714931e+54*cos(theta)**28 - 4.03483866670501e+53*cos(theta)**26 + 5.33057953934604e+52*cos(theta)**24 - 5.79000374993903e+51*cos(theta)**22 + 5.1088268381815e+50*cos(theta)**20 - 3.60712411465806e+49*cos(theta)**18 + 1.99960141138653e+48*cos(theta)**16 - 8.49388210146493e+46*cos(theta)**14 + 2.67825111307453e+45*cos(theta)**12 - 6.00627160934145e+43*cos(theta)**10 + 9.02143599533929e+41*cos(theta)**8 - 8.29557332904762e+39*cos(theta)**6 + 4.02697734419787e+37*cos(theta)**4 - 7.71697989945297e+34*cos(theta)**2 + 2.43591537230207e+31)*cos(17*phi)

#@torch.jit.script
def Yl81_m18(theta, phi):
    return 2.34758054821275e-34*(1.0 - cos(theta)**2)**9*(4.42504628563686e+56*cos(theta)**63 - 5.36777353779427e+57*cos(theta)**61 + 3.08900175288161e+58*cos(theta)**59 - 1.12214055184298e+59*cos(theta)**57 + 2.88860696893774e+59*cos(theta)**55 - 5.60729588087913e+59*cos(theta)**53 + 8.52853611904133e+59*cos(theta)**51 - 1.04255834628741e+60*cos(theta)**49 + 1.04255834628741e+60*cos(theta)**47 - 8.63605802556852e+59*cos(theta)**45 + 5.97880940231667e+59*cos(theta)**43 - 3.4808929015422e+59*cos(theta)**41 + 1.71123032330012e+59*cos(theta)**39 - 7.11971740351145e+58*cos(theta)**37 + 2.50885279933261e+58*cos(theta)**35 - 7.48254343660602e+57*cos(theta)**33 + 1.88491552219846e+57*cos(theta)**31 - 3.99674289932643e+56*cos(theta)**29 + 7.09832728401807e+55*cos(theta)**27 - 1.0490580533433e+55*cos(theta)**25 + 1.27933908944305e+54*cos(theta)**23 - 1.27380082498659e+53*cos(theta)**21 + 1.0217653676363e+52*cos(theta)**19 - 6.49282340638451e+50*cos(theta)**17 + 3.19936225821846e+49*cos(theta)**15 - 1.18914349420509e+48*cos(theta)**13 + 3.21390133568943e+46*cos(theta)**11 - 6.00627160934145e+44*cos(theta)**9 + 7.21714879627143e+42*cos(theta)**7 - 4.97734399742857e+40*cos(theta)**5 + 1.61079093767915e+38*cos(theta)**3 - 1.54339597989059e+35*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl81_m19(theta, phi):
    return 2.95767348250648e-36*(1.0 - cos(theta)**2)**9.5*(2.78777915995122e+58*cos(theta)**62 - 3.27434185805451e+59*cos(theta)**60 + 1.82251103420015e+60*cos(theta)**58 - 6.39620114550499e+60*cos(theta)**56 + 1.58873383291575e+61*cos(theta)**54 - 2.97186681686594e+61*cos(theta)**52 + 4.34955342071108e+61*cos(theta)**50 - 5.10853589680831e+61*cos(theta)**48 + 4.90002422755083e+61*cos(theta)**46 - 3.88622611150583e+61*cos(theta)**44 + 2.57088804299617e+61*cos(theta)**42 - 1.4271660896323e+61*cos(theta)**40 + 6.67379826087047e+60*cos(theta)**38 - 2.63429543929924e+60*cos(theta)**36 + 8.78098479766413e+59*cos(theta)**34 - 2.46923933407999e+59*cos(theta)**32 + 5.84323811881524e+58*cos(theta)**30 - 1.15905544080466e+58*cos(theta)**28 + 1.91654836668488e+57*cos(theta)**26 - 2.62264513335825e+56*cos(theta)**24 + 2.94247990571902e+55*cos(theta)**22 - 2.67498173247183e+54*cos(theta)**20 + 1.94135419850897e+53*cos(theta)**18 - 1.10377997908537e+52*cos(theta)**16 + 4.79904338732768e+50*cos(theta)**14 - 1.54588654246662e+49*cos(theta)**12 + 3.53529146925838e+47*cos(theta)**10 - 5.4056444484073e+45*cos(theta)**8 + 5.05200415739e+43*cos(theta)**6 - 2.48867199871429e+41*cos(theta)**4 + 4.83237281303745e+38*cos(theta)**2 - 1.54339597989059e+35)*cos(19*phi)

#@torch.jit.script
def Yl81_m20(theta, phi):
    return 3.73760752933104e-38*(1.0 - cos(theta)**2)**10*(1.72842307916976e+60*cos(theta)**61 - 1.9646051148327e+61*cos(theta)**59 + 1.05705639983609e+62*cos(theta)**57 - 3.58187264148279e+62*cos(theta)**55 + 8.57916269774508e+62*cos(theta)**53 - 1.54537074477029e+63*cos(theta)**51 + 2.17477671035554e+63*cos(theta)**49 - 2.45209723046799e+63*cos(theta)**47 + 2.25401114467338e+63*cos(theta)**45 - 1.70993948906257e+63*cos(theta)**43 + 1.07977297805839e+63*cos(theta)**41 - 5.7086643585292e+62*cos(theta)**39 + 2.53604333913078e+62*cos(theta)**37 - 9.48346358147726e+61*cos(theta)**35 + 2.9855348312058e+61*cos(theta)**33 - 7.90156586905596e+60*cos(theta)**31 + 1.75297143564457e+60*cos(theta)**29 - 3.24535523425306e+59*cos(theta)**27 + 4.98302575338068e+58*cos(theta)**25 - 6.29434832005981e+57*cos(theta)**23 + 6.47345579258184e+56*cos(theta)**21 - 5.34996346494367e+55*cos(theta)**19 + 3.49443755731615e+54*cos(theta)**17 - 1.76604796653659e+53*cos(theta)**15 + 6.71866074225876e+51*cos(theta)**13 - 1.85506385095994e+50*cos(theta)**11 + 3.53529146925837e+48*cos(theta)**9 - 4.32451555872584e+46*cos(theta)**7 + 3.031202494434e+44*cos(theta)**5 - 9.95468799485715e+41*cos(theta)**3 + 9.6647456260749e+38*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl81_m21(theta, phi):
    return 4.73836697333064e-40*(1.0 - cos(theta)**2)**10.5*(1.05433807829355e+62*cos(theta)**60 - 1.1591170177513e+63*cos(theta)**58 + 6.0252214790657e+63*cos(theta)**56 - 1.97002995281554e+64*cos(theta)**54 + 4.54695622980489e+64*cos(theta)**52 - 7.88139079832848e+64*cos(theta)**50 + 1.06564058807421e+65*cos(theta)**48 - 1.15248569831996e+65*cos(theta)**46 + 1.01430501510302e+65*cos(theta)**44 - 7.35273980296904e+64*cos(theta)**42 + 4.4270692100394e+64*cos(theta)**40 - 2.22637909982639e+64*cos(theta)**38 + 9.38336035478389e+63*cos(theta)**36 - 3.31921225351704e+63*cos(theta)**34 + 9.85226494297915e+62*cos(theta)**32 - 2.44948541940735e+62*cos(theta)**30 + 5.08361716336926e+61*cos(theta)**28 - 8.76245913248326e+60*cos(theta)**26 + 1.24575643834517e+60*cos(theta)**24 - 1.44770011361376e+59*cos(theta)**22 + 1.35942571644219e+58*cos(theta)**20 - 1.0164930583393e+57*cos(theta)**18 + 5.94054384743745e+55*cos(theta)**16 - 2.64907194980488e+54*cos(theta)**14 + 8.73425896493638e+52*cos(theta)**12 - 2.04057023605593e+51*cos(theta)**10 + 3.18176232233254e+49*cos(theta)**8 - 3.02716089110809e+47*cos(theta)**6 + 1.515601247217e+45*cos(theta)**4 - 2.98640639845714e+42*cos(theta)**2 + 9.6647456260749e+38)*cos(21*phi)

#@torch.jit.script
def Yl81_m22(theta, phi):
    return 6.02746163894733e-42*(1.0 - cos(theta)**2)**11*(6.32602846976131e+63*cos(theta)**59 - 6.72287870295751e+64*cos(theta)**57 + 3.37412402827679e+65*cos(theta)**55 - 1.06381617452039e+66*cos(theta)**53 + 2.36441723949854e+66*cos(theta)**51 - 3.94069539916424e+66*cos(theta)**49 + 5.11507482275623e+66*cos(theta)**47 - 5.3014342122718e+66*cos(theta)**45 + 4.4629420664533e+66*cos(theta)**43 - 3.08815071724699e+66*cos(theta)**41 + 1.77082768401576e+66*cos(theta)**39 - 8.46024057934028e+65*cos(theta)**37 + 3.3780097277222e+65*cos(theta)**35 - 1.12853216619579e+65*cos(theta)**33 + 3.15272478175333e+64*cos(theta)**31 - 7.34845625822204e+63*cos(theta)**29 + 1.42341280574339e+63*cos(theta)**27 - 2.27823937444565e+62*cos(theta)**25 + 2.98981545202841e+61*cos(theta)**23 - 3.18494024995026e+60*cos(theta)**21 + 2.71885143288437e+59*cos(theta)**19 - 1.82968750501073e+58*cos(theta)**17 + 9.50487015589992e+56*cos(theta)**15 - 3.70870072972683e+55*cos(theta)**13 + 1.04811107579237e+54*cos(theta)**11 - 2.04057023605593e+52*cos(theta)**9 + 2.54540985786603e+50*cos(theta)**7 - 1.81629653466485e+48*cos(theta)**5 + 6.062404988868e+45*cos(theta)**3 - 5.97281279691429e+42*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl81_m23(theta, phi):
    return 7.69470154665417e-44*(1.0 - cos(theta)**2)**11.5*(3.73235679715917e+65*cos(theta)**58 - 3.83204086068578e+66*cos(theta)**56 + 1.85576821555223e+67*cos(theta)**54 - 5.63822572495806e+67*cos(theta)**52 + 1.20585279214426e+68*cos(theta)**50 - 1.93094074559048e+68*cos(theta)**48 + 2.40408516669543e+68*cos(theta)**46 - 2.38564539552231e+68*cos(theta)**44 + 1.91906508857492e+68*cos(theta)**42 - 1.26614179407127e+68*cos(theta)**40 + 6.90622796766146e+67*cos(theta)**38 - 3.1302890143559e+67*cos(theta)**36 + 1.18230340470277e+67*cos(theta)**34 - 3.72415614844612e+66*cos(theta)**32 + 9.77344682343532e+65*cos(theta)**30 - 2.13105231488439e+65*cos(theta)**28 + 3.84321457550716e+64*cos(theta)**26 - 5.69559843611412e+63*cos(theta)**24 + 6.87657553966534e+62*cos(theta)**22 - 6.68837452489555e+61*cos(theta)**20 + 5.1658177224803e+60*cos(theta)**18 - 3.11046875851825e+59*cos(theta)**16 + 1.42573052338499e+58*cos(theta)**14 - 4.82131094864488e+56*cos(theta)**12 + 1.1529221833716e+55*cos(theta)**10 - 1.83651321245034e+53*cos(theta)**8 + 1.78178690050622e+51*cos(theta)**6 - 9.08148267332427e+48*cos(theta)**4 + 1.8187214966604e+46*cos(theta)**2 - 5.97281279691429e+42)*cos(23*phi)

#@torch.jit.script
def Yl81_m24(theta, phi):
    return 9.86014117846434e-46*(1.0 - cos(theta)**2)**12*(2.16476694235232e+67*cos(theta)**57 - 2.14594288198404e+68*cos(theta)**55 + 1.00211483639821e+69*cos(theta)**53 - 2.93187737697819e+69*cos(theta)**51 + 6.02926396072128e+69*cos(theta)**49 - 9.26851557883429e+69*cos(theta)**47 + 1.1058791766799e+70*cos(theta)**45 - 1.04968397402982e+70*cos(theta)**43 + 8.06007337201466e+69*cos(theta)**41 - 5.06456717628507e+69*cos(theta)**39 + 2.62436662771136e+69*cos(theta)**37 - 1.12690404516813e+69*cos(theta)**35 + 4.01983157598942e+68*cos(theta)**33 - 1.19172996750276e+68*cos(theta)**31 + 2.93203404703059e+67*cos(theta)**29 - 5.9669464816763e+66*cos(theta)**27 + 9.99235789631861e+65*cos(theta)**25 - 1.36694362466739e+65*cos(theta)**23 + 1.51284661872637e+64*cos(theta)**21 - 1.33767490497911e+63*cos(theta)**19 + 9.29847190046455e+61*cos(theta)**17 - 4.9767500136292e+60*cos(theta)**15 + 1.99602273273898e+59*cos(theta)**13 - 5.78557313837386e+57*cos(theta)**11 + 1.1529221833716e+56*cos(theta)**9 - 1.46921056996027e+54*cos(theta)**7 + 1.06907214030373e+52*cos(theta)**5 - 3.63259306932971e+49*cos(theta)**3 + 3.6374429933208e+46*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl81_m25(theta, phi):
    return 1.26850672151801e-47*(1.0 - cos(theta)**2)**12.5*(1.23391715714082e+69*cos(theta)**56 - 1.18026858509122e+70*cos(theta)**54 + 5.3112086329105e+70*cos(theta)**52 - 1.49525746225888e+71*cos(theta)**50 + 2.95433934075343e+71*cos(theta)**48 - 4.35620232205212e+71*cos(theta)**46 + 4.97645629505954e+71*cos(theta)**44 - 4.51364108832821e+71*cos(theta)**42 + 3.30463008252601e+71*cos(theta)**40 - 1.97518119875118e+71*cos(theta)**38 + 9.71015652253201e+70*cos(theta)**36 - 3.94416415808844e+70*cos(theta)**34 + 1.32654442007651e+70*cos(theta)**32 - 3.69436289925855e+69*cos(theta)**30 + 8.50289873638873e+68*cos(theta)**28 - 1.6110755500526e+68*cos(theta)**26 + 2.49808947407965e+67*cos(theta)**24 - 3.14397033673499e+66*cos(theta)**22 + 3.17697789932539e+65*cos(theta)**20 - 2.54158231946031e+64*cos(theta)**18 + 1.58074022307897e+63*cos(theta)**16 - 7.46512502044379e+61*cos(theta)**14 + 2.59482955256068e+60*cos(theta)**12 - 6.36413045221125e+58*cos(theta)**10 + 1.03762996503444e+57*cos(theta)**8 - 1.02844739897219e+55*cos(theta)**6 + 5.34536070151866e+52*cos(theta)**4 - 1.08977792079891e+50*cos(theta)**2 + 3.6374429933208e+46)*cos(25*phi)

#@torch.jit.script
def Yl81_m26(theta, phi):
    return 1.63872798539216e-49*(1.0 - cos(theta)**2)**13*(6.90993607998861e+70*cos(theta)**55 - 6.3734503594926e+71*cos(theta)**53 + 2.76182848911346e+72*cos(theta)**51 - 7.47628731129439e+72*cos(theta)**49 + 1.41808288356165e+73*cos(theta)**47 - 2.00385306814397e+73*cos(theta)**45 + 2.1896407698262e+73*cos(theta)**43 - 1.89572925709785e+73*cos(theta)**41 + 1.3218520330104e+73*cos(theta)**39 - 7.50568855525448e+72*cos(theta)**37 + 3.49565634811153e+72*cos(theta)**35 - 1.34101581375007e+72*cos(theta)**33 + 4.24494214424482e+71*cos(theta)**31 - 1.10830886977756e+71*cos(theta)**29 + 2.38081164618884e+70*cos(theta)**27 - 4.18879643013676e+69*cos(theta)**25 + 5.99541473779117e+68*cos(theta)**23 - 6.91673474081699e+67*cos(theta)**21 + 6.35395579865077e+66*cos(theta)**19 - 4.57484817502856e+65*cos(theta)**17 + 2.52918435692636e+64*cos(theta)**15 - 1.04511750286213e+63*cos(theta)**13 + 3.11379546307281e+61*cos(theta)**11 - 6.36413045221125e+59*cos(theta)**9 + 8.30103972027554e+57*cos(theta)**7 - 6.17068439383314e+55*cos(theta)**5 + 2.13814428060747e+53*cos(theta)**3 - 2.17955584159782e+50*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl81_m27(theta, phi):
    return 2.12624667732623e-51*(1.0 - cos(theta)**2)**13.5*(3.80046484399373e+72*cos(theta)**54 - 3.37792869053108e+73*cos(theta)**52 + 1.40853252944786e+74*cos(theta)**50 - 3.66338078253425e+74*cos(theta)**48 + 6.66498955273974e+74*cos(theta)**46 - 9.01733880664788e+74*cos(theta)**44 + 9.41545531025264e+74*cos(theta)**42 - 7.77248995410117e+74*cos(theta)**40 + 5.15522292874057e+74*cos(theta)**38 - 2.77710476544416e+74*cos(theta)**36 + 1.22347972183903e+74*cos(theta)**34 - 4.42535218537523e+73*cos(theta)**32 + 1.3159320647159e+73*cos(theta)**30 - 3.21409572235494e+72*cos(theta)**28 + 6.42819144470988e+71*cos(theta)**26 - 1.04719910753419e+71*cos(theta)**24 + 1.37894538969197e+70*cos(theta)**22 - 1.45251429557157e+69*cos(theta)**20 + 1.20725160174365e+68*cos(theta)**18 - 7.77724189754855e+66*cos(theta)**16 + 3.79377653538954e+65*cos(theta)**14 - 1.35865275372077e+64*cos(theta)**12 + 3.42517500938009e+62*cos(theta)**10 - 5.72771740699012e+60*cos(theta)**8 + 5.81072780419288e+58*cos(theta)**6 - 3.08534219691657e+56*cos(theta)**4 + 6.4144328418224e+53*cos(theta)**2 - 2.17955584159782e+50)*cos(27*phi)

#@torch.jit.script
def Yl81_m28(theta, phi):
    return 2.77142748118251e-53*(1.0 - cos(theta)**2)**14*(2.05225101575662e+74*cos(theta)**53 - 1.75652291907616e+75*cos(theta)**51 + 7.04266264723932e+75*cos(theta)**49 - 1.75842277561644e+76*cos(theta)**47 + 3.06589519426028e+76*cos(theta)**45 - 3.96762907492507e+76*cos(theta)**43 + 3.95449123030611e+76*cos(theta)**41 - 3.10899598164047e+76*cos(theta)**39 + 1.95898471292142e+76*cos(theta)**37 - 9.99757715559896e+75*cos(theta)**35 + 4.15983105425271e+75*cos(theta)**33 - 1.41611269932007e+75*cos(theta)**31 + 3.94779619414769e+74*cos(theta)**29 - 8.99946802259383e+73*cos(theta)**27 + 1.67132977562457e+73*cos(theta)**25 - 2.51327785808206e+72*cos(theta)**23 + 3.03367985732233e+71*cos(theta)**21 - 2.90502859114313e+70*cos(theta)**19 + 2.17305288313856e+69*cos(theta)**17 - 1.24435870360777e+68*cos(theta)**15 + 5.31128714954535e+66*cos(theta)**13 - 1.63038330446492e+65*cos(theta)**11 + 3.42517500938009e+63*cos(theta)**9 - 4.5821739255921e+61*cos(theta)**7 + 3.48643668251573e+59*cos(theta)**5 - 1.23413687876663e+57*cos(theta)**3 + 1.28288656836448e+54*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl81_m29(theta, phi):
    return 3.6296875490925e-55*(1.0 - cos(theta)**2)**14.5*(1.08769303835101e+76*cos(theta)**52 - 8.95826688728841e+76*cos(theta)**50 + 3.45090469714727e+77*cos(theta)**48 - 8.26458704539727e+77*cos(theta)**46 + 1.37965283741713e+78*cos(theta)**44 - 1.70608050221778e+78*cos(theta)**42 + 1.6213414044255e+78*cos(theta)**40 - 1.21250843283978e+78*cos(theta)**38 + 7.24824343780925e+77*cos(theta)**36 - 3.49915200445964e+77*cos(theta)**34 + 1.3727442479034e+77*cos(theta)**32 - 4.38994936789223e+76*cos(theta)**30 + 1.14486089630283e+76*cos(theta)**28 - 2.42985636610033e+75*cos(theta)**26 + 4.17832443906142e+74*cos(theta)**24 - 5.78053907358873e+73*cos(theta)**22 + 6.37072770037689e+72*cos(theta)**20 - 5.51955432317195e+71*cos(theta)**18 + 3.69418990133556e+70*cos(theta)**16 - 1.86653805541165e+69*cos(theta)**14 + 6.90467329440895e+67*cos(theta)**12 - 1.79342163491142e+66*cos(theta)**10 + 3.08265750844208e+64*cos(theta)**8 - 3.20752174791447e+62*cos(theta)**6 + 1.74321834125786e+60*cos(theta)**4 - 3.70241063629989e+57*cos(theta)**2 + 1.28288656836448e+54)*cos(29*phi)

#@torch.jit.script
def Yl81_m30(theta, phi):
    return 4.77755923587731e-57*(1.0 - cos(theta)**2)**15*(5.65600379942523e+77*cos(theta)**51 - 4.47913344364421e+78*cos(theta)**49 + 1.65643425463069e+79*cos(theta)**47 - 3.80171004088275e+79*cos(theta)**45 + 6.07047248463535e+79*cos(theta)**43 - 7.16553810931467e+79*cos(theta)**41 + 6.48536561770202e+79*cos(theta)**39 - 4.60753204479118e+79*cos(theta)**37 + 2.60936763761133e+79*cos(theta)**35 - 1.18971168151628e+79*cos(theta)**33 + 4.39278159329087e+78*cos(theta)**31 - 1.31698481036767e+78*cos(theta)**29 + 3.20561050964792e+77*cos(theta)**27 - 6.31762655186087e+76*cos(theta)**25 + 1.00279786537474e+76*cos(theta)**23 - 1.27171859618952e+75*cos(theta)**21 + 1.27414554007538e+74*cos(theta)**19 - 9.93519778170952e+72*cos(theta)**17 + 5.9107038421369e+71*cos(theta)**15 - 2.61315327757631e+70*cos(theta)**13 + 8.28560795329075e+68*cos(theta)**11 - 1.79342163491142e+67*cos(theta)**9 + 2.46612600675367e+65*cos(theta)**7 - 1.92451304874868e+63*cos(theta)**5 + 6.97287336503145e+60*cos(theta)**3 - 7.40482127259977e+57*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl81_m31(theta, phi):
    return 6.32138120870022e-59*(1.0 - cos(theta)**2)**15.5*(2.88456193770687e+79*cos(theta)**50 - 2.19477538738566e+80*cos(theta)**48 + 7.78524099676423e+80*cos(theta)**46 - 1.71076951839724e+81*cos(theta)**44 + 2.6103031683932e+81*cos(theta)**42 - 2.93787062481901e+81*cos(theta)**40 + 2.52929259090379e+81*cos(theta)**38 - 1.70478685657274e+81*cos(theta)**36 + 9.13278673163965e+80*cos(theta)**34 - 3.92604854900371e+80*cos(theta)**32 + 1.36176229392017e+80*cos(theta)**30 - 3.81925595006624e+79*cos(theta)**28 + 8.65514837604939e+78*cos(theta)**26 - 1.57940663796522e+78*cos(theta)**24 + 2.3064350903619e+77*cos(theta)**22 - 2.67060905199799e+76*cos(theta)**20 + 2.42087652614322e+75*cos(theta)**18 - 1.68898362289062e+74*cos(theta)**16 + 8.86605576320534e+72*cos(theta)**14 - 3.39709926084921e+71*cos(theta)**12 + 9.11416874861982e+69*cos(theta)**10 - 1.61407947142028e+68*cos(theta)**8 + 1.72628820472757e+66*cos(theta)**6 - 9.62256524374341e+63*cos(theta)**4 + 2.09186200950944e+61*cos(theta)**2 - 7.40482127259977e+57)*cos(31*phi)

#@torch.jit.script
def Yl81_m32(theta, phi):
    return 8.40984046292634e-61*(1.0 - cos(theta)**2)**16*(1.44228096885343e+81*cos(theta)**49 - 1.05349218594512e+82*cos(theta)**47 + 3.58121085851155e+82*cos(theta)**45 - 7.52738588094784e+82*cos(theta)**43 + 1.09632733072514e+83*cos(theta)**41 - 1.17514824992761e+83*cos(theta)**39 + 9.61131184543439e+82*cos(theta)**37 - 6.13723268366185e+82*cos(theta)**35 + 3.10514748875748e+82*cos(theta)**33 - 1.25633553568119e+82*cos(theta)**31 + 4.08528688176051e+81*cos(theta)**29 - 1.06939166601855e+81*cos(theta)**27 + 2.25033857777284e+80*cos(theta)**25 - 3.79057593111652e+79*cos(theta)**23 + 5.07415719879619e+78*cos(theta)**21 - 5.34121810399599e+77*cos(theta)**19 + 4.35757774705779e+76*cos(theta)**17 - 2.70237379662499e+75*cos(theta)**15 + 1.24124780684875e+74*cos(theta)**13 - 4.07651911301905e+72*cos(theta)**11 + 9.11416874861982e+70*cos(theta)**9 - 1.29126357713622e+69*cos(theta)**7 + 1.03577292283654e+67*cos(theta)**5 - 3.84902609749736e+64*cos(theta)**3 + 4.18372401901887e+61*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl81_m33(theta, phi):
    return 1.12521960789178e-62*(1.0 - cos(theta)**2)**16.5*(7.06717674738183e+82*cos(theta)**48 - 4.95141327394205e+83*cos(theta)**46 + 1.6115448863302e+84*cos(theta)**44 - 3.23677592880757e+84*cos(theta)**42 + 4.49494205597309e+84*cos(theta)**40 - 4.58307817471766e+84*cos(theta)**38 + 3.55618538281073e+84*cos(theta)**36 - 2.14803143928165e+84*cos(theta)**34 + 1.02469867128997e+84*cos(theta)**32 - 3.89464016061168e+83*cos(theta)**30 + 1.18473319571055e+83*cos(theta)**28 - 2.88735749825008e+82*cos(theta)**26 + 5.6258464444321e+81*cos(theta)**24 - 8.718324641568e+80*cos(theta)**22 + 1.0655730117472e+80*cos(theta)**20 - 1.01483143975924e+79*cos(theta)**18 + 7.40788216999825e+77*cos(theta)**16 - 4.05356069493748e+76*cos(theta)**14 + 1.61362214890337e+75*cos(theta)**12 - 4.48417102432095e+73*cos(theta)**10 + 8.20275187375784e+71*cos(theta)**8 - 9.03884503995354e+69*cos(theta)**6 + 5.1788646141827e+67*cos(theta)**4 - 1.15470782924921e+65*cos(theta)**2 + 4.18372401901887e+61)*cos(33*phi)

#@torch.jit.script
def Yl81_m34(theta, phi):
    return 1.51449468182479e-64*(1.0 - cos(theta)**2)**17*(3.39224483874328e+84*cos(theta)**47 - 2.27765010601334e+85*cos(theta)**45 + 7.09079749985286e+85*cos(theta)**43 - 1.35944589009918e+86*cos(theta)**41 + 1.79797682238924e+86*cos(theta)**39 - 1.74156970639271e+86*cos(theta)**37 + 1.28022673781186e+86*cos(theta)**35 - 7.3033068935576e+85*cos(theta)**33 + 3.2790357481279e+85*cos(theta)**31 - 1.1683920481835e+85*cos(theta)**29 + 3.31725294798953e+84*cos(theta)**27 - 7.5071294954502e+83*cos(theta)**25 + 1.3502031466637e+83*cos(theta)**23 - 1.91803142114496e+82*cos(theta)**21 + 2.1311460234944e+81*cos(theta)**19 - 1.82669659156663e+80*cos(theta)**17 + 1.18526114719972e+79*cos(theta)**15 - 5.67498497291248e+77*cos(theta)**13 + 1.93634657868405e+76*cos(theta)**11 - 4.48417102432095e+74*cos(theta)**9 + 6.56220149900627e+72*cos(theta)**7 - 5.42330702397212e+70*cos(theta)**5 + 2.07154584567308e+68*cos(theta)**3 - 2.30941565849842e+65*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl81_m35(theta, phi):
    return 2.05111414227571e-66*(1.0 - cos(theta)**2)**17.5*(1.59435507420934e+86*cos(theta)**46 - 1.024942547706e+87*cos(theta)**44 + 3.04904292493673e+87*cos(theta)**42 - 5.57372814940663e+87*cos(theta)**40 + 7.01210960731802e+87*cos(theta)**38 - 6.44380791365303e+87*cos(theta)**36 + 4.48079358234151e+87*cos(theta)**34 - 2.41009127487401e+87*cos(theta)**32 + 1.01650108191965e+87*cos(theta)**30 - 3.38833693973216e+86*cos(theta)**28 + 8.95658295957173e+85*cos(theta)**26 - 1.87678237386255e+85*cos(theta)**24 + 3.10546723732652e+84*cos(theta)**22 - 4.02786598440441e+83*cos(theta)**20 + 4.04917744463936e+82*cos(theta)**18 - 3.10538420566327e+81*cos(theta)**16 + 1.77789172079958e+80*cos(theta)**14 - 7.37748046478622e+78*cos(theta)**12 + 2.12998123655245e+77*cos(theta)**10 - 4.03575392188886e+75*cos(theta)**8 + 4.59354104930439e+73*cos(theta)**6 - 2.71165351198606e+71*cos(theta)**4 + 6.21463753701924e+68*cos(theta)**2 - 2.30941565849842e+65)*cos(35*phi)

#@torch.jit.script
def Yl81_m36(theta, phi):
    return 2.79587649089978e-68*(1.0 - cos(theta)**2)**18*(7.33403334136297e+87*cos(theta)**45 - 4.50974720990642e+88*cos(theta)**43 + 1.28059802847343e+89*cos(theta)**41 - 2.22949125976265e+89*cos(theta)**39 + 2.66460165078085e+89*cos(theta)**37 - 2.31977084891509e+89*cos(theta)**35 + 1.52346981799611e+89*cos(theta)**33 - 7.71229207959682e+88*cos(theta)**31 + 3.04950324575895e+88*cos(theta)**29 - 9.48734343125006e+87*cos(theta)**27 + 2.32871156948865e+87*cos(theta)**25 - 4.50427769727012e+86*cos(theta)**23 + 6.83202792211834e+85*cos(theta)**21 - 8.05573196880883e+84*cos(theta)**19 + 7.28851940035084e+83*cos(theta)**17 - 4.96861472906123e+82*cos(theta)**15 + 2.48904840911941e+81*cos(theta)**13 - 8.85297655774346e+79*cos(theta)**11 + 2.12998123655245e+78*cos(theta)**9 - 3.22860313751109e+76*cos(theta)**7 + 2.75612462958263e+74*cos(theta)**5 - 1.08466140479442e+72*cos(theta)**3 + 1.24292750740385e+69*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl81_m37(theta, phi):
    return 3.83681378532868e-70*(1.0 - cos(theta)**2)**18.5*(3.30031500361333e+89*cos(theta)**44 - 1.93919130025976e+90*cos(theta)**42 + 5.25045191674105e+90*cos(theta)**40 - 8.69501591307435e+90*cos(theta)**38 + 9.85902610788914e+90*cos(theta)**36 - 8.11919797120282e+90*cos(theta)**34 + 5.02745039938718e+90*cos(theta)**32 - 2.39081054467501e+90*cos(theta)**30 + 8.84355941270095e+89*cos(theta)**28 - 2.56158272643752e+89*cos(theta)**26 + 5.82177892372163e+88*cos(theta)**24 - 1.03598387037213e+88*cos(theta)**22 + 1.43472586364485e+87*cos(theta)**20 - 1.53058907407368e+86*cos(theta)**18 + 1.23904829805964e+85*cos(theta)**16 - 7.45292209359184e+83*cos(theta)**14 + 3.23576293185524e+82*cos(theta)**12 - 9.73827421351781e+80*cos(theta)**10 + 1.91698311289721e+79*cos(theta)**8 - 2.26002219625776e+77*cos(theta)**6 + 1.37806231479132e+75*cos(theta)**4 - 3.25398421438327e+72*cos(theta)**2 + 1.24292750740385e+69)*cos(37*phi)

#@torch.jit.script
def Yl81_m38(theta, phi):
    return 5.30238066213549e-72*(1.0 - cos(theta)**2)**19*(1.45213860158987e+91*cos(theta)**43 - 8.14460346109099e+91*cos(theta)**41 + 2.10018076669642e+92*cos(theta)**39 - 3.30410604696825e+92*cos(theta)**37 + 3.54924939884009e+92*cos(theta)**35 - 2.76052731020896e+92*cos(theta)**33 + 1.6087841278039e+92*cos(theta)**31 - 7.17243163402505e+91*cos(theta)**29 + 2.47619663555627e+91*cos(theta)**27 - 6.66011508873754e+90*cos(theta)**25 + 1.39722694169319e+90*cos(theta)**23 - 2.27916451481868e+89*cos(theta)**21 + 2.8694517272897e+88*cos(theta)**19 - 2.75506033333262e+87*cos(theta)**17 + 1.98247727689543e+86*cos(theta)**15 - 1.04340909310286e+85*cos(theta)**13 + 3.88291551822628e+83*cos(theta)**11 - 9.73827421351781e+81*cos(theta)**9 + 1.53358649031777e+80*cos(theta)**7 - 1.35601331775466e+78*cos(theta)**5 + 5.51224925916527e+75*cos(theta)**3 - 6.50796842876655e+72*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl81_m39(theta, phi):
    return 7.38152427040842e-74*(1.0 - cos(theta)**2)**19.5*(6.24419598683643e+92*cos(theta)**42 - 3.33928741904731e+93*cos(theta)**40 + 8.19070499011604e+93*cos(theta)**38 - 1.22251923737825e+94*cos(theta)**36 + 1.24223728959403e+94*cos(theta)**34 - 9.10974012368957e+93*cos(theta)**32 + 4.98723079619208e+93*cos(theta)**30 - 2.08000517386726e+93*cos(theta)**28 + 6.68573091600192e+92*cos(theta)**26 - 1.66502877218439e+92*cos(theta)**24 + 3.21362196589434e+91*cos(theta)**22 - 4.78624548111923e+90*cos(theta)**20 + 5.45195828185044e+89*cos(theta)**18 - 4.68360256666545e+88*cos(theta)**16 + 2.97371591534314e+87*cos(theta)**14 - 1.35643182103372e+86*cos(theta)**12 + 4.27120707004891e+84*cos(theta)**10 - 8.76444679216603e+82*cos(theta)**8 + 1.07351054322244e+81*cos(theta)**6 - 6.78006658877328e+78*cos(theta)**4 + 1.65367477774958e+76*cos(theta)**2 - 6.50796842876655e+72)*cos(39*phi)

#@torch.jit.script
def Yl81_m40(theta, phi):
    return 1.03544902068228e-75*(1.0 - cos(theta)**2)**20*(2.6225623144713e+94*cos(theta)**41 - 1.33571496761892e+95*cos(theta)**39 + 3.11246789624409e+95*cos(theta)**37 - 4.40106925456171e+95*cos(theta)**35 + 4.22360678461971e+95*cos(theta)**33 - 2.91511683958066e+95*cos(theta)**31 + 1.49616923885762e+95*cos(theta)**29 - 5.82401448682834e+94*cos(theta)**27 + 1.7382900381605e+94*cos(theta)**25 - 3.99606905324253e+93*cos(theta)**23 + 7.06996832496754e+92*cos(theta)**21 - 9.57249096223845e+91*cos(theta)**19 + 9.81352490733079e+90*cos(theta)**17 - 7.49376410666472e+89*cos(theta)**15 + 4.1632022814804e+88*cos(theta)**13 - 1.62771818524046e+87*cos(theta)**11 + 4.27120707004891e+85*cos(theta)**9 - 7.01155743373282e+83*cos(theta)**7 + 6.44106325933462e+81*cos(theta)**5 - 2.71202663550931e+79*cos(theta)**3 + 3.30734955549916e+76*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl81_m41(theta, phi):
    return 1.46405326681666e-77*(1.0 - cos(theta)**2)**20.5*(1.07525054893323e+96*cos(theta)**40 - 5.2092883737138e+96*cos(theta)**38 + 1.15161312161031e+97*cos(theta)**36 - 1.5403742390966e+97*cos(theta)**34 + 1.3937902389245e+97*cos(theta)**32 - 9.03686220270005e+96*cos(theta)**30 + 4.33889079268711e+96*cos(theta)**28 - 1.57248391144365e+96*cos(theta)**26 + 4.34572509540125e+95*cos(theta)**24 - 9.19095882245781e+94*cos(theta)**22 + 1.48469334824318e+94*cos(theta)**20 - 1.81877328282531e+93*cos(theta)**18 + 1.66829923424623e+92*cos(theta)**16 - 1.12406461599971e+91*cos(theta)**14 + 5.41216296592452e+89*cos(theta)**12 - 1.7904900037645e+88*cos(theta)**10 + 3.84408636304402e+86*cos(theta)**8 - 4.90809020361298e+84*cos(theta)**6 + 3.22053162966731e+82*cos(theta)**4 - 8.13607990652794e+79*cos(theta)**2 + 3.30734955549916e+76)*cos(41*phi)

#@torch.jit.script
def Yl81_m42(theta, phi):
    return 2.08724931218398e-79*(1.0 - cos(theta)**2)**21*(4.30100219573293e+97*cos(theta)**39 - 1.97952958201124e+98*cos(theta)**37 + 4.14580723779713e+98*cos(theta)**35 - 5.23727241292844e+98*cos(theta)**33 + 4.46012876455841e+98*cos(theta)**31 - 2.71105866081002e+98*cos(theta)**29 + 1.21488942195239e+98*cos(theta)**27 - 4.08845816975349e+97*cos(theta)**25 + 1.0429740228963e+97*cos(theta)**23 - 2.02201094094072e+96*cos(theta)**21 + 2.96938669648637e+95*cos(theta)**19 - 3.27379190908555e+94*cos(theta)**17 + 2.66927877479397e+93*cos(theta)**15 - 1.57369046239959e+92*cos(theta)**13 + 6.49459555910943e+90*cos(theta)**11 - 1.7904900037645e+89*cos(theta)**9 + 3.07526909043522e+87*cos(theta)**7 - 2.94485412216779e+85*cos(theta)**5 + 1.28821265186692e+83*cos(theta)**3 - 1.62721598130559e+80*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl81_m43(theta, phi):
    return 3.0014504665664e-81*(1.0 - cos(theta)**2)**21.5*(1.67739085633584e+99*cos(theta)**38 - 7.3242594534416e+99*cos(theta)**36 + 1.451032533229e+100*cos(theta)**34 - 1.72829989626638e+100*cos(theta)**32 + 1.38263991701311e+100*cos(theta)**30 - 7.86207011634904e+99*cos(theta)**28 + 3.28020143927146e+99*cos(theta)**26 - 1.02211454243837e+99*cos(theta)**24 + 2.39884025266149e+98*cos(theta)**22 - 4.24622297597551e+97*cos(theta)**20 + 5.6418347233241e+96*cos(theta)**18 - 5.56544624544544e+95*cos(theta)**16 + 4.00391816219096e+94*cos(theta)**14 - 2.04579760111947e+93*cos(theta)**12 + 7.14405511502037e+91*cos(theta)**10 - 1.61144100338805e+90*cos(theta)**8 + 2.15268836330465e+88*cos(theta)**6 - 1.47242706108389e+86*cos(theta)**4 + 3.86463795560077e+83*cos(theta)**2 - 1.62721598130559e+80)*cos(43*phi)

#@torch.jit.script
def Yl81_m44(theta, phi):
    return 4.35496205875107e-83*(1.0 - cos(theta)**2)**22*(6.37408525407621e+100*cos(theta)**37 - 2.63673340323898e+101*cos(theta)**35 + 4.93351061297859e+101*cos(theta)**33 - 5.53055966805243e+101*cos(theta)**31 + 4.14791975103932e+101*cos(theta)**29 - 2.20137963257773e+101*cos(theta)**27 + 8.52852374210578e+100*cos(theta)**25 - 2.4530749018521e+100*cos(theta)**23 + 5.27744855585527e+99*cos(theta)**21 - 8.49244595195101e+98*cos(theta)**19 + 1.01553025019834e+98*cos(theta)**17 - 8.9047139927127e+96*cos(theta)**15 + 5.60548542706735e+95*cos(theta)**13 - 2.45495712134336e+94*cos(theta)**11 + 7.14405511502037e+92*cos(theta)**9 - 1.28915280271044e+91*cos(theta)**7 + 1.29161301798279e+89*cos(theta)**5 - 5.88970824433557e+86*cos(theta)**3 + 7.72927591120154e+83*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl81_m45(theta, phi):
    return 6.37820158470133e-85*(1.0 - cos(theta)**2)**22.5*(2.3584115440082e+102*cos(theta)**36 - 9.22856691133642e+102*cos(theta)**34 + 1.62805850228293e+103*cos(theta)**32 - 1.71447349709625e+103*cos(theta)**30 + 1.2028967278014e+103*cos(theta)**28 - 5.94372500795988e+102*cos(theta)**26 + 2.13213093552645e+102*cos(theta)**24 - 5.64207227425982e+101*cos(theta)**22 + 1.10826419672961e+101*cos(theta)**20 - 1.61356473087069e+100*cos(theta)**18 + 1.72640142533717e+99*cos(theta)**16 - 1.3357070989069e+98*cos(theta)**14 + 7.28713105518755e+96*cos(theta)**12 - 2.7004528334777e+95*cos(theta)**10 + 6.42964960351833e+93*cos(theta)**8 - 9.0240696189731e+91*cos(theta)**6 + 6.45806508991396e+89*cos(theta)**4 - 1.76691247330067e+87*cos(theta)**2 + 7.72927591120154e+83)*cos(45*phi)

#@torch.jit.script
def Yl81_m46(theta, phi):
    return 9.43289782425483e-87*(1.0 - cos(theta)**2)**23*(8.49028155842951e+103*cos(theta)**35 - 3.13771274985438e+104*cos(theta)**33 + 5.20978720730539e+104*cos(theta)**31 - 5.14342049128876e+104*cos(theta)**29 + 3.36811083784393e+104*cos(theta)**27 - 1.54536850206957e+104*cos(theta)**25 + 5.11711424526347e+103*cos(theta)**23 - 1.24125590033716e+103*cos(theta)**21 + 2.21652839345921e+102*cos(theta)**19 - 2.90441651556725e+101*cos(theta)**17 + 2.76224228053948e+100*cos(theta)**15 - 1.86998993846967e+99*cos(theta)**13 + 8.74455726622506e+97*cos(theta)**11 - 2.7004528334777e+96*cos(theta)**9 + 5.14371968281467e+94*cos(theta)**7 - 5.41444177138386e+92*cos(theta)**5 + 2.58322603596558e+90*cos(theta)**3 - 3.53382494660134e+87*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl81_m47(theta, phi):
    return 1.40930866855969e-88*(1.0 - cos(theta)**2)**23.5*(2.97159854545033e+105*cos(theta)**34 - 1.03544520745195e+106*cos(theta)**32 + 1.61503403426467e+106*cos(theta)**30 - 1.49159194247374e+106*cos(theta)**28 + 9.09389926217861e+105*cos(theta)**26 - 3.86342125517392e+105*cos(theta)**24 + 1.1769362764106e+105*cos(theta)**22 - 2.60663739070804e+104*cos(theta)**20 + 4.21140394757251e+103*cos(theta)**18 - 4.93750807646432e+102*cos(theta)**16 + 4.14336342080922e+101*cos(theta)**14 - 2.43098692001057e+100*cos(theta)**12 + 9.61901299284757e+98*cos(theta)**10 - 2.43040755012993e+97*cos(theta)**8 + 3.60060377797027e+95*cos(theta)**6 - 2.70722088569193e+93*cos(theta)**4 + 7.74967810789675e+90*cos(theta)**2 - 3.53382494660134e+87)*cos(47*phi)

#@torch.jit.script
def Yl81_m48(theta, phi):
    return 2.12800091117688e-90*(1.0 - cos(theta)**2)**24*(1.01034350545311e+107*cos(theta)**33 - 3.31342466384623e+107*cos(theta)**31 + 4.84510210279401e+107*cos(theta)**29 - 4.17645743892647e+107*cos(theta)**27 + 2.36441380816644e+107*cos(theta)**25 - 9.27221101241741e+106*cos(theta)**23 + 2.58925980810332e+106*cos(theta)**21 - 5.21327478141607e+105*cos(theta)**19 + 7.58052710563051e+104*cos(theta)**17 - 7.90001292234291e+103*cos(theta)**15 + 5.80070878913291e+102*cos(theta)**13 - 2.91718430401268e+101*cos(theta)**11 + 9.61901299284757e+99*cos(theta)**9 - 1.94432604010394e+98*cos(theta)**7 + 2.16036226678216e+96*cos(theta)**5 - 1.08288835427677e+94*cos(theta)**3 + 1.54993562157935e+91*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl81_m49(theta, phi):
    return 3.24895101520936e-92*(1.0 - cos(theta)**2)**24.5*(3.33413356799527e+108*cos(theta)**32 - 1.02716164579233e+109*cos(theta)**30 + 1.40507960981026e+109*cos(theta)**28 - 1.12764350851015e+109*cos(theta)**26 + 5.9110345204161e+108*cos(theta)**24 - 2.132608532856e+108*cos(theta)**22 + 5.43744559701696e+107*cos(theta)**20 - 9.90522208469054e+106*cos(theta)**18 + 1.28868960795719e+106*cos(theta)**16 - 1.18500193835144e+105*cos(theta)**14 + 7.54092142587278e+103*cos(theta)**12 - 3.20890273441395e+102*cos(theta)**10 + 8.65711169356281e+100*cos(theta)**8 - 1.36102822807276e+99*cos(theta)**6 + 1.08018113339108e+97*cos(theta)**4 - 3.24866506283032e+94*cos(theta)**2 + 1.54993562157935e+91)*cos(49*phi)

#@torch.jit.script
def Yl81_m50(theta, phi):
    return 5.01802160120378e-94*(1.0 - cos(theta)**2)**25*(1.06692274175849e+110*cos(theta)**31 - 3.08148493737699e+110*cos(theta)**29 + 3.93422290746874e+110*cos(theta)**27 - 2.93187312212638e+110*cos(theta)**25 + 1.41864828489986e+110*cos(theta)**23 - 4.69173877228321e+109*cos(theta)**21 + 1.08748911940339e+109*cos(theta)**19 - 1.7829399752443e+108*cos(theta)**17 + 2.0619033727315e+107*cos(theta)**15 - 1.65900271369201e+106*cos(theta)**13 + 9.04910571104733e+104*cos(theta)**11 - 3.20890273441395e+103*cos(theta)**9 + 6.92568935485025e+101*cos(theta)**7 - 8.16616936843656e+99*cos(theta)**5 + 4.32072453356432e+97*cos(theta)**3 - 6.49733012566063e+94*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl81_m51(theta, phi):
    return 7.84449000485907e-96*(1.0 - cos(theta)**2)**25.5*(3.3074604994513e+111*cos(theta)**30 - 8.93630631839328e+111*cos(theta)**28 + 1.06224018501656e+112*cos(theta)**26 - 7.32968280531596e+111*cos(theta)**24 + 3.26289105526969e+111*cos(theta)**22 - 9.85265142179474e+110*cos(theta)**20 + 2.06622932686645e+110*cos(theta)**18 - 3.0309979579153e+109*cos(theta)**16 + 3.09285505909725e+108*cos(theta)**14 - 2.15670352779961e+107*cos(theta)**12 + 9.95401628215207e+105*cos(theta)**10 - 2.88801246097255e+104*cos(theta)**8 + 4.84798254839517e+102*cos(theta)**6 - 4.08308468421828e+100*cos(theta)**4 + 1.2962173600693e+98*cos(theta)**2 - 6.49733012566063e+94)*cos(51*phi)

#@torch.jit.script
def Yl81_m52(theta, phi):
    return 1.24187609143365e-97*(1.0 - cos(theta)**2)**26*(9.92238149835392e+112*cos(theta)**29 - 2.50216576915012e+113*cos(theta)**27 + 2.76182448104305e+113*cos(theta)**25 - 1.75912387327583e+113*cos(theta)**23 + 7.17836032159331e+112*cos(theta)**21 - 1.97053028435895e+112*cos(theta)**19 + 3.7192127883596e+111*cos(theta)**17 - 4.84959673266449e+110*cos(theta)**15 + 4.32999708273615e+109*cos(theta)**13 - 2.58804423335954e+108*cos(theta)**11 + 9.95401628215207e+106*cos(theta)**9 - 2.31040996877804e+105*cos(theta)**7 + 2.9087895290371e+103*cos(theta)**5 - 1.63323387368731e+101*cos(theta)**3 + 2.59243472013859e+98*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl81_m53(theta, phi):
    return 1.99217216611943e-99*(1.0 - cos(theta)**2)**26.5*(2.87749063452264e+114*cos(theta)**28 - 6.75584757670532e+114*cos(theta)**26 + 6.90456120260764e+114*cos(theta)**24 - 4.04598490853441e+114*cos(theta)**22 + 1.5074556675346e+114*cos(theta)**20 - 3.744007540282e+113*cos(theta)**18 + 6.32266174021133e+112*cos(theta)**16 - 7.27439509899673e+111*cos(theta)**14 + 5.62899620755699e+110*cos(theta)**12 - 2.84684865669549e+109*cos(theta)**10 + 8.95861465393686e+107*cos(theta)**8 - 1.61728697814463e+106*cos(theta)**6 + 1.45439476451855e+104*cos(theta)**4 - 4.89970162106194e+101*cos(theta)**2 + 2.59243472013859e+98)*cos(53*phi)

#@torch.jit.script
def Yl81_m54(theta, phi):
    return 3.24026827040331e-101*(1.0 - cos(theta)**2)**27*(8.05697377666338e+115*cos(theta)**27 - 1.75652036994338e+116*cos(theta)**25 + 1.65709468862583e+116*cos(theta)**23 - 8.9011667987757e+115*cos(theta)**21 + 3.01491133506919e+115*cos(theta)**19 - 6.7392135725076e+114*cos(theta)**17 + 1.01162587843381e+114*cos(theta)**15 - 1.01841531385954e+113*cos(theta)**13 + 6.75479544906839e+111*cos(theta)**11 - 2.84684865669549e+110*cos(theta)**9 + 7.16689172314949e+108*cos(theta)**7 - 9.70372186886778e+106*cos(theta)**5 + 5.81757905807421e+104*cos(theta)**3 - 9.79940324212388e+101*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl81_m55(theta, phi):
    return 5.34723944420852e-103*(1.0 - cos(theta)**2)**27.5*(2.17538291969911e+117*cos(theta)**26 - 4.39130092485846e+117*cos(theta)**24 + 3.81131778383941e+117*cos(theta)**22 - 1.8692450277429e+117*cos(theta)**20 + 5.72833153663146e+116*cos(theta)**18 - 1.14566630732629e+116*cos(theta)**16 + 1.51743881765072e+115*cos(theta)**14 - 1.32393990801741e+114*cos(theta)**12 + 7.43027499397523e+112*cos(theta)**10 - 2.56216379102594e+111*cos(theta)**8 + 5.01682420620464e+109*cos(theta)**6 - 4.85186093443389e+107*cos(theta)**4 + 1.74527371742226e+105*cos(theta)**2 - 9.79940324212388e+101)*cos(55*phi)

#@torch.jit.script
def Yl81_m56(theta, phi):
    return 8.95947731642572e-105*(1.0 - cos(theta)**2)**28*(5.65599559121769e+118*cos(theta)**25 - 1.05391222196603e+119*cos(theta)**23 + 8.38489912444671e+118*cos(theta)**21 - 3.7384900554858e+118*cos(theta)**19 + 1.03109967659366e+118*cos(theta)**17 - 1.83306609172207e+117*cos(theta)**15 + 2.12441434471101e+116*cos(theta)**13 - 1.58872788962089e+115*cos(theta)**11 + 7.43027499397523e+113*cos(theta)**9 - 2.04973103282075e+112*cos(theta)**7 + 3.01009452372279e+110*cos(theta)**5 - 1.94074437377356e+108*cos(theta)**3 + 3.49054743484453e+105*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl81_m57(theta, phi):
    return 1.52536271555845e-106*(1.0 - cos(theta)**2)**28.5*(1.41399889780442e+120*cos(theta)**24 - 2.42399811052187e+120*cos(theta)**22 + 1.76082881613381e+120*cos(theta)**20 - 7.10313110542301e+119*cos(theta)**18 + 1.75286945020923e+119*cos(theta)**16 - 2.7495991375831e+118*cos(theta)**14 + 2.76173864812431e+117*cos(theta)**12 - 1.74760067858297e+116*cos(theta)**10 + 6.68724749457771e+114*cos(theta)**8 - 1.43481172297453e+113*cos(theta)**6 + 1.50504726186139e+111*cos(theta)**4 - 5.82223312132067e+108*cos(theta)**2 + 3.49054743484453e+105)*cos(57*phi)

#@torch.jit.script
def Yl81_m58(theta, phi):
    return 2.6409495546881e-108*(1.0 - cos(theta)**2)**29*(3.39359735473062e+121*cos(theta)**23 - 5.33279584314811e+121*cos(theta)**21 + 3.52165763226762e+121*cos(theta)**19 - 1.27856359897614e+121*cos(theta)**17 + 2.80459112033476e+120*cos(theta)**15 - 3.84943879261634e+119*cos(theta)**13 + 3.31408637774917e+118*cos(theta)**11 - 1.74760067858297e+117*cos(theta)**9 + 5.34979799566217e+115*cos(theta)**7 - 8.60887033784717e+113*cos(theta)**5 + 6.02018904744557e+111*cos(theta)**3 - 1.16444662426413e+109*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl81_m59(theta, phi):
    return 4.6540620574725e-110*(1.0 - cos(theta)**2)**29.5*(7.80527391588041e+122*cos(theta)**22 - 1.1198871270611e+123*cos(theta)**20 + 6.69114950130848e+122*cos(theta)**18 - 2.17355811825944e+122*cos(theta)**16 + 4.20688668050214e+121*cos(theta)**14 - 5.00427043040124e+120*cos(theta)**12 + 3.64549501552409e+119*cos(theta)**10 - 1.57284061072468e+118*cos(theta)**8 + 3.74485859696352e+116*cos(theta)**6 - 4.30443516892358e+114*cos(theta)**4 + 1.80605671423367e+112*cos(theta)**2 - 1.16444662426413e+109)*cos(59*phi)

#@torch.jit.script
def Yl81_m60(theta, phi):
    return 8.35624708588904e-112*(1.0 - cos(theta)**2)**30*(1.71716026149369e+124*cos(theta)**21 - 2.23977425412221e+124*cos(theta)**19 + 1.20440691023553e+124*cos(theta)**17 - 3.47769298921511e+123*cos(theta)**15 + 5.889641352703e+122*cos(theta)**13 - 6.00512451648149e+121*cos(theta)**11 + 3.64549501552409e+120*cos(theta)**9 - 1.25827248857974e+119*cos(theta)**7 + 2.24691515817811e+117*cos(theta)**5 - 1.72177406756943e+115*cos(theta)**3 + 3.61211342846734e+112*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl81_m61(theta, phi):
    return 1.53023261296433e-113*(1.0 - cos(theta)**2)**30.5*(3.60603654913675e+125*cos(theta)**20 - 4.25557108283219e+125*cos(theta)**18 + 2.04749174740039e+125*cos(theta)**16 - 5.21653948382266e+124*cos(theta)**14 + 7.6565337585139e+123*cos(theta)**12 - 6.60563696812964e+122*cos(theta)**10 + 3.28094551397168e+121*cos(theta)**8 - 8.80790742005819e+119*cos(theta)**6 + 1.12345757908906e+118*cos(theta)**4 - 5.1653222027083e+115*cos(theta)**2 + 3.61211342846734e+112)*cos(61*phi)

#@torch.jit.script
def Yl81_m62(theta, phi):
    return 2.86137275100756e-115*(1.0 - cos(theta)**2)**31*(7.2120730982735e+126*cos(theta)**19 - 7.66002794909794e+126*cos(theta)**17 + 3.27598679584063e+126*cos(theta)**15 - 7.30315527735172e+125*cos(theta)**13 + 9.18784051021668e+124*cos(theta)**11 - 6.60563696812964e+123*cos(theta)**9 + 2.62475641117734e+122*cos(theta)**7 - 5.28474445203492e+120*cos(theta)**5 + 4.49383031635622e+118*cos(theta)**3 - 1.03306444054166e+116*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl81_m63(theta, phi):
    return 5.47036607958023e-117*(1.0 - cos(theta)**2)**31.5*(1.37029388867197e+128*cos(theta)**18 - 1.30220475134665e+128*cos(theta)**16 + 4.91398019376095e+127*cos(theta)**14 - 9.49410186055724e+126*cos(theta)**12 + 1.01066245612384e+126*cos(theta)**10 - 5.94507327131668e+124*cos(theta)**8 + 1.83732948782414e+123*cos(theta)**6 - 2.64237222601746e+121*cos(theta)**4 + 1.34814909490687e+119*cos(theta)**2 - 1.03306444054166e+116)*cos(63*phi)

#@torch.jit.script
def Yl81_m64(theta, phi):
    return 1.0707698566923e-118*(1.0 - cos(theta)**2)**32*(2.46652899960954e+129*cos(theta)**17 - 2.08352760215464e+129*cos(theta)**15 + 6.87957227126532e+128*cos(theta)**13 - 1.13929222326687e+128*cos(theta)**11 + 1.01066245612384e+127*cos(theta)**9 - 4.75605861705334e+125*cos(theta)**7 + 1.10239769269448e+124*cos(theta)**5 - 1.05694889040698e+122*cos(theta)**3 + 2.69629818981373e+119*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl81_m65(theta, phi):
    return 2.14929113925793e-120*(1.0 - cos(theta)**2)**32.5*(4.19309929933622e+130*cos(theta)**16 - 3.12529140323196e+130*cos(theta)**14 + 8.94344395264492e+129*cos(theta)**12 - 1.25322144559356e+129*cos(theta)**10 + 9.09596210511452e+127*cos(theta)**8 - 3.32924103193734e+126*cos(theta)**6 + 5.51198846347242e+124*cos(theta)**4 - 3.17084667122095e+122*cos(theta)**2 + 2.69629818981373e+119)*cos(65*phi)

#@torch.jit.script
def Yl81_m66(theta, phi):
    return 4.43176363506231e-122*(1.0 - cos(theta)**2)**33*(6.70895887893794e+131*cos(theta)**15 - 4.37540796452475e+131*cos(theta)**13 + 1.07321327431739e+131*cos(theta)**11 - 1.25322144559356e+130*cos(theta)**9 + 7.27676968409161e+128*cos(theta)**7 - 1.9975446191624e+127*cos(theta)**5 + 2.20479538538897e+125*cos(theta)**3 - 6.3416933424419e+122*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl81_m67(theta, phi):
    return 9.40589448047078e-124*(1.0 - cos(theta)**2)**33.5*(1.00634383184069e+133*cos(theta)**14 - 5.68803035388217e+132*cos(theta)**12 + 1.18053460174913e+132*cos(theta)**10 - 1.1278993010342e+131*cos(theta)**8 + 5.09373877886413e+129*cos(theta)**6 - 9.98772309581202e+127*cos(theta)**4 + 6.6143861561669e+125*cos(theta)**2 - 6.3416933424419e+122)*cos(67*phi)

#@torch.jit.script
def Yl81_m68(theta, phi):
    return 2.05941063088069e-125*(1.0 - cos(theta)**2)**34*(1.40888136457697e+134*cos(theta)**13 - 6.8256364246586e+133*cos(theta)**11 + 1.18053460174913e+133*cos(theta)**9 - 9.0231944082736e+131*cos(theta)**7 + 3.05624326731848e+130*cos(theta)**5 - 3.99508923832481e+128*cos(theta)**3 + 1.32287723123338e+126*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl81_m69(theta, phi):
    return 4.66364672243888e-127*(1.0 - cos(theta)**2)**34.5*(1.83154577395006e+135*cos(theta)**12 - 7.50820006712446e+134*cos(theta)**10 + 1.06248114157422e+134*cos(theta)**8 - 6.31623608579152e+132*cos(theta)**6 + 1.52812163365924e+131*cos(theta)**4 - 1.19852677149744e+129*cos(theta)**2 + 1.32287723123338e+126)*cos(69*phi)

#@torch.jit.script
def Yl81_m70(theta, phi):
    return 1.0955861865951e-128*(1.0 - cos(theta)**2)**35*(2.19785492874007e+136*cos(theta)**11 - 7.50820006712446e+135*cos(theta)**9 + 8.49984913259373e+134*cos(theta)**7 - 3.78974165147491e+133*cos(theta)**5 + 6.11248653463696e+131*cos(theta)**3 - 2.39705354299488e+129*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl81_m71(theta, phi):
    return 2.67934360072195e-130*(1.0 - cos(theta)**2)**35.5*(2.41764042161408e+137*cos(theta)**10 - 6.75738006041202e+136*cos(theta)**8 + 5.94989439281561e+135*cos(theta)**6 - 1.89487082573746e+134*cos(theta)**4 + 1.83374596039109e+132*cos(theta)**2 - 2.39705354299488e+129)*cos(71*phi)

#@torch.jit.script
def Yl81_m72(theta, phi):
    return 6.84987578281994e-132*(1.0 - cos(theta)**2)**36*(2.41764042161408e+138*cos(theta)**9 - 5.40590404832961e+137*cos(theta)**7 + 3.56993663568937e+136*cos(theta)**5 - 7.57948330294983e+134*cos(theta)**3 + 3.66749192078217e+132*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl81_m73(theta, phi):
    return 1.83992906883921e-133*(1.0 - cos(theta)**2)**36.5*(2.17587637945267e+139*cos(theta)**8 - 3.78413283383073e+138*cos(theta)**6 + 1.78496831784468e+137*cos(theta)**4 - 2.27384499088495e+135*cos(theta)**2 + 3.66749192078217e+132)*cos(73*phi)

#@torch.jit.script
def Yl81_m74(theta, phi):
    return 5.22504744411206e-135*(1.0 - cos(theta)**2)**37*(1.74070110356214e+140*cos(theta)**7 - 2.27047970029844e+139*cos(theta)**5 + 7.13987327137874e+137*cos(theta)**3 - 4.5476899817699e+135*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl81_m75(theta, phi):
    return 1.58117128633869e-136*(1.0 - cos(theta)**2)**37.5*(1.21849077249349e+141*cos(theta)**6 - 1.13523985014922e+140*cos(theta)**4 + 2.14196198141362e+138*cos(theta)**2 - 4.5476899817699e+135)*cos(75*phi)

#@torch.jit.script
def Yl81_m76(theta, phi):
    return 5.15173443547425e-138*(1.0 - cos(theta)**2)**38*(7.31094463496097e+141*cos(theta)**5 - 4.54095940059688e+140*cos(theta)**3 + 4.28392396282724e+138*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl81_m77(theta, phi):
    return 1.83290485688326e-139*(1.0 - cos(theta)**2)**38.5*(3.65547231748049e+142*cos(theta)**4 - 1.36228782017906e+141*cos(theta)**2 + 4.28392396282724e+138)*cos(77*phi)

#@torch.jit.script
def Yl81_m78(theta, phi):
    return 7.26794051610877e-141*(1.0 - cos(theta)**2)**39*(1.46218892699219e+143*cos(theta)**3 - 2.72457564035813e+141*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl81_m79(theta, phi):
    return 3.31734580606543e-142*(1.0 - cos(theta)**2)**39.5*(4.38656678097658e+143*cos(theta)**2 - 2.72457564035813e+141)*cos(79*phi)

#@torch.jit.script
def Yl81_m80(theta, phi):
    return 16.2187563947297*(1.0 - cos(theta)**2)**40*cos(80*phi)*cos(theta)

#@torch.jit.script
def Yl81_m81(theta, phi):
    return 1.27426584768067*(1.0 - cos(theta)**2)**40.5*cos(81*phi)

#@torch.jit.script
def Yl82_m_minus_82(theta, phi):
    return 1.27814490032998*(1.0 - cos(theta)**2)**41*sin(82*phi)

#@torch.jit.script
def Yl82_m_minus_81(theta, phi):
    return 16.3682411805081*(1.0 - cos(theta)**2)**40.5*sin(81*phi)*cos(theta)

#@torch.jit.script
def Yl82_m_minus_80(theta, phi):
    return 2.06665731756785e-144*(1.0 - cos(theta)**2)**40*(7.15010385299183e+145*cos(theta)**2 - 4.38656678097658e+143)*sin(80*phi)

#@torch.jit.script
def Yl82_m_minus_79(theta, phi):
    return 4.55603031110722e-143*(1.0 - cos(theta)**2)**39.5*(2.38336795099728e+145*cos(theta)**3 - 4.38656678097658e+143*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl82_m_minus_78(theta, phi):
    return 1.15619087758245e-141*(1.0 - cos(theta)**2)**39*(5.95841987749319e+144*cos(theta)**4 - 2.19328339048829e+143*cos(theta)**2 + 6.81143910089531e+140)*sin(78*phi)

#@torch.jit.script
def Yl82_m_minus_77(theta, phi):
    return 3.27020163953829e-140*(1.0 - cos(theta)**2)**38.5*(1.19168397549864e+144*cos(theta)**5 - 7.31094463496097e+142*cos(theta)**3 + 6.81143910089531e+140*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl82_m_minus_76(theta, phi):
    return 1.01006359701407e-138*(1.0 - cos(theta)**2)**38*(1.9861399591644e+143*cos(theta)**6 - 1.82773615874024e+142*cos(theta)**4 + 3.40571955044766e+140*cos(theta)**2 - 7.13987327137874e+137)*sin(76*phi)

#@torch.jit.script
def Yl82_m_minus_75(theta, phi):
    return 3.35912590986758e-137*(1.0 - cos(theta)**2)**37.5*(2.83734279880628e+142*cos(theta)**7 - 3.65547231748048e+141*cos(theta)**5 + 1.13523985014922e+140*cos(theta)**3 - 7.13987327137874e+137*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl82_m_minus_74(theta, phi):
    return 1.19047725552401e-135*(1.0 - cos(theta)**2)**37*(3.54667849850785e+141*cos(theta)**8 - 6.09245386246747e+140*cos(theta)**6 + 2.83809962537305e+139*cos(theta)**4 - 3.56993663568937e+137*cos(theta)**2 + 5.68461247721237e+134)*sin(74*phi)

#@torch.jit.script
def Yl82_m_minus_73(theta, phi):
    return 4.46071684673175e-134*(1.0 - cos(theta)**2)**36.5*(3.94075388723095e+140*cos(theta)**9 - 8.70350551781068e+139*cos(theta)**7 + 5.67619925074609e+138*cos(theta)**5 - 1.18997887856312e+137*cos(theta)**3 + 5.68461247721237e+134*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl82_m_minus_72(theta, phi):
    return 1.75618597874515e-132*(1.0 - cos(theta)**2)**36*(3.94075388723095e+139*cos(theta)**10 - 1.08793818972633e+139*cos(theta)**8 + 9.46033208457683e+137*cos(theta)**6 - 2.97494719640781e+136*cos(theta)**4 + 2.84230623860618e+134*cos(theta)**2 - 3.66749192078217e+131)*sin(72*phi)

#@torch.jit.script
def Yl82_m_minus_71(theta, phi):
    return 7.22815086391266e-131*(1.0 - cos(theta)**2)**35.5*(3.58250353384631e+138*cos(theta)**11 - 1.20882021080704e+138*cos(theta)**9 + 1.3514760120824e+137*cos(theta)**7 - 5.94989439281561e+135*cos(theta)**5 + 9.47435412868728e+133*cos(theta)**3 - 3.66749192078217e+131*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl82_m_minus_70(theta, phi):
    return 3.09715932392054e-129*(1.0 - cos(theta)**2)**35*(2.9854196115386e+137*cos(theta)**12 - 1.20882021080704e+137*cos(theta)**10 + 1.689345015103e+136*cos(theta)**8 - 9.91649065469269e+134*cos(theta)**6 + 2.36858853217182e+133*cos(theta)**4 - 1.83374596039109e+131*cos(theta)**2 + 1.9975446191624e+128)*sin(70*phi)

#@torch.jit.script
def Yl82_m_minus_69(theta, phi):
    return 1.37675612417123e-127*(1.0 - cos(theta)**2)**34.5*(2.29647662426046e+136*cos(theta)**13 - 1.09892746437004e+136*cos(theta)**11 + 1.87705001678112e+135*cos(theta)**9 - 1.41664152209896e+134*cos(theta)**7 + 4.73717706434364e+132*cos(theta)**5 - 6.11248653463696e+130*cos(theta)**3 + 1.9975446191624e+128*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl82_m_minus_68(theta, phi):
    return 6.33008451553887e-126*(1.0 - cos(theta)**2)**34*(1.64034044590033e+135*cos(theta)**14 - 9.15772886975029e+134*cos(theta)**12 + 1.87705001678112e+134*cos(theta)**10 - 1.77080190262369e+133*cos(theta)**8 + 7.8952951072394e+131*cos(theta)**6 - 1.52812163365924e+130*cos(theta)**4 + 9.98772309581202e+127*cos(theta)**2 - 9.44912308023843e+124)*sin(68*phi)

#@torch.jit.script
def Yl82_m_minus_67(theta, phi):
    return 3.00262272756995e-124*(1.0 - cos(theta)**2)**33.5*(1.09356029726688e+134*cos(theta)**15 - 7.04440682288484e+133*cos(theta)**13 + 1.70640910616465e+133*cos(theta)**11 - 1.96755766958188e+132*cos(theta)**9 + 1.1278993010342e+131*cos(theta)**7 - 3.05624326731848e+129*cos(theta)**5 + 3.32924103193734e+127*cos(theta)**3 - 9.44912308023843e+124*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl82_m_minus_66(theta, phi):
    return 1.46606725268595e-122*(1.0 - cos(theta)**2)**33*(6.83475185791803e+132*cos(theta)**16 - 5.03171915920346e+132*cos(theta)**14 + 1.42200758847054e+132*cos(theta)**12 - 1.96755766958188e+131*cos(theta)**10 + 1.40987412629275e+130*cos(theta)**8 - 5.09373877886413e+128*cos(theta)**6 + 8.32310257984335e+126*cos(theta)**4 - 4.72456154011921e+124*cos(theta)**2 + 3.96355833902619e+121)*sin(66*phi)

#@torch.jit.script
def Yl82_m_minus_65(theta, phi):
    return 7.35375592777301e-121*(1.0 - cos(theta)**2)**32.5*(4.02044226936355e+131*cos(theta)**17 - 3.35447943946897e+131*cos(theta)**15 + 1.09385199113119e+131*cos(theta)**13 - 1.78868879052898e+130*cos(theta)**11 + 1.56652680699194e+129*cos(theta)**9 - 7.27676968409161e+127*cos(theta)**7 + 1.66462051596867e+126*cos(theta)**5 - 1.5748538467064e+124*cos(theta)**3 + 3.96355833902619e+121*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl82_m_minus_64(theta, phi):
    return 3.7827194403623e-119*(1.0 - cos(theta)**2)**32*(2.2335790385353e+130*cos(theta)**18 - 2.09654964966811e+130*cos(theta)**16 + 7.8132285080799e+129*cos(theta)**14 - 1.49057399210749e+129*cos(theta)**12 + 1.56652680699194e+128*cos(theta)**10 - 9.09596210511452e+126*cos(theta)**8 + 2.77436752661445e+125*cos(theta)**6 - 3.93713461676601e+123*cos(theta)**4 + 1.98177916951309e+121*cos(theta)**2 - 1.49794343878541e+118)*sin(64*phi)

#@torch.jit.script
def Yl82_m_minus_63(theta, phi):
    return 1.99231204120009e-117*(1.0 - cos(theta)**2)**31.5*(1.17556791501858e+129*cos(theta)**19 - 1.23326449980477e+129*cos(theta)**17 + 5.2088190053866e+128*cos(theta)**15 - 1.14659537854422e+128*cos(theta)**13 + 1.42411527908359e+127*cos(theta)**11 - 1.01066245612384e+126*cos(theta)**9 + 3.96338218087779e+124*cos(theta)**7 - 7.87426923353203e+122*cos(theta)**5 + 6.60593056504364e+120*cos(theta)**3 - 1.49794343878541e+118*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl82_m_minus_62(theta, phi):
    return 1.07289286891011e-115*(1.0 - cos(theta)**2)**31*(5.87783957509291e+127*cos(theta)**20 - 6.85146944335983e+127*cos(theta)**18 + 3.25551187836663e+127*cos(theta)**16 - 8.18996698960158e+126*cos(theta)**14 + 1.18676273256966e+126*cos(theta)**12 - 1.01066245612384e+125*cos(theta)**10 + 4.95422772609723e+123*cos(theta)**8 - 1.31237820558867e+122*cos(theta)**6 + 1.65148264126091e+120*cos(theta)**4 - 7.48971719392703e+117*cos(theta)**2 + 5.1653222027083e+114)*sin(62*phi)

#@torch.jit.script
def Yl82_m_minus_61(theta, phi):
    return 5.89993534123067e-114*(1.0 - cos(theta)**2)**30.5*(2.79897122623472e+126*cos(theta)**21 - 3.60603654913675e+126*cos(theta)**19 + 1.91500698727449e+126*cos(theta)**17 - 5.45997799306772e+125*cos(theta)**15 + 9.12894409668965e+124*cos(theta)**13 - 9.18784051021668e+123*cos(theta)**11 + 5.50469747344137e+122*cos(theta)**9 - 1.87482600798382e+121*cos(theta)**7 + 3.30296528252182e+119*cos(theta)**5 - 2.49657239797568e+117*cos(theta)**3 + 5.1653222027083e+114*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl82_m_minus_60(theta, phi):
    return 3.3092273977258e-112*(1.0 - cos(theta)**2)**30*(1.27225964828851e+125*cos(theta)**22 - 1.80301827456838e+125*cos(theta)**20 + 1.06389277070805e+125*cos(theta)**18 - 3.41248624566732e+124*cos(theta)**16 + 6.52067435477832e+123*cos(theta)**14 - 7.6565337585139e+122*cos(theta)**12 + 5.50469747344137e+121*cos(theta)**10 - 2.34353250997977e+120*cos(theta)**8 + 5.50494213753637e+118*cos(theta)**6 - 6.2414309949392e+116*cos(theta)**4 + 2.58266110135415e+114*cos(theta)**2 - 1.64186974021243e+111)*sin(60*phi)

#@torch.jit.script
def Yl82_m_minus_59(theta, phi):
    return 1.89118799111986e-110*(1.0 - cos(theta)**2)**29.5*(5.5315636882109e+123*cos(theta)**23 - 8.58580130746846e+123*cos(theta)**21 + 5.59943563530552e+123*cos(theta)**19 - 2.00734485039254e+123*cos(theta)**17 + 4.34711623651888e+122*cos(theta)**15 - 5.889641352703e+121*cos(theta)**13 + 5.00427043040124e+120*cos(theta)**11 - 2.60392501108863e+119*cos(theta)**9 + 7.86420305362339e+117*cos(theta)**7 - 1.24828619898784e+116*cos(theta)**5 + 8.60887033784717e+113*cos(theta)**3 - 1.64186974021243e+111*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl82_m_minus_58(theta, phi):
    return 1.10014487173673e-108*(1.0 - cos(theta)**2)**29*(2.30481820342121e+122*cos(theta)**24 - 3.90263695794021e+122*cos(theta)**22 + 2.79971781765276e+122*cos(theta)**20 - 1.11519158355141e+122*cos(theta)**18 + 2.7169476478243e+121*cos(theta)**16 - 4.20688668050215e+120*cos(theta)**14 + 4.1702253586677e+119*cos(theta)**12 - 2.60392501108863e+118*cos(theta)**10 + 9.83025381702923e+116*cos(theta)**8 - 2.08047699831307e+115*cos(theta)**6 + 2.15221758446179e+113*cos(theta)**4 - 8.20934870106214e+110*cos(theta)**2 + 4.85186093443389e+107)*sin(58*phi)

#@torch.jit.script
def Yl82_m_minus_57(theta, phi):
    return 6.50854483416237e-107*(1.0 - cos(theta)**2)**28.5*(9.21927281368484e+120*cos(theta)**25 - 1.69679867736531e+121*cos(theta)**23 + 1.33319896078703e+121*cos(theta)**21 - 5.8694293871127e+120*cos(theta)**19 + 1.59820449872018e+120*cos(theta)**17 - 2.80459112033476e+119*cos(theta)**15 + 3.20786566051362e+118*cos(theta)**13 - 2.36720455553512e+117*cos(theta)**11 + 1.09225042411436e+116*cos(theta)**9 - 2.97210999759009e+114*cos(theta)**7 + 4.30443516892358e+112*cos(theta)**5 - 2.73644956702071e+110*cos(theta)**3 + 4.85186093443389e+107*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl82_m_minus_56(theta, phi):
    return 3.91271283474653e-105*(1.0 - cos(theta)**2)**28*(3.54587415910955e+119*cos(theta)**26 - 7.06999448902212e+119*cos(theta)**24 + 6.05999527630467e+119*cos(theta)**22 - 2.93471469355635e+119*cos(theta)**20 + 8.87891388177877e+118*cos(theta)**18 - 1.75286945020923e+118*cos(theta)**16 + 2.29133261465258e+117*cos(theta)**14 - 1.97267046294593e+116*cos(theta)**12 + 1.09225042411436e+115*cos(theta)**10 - 3.71513749698762e+113*cos(theta)**8 + 7.17405861487264e+111*cos(theta)**6 - 6.84112391755179e+109*cos(theta)**4 + 2.42593046721695e+107*cos(theta)**2 - 1.34251824417097e+104)*sin(56*phi)

#@torch.jit.script
def Yl82_m_minus_55(theta, phi):
    return 2.38835786170144e-103*(1.0 - cos(theta)**2)**27.5*(1.31328672559613e+118*cos(theta)**27 - 2.82799779560885e+118*cos(theta)**25 + 2.63478055491507e+118*cos(theta)**23 - 1.39748318740779e+118*cos(theta)**21 + 4.67311256935724e+117*cos(theta)**19 - 1.03109967659366e+117*cos(theta)**17 + 1.52755507643506e+116*cos(theta)**15 - 1.51743881765072e+115*cos(theta)**13 + 9.92954931013054e+113*cos(theta)**11 - 4.12793055220846e+112*cos(theta)**9 + 1.02486551641038e+111*cos(theta)**7 - 1.36822478351036e+109*cos(theta)**5 + 8.08643489072315e+106*cos(theta)**3 - 1.34251824417097e+104*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl82_m_minus_54(theta, phi):
    return 1.47924019567526e-101*(1.0 - cos(theta)**2)**27*(4.6903097342719e+116*cos(theta)**28 - 1.08769145984956e+117*cos(theta)**26 + 1.09782523121461e+117*cos(theta)**24 - 6.35219630639903e+116*cos(theta)**22 + 2.33655628467862e+116*cos(theta)**20 - 5.72833153663146e+115*cos(theta)**18 + 9.5472192277191e+114*cos(theta)**16 - 1.08388486975051e+114*cos(theta)**14 + 8.27462442510878e+112*cos(theta)**12 - 4.12793055220846e+111*cos(theta)**10 + 1.28108189551297e+110*cos(theta)**8 - 2.28037463918393e+108*cos(theta)**6 + 2.02160872268079e+106*cos(theta)**4 - 6.71259122085486e+103*cos(theta)**2 + 3.4997868721871e+100)*sin(54*phi)

#@torch.jit.script
def Yl82_m_minus_53(theta, phi):
    return 9.28981686517097e-100*(1.0 - cos(theta)**2)**26.5*(1.61734818423169e+115*cos(theta)**29 - 4.02848688833169e+115*cos(theta)**27 + 4.39130092485846e+115*cos(theta)**25 - 2.76182448104305e+115*cos(theta)**23 + 1.11264584984696e+115*cos(theta)**21 - 3.01491133506919e+114*cos(theta)**19 + 5.616011310423e+113*cos(theta)**17 - 7.22589913167009e+112*cos(theta)**15 + 6.36509571162214e+111*cos(theta)**13 - 3.75266413837133e+110*cos(theta)**11 + 1.42342432834775e+109*cos(theta)**9 - 3.25767805597704e+107*cos(theta)**7 + 4.04321744536157e+105*cos(theta)**5 - 2.23753040695162e+103*cos(theta)**3 + 3.4997868721871e+100*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl82_m_minus_52(theta, phi):
    return 5.91200325120919e-98*(1.0 - cos(theta)**2)**26*(5.39116061410563e+113*cos(theta)**30 - 1.43874531726132e+114*cos(theta)**28 + 1.68896189417633e+114*cos(theta)**26 - 1.15076020043461e+114*cos(theta)**24 + 5.05748113566801e+113*cos(theta)**22 - 1.5074556675346e+113*cos(theta)**20 + 3.12000628356833e+112*cos(theta)**18 - 4.5161869572938e+111*cos(theta)**16 + 4.54649693687296e+110*cos(theta)**14 - 3.12722011530944e+109*cos(theta)**12 + 1.42342432834775e+108*cos(theta)**10 - 4.0720975699713e+106*cos(theta)**8 + 6.73869574226929e+104*cos(theta)**6 - 5.59382601737905e+102*cos(theta)**4 + 1.74989343609355e+100*cos(theta)**2 - 8.64144906712864e+96)*sin(52*phi)

#@torch.jit.script
def Yl82_m_minus_51(theta, phi):
    return 3.81037667777541e-96*(1.0 - cos(theta)**2)**25.5*(1.73908406906633e+112*cos(theta)**31 - 4.96119074917696e+112*cos(theta)**29 + 6.25541442287529e+112*cos(theta)**27 - 4.60304080173842e+112*cos(theta)**25 + 2.19890484159479e+112*cos(theta)**23 - 7.17836032159331e+111*cos(theta)**21 + 1.64210857029912e+111*cos(theta)**19 - 2.656580563114e+110*cos(theta)**17 + 3.0309979579153e+109*cos(theta)**15 - 2.40555393485342e+108*cos(theta)**13 + 1.29402211667977e+107*cos(theta)**11 - 4.52455285552367e+105*cos(theta)**9 + 9.62670820324185e+103*cos(theta)**7 - 1.11876520347581e+102*cos(theta)**5 + 5.83297812031183e+99*cos(theta)**3 - 8.64144906712864e+96*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl82_m_minus_50(theta, phi):
    return 2.48581451712174e-94*(1.0 - cos(theta)**2)**25*(5.43463771583229e+110*cos(theta)**32 - 1.65373024972565e+111*cos(theta)**30 + 2.23407657959832e+111*cos(theta)**28 - 1.77040030836093e+111*cos(theta)**26 + 9.16210350664495e+110*cos(theta)**24 - 3.26289105526969e+110*cos(theta)**22 + 8.21054285149561e+109*cos(theta)**20 - 1.47587809061889e+109*cos(theta)**18 + 1.89437372369707e+108*cos(theta)**16 - 1.71825281060958e+107*cos(theta)**14 + 1.07835176389981e+106*cos(theta)**12 - 4.52455285552367e+104*cos(theta)**10 + 1.20333852540523e+103*cos(theta)**8 - 1.86460867245968e+101*cos(theta)**6 + 1.45824453007796e+99*cos(theta)**4 - 4.32072453356432e+96*cos(theta)**2 + 2.03041566426895e+93)*sin(50*phi)

#@torch.jit.script
def Yl82_m_minus_49(theta, phi):
    return 1.64063758130035e-92*(1.0 - cos(theta)**2)**24.5*(1.64685991388857e+109*cos(theta)**33 - 5.33461370879243e+109*cos(theta)**31 + 7.70371234344248e+109*cos(theta)**29 - 6.55703817911456e+109*cos(theta)**27 + 3.66484140265798e+109*cos(theta)**25 - 1.41864828489986e+109*cos(theta)**23 + 3.90978231023601e+108*cos(theta)**21 - 7.76777942430995e+107*cos(theta)**19 + 1.11433748452769e+107*cos(theta)**17 - 1.14550187373972e+106*cos(theta)**15 + 8.29501356846006e+104*cos(theta)**13 - 4.11322986865788e+103*cos(theta)**11 + 1.33704280600581e+102*cos(theta)**9 - 2.6637266749424e+100*cos(theta)**7 + 2.91648906015592e+98*cos(theta)**5 - 1.44024151118811e+96*cos(theta)**3 + 2.03041566426895e+93*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl82_m_minus_48(theta, phi):
    return 1.09493354649137e-90*(1.0 - cos(theta)**2)**24*(4.84370562908403e+107*cos(theta)**34 - 1.66706678399763e+108*cos(theta)**32 + 2.56790411448083e+108*cos(theta)**30 - 2.34179934968377e+108*cos(theta)**28 + 1.40955438563768e+108*cos(theta)**26 - 5.9110345204161e+107*cos(theta)**24 + 1.77717377738e+107*cos(theta)**22 - 3.88388971215497e+106*cos(theta)**20 + 6.19076380293159e+105*cos(theta)**18 - 7.15938671087326e+104*cos(theta)**16 + 5.92500969175718e+103*cos(theta)**14 - 3.4276915572149e+102*cos(theta)**12 + 1.33704280600581e+101*cos(theta)**10 - 3.329658343678e+99*cos(theta)**8 + 4.86081510025986e+97*cos(theta)**6 - 3.60060377797027e+95*cos(theta)**4 + 1.01520783213447e+93*cos(theta)**2 - 4.55863418111573e+89)*sin(48*phi)

#@torch.jit.script
def Yl82_m_minus_47(theta, phi):
    return 7.38573056244701e-89*(1.0 - cos(theta)**2)**23.5*(1.38391589402401e+106*cos(theta)**35 - 5.05171752726556e+106*cos(theta)**33 + 8.28356165961557e+106*cos(theta)**31 - 8.07517017132336e+106*cos(theta)**29 + 5.22057179865809e+106*cos(theta)**27 - 2.36441380816644e+106*cos(theta)**25 + 7.72684251034784e+105*cos(theta)**23 - 1.84947129150237e+105*cos(theta)**21 + 3.25829673838505e+104*cos(theta)**19 - 4.21140394757251e+103*cos(theta)**17 + 3.95000646117146e+102*cos(theta)**15 - 2.63668581324223e+101*cos(theta)**13 + 1.21549346000528e+100*cos(theta)**11 - 3.69962038186445e+98*cos(theta)**9 + 6.9440215717998e+96*cos(theta)**7 - 7.20120755594053e+94*cos(theta)**5 + 3.38402610711491e+92*cos(theta)**3 - 4.55863418111573e+89*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl82_m_minus_46(theta, phi):
    return 5.0331464317095e-87*(1.0 - cos(theta)**2)**23*(3.84421081673336e+104*cos(theta)**36 - 1.48579927272516e+105*cos(theta)**34 + 2.58861301862987e+105*cos(theta)**32 - 2.69172339044112e+105*cos(theta)**30 + 1.86448992809218e+105*cos(theta)**28 - 9.09389926217861e+104*cos(theta)**26 + 3.21951771264493e+104*cos(theta)**24 - 8.40668768864713e+103*cos(theta)**22 + 1.62914836919252e+103*cos(theta)**20 - 2.3396688597625e+102*cos(theta)**18 + 2.46875403823216e+101*cos(theta)**16 - 1.88334700945874e+100*cos(theta)**14 + 1.01291121667107e+99*cos(theta)**12 - 3.69962038186445e+97*cos(theta)**10 + 8.68002696474975e+95*cos(theta)**8 - 1.20020125932342e+94*cos(theta)**6 + 8.46006526778728e+91*cos(theta)**4 - 2.27931709055787e+89*cos(theta)**2 + 9.81618040722595e+85)*sin(46*phi)

#@torch.jit.script
def Yl82_m_minus_45(theta, phi):
    return 3.4637410177776e-85*(1.0 - cos(theta)**2)**22.5*(1.03897589641442e+103*cos(theta)**37 - 4.24514077921475e+103*cos(theta)**35 + 7.84428187463596e+103*cos(theta)**33 - 8.68297867884232e+103*cos(theta)**31 + 6.42927561411095e+103*cos(theta)**29 - 3.36811083784393e+103*cos(theta)**27 + 1.28780708505797e+103*cos(theta)**25 - 3.65508160375962e+102*cos(theta)**23 + 7.75784937710725e+101*cos(theta)**21 - 1.2314046630329e+101*cos(theta)**19 + 1.45220825778362e+100*cos(theta)**17 - 1.25556467297249e+99*cos(theta)**15 + 7.79162474362361e+97*cos(theta)**13 - 3.36329125624041e+96*cos(theta)**11 + 9.6444744052775e+94*cos(theta)**9 - 1.71457322760489e+93*cos(theta)**7 + 1.69201305355746e+91*cos(theta)**5 - 7.59772363519289e+88*cos(theta)**3 + 9.81618040722595e+85*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl82_m_minus_44(theta, phi):
    return 2.40624071678879e-83*(1.0 - cos(theta)**2)**22*(2.73414709582743e+101*cos(theta)**38 - 1.1792057720041e+102*cos(theta)**36 + 2.30714172783411e+102*cos(theta)**34 - 2.71343083713822e+102*cos(theta)**32 + 2.14309187137032e+102*cos(theta)**30 - 1.2028967278014e+102*cos(theta)**28 + 4.9531041732999e+101*cos(theta)**26 - 1.52295066823318e+101*cos(theta)**24 + 3.52629517141239e+100*cos(theta)**22 - 6.15702331516449e+99*cos(theta)**20 + 8.06782365435346e+98*cos(theta)**18 - 7.84727920607807e+97*cos(theta)**16 + 5.56544624544544e+96*cos(theta)**14 - 2.80274271353367e+95*cos(theta)**12 + 9.6444744052775e+93*cos(theta)**10 - 2.14321653450611e+92*cos(theta)**8 + 2.82002175592909e+90*cos(theta)**6 - 1.89943090879822e+88*cos(theta)**4 + 4.90809020361298e+85*cos(theta)**2 - 2.03401997663198e+82)*sin(44*phi)

#@torch.jit.script
def Yl82_m_minus_43(theta, phi):
    return 1.68677302617654e-81*(1.0 - cos(theta)**2)**21.5*(7.01063357904468e+99*cos(theta)**39 - 3.1870426270381e+100*cos(theta)**37 + 6.59183350809744e+100*cos(theta)**35 - 8.22251768829765e+100*cos(theta)**33 + 6.91319958506554e+100*cos(theta)**31 - 4.14791975103932e+100*cos(theta)**29 + 1.83448302714811e+100*cos(theta)**27 - 6.0918026729327e+99*cos(theta)**25 + 1.53317181365756e+99*cos(theta)**23 - 2.93191586436404e+98*cos(theta)**21 + 4.24622297597551e+97*cos(theta)**19 - 4.61604659181063e+96*cos(theta)**17 + 3.71029749696363e+95*cos(theta)**15 - 2.15595593348744e+94*cos(theta)**13 + 8.76770400479773e+92*cos(theta)**11 - 2.38135170500679e+91*cos(theta)**9 + 4.02860250847013e+89*cos(theta)**7 - 3.79886181759644e+87*cos(theta)**5 + 1.63603006787099e+85*cos(theta)**3 - 2.03401997663198e+82*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl82_m_minus_42(theta, phi):
    return 1.19272864513199e-79*(1.0 - cos(theta)**2)**21*(1.75265839476117e+98*cos(theta)**40 - 8.38695428167922e+98*cos(theta)**38 + 1.8310648633604e+99*cos(theta)**36 - 2.41838755538166e+99*cos(theta)**34 + 2.16037487033298e+99*cos(theta)**32 - 1.38263991701311e+99*cos(theta)**30 + 6.55172509695754e+98*cos(theta)**28 - 2.34300102805104e+98*cos(theta)**26 + 6.38821589023983e+97*cos(theta)**24 - 1.33268902925638e+97*cos(theta)**22 + 2.12311148798775e+96*cos(theta)**20 - 2.56447032878368e+95*cos(theta)**18 + 2.31893593560227e+94*cos(theta)**16 - 1.5399685239196e+93*cos(theta)**14 + 7.30642000399811e+91*cos(theta)**12 - 2.38135170500679e+90*cos(theta)**10 + 5.03575313558767e+88*cos(theta)**8 - 6.33143636266074e+86*cos(theta)**6 + 4.09007516967748e+84*cos(theta)**4 - 1.01700998831599e+82*cos(theta)**2 + 4.06803995326397e+78)*sin(42*phi)

#@torch.jit.script
def Yl82_m_minus_41(theta, phi):
    return 8.50441452467428e-78*(1.0 - cos(theta)**2)**20.5*(4.27477657258822e+96*cos(theta)**41 - 2.15050109786647e+97*cos(theta)**39 + 4.94882395502811e+97*cos(theta)**37 - 6.90967872966189e+97*cos(theta)**35 + 6.54659051616055e+97*cos(theta)**33 - 4.46012876455841e+97*cos(theta)**31 + 2.25921555067501e+97*cos(theta)**29 - 8.67778158537422e+96*cos(theta)**27 + 2.55528635609593e+96*cos(theta)**25 - 5.79430012720166e+95*cos(theta)**23 + 1.01100547047036e+95*cos(theta)**21 - 1.34972122567562e+94*cos(theta)**19 + 1.36407996211898e+93*cos(theta)**17 - 1.02664568261307e+92*cos(theta)**15 + 5.62032307999854e+90*cos(theta)**13 - 2.16486518636981e+89*cos(theta)**11 + 5.59528126176407e+87*cos(theta)**9 - 9.04490908951534e+85*cos(theta)**7 + 8.18015033935496e+83*cos(theta)**5 - 3.39003329438664e+81*cos(theta)**3 + 4.06803995326397e+78*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl82_m_minus_40(theta, phi):
    return 6.11253869567382e-76*(1.0 - cos(theta)**2)**20*(1.01780394585434e+95*cos(theta)**42 - 5.37625274466616e+95*cos(theta)**40 + 1.30232209342845e+96*cos(theta)**38 - 1.91935520268386e+96*cos(theta)**36 + 1.92546779887075e+96*cos(theta)**34 - 1.3937902389245e+96*cos(theta)**32 + 7.53071850225004e+95*cos(theta)**30 - 3.09920770906222e+95*cos(theta)**28 + 9.82802444652282e+94*cos(theta)**26 - 2.41429171966736e+94*cos(theta)**24 + 4.5954794112289e+93*cos(theta)**22 - 6.74860612837811e+92*cos(theta)**20 + 7.57822201177211e+91*cos(theta)**18 - 6.41653551633167e+90*cos(theta)**16 + 4.01451648571325e+89*cos(theta)**14 - 1.80405432197484e+88*cos(theta)**12 + 5.59528126176407e+86*cos(theta)**10 - 1.13061363618942e+85*cos(theta)**8 + 1.36335838989249e+83*cos(theta)**6 - 8.4750832359666e+80*cos(theta)**4 + 2.03401997663198e+78*cos(theta)**2 - 7.87464179880752e+74)*sin(40*phi)

#@torch.jit.script
def Yl82_m_minus_39(theta, phi):
    return 4.42726751326201e-74*(1.0 - cos(theta)**2)**19.5*(2.36698592059148e+93*cos(theta)**43 - 1.31128115723565e+94*cos(theta)**41 + 3.33928741904731e+94*cos(theta)**39 - 5.18744649374016e+94*cos(theta)**37 + 5.50133656820214e+94*cos(theta)**35 - 4.22360678461971e+94*cos(theta)**33 + 2.42926403298388e+94*cos(theta)**31 - 1.06869231346973e+94*cos(theta)**29 + 3.64000905426771e+93*cos(theta)**27 - 9.65716687866943e+92*cos(theta)**25 + 1.99803452662126e+92*cos(theta)**23 - 3.21362196589434e+91*cos(theta)**21 + 3.98853790093269e+90*cos(theta)**19 - 3.77443265666569e+89*cos(theta)**17 + 2.67634432380883e+88*cos(theta)**15 - 1.3877340938268e+87*cos(theta)**13 + 5.08661932887643e+85*cos(theta)**11 - 1.2562373735438e+84*cos(theta)**9 + 1.94765484270356e+82*cos(theta)**7 - 1.69501664719332e+80*cos(theta)**5 + 6.78006658877328e+77*cos(theta)**3 - 7.87464179880752e+74*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl82_m_minus_38(theta, phi):
    return 3.23038874136438e-72*(1.0 - cos(theta)**2)**19*(5.37951345588974e+91*cos(theta)**44 - 3.12209799341821e+92*cos(theta)**42 + 8.34821854761827e+92*cos(theta)**40 - 1.36511749835267e+93*cos(theta)**38 + 1.52814904672282e+93*cos(theta)**36 - 1.24223728959403e+93*cos(theta)**34 + 7.59145010307464e+92*cos(theta)**32 - 3.56230771156577e+92*cos(theta)**30 + 1.30000323366704e+92*cos(theta)**28 - 3.7142949533344e+91*cos(theta)**26 + 8.32514386092193e+90*cos(theta)**24 - 1.4607372572247e+90*cos(theta)**22 + 1.99426895046634e+89*cos(theta)**20 - 2.09690703148094e+88*cos(theta)**18 + 1.67271520238052e+87*cos(theta)**16 - 9.91238638447715e+85*cos(theta)**14 + 4.23884944073036e+84*cos(theta)**12 - 1.2562373735438e+83*cos(theta)**10 + 2.43456855337945e+81*cos(theta)**8 - 2.8250277453222e+79*cos(theta)**6 + 1.69501664719332e+77*cos(theta)**4 - 3.93732089940376e+74*cos(theta)**2 + 1.47908373381058e+71)*sin(38*phi)

#@torch.jit.script
def Yl82_m_minus_37(theta, phi):
    return 2.37384122615229e-70*(1.0 - cos(theta)**2)**18.5*(1.19544743464216e+90*cos(theta)**45 - 7.26069300794934e+90*cos(theta)**43 + 2.03615086527275e+91*cos(theta)**41 - 3.50030127782737e+91*cos(theta)**39 + 4.13013255871032e+91*cos(theta)**37 - 3.54924939884009e+91*cos(theta)**35 + 2.30043942517413e+91*cos(theta)**33 - 1.14913151985993e+91*cos(theta)**31 + 4.48276977126565e+90*cos(theta)**29 - 1.37566479753126e+90*cos(theta)**27 + 3.33005754436877e+89*cos(theta)**25 - 6.35103155315087e+88*cos(theta)**23 + 9.4965188117445e+87*cos(theta)**21 - 1.10363527972681e+87*cos(theta)**19 + 9.83950119047364e+85*cos(theta)**17 - 6.60825758965143e+84*cos(theta)**15 + 3.26065341594643e+83*cos(theta)**13 - 1.14203397594891e+82*cos(theta)**11 + 2.70507617042161e+80*cos(theta)**9 - 4.03575392188886e+78*cos(theta)**7 + 3.39003329438664e+76*cos(theta)**5 - 1.31244029980125e+74*cos(theta)**3 + 1.47908373381058e+71*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl82_m_minus_36(theta, phi):
    return 1.75632168870198e-68*(1.0 - cos(theta)**2)**18*(2.59879877096122e+88*cos(theta)**46 - 1.65015750180667e+89*cos(theta)**44 + 4.8479782506494e+89*cos(theta)**42 - 8.75075319456842e+89*cos(theta)**40 + 1.08687698913429e+90*cos(theta)**38 - 9.85902610788914e+89*cos(theta)**36 + 6.76599830933569e+89*cos(theta)**34 - 3.59103599956227e+89*cos(theta)**32 + 1.49425659042188e+89*cos(theta)**30 - 4.91308856261164e+88*cos(theta)**28 + 1.28079136321876e+88*cos(theta)**26 - 2.64626314714619e+87*cos(theta)**24 + 4.31659945988386e+86*cos(theta)**22 - 5.51817639863405e+85*cos(theta)**20 + 5.46638955026313e+84*cos(theta)**18 - 4.13016099353215e+83*cos(theta)**16 + 2.32903815424745e+82*cos(theta)**14 - 9.51694979957422e+80*cos(theta)**12 + 2.70507617042161e+79*cos(theta)**10 - 5.04469240236107e+77*cos(theta)**8 + 5.6500554906444e+75*cos(theta)**6 - 3.28110074950314e+73*cos(theta)**4 + 7.3954186690529e+70*cos(theta)**2 - 2.70201632044315e+67)*sin(36*phi)

#@torch.jit.script
def Yl82_m_minus_35(theta, phi):
    return 1.30795859790518e-66*(1.0 - cos(theta)**2)**17.5*(5.52935908715154e+86*cos(theta)**47 - 3.66701667068148e+87*cos(theta)**45 + 1.12743680247661e+88*cos(theta)**43 - 2.13433004745571e+88*cos(theta)**41 + 2.78686407470332e+88*cos(theta)**39 - 2.66460165078085e+88*cos(theta)**37 + 1.93314237409591e+88*cos(theta)**35 - 1.08819272714008e+88*cos(theta)**33 + 4.82018254974801e+87*cos(theta)**31 - 1.69416846986608e+87*cos(theta)**29 + 4.74367171562503e+86*cos(theta)**27 - 1.05850525885848e+86*cos(theta)**25 + 1.87678237386255e+85*cos(theta)**23 - 2.62770304696859e+84*cos(theta)**21 + 2.87704713171744e+83*cos(theta)**19 - 2.42950646678361e+82*cos(theta)**17 + 1.55269210283163e+81*cos(theta)**15 - 7.3207306150571e+79*cos(theta)**13 + 2.45916015492874e+78*cos(theta)**11 - 5.60521378040119e+76*cos(theta)**9 + 8.07150784377771e+74*cos(theta)**7 - 6.56220149900627e+72*cos(theta)**5 + 2.46513955635097e+70*cos(theta)**3 - 2.70201632044315e+67*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl82_m_minus_34(theta, phi):
    return 9.80183859108696e-65*(1.0 - cos(theta)**2)**17*(1.15194980982324e+85*cos(theta)**48 - 7.9717753710467e+85*cos(theta)**46 + 2.56235636926501e+86*cos(theta)**44 - 5.08173820822788e+86*cos(theta)**42 + 6.96716018675829e+86*cos(theta)**40 - 7.01210960731802e+86*cos(theta)**38 + 5.3698399280442e+86*cos(theta)**36 - 3.20056684452965e+86*cos(theta)**34 + 1.50630704679625e+86*cos(theta)**32 - 5.64722823288694e+85*cos(theta)**30 + 1.69416846986608e+85*cos(theta)**28 - 4.07117407253261e+84*cos(theta)**26 + 7.81992655776062e+83*cos(theta)**24 - 1.19441047589482e+83*cos(theta)**22 + 1.43852356585872e+82*cos(theta)**20 - 1.34972581487979e+81*cos(theta)**18 + 9.70432564269771e+79*cos(theta)**16 - 5.22909329646935e+78*cos(theta)**14 + 2.04930012910728e+77*cos(theta)**12 - 5.60521378040119e+75*cos(theta)**10 + 1.00893848047221e+74*cos(theta)**8 - 1.09370024983438e+72*cos(theta)**6 + 6.16284889087741e+69*cos(theta)**4 - 1.35100816022157e+67*cos(theta)**2 + 4.8112826218717e+63)*sin(34*phi)

#@torch.jit.script
def Yl82_m_minus_33(theta, phi):
    return 7.38983227163081e-63*(1.0 - cos(theta)**2)**16.5*(2.3509179792311e+83*cos(theta)**49 - 1.69612241937164e+84*cos(theta)**47 + 5.69412526503336e+84*cos(theta)**45 - 1.18179958330881e+85*cos(theta)**43 + 1.69930736262397e+85*cos(theta)**41 - 1.79797682238924e+85*cos(theta)**39 + 1.45130808866059e+85*cos(theta)**37 - 9.14447669865615e+84*cos(theta)**35 + 4.5645668084735e+84*cos(theta)**33 - 1.82168652673772e+84*cos(theta)**31 + 5.84196024091752e+83*cos(theta)**29 - 1.50784224908615e+83*cos(theta)**27 + 3.12797062310425e+82*cos(theta)**25 - 5.19308902562963e+81*cos(theta)**23 + 6.85011221837485e+80*cos(theta)**21 - 7.10382007831466e+79*cos(theta)**19 + 5.70842684864571e+78*cos(theta)**17 - 3.48606219764624e+77*cos(theta)**15 + 1.57638471469791e+76*cos(theta)**13 - 5.09564889127381e+74*cos(theta)**11 + 1.12104275608024e+73*cos(theta)**9 - 1.56242892833483e+71*cos(theta)**7 + 1.23256977817548e+69*cos(theta)**5 - 4.50336053407191e+66*cos(theta)**3 + 4.8112826218717e+63*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl82_m_minus_32(theta, phi):
    return 5.60361776682089e-61*(1.0 - cos(theta)**2)**16*(4.7018359584622e+81*cos(theta)**50 - 3.53358837369091e+82*cos(theta)**48 + 1.23785331848551e+83*cos(theta)**46 - 2.68590814388366e+83*cos(theta)**44 + 4.04596991100946e+83*cos(theta)**42 - 4.49494205597309e+83*cos(theta)**40 + 3.81923181226472e+83*cos(theta)**38 - 2.54013241629337e+83*cos(theta)**36 + 1.34251964955103e+83*cos(theta)**34 - 5.69277039605538e+82*cos(theta)**32 + 1.94732008030584e+82*cos(theta)**30 - 5.38515088959339e+81*cos(theta)**28 + 1.20306562427086e+81*cos(theta)**26 - 2.16378709401235e+80*cos(theta)**24 + 3.11368737198857e+79*cos(theta)**22 - 3.55191003915733e+78*cos(theta)**20 + 3.17134824924762e+77*cos(theta)**18 - 2.1787888735289e+76*cos(theta)**16 + 1.12598908192708e+75*cos(theta)**14 - 4.24637407606151e+73*cos(theta)**12 + 1.12104275608024e+72*cos(theta)**10 - 1.95303616041853e+70*cos(theta)**8 + 2.0542829636258e+68*cos(theta)**6 - 1.12584013351798e+66*cos(theta)**4 + 2.40564131093585e+63*cos(theta)**2 - 8.36744803803774e+59)*sin(32*phi)

#@torch.jit.script
def Yl82_m_minus_31(theta, phi):
    return 4.27273558149263e-59*(1.0 - cos(theta)**2)**15.5*(9.21928619306313e+79*cos(theta)**51 - 7.21140484426717e+80*cos(theta)**49 + 2.63373046486279e+81*cos(theta)**47 - 5.96868476418591e+81*cos(theta)**45 + 9.4092323511848e+81*cos(theta)**43 - 1.09632733072514e+82*cos(theta)**41 + 9.79290208273005e+81*cos(theta)**39 - 6.86522274673885e+81*cos(theta)**37 + 3.83577042728865e+81*cos(theta)**35 - 1.7250819381986e+81*cos(theta)**33 + 6.28167767840594e+80*cos(theta)**31 - 1.85694858261841e+80*cos(theta)**29 + 4.45579860841061e+79*cos(theta)**27 - 8.65514837604939e+78*cos(theta)**25 + 1.3537771182559e+78*cos(theta)**23 - 1.69138573293206e+77*cos(theta)**21 + 1.66913065749875e+76*cos(theta)**19 - 1.28164051384053e+75*cos(theta)**17 + 7.50659387951386e+73*cos(theta)**15 - 3.26644159697039e+72*cos(theta)**13 + 1.01912977825476e+71*cos(theta)**11 - 2.17004017824281e+69*cos(theta)**9 + 2.93468994803686e+67*cos(theta)**7 - 2.25168026703596e+65*cos(theta)**5 + 8.01880436978617e+62*cos(theta)**3 - 8.36744803803774e+59*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl82_m_minus_30(theta, phi):
    return 3.27526851871414e-57*(1.0 - cos(theta)**2)**15*(1.77293965251214e+78*cos(theta)**52 - 1.44228096885343e+79*cos(theta)**50 + 5.48693846846415e+79*cos(theta)**48 - 1.29754016612737e+80*cos(theta)**46 + 2.13846189799654e+80*cos(theta)**44 - 2.6103031683932e+80*cos(theta)**42 + 2.44822552068251e+80*cos(theta)**40 - 1.80663756493128e+80*cos(theta)**38 + 1.06549178535796e+80*cos(theta)**36 - 5.07377040646647e+79*cos(theta)**34 + 1.96302427450186e+79*cos(theta)**32 - 6.18982860872804e+78*cos(theta)**30 + 1.59135664586093e+78*cos(theta)**28 - 3.32890322155746e+77*cos(theta)**26 + 5.64073799273292e+76*cos(theta)**24 - 7.68811696787301e+75*cos(theta)**22 + 8.34565328749373e+74*cos(theta)**20 - 7.12022507689182e+73*cos(theta)**18 + 4.69162117469616e+72*cos(theta)**16 - 2.33317256926456e+71*cos(theta)**14 + 8.49274815212301e+69*cos(theta)**12 - 2.17004017824281e+68*cos(theta)**10 + 3.66836243504608e+66*cos(theta)**8 - 3.75280044505993e+64*cos(theta)**6 + 2.00470109244654e+62*cos(theta)**4 - 4.18372401901887e+59*cos(theta)**2 + 1.42400409088457e+56)*sin(30*phi)

#@torch.jit.script
def Yl82_m_minus_29(theta, phi):
    return 2.52344507866567e-55*(1.0 - cos(theta)**2)**14.5*(3.34516915568328e+76*cos(theta)**53 - 2.82800189971262e+77*cos(theta)**51 + 1.11978336091105e+78*cos(theta)**49 - 2.76072375771781e+78*cos(theta)**47 + 4.75213755110343e+78*cos(theta)**45 - 6.07047248463535e+78*cos(theta)**43 + 5.97128175776222e+78*cos(theta)**41 - 4.6324040126443e+78*cos(theta)**39 + 2.87970752799448e+78*cos(theta)**37 - 1.44964868756185e+78*cos(theta)**35 + 5.94855840758138e+77*cos(theta)**33 - 1.9967189060413e+77*cos(theta)**31 + 5.48743670986528e+76*cos(theta)**29 - 1.23292711909535e+76*cos(theta)**27 + 2.25629519709317e+75*cos(theta)**25 - 3.34265955124914e+74*cos(theta)**23 + 3.97412061309225e+73*cos(theta)**21 - 3.74748688257464e+72*cos(theta)**19 + 2.75977716158598e+71*cos(theta)**17 - 1.55544837950971e+70*cos(theta)**15 + 6.53288319394078e+68*cos(theta)**13 - 1.97276379840256e+67*cos(theta)**11 + 4.07595826116231e+65*cos(theta)**9 - 5.36114349294275e+63*cos(theta)**7 + 4.00940218489309e+61*cos(theta)**5 - 1.39457467300629e+59*cos(theta)**3 + 1.42400409088457e+56*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl82_m_minus_28(theta, phi):
    return 1.95367458241801e-53*(1.0 - cos(theta)**2)**14*(6.19475769570978e+74*cos(theta)**54 - 5.43846519175503e+75*cos(theta)**52 + 2.2395667218221e+76*cos(theta)**50 - 5.75150782857878e+76*cos(theta)**48 + 1.03307338067466e+77*cos(theta)**46 - 1.37965283741713e+77*cos(theta)**44 + 1.42173375184815e+77*cos(theta)**42 - 1.15810100316107e+77*cos(theta)**40 + 7.57817770524864e+76*cos(theta)**38 - 4.02680190989403e+76*cos(theta)**36 + 1.74957600222982e+76*cos(theta)**34 - 6.23974658137907e+75*cos(theta)**32 + 1.82914556995509e+75*cos(theta)**30 - 4.40331113962627e+74*cos(theta)**28 + 8.67805845035833e+73*cos(theta)**26 - 1.39277481302047e+73*cos(theta)**24 + 1.80641846049648e+72*cos(theta)**22 - 1.87374344128732e+71*cos(theta)**20 + 1.53320953421443e+70*cos(theta)**18 - 9.72155237193569e+68*cos(theta)**16 + 4.66634513852913e+67*cos(theta)**14 - 1.64396983200213e+66*cos(theta)**12 + 4.07595826116231e+64*cos(theta)**10 - 6.70142936617844e+62*cos(theta)**8 + 6.68233697482181e+60*cos(theta)**6 - 3.48643668251573e+58*cos(theta)**4 + 7.12002045442286e+55*cos(theta)**2 - 2.37571586734163e+52)*sin(28*phi)

#@torch.jit.script
def Yl82_m_minus_27(theta, phi):
    return 1.51960220000552e-51*(1.0 - cos(theta)**2)**13.5*(1.12631958103814e+73*cos(theta)**55 - 1.02612550787831e+74*cos(theta)**53 + 4.3913072976904e+74*cos(theta)**51 - 1.17377710787322e+75*cos(theta)**49 + 2.19802846952055e+75*cos(theta)**47 - 3.06589519426028e+75*cos(theta)**45 + 3.30635756243756e+75*cos(theta)**43 - 2.82463659307579e+75*cos(theta)**41 + 1.94312248852529e+75*cos(theta)**39 - 1.0883248405119e+75*cos(theta)**37 + 4.99878857779948e+74*cos(theta)**35 - 1.8908322973876e+74*cos(theta)**33 + 5.90046958050031e+73*cos(theta)**31 - 1.51838315159526e+73*cos(theta)**29 + 3.21409572235494e+72*cos(theta)**27 - 5.57109925208189e+71*cos(theta)**25 + 7.85399330650643e+70*cos(theta)**23 - 8.92258781565391e+69*cos(theta)**21 + 8.06952386428648e+68*cos(theta)**19 - 5.7185602187857e+67*cos(theta)**17 + 3.11089675901942e+66*cos(theta)**15 - 1.26459217846318e+65*cos(theta)**13 + 3.70541660105665e+63*cos(theta)**11 - 7.44603262908716e+61*cos(theta)**9 + 9.54619567831687e+59*cos(theta)**7 - 6.97287336503145e+57*cos(theta)**5 + 2.37334015147429e+55*cos(theta)**3 - 2.37571586734163e+52*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl82_m_minus_26(theta, phi):
    return 1.18723632548794e-49*(1.0 - cos(theta)**2)**13*(2.01128496613954e+71*cos(theta)**56 - 1.90023242199687e+72*cos(theta)**54 + 8.44482172632769e+72*cos(theta)**52 - 2.34755421574644e+73*cos(theta)**50 + 4.57922597816782e+73*cos(theta)**48 - 6.66498955273974e+73*cos(theta)**46 + 7.5144490055399e+73*cos(theta)**44 - 6.72532522160903e+73*cos(theta)**42 + 4.85780622131323e+73*cos(theta)**40 - 2.86401273818921e+73*cos(theta)**38 + 1.38855238272208e+73*cos(theta)**36 - 5.5612714629047e+72*cos(theta)**34 + 1.84389674390635e+72*cos(theta)**32 - 5.06127717198421e+71*cos(theta)**30 + 1.14789132941248e+71*cos(theta)**28 - 2.14273048156996e+70*cos(theta)**26 + 3.27249721104435e+69*cos(theta)**24 - 4.05572173438814e+68*cos(theta)**22 + 4.03476193214324e+67*cos(theta)**20 - 3.17697789932539e+66*cos(theta)**18 + 1.94431047438714e+65*cos(theta)**16 - 9.03280127473699e+63*cos(theta)**14 + 3.08784716754721e+62*cos(theta)**12 - 7.44603262908716e+60*cos(theta)**10 + 1.19327445978961e+59*cos(theta)**8 - 1.16214556083858e+57*cos(theta)**6 + 5.93335037868572e+54*cos(theta)**4 - 1.18785793367081e+52*cos(theta)**2 + 3.89206400285326e+48)*sin(26*phi)

#@torch.jit.script
def Yl82_m_minus_25(theta, phi):
    return 9.31507769682447e-48*(1.0 - cos(theta)**2)**12.5*(3.52857011603428e+69*cos(theta)**57 - 3.4549680399943e+70*cos(theta)**55 + 1.59336258987315e+71*cos(theta)**53 - 4.60304748185576e+71*cos(theta)**51 + 9.34535913911799e+71*cos(theta)**49 - 1.41808288356165e+72*cos(theta)**47 + 1.66987755678664e+72*cos(theta)**45 - 1.56402912130443e+72*cos(theta)**43 + 1.18483078568615e+72*cos(theta)**41 - 7.34362240561335e+71*cos(theta)**39 + 3.75284427762724e+71*cos(theta)**37 - 1.58893470368706e+71*cos(theta)**35 + 5.58756589062529e+70*cos(theta)**33 - 1.63267005547878e+70*cos(theta)**31 + 3.9582459634913e+69*cos(theta)**29 - 7.93603882062948e+68*cos(theta)**27 + 1.30899888441774e+68*cos(theta)**25 - 1.76335727582093e+67*cos(theta)**23 + 1.9213152057825e+66*cos(theta)**21 - 1.67209363122389e+65*cos(theta)**19 + 1.14371204375714e+64*cos(theta)**17 - 6.02186751649133e+62*cos(theta)**15 + 2.37526705195939e+61*cos(theta)**13 - 6.76912057189742e+59*cos(theta)**11 + 1.32586051087734e+58*cos(theta)**9 - 1.66020794405511e+56*cos(theta)**7 + 1.18667007573714e+54*cos(theta)**5 - 3.95952644556938e+51*cos(theta)**3 + 3.89206400285326e+48*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl82_m_minus_24(theta, phi):
    return 7.33824770310885e-46*(1.0 - cos(theta)**2)**12*(6.08374157936945e+67*cos(theta)**58 - 6.16958578570411e+68*cos(theta)**56 + 2.95067146272805e+69*cos(theta)**54 - 8.85201438818416e+69*cos(theta)**52 + 1.8690718278236e+70*cos(theta)**50 - 2.95433934075343e+70*cos(theta)**48 + 3.6301686017101e+70*cos(theta)**46 - 3.55461163932824e+70*cos(theta)**44 + 2.82102568020513e+70*cos(theta)**42 - 1.83590560140334e+70*cos(theta)**40 + 9.87590599375589e+69*cos(theta)**38 - 4.41370751024183e+69*cos(theta)**36 + 1.64340173253685e+69*cos(theta)**34 - 5.10209392337118e+68*cos(theta)**32 + 1.31941532116377e+68*cos(theta)**30 - 2.83429957879624e+67*cos(theta)**28 + 5.03461109391438e+66*cos(theta)**26 - 7.34732198258721e+65*cos(theta)**24 + 8.73325093537498e+64*cos(theta)**22 - 8.36046815611944e+63*cos(theta)**20 + 6.35395579865077e+62*cos(theta)**18 - 3.76366719780708e+61*cos(theta)**16 + 1.69661932282813e+60*cos(theta)**14 - 5.64093380991451e+58*cos(theta)**12 + 1.32586051087734e+57*cos(theta)**10 - 2.07525993006889e+55*cos(theta)**8 + 1.97778345956191e+53*cos(theta)**6 - 9.89881611392345e+50*cos(theta)**4 + 1.94603200142663e+48*cos(theta)**2 - 6.27145343676e+44)*sin(24*phi)

#@torch.jit.script
def Yl82_m_minus_23(theta, phi):
    return 5.80325034328649e-44*(1.0 - cos(theta)**2)**11.5*(1.03114264057109e+66*cos(theta)**59 - 1.08238347117616e+67*cos(theta)**57 + 5.3648572049601e+67*cos(theta)**55 - 1.67019139399701e+68*cos(theta)**53 + 3.66484672122274e+68*cos(theta)**51 - 6.02926396072128e+68*cos(theta)**49 + 7.72376298236191e+68*cos(theta)**47 - 7.89913697628498e+68*cos(theta)**45 + 6.56052483768635e+68*cos(theta)**43 - 4.47781854000814e+68*cos(theta)**41 + 2.53228358814254e+68*cos(theta)**39 - 1.19289392168698e+68*cos(theta)**37 + 4.69543352153386e+67*cos(theta)**35 - 1.54608906768824e+67*cos(theta)**33 + 4.25617845536699e+66*cos(theta)**31 - 9.77344682343532e+65*cos(theta)**29 + 1.86467077552384e+65*cos(theta)**27 - 2.93892879303489e+64*cos(theta)**25 + 3.79706562407608e+63*cos(theta)**23 - 3.98117531243783e+62*cos(theta)**21 + 3.34418726244778e+61*cos(theta)**19 - 2.21392188106299e+60*cos(theta)**17 + 1.13107954855209e+59*cos(theta)**15 - 4.3391798537804e+57*cos(theta)**13 + 1.20532773716122e+56*cos(theta)**11 - 2.30584436674321e+54*cos(theta)**9 + 2.82540494223129e+52*cos(theta)**7 - 1.97976322278469e+50*cos(theta)**5 + 6.48677333808876e+47*cos(theta)**3 - 6.27145343676e+44*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl82_m_minus_22(theta, phi):
    return 4.60618716125588e-42*(1.0 - cos(theta)**2)**11*(1.71857106761849e+64*cos(theta)**60 - 1.86617839857959e+65*cos(theta)**58 + 9.58010215171446e+65*cos(theta)**56 - 3.09294702592039e+66*cos(theta)**54 + 7.04778215619758e+66*cos(theta)**52 - 1.20585279214426e+67*cos(theta)**50 + 1.60911728799206e+67*cos(theta)**48 - 1.71720369049673e+67*cos(theta)**46 + 1.49102837220144e+67*cos(theta)**44 - 1.06614727143051e+67*cos(theta)**42 + 6.33070897035634e+66*cos(theta)**40 - 3.13919453075521e+66*cos(theta)**38 + 1.30428708931496e+66*cos(theta)**36 - 4.54732078731834e+65*cos(theta)**34 + 1.33005576730219e+65*cos(theta)**32 - 3.25781560781177e+64*cos(theta)**30 + 6.65953848401373e+63*cos(theta)**28 - 1.13035722809034e+63*cos(theta)**26 + 1.58211067669837e+62*cos(theta)**24 - 1.8096251420172e+61*cos(theta)**22 + 1.67209363122389e+60*cos(theta)**20 - 1.22995660059055e+59*cos(theta)**18 + 7.06924717845056e+57*cos(theta)**16 - 3.09941418127171e+56*cos(theta)**14 + 1.00443978096768e+55*cos(theta)**12 - 2.30584436674321e+53*cos(theta)**10 + 3.53175617778912e+51*cos(theta)**8 - 3.29960537130782e+49*cos(theta)**6 + 1.62169333452219e+47*cos(theta)**4 - 3.13572671838e+44*cos(theta)**2 + 9.95468799485715e+40)*sin(22*phi)

#@torch.jit.script
def Yl82_m_minus_21(theta, phi):
    return 3.66879265268161e-40*(1.0 - cos(theta)**2)**10.5*(2.8173296190467e+62*cos(theta)**61 - 3.16301423488065e+63*cos(theta)**59 + 1.68071967573938e+64*cos(theta)**57 - 5.62354004712798e+64*cos(theta)**55 + 1.32977021815049e+65*cos(theta)**53 - 2.36441723949854e+65*cos(theta)**51 + 3.28391283263686e+65*cos(theta)**49 - 3.65362487339731e+65*cos(theta)**47 + 3.31339638266987e+65*cos(theta)**45 - 2.47941225914072e+65*cos(theta)**43 + 1.5440753586235e+65*cos(theta)**41 - 8.04921674552618e+64*cos(theta)**39 + 3.52510024139178e+64*cos(theta)**37 - 1.29923451066238e+64*cos(theta)**35 + 4.03047202212783e+63*cos(theta)**33 - 1.05090826058444e+63*cos(theta)**31 + 2.29639258069439e+62*cos(theta)**29 - 4.18650825218645e+61*cos(theta)**27 + 6.32844270679347e+60*cos(theta)**25 - 7.86793540007476e+59*cos(theta)**23 + 7.96235062487566e+58*cos(theta)**21 - 6.47345579258184e+57*cos(theta)**19 + 4.15838069320621e+56*cos(theta)**17 - 2.06627612084781e+55*cos(theta)**15 + 7.72645985359757e+53*cos(theta)**13 - 2.09622215158473e+52*cos(theta)**11 + 3.9241735308768e+50*cos(theta)**9 - 4.71372195901117e+48*cos(theta)**7 + 3.24338666904438e+46*cos(theta)**5 - 1.04524223946e+44*cos(theta)**3 + 9.95468799485715e+40*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl82_m_minus_20(theta, phi):
    return 2.93182217107679e-38*(1.0 - cos(theta)**2)**10*(4.54408003072049e+60*cos(theta)**62 - 5.27169039146776e+61*cos(theta)**60 + 2.89779254437824e+62*cos(theta)**58 - 1.00420357984428e+63*cos(theta)**56 + 2.46253744101942e+63*cos(theta)**54 - 4.54695622980489e+63*cos(theta)**52 + 6.56782566527373e+63*cos(theta)**50 - 7.61171848624439e+63*cos(theta)**48 + 7.20303561449972e+63*cos(theta)**46 - 5.63502786168346e+63*cos(theta)**44 + 3.67636990148452e+63*cos(theta)**42 - 2.01230418638154e+63*cos(theta)**40 + 9.27657958260996e+62*cos(theta)**38 - 3.60898475183996e+62*cos(theta)**36 + 1.18543294768466e+62*cos(theta)**34 - 3.28408831432638e+61*cos(theta)**32 + 7.65464193564796e+60*cos(theta)**30 - 1.49518151863802e+60*cos(theta)**28 + 2.43401642568979e+59*cos(theta)**26 - 3.27830641669782e+58*cos(theta)**24 + 3.61925028403439e+57*cos(theta)**22 - 3.23672789629092e+56*cos(theta)**20 + 2.31021149622567e+55*cos(theta)**18 - 1.29142257552988e+54*cos(theta)**16 + 5.51889989542684e+52*cos(theta)**14 - 1.74685179298728e+51*cos(theta)**12 + 3.9241735308768e+49*cos(theta)**10 - 5.89215244876396e+47*cos(theta)**8 + 5.4056444484073e+45*cos(theta)**6 - 2.61310559865e+43*cos(theta)**4 + 4.97734399742857e+40*cos(theta)**2 - 1.5588299396895e+37)*sin(20*phi)

#@torch.jit.script
def Yl82_m_minus_19(theta, phi):
    return 2.35021711904123e-36*(1.0 - cos(theta)**2)**9.5*(7.21282544558808e+58*cos(theta)**63 - 8.64211539584878e+59*cos(theta)**61 + 4.91151278708176e+60*cos(theta)**59 - 1.76176066639348e+61*cos(theta)**57 + 4.47734080185349e+61*cos(theta)**55 - 8.57916269774508e+61*cos(theta)**53 + 1.28780895397524e+62*cos(theta)**51 - 1.55341193596824e+62*cos(theta)**49 + 1.53256076904249e+62*cos(theta)**47 - 1.25222841370743e+62*cos(theta)**45 + 8.54969744531283e+61*cos(theta)**43 - 4.9080589911745e+61*cos(theta)**41 + 2.37861014938717e+61*cos(theta)**39 - 9.75401284281069e+60*cos(theta)**37 + 3.38695127909902e+60*cos(theta)**35 - 9.95178277068601e+59*cos(theta)**33 + 2.46923933407999e+59*cos(theta)**31 - 5.15579834013109e+58*cos(theta)**29 + 9.01487565070294e+57*cos(theta)**27 - 1.31132256667913e+57*cos(theta)**25 + 1.57358708001495e+56*cos(theta)**23 - 1.54129899823377e+55*cos(theta)**21 + 1.2159007874872e+54*cos(theta)**19 - 7.59660338546988e+52*cos(theta)**17 + 3.67926659695122e+51*cos(theta)**15 - 1.34373214845175e+50*cos(theta)**13 + 3.56743048261527e+48*cos(theta)**11 - 6.54683605418218e+46*cos(theta)**9 + 7.72234921201043e+44*cos(theta)**7 - 5.2262111973e+42*cos(theta)**5 + 1.65911466580952e+40*cos(theta)**3 - 1.5588299396895e+37*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl82_m_minus_18(theta, phi):
    return 1.88955117831948e-34*(1.0 - cos(theta)**2)**9*(1.12700397587314e+57*cos(theta)**64 - 1.39388957997561e+58*cos(theta)**62 + 8.18585464513627e+58*cos(theta)**60 - 3.03751839033358e+59*cos(theta)**58 + 7.99525143188123e+59*cos(theta)**56 - 1.58873383291575e+60*cos(theta)**54 + 2.47655568072162e+60*cos(theta)**52 - 3.10682387193649e+60*cos(theta)**50 + 3.1928349355052e+60*cos(theta)**48 - 2.72223568197268e+60*cos(theta)**46 + 1.94311305575292e+60*cos(theta)**44 - 1.16858547408917e+60*cos(theta)**42 + 5.94652537346792e+59*cos(theta)**40 - 2.56684548495018e+59*cos(theta)**38 + 9.40819799749728e+58*cos(theta)**36 - 2.92699493255471e+58*cos(theta)**34 + 7.71637291899996e+57*cos(theta)**32 - 1.71859944671036e+57*cos(theta)**30 + 3.21959844667962e+56*cos(theta)**28 - 5.04354833338126e+55*cos(theta)**26 + 6.55661283339563e+54*cos(theta)**24 - 7.00590453742623e+53*cos(theta)**22 + 6.07950393743598e+52*cos(theta)**20 - 4.22033521414993e+51*cos(theta)**18 + 2.29954162309452e+50*cos(theta)**16 - 9.59808677465537e+48*cos(theta)**14 + 2.97285873551272e+47*cos(theta)**12 - 6.54683605418218e+45*cos(theta)**10 + 9.65293651501304e+43*cos(theta)**8 - 8.7103519955e+41*cos(theta)**6 + 4.14778666452381e+39*cos(theta)**4 - 7.7941496984475e+36*cos(theta)**2 + 2.41155621857905e+33)*sin(18*phi)

#@torch.jit.script
def Yl82_m_minus_17(theta, phi):
    return 1.52340486282129e-32*(1.0 - cos(theta)**2)**8.5*(1.73385227057406e+55*cos(theta)**65 - 2.21252314281843e+56*cos(theta)**63 + 1.34194338444857e+57*cos(theta)**61 - 5.14833625480268e+57*cos(theta)**59 + 1.40267568980372e+58*cos(theta)**57 - 2.88860696893774e+58*cos(theta)**55 + 4.67274656739928e+58*cos(theta)**53 - 6.09181151360095e+58*cos(theta)**51 + 6.51598966429632e+58*cos(theta)**49 - 5.79199081270784e+58*cos(theta)**47 + 4.31802901278426e+58*cos(theta)**45 - 2.71764063741667e+58*cos(theta)**43 + 1.45037204230925e+58*cos(theta)**41 - 6.58165508961585e+57*cos(theta)**39 + 2.5427562155398e+57*cos(theta)**37 - 8.36284266444202e+56*cos(theta)**35 + 2.33829482393938e+56*cos(theta)**33 - 5.54386918293666e+55*cos(theta)**31 + 1.11020636092401e+55*cos(theta)**29 - 1.86798086421528e+54*cos(theta)**27 + 2.62264513335825e+53*cos(theta)**25 - 3.04604545105488e+52*cos(theta)**23 + 2.89500187496952e+51*cos(theta)**21 - 2.22122906007891e+50*cos(theta)**19 + 1.35267154299677e+49*cos(theta)**17 - 6.39872451643691e+47*cos(theta)**15 + 2.28681441193286e+46*cos(theta)**13 - 5.95166914016562e+44*cos(theta)**11 + 1.07254850166812e+43*cos(theta)**9 - 1.24433599935714e+41*cos(theta)**7 + 8.29557332904762e+38*cos(theta)**5 - 2.5980498994825e+36*cos(theta)**3 + 2.41155621857905e+33*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl82_m_minus_16(theta, phi):
    return 1.23141631324363e-30*(1.0 - cos(theta)**2)**8*(2.62704889480918e+53*cos(theta)**66 - 3.45706741065379e+54*cos(theta)**64 + 2.16442481362672e+55*cos(theta)**62 - 8.58056042467114e+55*cos(theta)**60 + 2.41840636173056e+56*cos(theta)**58 - 5.15822673024596e+56*cos(theta)**56 + 8.65323438407274e+56*cos(theta)**54 - 1.17150221415403e+57*cos(theta)**52 + 1.30319793285926e+57*cos(theta)**50 - 1.20666475264747e+57*cos(theta)**48 + 9.38701959300926e+56*cos(theta)**46 - 6.17645599412879e+56*cos(theta)**44 + 3.45326676740297e+56*cos(theta)**42 - 1.64541377240396e+56*cos(theta)**40 + 6.69146372510475e+55*cos(theta)**38 - 2.3230118512339e+55*cos(theta)**36 + 6.87733771746877e+54*cos(theta)**34 - 1.73245911966771e+54*cos(theta)**32 + 3.70068786974669e+53*cos(theta)**30 - 6.67136022934029e+52*cos(theta)**28 + 1.00870966667625e+52*cos(theta)**26 - 1.2691856046062e+51*cos(theta)**24 + 1.31590994316796e+50*cos(theta)**22 - 1.11061453003946e+49*cos(theta)**20 + 7.51484190553763e+47*cos(theta)**18 - 3.99920282277307e+46*cos(theta)**16 + 1.63343886566633e+45*cos(theta)**14 - 4.95972428347135e+43*cos(theta)**12 + 1.07254850166812e+42*cos(theta)**10 - 1.55541999919643e+40*cos(theta)**8 + 1.38259555484127e+38*cos(theta)**6 - 6.49512474870625e+35*cos(theta)**4 + 1.20577810928953e+33*cos(theta)**2 - 3.69078086712435e+29)*sin(16*phi)

#@torch.jit.script
def Yl82_m_minus_15(theta, phi):
    return 9.97827208108044e-29*(1.0 - cos(theta)**2)**7.5*(3.92096849971519e+51*cos(theta)**67 - 5.31856524715968e+52*cos(theta)**65 + 3.43559494226464e+53*cos(theta)**63 - 1.40664924994609e+54*cos(theta)**61 + 4.09899383344163e+54*cos(theta)**59 - 9.04952057937887e+54*cos(theta)**57 + 1.57331534255868e+55*cos(theta)**55 - 2.21038153613968e+55*cos(theta)**53 + 2.55529006442993e+55*cos(theta)**51 - 2.46258112785197e+55*cos(theta)**49 + 1.99723821127857e+55*cos(theta)**47 - 1.37254577647306e+55*cos(theta)**45 + 8.03085294744878e+54*cos(theta)**43 - 4.01320432293649e+54*cos(theta)**41 + 1.71575992951404e+54*cos(theta)**39 - 6.27841040874026e+53*cos(theta)**37 + 1.96495363356251e+53*cos(theta)**35 - 5.24987612020517e+52*cos(theta)**33 + 1.19377028056345e+52*cos(theta)**31 - 2.3004690446001e+51*cos(theta)**29 + 3.73596172843056e+50*cos(theta)**27 - 5.0767424184248e+49*cos(theta)**25 + 5.72134757899114e+48*cos(theta)**23 - 5.28864061923551e+47*cos(theta)**21 + 3.95517995028296e+46*cos(theta)**19 - 2.35247224869004e+45*cos(theta)**17 + 1.08895924377755e+44*cos(theta)**15 - 3.81517252574719e+42*cos(theta)**13 + 9.75044092425559e+40*cos(theta)**11 - 1.72824444355159e+39*cos(theta)**9 + 1.9751365069161e+37*cos(theta)**7 - 1.29902494974125e+35*cos(theta)**5 + 4.01926036429842e+32*cos(theta)**3 - 3.69078086712435e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl82_m_minus_14(theta, phi):
    return 8.10392970677783e-27*(1.0 - cos(theta)**2)**7*(5.76613014663999e+49*cos(theta)**68 - 8.05843219266619e+50*cos(theta)**66 + 5.3681170972885e+51*cos(theta)**64 - 2.26878911281627e+52*cos(theta)**62 + 6.83165638906938e+52*cos(theta)**60 - 1.56026216885843e+53*cos(theta)**58 + 2.8094916831405e+53*cos(theta)**56 - 4.0932991409994e+53*cos(theta)**54 + 4.91401935467294e+53*cos(theta)**52 - 4.92516225570395e+53*cos(theta)**50 + 4.16091294016368e+53*cos(theta)**48 - 2.98379516624579e+53*cos(theta)**46 + 1.8251938516929e+53*cos(theta)**44 - 9.55524838794403e+52*cos(theta)**42 + 4.2893998237851e+52*cos(theta)**40 - 1.65221326545796e+52*cos(theta)**38 + 5.45820453767363e+51*cos(theta)**36 - 1.54408121182505e+51*cos(theta)**34 + 3.73053212676078e+50*cos(theta)**32 - 7.668230148667e+49*cos(theta)**30 + 1.33427204586806e+49*cos(theta)**28 - 1.95259323785569e+48*cos(theta)**26 + 2.38389482457964e+47*cos(theta)**24 - 2.40392755419796e+46*cos(theta)**22 + 1.97758997514148e+45*cos(theta)**20 - 1.30692902705002e+44*cos(theta)**18 + 6.80599527360972e+42*cos(theta)**16 - 2.72512323267656e+41*cos(theta)**14 + 8.12536743687966e+39*cos(theta)**12 - 1.72824444355159e+38*cos(theta)**10 + 2.46892063364513e+36*cos(theta)**8 - 2.16504158290208e+34*cos(theta)**6 + 1.00481509107461e+32*cos(theta)**4 - 1.84539043356218e+29*cos(theta)**2 + 5.59548342499144e+25)*sin(14*phi)

#@torch.jit.script
def Yl82_m_minus_13(theta, phi):
    return 6.59562305177026e-25*(1.0 - cos(theta)**2)**6.5*(8.35671035744925e+47*cos(theta)**69 - 1.20275107353227e+49*cos(theta)**67 + 8.25864168813616e+49*cos(theta)**65 - 3.60125256002583e+50*cos(theta)**63 + 1.11994367033924e+51*cos(theta)**61 - 2.6445121506075e+51*cos(theta)**59 + 4.92893277743947e+51*cos(theta)**57 - 7.44236207454437e+51*cos(theta)**55 + 9.27173463145838e+51*cos(theta)**53 - 9.65718089353715e+51*cos(theta)**51 + 8.49165906155853e+51*cos(theta)**49 - 6.34850035371445e+51*cos(theta)**47 + 4.05598633709534e+51*cos(theta)**45 - 2.22215078789396e+51*cos(theta)**43 + 1.04619507897197e+51*cos(theta)**41 - 4.23644427040503e+50*cos(theta)**39 + 1.47519041558747e+50*cos(theta)**37 - 4.41166060521443e+49*cos(theta)**35 + 1.1304642808366e+49*cos(theta)**33 - 2.47362262860226e+48*cos(theta)**31 + 4.6009380892002e+47*cos(theta)**29 - 7.23182680687294e+46*cos(theta)**27 + 9.53557929831856e+45*cos(theta)**25 - 1.04518589312955e+45*cos(theta)**23 + 9.41709511972134e+43*cos(theta)**21 - 6.87857382657907e+42*cos(theta)**19 + 4.00352663153513e+41*cos(theta)**17 - 1.81674882178438e+40*cos(theta)**15 + 6.25028264375359e+38*cos(theta)**13 - 1.57113131231963e+37*cos(theta)**11 + 2.74324514849458e+35*cos(theta)**9 - 3.09291654700298e+33*cos(theta)**7 + 2.00963018214921e+31*cos(theta)**5 - 6.15130144520726e+28*cos(theta)**3 + 5.59548342499144e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl82_m_minus_12(theta, phi):
    return 5.37856782873413e-23*(1.0 - cos(theta)**2)**6*(1.19381576534989e+46*cos(theta)**70 - 1.76875157872392e+47*cos(theta)**68 + 1.2513093466873e+48*cos(theta)**66 - 5.62695712504036e+48*cos(theta)**64 + 1.80636075861168e+49*cos(theta)**62 - 4.4075202510125e+49*cos(theta)**60 + 8.49815996110254e+49*cos(theta)**58 - 1.32899322759721e+50*cos(theta)**56 + 1.71698789471451e+50*cos(theta)**54 - 1.85715017183407e+50*cos(theta)**52 + 1.69833181231171e+50*cos(theta)**50 - 1.32260424035718e+50*cos(theta)**48 + 8.81736160238118e+49*cos(theta)**46 - 5.050342699759e+49*cos(theta)**44 + 2.49094066421899e+49*cos(theta)**42 - 1.05911106760126e+49*cos(theta)**40 + 3.88208004101965e+48*cos(theta)**38 - 1.22546127922623e+48*cos(theta)**36 + 3.32489494363706e+47*cos(theta)**34 - 7.73007071438205e+46*cos(theta)**32 + 1.5336460297334e+46*cos(theta)**30 - 2.58279528816891e+45*cos(theta)**28 + 3.66753049935329e+44*cos(theta)**26 - 4.35494122137311e+43*cos(theta)**24 + 4.28049778169152e+42*cos(theta)**22 - 3.43928691328953e+41*cos(theta)**20 + 2.22418146196396e+40*cos(theta)**18 - 1.13546801361523e+39*cos(theta)**16 + 4.46448760268113e+37*cos(theta)**14 - 1.30927609359969e+36*cos(theta)**12 + 2.74324514849458e+34*cos(theta)**10 - 3.86614568375372e+32*cos(theta)**8 + 3.34938363691535e+30*cos(theta)**6 - 1.53782536130181e+28*cos(theta)**4 + 2.79774171249572e+25*cos(theta)**2 - 8.41426078946081e+21)*sin(12*phi)

#@torch.jit.script
def Yl82_m_minus_11(theta, phi):
    return 4.39399694882089e-21*(1.0 - cos(theta)**2)**5.5*(1.68143065542239e+44*cos(theta)**71 - 2.56340808510713e+45*cos(theta)**69 + 1.86762589057805e+46*cos(theta)**67 - 8.6568571154467e+46*cos(theta)**65 + 2.86723929938362e+47*cos(theta)**63 - 7.22544303444673e+47*cos(theta)**61 + 1.44036609510213e+48*cos(theta)**59 - 2.33156706596002e+48*cos(theta)**57 + 3.12179617220821e+48*cos(theta)**55 - 3.50405692798881e+48*cos(theta)**53 + 3.33006237708178e+48*cos(theta)**51 - 2.69919232725954e+48*cos(theta)**49 + 1.87603438348536e+48*cos(theta)**47 - 1.12229837772422e+48*cos(theta)**45 + 5.79288526562555e+47*cos(theta)**43 - 2.58319772585673e+47*cos(theta)**41 + 9.95405138722987e+46*cos(theta)**39 - 3.31205751142224e+46*cos(theta)**37 + 9.49969983896302e+45*cos(theta)**35 - 2.34244567102486e+45*cos(theta)**33 + 4.94724525720451e+44*cos(theta)**31 - 8.9061906488583e+43*cos(theta)**29 + 1.35834462939011e+43*cos(theta)**27 - 1.74197648854924e+42*cos(theta)**25 + 1.86108599203979e+41*cos(theta)**23 - 1.63775567299502e+40*cos(theta)**21 + 1.17062182208629e+39*cos(theta)**19 - 6.67922360950138e+37*cos(theta)**17 + 2.97632506845409e+36*cos(theta)**15 - 1.00713545661514e+35*cos(theta)**13 + 2.49385922590417e+33*cos(theta)**11 - 4.29571742639302e+31*cos(theta)**9 + 4.78483376702193e+29*cos(theta)**7 - 3.07565072260363e+27*cos(theta)**5 + 9.32580570831907e+24*cos(theta)**3 - 8.41426078946081e+21*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl82_m_minus_10(theta, phi):
    return 3.59556772584124e-19*(1.0 - cos(theta)**2)**5*(2.33532035475331e+42*cos(theta)**72 - 3.66201155015305e+43*cos(theta)**70 + 2.74650866261479e+44*cos(theta)**68 - 1.31164501749192e+45*cos(theta)**66 + 4.48006140528691e+45*cos(theta)**64 - 1.16539403781399e+46*cos(theta)**62 + 2.40061015850354e+46*cos(theta)**60 - 4.01994321717244e+46*cos(theta)**58 + 5.57463602180037e+46*cos(theta)**56 - 6.48899431109038e+46*cos(theta)**54 + 6.40396610977264e+46*cos(theta)**52 - 5.39838465451909e+46*cos(theta)**50 + 3.90840496559449e+46*cos(theta)**48 - 2.43977908200918e+46*cos(theta)**46 + 1.31656483309672e+46*cos(theta)**44 - 6.15047077584935e+45*cos(theta)**42 + 2.48851284680747e+45*cos(theta)**40 - 8.71594081953222e+44*cos(theta)**38 + 2.63880551082306e+44*cos(theta)**36 - 6.8895460912496e+43*cos(theta)**34 + 1.54601414287641e+43*cos(theta)**32 - 2.9687302162861e+42*cos(theta)**30 + 4.85123081925039e+41*cos(theta)**28 - 6.69990957134325e+40*cos(theta)**26 + 7.75452496683246e+39*cos(theta)**24 - 7.44434396815916e+38*cos(theta)**22 + 5.85310911043147e+37*cos(theta)**20 - 3.71067978305632e+36*cos(theta)**18 + 1.86020316778381e+35*cos(theta)**16 - 7.19382469010817e+33*cos(theta)**14 + 2.07821602158681e+32*cos(theta)**12 - 4.29571742639302e+30*cos(theta)**10 + 5.98104220877741e+28*cos(theta)**8 - 5.12608453767271e+26*cos(theta)**6 + 2.33145142707977e+24*cos(theta)**4 - 4.20713039473041e+21*cos(theta)**2 + 1.25661003426834e+18)*sin(10*phi)

#@torch.jit.script
def Yl82_m_minus_9(theta, phi):
    return 2.94661107770915e-17*(1.0 - cos(theta)**2)**4.5*(3.19906897911413e+40*cos(theta)**73 - 5.15776274669443e+41*cos(theta)**71 + 3.98044733712288e+42*cos(theta)**69 - 1.95767913058496e+43*cos(theta)**67 + 6.89240216197986e+43*cos(theta)**65 - 1.84983180605395e+44*cos(theta)**63 + 3.93542648935007e+44*cos(theta)**61 - 6.81346307995329e+44*cos(theta)**59 + 9.780063196141e+44*cos(theta)**57 - 1.17981714747098e+45*cos(theta)**55 + 1.20829549240993e+45*cos(theta)**53 - 1.05850679500374e+45*cos(theta)**51 + 7.97633666447856e+44*cos(theta)**49 - 5.19101932342379e+44*cos(theta)**47 + 2.92569962910381e+44*cos(theta)**45 - 1.4303420408952e+44*cos(theta)**43 + 6.0695435287987e+43*cos(theta)**41 - 2.23485662039288e+43*cos(theta)**39 + 7.13190678600827e+42*cos(theta)**37 - 1.96844174035703e+42*cos(theta)**35 + 4.68489134204973e+41*cos(theta)**33 - 9.57654908479387e+40*cos(theta)**31 + 1.67283821353462e+40*cos(theta)**29 - 2.48144798938639e+39*cos(theta)**27 + 3.10180998673299e+38*cos(theta)**25 - 3.23667129050398e+37*cos(theta)**23 + 2.78719481449118e+36*cos(theta)**21 - 1.95298935950333e+35*cos(theta)**19 + 1.09423715751989e+34*cos(theta)**17 - 4.79588312673878e+32*cos(theta)**15 + 1.59862770891293e+31*cos(theta)**13 - 3.90519766035729e+29*cos(theta)**11 + 6.64560245419713e+27*cos(theta)**9 - 7.32297791096102e+25*cos(theta)**7 + 4.66290285415953e+23*cos(theta)**5 - 1.40237679824347e+21*cos(theta)**3 + 1.25661003426834e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl82_m_minus_8(theta, phi):
    return 2.41801713026678e-15*(1.0 - cos(theta)**2)**4*(4.32306618799206e+38*cos(theta)**74 - 7.16355937040893e+39*cos(theta)**72 + 5.68635333874697e+40*cos(theta)**70 - 2.87893989791906e+41*cos(theta)**68 + 1.04430335787574e+42*cos(theta)**66 - 2.8903621969593e+42*cos(theta)**64 + 6.34746207959688e+42*cos(theta)**62 - 1.13557717999221e+43*cos(theta)**60 + 1.6862177924381e+43*cos(theta)**58 - 2.1068163347696e+43*cos(theta)**56 + 2.23758424520358e+43*cos(theta)**54 - 2.03558999039181e+43*cos(theta)**52 + 1.59526733289571e+43*cos(theta)**50 - 1.08146235904662e+43*cos(theta)**48 + 6.36021658500829e+42*cos(theta)**46 - 3.2507773656709e+42*cos(theta)**44 + 1.44512941161874e+42*cos(theta)**42 - 5.58714155098219e+41*cos(theta)**40 + 1.87681757526534e+41*cos(theta)**38 - 5.46789372321397e+40*cos(theta)**36 + 1.37790921824992e+40*cos(theta)**34 - 2.99267158899808e+39*cos(theta)**32 + 5.57612737844872e+38*cos(theta)**30 - 8.86231424780853e+37*cos(theta)**28 + 1.19300384105115e+37*cos(theta)**26 - 1.34861303770999e+36*cos(theta)**24 + 1.26690673385963e+35*cos(theta)**22 - 9.76494679751664e+33*cos(theta)**20 + 6.07909531955492e+32*cos(theta)**18 - 2.99742695421174e+31*cos(theta)**16 + 1.14187693493781e+30*cos(theta)**14 - 3.25433138363108e+28*cos(theta)**12 + 6.64560245419713e+26*cos(theta)**10 - 9.15372238870127e+24*cos(theta)**8 + 7.77150475693256e+22*cos(theta)**6 - 3.50594199560867e+20*cos(theta)**4 + 6.28305017134171e+17*cos(theta)**2 - 186606776695625.0)*sin(8*phi)

#@torch.jit.script
def Yl82_m_minus_7(theta, phi):
    return 1.98660379002153e-13*(1.0 - cos(theta)**2)**3.5*(5.76408825065609e+36*cos(theta)**75 - 9.81309502795744e+37*cos(theta)**73 + 8.00894836443235e+38*cos(theta)**71 - 4.17237666365081e+39*cos(theta)**69 + 1.55866172817274e+40*cos(theta)**67 - 4.44671107224507e+40*cos(theta)**65 + 1.00753366342808e+41*cos(theta)**63 - 1.86160193441347e+41*cos(theta)**61 + 2.85799625836967e+41*cos(theta)**59 - 3.69616900836773e+41*cos(theta)**57 + 4.06833499127924e+41*cos(theta)**55 - 3.84073583092795e+41*cos(theta)**53 + 3.12797516254061e+41*cos(theta)**51 - 2.20706603887066e+41*cos(theta)**49 + 1.35323757127836e+41*cos(theta)**47 - 7.2239497014909e+40*cos(theta)**45 + 3.36076607353195e+40*cos(theta)**43 - 1.36271745145907e+40*cos(theta)**41 + 4.8123527570906e+39*cos(theta)**39 - 1.47780911438215e+39*cos(theta)**37 + 3.93688348071406e+38*cos(theta)**35 - 9.06870178484268e+37*cos(theta)**33 + 1.79875076724152e+37*cos(theta)**31 - 3.0559704302788e+36*cos(theta)**29 + 4.41853274463388e+35*cos(theta)**27 - 5.39445215083997e+34*cos(theta)**25 + 5.50829014721577e+33*cos(theta)**23 - 4.64997466548411e+32*cos(theta)**21 + 3.19952385239733e+31*cos(theta)**19 - 1.76319232600691e+30*cos(theta)**17 + 7.61251289958537e+28*cos(theta)**15 - 2.50333183356237e+27*cos(theta)**13 + 6.04145677654284e+25*cos(theta)**11 - 1.01708026541125e+24*cos(theta)**9 + 1.11021496527608e+22*cos(theta)**7 - 7.01188399121734e+19*cos(theta)**5 + 2.0943500571139e+17*cos(theta)**3 - 186606776695625.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl82_m_minus_6(theta, phi):
    return 1.63385329817958e-11*(1.0 - cos(theta)**2)**3*(7.58432664560011e+34*cos(theta)**76 - 1.32609392269695e+36*cos(theta)**74 + 1.11235393950449e+37*cos(theta)**72 - 5.96053809092974e+37*cos(theta)**70 + 2.29214960025403e+38*cos(theta)**68 - 6.73744101855314e+38*cos(theta)**66 + 1.57427134910637e+39*cos(theta)**64 - 3.00258376518301e+39*cos(theta)**62 + 4.76332709728278e+39*cos(theta)**60 - 6.37270518684091e+39*cos(theta)**58 + 7.26488391299863e+39*cos(theta)**56 - 7.11247376097768e+39*cos(theta)**54 + 6.01533685103964e+39*cos(theta)**52 - 4.41413207774132e+39*cos(theta)**50 + 2.81924494016325e+39*cos(theta)**48 - 1.5704238481502e+39*cos(theta)**46 + 7.63810471257261e+38*cos(theta)**44 - 3.24456536061684e+38*cos(theta)**42 + 1.20308818927265e+38*cos(theta)**40 - 3.88897135363725e+37*cos(theta)**38 + 1.09357874464279e+37*cos(theta)**36 - 2.66726523083608e+36*cos(theta)**34 + 5.62109614762976e+35*cos(theta)**32 - 1.01865681009293e+35*cos(theta)**30 + 1.57804740879782e+34*cos(theta)**28 - 2.07478928878461e+33*cos(theta)**26 + 2.29512089467324e+32*cos(theta)**24 - 2.11362484794732e+31*cos(theta)**22 + 1.59976192619866e+30*cos(theta)**20 - 9.79551292226059e+28*cos(theta)**18 + 4.75782056224086e+27*cos(theta)**16 - 1.78809416683026e+26*cos(theta)**14 + 5.0345473137857e+24*cos(theta)**12 - 1.01708026541125e+23*cos(theta)**10 + 1.3877687065951e+21*cos(theta)**8 - 1.16864733186956e+19*cos(theta)**6 + 5.23587514278476e+16*cos(theta)**4 - 93303388347812.7*cos(theta)**2 + 27588228370.1398)*sin(6*phi)

#@torch.jit.script
def Yl82_m_minus_5(theta, phi):
    return 1.34493023764849e-9*(1.0 - cos(theta)**2)**2.5*(9.84977486441573e+32*cos(theta)**77 - 1.7681252302626e+34*cos(theta)**75 + 1.52377251986917e+35*cos(theta)**73 - 8.39512407173202e+35*cos(theta)**71 + 3.32195594239715e+36*cos(theta)**69 - 1.00558821172435e+37*cos(theta)**67 + 2.42195592170211e+37*cos(theta)**65 - 4.76600597648097e+37*cos(theta)**63 + 7.80873294636521e+37*cos(theta)**61 - 1.08011952319337e+38*cos(theta)**59 + 1.27454103736818e+38*cos(theta)**57 - 1.29317704745049e+38*cos(theta)**55 + 1.13496921717729e+38*cos(theta)**53 - 8.65516093674768e+37*cos(theta)**51 + 5.75356110237398e+37*cos(theta)**49 - 3.34132733648978e+37*cos(theta)**47 + 1.69735660279391e+37*cos(theta)**45 - 7.5455008386438e+36*cos(theta)**43 + 2.93436143725037e+36*cos(theta)**41 - 9.97172141958268e+35*cos(theta)**39 + 2.95561822876431e+35*cos(theta)**37 - 7.62075780238881e+34*cos(theta)**35 + 1.70336246897872e+34*cos(theta)**33 - 3.28598970997721e+33*cos(theta)**31 + 5.44154278895798e+32*cos(theta)**29 - 7.68440477327632e+31*cos(theta)**27 + 9.18048357869294e+30*cos(theta)**25 - 9.18967325194489e+29*cos(theta)**23 + 7.61791393427935e+28*cos(theta)**21 - 5.15553311697926e+27*cos(theta)**19 + 2.79871797778874e+26*cos(theta)**17 - 1.19206277788684e+25*cos(theta)**15 + 3.87272870291208e+23*cos(theta)**13 - 9.24618423101139e+21*cos(theta)**11 + 1.54196522955011e+20*cos(theta)**9 - 1.66949618838508e+18*cos(theta)**7 + 1.04717502855695e+16*cos(theta)**5 - 31101129449270.9*cos(theta)**3 + 27588228370.1398*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl82_m_minus_4(theta, phi):
    return 1.10791562031331e-7*(1.0 - cos(theta)**2)**2*(1.26279164928407e+31*cos(theta)**78 - 2.326480566135e+32*cos(theta)**76 + 2.05915205387725e+33*cos(theta)**74 - 1.16598945440723e+34*cos(theta)**72 + 4.74565134628164e+34*cos(theta)**70 - 1.47880619371228e+35*cos(theta)**68 + 3.66963018439713e+35*cos(theta)**66 - 7.44688433825152e+35*cos(theta)**64 + 1.25947305586536e+36*cos(theta)**62 - 1.80019920532229e+36*cos(theta)**60 + 2.19748454718652e+36*cos(theta)**58 - 2.30924472759016e+36*cos(theta)**56 + 2.10179484662461e+36*cos(theta)**54 - 1.66445402629763e+36*cos(theta)**52 + 1.1507122204748e+36*cos(theta)**50 - 6.96109861768704e+35*cos(theta)**48 + 3.68990565824764e+35*cos(theta)**46 - 1.71488655423723e+35*cos(theta)**44 + 6.98657485059611e+34*cos(theta)**42 - 2.49293035489567e+34*cos(theta)**40 + 7.77794270727449e+33*cos(theta)**38 - 2.11687716733022e+33*cos(theta)**36 + 5.00988961464328e+32*cos(theta)**34 - 1.02687178436788e+32*cos(theta)**32 + 1.81384759631933e+31*cos(theta)**30 - 2.74443027617011e+30*cos(theta)**28 + 3.53095522257421e+29*cos(theta)**26 - 3.8290305216437e+28*cos(theta)**24 + 3.46268815194516e+27*cos(theta)**22 - 2.57776655848963e+26*cos(theta)**20 + 1.55484332099374e+25*cos(theta)**18 - 7.45039236179276e+23*cos(theta)**16 + 2.76623478779434e+22*cos(theta)**14 - 7.70515352584282e+20*cos(theta)**12 + 1.54196522955011e+19*cos(theta)**10 - 2.08687023548135e+17*cos(theta)**8 + 1.74529171426159e+15*cos(theta)**6 - 7775282362317.72*cos(theta)**4 + 13794114185.0699*cos(theta)**2 - 4065462.47717945)*sin(4*phi)

#@torch.jit.script
def Yl82_m_minus_3(theta, phi):
    return 9.13207472903193e-6*(1.0 - cos(theta)**2)**1.5*(1.59847044213173e+29*cos(theta)**79 - 3.02140333264286e+30*cos(theta)**77 + 2.74553607183634e+31*cos(theta)**75 - 1.5972458279551e+32*cos(theta)**73 + 6.68401598067836e+32*cos(theta)**71 - 2.14319738219171e+33*cos(theta)**69 + 5.47705997671214e+33*cos(theta)**67 - 1.14567451357716e+34*cos(theta)**65 + 1.99916358073866e+34*cos(theta)**63 - 2.95114623823326e+34*cos(theta)**61 + 3.72455007997715e+34*cos(theta)**59 - 4.05130653963185e+34*cos(theta)**57 + 3.82144517568111e+34*cos(theta)**55 - 3.14047929490119e+34*cos(theta)**53 + 2.25629847151921e+34*cos(theta)**51 - 1.42063237095654e+34*cos(theta)**49 + 7.85086310265455e+33*cos(theta)**47 - 3.81085900941606e+33*cos(theta)**45 + 1.62478484897584e+33*cos(theta)**43 - 6.08031793876993e+32*cos(theta)**41 + 1.99434428391654e+32*cos(theta)**39 - 5.72128964143304e+31*cos(theta)**37 + 1.43139703275522e+31*cos(theta)**35 - 3.11173267990266e+30*cos(theta)**33 + 5.85112127844944e+29*cos(theta)**31 - 9.46355267644866e+28*cos(theta)**29 + 1.307761193546e+28*cos(theta)**27 - 1.53161220865748e+27*cos(theta)**25 + 1.50551658780224e+26*cos(theta)**23 - 1.22750788499506e+25*cos(theta)**21 + 8.18338589996707e+23*cos(theta)**19 - 4.38258374223103e+22*cos(theta)**17 + 1.84415652519623e+21*cos(theta)**15 - 5.92704117372525e+19*cos(theta)**13 + 1.40178657231828e+18*cos(theta)**11 - 2.31874470609039e+16*cos(theta)**9 + 249327387751655.0*cos(theta)**7 - 1555056472463.54*cos(theta)**5 + 4598038061.68996*cos(theta)**3 - 4065462.47717945*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl82_m_minus_2(theta, phi):
    return 0.000753050173776649*(1.0 - cos(theta)**2)*(1.99808805266466e+27*cos(theta)**80 - 3.8735940162088e+28*cos(theta)**78 + 3.61254746294255e+29*cos(theta)**76 - 2.15844030804744e+30*cos(theta)**74 + 9.28335552871995e+30*cos(theta)**72 - 3.06171054598815e+31*cos(theta)**70 + 8.05449996575315e+31*cos(theta)**68 - 1.7358704751169e+32*cos(theta)**66 + 3.12369309490416e+32*cos(theta)**64 - 4.759913287473e+32*cos(theta)**62 + 6.20758346662859e+32*cos(theta)**60 - 6.98501127522734e+32*cos(theta)**58 + 6.8240092422877e+32*cos(theta)**56 - 5.81570239796517e+32*cos(theta)**54 + 4.33903552215232e+32*cos(theta)**52 - 2.84126474191308e+32*cos(theta)**50 + 1.6355964797197e+32*cos(theta)**48 - 8.28447610742622e+31*cos(theta)**46 + 3.69269283858146e+31*cos(theta)**44 - 1.44769474732617e+31*cos(theta)**42 + 4.98586070979134e+30*cos(theta)**40 - 1.50560253721922e+30*cos(theta)**38 + 3.97610286876451e+29*cos(theta)**36 - 9.15215494089017e+28*cos(theta)**34 + 1.82847539951545e+28*cos(theta)**32 - 3.15451755881622e+27*cos(theta)**30 + 4.67057569123573e+26*cos(theta)**28 - 5.89081618714416e+25*cos(theta)**26 + 6.27298578250934e+24*cos(theta)**24 - 5.5795812954321e+23*cos(theta)**22 + 4.09169294998354e+22*cos(theta)**20 - 2.43476874568391e+21*cos(theta)**18 + 1.15259782824764e+20*cos(theta)**16 - 4.23360083837518e+18*cos(theta)**14 + 1.1681554769319e+17*cos(theta)**12 - 2.31874470609039e+15*cos(theta)**10 + 31165923468956.9*cos(theta)**8 - 259176078743.924*cos(theta)**6 + 1149509515.42249*cos(theta)**4 - 2032731.23858973*cos(theta)**2 + 597.862128996978)*sin(2*phi)

#@torch.jit.script
def Yl82_m_minus_1(theta, phi):
    return 0.0621163696217606*(1.0 - cos(theta)**2)**0.5*(2.46677537366008e+25*cos(theta)**81 - 4.90328356482126e+26*cos(theta)**79 + 4.69162008174357e+27*cos(theta)**77 - 2.87792041072992e+28*cos(theta)**75 + 1.27169253818081e+29*cos(theta)**73 - 4.3122683746312e+29*cos(theta)**71 + 1.1673188356164e+30*cos(theta)**69 - 2.59085145539836e+30*cos(theta)**67 + 4.80568168446794e+30*cos(theta)**65 - 7.55541791662382e+30*cos(theta)**63 + 1.01763663387354e+31*cos(theta)**61 - 1.18390021614023e+31*cos(theta)**59 + 1.19719460391012e+31*cos(theta)**57 - 1.05740043599367e+31*cos(theta)**55 + 8.1868594757591e+30*cos(theta)**53 - 5.57110733708446e+30*cos(theta)**51 + 3.33795199942796e+30*cos(theta)**49 - 1.76265449094175e+30*cos(theta)**47 + 8.20598408573657e+29*cos(theta)**45 - 3.36673197052599e+29*cos(theta)**43 + 1.21606358775399e+29*cos(theta)**41 - 3.86051932620313e+28*cos(theta)**39 + 1.07462239696338e+28*cos(theta)**37 - 2.61490141168291e+27*cos(theta)**35 + 5.54083454398622e+26*cos(theta)**33 - 1.01758630929556e+26*cos(theta)**31 + 1.61054334180542e+25*cos(theta)**29 - 2.18178377301636e+24*cos(theta)**27 + 2.50919431300374e+23*cos(theta)**25 - 2.42590491105743e+22*cos(theta)**23 + 1.94842521427787e+21*cos(theta)**21 - 1.28145723457048e+20*cos(theta)**19 + 6.77998722498613e+18*cos(theta)**17 - 2.82240055891679e+17*cos(theta)**15 + 8.98581136101463e+15*cos(theta)**13 - 210794973280945.0*cos(theta)**11 + 3462880385439.65*cos(theta)**9 - 37025154106.2749*cos(theta)**7 + 229901903.084498*cos(theta)**5 - 677577.079529909*cos(theta)**3 + 597.862128996978*cos(theta))*sin(phi)

#@torch.jit.script
def Yl82_m0(theta, phi):
    return 3.42454332144106e+24*cos(theta)**82 - 6.97724439908328e+25*cos(theta)**80 + 6.84723363388297e+26*cos(theta)**78 - 4.31074268397286e+27*cos(theta)**76 + 1.95630838365011e+28*cos(theta)**74 - 6.81805025063088e+28*cos(theta)**72 + 1.89835908939134e+29*cos(theta)**70 - 4.33731050225175e+29*cos(theta)**68 + 8.28892057393413e+29*cos(theta)**66 - 1.34389528579658e+30*cos(theta)**64 + 1.86847785942476e+30*cos(theta)**62 - 2.24621209928303e+30*cos(theta)**60 + 2.34976088400176e+30*cos(theta)**58 - 2.14950456073874e+30*cos(theta)**56 + 1.72587957431578e+30*cos(theta)**54 - 1.21962156584982e+30*cos(theta)**52 + 7.59970956915816e+29*cos(theta)**50 - 4.18035214289122e+29*cos(theta)**48 + 2.03076538207635e+29*cos(theta)**46 - 8.71049386841702e+28*cos(theta)**44 + 3.296050879809e+28*cos(theta)**42 - 1.098683626603e+28*cos(theta)**40 + 3.21928335368272e+27*cos(theta)**38 - 8.26874752516972e+26*cos(theta)**36 + 1.85516771398039e+26*cos(theta)**34 - 3.61999682623651e+25*cos(theta)**32 + 6.11136291971854e+24*cos(theta)**30 - 8.87034658017206e+23*cos(theta)**28 + 1.09862090671856e+23*cos(theta)**26 - 1.1506664346875e+22*cos(theta)**24 + 1.00820297134524e+21*cos(theta)**22 - 7.29392065082211e+19*cos(theta)**20 + 4.28788652121349e+18*cos(theta)**18 - 2.00810112563717e+17*cos(theta)**16 + 7.30661416241543e+15*cos(theta)**14 - 199970492866106.0*cos(theta)**12 + 3942070647898.16*cos(theta)**10 - 52685826894.9857*cos(theta)**8 + 436192534.90822*cos(theta)**6 - 1928348.96069063*cos(theta)**4 + 3402.96875415993*cos(theta)**2 - 0.999990818148673

#@torch.jit.script
def Yl82_m1(theta, phi):
    return 0.0621163696217606*(1.0 - cos(theta)**2)**0.5*(2.46677537366008e+25*cos(theta)**81 - 4.90328356482126e+26*cos(theta)**79 + 4.69162008174357e+27*cos(theta)**77 - 2.87792041072992e+28*cos(theta)**75 + 1.27169253818081e+29*cos(theta)**73 - 4.3122683746312e+29*cos(theta)**71 + 1.1673188356164e+30*cos(theta)**69 - 2.59085145539836e+30*cos(theta)**67 + 4.80568168446794e+30*cos(theta)**65 - 7.55541791662382e+30*cos(theta)**63 + 1.01763663387354e+31*cos(theta)**61 - 1.18390021614023e+31*cos(theta)**59 + 1.19719460391012e+31*cos(theta)**57 - 1.05740043599367e+31*cos(theta)**55 + 8.1868594757591e+30*cos(theta)**53 - 5.57110733708446e+30*cos(theta)**51 + 3.33795199942796e+30*cos(theta)**49 - 1.76265449094175e+30*cos(theta)**47 + 8.20598408573657e+29*cos(theta)**45 - 3.36673197052599e+29*cos(theta)**43 + 1.21606358775399e+29*cos(theta)**41 - 3.86051932620313e+28*cos(theta)**39 + 1.07462239696338e+28*cos(theta)**37 - 2.61490141168291e+27*cos(theta)**35 + 5.54083454398622e+26*cos(theta)**33 - 1.01758630929556e+26*cos(theta)**31 + 1.61054334180542e+25*cos(theta)**29 - 2.18178377301636e+24*cos(theta)**27 + 2.50919431300374e+23*cos(theta)**25 - 2.42590491105743e+22*cos(theta)**23 + 1.94842521427787e+21*cos(theta)**21 - 1.28145723457048e+20*cos(theta)**19 + 6.77998722498613e+18*cos(theta)**17 - 2.82240055891679e+17*cos(theta)**15 + 8.98581136101463e+15*cos(theta)**13 - 210794973280945.0*cos(theta)**11 + 3462880385439.65*cos(theta)**9 - 37025154106.2749*cos(theta)**7 + 229901903.084498*cos(theta)**5 - 677577.079529909*cos(theta)**3 + 597.862128996978*cos(theta))*cos(phi)

#@torch.jit.script
def Yl82_m2(theta, phi):
    return 0.000753050173776649*(1.0 - cos(theta)**2)*(1.99808805266466e+27*cos(theta)**80 - 3.8735940162088e+28*cos(theta)**78 + 3.61254746294255e+29*cos(theta)**76 - 2.15844030804744e+30*cos(theta)**74 + 9.28335552871995e+30*cos(theta)**72 - 3.06171054598815e+31*cos(theta)**70 + 8.05449996575315e+31*cos(theta)**68 - 1.7358704751169e+32*cos(theta)**66 + 3.12369309490416e+32*cos(theta)**64 - 4.759913287473e+32*cos(theta)**62 + 6.20758346662859e+32*cos(theta)**60 - 6.98501127522734e+32*cos(theta)**58 + 6.8240092422877e+32*cos(theta)**56 - 5.81570239796517e+32*cos(theta)**54 + 4.33903552215232e+32*cos(theta)**52 - 2.84126474191308e+32*cos(theta)**50 + 1.6355964797197e+32*cos(theta)**48 - 8.28447610742622e+31*cos(theta)**46 + 3.69269283858146e+31*cos(theta)**44 - 1.44769474732617e+31*cos(theta)**42 + 4.98586070979134e+30*cos(theta)**40 - 1.50560253721922e+30*cos(theta)**38 + 3.97610286876451e+29*cos(theta)**36 - 9.15215494089017e+28*cos(theta)**34 + 1.82847539951545e+28*cos(theta)**32 - 3.15451755881622e+27*cos(theta)**30 + 4.67057569123573e+26*cos(theta)**28 - 5.89081618714416e+25*cos(theta)**26 + 6.27298578250934e+24*cos(theta)**24 - 5.5795812954321e+23*cos(theta)**22 + 4.09169294998354e+22*cos(theta)**20 - 2.43476874568391e+21*cos(theta)**18 + 1.15259782824764e+20*cos(theta)**16 - 4.23360083837518e+18*cos(theta)**14 + 1.1681554769319e+17*cos(theta)**12 - 2.31874470609039e+15*cos(theta)**10 + 31165923468956.9*cos(theta)**8 - 259176078743.924*cos(theta)**6 + 1149509515.42249*cos(theta)**4 - 2032731.23858973*cos(theta)**2 + 597.862128996978)*cos(2*phi)

#@torch.jit.script
def Yl82_m3(theta, phi):
    return 9.13207472903193e-6*(1.0 - cos(theta)**2)**1.5*(1.59847044213173e+29*cos(theta)**79 - 3.02140333264286e+30*cos(theta)**77 + 2.74553607183634e+31*cos(theta)**75 - 1.5972458279551e+32*cos(theta)**73 + 6.68401598067836e+32*cos(theta)**71 - 2.14319738219171e+33*cos(theta)**69 + 5.47705997671214e+33*cos(theta)**67 - 1.14567451357716e+34*cos(theta)**65 + 1.99916358073866e+34*cos(theta)**63 - 2.95114623823326e+34*cos(theta)**61 + 3.72455007997715e+34*cos(theta)**59 - 4.05130653963185e+34*cos(theta)**57 + 3.82144517568111e+34*cos(theta)**55 - 3.14047929490119e+34*cos(theta)**53 + 2.25629847151921e+34*cos(theta)**51 - 1.42063237095654e+34*cos(theta)**49 + 7.85086310265455e+33*cos(theta)**47 - 3.81085900941606e+33*cos(theta)**45 + 1.62478484897584e+33*cos(theta)**43 - 6.08031793876993e+32*cos(theta)**41 + 1.99434428391654e+32*cos(theta)**39 - 5.72128964143304e+31*cos(theta)**37 + 1.43139703275522e+31*cos(theta)**35 - 3.11173267990266e+30*cos(theta)**33 + 5.85112127844944e+29*cos(theta)**31 - 9.46355267644866e+28*cos(theta)**29 + 1.307761193546e+28*cos(theta)**27 - 1.53161220865748e+27*cos(theta)**25 + 1.50551658780224e+26*cos(theta)**23 - 1.22750788499506e+25*cos(theta)**21 + 8.18338589996707e+23*cos(theta)**19 - 4.38258374223103e+22*cos(theta)**17 + 1.84415652519623e+21*cos(theta)**15 - 5.92704117372525e+19*cos(theta)**13 + 1.40178657231828e+18*cos(theta)**11 - 2.31874470609039e+16*cos(theta)**9 + 249327387751655.0*cos(theta)**7 - 1555056472463.54*cos(theta)**5 + 4598038061.68996*cos(theta)**3 - 4065462.47717945*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl82_m4(theta, phi):
    return 1.10791562031331e-7*(1.0 - cos(theta)**2)**2*(1.26279164928407e+31*cos(theta)**78 - 2.326480566135e+32*cos(theta)**76 + 2.05915205387725e+33*cos(theta)**74 - 1.16598945440723e+34*cos(theta)**72 + 4.74565134628164e+34*cos(theta)**70 - 1.47880619371228e+35*cos(theta)**68 + 3.66963018439713e+35*cos(theta)**66 - 7.44688433825152e+35*cos(theta)**64 + 1.25947305586536e+36*cos(theta)**62 - 1.80019920532229e+36*cos(theta)**60 + 2.19748454718652e+36*cos(theta)**58 - 2.30924472759016e+36*cos(theta)**56 + 2.10179484662461e+36*cos(theta)**54 - 1.66445402629763e+36*cos(theta)**52 + 1.1507122204748e+36*cos(theta)**50 - 6.96109861768704e+35*cos(theta)**48 + 3.68990565824764e+35*cos(theta)**46 - 1.71488655423723e+35*cos(theta)**44 + 6.98657485059611e+34*cos(theta)**42 - 2.49293035489567e+34*cos(theta)**40 + 7.77794270727449e+33*cos(theta)**38 - 2.11687716733022e+33*cos(theta)**36 + 5.00988961464328e+32*cos(theta)**34 - 1.02687178436788e+32*cos(theta)**32 + 1.81384759631933e+31*cos(theta)**30 - 2.74443027617011e+30*cos(theta)**28 + 3.53095522257421e+29*cos(theta)**26 - 3.8290305216437e+28*cos(theta)**24 + 3.46268815194516e+27*cos(theta)**22 - 2.57776655848963e+26*cos(theta)**20 + 1.55484332099374e+25*cos(theta)**18 - 7.45039236179276e+23*cos(theta)**16 + 2.76623478779434e+22*cos(theta)**14 - 7.70515352584282e+20*cos(theta)**12 + 1.54196522955011e+19*cos(theta)**10 - 2.08687023548135e+17*cos(theta)**8 + 1.74529171426159e+15*cos(theta)**6 - 7775282362317.72*cos(theta)**4 + 13794114185.0699*cos(theta)**2 - 4065462.47717945)*cos(4*phi)

#@torch.jit.script
def Yl82_m5(theta, phi):
    return 1.34493023764849e-9*(1.0 - cos(theta)**2)**2.5*(9.84977486441573e+32*cos(theta)**77 - 1.7681252302626e+34*cos(theta)**75 + 1.52377251986917e+35*cos(theta)**73 - 8.39512407173202e+35*cos(theta)**71 + 3.32195594239715e+36*cos(theta)**69 - 1.00558821172435e+37*cos(theta)**67 + 2.42195592170211e+37*cos(theta)**65 - 4.76600597648097e+37*cos(theta)**63 + 7.80873294636521e+37*cos(theta)**61 - 1.08011952319337e+38*cos(theta)**59 + 1.27454103736818e+38*cos(theta)**57 - 1.29317704745049e+38*cos(theta)**55 + 1.13496921717729e+38*cos(theta)**53 - 8.65516093674768e+37*cos(theta)**51 + 5.75356110237398e+37*cos(theta)**49 - 3.34132733648978e+37*cos(theta)**47 + 1.69735660279391e+37*cos(theta)**45 - 7.5455008386438e+36*cos(theta)**43 + 2.93436143725037e+36*cos(theta)**41 - 9.97172141958268e+35*cos(theta)**39 + 2.95561822876431e+35*cos(theta)**37 - 7.62075780238881e+34*cos(theta)**35 + 1.70336246897872e+34*cos(theta)**33 - 3.28598970997721e+33*cos(theta)**31 + 5.44154278895798e+32*cos(theta)**29 - 7.68440477327632e+31*cos(theta)**27 + 9.18048357869294e+30*cos(theta)**25 - 9.18967325194489e+29*cos(theta)**23 + 7.61791393427935e+28*cos(theta)**21 - 5.15553311697926e+27*cos(theta)**19 + 2.79871797778874e+26*cos(theta)**17 - 1.19206277788684e+25*cos(theta)**15 + 3.87272870291208e+23*cos(theta)**13 - 9.24618423101139e+21*cos(theta)**11 + 1.54196522955011e+20*cos(theta)**9 - 1.66949618838508e+18*cos(theta)**7 + 1.04717502855695e+16*cos(theta)**5 - 31101129449270.9*cos(theta)**3 + 27588228370.1398*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl82_m6(theta, phi):
    return 1.63385329817958e-11*(1.0 - cos(theta)**2)**3*(7.58432664560011e+34*cos(theta)**76 - 1.32609392269695e+36*cos(theta)**74 + 1.11235393950449e+37*cos(theta)**72 - 5.96053809092974e+37*cos(theta)**70 + 2.29214960025403e+38*cos(theta)**68 - 6.73744101855314e+38*cos(theta)**66 + 1.57427134910637e+39*cos(theta)**64 - 3.00258376518301e+39*cos(theta)**62 + 4.76332709728278e+39*cos(theta)**60 - 6.37270518684091e+39*cos(theta)**58 + 7.26488391299863e+39*cos(theta)**56 - 7.11247376097768e+39*cos(theta)**54 + 6.01533685103964e+39*cos(theta)**52 - 4.41413207774132e+39*cos(theta)**50 + 2.81924494016325e+39*cos(theta)**48 - 1.5704238481502e+39*cos(theta)**46 + 7.63810471257261e+38*cos(theta)**44 - 3.24456536061684e+38*cos(theta)**42 + 1.20308818927265e+38*cos(theta)**40 - 3.88897135363725e+37*cos(theta)**38 + 1.09357874464279e+37*cos(theta)**36 - 2.66726523083608e+36*cos(theta)**34 + 5.62109614762976e+35*cos(theta)**32 - 1.01865681009293e+35*cos(theta)**30 + 1.57804740879782e+34*cos(theta)**28 - 2.07478928878461e+33*cos(theta)**26 + 2.29512089467324e+32*cos(theta)**24 - 2.11362484794732e+31*cos(theta)**22 + 1.59976192619866e+30*cos(theta)**20 - 9.79551292226059e+28*cos(theta)**18 + 4.75782056224086e+27*cos(theta)**16 - 1.78809416683026e+26*cos(theta)**14 + 5.0345473137857e+24*cos(theta)**12 - 1.01708026541125e+23*cos(theta)**10 + 1.3877687065951e+21*cos(theta)**8 - 1.16864733186956e+19*cos(theta)**6 + 5.23587514278476e+16*cos(theta)**4 - 93303388347812.7*cos(theta)**2 + 27588228370.1398)*cos(6*phi)

#@torch.jit.script
def Yl82_m7(theta, phi):
    return 1.98660379002153e-13*(1.0 - cos(theta)**2)**3.5*(5.76408825065609e+36*cos(theta)**75 - 9.81309502795744e+37*cos(theta)**73 + 8.00894836443235e+38*cos(theta)**71 - 4.17237666365081e+39*cos(theta)**69 + 1.55866172817274e+40*cos(theta)**67 - 4.44671107224507e+40*cos(theta)**65 + 1.00753366342808e+41*cos(theta)**63 - 1.86160193441347e+41*cos(theta)**61 + 2.85799625836967e+41*cos(theta)**59 - 3.69616900836773e+41*cos(theta)**57 + 4.06833499127924e+41*cos(theta)**55 - 3.84073583092795e+41*cos(theta)**53 + 3.12797516254061e+41*cos(theta)**51 - 2.20706603887066e+41*cos(theta)**49 + 1.35323757127836e+41*cos(theta)**47 - 7.2239497014909e+40*cos(theta)**45 + 3.36076607353195e+40*cos(theta)**43 - 1.36271745145907e+40*cos(theta)**41 + 4.8123527570906e+39*cos(theta)**39 - 1.47780911438215e+39*cos(theta)**37 + 3.93688348071406e+38*cos(theta)**35 - 9.06870178484268e+37*cos(theta)**33 + 1.79875076724152e+37*cos(theta)**31 - 3.0559704302788e+36*cos(theta)**29 + 4.41853274463388e+35*cos(theta)**27 - 5.39445215083997e+34*cos(theta)**25 + 5.50829014721577e+33*cos(theta)**23 - 4.64997466548411e+32*cos(theta)**21 + 3.19952385239733e+31*cos(theta)**19 - 1.76319232600691e+30*cos(theta)**17 + 7.61251289958537e+28*cos(theta)**15 - 2.50333183356237e+27*cos(theta)**13 + 6.04145677654284e+25*cos(theta)**11 - 1.01708026541125e+24*cos(theta)**9 + 1.11021496527608e+22*cos(theta)**7 - 7.01188399121734e+19*cos(theta)**5 + 2.0943500571139e+17*cos(theta)**3 - 186606776695625.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl82_m8(theta, phi):
    return 2.41801713026678e-15*(1.0 - cos(theta)**2)**4*(4.32306618799206e+38*cos(theta)**74 - 7.16355937040893e+39*cos(theta)**72 + 5.68635333874697e+40*cos(theta)**70 - 2.87893989791906e+41*cos(theta)**68 + 1.04430335787574e+42*cos(theta)**66 - 2.8903621969593e+42*cos(theta)**64 + 6.34746207959688e+42*cos(theta)**62 - 1.13557717999221e+43*cos(theta)**60 + 1.6862177924381e+43*cos(theta)**58 - 2.1068163347696e+43*cos(theta)**56 + 2.23758424520358e+43*cos(theta)**54 - 2.03558999039181e+43*cos(theta)**52 + 1.59526733289571e+43*cos(theta)**50 - 1.08146235904662e+43*cos(theta)**48 + 6.36021658500829e+42*cos(theta)**46 - 3.2507773656709e+42*cos(theta)**44 + 1.44512941161874e+42*cos(theta)**42 - 5.58714155098219e+41*cos(theta)**40 + 1.87681757526534e+41*cos(theta)**38 - 5.46789372321397e+40*cos(theta)**36 + 1.37790921824992e+40*cos(theta)**34 - 2.99267158899808e+39*cos(theta)**32 + 5.57612737844872e+38*cos(theta)**30 - 8.86231424780853e+37*cos(theta)**28 + 1.19300384105115e+37*cos(theta)**26 - 1.34861303770999e+36*cos(theta)**24 + 1.26690673385963e+35*cos(theta)**22 - 9.76494679751664e+33*cos(theta)**20 + 6.07909531955492e+32*cos(theta)**18 - 2.99742695421174e+31*cos(theta)**16 + 1.14187693493781e+30*cos(theta)**14 - 3.25433138363108e+28*cos(theta)**12 + 6.64560245419713e+26*cos(theta)**10 - 9.15372238870127e+24*cos(theta)**8 + 7.77150475693256e+22*cos(theta)**6 - 3.50594199560867e+20*cos(theta)**4 + 6.28305017134171e+17*cos(theta)**2 - 186606776695625.0)*cos(8*phi)

#@torch.jit.script
def Yl82_m9(theta, phi):
    return 2.94661107770915e-17*(1.0 - cos(theta)**2)**4.5*(3.19906897911413e+40*cos(theta)**73 - 5.15776274669443e+41*cos(theta)**71 + 3.98044733712288e+42*cos(theta)**69 - 1.95767913058496e+43*cos(theta)**67 + 6.89240216197986e+43*cos(theta)**65 - 1.84983180605395e+44*cos(theta)**63 + 3.93542648935007e+44*cos(theta)**61 - 6.81346307995329e+44*cos(theta)**59 + 9.780063196141e+44*cos(theta)**57 - 1.17981714747098e+45*cos(theta)**55 + 1.20829549240993e+45*cos(theta)**53 - 1.05850679500374e+45*cos(theta)**51 + 7.97633666447856e+44*cos(theta)**49 - 5.19101932342379e+44*cos(theta)**47 + 2.92569962910381e+44*cos(theta)**45 - 1.4303420408952e+44*cos(theta)**43 + 6.0695435287987e+43*cos(theta)**41 - 2.23485662039288e+43*cos(theta)**39 + 7.13190678600827e+42*cos(theta)**37 - 1.96844174035703e+42*cos(theta)**35 + 4.68489134204973e+41*cos(theta)**33 - 9.57654908479387e+40*cos(theta)**31 + 1.67283821353462e+40*cos(theta)**29 - 2.48144798938639e+39*cos(theta)**27 + 3.10180998673299e+38*cos(theta)**25 - 3.23667129050398e+37*cos(theta)**23 + 2.78719481449118e+36*cos(theta)**21 - 1.95298935950333e+35*cos(theta)**19 + 1.09423715751989e+34*cos(theta)**17 - 4.79588312673878e+32*cos(theta)**15 + 1.59862770891293e+31*cos(theta)**13 - 3.90519766035729e+29*cos(theta)**11 + 6.64560245419713e+27*cos(theta)**9 - 7.32297791096102e+25*cos(theta)**7 + 4.66290285415953e+23*cos(theta)**5 - 1.40237679824347e+21*cos(theta)**3 + 1.25661003426834e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl82_m10(theta, phi):
    return 3.59556772584124e-19*(1.0 - cos(theta)**2)**5*(2.33532035475331e+42*cos(theta)**72 - 3.66201155015305e+43*cos(theta)**70 + 2.74650866261479e+44*cos(theta)**68 - 1.31164501749192e+45*cos(theta)**66 + 4.48006140528691e+45*cos(theta)**64 - 1.16539403781399e+46*cos(theta)**62 + 2.40061015850354e+46*cos(theta)**60 - 4.01994321717244e+46*cos(theta)**58 + 5.57463602180037e+46*cos(theta)**56 - 6.48899431109038e+46*cos(theta)**54 + 6.40396610977264e+46*cos(theta)**52 - 5.39838465451909e+46*cos(theta)**50 + 3.90840496559449e+46*cos(theta)**48 - 2.43977908200918e+46*cos(theta)**46 + 1.31656483309672e+46*cos(theta)**44 - 6.15047077584935e+45*cos(theta)**42 + 2.48851284680747e+45*cos(theta)**40 - 8.71594081953222e+44*cos(theta)**38 + 2.63880551082306e+44*cos(theta)**36 - 6.8895460912496e+43*cos(theta)**34 + 1.54601414287641e+43*cos(theta)**32 - 2.9687302162861e+42*cos(theta)**30 + 4.85123081925039e+41*cos(theta)**28 - 6.69990957134325e+40*cos(theta)**26 + 7.75452496683246e+39*cos(theta)**24 - 7.44434396815916e+38*cos(theta)**22 + 5.85310911043147e+37*cos(theta)**20 - 3.71067978305632e+36*cos(theta)**18 + 1.86020316778381e+35*cos(theta)**16 - 7.19382469010817e+33*cos(theta)**14 + 2.07821602158681e+32*cos(theta)**12 - 4.29571742639302e+30*cos(theta)**10 + 5.98104220877741e+28*cos(theta)**8 - 5.12608453767271e+26*cos(theta)**6 + 2.33145142707977e+24*cos(theta)**4 - 4.20713039473041e+21*cos(theta)**2 + 1.25661003426834e+18)*cos(10*phi)

#@torch.jit.script
def Yl82_m11(theta, phi):
    return 4.39399694882089e-21*(1.0 - cos(theta)**2)**5.5*(1.68143065542239e+44*cos(theta)**71 - 2.56340808510713e+45*cos(theta)**69 + 1.86762589057805e+46*cos(theta)**67 - 8.6568571154467e+46*cos(theta)**65 + 2.86723929938362e+47*cos(theta)**63 - 7.22544303444673e+47*cos(theta)**61 + 1.44036609510213e+48*cos(theta)**59 - 2.33156706596002e+48*cos(theta)**57 + 3.12179617220821e+48*cos(theta)**55 - 3.50405692798881e+48*cos(theta)**53 + 3.33006237708178e+48*cos(theta)**51 - 2.69919232725954e+48*cos(theta)**49 + 1.87603438348536e+48*cos(theta)**47 - 1.12229837772422e+48*cos(theta)**45 + 5.79288526562555e+47*cos(theta)**43 - 2.58319772585673e+47*cos(theta)**41 + 9.95405138722987e+46*cos(theta)**39 - 3.31205751142224e+46*cos(theta)**37 + 9.49969983896302e+45*cos(theta)**35 - 2.34244567102486e+45*cos(theta)**33 + 4.94724525720451e+44*cos(theta)**31 - 8.9061906488583e+43*cos(theta)**29 + 1.35834462939011e+43*cos(theta)**27 - 1.74197648854924e+42*cos(theta)**25 + 1.86108599203979e+41*cos(theta)**23 - 1.63775567299502e+40*cos(theta)**21 + 1.17062182208629e+39*cos(theta)**19 - 6.67922360950138e+37*cos(theta)**17 + 2.97632506845409e+36*cos(theta)**15 - 1.00713545661514e+35*cos(theta)**13 + 2.49385922590417e+33*cos(theta)**11 - 4.29571742639302e+31*cos(theta)**9 + 4.78483376702193e+29*cos(theta)**7 - 3.07565072260363e+27*cos(theta)**5 + 9.32580570831907e+24*cos(theta)**3 - 8.41426078946081e+21*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl82_m12(theta, phi):
    return 5.37856782873413e-23*(1.0 - cos(theta)**2)**6*(1.19381576534989e+46*cos(theta)**70 - 1.76875157872392e+47*cos(theta)**68 + 1.2513093466873e+48*cos(theta)**66 - 5.62695712504036e+48*cos(theta)**64 + 1.80636075861168e+49*cos(theta)**62 - 4.4075202510125e+49*cos(theta)**60 + 8.49815996110254e+49*cos(theta)**58 - 1.32899322759721e+50*cos(theta)**56 + 1.71698789471451e+50*cos(theta)**54 - 1.85715017183407e+50*cos(theta)**52 + 1.69833181231171e+50*cos(theta)**50 - 1.32260424035718e+50*cos(theta)**48 + 8.81736160238118e+49*cos(theta)**46 - 5.050342699759e+49*cos(theta)**44 + 2.49094066421899e+49*cos(theta)**42 - 1.05911106760126e+49*cos(theta)**40 + 3.88208004101965e+48*cos(theta)**38 - 1.22546127922623e+48*cos(theta)**36 + 3.32489494363706e+47*cos(theta)**34 - 7.73007071438205e+46*cos(theta)**32 + 1.5336460297334e+46*cos(theta)**30 - 2.58279528816891e+45*cos(theta)**28 + 3.66753049935329e+44*cos(theta)**26 - 4.35494122137311e+43*cos(theta)**24 + 4.28049778169152e+42*cos(theta)**22 - 3.43928691328953e+41*cos(theta)**20 + 2.22418146196396e+40*cos(theta)**18 - 1.13546801361523e+39*cos(theta)**16 + 4.46448760268113e+37*cos(theta)**14 - 1.30927609359969e+36*cos(theta)**12 + 2.74324514849458e+34*cos(theta)**10 - 3.86614568375372e+32*cos(theta)**8 + 3.34938363691535e+30*cos(theta)**6 - 1.53782536130181e+28*cos(theta)**4 + 2.79774171249572e+25*cos(theta)**2 - 8.41426078946081e+21)*cos(12*phi)

#@torch.jit.script
def Yl82_m13(theta, phi):
    return 6.59562305177026e-25*(1.0 - cos(theta)**2)**6.5*(8.35671035744925e+47*cos(theta)**69 - 1.20275107353227e+49*cos(theta)**67 + 8.25864168813616e+49*cos(theta)**65 - 3.60125256002583e+50*cos(theta)**63 + 1.11994367033924e+51*cos(theta)**61 - 2.6445121506075e+51*cos(theta)**59 + 4.92893277743947e+51*cos(theta)**57 - 7.44236207454437e+51*cos(theta)**55 + 9.27173463145838e+51*cos(theta)**53 - 9.65718089353715e+51*cos(theta)**51 + 8.49165906155853e+51*cos(theta)**49 - 6.34850035371445e+51*cos(theta)**47 + 4.05598633709534e+51*cos(theta)**45 - 2.22215078789396e+51*cos(theta)**43 + 1.04619507897197e+51*cos(theta)**41 - 4.23644427040503e+50*cos(theta)**39 + 1.47519041558747e+50*cos(theta)**37 - 4.41166060521443e+49*cos(theta)**35 + 1.1304642808366e+49*cos(theta)**33 - 2.47362262860226e+48*cos(theta)**31 + 4.6009380892002e+47*cos(theta)**29 - 7.23182680687294e+46*cos(theta)**27 + 9.53557929831856e+45*cos(theta)**25 - 1.04518589312955e+45*cos(theta)**23 + 9.41709511972134e+43*cos(theta)**21 - 6.87857382657907e+42*cos(theta)**19 + 4.00352663153513e+41*cos(theta)**17 - 1.81674882178438e+40*cos(theta)**15 + 6.25028264375359e+38*cos(theta)**13 - 1.57113131231963e+37*cos(theta)**11 + 2.74324514849458e+35*cos(theta)**9 - 3.09291654700298e+33*cos(theta)**7 + 2.00963018214921e+31*cos(theta)**5 - 6.15130144520726e+28*cos(theta)**3 + 5.59548342499144e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl82_m14(theta, phi):
    return 8.10392970677783e-27*(1.0 - cos(theta)**2)**7*(5.76613014663999e+49*cos(theta)**68 - 8.05843219266619e+50*cos(theta)**66 + 5.3681170972885e+51*cos(theta)**64 - 2.26878911281627e+52*cos(theta)**62 + 6.83165638906938e+52*cos(theta)**60 - 1.56026216885843e+53*cos(theta)**58 + 2.8094916831405e+53*cos(theta)**56 - 4.0932991409994e+53*cos(theta)**54 + 4.91401935467294e+53*cos(theta)**52 - 4.92516225570395e+53*cos(theta)**50 + 4.16091294016368e+53*cos(theta)**48 - 2.98379516624579e+53*cos(theta)**46 + 1.8251938516929e+53*cos(theta)**44 - 9.55524838794403e+52*cos(theta)**42 + 4.2893998237851e+52*cos(theta)**40 - 1.65221326545796e+52*cos(theta)**38 + 5.45820453767363e+51*cos(theta)**36 - 1.54408121182505e+51*cos(theta)**34 + 3.73053212676078e+50*cos(theta)**32 - 7.668230148667e+49*cos(theta)**30 + 1.33427204586806e+49*cos(theta)**28 - 1.95259323785569e+48*cos(theta)**26 + 2.38389482457964e+47*cos(theta)**24 - 2.40392755419796e+46*cos(theta)**22 + 1.97758997514148e+45*cos(theta)**20 - 1.30692902705002e+44*cos(theta)**18 + 6.80599527360972e+42*cos(theta)**16 - 2.72512323267656e+41*cos(theta)**14 + 8.12536743687966e+39*cos(theta)**12 - 1.72824444355159e+38*cos(theta)**10 + 2.46892063364513e+36*cos(theta)**8 - 2.16504158290208e+34*cos(theta)**6 + 1.00481509107461e+32*cos(theta)**4 - 1.84539043356218e+29*cos(theta)**2 + 5.59548342499144e+25)*cos(14*phi)

#@torch.jit.script
def Yl82_m15(theta, phi):
    return 9.97827208108044e-29*(1.0 - cos(theta)**2)**7.5*(3.92096849971519e+51*cos(theta)**67 - 5.31856524715968e+52*cos(theta)**65 + 3.43559494226464e+53*cos(theta)**63 - 1.40664924994609e+54*cos(theta)**61 + 4.09899383344163e+54*cos(theta)**59 - 9.04952057937887e+54*cos(theta)**57 + 1.57331534255868e+55*cos(theta)**55 - 2.21038153613968e+55*cos(theta)**53 + 2.55529006442993e+55*cos(theta)**51 - 2.46258112785197e+55*cos(theta)**49 + 1.99723821127857e+55*cos(theta)**47 - 1.37254577647306e+55*cos(theta)**45 + 8.03085294744878e+54*cos(theta)**43 - 4.01320432293649e+54*cos(theta)**41 + 1.71575992951404e+54*cos(theta)**39 - 6.27841040874026e+53*cos(theta)**37 + 1.96495363356251e+53*cos(theta)**35 - 5.24987612020517e+52*cos(theta)**33 + 1.19377028056345e+52*cos(theta)**31 - 2.3004690446001e+51*cos(theta)**29 + 3.73596172843056e+50*cos(theta)**27 - 5.0767424184248e+49*cos(theta)**25 + 5.72134757899114e+48*cos(theta)**23 - 5.28864061923551e+47*cos(theta)**21 + 3.95517995028296e+46*cos(theta)**19 - 2.35247224869004e+45*cos(theta)**17 + 1.08895924377755e+44*cos(theta)**15 - 3.81517252574719e+42*cos(theta)**13 + 9.75044092425559e+40*cos(theta)**11 - 1.72824444355159e+39*cos(theta)**9 + 1.9751365069161e+37*cos(theta)**7 - 1.29902494974125e+35*cos(theta)**5 + 4.01926036429842e+32*cos(theta)**3 - 3.69078086712435e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl82_m16(theta, phi):
    return 1.23141631324363e-30*(1.0 - cos(theta)**2)**8*(2.62704889480918e+53*cos(theta)**66 - 3.45706741065379e+54*cos(theta)**64 + 2.16442481362672e+55*cos(theta)**62 - 8.58056042467114e+55*cos(theta)**60 + 2.41840636173056e+56*cos(theta)**58 - 5.15822673024596e+56*cos(theta)**56 + 8.65323438407274e+56*cos(theta)**54 - 1.17150221415403e+57*cos(theta)**52 + 1.30319793285926e+57*cos(theta)**50 - 1.20666475264747e+57*cos(theta)**48 + 9.38701959300926e+56*cos(theta)**46 - 6.17645599412879e+56*cos(theta)**44 + 3.45326676740297e+56*cos(theta)**42 - 1.64541377240396e+56*cos(theta)**40 + 6.69146372510475e+55*cos(theta)**38 - 2.3230118512339e+55*cos(theta)**36 + 6.87733771746877e+54*cos(theta)**34 - 1.73245911966771e+54*cos(theta)**32 + 3.70068786974669e+53*cos(theta)**30 - 6.67136022934029e+52*cos(theta)**28 + 1.00870966667625e+52*cos(theta)**26 - 1.2691856046062e+51*cos(theta)**24 + 1.31590994316796e+50*cos(theta)**22 - 1.11061453003946e+49*cos(theta)**20 + 7.51484190553763e+47*cos(theta)**18 - 3.99920282277307e+46*cos(theta)**16 + 1.63343886566633e+45*cos(theta)**14 - 4.95972428347135e+43*cos(theta)**12 + 1.07254850166812e+42*cos(theta)**10 - 1.55541999919643e+40*cos(theta)**8 + 1.38259555484127e+38*cos(theta)**6 - 6.49512474870625e+35*cos(theta)**4 + 1.20577810928953e+33*cos(theta)**2 - 3.69078086712435e+29)*cos(16*phi)

#@torch.jit.script
def Yl82_m17(theta, phi):
    return 1.52340486282129e-32*(1.0 - cos(theta)**2)**8.5*(1.73385227057406e+55*cos(theta)**65 - 2.21252314281843e+56*cos(theta)**63 + 1.34194338444857e+57*cos(theta)**61 - 5.14833625480268e+57*cos(theta)**59 + 1.40267568980372e+58*cos(theta)**57 - 2.88860696893774e+58*cos(theta)**55 + 4.67274656739928e+58*cos(theta)**53 - 6.09181151360095e+58*cos(theta)**51 + 6.51598966429632e+58*cos(theta)**49 - 5.79199081270784e+58*cos(theta)**47 + 4.31802901278426e+58*cos(theta)**45 - 2.71764063741667e+58*cos(theta)**43 + 1.45037204230925e+58*cos(theta)**41 - 6.58165508961585e+57*cos(theta)**39 + 2.5427562155398e+57*cos(theta)**37 - 8.36284266444202e+56*cos(theta)**35 + 2.33829482393938e+56*cos(theta)**33 - 5.54386918293666e+55*cos(theta)**31 + 1.11020636092401e+55*cos(theta)**29 - 1.86798086421528e+54*cos(theta)**27 + 2.62264513335825e+53*cos(theta)**25 - 3.04604545105488e+52*cos(theta)**23 + 2.89500187496952e+51*cos(theta)**21 - 2.22122906007891e+50*cos(theta)**19 + 1.35267154299677e+49*cos(theta)**17 - 6.39872451643691e+47*cos(theta)**15 + 2.28681441193286e+46*cos(theta)**13 - 5.95166914016562e+44*cos(theta)**11 + 1.07254850166812e+43*cos(theta)**9 - 1.24433599935714e+41*cos(theta)**7 + 8.29557332904762e+38*cos(theta)**5 - 2.5980498994825e+36*cos(theta)**3 + 2.41155621857905e+33*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl82_m18(theta, phi):
    return 1.88955117831948e-34*(1.0 - cos(theta)**2)**9*(1.12700397587314e+57*cos(theta)**64 - 1.39388957997561e+58*cos(theta)**62 + 8.18585464513627e+58*cos(theta)**60 - 3.03751839033358e+59*cos(theta)**58 + 7.99525143188123e+59*cos(theta)**56 - 1.58873383291575e+60*cos(theta)**54 + 2.47655568072162e+60*cos(theta)**52 - 3.10682387193649e+60*cos(theta)**50 + 3.1928349355052e+60*cos(theta)**48 - 2.72223568197268e+60*cos(theta)**46 + 1.94311305575292e+60*cos(theta)**44 - 1.16858547408917e+60*cos(theta)**42 + 5.94652537346792e+59*cos(theta)**40 - 2.56684548495018e+59*cos(theta)**38 + 9.40819799749728e+58*cos(theta)**36 - 2.92699493255471e+58*cos(theta)**34 + 7.71637291899996e+57*cos(theta)**32 - 1.71859944671036e+57*cos(theta)**30 + 3.21959844667962e+56*cos(theta)**28 - 5.04354833338126e+55*cos(theta)**26 + 6.55661283339563e+54*cos(theta)**24 - 7.00590453742623e+53*cos(theta)**22 + 6.07950393743598e+52*cos(theta)**20 - 4.22033521414993e+51*cos(theta)**18 + 2.29954162309452e+50*cos(theta)**16 - 9.59808677465537e+48*cos(theta)**14 + 2.97285873551272e+47*cos(theta)**12 - 6.54683605418218e+45*cos(theta)**10 + 9.65293651501304e+43*cos(theta)**8 - 8.7103519955e+41*cos(theta)**6 + 4.14778666452381e+39*cos(theta)**4 - 7.7941496984475e+36*cos(theta)**2 + 2.41155621857905e+33)*cos(18*phi)

#@torch.jit.script
def Yl82_m19(theta, phi):
    return 2.35021711904123e-36*(1.0 - cos(theta)**2)**9.5*(7.21282544558808e+58*cos(theta)**63 - 8.64211539584878e+59*cos(theta)**61 + 4.91151278708176e+60*cos(theta)**59 - 1.76176066639348e+61*cos(theta)**57 + 4.47734080185349e+61*cos(theta)**55 - 8.57916269774508e+61*cos(theta)**53 + 1.28780895397524e+62*cos(theta)**51 - 1.55341193596824e+62*cos(theta)**49 + 1.53256076904249e+62*cos(theta)**47 - 1.25222841370743e+62*cos(theta)**45 + 8.54969744531283e+61*cos(theta)**43 - 4.9080589911745e+61*cos(theta)**41 + 2.37861014938717e+61*cos(theta)**39 - 9.75401284281069e+60*cos(theta)**37 + 3.38695127909902e+60*cos(theta)**35 - 9.95178277068601e+59*cos(theta)**33 + 2.46923933407999e+59*cos(theta)**31 - 5.15579834013109e+58*cos(theta)**29 + 9.01487565070294e+57*cos(theta)**27 - 1.31132256667913e+57*cos(theta)**25 + 1.57358708001495e+56*cos(theta)**23 - 1.54129899823377e+55*cos(theta)**21 + 1.2159007874872e+54*cos(theta)**19 - 7.59660338546988e+52*cos(theta)**17 + 3.67926659695122e+51*cos(theta)**15 - 1.34373214845175e+50*cos(theta)**13 + 3.56743048261527e+48*cos(theta)**11 - 6.54683605418218e+46*cos(theta)**9 + 7.72234921201043e+44*cos(theta)**7 - 5.2262111973e+42*cos(theta)**5 + 1.65911466580952e+40*cos(theta)**3 - 1.5588299396895e+37*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl82_m20(theta, phi):
    return 2.93182217107679e-38*(1.0 - cos(theta)**2)**10*(4.54408003072049e+60*cos(theta)**62 - 5.27169039146776e+61*cos(theta)**60 + 2.89779254437824e+62*cos(theta)**58 - 1.00420357984428e+63*cos(theta)**56 + 2.46253744101942e+63*cos(theta)**54 - 4.54695622980489e+63*cos(theta)**52 + 6.56782566527373e+63*cos(theta)**50 - 7.61171848624439e+63*cos(theta)**48 + 7.20303561449972e+63*cos(theta)**46 - 5.63502786168346e+63*cos(theta)**44 + 3.67636990148452e+63*cos(theta)**42 - 2.01230418638154e+63*cos(theta)**40 + 9.27657958260996e+62*cos(theta)**38 - 3.60898475183996e+62*cos(theta)**36 + 1.18543294768466e+62*cos(theta)**34 - 3.28408831432638e+61*cos(theta)**32 + 7.65464193564796e+60*cos(theta)**30 - 1.49518151863802e+60*cos(theta)**28 + 2.43401642568979e+59*cos(theta)**26 - 3.27830641669782e+58*cos(theta)**24 + 3.61925028403439e+57*cos(theta)**22 - 3.23672789629092e+56*cos(theta)**20 + 2.31021149622567e+55*cos(theta)**18 - 1.29142257552988e+54*cos(theta)**16 + 5.51889989542684e+52*cos(theta)**14 - 1.74685179298728e+51*cos(theta)**12 + 3.9241735308768e+49*cos(theta)**10 - 5.89215244876396e+47*cos(theta)**8 + 5.4056444484073e+45*cos(theta)**6 - 2.61310559865e+43*cos(theta)**4 + 4.97734399742857e+40*cos(theta)**2 - 1.5588299396895e+37)*cos(20*phi)

#@torch.jit.script
def Yl82_m21(theta, phi):
    return 3.66879265268161e-40*(1.0 - cos(theta)**2)**10.5*(2.8173296190467e+62*cos(theta)**61 - 3.16301423488065e+63*cos(theta)**59 + 1.68071967573938e+64*cos(theta)**57 - 5.62354004712798e+64*cos(theta)**55 + 1.32977021815049e+65*cos(theta)**53 - 2.36441723949854e+65*cos(theta)**51 + 3.28391283263686e+65*cos(theta)**49 - 3.65362487339731e+65*cos(theta)**47 + 3.31339638266987e+65*cos(theta)**45 - 2.47941225914072e+65*cos(theta)**43 + 1.5440753586235e+65*cos(theta)**41 - 8.04921674552618e+64*cos(theta)**39 + 3.52510024139178e+64*cos(theta)**37 - 1.29923451066238e+64*cos(theta)**35 + 4.03047202212783e+63*cos(theta)**33 - 1.05090826058444e+63*cos(theta)**31 + 2.29639258069439e+62*cos(theta)**29 - 4.18650825218645e+61*cos(theta)**27 + 6.32844270679347e+60*cos(theta)**25 - 7.86793540007476e+59*cos(theta)**23 + 7.96235062487566e+58*cos(theta)**21 - 6.47345579258184e+57*cos(theta)**19 + 4.15838069320621e+56*cos(theta)**17 - 2.06627612084781e+55*cos(theta)**15 + 7.72645985359757e+53*cos(theta)**13 - 2.09622215158473e+52*cos(theta)**11 + 3.9241735308768e+50*cos(theta)**9 - 4.71372195901117e+48*cos(theta)**7 + 3.24338666904438e+46*cos(theta)**5 - 1.04524223946e+44*cos(theta)**3 + 9.95468799485715e+40*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl82_m22(theta, phi):
    return 4.60618716125588e-42*(1.0 - cos(theta)**2)**11*(1.71857106761849e+64*cos(theta)**60 - 1.86617839857959e+65*cos(theta)**58 + 9.58010215171446e+65*cos(theta)**56 - 3.09294702592039e+66*cos(theta)**54 + 7.04778215619758e+66*cos(theta)**52 - 1.20585279214426e+67*cos(theta)**50 + 1.60911728799206e+67*cos(theta)**48 - 1.71720369049673e+67*cos(theta)**46 + 1.49102837220144e+67*cos(theta)**44 - 1.06614727143051e+67*cos(theta)**42 + 6.33070897035634e+66*cos(theta)**40 - 3.13919453075521e+66*cos(theta)**38 + 1.30428708931496e+66*cos(theta)**36 - 4.54732078731834e+65*cos(theta)**34 + 1.33005576730219e+65*cos(theta)**32 - 3.25781560781177e+64*cos(theta)**30 + 6.65953848401373e+63*cos(theta)**28 - 1.13035722809034e+63*cos(theta)**26 + 1.58211067669837e+62*cos(theta)**24 - 1.8096251420172e+61*cos(theta)**22 + 1.67209363122389e+60*cos(theta)**20 - 1.22995660059055e+59*cos(theta)**18 + 7.06924717845056e+57*cos(theta)**16 - 3.09941418127171e+56*cos(theta)**14 + 1.00443978096768e+55*cos(theta)**12 - 2.30584436674321e+53*cos(theta)**10 + 3.53175617778912e+51*cos(theta)**8 - 3.29960537130782e+49*cos(theta)**6 + 1.62169333452219e+47*cos(theta)**4 - 3.13572671838e+44*cos(theta)**2 + 9.95468799485715e+40)*cos(22*phi)

#@torch.jit.script
def Yl82_m23(theta, phi):
    return 5.80325034328649e-44*(1.0 - cos(theta)**2)**11.5*(1.03114264057109e+66*cos(theta)**59 - 1.08238347117616e+67*cos(theta)**57 + 5.3648572049601e+67*cos(theta)**55 - 1.67019139399701e+68*cos(theta)**53 + 3.66484672122274e+68*cos(theta)**51 - 6.02926396072128e+68*cos(theta)**49 + 7.72376298236191e+68*cos(theta)**47 - 7.89913697628498e+68*cos(theta)**45 + 6.56052483768635e+68*cos(theta)**43 - 4.47781854000814e+68*cos(theta)**41 + 2.53228358814254e+68*cos(theta)**39 - 1.19289392168698e+68*cos(theta)**37 + 4.69543352153386e+67*cos(theta)**35 - 1.54608906768824e+67*cos(theta)**33 + 4.25617845536699e+66*cos(theta)**31 - 9.77344682343532e+65*cos(theta)**29 + 1.86467077552384e+65*cos(theta)**27 - 2.93892879303489e+64*cos(theta)**25 + 3.79706562407608e+63*cos(theta)**23 - 3.98117531243783e+62*cos(theta)**21 + 3.34418726244778e+61*cos(theta)**19 - 2.21392188106299e+60*cos(theta)**17 + 1.13107954855209e+59*cos(theta)**15 - 4.3391798537804e+57*cos(theta)**13 + 1.20532773716122e+56*cos(theta)**11 - 2.30584436674321e+54*cos(theta)**9 + 2.82540494223129e+52*cos(theta)**7 - 1.97976322278469e+50*cos(theta)**5 + 6.48677333808876e+47*cos(theta)**3 - 6.27145343676e+44*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl82_m24(theta, phi):
    return 7.33824770310885e-46*(1.0 - cos(theta)**2)**12*(6.08374157936945e+67*cos(theta)**58 - 6.16958578570411e+68*cos(theta)**56 + 2.95067146272805e+69*cos(theta)**54 - 8.85201438818416e+69*cos(theta)**52 + 1.8690718278236e+70*cos(theta)**50 - 2.95433934075343e+70*cos(theta)**48 + 3.6301686017101e+70*cos(theta)**46 - 3.55461163932824e+70*cos(theta)**44 + 2.82102568020513e+70*cos(theta)**42 - 1.83590560140334e+70*cos(theta)**40 + 9.87590599375589e+69*cos(theta)**38 - 4.41370751024183e+69*cos(theta)**36 + 1.64340173253685e+69*cos(theta)**34 - 5.10209392337118e+68*cos(theta)**32 + 1.31941532116377e+68*cos(theta)**30 - 2.83429957879624e+67*cos(theta)**28 + 5.03461109391438e+66*cos(theta)**26 - 7.34732198258721e+65*cos(theta)**24 + 8.73325093537498e+64*cos(theta)**22 - 8.36046815611944e+63*cos(theta)**20 + 6.35395579865077e+62*cos(theta)**18 - 3.76366719780708e+61*cos(theta)**16 + 1.69661932282813e+60*cos(theta)**14 - 5.64093380991451e+58*cos(theta)**12 + 1.32586051087734e+57*cos(theta)**10 - 2.07525993006889e+55*cos(theta)**8 + 1.97778345956191e+53*cos(theta)**6 - 9.89881611392345e+50*cos(theta)**4 + 1.94603200142663e+48*cos(theta)**2 - 6.27145343676e+44)*cos(24*phi)

#@torch.jit.script
def Yl82_m25(theta, phi):
    return 9.31507769682447e-48*(1.0 - cos(theta)**2)**12.5*(3.52857011603428e+69*cos(theta)**57 - 3.4549680399943e+70*cos(theta)**55 + 1.59336258987315e+71*cos(theta)**53 - 4.60304748185576e+71*cos(theta)**51 + 9.34535913911799e+71*cos(theta)**49 - 1.41808288356165e+72*cos(theta)**47 + 1.66987755678664e+72*cos(theta)**45 - 1.56402912130443e+72*cos(theta)**43 + 1.18483078568615e+72*cos(theta)**41 - 7.34362240561335e+71*cos(theta)**39 + 3.75284427762724e+71*cos(theta)**37 - 1.58893470368706e+71*cos(theta)**35 + 5.58756589062529e+70*cos(theta)**33 - 1.63267005547878e+70*cos(theta)**31 + 3.9582459634913e+69*cos(theta)**29 - 7.93603882062948e+68*cos(theta)**27 + 1.30899888441774e+68*cos(theta)**25 - 1.76335727582093e+67*cos(theta)**23 + 1.9213152057825e+66*cos(theta)**21 - 1.67209363122389e+65*cos(theta)**19 + 1.14371204375714e+64*cos(theta)**17 - 6.02186751649133e+62*cos(theta)**15 + 2.37526705195939e+61*cos(theta)**13 - 6.76912057189742e+59*cos(theta)**11 + 1.32586051087734e+58*cos(theta)**9 - 1.66020794405511e+56*cos(theta)**7 + 1.18667007573714e+54*cos(theta)**5 - 3.95952644556938e+51*cos(theta)**3 + 3.89206400285326e+48*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl82_m26(theta, phi):
    return 1.18723632548794e-49*(1.0 - cos(theta)**2)**13*(2.01128496613954e+71*cos(theta)**56 - 1.90023242199687e+72*cos(theta)**54 + 8.44482172632769e+72*cos(theta)**52 - 2.34755421574644e+73*cos(theta)**50 + 4.57922597816782e+73*cos(theta)**48 - 6.66498955273974e+73*cos(theta)**46 + 7.5144490055399e+73*cos(theta)**44 - 6.72532522160903e+73*cos(theta)**42 + 4.85780622131323e+73*cos(theta)**40 - 2.86401273818921e+73*cos(theta)**38 + 1.38855238272208e+73*cos(theta)**36 - 5.5612714629047e+72*cos(theta)**34 + 1.84389674390635e+72*cos(theta)**32 - 5.06127717198421e+71*cos(theta)**30 + 1.14789132941248e+71*cos(theta)**28 - 2.14273048156996e+70*cos(theta)**26 + 3.27249721104435e+69*cos(theta)**24 - 4.05572173438814e+68*cos(theta)**22 + 4.03476193214324e+67*cos(theta)**20 - 3.17697789932539e+66*cos(theta)**18 + 1.94431047438714e+65*cos(theta)**16 - 9.03280127473699e+63*cos(theta)**14 + 3.08784716754721e+62*cos(theta)**12 - 7.44603262908716e+60*cos(theta)**10 + 1.19327445978961e+59*cos(theta)**8 - 1.16214556083858e+57*cos(theta)**6 + 5.93335037868572e+54*cos(theta)**4 - 1.18785793367081e+52*cos(theta)**2 + 3.89206400285326e+48)*cos(26*phi)

#@torch.jit.script
def Yl82_m27(theta, phi):
    return 1.51960220000552e-51*(1.0 - cos(theta)**2)**13.5*(1.12631958103814e+73*cos(theta)**55 - 1.02612550787831e+74*cos(theta)**53 + 4.3913072976904e+74*cos(theta)**51 - 1.17377710787322e+75*cos(theta)**49 + 2.19802846952055e+75*cos(theta)**47 - 3.06589519426028e+75*cos(theta)**45 + 3.30635756243756e+75*cos(theta)**43 - 2.82463659307579e+75*cos(theta)**41 + 1.94312248852529e+75*cos(theta)**39 - 1.0883248405119e+75*cos(theta)**37 + 4.99878857779948e+74*cos(theta)**35 - 1.8908322973876e+74*cos(theta)**33 + 5.90046958050031e+73*cos(theta)**31 - 1.51838315159526e+73*cos(theta)**29 + 3.21409572235494e+72*cos(theta)**27 - 5.57109925208189e+71*cos(theta)**25 + 7.85399330650643e+70*cos(theta)**23 - 8.92258781565391e+69*cos(theta)**21 + 8.06952386428648e+68*cos(theta)**19 - 5.7185602187857e+67*cos(theta)**17 + 3.11089675901942e+66*cos(theta)**15 - 1.26459217846318e+65*cos(theta)**13 + 3.70541660105665e+63*cos(theta)**11 - 7.44603262908716e+61*cos(theta)**9 + 9.54619567831687e+59*cos(theta)**7 - 6.97287336503145e+57*cos(theta)**5 + 2.37334015147429e+55*cos(theta)**3 - 2.37571586734163e+52*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl82_m28(theta, phi):
    return 1.95367458241801e-53*(1.0 - cos(theta)**2)**14*(6.19475769570978e+74*cos(theta)**54 - 5.43846519175503e+75*cos(theta)**52 + 2.2395667218221e+76*cos(theta)**50 - 5.75150782857878e+76*cos(theta)**48 + 1.03307338067466e+77*cos(theta)**46 - 1.37965283741713e+77*cos(theta)**44 + 1.42173375184815e+77*cos(theta)**42 - 1.15810100316107e+77*cos(theta)**40 + 7.57817770524864e+76*cos(theta)**38 - 4.02680190989403e+76*cos(theta)**36 + 1.74957600222982e+76*cos(theta)**34 - 6.23974658137907e+75*cos(theta)**32 + 1.82914556995509e+75*cos(theta)**30 - 4.40331113962627e+74*cos(theta)**28 + 8.67805845035833e+73*cos(theta)**26 - 1.39277481302047e+73*cos(theta)**24 + 1.80641846049648e+72*cos(theta)**22 - 1.87374344128732e+71*cos(theta)**20 + 1.53320953421443e+70*cos(theta)**18 - 9.72155237193569e+68*cos(theta)**16 + 4.66634513852913e+67*cos(theta)**14 - 1.64396983200213e+66*cos(theta)**12 + 4.07595826116231e+64*cos(theta)**10 - 6.70142936617844e+62*cos(theta)**8 + 6.68233697482181e+60*cos(theta)**6 - 3.48643668251573e+58*cos(theta)**4 + 7.12002045442286e+55*cos(theta)**2 - 2.37571586734163e+52)*cos(28*phi)

#@torch.jit.script
def Yl82_m29(theta, phi):
    return 2.52344507866567e-55*(1.0 - cos(theta)**2)**14.5*(3.34516915568328e+76*cos(theta)**53 - 2.82800189971262e+77*cos(theta)**51 + 1.11978336091105e+78*cos(theta)**49 - 2.76072375771781e+78*cos(theta)**47 + 4.75213755110343e+78*cos(theta)**45 - 6.07047248463535e+78*cos(theta)**43 + 5.97128175776222e+78*cos(theta)**41 - 4.6324040126443e+78*cos(theta)**39 + 2.87970752799448e+78*cos(theta)**37 - 1.44964868756185e+78*cos(theta)**35 + 5.94855840758138e+77*cos(theta)**33 - 1.9967189060413e+77*cos(theta)**31 + 5.48743670986528e+76*cos(theta)**29 - 1.23292711909535e+76*cos(theta)**27 + 2.25629519709317e+75*cos(theta)**25 - 3.34265955124914e+74*cos(theta)**23 + 3.97412061309225e+73*cos(theta)**21 - 3.74748688257464e+72*cos(theta)**19 + 2.75977716158598e+71*cos(theta)**17 - 1.55544837950971e+70*cos(theta)**15 + 6.53288319394078e+68*cos(theta)**13 - 1.97276379840256e+67*cos(theta)**11 + 4.07595826116231e+65*cos(theta)**9 - 5.36114349294275e+63*cos(theta)**7 + 4.00940218489309e+61*cos(theta)**5 - 1.39457467300629e+59*cos(theta)**3 + 1.42400409088457e+56*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl82_m30(theta, phi):
    return 3.27526851871414e-57*(1.0 - cos(theta)**2)**15*(1.77293965251214e+78*cos(theta)**52 - 1.44228096885343e+79*cos(theta)**50 + 5.48693846846415e+79*cos(theta)**48 - 1.29754016612737e+80*cos(theta)**46 + 2.13846189799654e+80*cos(theta)**44 - 2.6103031683932e+80*cos(theta)**42 + 2.44822552068251e+80*cos(theta)**40 - 1.80663756493128e+80*cos(theta)**38 + 1.06549178535796e+80*cos(theta)**36 - 5.07377040646647e+79*cos(theta)**34 + 1.96302427450186e+79*cos(theta)**32 - 6.18982860872804e+78*cos(theta)**30 + 1.59135664586093e+78*cos(theta)**28 - 3.32890322155746e+77*cos(theta)**26 + 5.64073799273292e+76*cos(theta)**24 - 7.68811696787301e+75*cos(theta)**22 + 8.34565328749373e+74*cos(theta)**20 - 7.12022507689182e+73*cos(theta)**18 + 4.69162117469616e+72*cos(theta)**16 - 2.33317256926456e+71*cos(theta)**14 + 8.49274815212301e+69*cos(theta)**12 - 2.17004017824281e+68*cos(theta)**10 + 3.66836243504608e+66*cos(theta)**8 - 3.75280044505993e+64*cos(theta)**6 + 2.00470109244654e+62*cos(theta)**4 - 4.18372401901887e+59*cos(theta)**2 + 1.42400409088457e+56)*cos(30*phi)

#@torch.jit.script
def Yl82_m31(theta, phi):
    return 4.27273558149263e-59*(1.0 - cos(theta)**2)**15.5*(9.21928619306313e+79*cos(theta)**51 - 7.21140484426717e+80*cos(theta)**49 + 2.63373046486279e+81*cos(theta)**47 - 5.96868476418591e+81*cos(theta)**45 + 9.4092323511848e+81*cos(theta)**43 - 1.09632733072514e+82*cos(theta)**41 + 9.79290208273005e+81*cos(theta)**39 - 6.86522274673885e+81*cos(theta)**37 + 3.83577042728865e+81*cos(theta)**35 - 1.7250819381986e+81*cos(theta)**33 + 6.28167767840594e+80*cos(theta)**31 - 1.85694858261841e+80*cos(theta)**29 + 4.45579860841061e+79*cos(theta)**27 - 8.65514837604939e+78*cos(theta)**25 + 1.3537771182559e+78*cos(theta)**23 - 1.69138573293206e+77*cos(theta)**21 + 1.66913065749875e+76*cos(theta)**19 - 1.28164051384053e+75*cos(theta)**17 + 7.50659387951386e+73*cos(theta)**15 - 3.26644159697039e+72*cos(theta)**13 + 1.01912977825476e+71*cos(theta)**11 - 2.17004017824281e+69*cos(theta)**9 + 2.93468994803686e+67*cos(theta)**7 - 2.25168026703596e+65*cos(theta)**5 + 8.01880436978617e+62*cos(theta)**3 - 8.36744803803774e+59*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl82_m32(theta, phi):
    return 5.60361776682089e-61*(1.0 - cos(theta)**2)**16*(4.7018359584622e+81*cos(theta)**50 - 3.53358837369091e+82*cos(theta)**48 + 1.23785331848551e+83*cos(theta)**46 - 2.68590814388366e+83*cos(theta)**44 + 4.04596991100946e+83*cos(theta)**42 - 4.49494205597309e+83*cos(theta)**40 + 3.81923181226472e+83*cos(theta)**38 - 2.54013241629337e+83*cos(theta)**36 + 1.34251964955103e+83*cos(theta)**34 - 5.69277039605538e+82*cos(theta)**32 + 1.94732008030584e+82*cos(theta)**30 - 5.38515088959339e+81*cos(theta)**28 + 1.20306562427086e+81*cos(theta)**26 - 2.16378709401235e+80*cos(theta)**24 + 3.11368737198857e+79*cos(theta)**22 - 3.55191003915733e+78*cos(theta)**20 + 3.17134824924762e+77*cos(theta)**18 - 2.1787888735289e+76*cos(theta)**16 + 1.12598908192708e+75*cos(theta)**14 - 4.24637407606151e+73*cos(theta)**12 + 1.12104275608024e+72*cos(theta)**10 - 1.95303616041853e+70*cos(theta)**8 + 2.0542829636258e+68*cos(theta)**6 - 1.12584013351798e+66*cos(theta)**4 + 2.40564131093585e+63*cos(theta)**2 - 8.36744803803774e+59)*cos(32*phi)

#@torch.jit.script
def Yl82_m33(theta, phi):
    return 7.38983227163081e-63*(1.0 - cos(theta)**2)**16.5*(2.3509179792311e+83*cos(theta)**49 - 1.69612241937164e+84*cos(theta)**47 + 5.69412526503336e+84*cos(theta)**45 - 1.18179958330881e+85*cos(theta)**43 + 1.69930736262397e+85*cos(theta)**41 - 1.79797682238924e+85*cos(theta)**39 + 1.45130808866059e+85*cos(theta)**37 - 9.14447669865615e+84*cos(theta)**35 + 4.5645668084735e+84*cos(theta)**33 - 1.82168652673772e+84*cos(theta)**31 + 5.84196024091752e+83*cos(theta)**29 - 1.50784224908615e+83*cos(theta)**27 + 3.12797062310425e+82*cos(theta)**25 - 5.19308902562963e+81*cos(theta)**23 + 6.85011221837485e+80*cos(theta)**21 - 7.10382007831466e+79*cos(theta)**19 + 5.70842684864571e+78*cos(theta)**17 - 3.48606219764624e+77*cos(theta)**15 + 1.57638471469791e+76*cos(theta)**13 - 5.09564889127381e+74*cos(theta)**11 + 1.12104275608024e+73*cos(theta)**9 - 1.56242892833483e+71*cos(theta)**7 + 1.23256977817548e+69*cos(theta)**5 - 4.50336053407191e+66*cos(theta)**3 + 4.8112826218717e+63*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl82_m34(theta, phi):
    return 9.80183859108696e-65*(1.0 - cos(theta)**2)**17*(1.15194980982324e+85*cos(theta)**48 - 7.9717753710467e+85*cos(theta)**46 + 2.56235636926501e+86*cos(theta)**44 - 5.08173820822788e+86*cos(theta)**42 + 6.96716018675829e+86*cos(theta)**40 - 7.01210960731802e+86*cos(theta)**38 + 5.3698399280442e+86*cos(theta)**36 - 3.20056684452965e+86*cos(theta)**34 + 1.50630704679625e+86*cos(theta)**32 - 5.64722823288694e+85*cos(theta)**30 + 1.69416846986608e+85*cos(theta)**28 - 4.07117407253261e+84*cos(theta)**26 + 7.81992655776062e+83*cos(theta)**24 - 1.19441047589482e+83*cos(theta)**22 + 1.43852356585872e+82*cos(theta)**20 - 1.34972581487979e+81*cos(theta)**18 + 9.70432564269771e+79*cos(theta)**16 - 5.22909329646935e+78*cos(theta)**14 + 2.04930012910728e+77*cos(theta)**12 - 5.60521378040119e+75*cos(theta)**10 + 1.00893848047221e+74*cos(theta)**8 - 1.09370024983438e+72*cos(theta)**6 + 6.16284889087741e+69*cos(theta)**4 - 1.35100816022157e+67*cos(theta)**2 + 4.8112826218717e+63)*cos(34*phi)

#@torch.jit.script
def Yl82_m35(theta, phi):
    return 1.30795859790518e-66*(1.0 - cos(theta)**2)**17.5*(5.52935908715154e+86*cos(theta)**47 - 3.66701667068148e+87*cos(theta)**45 + 1.12743680247661e+88*cos(theta)**43 - 2.13433004745571e+88*cos(theta)**41 + 2.78686407470332e+88*cos(theta)**39 - 2.66460165078085e+88*cos(theta)**37 + 1.93314237409591e+88*cos(theta)**35 - 1.08819272714008e+88*cos(theta)**33 + 4.82018254974801e+87*cos(theta)**31 - 1.69416846986608e+87*cos(theta)**29 + 4.74367171562503e+86*cos(theta)**27 - 1.05850525885848e+86*cos(theta)**25 + 1.87678237386255e+85*cos(theta)**23 - 2.62770304696859e+84*cos(theta)**21 + 2.87704713171744e+83*cos(theta)**19 - 2.42950646678361e+82*cos(theta)**17 + 1.55269210283163e+81*cos(theta)**15 - 7.3207306150571e+79*cos(theta)**13 + 2.45916015492874e+78*cos(theta)**11 - 5.60521378040119e+76*cos(theta)**9 + 8.07150784377771e+74*cos(theta)**7 - 6.56220149900627e+72*cos(theta)**5 + 2.46513955635097e+70*cos(theta)**3 - 2.70201632044315e+67*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl82_m36(theta, phi):
    return 1.75632168870198e-68*(1.0 - cos(theta)**2)**18*(2.59879877096122e+88*cos(theta)**46 - 1.65015750180667e+89*cos(theta)**44 + 4.8479782506494e+89*cos(theta)**42 - 8.75075319456842e+89*cos(theta)**40 + 1.08687698913429e+90*cos(theta)**38 - 9.85902610788914e+89*cos(theta)**36 + 6.76599830933569e+89*cos(theta)**34 - 3.59103599956227e+89*cos(theta)**32 + 1.49425659042188e+89*cos(theta)**30 - 4.91308856261164e+88*cos(theta)**28 + 1.28079136321876e+88*cos(theta)**26 - 2.64626314714619e+87*cos(theta)**24 + 4.31659945988386e+86*cos(theta)**22 - 5.51817639863405e+85*cos(theta)**20 + 5.46638955026313e+84*cos(theta)**18 - 4.13016099353215e+83*cos(theta)**16 + 2.32903815424745e+82*cos(theta)**14 - 9.51694979957422e+80*cos(theta)**12 + 2.70507617042161e+79*cos(theta)**10 - 5.04469240236107e+77*cos(theta)**8 + 5.6500554906444e+75*cos(theta)**6 - 3.28110074950314e+73*cos(theta)**4 + 7.3954186690529e+70*cos(theta)**2 - 2.70201632044315e+67)*cos(36*phi)

#@torch.jit.script
def Yl82_m37(theta, phi):
    return 2.37384122615229e-70*(1.0 - cos(theta)**2)**18.5*(1.19544743464216e+90*cos(theta)**45 - 7.26069300794934e+90*cos(theta)**43 + 2.03615086527275e+91*cos(theta)**41 - 3.50030127782737e+91*cos(theta)**39 + 4.13013255871032e+91*cos(theta)**37 - 3.54924939884009e+91*cos(theta)**35 + 2.30043942517413e+91*cos(theta)**33 - 1.14913151985993e+91*cos(theta)**31 + 4.48276977126565e+90*cos(theta)**29 - 1.37566479753126e+90*cos(theta)**27 + 3.33005754436877e+89*cos(theta)**25 - 6.35103155315087e+88*cos(theta)**23 + 9.4965188117445e+87*cos(theta)**21 - 1.10363527972681e+87*cos(theta)**19 + 9.83950119047364e+85*cos(theta)**17 - 6.60825758965143e+84*cos(theta)**15 + 3.26065341594643e+83*cos(theta)**13 - 1.14203397594891e+82*cos(theta)**11 + 2.70507617042161e+80*cos(theta)**9 - 4.03575392188886e+78*cos(theta)**7 + 3.39003329438664e+76*cos(theta)**5 - 1.31244029980125e+74*cos(theta)**3 + 1.47908373381058e+71*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl82_m38(theta, phi):
    return 3.23038874136438e-72*(1.0 - cos(theta)**2)**19*(5.37951345588974e+91*cos(theta)**44 - 3.12209799341821e+92*cos(theta)**42 + 8.34821854761827e+92*cos(theta)**40 - 1.36511749835267e+93*cos(theta)**38 + 1.52814904672282e+93*cos(theta)**36 - 1.24223728959403e+93*cos(theta)**34 + 7.59145010307464e+92*cos(theta)**32 - 3.56230771156577e+92*cos(theta)**30 + 1.30000323366704e+92*cos(theta)**28 - 3.7142949533344e+91*cos(theta)**26 + 8.32514386092193e+90*cos(theta)**24 - 1.4607372572247e+90*cos(theta)**22 + 1.99426895046634e+89*cos(theta)**20 - 2.09690703148094e+88*cos(theta)**18 + 1.67271520238052e+87*cos(theta)**16 - 9.91238638447715e+85*cos(theta)**14 + 4.23884944073036e+84*cos(theta)**12 - 1.2562373735438e+83*cos(theta)**10 + 2.43456855337945e+81*cos(theta)**8 - 2.8250277453222e+79*cos(theta)**6 + 1.69501664719332e+77*cos(theta)**4 - 3.93732089940376e+74*cos(theta)**2 + 1.47908373381058e+71)*cos(38*phi)

#@torch.jit.script
def Yl82_m39(theta, phi):
    return 4.42726751326201e-74*(1.0 - cos(theta)**2)**19.5*(2.36698592059148e+93*cos(theta)**43 - 1.31128115723565e+94*cos(theta)**41 + 3.33928741904731e+94*cos(theta)**39 - 5.18744649374016e+94*cos(theta)**37 + 5.50133656820214e+94*cos(theta)**35 - 4.22360678461971e+94*cos(theta)**33 + 2.42926403298388e+94*cos(theta)**31 - 1.06869231346973e+94*cos(theta)**29 + 3.64000905426771e+93*cos(theta)**27 - 9.65716687866943e+92*cos(theta)**25 + 1.99803452662126e+92*cos(theta)**23 - 3.21362196589434e+91*cos(theta)**21 + 3.98853790093269e+90*cos(theta)**19 - 3.77443265666569e+89*cos(theta)**17 + 2.67634432380883e+88*cos(theta)**15 - 1.3877340938268e+87*cos(theta)**13 + 5.08661932887643e+85*cos(theta)**11 - 1.2562373735438e+84*cos(theta)**9 + 1.94765484270356e+82*cos(theta)**7 - 1.69501664719332e+80*cos(theta)**5 + 6.78006658877328e+77*cos(theta)**3 - 7.87464179880752e+74*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl82_m40(theta, phi):
    return 6.11253869567382e-76*(1.0 - cos(theta)**2)**20*(1.01780394585434e+95*cos(theta)**42 - 5.37625274466616e+95*cos(theta)**40 + 1.30232209342845e+96*cos(theta)**38 - 1.91935520268386e+96*cos(theta)**36 + 1.92546779887075e+96*cos(theta)**34 - 1.3937902389245e+96*cos(theta)**32 + 7.53071850225004e+95*cos(theta)**30 - 3.09920770906222e+95*cos(theta)**28 + 9.82802444652282e+94*cos(theta)**26 - 2.41429171966736e+94*cos(theta)**24 + 4.5954794112289e+93*cos(theta)**22 - 6.74860612837811e+92*cos(theta)**20 + 7.57822201177211e+91*cos(theta)**18 - 6.41653551633167e+90*cos(theta)**16 + 4.01451648571325e+89*cos(theta)**14 - 1.80405432197484e+88*cos(theta)**12 + 5.59528126176407e+86*cos(theta)**10 - 1.13061363618942e+85*cos(theta)**8 + 1.36335838989249e+83*cos(theta)**6 - 8.4750832359666e+80*cos(theta)**4 + 2.03401997663198e+78*cos(theta)**2 - 7.87464179880752e+74)*cos(40*phi)

#@torch.jit.script
def Yl82_m41(theta, phi):
    return 8.50441452467428e-78*(1.0 - cos(theta)**2)**20.5*(4.27477657258822e+96*cos(theta)**41 - 2.15050109786647e+97*cos(theta)**39 + 4.94882395502811e+97*cos(theta)**37 - 6.90967872966189e+97*cos(theta)**35 + 6.54659051616055e+97*cos(theta)**33 - 4.46012876455841e+97*cos(theta)**31 + 2.25921555067501e+97*cos(theta)**29 - 8.67778158537422e+96*cos(theta)**27 + 2.55528635609593e+96*cos(theta)**25 - 5.79430012720166e+95*cos(theta)**23 + 1.01100547047036e+95*cos(theta)**21 - 1.34972122567562e+94*cos(theta)**19 + 1.36407996211898e+93*cos(theta)**17 - 1.02664568261307e+92*cos(theta)**15 + 5.62032307999854e+90*cos(theta)**13 - 2.16486518636981e+89*cos(theta)**11 + 5.59528126176407e+87*cos(theta)**9 - 9.04490908951534e+85*cos(theta)**7 + 8.18015033935496e+83*cos(theta)**5 - 3.39003329438664e+81*cos(theta)**3 + 4.06803995326397e+78*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl82_m42(theta, phi):
    return 1.19272864513199e-79*(1.0 - cos(theta)**2)**21*(1.75265839476117e+98*cos(theta)**40 - 8.38695428167922e+98*cos(theta)**38 + 1.8310648633604e+99*cos(theta)**36 - 2.41838755538166e+99*cos(theta)**34 + 2.16037487033298e+99*cos(theta)**32 - 1.38263991701311e+99*cos(theta)**30 + 6.55172509695754e+98*cos(theta)**28 - 2.34300102805104e+98*cos(theta)**26 + 6.38821589023983e+97*cos(theta)**24 - 1.33268902925638e+97*cos(theta)**22 + 2.12311148798775e+96*cos(theta)**20 - 2.56447032878368e+95*cos(theta)**18 + 2.31893593560227e+94*cos(theta)**16 - 1.5399685239196e+93*cos(theta)**14 + 7.30642000399811e+91*cos(theta)**12 - 2.38135170500679e+90*cos(theta)**10 + 5.03575313558767e+88*cos(theta)**8 - 6.33143636266074e+86*cos(theta)**6 + 4.09007516967748e+84*cos(theta)**4 - 1.01700998831599e+82*cos(theta)**2 + 4.06803995326397e+78)*cos(42*phi)

#@torch.jit.script
def Yl82_m43(theta, phi):
    return 1.68677302617654e-81*(1.0 - cos(theta)**2)**21.5*(7.01063357904468e+99*cos(theta)**39 - 3.1870426270381e+100*cos(theta)**37 + 6.59183350809744e+100*cos(theta)**35 - 8.22251768829765e+100*cos(theta)**33 + 6.91319958506554e+100*cos(theta)**31 - 4.14791975103932e+100*cos(theta)**29 + 1.83448302714811e+100*cos(theta)**27 - 6.0918026729327e+99*cos(theta)**25 + 1.53317181365756e+99*cos(theta)**23 - 2.93191586436404e+98*cos(theta)**21 + 4.24622297597551e+97*cos(theta)**19 - 4.61604659181063e+96*cos(theta)**17 + 3.71029749696363e+95*cos(theta)**15 - 2.15595593348744e+94*cos(theta)**13 + 8.76770400479773e+92*cos(theta)**11 - 2.38135170500679e+91*cos(theta)**9 + 4.02860250847013e+89*cos(theta)**7 - 3.79886181759644e+87*cos(theta)**5 + 1.63603006787099e+85*cos(theta)**3 - 2.03401997663198e+82*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl82_m44(theta, phi):
    return 2.40624071678879e-83*(1.0 - cos(theta)**2)**22*(2.73414709582743e+101*cos(theta)**38 - 1.1792057720041e+102*cos(theta)**36 + 2.30714172783411e+102*cos(theta)**34 - 2.71343083713822e+102*cos(theta)**32 + 2.14309187137032e+102*cos(theta)**30 - 1.2028967278014e+102*cos(theta)**28 + 4.9531041732999e+101*cos(theta)**26 - 1.52295066823318e+101*cos(theta)**24 + 3.52629517141239e+100*cos(theta)**22 - 6.15702331516449e+99*cos(theta)**20 + 8.06782365435346e+98*cos(theta)**18 - 7.84727920607807e+97*cos(theta)**16 + 5.56544624544544e+96*cos(theta)**14 - 2.80274271353367e+95*cos(theta)**12 + 9.6444744052775e+93*cos(theta)**10 - 2.14321653450611e+92*cos(theta)**8 + 2.82002175592909e+90*cos(theta)**6 - 1.89943090879822e+88*cos(theta)**4 + 4.90809020361298e+85*cos(theta)**2 - 2.03401997663198e+82)*cos(44*phi)

#@torch.jit.script
def Yl82_m45(theta, phi):
    return 3.4637410177776e-85*(1.0 - cos(theta)**2)**22.5*(1.03897589641442e+103*cos(theta)**37 - 4.24514077921475e+103*cos(theta)**35 + 7.84428187463596e+103*cos(theta)**33 - 8.68297867884232e+103*cos(theta)**31 + 6.42927561411095e+103*cos(theta)**29 - 3.36811083784393e+103*cos(theta)**27 + 1.28780708505797e+103*cos(theta)**25 - 3.65508160375962e+102*cos(theta)**23 + 7.75784937710725e+101*cos(theta)**21 - 1.2314046630329e+101*cos(theta)**19 + 1.45220825778362e+100*cos(theta)**17 - 1.25556467297249e+99*cos(theta)**15 + 7.79162474362361e+97*cos(theta)**13 - 3.36329125624041e+96*cos(theta)**11 + 9.6444744052775e+94*cos(theta)**9 - 1.71457322760489e+93*cos(theta)**7 + 1.69201305355746e+91*cos(theta)**5 - 7.59772363519289e+88*cos(theta)**3 + 9.81618040722595e+85*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl82_m46(theta, phi):
    return 5.0331464317095e-87*(1.0 - cos(theta)**2)**23*(3.84421081673336e+104*cos(theta)**36 - 1.48579927272516e+105*cos(theta)**34 + 2.58861301862987e+105*cos(theta)**32 - 2.69172339044112e+105*cos(theta)**30 + 1.86448992809218e+105*cos(theta)**28 - 9.09389926217861e+104*cos(theta)**26 + 3.21951771264493e+104*cos(theta)**24 - 8.40668768864713e+103*cos(theta)**22 + 1.62914836919252e+103*cos(theta)**20 - 2.3396688597625e+102*cos(theta)**18 + 2.46875403823216e+101*cos(theta)**16 - 1.88334700945874e+100*cos(theta)**14 + 1.01291121667107e+99*cos(theta)**12 - 3.69962038186445e+97*cos(theta)**10 + 8.68002696474975e+95*cos(theta)**8 - 1.20020125932342e+94*cos(theta)**6 + 8.46006526778728e+91*cos(theta)**4 - 2.27931709055787e+89*cos(theta)**2 + 9.81618040722595e+85)*cos(46*phi)

#@torch.jit.script
def Yl82_m47(theta, phi):
    return 7.38573056244701e-89*(1.0 - cos(theta)**2)**23.5*(1.38391589402401e+106*cos(theta)**35 - 5.05171752726556e+106*cos(theta)**33 + 8.28356165961557e+106*cos(theta)**31 - 8.07517017132336e+106*cos(theta)**29 + 5.22057179865809e+106*cos(theta)**27 - 2.36441380816644e+106*cos(theta)**25 + 7.72684251034784e+105*cos(theta)**23 - 1.84947129150237e+105*cos(theta)**21 + 3.25829673838505e+104*cos(theta)**19 - 4.21140394757251e+103*cos(theta)**17 + 3.95000646117146e+102*cos(theta)**15 - 2.63668581324223e+101*cos(theta)**13 + 1.21549346000528e+100*cos(theta)**11 - 3.69962038186445e+98*cos(theta)**9 + 6.9440215717998e+96*cos(theta)**7 - 7.20120755594053e+94*cos(theta)**5 + 3.38402610711491e+92*cos(theta)**3 - 4.55863418111573e+89*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl82_m48(theta, phi):
    return 1.09493354649137e-90*(1.0 - cos(theta)**2)**24*(4.84370562908403e+107*cos(theta)**34 - 1.66706678399763e+108*cos(theta)**32 + 2.56790411448083e+108*cos(theta)**30 - 2.34179934968377e+108*cos(theta)**28 + 1.40955438563768e+108*cos(theta)**26 - 5.9110345204161e+107*cos(theta)**24 + 1.77717377738e+107*cos(theta)**22 - 3.88388971215497e+106*cos(theta)**20 + 6.19076380293159e+105*cos(theta)**18 - 7.15938671087326e+104*cos(theta)**16 + 5.92500969175718e+103*cos(theta)**14 - 3.4276915572149e+102*cos(theta)**12 + 1.33704280600581e+101*cos(theta)**10 - 3.329658343678e+99*cos(theta)**8 + 4.86081510025986e+97*cos(theta)**6 - 3.60060377797027e+95*cos(theta)**4 + 1.01520783213447e+93*cos(theta)**2 - 4.55863418111573e+89)*cos(48*phi)

#@torch.jit.script
def Yl82_m49(theta, phi):
    return 1.64063758130035e-92*(1.0 - cos(theta)**2)**24.5*(1.64685991388857e+109*cos(theta)**33 - 5.33461370879243e+109*cos(theta)**31 + 7.70371234344248e+109*cos(theta)**29 - 6.55703817911456e+109*cos(theta)**27 + 3.66484140265798e+109*cos(theta)**25 - 1.41864828489986e+109*cos(theta)**23 + 3.90978231023601e+108*cos(theta)**21 - 7.76777942430995e+107*cos(theta)**19 + 1.11433748452769e+107*cos(theta)**17 - 1.14550187373972e+106*cos(theta)**15 + 8.29501356846006e+104*cos(theta)**13 - 4.11322986865788e+103*cos(theta)**11 + 1.33704280600581e+102*cos(theta)**9 - 2.6637266749424e+100*cos(theta)**7 + 2.91648906015592e+98*cos(theta)**5 - 1.44024151118811e+96*cos(theta)**3 + 2.03041566426895e+93*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl82_m50(theta, phi):
    return 2.48581451712174e-94*(1.0 - cos(theta)**2)**25*(5.43463771583229e+110*cos(theta)**32 - 1.65373024972565e+111*cos(theta)**30 + 2.23407657959832e+111*cos(theta)**28 - 1.77040030836093e+111*cos(theta)**26 + 9.16210350664495e+110*cos(theta)**24 - 3.26289105526969e+110*cos(theta)**22 + 8.21054285149561e+109*cos(theta)**20 - 1.47587809061889e+109*cos(theta)**18 + 1.89437372369707e+108*cos(theta)**16 - 1.71825281060958e+107*cos(theta)**14 + 1.07835176389981e+106*cos(theta)**12 - 4.52455285552367e+104*cos(theta)**10 + 1.20333852540523e+103*cos(theta)**8 - 1.86460867245968e+101*cos(theta)**6 + 1.45824453007796e+99*cos(theta)**4 - 4.32072453356432e+96*cos(theta)**2 + 2.03041566426895e+93)*cos(50*phi)

#@torch.jit.script
def Yl82_m51(theta, phi):
    return 3.81037667777541e-96*(1.0 - cos(theta)**2)**25.5*(1.73908406906633e+112*cos(theta)**31 - 4.96119074917696e+112*cos(theta)**29 + 6.25541442287529e+112*cos(theta)**27 - 4.60304080173842e+112*cos(theta)**25 + 2.19890484159479e+112*cos(theta)**23 - 7.17836032159331e+111*cos(theta)**21 + 1.64210857029912e+111*cos(theta)**19 - 2.656580563114e+110*cos(theta)**17 + 3.0309979579153e+109*cos(theta)**15 - 2.40555393485342e+108*cos(theta)**13 + 1.29402211667977e+107*cos(theta)**11 - 4.52455285552367e+105*cos(theta)**9 + 9.62670820324185e+103*cos(theta)**7 - 1.11876520347581e+102*cos(theta)**5 + 5.83297812031183e+99*cos(theta)**3 - 8.64144906712864e+96*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl82_m52(theta, phi):
    return 5.91200325120919e-98*(1.0 - cos(theta)**2)**26*(5.39116061410563e+113*cos(theta)**30 - 1.43874531726132e+114*cos(theta)**28 + 1.68896189417633e+114*cos(theta)**26 - 1.15076020043461e+114*cos(theta)**24 + 5.05748113566801e+113*cos(theta)**22 - 1.5074556675346e+113*cos(theta)**20 + 3.12000628356833e+112*cos(theta)**18 - 4.5161869572938e+111*cos(theta)**16 + 4.54649693687296e+110*cos(theta)**14 - 3.12722011530944e+109*cos(theta)**12 + 1.42342432834775e+108*cos(theta)**10 - 4.0720975699713e+106*cos(theta)**8 + 6.73869574226929e+104*cos(theta)**6 - 5.59382601737905e+102*cos(theta)**4 + 1.74989343609355e+100*cos(theta)**2 - 8.64144906712864e+96)*cos(52*phi)

#@torch.jit.script
def Yl82_m53(theta, phi):
    return 9.28981686517097e-100*(1.0 - cos(theta)**2)**26.5*(1.61734818423169e+115*cos(theta)**29 - 4.02848688833169e+115*cos(theta)**27 + 4.39130092485846e+115*cos(theta)**25 - 2.76182448104305e+115*cos(theta)**23 + 1.11264584984696e+115*cos(theta)**21 - 3.01491133506919e+114*cos(theta)**19 + 5.616011310423e+113*cos(theta)**17 - 7.22589913167009e+112*cos(theta)**15 + 6.36509571162214e+111*cos(theta)**13 - 3.75266413837133e+110*cos(theta)**11 + 1.42342432834775e+109*cos(theta)**9 - 3.25767805597704e+107*cos(theta)**7 + 4.04321744536157e+105*cos(theta)**5 - 2.23753040695162e+103*cos(theta)**3 + 3.4997868721871e+100*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl82_m54(theta, phi):
    return 1.47924019567526e-101*(1.0 - cos(theta)**2)**27*(4.6903097342719e+116*cos(theta)**28 - 1.08769145984956e+117*cos(theta)**26 + 1.09782523121461e+117*cos(theta)**24 - 6.35219630639903e+116*cos(theta)**22 + 2.33655628467862e+116*cos(theta)**20 - 5.72833153663146e+115*cos(theta)**18 + 9.5472192277191e+114*cos(theta)**16 - 1.08388486975051e+114*cos(theta)**14 + 8.27462442510878e+112*cos(theta)**12 - 4.12793055220846e+111*cos(theta)**10 + 1.28108189551297e+110*cos(theta)**8 - 2.28037463918393e+108*cos(theta)**6 + 2.02160872268079e+106*cos(theta)**4 - 6.71259122085486e+103*cos(theta)**2 + 3.4997868721871e+100)*cos(54*phi)

#@torch.jit.script
def Yl82_m55(theta, phi):
    return 2.38835786170144e-103*(1.0 - cos(theta)**2)**27.5*(1.31328672559613e+118*cos(theta)**27 - 2.82799779560885e+118*cos(theta)**25 + 2.63478055491507e+118*cos(theta)**23 - 1.39748318740779e+118*cos(theta)**21 + 4.67311256935724e+117*cos(theta)**19 - 1.03109967659366e+117*cos(theta)**17 + 1.52755507643506e+116*cos(theta)**15 - 1.51743881765072e+115*cos(theta)**13 + 9.92954931013054e+113*cos(theta)**11 - 4.12793055220846e+112*cos(theta)**9 + 1.02486551641038e+111*cos(theta)**7 - 1.36822478351036e+109*cos(theta)**5 + 8.08643489072315e+106*cos(theta)**3 - 1.34251824417097e+104*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl82_m56(theta, phi):
    return 3.91271283474653e-105*(1.0 - cos(theta)**2)**28*(3.54587415910955e+119*cos(theta)**26 - 7.06999448902212e+119*cos(theta)**24 + 6.05999527630467e+119*cos(theta)**22 - 2.93471469355635e+119*cos(theta)**20 + 8.87891388177877e+118*cos(theta)**18 - 1.75286945020923e+118*cos(theta)**16 + 2.29133261465258e+117*cos(theta)**14 - 1.97267046294593e+116*cos(theta)**12 + 1.09225042411436e+115*cos(theta)**10 - 3.71513749698762e+113*cos(theta)**8 + 7.17405861487264e+111*cos(theta)**6 - 6.84112391755179e+109*cos(theta)**4 + 2.42593046721695e+107*cos(theta)**2 - 1.34251824417097e+104)*cos(56*phi)

#@torch.jit.script
def Yl82_m57(theta, phi):
    return 6.50854483416237e-107*(1.0 - cos(theta)**2)**28.5*(9.21927281368484e+120*cos(theta)**25 - 1.69679867736531e+121*cos(theta)**23 + 1.33319896078703e+121*cos(theta)**21 - 5.8694293871127e+120*cos(theta)**19 + 1.59820449872018e+120*cos(theta)**17 - 2.80459112033476e+119*cos(theta)**15 + 3.20786566051362e+118*cos(theta)**13 - 2.36720455553512e+117*cos(theta)**11 + 1.09225042411436e+116*cos(theta)**9 - 2.97210999759009e+114*cos(theta)**7 + 4.30443516892358e+112*cos(theta)**5 - 2.73644956702071e+110*cos(theta)**3 + 4.85186093443389e+107*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl82_m58(theta, phi):
    return 1.10014487173673e-108*(1.0 - cos(theta)**2)**29*(2.30481820342121e+122*cos(theta)**24 - 3.90263695794021e+122*cos(theta)**22 + 2.79971781765276e+122*cos(theta)**20 - 1.11519158355141e+122*cos(theta)**18 + 2.7169476478243e+121*cos(theta)**16 - 4.20688668050215e+120*cos(theta)**14 + 4.1702253586677e+119*cos(theta)**12 - 2.60392501108863e+118*cos(theta)**10 + 9.83025381702923e+116*cos(theta)**8 - 2.08047699831307e+115*cos(theta)**6 + 2.15221758446179e+113*cos(theta)**4 - 8.20934870106214e+110*cos(theta)**2 + 4.85186093443389e+107)*cos(58*phi)

#@torch.jit.script
def Yl82_m59(theta, phi):
    return 1.89118799111986e-110*(1.0 - cos(theta)**2)**29.5*(5.5315636882109e+123*cos(theta)**23 - 8.58580130746846e+123*cos(theta)**21 + 5.59943563530552e+123*cos(theta)**19 - 2.00734485039254e+123*cos(theta)**17 + 4.34711623651888e+122*cos(theta)**15 - 5.889641352703e+121*cos(theta)**13 + 5.00427043040124e+120*cos(theta)**11 - 2.60392501108863e+119*cos(theta)**9 + 7.86420305362339e+117*cos(theta)**7 - 1.24828619898784e+116*cos(theta)**5 + 8.60887033784717e+113*cos(theta)**3 - 1.64186974021243e+111*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl82_m60(theta, phi):
    return 3.3092273977258e-112*(1.0 - cos(theta)**2)**30*(1.27225964828851e+125*cos(theta)**22 - 1.80301827456838e+125*cos(theta)**20 + 1.06389277070805e+125*cos(theta)**18 - 3.41248624566732e+124*cos(theta)**16 + 6.52067435477832e+123*cos(theta)**14 - 7.6565337585139e+122*cos(theta)**12 + 5.50469747344137e+121*cos(theta)**10 - 2.34353250997977e+120*cos(theta)**8 + 5.50494213753637e+118*cos(theta)**6 - 6.2414309949392e+116*cos(theta)**4 + 2.58266110135415e+114*cos(theta)**2 - 1.64186974021243e+111)*cos(60*phi)

#@torch.jit.script
def Yl82_m61(theta, phi):
    return 5.89993534123067e-114*(1.0 - cos(theta)**2)**30.5*(2.79897122623472e+126*cos(theta)**21 - 3.60603654913675e+126*cos(theta)**19 + 1.91500698727449e+126*cos(theta)**17 - 5.45997799306772e+125*cos(theta)**15 + 9.12894409668965e+124*cos(theta)**13 - 9.18784051021668e+123*cos(theta)**11 + 5.50469747344137e+122*cos(theta)**9 - 1.87482600798382e+121*cos(theta)**7 + 3.30296528252182e+119*cos(theta)**5 - 2.49657239797568e+117*cos(theta)**3 + 5.1653222027083e+114*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl82_m62(theta, phi):
    return 1.07289286891011e-115*(1.0 - cos(theta)**2)**31*(5.87783957509291e+127*cos(theta)**20 - 6.85146944335983e+127*cos(theta)**18 + 3.25551187836663e+127*cos(theta)**16 - 8.18996698960158e+126*cos(theta)**14 + 1.18676273256966e+126*cos(theta)**12 - 1.01066245612384e+125*cos(theta)**10 + 4.95422772609723e+123*cos(theta)**8 - 1.31237820558867e+122*cos(theta)**6 + 1.65148264126091e+120*cos(theta)**4 - 7.48971719392703e+117*cos(theta)**2 + 5.1653222027083e+114)*cos(62*phi)

#@torch.jit.script
def Yl82_m63(theta, phi):
    return 1.99231204120009e-117*(1.0 - cos(theta)**2)**31.5*(1.17556791501858e+129*cos(theta)**19 - 1.23326449980477e+129*cos(theta)**17 + 5.2088190053866e+128*cos(theta)**15 - 1.14659537854422e+128*cos(theta)**13 + 1.42411527908359e+127*cos(theta)**11 - 1.01066245612384e+126*cos(theta)**9 + 3.96338218087779e+124*cos(theta)**7 - 7.87426923353203e+122*cos(theta)**5 + 6.60593056504364e+120*cos(theta)**3 - 1.49794343878541e+118*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl82_m64(theta, phi):
    return 3.7827194403623e-119*(1.0 - cos(theta)**2)**32*(2.2335790385353e+130*cos(theta)**18 - 2.09654964966811e+130*cos(theta)**16 + 7.8132285080799e+129*cos(theta)**14 - 1.49057399210749e+129*cos(theta)**12 + 1.56652680699194e+128*cos(theta)**10 - 9.09596210511452e+126*cos(theta)**8 + 2.77436752661445e+125*cos(theta)**6 - 3.93713461676601e+123*cos(theta)**4 + 1.98177916951309e+121*cos(theta)**2 - 1.49794343878541e+118)*cos(64*phi)

#@torch.jit.script
def Yl82_m65(theta, phi):
    return 7.35375592777301e-121*(1.0 - cos(theta)**2)**32.5*(4.02044226936355e+131*cos(theta)**17 - 3.35447943946897e+131*cos(theta)**15 + 1.09385199113119e+131*cos(theta)**13 - 1.78868879052898e+130*cos(theta)**11 + 1.56652680699194e+129*cos(theta)**9 - 7.27676968409161e+127*cos(theta)**7 + 1.66462051596867e+126*cos(theta)**5 - 1.5748538467064e+124*cos(theta)**3 + 3.96355833902619e+121*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl82_m66(theta, phi):
    return 1.46606725268595e-122*(1.0 - cos(theta)**2)**33*(6.83475185791803e+132*cos(theta)**16 - 5.03171915920346e+132*cos(theta)**14 + 1.42200758847054e+132*cos(theta)**12 - 1.96755766958188e+131*cos(theta)**10 + 1.40987412629275e+130*cos(theta)**8 - 5.09373877886413e+128*cos(theta)**6 + 8.32310257984335e+126*cos(theta)**4 - 4.72456154011921e+124*cos(theta)**2 + 3.96355833902619e+121)*cos(66*phi)

#@torch.jit.script
def Yl82_m67(theta, phi):
    return 3.00262272756995e-124*(1.0 - cos(theta)**2)**33.5*(1.09356029726688e+134*cos(theta)**15 - 7.04440682288484e+133*cos(theta)**13 + 1.70640910616465e+133*cos(theta)**11 - 1.96755766958188e+132*cos(theta)**9 + 1.1278993010342e+131*cos(theta)**7 - 3.05624326731848e+129*cos(theta)**5 + 3.32924103193734e+127*cos(theta)**3 - 9.44912308023843e+124*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl82_m68(theta, phi):
    return 6.33008451553887e-126*(1.0 - cos(theta)**2)**34*(1.64034044590033e+135*cos(theta)**14 - 9.15772886975029e+134*cos(theta)**12 + 1.87705001678112e+134*cos(theta)**10 - 1.77080190262369e+133*cos(theta)**8 + 7.8952951072394e+131*cos(theta)**6 - 1.52812163365924e+130*cos(theta)**4 + 9.98772309581202e+127*cos(theta)**2 - 9.44912308023843e+124)*cos(68*phi)

#@torch.jit.script
def Yl82_m69(theta, phi):
    return 1.37675612417123e-127*(1.0 - cos(theta)**2)**34.5*(2.29647662426046e+136*cos(theta)**13 - 1.09892746437004e+136*cos(theta)**11 + 1.87705001678112e+135*cos(theta)**9 - 1.41664152209896e+134*cos(theta)**7 + 4.73717706434364e+132*cos(theta)**5 - 6.11248653463696e+130*cos(theta)**3 + 1.9975446191624e+128*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl82_m70(theta, phi):
    return 3.09715932392054e-129*(1.0 - cos(theta)**2)**35*(2.9854196115386e+137*cos(theta)**12 - 1.20882021080704e+137*cos(theta)**10 + 1.689345015103e+136*cos(theta)**8 - 9.91649065469269e+134*cos(theta)**6 + 2.36858853217182e+133*cos(theta)**4 - 1.83374596039109e+131*cos(theta)**2 + 1.9975446191624e+128)*cos(70*phi)

#@torch.jit.script
def Yl82_m71(theta, phi):
    return 7.22815086391266e-131*(1.0 - cos(theta)**2)**35.5*(3.58250353384631e+138*cos(theta)**11 - 1.20882021080704e+138*cos(theta)**9 + 1.3514760120824e+137*cos(theta)**7 - 5.94989439281561e+135*cos(theta)**5 + 9.47435412868728e+133*cos(theta)**3 - 3.66749192078217e+131*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl82_m72(theta, phi):
    return 1.75618597874515e-132*(1.0 - cos(theta)**2)**36*(3.94075388723095e+139*cos(theta)**10 - 1.08793818972633e+139*cos(theta)**8 + 9.46033208457683e+137*cos(theta)**6 - 2.97494719640781e+136*cos(theta)**4 + 2.84230623860618e+134*cos(theta)**2 - 3.66749192078217e+131)*cos(72*phi)

#@torch.jit.script
def Yl82_m73(theta, phi):
    return 4.46071684673175e-134*(1.0 - cos(theta)**2)**36.5*(3.94075388723095e+140*cos(theta)**9 - 8.70350551781068e+139*cos(theta)**7 + 5.67619925074609e+138*cos(theta)**5 - 1.18997887856312e+137*cos(theta)**3 + 5.68461247721237e+134*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl82_m74(theta, phi):
    return 1.19047725552401e-135*(1.0 - cos(theta)**2)**37*(3.54667849850785e+141*cos(theta)**8 - 6.09245386246747e+140*cos(theta)**6 + 2.83809962537305e+139*cos(theta)**4 - 3.56993663568937e+137*cos(theta)**2 + 5.68461247721237e+134)*cos(74*phi)

#@torch.jit.script
def Yl82_m75(theta, phi):
    return 3.35912590986758e-137*(1.0 - cos(theta)**2)**37.5*(2.83734279880628e+142*cos(theta)**7 - 3.65547231748048e+141*cos(theta)**5 + 1.13523985014922e+140*cos(theta)**3 - 7.13987327137874e+137*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl82_m76(theta, phi):
    return 1.01006359701407e-138*(1.0 - cos(theta)**2)**38*(1.9861399591644e+143*cos(theta)**6 - 1.82773615874024e+142*cos(theta)**4 + 3.40571955044766e+140*cos(theta)**2 - 7.13987327137874e+137)*cos(76*phi)

#@torch.jit.script
def Yl82_m77(theta, phi):
    return 3.27020163953829e-140*(1.0 - cos(theta)**2)**38.5*(1.19168397549864e+144*cos(theta)**5 - 7.31094463496097e+142*cos(theta)**3 + 6.81143910089531e+140*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl82_m78(theta, phi):
    return 1.15619087758245e-141*(1.0 - cos(theta)**2)**39*(5.95841987749319e+144*cos(theta)**4 - 2.19328339048829e+143*cos(theta)**2 + 6.81143910089531e+140)*cos(78*phi)

#@torch.jit.script
def Yl82_m79(theta, phi):
    return 4.55603031110722e-143*(1.0 - cos(theta)**2)**39.5*(2.38336795099728e+145*cos(theta)**3 - 4.38656678097658e+143*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl82_m80(theta, phi):
    return 2.06665731756785e-144*(1.0 - cos(theta)**2)**40*(7.15010385299183e+145*cos(theta)**2 - 4.38656678097658e+143)*cos(80*phi)

#@torch.jit.script
def Yl82_m81(theta, phi):
    return 16.3682411805081*(1.0 - cos(theta)**2)**40.5*cos(81*phi)*cos(theta)

#@torch.jit.script
def Yl82_m82(theta, phi):
    return 1.27814490032998*(1.0 - cos(theta)**2)**41*cos(82*phi)

#@torch.jit.script
def Yl83_m_minus_83(theta, phi):
    return 1.2819889538225*(1.0 - cos(theta)**2)**41.5*sin(83*phi)

#@torch.jit.script
def Yl83_m_minus_82(theta, phi):
    return 16.5172722476201*(1.0 - cos(theta)**2)**41*sin(82*phi)*cos(theta)

#@torch.jit.script
def Yl83_m_minus_81(theta, phi):
    return 1.27165413378911e-146*(1.0 - cos(theta)**2)**40.5*(1.17976713574365e+148*cos(theta)**2 - 7.15010385299183e+145)*sin(81*phi)

#@torch.jit.script
def Yl83_m_minus_80(theta, phi):
    return 2.82066531886291e-145*(1.0 - cos(theta)**2)**40*(3.93255711914551e+147*cos(theta)**3 - 7.15010385299183e+145*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl83_m_minus_79(theta, phi):
    return 7.20236881335263e-144*(1.0 - cos(theta)**2)**39.5*(9.83139279786376e+146*cos(theta)**4 - 3.57505192649591e+145*cos(theta)**2 + 1.09664169524415e+143)*sin(79*phi)

#@torch.jit.script
def Yl83_m_minus_78(theta, phi):
    return 2.04983009988826e-142*(1.0 - cos(theta)**2)**39*(1.96627855957275e+146*cos(theta)**5 - 1.19168397549864e+145*cos(theta)**3 + 1.09664169524415e+143*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl83_m_minus_77(theta, phi):
    return 6.37098275111623e-141*(1.0 - cos(theta)**2)**38.5*(3.27713093262125e+145*cos(theta)**6 - 2.9792099387466e+144*cos(theta)**4 + 5.48320847622073e+142*cos(theta)**2 - 1.13523985014922e+140)*sin(77*phi)

#@torch.jit.script
def Yl83_m_minus_76(theta, phi):
    return 2.13213863903882e-139*(1.0 - cos(theta)**2)**38*(4.68161561803036e+144*cos(theta)**7 - 5.95841987749319e+143*cos(theta)**5 + 1.82773615874024e+142*cos(theta)**3 - 1.13523985014922e+140*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl83_m_minus_75(theta, phi):
    return 7.60429569649727e-138*(1.0 - cos(theta)**2)**37.5*(5.85201952253796e+143*cos(theta)**8 - 9.93069979582199e+142*cos(theta)**6 + 4.56934039685061e+141*cos(theta)**4 - 5.67619925074609e+139*cos(theta)**2 + 8.92484158922342e+136)*sin(75*phi)

#@torch.jit.script
def Yl83_m_minus_74(theta, phi):
    return 2.86753544254554e-136*(1.0 - cos(theta)**2)**37*(6.50224391393106e+142*cos(theta)**9 - 1.41867139940314e+142*cos(theta)**7 + 9.13868079370121e+140*cos(theta)**5 - 1.89206641691537e+139*cos(theta)**3 + 8.92484158922342e+136*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl83_m_minus_73(theta, phi):
    return 1.13621003504546e-134*(1.0 - cos(theta)**2)**36.5*(6.50224391393106e+141*cos(theta)**10 - 1.77333924925393e+141*cos(theta)**8 + 1.52311346561687e+140*cos(theta)**6 - 4.73016604228841e+138*cos(theta)**4 + 4.46242079461171e+136*cos(theta)**2 - 5.68461247721237e+133)*sin(73*phi)

#@torch.jit.script
def Yl83_m_minus_72(theta, phi):
    return 4.70670807067363e-133*(1.0 - cos(theta)**2)**36*(5.91113083084642e+140*cos(theta)**11 - 1.97037694361547e+140*cos(theta)**9 + 2.17587637945267e+139*cos(theta)**7 - 9.46033208457683e+137*cos(theta)**5 + 1.4874735982039e+136*cos(theta)**3 - 5.68461247721237e+133*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl83_m_minus_71(theta, phi):
    return 2.02989575112448e-131*(1.0 - cos(theta)**2)**35.5*(4.92594235903868e+139*cos(theta)**12 - 1.97037694361547e+139*cos(theta)**10 + 2.71984547431584e+138*cos(theta)**8 - 1.57672201409614e+137*cos(theta)**6 + 3.71868399550976e+135*cos(theta)**4 - 2.84230623860618e+133*cos(theta)**2 + 3.05624326731848e+130)*sin(71*phi)

#@torch.jit.script
def Yl83_m_minus_70(theta, phi):
    return 9.08250762421223e-130*(1.0 - cos(theta)**2)**35*(3.78918643002976e+138*cos(theta)**13 - 1.79125176692316e+138*cos(theta)**11 + 3.0220505270176e+137*cos(theta)**9 - 2.25246002013734e+136*cos(theta)**7 + 7.43736799101952e+134*cos(theta)**5 - 9.47435412868728e+132*cos(theta)**3 + 3.05624326731848e+130*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl83_m_minus_69(theta, phi):
    return 4.20354309650058e-128*(1.0 - cos(theta)**2)**34.5*(2.70656173573554e+137*cos(theta)**14 - 1.4927098057693e+137*cos(theta)**12 + 3.0220505270176e+136*cos(theta)**10 - 2.81557502517167e+135*cos(theta)**8 + 1.23956133183659e+134*cos(theta)**6 - 2.36858853217182e+132*cos(theta)**4 + 1.52812163365924e+130*cos(theta)**2 - 1.426817585116e+127)*sin(69*phi)

#@torch.jit.script
def Yl83_m_minus_68(theta, phi):
    return 2.0071643182917e-126*(1.0 - cos(theta)**2)**34*(1.80437449049036e+136*cos(theta)**15 - 1.14823831213023e+136*cos(theta)**13 + 2.74731866092509e+135*cos(theta)**11 - 3.12841669463519e+134*cos(theta)**9 + 1.77080190262369e+133*cos(theta)**7 - 4.73717706434364e+131*cos(theta)**5 + 5.09373877886413e+129*cos(theta)**3 - 1.426817585116e+127*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl83_m_minus_67(theta, phi):
    return 9.86577922878173e-125*(1.0 - cos(theta)**2)**33.5*(1.12773405655647e+135*cos(theta)**16 - 8.20170222950164e+134*cos(theta)**14 + 2.28943221743757e+134*cos(theta)**12 - 3.12841669463519e+133*cos(theta)**10 + 2.21350237827962e+132*cos(theta)**8 - 7.8952951072394e+130*cos(theta)**6 + 1.27343469471603e+129*cos(theta)**4 - 7.13408792558001e+126*cos(theta)**2 + 5.90570192514902e+123)*sin(67*phi)

#@torch.jit.script
def Yl83_m_minus_66(theta, phi):
    return 4.98197430209356e-123*(1.0 - cos(theta)**2)**33*(6.63372974444985e+133*cos(theta)**17 - 5.46780148633442e+133*cos(theta)**15 + 1.76110170572121e+133*cos(theta)**13 - 2.84401517694108e+132*cos(theta)**11 + 2.45944708697735e+131*cos(theta)**9 - 1.1278993010342e+130*cos(theta)**7 + 2.54686938943207e+128*cos(theta)**5 - 2.37802930852667e+126*cos(theta)**3 + 5.90570192514902e+123*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl83_m_minus_65(theta, phi):
    return 2.58006632149456e-121*(1.0 - cos(theta)**2)**32.5*(3.68540541358325e+132*cos(theta)**18 - 3.41737592895902e+132*cos(theta)**16 + 1.25792978980086e+132*cos(theta)**14 - 2.3700126474509e+131*cos(theta)**12 + 2.45944708697735e+130*cos(theta)**10 - 1.40987412629275e+129*cos(theta)**8 + 4.24478231572011e+127*cos(theta)**6 - 5.94507327131668e+125*cos(theta)**4 + 2.95285096257451e+123*cos(theta)**2 - 2.20197685501455e+120)*sin(65*phi)

#@torch.jit.script
def Yl83_m_minus_64(theta, phi):
    return 1.36816516298103e-119*(1.0 - cos(theta)**2)**32*(1.93968705978066e+131*cos(theta)**19 - 2.01022113468177e+131*cos(theta)**17 + 8.38619859867243e+130*cos(theta)**15 - 1.82308665188531e+130*cos(theta)**13 + 2.23586098816123e+129*cos(theta)**11 - 1.56652680699194e+128*cos(theta)**9 + 6.06397473674301e+126*cos(theta)**7 - 1.18901465426334e+125*cos(theta)**5 + 9.84283654191503e+122*cos(theta)**3 - 2.20197685501455e+120*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl83_m_minus_63(theta, phi):
    return 7.41843324752135e-118*(1.0 - cos(theta)**2)**31.5*(9.69843529890329e+129*cos(theta)**20 - 1.11678951926765e+130*cos(theta)**18 + 5.24137412417027e+129*cos(theta)**16 - 1.30220475134665e+129*cos(theta)**14 + 1.86321749013436e+128*cos(theta)**12 - 1.56652680699194e+127*cos(theta)**10 + 7.57996842092876e+125*cos(theta)**8 - 1.98169109043889e+124*cos(theta)**6 + 2.46070913547876e+122*cos(theta)**4 - 1.10098842750727e+120*cos(theta)**2 + 7.48971719392703e+116)*sin(63*phi)

#@torch.jit.script
def Yl83_m_minus_62(theta, phi):
    return 4.10769574780988e-116*(1.0 - cos(theta)**2)**31*(4.61830252328728e+128*cos(theta)**21 - 5.87783957509291e+128*cos(theta)**19 + 3.08316124951192e+128*cos(theta)**17 - 8.68136500897767e+127*cos(theta)**15 + 1.43324422318028e+127*cos(theta)**13 - 1.42411527908359e+126*cos(theta)**11 + 8.42218713436529e+124*cos(theta)**9 - 2.83098727205556e+123*cos(theta)**7 + 4.92141827095752e+121*cos(theta)**5 - 3.66996142502425e+119*cos(theta)**3 + 7.48971719392703e+116*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl83_m_minus_61(theta, phi):
    return 2.32003004931995e-114*(1.0 - cos(theta)**2)**30.5*(2.09922841967604e+127*cos(theta)**22 - 2.93891978754645e+127*cos(theta)**20 + 1.71286736083996e+127*cos(theta)**18 - 5.42585313061104e+126*cos(theta)**16 + 1.0237458737002e+126*cos(theta)**14 - 1.18676273256966e+125*cos(theta)**12 + 8.42218713436529e+123*cos(theta)**10 - 3.53873409006945e+122*cos(theta)**8 + 8.20236378492919e+120*cos(theta)**6 - 9.17490356256062e+118*cos(theta)**4 + 3.74485859696352e+116*cos(theta)**2 - 2.34787372850377e+113)*sin(61*phi)

#@torch.jit.script
def Yl83_m_minus_60(theta, phi):
    return 1.33517678946737e-112*(1.0 - cos(theta)**2)**30*(9.12708008554799e+125*cos(theta)**23 - 1.39948561311736e+126*cos(theta)**21 + 9.01509137284188e+125*cos(theta)**19 - 3.19167831212414e+125*cos(theta)**17 + 6.82497249133465e+124*cos(theta)**15 - 9.12894409668965e+123*cos(theta)**13 + 7.6565337585139e+122*cos(theta)**11 - 3.93192676674383e+121*cos(theta)**9 + 1.17176625498988e+120*cos(theta)**7 - 1.83498071251212e+118*cos(theta)**5 + 1.24828619898784e+116*cos(theta)**3 - 2.34787372850377e+113*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl83_m_minus_59(theta, phi):
    return 7.82190277806005e-111*(1.0 - cos(theta)**2)**29.5*(3.802950035645e+124*cos(theta)**24 - 6.36129824144254e+124*cos(theta)**22 + 4.50754568642094e+124*cos(theta)**20 - 1.77315461784675e+124*cos(theta)**18 + 4.26560780708415e+123*cos(theta)**16 - 6.52067435477833e+122*cos(theta)**14 + 6.38044479876159e+121*cos(theta)**12 - 3.93192676674383e+120*cos(theta)**10 + 1.46470781873736e+119*cos(theta)**8 - 3.05830118752021e+117*cos(theta)**6 + 3.1207154974696e+115*cos(theta)**4 - 1.17393686425189e+113*cos(theta)**2 + 6.84112391755179e+109)*sin(59*phi)

#@torch.jit.script
def Yl83_m_minus_58(theta, phi):
    return 4.66043644840752e-109*(1.0 - cos(theta)**2)**29*(1.521180014258e+123*cos(theta)**25 - 2.76578184410545e+123*cos(theta)**23 + 2.14645032686711e+123*cos(theta)**21 - 9.33239272550919e+122*cos(theta)**19 + 2.50918106299068e+122*cos(theta)**17 - 4.34711623651888e+121*cos(theta)**15 + 4.90803446058584e+120*cos(theta)**13 - 3.57447887885803e+119*cos(theta)**11 + 1.6274531319304e+118*cos(theta)**9 - 4.36900169645744e+116*cos(theta)**7 + 6.2414309949392e+114*cos(theta)**5 - 3.91312288083962e+112*cos(theta)**3 + 6.84112391755179e+109*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl83_m_minus_57(theta, phi):
    return 2.82177785240865e-107*(1.0 - cos(theta)**2)**28.5*(5.85069236253076e+121*cos(theta)**26 - 1.1524091017106e+122*cos(theta)**24 + 9.75659239485052e+121*cos(theta)**22 - 4.6661963627546e+121*cos(theta)**20 + 1.39398947943927e+121*cos(theta)**18 - 2.7169476478243e+120*cos(theta)**16 + 3.50573890041845e+119*cos(theta)**14 - 2.97873239904836e+118*cos(theta)**12 + 1.6274531319304e+117*cos(theta)**10 - 5.4612521205718e+115*cos(theta)**8 + 1.04023849915653e+114*cos(theta)**6 - 9.78280720209905e+111*cos(theta)**4 + 3.42056195877589e+109*cos(theta)**2 - 1.86610035939765e+106)*sin(57*phi)

#@torch.jit.script
def Yl83_m_minus_56(theta, phi):
    return 1.7348771235664e-105*(1.0 - cos(theta)**2)**28*(2.16692309723362e+120*cos(theta)**27 - 4.60963640684242e+120*cos(theta)**25 + 4.24199669341327e+120*cos(theta)**23 - 2.22199826797838e+120*cos(theta)**21 + 7.33678673389087e+119*cos(theta)**19 - 1.59820449872018e+119*cos(theta)**17 + 2.33715926694564e+118*cos(theta)**15 - 2.29133261465258e+117*cos(theta)**13 + 1.47950284720945e+116*cos(theta)**11 - 6.06805791174644e+114*cos(theta)**9 + 1.48605499879505e+113*cos(theta)**7 - 1.95656144041981e+111*cos(theta)**5 + 1.14018731959196e+109*cos(theta)**3 - 1.86610035939765e+106*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl83_m_minus_55(theta, phi):
    return 1.08231863529359e-103*(1.0 - cos(theta)**2)**27.5*(7.73901106154863e+118*cos(theta)**28 - 1.77293707955478e+119*cos(theta)**26 + 1.76749862225553e+119*cos(theta)**24 - 1.00999921271744e+119*cos(theta)**22 + 3.66839336694544e+118*cos(theta)**20 - 8.87891388177877e+117*cos(theta)**18 + 1.46072454184102e+117*cos(theta)**16 - 1.63666615332327e+116*cos(theta)**14 + 1.23291903934121e+115*cos(theta)**12 - 6.06805791174644e+113*cos(theta)**10 + 1.85756874849381e+112*cos(theta)**8 - 3.26093573403302e+110*cos(theta)**6 + 2.85046829897991e+108*cos(theta)**4 - 9.33050179698825e+105*cos(theta)**2 + 4.79470801489633e+102)*sin(55*phi)

#@torch.jit.script
def Yl83_m_minus_54(theta, phi):
    return 6.84689516530791e-102*(1.0 - cos(theta)**2)**27*(2.66862450398229e+117*cos(theta)**29 - 6.56643362798065e+117*cos(theta)**27 + 7.06999448902212e+117*cos(theta)**25 - 4.39130092485846e+117*cos(theta)**23 + 1.74685398425973e+117*cos(theta)**21 - 4.67311256935724e+116*cos(theta)**19 + 8.59249730494719e+115*cos(theta)**17 - 1.09111076888218e+115*cos(theta)**15 + 9.48399261031699e+113*cos(theta)**13 - 5.51641628340585e+112*cos(theta)**11 + 2.06396527610423e+111*cos(theta)**9 - 4.65847962004717e+109*cos(theta)**7 + 5.70093659795982e+107*cos(theta)**5 - 3.11016726566275e+105*cos(theta)**3 + 4.79470801489633e+102*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl83_m_minus_53(theta, phi):
    return 4.3894953091829e-100*(1.0 - cos(theta)**2)**26.5*(8.89541501327428e+115*cos(theta)**30 - 2.34515486713595e+116*cos(theta)**28 + 2.71922864962389e+116*cos(theta)**26 - 1.82970871869102e+116*cos(theta)**24 + 7.94024538299878e+115*cos(theta)**22 - 2.33655628467862e+115*cos(theta)**20 + 4.77360961385955e+114*cos(theta)**18 - 6.81944230551364e+113*cos(theta)**16 + 6.77428043594071e+112*cos(theta)**14 - 4.59701356950488e+111*cos(theta)**12 + 2.06396527610423e+110*cos(theta)**10 - 5.82309952505896e+108*cos(theta)**8 + 9.5015609965997e+106*cos(theta)**6 - 7.77541816415688e+104*cos(theta)**4 + 2.39735400744816e+102*cos(theta)**2 - 1.16659562406237e+99)*sin(53*phi)

#@torch.jit.script
def Yl83_m_minus_52(theta, phi):
    return 2.85013144953582e-98*(1.0 - cos(theta)**2)**26*(2.86948871395945e+114*cos(theta)**31 - 8.08674092115844e+114*cos(theta)**29 + 1.00712172208292e+115*cos(theta)**27 - 7.31883487476409e+114*cos(theta)**25 + 3.45228060130382e+114*cos(theta)**23 - 1.11264584984696e+114*cos(theta)**21 + 2.51242611255766e+113*cos(theta)**19 - 4.01143665030214e+112*cos(theta)**17 + 4.5161869572938e+111*cos(theta)**15 - 3.53616428423452e+110*cos(theta)**13 + 1.87633206918566e+109*cos(theta)**11 - 6.47011058339884e+107*cos(theta)**9 + 1.3573658566571e+106*cos(theta)**7 - 1.55508363283138e+104*cos(theta)**5 + 7.99118002482721e+101*cos(theta)**3 - 1.16659562406237e+99*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl83_m_minus_51(theta, phi):
    return 1.8732975441188e-96*(1.0 - cos(theta)**2)**25.5*(8.96715223112327e+112*cos(theta)**32 - 2.69558030705281e+113*cos(theta)**30 + 3.59686329315329e+113*cos(theta)**28 - 2.81493649029388e+113*cos(theta)**26 + 1.43845025054326e+113*cos(theta)**24 - 5.05748113566801e+112*cos(theta)**22 + 1.25621305627883e+112*cos(theta)**20 - 2.22857591683452e+111*cos(theta)**18 + 2.82261684830863e+110*cos(theta)**16 - 2.52583163159609e+109*cos(theta)**14 + 1.56361005765472e+108*cos(theta)**12 - 6.47011058339884e+106*cos(theta)**10 + 1.69670732082138e+105*cos(theta)**8 - 2.59180605471896e+103*cos(theta)**6 + 1.9977950062068e+101*cos(theta)**4 - 5.83297812031183e+98*cos(theta)**2 + 2.7004528334777e+95)*sin(51*phi)

#@torch.jit.script
def Yl83_m_minus_50(theta, phi):
    return 1.24570765398148e-94*(1.0 - cos(theta)**2)**25*(2.71731885791614e+111*cos(theta)**33 - 8.69542034533166e+111*cos(theta)**31 + 1.24029768729424e+112*cos(theta)**29 - 1.04256907047922e+112*cos(theta)**27 + 5.75380100217303e+111*cos(theta)**25 - 2.19890484159479e+111*cos(theta)**23 + 5.98196693466109e+110*cos(theta)**21 - 1.1729346930708e+110*cos(theta)**19 + 1.66036285194625e+109*cos(theta)**17 - 1.68388775439739e+108*cos(theta)**15 + 1.20277696742671e+107*cos(theta)**13 - 5.88191871218077e+105*cos(theta)**11 + 1.88523035646819e+104*cos(theta)**9 - 3.70258007816994e+102*cos(theta)**7 + 3.9955900124136e+100*cos(theta)**5 - 1.94432604010394e+98*cos(theta)**3 + 2.7004528334777e+95*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl83_m_minus_49(theta, phi):
    return 8.3768629824346e-93*(1.0 - cos(theta)**2)**24.5*(7.99211428798866e+109*cos(theta)**34 - 2.71731885791614e+110*cos(theta)**32 + 4.13432562431413e+110*cos(theta)**30 - 3.7234609659972e+110*cos(theta)**28 + 2.21300038545117e+110*cos(theta)**26 - 9.16210350664495e+109*cos(theta)**24 + 2.71907587939141e+109*cos(theta)**22 - 5.86467346535401e+108*cos(theta)**20 + 9.22423806636806e+107*cos(theta)**18 - 1.05242984649837e+107*cos(theta)**16 + 8.59126405304792e+105*cos(theta)**14 - 4.90159892681731e+104*cos(theta)**12 + 1.88523035646819e+103*cos(theta)**10 - 4.62822509771243e+101*cos(theta)**8 + 6.65931668735601e+99*cos(theta)**6 - 4.86081510025986e+97*cos(theta)**4 + 1.35022641673885e+95*cos(theta)**2 - 5.97181077726161e+91)*sin(49*phi)

#@torch.jit.script
def Yl83_m_minus_48(theta, phi):
    return 5.69380251176972e-91*(1.0 - cos(theta)**2)**24*(2.28346122513962e+108*cos(theta)**35 - 8.23429956944286e+108*cos(theta)**33 + 1.33365342719811e+109*cos(theta)**31 - 1.28395205724041e+109*cos(theta)**29 + 8.1962977238932e+108*cos(theta)**27 - 3.66484140265798e+108*cos(theta)**25 + 1.18220690408322e+108*cos(theta)**23 - 2.79270165016858e+107*cos(theta)**21 + 4.85486214019372e+106*cos(theta)**19 - 6.19076380293159e+105*cos(theta)**17 + 5.72750936869861e+104*cos(theta)**15 - 3.77046071293639e+103*cos(theta)**13 + 1.71384577860745e+102*cos(theta)**11 - 5.14247233079158e+100*cos(theta)**9 + 9.51330955336573e+98*cos(theta)**7 - 9.72163020051972e+96*cos(theta)**5 + 4.50075472246283e+94*cos(theta)**3 - 5.97181077726161e+91*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl83_m_minus_47(theta, phi):
    return 3.91011290495497e-89*(1.0 - cos(theta)**2)**23.5*(6.34294784761004e+106*cos(theta)**36 - 2.42185281454202e+107*cos(theta)**34 + 4.16766695999408e+107*cos(theta)**32 - 4.27984019080138e+107*cos(theta)**30 + 2.92724918710472e+107*cos(theta)**28 - 1.40955438563769e+107*cos(theta)**26 + 4.92586210034675e+106*cos(theta)**24 - 1.26940984098572e+106*cos(theta)**22 + 2.42743107009686e+105*cos(theta)**20 - 3.43931322385088e+104*cos(theta)**18 + 3.57969335543663e+103*cos(theta)**16 - 2.69318622352599e+102*cos(theta)**14 + 1.42820481550621e+101*cos(theta)**12 - 5.14247233079158e+99*cos(theta)**10 + 1.18916369417072e+98*cos(theta)**8 - 1.62027170008662e+96*cos(theta)**6 + 1.12518868061571e+94*cos(theta)**4 - 2.98590538863081e+91*cos(theta)**2 + 1.26628727253215e+88)*sin(47*phi)

#@torch.jit.script
def Yl83_m_minus_46(theta, phi):
    return 2.71182609860722e-87*(1.0 - cos(theta)**2)**23*(1.7143102290838e+105*cos(theta)**37 - 6.91957947012005e+105*cos(theta)**35 + 1.26292938181639e+106*cos(theta)**33 - 1.38059360993593e+106*cos(theta)**31 + 1.00939627141542e+106*cos(theta)**29 - 5.22057179865809e+105*cos(theta)**27 + 1.9703448401387e+105*cos(theta)**25 - 5.51917322167703e+104*cos(theta)**23 + 1.15591955718898e+104*cos(theta)**21 - 1.81016485465836e+103*cos(theta)**19 + 2.10570197378625e+102*cos(theta)**17 - 1.79545748235066e+101*cos(theta)**15 + 1.09861908885093e+100*cos(theta)**13 - 4.67497484617417e+98*cos(theta)**11 + 1.32129299352302e+97*cos(theta)**9 - 2.3146738572666e+95*cos(theta)**7 + 2.25037736123142e+93*cos(theta)**5 - 9.95301796210268e+90*cos(theta)**3 + 1.26628727253215e+88*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl83_m_minus_45(theta, phi):
    return 1.8986656332305e-85*(1.0 - cos(theta)**2)**22.5*(4.51134270811525e+103*cos(theta)**38 - 1.92210540836668e+104*cos(theta)**36 + 3.71449818181291e+104*cos(theta)**34 - 4.31435503104978e+104*cos(theta)**32 + 3.3646542380514e+104*cos(theta)**30 - 1.86448992809218e+104*cos(theta)**28 + 7.57824938514884e+103*cos(theta)**26 - 2.2996555090321e+103*cos(theta)**24 + 5.25417980540446e+102*cos(theta)**22 - 9.05082427329179e+101*cos(theta)**20 + 1.16983442988125e+101*cos(theta)**18 - 1.12216092646916e+100*cos(theta)**16 + 7.84727920607807e+98*cos(theta)**14 - 3.89581237181181e+97*cos(theta)**12 + 1.32129299352302e+96*cos(theta)**10 - 2.89334232158325e+94*cos(theta)**8 + 3.75062893538569e+92*cos(theta)**6 - 2.48825449052567e+90*cos(theta)**4 + 6.33143636266074e+87*cos(theta)**2 - 2.58320537032262e+84)*sin(45*phi)

#@torch.jit.script
def Yl83_m_minus_44(theta, phi):
    return 1.34148486702454e-83*(1.0 - cos(theta)**2)**22*(1.15675454054237e+102*cos(theta)**39 - 5.19487948207211e+102*cos(theta)**37 + 1.06128519480369e+103*cos(theta)**35 - 1.30738031243933e+103*cos(theta)**33 + 1.08537233485529e+103*cos(theta)**31 - 6.42927561411095e+102*cos(theta)**29 + 2.80675903153661e+102*cos(theta)**27 - 9.19862203612838e+101*cos(theta)**25 + 2.28442600234976e+101*cos(theta)**23 - 4.30991632061514e+100*cos(theta)**21 + 6.15702331516449e+99*cos(theta)**19 - 6.6009466262892e+98*cos(theta)**17 + 5.23151947071871e+97*cos(theta)**15 - 2.99677874754754e+96*cos(theta)**13 + 1.20117544865729e+95*cos(theta)**11 - 3.21482480175917e+93*cos(theta)**9 + 5.35804133626528e+91*cos(theta)**7 - 4.97650898105134e+89*cos(theta)**5 + 2.11047878755358e+87*cos(theta)**3 - 2.58320537032262e+84*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl83_m_minus_43(theta, phi):
    return 9.56131516798588e-82*(1.0 - cos(theta)**2)**21.5*(2.89188635135593e+100*cos(theta)**40 - 1.36707354791371e+101*cos(theta)**38 + 2.94801443001025e+101*cos(theta)**36 - 3.84523621305684e+101*cos(theta)**34 + 3.39178854642278e+101*cos(theta)**32 - 2.14309187137032e+101*cos(theta)**30 + 1.0024139398345e+101*cos(theta)**28 - 3.53793155235707e+100*cos(theta)**26 + 9.51844167645735e+99*cos(theta)**24 - 1.95905287300688e+99*cos(theta)**22 + 3.07851165758224e+98*cos(theta)**20 - 3.66719257016067e+97*cos(theta)**18 + 3.26969966919919e+96*cos(theta)**16 - 2.14055624824825e+95*cos(theta)**14 + 1.00097954054774e+94*cos(theta)**12 - 3.21482480175917e+92*cos(theta)**10 + 6.6975516703316e+90*cos(theta)**8 - 8.29418163508557e+88*cos(theta)**6 + 5.27619696888395e+86*cos(theta)**4 - 1.29160268516131e+84*cos(theta)**2 + 5.08504994157996e+80)*sin(43*phi)

#@torch.jit.script
def Yl83_m_minus_42(theta, phi):
    return 6.87218488424811e-80*(1.0 - cos(theta)**2)**21*(7.05338134477056e+98*cos(theta)**41 - 3.50531678952234e+99*cos(theta)**39 + 7.96760656759526e+99*cos(theta)**37 - 1.09863891801624e+100*cos(theta)**35 + 1.02781471103721e+100*cos(theta)**33 - 6.91319958506554e+99*cos(theta)**31 + 3.45659979253277e+99*cos(theta)**29 - 1.31034501939151e+99*cos(theta)**27 + 3.80737667058294e+98*cos(theta)**25 - 8.51762118698644e+97*cos(theta)**23 + 1.46595793218202e+97*cos(theta)**21 - 1.93010135271614e+96*cos(theta)**19 + 1.92335274658776e+95*cos(theta)**17 - 1.42703749883216e+94*cos(theta)**15 + 7.699842619598e+92*cos(theta)**13 - 2.92256800159924e+91*cos(theta)**11 + 7.44172407814622e+89*cos(theta)**9 - 1.18488309072651e+88*cos(theta)**7 + 1.05523939377679e+86*cos(theta)**5 - 4.30534228387103e+83*cos(theta)**3 + 5.08504994157996e+80*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl83_m_minus_41(theta, phi):
    return 4.97937101135538e-78*(1.0 - cos(theta)**2)**20.5*(1.67937651065966e+97*cos(theta)**42 - 8.76329197380585e+97*cos(theta)**40 + 2.0967385704198e+98*cos(theta)**38 - 3.05177477226733e+98*cos(theta)**36 + 3.02298444422708e+98*cos(theta)**34 - 2.16037487033298e+98*cos(theta)**32 + 1.15219993084426e+98*cos(theta)**30 - 4.67980364068395e+97*cos(theta)**28 + 1.4643756425319e+97*cos(theta)**26 - 3.54900882791102e+96*cos(theta)**24 + 6.66344514628191e+95*cos(theta)**22 - 9.6505067635807e+94*cos(theta)**20 + 1.06852930365987e+94*cos(theta)**18 - 8.91898436770102e+92*cos(theta)**16 + 5.49988758542715e+91*cos(theta)**14 - 2.43547333466604e+90*cos(theta)**12 + 7.44172407814622e+88*cos(theta)**10 - 1.48110386340814e+87*cos(theta)**8 + 1.75873232296132e+85*cos(theta)**6 - 1.07633557096776e+83*cos(theta)**4 + 2.54252497078998e+80*cos(theta)**2 - 9.68580941253326e+76)*sin(41*phi)

#@torch.jit.script
def Yl83_m_minus_40(theta, phi):
    return 3.63596385275829e-76*(1.0 - cos(theta)**2)**20*(3.90552676897595e+95*cos(theta)**43 - 2.13738828629411e+96*cos(theta)**41 + 5.37625274466617e+96*cos(theta)**39 - 8.24803992504685e+96*cos(theta)**37 + 8.63709841207736e+96*cos(theta)**35 - 6.54659051616055e+96*cos(theta)**33 + 3.71677397046534e+96*cos(theta)**31 - 1.61372539333929e+96*cos(theta)**29 + 5.42361349085889e+95*cos(theta)**27 - 1.41960353116441e+95*cos(theta)**25 + 2.89715006360083e+94*cos(theta)**23 - 4.5954794112289e+93*cos(theta)**21 + 5.62383844031509e+92*cos(theta)**19 - 5.24646139276531e+91*cos(theta)**17 + 3.6665917236181e+90*cos(theta)**15 - 1.87344102666618e+89*cos(theta)**13 + 6.76520370740565e+87*cos(theta)**11 - 1.64567095934237e+86*cos(theta)**9 + 2.5124747470876e+84*cos(theta)**7 - 2.15267114193552e+82*cos(theta)**5 + 8.4750832359666e+79*cos(theta)**3 - 9.68580941253326e+76*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl83_m_minus_39(theta, phi):
    return 2.67484395331603e-74*(1.0 - cos(theta)**2)**19.5*(8.87619720221806e+93*cos(theta)**44 - 5.08901972927169e+94*cos(theta)**42 + 1.34406318616654e+95*cos(theta)**40 - 2.17053682238075e+95*cos(theta)**38 + 2.39919400335482e+95*cos(theta)**36 - 1.92546779887075e+95*cos(theta)**34 + 1.16149186577042e+95*cos(theta)**32 - 5.37908464446432e+94*cos(theta)**30 + 1.93700481816389e+94*cos(theta)**28 - 5.46001358140157e+93*cos(theta)**26 + 1.20714585983368e+93*cos(theta)**24 - 2.08885427783132e+92*cos(theta)**22 + 2.81191922015755e+91*cos(theta)**20 - 2.9147007737585e+90*cos(theta)**18 + 2.29161982726131e+89*cos(theta)**16 - 1.33817216190442e+88*cos(theta)**14 + 5.63766975617138e+86*cos(theta)**12 - 1.64567095934237e+85*cos(theta)**10 + 3.14059343385949e+83*cos(theta)**8 - 3.58778523655919e+81*cos(theta)**6 + 2.11877080899165e+79*cos(theta)**4 - 4.84290470626663e+76*cos(theta)**2 + 1.7896913179108e+73)*sin(39*phi)

#@torch.jit.script
def Yl83_m_minus_38(theta, phi):
    return 1.98191316809053e-72*(1.0 - cos(theta)**2)**19*(1.97248826715957e+92*cos(theta)**45 - 1.18349296029574e+93*cos(theta)**43 + 3.27820289308913e+93*cos(theta)**41 - 5.56547903174551e+93*cos(theta)**39 + 6.4843081171752e+93*cos(theta)**37 - 5.50133656820214e+93*cos(theta)**35 + 3.51967232051642e+93*cos(theta)**33 - 1.73518859498849e+93*cos(theta)**31 + 6.67932695918582e+92*cos(theta)**29 - 2.02222725237095e+92*cos(theta)**27 + 4.82858343933472e+91*cos(theta)**25 - 9.08197512100574e+90*cos(theta)**23 + 1.33900915245597e+90*cos(theta)**21 - 1.53405303882027e+89*cos(theta)**19 + 1.34801166309489e+88*cos(theta)**17 - 8.92114774602943e+86*cos(theta)**15 + 4.33666904320875e+85*cos(theta)**13 - 1.49606450849307e+84*cos(theta)**11 + 3.48954825984388e+82*cos(theta)**9 - 5.12540748079885e+80*cos(theta)**7 + 4.2375416179833e+78*cos(theta)**5 - 1.61430156875554e+76*cos(theta)**3 + 1.7896913179108e+73*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl83_m_minus_37(theta, phi):
    return 1.47861880142803e-70*(1.0 - cos(theta)**2)**18.5*(4.28801797208602e+90*cos(theta)**46 - 2.68975672794487e+91*cos(theta)**44 + 7.80524498354554e+91*cos(theta)**42 - 1.39136975793638e+92*cos(theta)**40 + 1.70639687294084e+92*cos(theta)**38 - 1.52814904672282e+92*cos(theta)**36 + 1.03519774132836e+92*cos(theta)**34 - 5.42246435933903e+91*cos(theta)**32 + 2.22644231972861e+91*cos(theta)**30 - 7.22224018703911e+90*cos(theta)**28 + 1.8571474766672e+90*cos(theta)**26 - 3.78415630041906e+89*cos(theta)**24 + 6.08640523843625e+88*cos(theta)**22 - 7.67026519410133e+87*cos(theta)**20 + 7.48895368386049e+86*cos(theta)**18 - 5.5757173412684e+85*cos(theta)**16 + 3.09762074514911e+84*cos(theta)**14 - 1.24672042374422e+83*cos(theta)**12 + 3.48954825984388e+81*cos(theta)**10 - 6.40675935099856e+79*cos(theta)**8 + 7.0625693633055e+77*cos(theta)**6 - 4.03575392188886e+75*cos(theta)**4 + 8.94845658955401e+72*cos(theta)**2 - 3.21539942132735e+69)*sin(37*phi)

#@torch.jit.script
def Yl83_m_minus_36(theta, phi):
    return 1.11044173543872e-68*(1.0 - cos(theta)**2)**18*(9.12344249380005e+88*cos(theta)**47 - 5.97723717321082e+89*cos(theta)**45 + 1.81517325198733e+90*cos(theta)**43 - 3.39358477545458e+90*cos(theta)**41 + 4.37537659728421e+90*cos(theta)**39 - 4.13013255871032e+90*cos(theta)**37 + 2.95770783236674e+90*cos(theta)**35 - 1.64317101798152e+90*cos(theta)**33 + 7.18207199912454e+89*cos(theta)**31 - 2.49042765070314e+89*cos(theta)**29 + 6.87832398765629e+88*cos(theta)**27 - 1.51366252016762e+88*cos(theta)**25 + 2.64626314714619e+87*cos(theta)**23 - 3.65250723528635e+86*cos(theta)**21 + 3.94155457045289e+85*cos(theta)**19 - 3.27983373015788e+84*cos(theta)**17 + 2.06508049676607e+83*cos(theta)**15 - 9.59015710572479e+81*cos(theta)**13 + 3.17231659985807e+80*cos(theta)**11 - 7.11862150110951e+78*cos(theta)**9 + 1.00893848047221e+77*cos(theta)**7 - 8.07150784377771e+74*cos(theta)**5 + 2.98281886318467e+72*cos(theta)**3 - 3.21539942132735e+69*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl83_m_minus_35(theta, phi):
    return 8.39247150883301e-67*(1.0 - cos(theta)**2)**17.5*(1.90071718620834e+87*cos(theta)**48 - 1.29939938548061e+88*cos(theta)**46 + 4.12539375451667e+88*cos(theta)**44 - 8.07996375108234e+88*cos(theta)**42 + 1.09384414932105e+89*cos(theta)**40 - 1.08687698913429e+89*cos(theta)**38 + 8.21585508990762e+88*cos(theta)**36 - 4.83285593523978e+88*cos(theta)**34 + 2.24439749972642e+88*cos(theta)**32 - 8.3014255023438e+87*cos(theta)**30 + 2.45654428130582e+87*cos(theta)**28 - 5.82177892372163e+86*cos(theta)**26 + 1.10260964464425e+86*cos(theta)**24 - 1.66023056149379e+85*cos(theta)**22 + 1.97077728522645e+84*cos(theta)**20 - 1.82212985008771e+83*cos(theta)**18 + 1.2906753104788e+82*cos(theta)**16 - 6.85011221837485e+80*cos(theta)**14 + 2.6435971665484e+79*cos(theta)**12 - 7.11862150110951e+77*cos(theta)**10 + 1.26117310059027e+76*cos(theta)**8 - 1.34525130729629e+74*cos(theta)**6 + 7.45704715796167e+71*cos(theta)**4 - 1.60769971066367e+69*cos(theta)**2 + 5.62920066758989e+65)*sin(35*phi)

#@torch.jit.script
def Yl83_m_minus_34(theta, phi):
    return 6.38159030453734e-65*(1.0 - cos(theta)**2)**17*(3.87901466573131e+85*cos(theta)**49 - 2.76467954357577e+86*cos(theta)**47 + 9.16754167670371e+86*cos(theta)**45 - 1.87906133746101e+87*cos(theta)**43 + 2.66791255931964e+87*cos(theta)**41 - 2.78686407470332e+87*cos(theta)**39 + 2.22050137565071e+87*cos(theta)**37 - 1.38081598149708e+87*cos(theta)**35 + 6.80120454462551e+86*cos(theta)**33 - 2.67787919430445e+86*cos(theta)**31 + 8.47084234933041e+85*cos(theta)**29 - 2.1562144161932e+85*cos(theta)**27 + 4.41043857857699e+84*cos(theta)**25 - 7.21839374562519e+83*cos(theta)**23 + 9.38465373917355e+82*cos(theta)**21 - 9.59015710572479e+81*cos(theta)**19 + 7.5922077086988e+80*cos(theta)**17 - 4.56674147891657e+79*cos(theta)**15 + 2.0335362819603e+78*cos(theta)**13 - 6.47147409191774e+76*cos(theta)**11 + 1.4013034451003e+75*cos(theta)**9 - 1.92178758185184e+73*cos(theta)**7 + 1.49140943159233e+71*cos(theta)**5 - 5.35899903554558e+68*cos(theta)**3 + 5.62920066758989e+65*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl83_m_minus_33(theta, phi):
    return 4.88097802358857e-63*(1.0 - cos(theta)**2)**16.5*(7.75802933146262e+83*cos(theta)**50 - 5.75974904911619e+84*cos(theta)**48 + 1.99294384276168e+85*cos(theta)**46 - 4.27059394877502e+85*cos(theta)**44 + 6.35217276028485e+85*cos(theta)**42 - 6.96716018675829e+85*cos(theta)**40 + 5.84342467276502e+85*cos(theta)**38 - 3.835599948603e+85*cos(theta)**36 + 2.00035427783103e+85*cos(theta)**34 - 8.36837248220141e+84*cos(theta)**32 + 2.82361411644347e+84*cos(theta)**30 - 7.70076577211855e+83*cos(theta)**28 + 1.69632253022192e+83*cos(theta)**26 - 3.00766406067716e+82*cos(theta)**24 + 4.26575169962434e+81*cos(theta)**22 - 4.7950785528624e+80*cos(theta)**20 + 4.21789317149933e+79*cos(theta)**18 - 2.85421342432286e+78*cos(theta)**16 + 1.45252591568593e+77*cos(theta)**14 - 5.39289507659811e+75*cos(theta)**12 + 1.4013034451003e+74*cos(theta)**10 - 2.4022344773148e+72*cos(theta)**8 + 2.48568238598722e+70*cos(theta)**6 - 1.33974975888639e+68*cos(theta)**4 + 2.81460033379495e+65*cos(theta)**2 - 9.62256524374341e+61)*sin(33*phi)

#@torch.jit.script
def Yl83_m_minus_32(theta, phi):
    return 3.75423051100115e-61*(1.0 - cos(theta)**2)**16*(1.52118222185542e+82*cos(theta)**51 - 1.17545898961555e+83*cos(theta)**49 + 4.2403060484291e+83*cos(theta)**47 - 9.4902087750556e+83*cos(theta)**45 + 1.47724947913601e+84*cos(theta)**43 - 1.69930736262397e+84*cos(theta)**41 + 1.4983140186577e+84*cos(theta)**39 - 1.03664863475757e+84*cos(theta)**37 + 5.71529793666009e+83*cos(theta)**35 - 2.53587044915194e+83*cos(theta)**33 + 9.10843263368861e+82*cos(theta)**31 - 2.65543647314433e+82*cos(theta)**29 + 6.28267603785896e+81*cos(theta)**27 - 1.20306562427086e+81*cos(theta)**25 + 1.85467465201058e+80*cos(theta)**23 - 2.28337073945828e+79*cos(theta)**21 + 2.21994377447333e+78*cos(theta)**19 - 1.67894907313109e+77*cos(theta)**17 + 9.68350610457288e+75*cos(theta)**15 - 4.1483808281524e+74*cos(theta)**13 + 1.27391222281845e+73*cos(theta)**11 - 2.66914941923866e+71*cos(theta)**9 + 3.55097483712461e+69*cos(theta)**7 - 2.67949951777279e+67*cos(theta)**5 + 9.38200111264982e+64*cos(theta)**3 - 9.62256524374341e+61*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl83_m_minus_31(theta, phi):
    return 2.90316371298274e-59*(1.0 - cos(theta)**2)**15.5*(2.92535042664503e+80*cos(theta)**52 - 2.3509179792311e+81*cos(theta)**50 + 8.83397093422728e+81*cos(theta)**48 - 2.06308886414252e+82*cos(theta)**46 + 3.35738517985457e+82*cos(theta)**44 - 4.04596991100946e+82*cos(theta)**42 + 3.74578504664424e+82*cos(theta)**40 - 2.72802272304623e+82*cos(theta)**38 + 1.58758276018336e+82*cos(theta)**36 - 7.45844249750572e+81*cos(theta)**34 + 2.84638519802769e+81*cos(theta)**32 - 8.8514549104811e+80*cos(theta)**30 + 2.24381287066391e+80*cos(theta)**28 - 4.62717547796486e+79*cos(theta)**26 + 7.7278110500441e+78*cos(theta)**24 - 1.03789579066286e+78*cos(theta)**22 + 1.10997188723667e+77*cos(theta)**20 - 9.32749485072829e+75*cos(theta)**18 + 6.05219131535805e+74*cos(theta)**16 - 2.963129162966e+73*cos(theta)**14 + 1.06159351901538e+72*cos(theta)**12 - 2.66914941923866e+70*cos(theta)**10 + 4.43871854640576e+68*cos(theta)**8 - 4.46583252962131e+66*cos(theta)**6 + 2.34550027816246e+64*cos(theta)**4 - 4.8112826218717e+61*cos(theta)**2 + 1.60912462269957e+58)*sin(31*phi)

#@torch.jit.script
def Yl83_m_minus_30(theta, phi):
    return 2.25663794985244e-57*(1.0 - cos(theta)**2)**15*(5.51952910687742e+78*cos(theta)**53 - 4.60964309653156e+79*cos(theta)**51 + 1.80285121106679e+80*cos(theta)**49 - 4.38955077477132e+80*cos(theta)**47 + 7.46085595523239e+80*cos(theta)**45 - 9.4092323511848e+80*cos(theta)**43 + 9.1360610893762e+80*cos(theta)**41 - 6.99493005909289e+80*cos(theta)**39 + 4.29076421671178e+80*cos(theta)**37 - 2.13098357071592e+80*cos(theta)**35 + 8.625409690993e+79*cos(theta)**33 - 2.85530803563906e+79*cos(theta)**31 + 7.73728576091005e+78*cos(theta)**29 - 1.71376869554254e+78*cos(theta)**27 + 3.09112442001764e+77*cos(theta)**25 - 4.51259039418633e+76*cos(theta)**23 + 5.2855804154127e+75*cos(theta)**21 - 4.90920781617278e+74*cos(theta)**19 + 3.56011253844591e+73*cos(theta)**17 - 1.97541944197733e+72*cos(theta)**15 + 8.16610399242598e+70*cos(theta)**13 - 2.42649947203515e+69*cos(theta)**11 + 4.9319094960064e+67*cos(theta)**9 - 6.37976075660188e+65*cos(theta)**7 + 4.69100055632491e+63*cos(theta)**5 - 1.60376087395723e+61*cos(theta)**3 + 1.60912462269957e+58*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl83_m_minus_29(theta, phi):
    return 1.76277949085046e-55*(1.0 - cos(theta)**2)**14.5*(1.02213501979211e+77*cos(theta)**54 - 8.8646982625607e+77*cos(theta)**52 + 3.60570242213359e+78*cos(theta)**50 - 9.14489744744025e+78*cos(theta)**48 + 1.62192520765921e+79*cos(theta)**46 - 2.13846189799654e+79*cos(theta)**44 + 2.17525264032767e+79*cos(theta)**42 - 1.74873251477322e+79*cos(theta)**40 + 1.12914847808205e+79*cos(theta)**38 - 5.91939880754422e+78*cos(theta)**36 + 2.53688520323324e+78*cos(theta)**34 - 8.92283761137207e+77*cos(theta)**32 + 2.57909525363668e+77*cos(theta)**30 - 6.12060248408051e+76*cos(theta)**28 + 1.18889400769909e+76*cos(theta)**26 - 1.88024599757764e+75*cos(theta)**24 + 2.40253655246032e+74*cos(theta)**22 - 2.45460390808639e+73*cos(theta)**20 + 1.97784029913662e+72*cos(theta)**18 - 1.23463715123583e+71*cos(theta)**16 + 5.83293142316141e+69*cos(theta)**14 - 2.02208289336262e+68*cos(theta)**12 + 4.9319094960064e+66*cos(theta)**10 - 7.97470094575235e+64*cos(theta)**8 + 7.81833426054152e+62*cos(theta)**6 - 4.00940218489309e+60*cos(theta)**4 + 8.04562311349783e+57*cos(theta)**2 - 2.63704461274921e+54)*sin(29*phi)

#@torch.jit.script
def Yl83_m_minus_28(theta, phi):
    return 1.38352924961911e-53*(1.0 - cos(theta)**2)**14*(1.85842730871294e+75*cos(theta)**55 - 1.67258457784164e+76*cos(theta)**53 + 7.07000474928154e+76*cos(theta)**51 - 1.86630560151842e+77*cos(theta)**49 + 3.45090469714727e+77*cos(theta)**47 - 4.75213755110343e+77*cos(theta)**45 + 5.05872707052946e+77*cos(theta)**43 - 4.26520125554445e+77*cos(theta)**41 + 2.89525250790269e+77*cos(theta)**39 - 1.59983751555249e+77*cos(theta)**37 + 7.24824343780925e+76*cos(theta)**35 - 2.70389018526426e+76*cos(theta)**33 + 8.31966210850543e+75*cos(theta)**31 - 2.11055258071742e+75*cos(theta)**29 + 4.40331113962627e+74*cos(theta)**27 - 7.52098399031056e+73*cos(theta)**25 + 1.04458110976535e+73*cos(theta)**23 - 1.16885900385066e+72*cos(theta)**21 + 1.04096857849296e+71*cos(theta)**19 - 7.26257147785784e+69*cos(theta)**17 + 3.88862094877427e+68*cos(theta)**15 - 1.55544837950971e+67*cos(theta)**13 + 4.48355408727854e+65*cos(theta)**11 - 8.86077882861372e+63*cos(theta)**9 + 1.11690489436307e+62*cos(theta)**7 - 8.01880436978617e+59*cos(theta)**5 + 2.68187437116594e+57*cos(theta)**3 - 2.63704461274921e+54*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl83_m_minus_27(theta, phi):
    return 1.09079678195221e-51*(1.0 - cos(theta)**2)**13.5*(3.31862019413024e+73*cos(theta)**56 - 3.09737884785489e+74*cos(theta)**54 + 1.35961629793876e+75*cos(theta)**52 - 3.73261120303684e+75*cos(theta)**50 + 7.18938478572347e+75*cos(theta)**48 - 1.03307338067466e+76*cos(theta)**46 + 1.1497106978476e+76*cos(theta)**44 - 1.01552410846296e+76*cos(theta)**42 + 7.23813126975672e+75*cos(theta)**40 - 4.21009872513814e+75*cos(theta)**38 + 2.01340095494701e+75*cos(theta)**36 - 7.95261819195372e+74*cos(theta)**34 + 2.59989440890795e+74*cos(theta)**32 - 7.03517526905806e+73*cos(theta)**30 + 1.57261112129509e+73*cos(theta)**28 - 2.89268615011944e+72*cos(theta)**26 + 4.35242129068898e+71*cos(theta)**24 - 5.31299547204847e+70*cos(theta)**22 + 5.20484289246478e+69*cos(theta)**20 - 4.03476193214324e+68*cos(theta)**18 + 2.43038809298392e+67*cos(theta)**16 - 1.11103455679265e+66*cos(theta)**14 + 3.73629507273212e+64*cos(theta)**12 - 8.86077882861372e+62*cos(theta)**10 + 1.39613111795384e+61*cos(theta)**8 - 1.33646739496436e+59*cos(theta)**6 + 6.70468592791486e+56*cos(theta)**4 - 1.3185223063746e+54*cos(theta)**2 + 4.24234976311005e+50)*sin(27*phi)

#@torch.jit.script
def Yl83_m_minus_26(theta, phi):
    return 8.6372923270973e-50*(1.0 - cos(theta)**2)**13*(5.82214069145656e+71*cos(theta)**57 - 5.63159790519071e+72*cos(theta)**55 + 2.56531376969577e+73*cos(theta)**53 - 7.31884549615066e+73*cos(theta)**51 + 1.46722138484152e+74*cos(theta)**49 - 2.19802846952055e+74*cos(theta)**47 + 2.55491266188357e+74*cos(theta)**45 - 2.36168397316968e+74*cos(theta)**43 + 1.76539787067237e+74*cos(theta)**41 - 1.07951249362516e+74*cos(theta)**39 + 5.4416242025595e+73*cos(theta)**37 - 2.27217662627249e+73*cos(theta)**35 + 7.87846790578166e+72*cos(theta)**33 - 2.2694113771155e+72*cos(theta)**31 + 5.42279696998309e+71*cos(theta)**29 - 1.07136524078498e+71*cos(theta)**27 + 1.74096851627559e+70*cos(theta)**25 - 2.30999803132542e+69*cos(theta)**23 + 2.47849661545942e+68*cos(theta)**21 - 2.12355891165434e+67*cos(theta)**19 + 1.42964005469642e+66*cos(theta)**17 - 7.40689704528433e+64*cos(theta)**15 + 2.87407313287086e+63*cos(theta)**13 - 8.05525348055793e+61*cos(theta)**11 + 1.55125679772649e+60*cos(theta)**9 - 1.90923913566337e+58*cos(theta)**7 + 1.34093718558297e+56*cos(theta)**5 - 4.39507435458201e+53*cos(theta)**3 + 4.24234976311005e+50*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl83_m_minus_25(theta, phi):
    return 6.86759797962786e-48*(1.0 - cos(theta)**2)**12.5*(1.00381736059596e+70*cos(theta)**58 - 1.00564248306977e+71*cos(theta)**56 + 4.75058105499217e+71*cos(theta)**54 - 1.40747028772128e+72*cos(theta)**52 + 2.93444276968305e+72*cos(theta)**50 - 4.57922597816781e+72*cos(theta)**48 + 5.55415796061645e+72*cos(theta)**46 - 5.36746357538564e+72*cos(theta)**44 + 4.20332826350564e+72*cos(theta)**42 - 2.69878123406291e+72*cos(theta)**40 + 1.4320063690946e+72*cos(theta)**38 - 6.31160173964581e+71*cos(theta)**36 + 2.31719644287696e+71*cos(theta)**34 - 7.09191055348594e+70*cos(theta)**32 + 1.80759898999436e+70*cos(theta)**30 - 3.82630443137493e+69*cos(theta)**28 + 6.69603275490612e+68*cos(theta)**26 - 9.62499179718925e+67*cos(theta)**24 + 1.12658937066337e+67*cos(theta)**22 - 1.06177945582717e+66*cos(theta)**20 + 7.94244474831347e+64*cos(theta)**18 - 4.62931065330271e+63*cos(theta)**16 + 2.05290938062204e+62*cos(theta)**14 - 6.71271123379827e+60*cos(theta)**12 + 1.55125679772649e+59*cos(theta)**10 - 2.38654891957922e+57*cos(theta)**8 + 2.23489530930495e+55*cos(theta)**6 - 1.0987685886455e+53*cos(theta)**4 + 2.12117488155503e+50*cos(theta)**2 - 6.7104551773332e+46)*sin(25*phi)

#@torch.jit.script
def Yl83_m_minus_24(theta, phi):
    return 5.4820469133926e-46*(1.0 - cos(theta)**2)**12*(1.7013853569423e+68*cos(theta)**59 - 1.76428505801714e+69*cos(theta)**57 + 8.63742009998576e+69*cos(theta)**55 - 2.65560431645525e+70*cos(theta)**53 + 5.7538093523197e+70*cos(theta)**51 - 9.34535913911799e+70*cos(theta)**49 + 1.18173573630137e+71*cos(theta)**47 - 1.19276968341903e+71*cos(theta)**45 + 9.77518200815266e+70*cos(theta)**43 - 6.58239325381197e+70*cos(theta)**41 + 3.67181120280668e+70*cos(theta)**39 - 1.70583830801238e+70*cos(theta)**37 + 6.62056126536274e+69*cos(theta)**35 - 2.14906380408665e+69*cos(theta)**33 + 5.83096448385278e+68*cos(theta)**31 - 1.31941532116377e+68*cos(theta)**29 + 2.48001213144671e+67*cos(theta)**27 - 3.8499967188757e+66*cos(theta)**25 + 4.89821465505814e+65*cos(theta)**23 - 5.05609264679604e+64*cos(theta)**21 + 4.18023407805972e+63*cos(theta)**19 - 2.72312391370748e+62*cos(theta)**17 + 1.36860625374803e+61*cos(theta)**15 - 5.16362402599867e+59*cos(theta)**13 + 1.41023345247863e+58*cos(theta)**11 - 2.65172102175469e+56*cos(theta)**9 + 3.19270758472136e+54*cos(theta)**7 - 2.19753717729101e+52*cos(theta)**5 + 7.07058293851675e+49*cos(theta)**3 - 6.7104551773332e+46*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl83_m_minus_23(theta, phi):
    return 4.39248474414302e-44*(1.0 - cos(theta)**2)**11.5*(2.83564226157051e+66*cos(theta)**60 - 3.04187078968473e+67*cos(theta)**58 + 1.54239644642603e+68*cos(theta)**56 - 4.91778577121342e+68*cos(theta)**54 + 1.10650179852302e+69*cos(theta)**52 - 1.8690718278236e+69*cos(theta)**50 + 2.46194945062786e+69*cos(theta)**48 - 2.59297757265007e+69*cos(theta)**46 + 2.22163227458015e+69*cos(theta)**44 - 1.56723648900285e+69*cos(theta)**42 + 9.17952800701669e+68*cos(theta)**40 - 4.48904817897995e+68*cos(theta)**38 + 1.83904479593409e+68*cos(theta)**36 - 6.3207758943725e+67*cos(theta)**34 + 1.82217640120399e+67*cos(theta)**32 - 4.39805107054589e+66*cos(theta)**30 + 8.85718618373826e+65*cos(theta)**28 - 1.48076796879835e+65*cos(theta)**26 + 2.04092277294089e+64*cos(theta)**24 - 2.29822393036184e+63*cos(theta)**22 + 2.09011703902986e+62*cos(theta)**20 - 1.51284661872637e+61*cos(theta)**18 + 8.55378908592518e+59*cos(theta)**16 - 3.68830287571334e+58*cos(theta)**14 + 1.17519454373219e+57*cos(theta)**12 - 2.65172102175469e+55*cos(theta)**10 + 3.9908844809017e+53*cos(theta)**8 - 3.66256196215168e+51*cos(theta)**6 + 1.76764573462919e+49*cos(theta)**4 - 3.3552275886666e+46*cos(theta)**2 + 1.04524223946e+43)*sin(23*phi)

#@torch.jit.script
def Yl83_m_minus_22(theta, phi):
    return 3.53206032116106e-42*(1.0 - cos(theta)**2)**11*(4.64859387142706e+64*cos(theta)**61 - 5.15571320285547e+65*cos(theta)**59 + 2.7059586779404e+66*cos(theta)**57 - 8.9414286749335e+66*cos(theta)**55 + 2.08773924249626e+67*cos(theta)**53 - 3.66484672122274e+67*cos(theta)**51 + 5.0243866339344e+67*cos(theta)**49 - 5.51697355882993e+67*cos(theta)**47 + 4.93696061017811e+67*cos(theta)**45 - 3.64473602093686e+67*cos(theta)**43 + 2.23890927000407e+67*cos(theta)**41 - 1.15103799461024e+67*cos(theta)**39 + 4.97039134036242e+66*cos(theta)**37 - 1.80593596982071e+66*cos(theta)**35 + 5.52174667031513e+65*cos(theta)**33 - 1.418726151789e+65*cos(theta)**31 + 3.05420213232354e+64*cos(theta)**29 - 5.48432581036425e+63*cos(theta)**27 + 8.16369109176357e+62*cos(theta)**25 - 9.99227795809495e+61*cos(theta)**23 + 9.95293828109457e+60*cos(theta)**21 - 7.96235062487566e+59*cos(theta)**19 + 5.03164063877952e+58*cos(theta)**17 - 2.45886858380889e+57*cos(theta)**15 + 9.03995802870916e+55*cos(theta)**13 - 2.41065547432244e+54*cos(theta)**11 + 4.43431608989078e+52*cos(theta)**9 - 5.2322313745024e+50*cos(theta)**7 + 3.53529146925837e+48*cos(theta)**5 - 1.1184091962222e+46*cos(theta)**3 + 1.04524223946e+43*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl83_m_minus_21(theta, phi):
    return 2.84982771814728e-40*(1.0 - cos(theta)**2)**10.5*(7.49773205068881e+62*cos(theta)**62 - 8.59285533809244e+63*cos(theta)**60 + 4.66544599644896e+64*cos(theta)**58 - 1.59668369195241e+65*cos(theta)**56 + 3.86618378240049e+65*cos(theta)**54 - 7.04778215619758e+65*cos(theta)**52 + 1.00487732678688e+66*cos(theta)**50 - 1.1493694914229e+66*cos(theta)**48 + 1.07325230656046e+66*cos(theta)**46 - 8.28349095667468e+65*cos(theta)**44 + 5.33073635715255e+65*cos(theta)**42 - 2.87759498652561e+65*cos(theta)**40 + 1.307997721148e+65*cos(theta)**38 - 5.01648880505754e+64*cos(theta)**36 + 1.62404313832798e+64*cos(theta)**34 - 4.43351922434062e+63*cos(theta)**32 + 1.01806737744118e+63*cos(theta)**30 - 1.9586877894158e+62*cos(theta)**28 + 3.13988118913983e+61*cos(theta)**26 - 4.16344914920623e+60*cos(theta)**24 + 4.52406285504299e+59*cos(theta)**22 - 3.98117531243783e+58*cos(theta)**20 + 2.79535591043307e+57*cos(theta)**18 - 1.53679286488056e+56*cos(theta)**16 + 6.4571128776494e+54*cos(theta)**14 - 2.00887956193537e+53*cos(theta)**12 + 4.43431608989078e+51*cos(theta)**10 - 6.54028921812799e+49*cos(theta)**8 + 5.89215244876396e+47*cos(theta)**6 - 2.7960229905555e+45*cos(theta)**4 + 5.2262111973e+42*cos(theta)**2 - 1.60559483788018e+39)*sin(21*phi)

#@torch.jit.script
def Yl83_m_minus_20(theta, phi):
    return 2.30677667075696e-38*(1.0 - cos(theta)**2)**10*(1.19011619852203e+61*cos(theta)**63 - 1.40866480952335e+62*cos(theta)**61 + 7.90753558720164e+62*cos(theta)**59 - 2.80119945956563e+63*cos(theta)**57 + 7.02942505890998e+63*cos(theta)**55 - 1.32977021815049e+64*cos(theta)**53 + 1.97034769958212e+64*cos(theta)**51 - 2.34565202331205e+64*cos(theta)**49 + 2.28351554587332e+64*cos(theta)**47 - 1.84077576814993e+64*cos(theta)**45 + 1.23970612957036e+64*cos(theta)**43 - 7.01852435737953e+63*cos(theta)**41 + 3.35384031063591e+63*cos(theta)**39 - 1.35580778515069e+63*cos(theta)**37 + 4.64012325236566e+62*cos(theta)**35 - 1.34349067404261e+62*cos(theta)**33 + 3.28408831432638e+61*cos(theta)**31 - 6.75409582557173e+60*cos(theta)**29 + 1.16291895894068e+60*cos(theta)**27 - 1.66537965968249e+59*cos(theta)**25 + 1.96698385001869e+58*cos(theta)**23 - 1.89579776782754e+57*cos(theta)**21 + 1.47123995285951e+56*cos(theta)**19 - 9.03995802870916e+54*cos(theta)**17 + 4.30474191843293e+53*cos(theta)**15 - 1.54529197071951e+52*cos(theta)**13 + 4.03119644535525e+50*cos(theta)**11 - 7.26698802014222e+48*cos(theta)**9 + 8.41736064109137e+46*cos(theta)**7 - 5.592045981111e+44*cos(theta)**5 + 1.7420703991e+42*cos(theta)**3 - 1.60559483788018e+39*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl83_m_minus_19(theta, phi):
    return 1.87289810371175e-36*(1.0 - cos(theta)**2)**9.5*(1.85955656019068e+59*cos(theta)**64 - 2.27204001536024e+60*cos(theta)**62 + 1.31792259786694e+61*cos(theta)**60 - 4.8296542406304e+61*cos(theta)**58 + 1.25525447480535e+62*cos(theta)**56 - 2.46253744101942e+62*cos(theta)**54 + 3.78913019150408e+62*cos(theta)**52 - 4.69130404662409e+62*cos(theta)**50 + 4.75732405390274e+62*cos(theta)**48 - 4.00168645249985e+62*cos(theta)**46 + 2.81751393084173e+62*cos(theta)**44 - 1.67107722794751e+62*cos(theta)**42 + 8.38460077658977e+61*cos(theta)**40 - 3.56791522408075e+61*cos(theta)**38 + 1.28892312565713e+61*cos(theta)**36 - 3.95144315894886e+60*cos(theta)**34 + 1.02627759822699e+60*cos(theta)**32 - 2.25136527519058e+59*cos(theta)**30 + 4.15328199621671e+58*cos(theta)**28 - 6.4053063833942e+57*cos(theta)**26 + 8.19576604174454e+56*cos(theta)**24 - 8.61726258103426e+55*cos(theta)**22 + 7.35619976429754e+54*cos(theta)**20 - 5.02219890483842e+53*cos(theta)**18 + 2.69046369902058e+52*cos(theta)**16 - 1.10377997908537e+51*cos(theta)**14 + 3.35933037112938e+49*cos(theta)**12 - 7.26698802014222e+47*cos(theta)**10 + 1.05217008013642e+46*cos(theta)**8 - 9.320076635185e+43*cos(theta)**6 + 4.35517599775e+41*cos(theta)**4 - 8.02797418940092e+38*cos(theta)**2 + 2.43567178076484e+35)*sin(19*phi)

#@torch.jit.script
def Yl83_m_minus_18(theta, phi):
    return 1.52500375883672e-34*(1.0 - cos(theta)**2)**9*(2.86085624644719e+57*cos(theta)**65 - 3.60641272279404e+58*cos(theta)**63 + 2.1605288489622e+59*cos(theta)**61 - 8.18585464513627e+59*cos(theta)**59 + 2.20220083299185e+60*cos(theta)**57 - 4.47734080185349e+60*cos(theta)**55 + 7.1493022481209e+60*cos(theta)**53 - 9.19863538553744e+60*cos(theta)**51 + 9.70882459980152e+60*cos(theta)**49 - 8.51422649468053e+60*cos(theta)**47 + 6.26114206853718e+60*cos(theta)**45 - 3.88622611150583e+60*cos(theta)**43 + 2.04502457965604e+60*cos(theta)**41 - 9.14850057456603e+59*cos(theta)**39 + 3.48357601528953e+59*cos(theta)**37 - 1.12898375969967e+59*cos(theta)**35 + 3.10993211583938e+58*cos(theta)**33 - 7.26246862964702e+57*cos(theta)**31 + 1.43216620559197e+57*cos(theta)**29 - 2.37233569755341e+56*cos(theta)**27 + 3.27830641669782e+55*cos(theta)**25 - 3.7466359047975e+54*cos(theta)**23 + 3.50295226871311e+53*cos(theta)**21 - 2.64326258149391e+52*cos(theta)**19 + 1.58262570530623e+51*cos(theta)**17 - 7.35853319390245e+49*cos(theta)**15 + 2.58410028548414e+48*cos(theta)**13 - 6.60635274558383e+46*cos(theta)**11 + 1.16907786681825e+45*cos(theta)**9 - 1.33143951931214e+43*cos(theta)**7 + 8.7103519955e+40*cos(theta)**5 - 2.67599139646697e+38*cos(theta)**3 + 2.43567178076484e+35*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl83_m_minus_17(theta, phi):
    return 1.24509809541783e-32*(1.0 - cos(theta)**2)**8.5*(4.33463067643514e+55*cos(theta)**66 - 5.63501987936569e+56*cos(theta)**64 + 3.48472394993903e+57*cos(theta)**62 - 1.36430910752271e+58*cos(theta)**60 + 3.79689798791698e+58*cos(theta)**58 - 7.99525143188123e+58*cos(theta)**56 + 1.32394486076313e+59*cos(theta)**54 - 1.76896834337258e+59*cos(theta)**52 + 1.9417649199603e+59*cos(theta)**50 - 1.77379718639178e+59*cos(theta)**48 + 1.36111784098634e+59*cos(theta)**46 - 8.83233207160417e+58*cos(theta)**44 + 4.86910614203819e+58*cos(theta)**42 - 2.28712514364151e+58*cos(theta)**40 + 9.16730530339351e+57*cos(theta)**38 - 3.13606599916576e+57*cos(theta)**36 + 9.14685916423347e+56*cos(theta)**34 - 2.26952144676469e+56*cos(theta)**32 + 4.77388735197323e+55*cos(theta)**30 - 8.47262749126216e+54*cos(theta)**28 + 1.26088708334531e+54*cos(theta)**26 - 1.56109829366563e+53*cos(theta)**24 + 1.59225103123323e+52*cos(theta)**22 - 1.32163129074695e+51*cos(theta)**20 + 8.79236502947903e+49*cos(theta)**18 - 4.59908324618903e+48*cos(theta)**16 + 1.84578591820296e+47*cos(theta)**14 - 5.50529395465319e+45*cos(theta)**12 + 1.16907786681825e+44*cos(theta)**10 - 1.66429939914018e+42*cos(theta)**8 + 1.45172533258333e+40*cos(theta)**6 - 6.68997849116744e+37*cos(theta)**4 + 1.21783589038242e+35*cos(theta)**2 - 3.65387305845311e+31)*sin(17*phi)

#@torch.jit.script
def Yl83_m_minus_16(theta, phi):
    return 1.01915671465815e-30*(1.0 - cos(theta)**2)**8*(6.46959802453006e+53*cos(theta)**67 - 8.66926135287028e+54*cos(theta)**65 + 5.53130785704607e+55*cos(theta)**63 - 2.23657230741428e+56*cos(theta)**61 + 6.43542031850336e+56*cos(theta)**59 - 1.40267568980373e+57*cos(theta)**57 + 2.40717247411478e+57*cos(theta)**55 - 3.33767611957091e+57*cos(theta)**53 + 3.80738219600059e+57*cos(theta)**51 - 3.6199942579424e+57*cos(theta)**49 + 2.89599540635392e+57*cos(theta)**47 - 1.96274046035648e+57*cos(theta)**45 + 1.13235026559028e+57*cos(theta)**43 - 5.57835400888173e+56*cos(theta)**41 + 2.35059110343423e+56*cos(theta)**39 - 8.47585405179935e+55*cos(theta)**37 + 2.61338833263813e+55*cos(theta)**35 - 6.87733771746877e+54*cos(theta)**33 + 1.53996366192685e+54*cos(theta)**31 - 2.92159568664213e+53*cos(theta)**29 + 4.6699521605382e+52*cos(theta)**27 - 6.24439317466251e+51*cos(theta)**25 + 6.92283057057928e+50*cos(theta)**23 - 6.29348233689025e+49*cos(theta)**21 + 4.62756054183107e+48*cos(theta)**19 - 2.70534308599355e+47*cos(theta)**17 + 1.23052394546864e+46*cos(theta)**15 - 4.23484150357938e+44*cos(theta)**13 + 1.06279806074386e+43*cos(theta)**11 - 1.8492215546002e+41*cos(theta)**9 + 2.07389333226191e+39*cos(theta)**7 - 1.33799569823349e+37*cos(theta)**5 + 4.05945296794141e+34*cos(theta)**3 - 3.65387305845311e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl83_m_minus_15(theta, phi):
    return 8.36205507851314e-29*(1.0 - cos(theta)**2)**7.5*(9.51411474195598e+51*cos(theta)**68 - 1.31352444740459e+53*cos(theta)**66 + 8.64266852663449e+53*cos(theta)**64 - 3.60737468937787e+54*cos(theta)**62 + 1.07257005308389e+55*cos(theta)**60 - 2.41840636173056e+55*cos(theta)**58 + 4.29852227520496e+55*cos(theta)**56 - 6.1808817029091e+55*cos(theta)**54 + 7.32188883846268e+55*cos(theta)**52 - 7.2399885158848e+55*cos(theta)**50 + 6.03332376323733e+55*cos(theta)**48 - 4.26682708773148e+55*cos(theta)**46 + 2.57352333088699e+55*cos(theta)**44 - 1.32817952592422e+55*cos(theta)**42 + 5.87647775858558e+54*cos(theta)**40 - 2.23048790836825e+54*cos(theta)**38 + 7.25941203510592e+53*cos(theta)**36 - 2.02274638749081e+53*cos(theta)**34 + 4.8123864435214e+52*cos(theta)**32 - 9.73865228880708e+51*cos(theta)**30 + 1.66784005733507e+51*cos(theta)**28 - 2.4016896825625e+50*cos(theta)**26 + 2.88451273774137e+49*cos(theta)**24 - 2.86067378949557e+48*cos(theta)**22 + 2.31378027091553e+47*cos(theta)**20 - 1.50296838110753e+46*cos(theta)**18 + 7.69077465917898e+44*cos(theta)**16 - 3.02488678827099e+43*cos(theta)**14 + 8.85665050619883e+41*cos(theta)**12 - 1.8492215546002e+40*cos(theta)**10 + 2.59236666532738e+38*cos(theta)**8 - 2.22999283038915e+36*cos(theta)**6 + 1.01486324198535e+34*cos(theta)**4 - 1.82693652922656e+31*cos(theta)**2 + 5.4276189222417e+27)*sin(15*phi)

#@torch.jit.script
def Yl83_m_minus_14(theta, phi):
    return 6.87623336027961e-27*(1.0 - cos(theta)**2)**7*(1.37885720897913e+50*cos(theta)**69 - 1.9604842498576e+51*cos(theta)**67 + 1.32964131178992e+52*cos(theta)**65 - 5.72599157044107e+52*cos(theta)**63 + 1.75831156243261e+53*cos(theta)**61 - 4.09899383344163e+53*cos(theta)**59 + 7.54126714948239e+53*cos(theta)**57 - 1.1237966732562e+54*cos(theta)**55 + 1.3814884600873e+54*cos(theta)**53 - 1.41960559134996e+54*cos(theta)**51 + 1.23129056392599e+54*cos(theta)**49 - 9.07835550581166e+53*cos(theta)**47 + 5.71894073530443e+53*cos(theta)**45 - 3.08878959517261e+53*cos(theta)**43 + 1.43328725819161e+53*cos(theta)**41 - 5.71919976504679e+52*cos(theta)**39 + 1.96200325273133e+52*cos(theta)**37 - 5.7792753928309e+51*cos(theta)**35 + 1.45829892227921e+51*cos(theta)**33 - 3.14150073832487e+50*cos(theta)**31 + 5.75117261150025e+49*cos(theta)**29 - 8.89514697245371e+48*cos(theta)**27 + 1.15380509509655e+48*cos(theta)**25 - 1.24377121282416e+47*cos(theta)**23 + 1.1018001290074e+46*cos(theta)**21 - 7.91035990056593e+44*cos(theta)**19 + 4.52398509363469e+43*cos(theta)**17 - 2.01659119218066e+42*cos(theta)**15 + 6.81280808169141e+40*cos(theta)**13 - 1.681110504182e+39*cos(theta)**11 + 2.88040740591931e+37*cos(theta)**9 - 3.18570404341306e+35*cos(theta)**7 + 2.0297264839707e+33*cos(theta)**5 - 6.08978843075518e+30*cos(theta)**3 + 5.4276189222417e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl83_m_minus_13(theta, phi):
    return 5.66611642730628e-25*(1.0 - cos(theta)**2)**6.5*(1.96979601282732e+48*cos(theta)**70 - 2.88306507331999e+49*cos(theta)**68 + 2.01460804816655e+50*cos(theta)**66 - 8.94686182881417e+50*cos(theta)**64 + 2.83598639102034e+51*cos(theta)**62 - 6.83165638906938e+51*cos(theta)**60 + 1.30021847404869e+52*cos(theta)**58 - 2.00677977367179e+52*cos(theta)**56 + 2.55831196312463e+52*cos(theta)**54 - 2.73001075259608e+52*cos(theta)**52 + 2.46258112785197e+52*cos(theta)**50 - 1.89132406371076e+52*cos(theta)**48 + 1.24324798593575e+52*cos(theta)**46 - 7.01997635266502e+51*cos(theta)**44 + 3.41258870998001e+51*cos(theta)**42 - 1.4297999412617e+51*cos(theta)**40 + 5.16316645455613e+50*cos(theta)**38 - 1.60535427578636e+50*cos(theta)**36 + 4.2891144772918e+49*cos(theta)**34 - 9.81718980726521e+48*cos(theta)**32 + 1.91705753716675e+48*cos(theta)**30 - 3.17683820444776e+47*cos(theta)**28 + 4.43771190421749e+46*cos(theta)**26 - 5.182380053434e+45*cos(theta)**24 + 5.00818240457908e+44*cos(theta)**22 - 3.95517995028296e+43*cos(theta)**20 + 2.51332505201927e+42*cos(theta)**18 - 1.26036949511291e+41*cos(theta)**16 + 4.86629148692243e+39*cos(theta)**14 - 1.40092542015167e+38*cos(theta)**12 + 2.88040740591931e+36*cos(theta)**10 - 3.98213005426633e+34*cos(theta)**8 + 3.38287747328451e+32*cos(theta)**6 - 1.5224471076888e+30*cos(theta)**4 + 2.71380946112085e+27*cos(theta)**2 - 7.99354774998777e+23)*sin(13*phi)

#@torch.jit.script
def Yl83_m_minus_12(theta, phi):
    return 4.67789301402734e-23*(1.0 - cos(theta)**2)**6*(2.77436058144694e+46*cos(theta)**71 - 4.17835517872463e+47*cos(theta)**69 + 3.00687768383067e+48*cos(theta)**67 - 1.37644028135603e+49*cos(theta)**65 + 4.50156570003229e+49*cos(theta)**63 - 1.11994367033924e+50*cos(theta)**61 + 2.20376012550625e+50*cos(theta)**59 - 3.52066626959962e+50*cos(theta)**57 + 4.65147629659023e+50*cos(theta)**55 - 5.15096368414354e+50*cos(theta)**53 + 4.82859044676857e+50*cos(theta)**51 - 3.85984502798115e+50*cos(theta)**49 + 2.64520848071435e+50*cos(theta)**47 - 1.55999474503667e+50*cos(theta)**45 + 7.93625281390701e+49*cos(theta)**43 - 3.48731692990658e+49*cos(theta)**41 + 1.32388883450157e+49*cos(theta)**39 - 4.33879533996314e+48*cos(theta)**37 + 1.22546127922623e+48*cos(theta)**35 - 2.97490600220158e+47*cos(theta)**33 + 6.18405657150564e+46*cos(theta)**31 - 1.09546144980957e+46*cos(theta)**29 + 1.64359700156203e+45*cos(theta)**27 - 2.0729520213736e+44*cos(theta)**25 + 2.17747061068656e+43*cos(theta)**23 - 1.88341902394427e+42*cos(theta)**21 + 1.32280265895751e+41*cos(theta)**19 - 7.41393820654653e+39*cos(theta)**17 + 3.24419432461496e+38*cos(theta)**15 - 1.0776349385782e+37*cos(theta)**13 + 2.61855218719938e+35*cos(theta)**11 - 4.42458894918481e+33*cos(theta)**9 + 4.83268210469215e+31*cos(theta)**7 - 3.04489421537759e+29*cos(theta)**5 + 9.04603153706949e+26*cos(theta)**3 - 7.99354774998777e+23*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl83_m_minus_11(theta, phi):
    return 3.8688183217449e-21*(1.0 - cos(theta)**2)**5.5*(3.85327858534297e+44*cos(theta)**72 - 5.96907882674947e+45*cos(theta)**70 + 4.4218789468098e+46*cos(theta)**68 - 2.08551557781216e+47*cos(theta)**66 + 7.03369640630045e+47*cos(theta)**64 - 1.80636075861168e+48*cos(theta)**62 + 3.67293354251042e+48*cos(theta)**60 - 6.07011425793038e+48*cos(theta)**58 + 8.30620767248255e+48*cos(theta)**56 - 9.53882163730286e+48*cos(theta)**54 + 9.28575085917033e+48*cos(theta)**52 - 7.7196900559623e+48*cos(theta)**50 + 5.51085100148824e+48*cos(theta)**48 - 3.39129292399276e+48*cos(theta)**46 + 1.8036938213425e+48*cos(theta)**44 - 8.30313554739662e+47*cos(theta)**42 + 3.30972208625393e+47*cos(theta)**40 - 1.14178824735872e+47*cos(theta)**38 + 3.40405910896175e+46*cos(theta)**36 - 8.74972353588699e+45*cos(theta)**34 + 1.93251767859551e+45*cos(theta)**32 - 3.6515381660319e+44*cos(theta)**30 + 5.86998929129297e+43*cos(theta)**28 - 7.97289238989847e+42*cos(theta)**26 + 9.07279421119398e+41*cos(theta)**24 - 8.56099556338304e+40*cos(theta)**22 + 6.61401329478757e+39*cos(theta)**20 - 4.11885455919252e+38*cos(theta)**18 + 2.02762145288435e+37*cos(theta)**16 - 7.69739241841575e+35*cos(theta)**14 + 2.18212682266615e+34*cos(theta)**12 - 4.42458894918481e+32*cos(theta)**10 + 6.04085263086519e+30*cos(theta)**8 - 5.07482369229599e+28*cos(theta)**6 + 2.26150788426737e+26*cos(theta)**4 - 3.99677387499389e+23*cos(theta)**2 + 1.16864733186956e+20)*sin(11*phi)

#@torch.jit.script
def Yl83_m_minus_10(theta, phi):
    return 3.20482037294078e-19*(1.0 - cos(theta)**2)**5*(5.27846381553831e+42*cos(theta)**73 - 8.40715327711193e+43*cos(theta)**71 + 6.40852021276783e+44*cos(theta)**69 - 3.11270981763009e+45*cos(theta)**67 + 1.08210713943084e+46*cos(theta)**65 - 2.86723929938362e+46*cos(theta)**63 + 6.02120252870561e+46*cos(theta)**61 - 1.02883292507295e+47*cos(theta)**59 + 1.45722941622501e+47*cos(theta)**57 - 1.73433120678234e+47*cos(theta)**55 + 1.7520284639944e+47*cos(theta)**53 - 1.51366471685535e+47*cos(theta)**51 + 1.12466346969148e+47*cos(theta)**49 - 7.21551685955907e+46*cos(theta)**47 + 4.00820849187223e+46*cos(theta)**45 - 1.93096175520852e+46*cos(theta)**43 + 8.07249289330227e+45*cos(theta)**41 - 2.92766217271467e+45*cos(theta)**39 + 9.20015975395067e+44*cos(theta)**37 - 2.49992101025343e+44*cos(theta)**35 + 5.85611417756216e+43*cos(theta)**33 - 1.17791553742965e+43*cos(theta)**31 + 2.02413423837689e+42*cos(theta)**29 - 2.9529231073698e+41*cos(theta)**27 + 3.62911768447759e+40*cos(theta)**25 - 3.72217198407958e+39*cos(theta)**23 + 3.14953014037503e+38*cos(theta)**21 - 2.16781818904869e+37*cos(theta)**19 + 1.19271850169668e+36*cos(theta)**17 - 5.1315949456105e+34*cos(theta)**15 + 1.67855909435857e+33*cos(theta)**13 - 4.02235359016801e+31*cos(theta)**11 + 6.7120584787391e+29*cos(theta)**9 - 7.24974813185141e+27*cos(theta)**7 + 4.52301576853475e+25*cos(theta)**5 - 1.3322579583313e+23*cos(theta)**3 + 1.16864733186956e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl83_m_minus_9(theta, phi):
    return 2.65864913578723e-17*(1.0 - cos(theta)**2)**4.5*(7.13305921018691e+40*cos(theta)**74 - 1.16766017737666e+42*cos(theta)**72 + 9.15502887538262e+42*cos(theta)**70 - 4.57751443769131e+43*cos(theta)**68 + 1.63955627186491e+44*cos(theta)**66 - 4.48006140528691e+44*cos(theta)**64 + 9.71161698178323e+44*cos(theta)**62 - 1.71472154178824e+45*cos(theta)**60 + 2.51246451073278e+45*cos(theta)**58 - 3.09702001211132e+45*cos(theta)**56 + 3.24449715554519e+45*cos(theta)**54 - 2.91089368626029e+45*cos(theta)**52 + 2.24932693938295e+45*cos(theta)**50 - 1.50323267907481e+45*cos(theta)**48 + 8.71349672146136e+44*cos(theta)**46 - 4.38854944365572e+44*cos(theta)**44 + 1.92202211745292e+44*cos(theta)**42 - 7.31915543178667e+43*cos(theta)**40 + 2.42109467209228e+43*cos(theta)**38 - 6.94422502848174e+42*cos(theta)**36 + 1.7223865228124e+42*cos(theta)**34 - 3.68098605446764e+41*cos(theta)**32 + 6.74711412792295e+40*cos(theta)**30 - 1.05461539548921e+40*cos(theta)**28 + 1.39581449402984e+39*cos(theta)**26 - 1.55090499336649e+38*cos(theta)**24 + 1.43160460926138e+37*cos(theta)**22 - 1.08390909452435e+36*cos(theta)**20 + 6.62621389831486e+34*cos(theta)**18 - 3.20724684100656e+33*cos(theta)**16 + 1.1989707816847e+32*cos(theta)**14 - 3.35196132514001e+30*cos(theta)**12 + 6.7120584787391e+28*cos(theta)**10 - 9.06218516481426e+26*cos(theta)**8 + 7.53835961422458e+24*cos(theta)**6 - 3.33064489582824e+22*cos(theta)**4 + 5.84323665934779e+19*cos(theta)**2 - 1.69812166793019e+16)*sin(9*phi)

#@torch.jit.script
def Yl83_m_minus_8(theta, phi):
    return 2.20843983544567e-15*(1.0 - cos(theta)**2)**4*(9.51074561358254e+38*cos(theta)**75 - 1.59953448955706e+40*cos(theta)**73 + 1.28944068667361e+41*cos(theta)**71 - 6.6340788952048e+41*cos(theta)**69 + 2.4470989132312e+42*cos(theta)**67 - 6.89240216197986e+42*cos(theta)**65 + 1.54152650504496e+43*cos(theta)**63 - 2.81101892096434e+43*cos(theta)**61 + 4.25841442497081e+43*cos(theta)**59 - 5.43336844230056e+43*cos(theta)**57 + 5.89908573735489e+43*cos(theta)**55 - 5.49225223822697e+43*cos(theta)**53 + 4.41044497918226e+43*cos(theta)**51 - 3.06782179403021e+43*cos(theta)**49 + 1.85393547265135e+43*cos(theta)**47 - 9.75233209701271e+42*cos(theta)**45 + 4.46981887779749e+42*cos(theta)**43 - 1.78515986141138e+42*cos(theta)**41 + 6.20793505664688e+41*cos(theta)**39 - 1.87681757526534e+41*cos(theta)**37 + 4.92110435089257e+40*cos(theta)**35 - 1.11545031953565e+40*cos(theta)**33 + 2.17648842836224e+39*cos(theta)**31 - 3.63660481203178e+38*cos(theta)**29 + 5.16968331122164e+37*cos(theta)**27 - 6.20361997346597e+36*cos(theta)**25 + 6.22436786635382e+35*cos(theta)**23 - 5.16147187868737e+34*cos(theta)**21 + 3.48748099911309e+33*cos(theta)**19 - 1.88661578882739e+32*cos(theta)**17 + 7.99313854456464e+30*cos(theta)**15 - 2.57843178856924e+29*cos(theta)**13 + 6.10187134430827e+27*cos(theta)**11 - 1.00690946275714e+26*cos(theta)**9 + 1.0769085163178e+24*cos(theta)**7 - 6.66128979165648e+21*cos(theta)**5 + 1.94774555311593e+19*cos(theta)**3 - 1.69812166793019e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl83_m_minus_7(theta, phi):
    return 1.83659359143261e-13*(1.0 - cos(theta)**2)**3.5*(1.25141389652402e+37*cos(theta)**76 - 2.16153309399603e+38*cos(theta)**74 + 1.79088984260223e+39*cos(theta)**72 - 9.47725556457828e+39*cos(theta)**70 + 3.59867487239883e+40*cos(theta)**68 - 1.04430335787574e+41*cos(theta)**66 + 2.40863516413275e+41*cos(theta)**64 - 4.53390148542635e+41*cos(theta)**62 + 7.09735737495134e+41*cos(theta)**60 - 9.36787662465613e+41*cos(theta)**58 + 1.0534081673848e+42*cos(theta)**56 - 1.01708374781981e+42*cos(theta)**54 + 8.48162495996589e+41*cos(theta)**52 - 6.13564358806043e+41*cos(theta)**50 + 3.86236556802365e+41*cos(theta)**48 - 2.12007219500276e+41*cos(theta)**46 + 1.01586792677216e+41*cos(theta)**44 - 4.25038062240805e+40*cos(theta)**42 + 1.55198376416172e+40*cos(theta)**40 - 4.9389936191193e+39*cos(theta)**38 + 1.36697343080349e+39*cos(theta)**36 - 3.28073623392838e+38*cos(theta)**34 + 6.80152633863201e+37*cos(theta)**32 - 1.21220160401059e+37*cos(theta)**30 + 1.84631546829344e+36*cos(theta)**28 - 2.3860076821023e+35*cos(theta)**26 + 2.59348661098076e+34*cos(theta)**24 - 2.34612358122153e+33*cos(theta)**22 + 1.74374049955654e+32*cos(theta)**20 - 1.04811988268188e+31*cos(theta)**18 + 4.9957115903529e+29*cos(theta)**16 - 1.84173699183517e+28*cos(theta)**14 + 5.08489278692356e+26*cos(theta)**12 - 1.00690946275714e+25*cos(theta)**10 + 1.34613564539725e+23*cos(theta)**8 - 1.11021496527608e+21*cos(theta)**6 + 4.86936388278982e+18*cos(theta)**4 - 8.49060833965095e+15*cos(theta)**2 + 2455352324942.44)*sin(7*phi)

#@torch.jit.script
def Yl83_m_minus_6(theta, phi):
    return 1.52890211652784e-11*(1.0 - cos(theta)**2)**3*(1.6252128526286e+35*cos(theta)**77 - 2.88204412532804e+36*cos(theta)**75 + 2.45327375698936e+37*cos(theta)**73 - 1.33482472740539e+38*cos(theta)**71 + 5.21547082956352e+38*cos(theta)**69 - 1.55866172817274e+39*cos(theta)**67 + 3.70559256020423e+39*cos(theta)**65 - 7.19666902448627e+39*cos(theta)**63 + 1.16350120900842e+40*cos(theta)**61 - 1.58777569909426e+40*cos(theta)**59 + 1.84808450418386e+40*cos(theta)**57 - 1.8492431778542e+40*cos(theta)**55 + 1.60030659621998e+40*cos(theta)**53 - 1.20306737020793e+40*cos(theta)**51 + 7.88237871025235e+39*cos(theta)**49 - 4.5107919042612e+39*cos(theta)**47 + 2.25748428171591e+39*cos(theta)**45 - 9.88460609862338e+38*cos(theta)**43 + 3.78532625405297e+38*cos(theta)**41 - 1.266408620287e+38*cos(theta)**39 + 3.69452278595538e+37*cos(theta)**37 - 9.37353209693823e+36*cos(theta)**35 + 2.06106858746425e+36*cos(theta)**33 - 3.91032775487288e+35*cos(theta)**31 + 6.36660506308084e+34*cos(theta)**29 - 8.83706548926776e+33*cos(theta)**27 + 1.0373946443923e+33*cos(theta)**25 - 1.02005373096588e+32*cos(theta)**23 + 8.30352618836449e+30*cos(theta)**21 - 5.5164204351678e+29*cos(theta)**19 + 2.93865387667818e+28*cos(theta)**17 - 1.22782466122345e+27*cos(theta)**15 + 3.9114559899412e+25*cos(theta)**13 - 9.15372238870127e+23*cos(theta)**11 + 1.49570627266361e+22*cos(theta)**9 - 1.58602137896583e+20*cos(theta)**7 + 9.73872776557964e+17*cos(theta)**5 - 2.83020277988365e+15*cos(theta)**3 + 2455352324942.44*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl83_m_minus_5(theta, phi):
    return 1.27386083839294e-9*(1.0 - cos(theta)**2)**2.5*(2.08360622131871e+33*cos(theta)**78 - 3.79216332280006e+34*cos(theta)**76 + 3.31523480674238e+35*cos(theta)**74 - 1.85392323250749e+36*cos(theta)**72 + 7.45067261366217e+36*cos(theta)**70 - 2.29214960025403e+37*cos(theta)**68 + 5.61453418212761e+37*cos(theta)**66 - 1.12447953507598e+38*cos(theta)**64 + 1.87661485323938e+38*cos(theta)**62 - 2.64629283182377e+38*cos(theta)**60 + 3.18635259342045e+38*cos(theta)**58 - 3.30221996045392e+38*cos(theta)**56 + 2.9635307337407e+38*cos(theta)**54 - 2.31359109655371e+38*cos(theta)**52 + 1.57647574205047e+38*cos(theta)**50 - 9.3974831338775e+37*cos(theta)**48 + 4.90757452546936e+37*cos(theta)**46 - 2.24650138605077e+37*cos(theta)**44 + 9.01268155726899e+36*cos(theta)**42 - 3.1660215507175e+36*cos(theta)**40 + 9.72242838409312e+35*cos(theta)**38 - 2.60375891581618e+35*cos(theta)**36 + 6.06196643371837e+34*cos(theta)**34 - 1.22197742339777e+34*cos(theta)**32 + 2.12220168769361e+33*cos(theta)**30 - 3.15609481759563e+32*cos(theta)**28 + 3.98997940150886e+31*cos(theta)**26 - 4.25022387902451e+30*cos(theta)**24 + 3.77433008562022e+29*cos(theta)**22 - 2.7582102175839e+28*cos(theta)**20 + 1.63258548704343e+27*cos(theta)**18 - 7.67390413264654e+25*cos(theta)**16 + 2.79389713567228e+24*cos(theta)**14 - 7.6281019905844e+22*cos(theta)**12 + 1.49570627266361e+21*cos(theta)**10 - 1.98252672370728e+19*cos(theta)**8 + 1.62312129426327e+17*cos(theta)**6 - 707550694970913.0*cos(theta)**4 + 1227676162471.22*cos(theta)**2 - 353695235.514612)*sin(5*phi)

#@torch.jit.script
def Yl83_m_minus_4(theta, phi):
    return 1.06212802525071e-7*(1.0 - cos(theta)**2)**2*(2.63747622951736e+31*cos(theta)**79 - 4.92488743220786e+32*cos(theta)**77 + 4.42031307565651e+33*cos(theta)**75 - 2.53962086644861e+34*cos(theta)**73 + 1.0493905089665e+35*cos(theta)**71 - 3.32195594239715e+35*cos(theta)**69 + 8.37990176436957e+35*cos(theta)**67 - 1.72996851550151e+36*cos(theta)**65 + 2.97875373530061e+36*cos(theta)**63 - 4.3381849702029e+36*cos(theta)**61 + 5.40059761596687e+36*cos(theta)**59 - 5.79336835167355e+36*cos(theta)**57 + 5.38823769771037e+36*cos(theta)**55 - 4.36526621991265e+36*cos(theta)**53 + 3.09112890598131e+36*cos(theta)**51 - 1.91785370079133e+36*cos(theta)**49 + 1.04416479265306e+36*cos(theta)**47 - 4.99222530233504e+35*cos(theta)**45 + 2.09597245517883e+35*cos(theta)**43 - 7.72200378223781e+34*cos(theta)**41 + 2.49293035489567e+34*cos(theta)**39 - 7.03718625896264e+33*cos(theta)**37 + 1.73199040963382e+33*cos(theta)**35 - 3.70296188908416e+32*cos(theta)**33 + 6.84581189578585e+31*cos(theta)**31 - 1.0883085577916e+31*cos(theta)**29 + 1.47777014870698e+30*cos(theta)**27 - 1.7000895516098e+29*cos(theta)**25 + 1.64101308070444e+28*cos(theta)**23 - 1.31343343694472e+27*cos(theta)**21 + 8.59255519496543e+25*cos(theta)**19 - 4.51406125449797e+24*cos(theta)**17 + 1.86259809044819e+23*cos(theta)**15 - 5.867770761988e+21*cos(theta)**13 + 1.35973297514873e+20*cos(theta)**11 - 2.20280747078587e+18*cos(theta)**9 + 2.31874470609039e+16*cos(theta)**7 - 141510138994183.0*cos(theta)**5 + 409225387490.406*cos(theta)**3 - 353695235.514612*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl83_m_minus_3(theta, phi):
    return 8.86097452681129e-6*(1.0 - cos(theta)**2)**1.5*(3.2968452868967e+29*cos(theta)**80 - 6.31395824642034e+30*cos(theta)**78 + 5.81620141533751e+31*cos(theta)**76 - 3.43192008979542e+32*cos(theta)**74 + 1.45748681800903e+33*cos(theta)**72 - 4.74565134628164e+33*cos(theta)**70 + 1.23233849476023e+34*cos(theta)**68 - 2.62116441742652e+34*cos(theta)**66 + 4.6543027114072e+34*cos(theta)**64 - 6.99707253258532e+34*cos(theta)**62 + 9.00099602661145e+34*cos(theta)**60 - 9.98856612357509e+34*cos(theta)**58 + 9.62185303162565e+34*cos(theta)**56 - 8.08382633317158e+34*cos(theta)**54 + 5.94447866534868e+34*cos(theta)**52 - 3.83570740158265e+34*cos(theta)**50 + 2.1753433180272e+34*cos(theta)**48 - 1.08526637007284e+34*cos(theta)**46 + 4.76357376177008e+33*cos(theta)**44 - 1.83857232910424e+33*cos(theta)**42 + 6.23232588723918e+32*cos(theta)**40 - 1.85189112077964e+32*cos(theta)**38 + 4.81108447120505e+31*cos(theta)**36 - 1.08910643796593e+31*cos(theta)**34 + 2.13931621743308e+30*cos(theta)**32 - 3.62769519263865e+29*cos(theta)**30 + 5.27775053109637e+28*cos(theta)**28 - 6.53880596773002e+27*cos(theta)**26 + 6.83755450293519e+26*cos(theta)**24 - 5.97015198611234e+25*cos(theta)**22 + 4.29627759748271e+24*cos(theta)**20 - 2.50781180805443e+23*cos(theta)**18 + 1.16412380653012e+22*cos(theta)**16 - 4.19126482999143e+20*cos(theta)**14 + 1.13311081262394e+19*cos(theta)**12 - 2.20280747078587e+17*cos(theta)**10 + 2.89843088261299e+15*cos(theta)**8 - 23585023165697.1*cos(theta)**6 + 102306346872.602*cos(theta)**4 - 176847617.757306*cos(theta)**2 + 50818.2809647432)*sin(3*phi)

#@torch.jit.script
def Yl83_m_minus_2(theta, phi):
    return 0.000739559675339581*(1.0 - cos(theta)**2)*(4.07017936653913e+27*cos(theta)**81 - 7.99235221065866e+28*cos(theta)**79 + 7.55350833160715e+29*cos(theta)**77 - 4.57589345306057e+30*cos(theta)**75 + 1.99655728494388e+31*cos(theta)**73 - 6.68401598067836e+31*cos(theta)**71 + 1.78599781849309e+32*cos(theta)**69 - 3.91218569765153e+32*cos(theta)**67 + 7.16046570985723e+32*cos(theta)**65 - 1.1106464337437e+33*cos(theta)**63 + 1.47557311911663e+33*cos(theta)**61 - 1.69297730908052e+33*cos(theta)**59 + 1.68804439151327e+33*cos(theta)**57 - 1.4697866060312e+33*cos(theta)**55 + 1.121599748179e+33*cos(theta)**53 - 7.52099490506402e+32*cos(theta)**51 + 4.43947615923918e+32*cos(theta)**49 - 2.30907738313369e+32*cos(theta)**47 + 1.05857194706002e+32*cos(theta)**45 - 4.275749602568e+31*cos(theta)**43 + 1.52007948469248e+31*cos(theta)**41 - 4.74843877122985e+30*cos(theta)**39 + 1.30029310032569e+30*cos(theta)**37 - 3.11173267990266e+29*cos(theta)**35 + 6.48277641646387e+28*cos(theta)**33 - 1.17022425568989e+28*cos(theta)**31 + 1.81991397624013e+27*cos(theta)**29 - 2.42177998804815e+26*cos(theta)**27 + 2.73502180117407e+25*cos(theta)**25 - 2.59571825483145e+24*cos(theta)**23 + 2.04584647499177e+23*cos(theta)**21 - 1.31990095160759e+22*cos(theta)**19 + 6.84778709723599e+20*cos(theta)**17 - 2.79417655332762e+19*cos(theta)**15 + 8.71623702018419e+17*cos(theta)**13 - 2.00255224616897e+16*cos(theta)**11 + 322047875845888.0*cos(theta)**9 - 3369289023671.01*cos(theta)**7 + 20461269374.5203*cos(theta)**5 - 58949205.9191021*cos(theta)**3 + 50818.2809647432*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl83_m_minus_1(theta, phi):
    return 0.0617432679594873*(1.0 - cos(theta)**2)**0.5*(4.96363337382821e+25*cos(theta)**82 - 9.99044026332332e+26*cos(theta)**80 + 9.68398504052199e+27*cos(theta)**78 - 6.02091243823759e+28*cos(theta)**76 + 2.6980503850593e+29*cos(theta)**74 - 9.28335552871995e+29*cos(theta)**72 + 2.55142545499013e+30*cos(theta)**70 - 5.75321426125225e+30*cos(theta)**68 + 1.08491904694806e+31*cos(theta)**66 - 1.73538505272453e+31*cos(theta)**64 + 2.3799566437365e+31*cos(theta)**62 - 2.82162884846754e+31*cos(theta)**60 + 2.91042136467806e+31*cos(theta)**58 - 2.62461893934142e+31*cos(theta)**56 + 2.07703657070185e+31*cos(theta)**54 - 1.44634517405077e+31*cos(theta)**52 + 8.87895231847836e+30*cos(theta)**50 - 4.81057788152852e+30*cos(theta)**48 + 2.30124336317395e+30*cos(theta)**46 - 9.71761273310909e+29*cos(theta)**44 + 3.61923686831543e+29*cos(theta)**42 - 1.18710969280746e+29*cos(theta)**40 + 3.4218239482255e+28*cos(theta)**38 - 8.6437018886185e+27*cos(theta)**36 + 1.90669894601879e+27*cos(theta)**34 - 3.6569507990309e+26*cos(theta)**32 + 6.06637992080043e+25*cos(theta)**30 - 8.64921424302912e+24*cos(theta)**28 + 1.05193146199003e+24*cos(theta)**26 - 1.08154927284644e+23*cos(theta)**24 + 9.29930215905349e+21*cos(theta)**22 - 6.59950475803796e+20*cos(theta)**20 + 3.80432616513111e+19*cos(theta)**18 - 1.74636034582976e+18*cos(theta)**16 + 6.22588358584585e+16*cos(theta)**14 - 1.66879353847415e+15*cos(theta)**12 + 32204787584588.8*cos(theta)**10 - 421161127958.877*cos(theta)**8 + 3410211562.42005*cos(theta)**6 - 14737301.4797755*cos(theta)**4 + 25409.1404823716*cos(theta)**2 - 7.29100157313388)*sin(phi)

#@torch.jit.script
def Yl83_m0(theta, phi):
    return 6.84896236597723e+24*cos(theta)**83 - 1.41254660190427e+26*cos(theta)**81 + 1.40388067183124e+27*cos(theta)**79 - 8.9551891302527e+27*cos(theta)**77 + 4.11995021935839e+28*cos(theta)**75 - 1.45641552340376e+29*cos(theta)**73 + 4.11554838226354e+29*cos(theta)**71 - 9.54914820721279e+29*cos(theta)**69 + 1.8544951733544e+30*cos(theta)**67 - 3.05763521870737e+30*cos(theta)**65 + 4.32644983327302e+30*cos(theta)**63 - 5.29752760149354e+30*cos(theta)**61 + 5.64946125334102e+30*cos(theta)**59 - 5.27344692005809e+30*cos(theta)**57 + 4.32498524378865e+30*cos(theta)**55 - 3.12535430025603e+30*cos(theta)**53 + 1.99386028970038e+30*cos(theta)**51 - 1.12435730622202e+30*cos(theta)**49 + 5.60748173077647e+29*cos(theta)**47 - 2.47314881720496e+29*cos(theta)**45 + 9.63943830327918e+28*cos(theta)**43 - 3.31596677632804e+28*cos(theta)**41 + 1.0048384170691e+28*cos(theta)**39 - 2.67547706449229e+27*cos(theta)**37 + 6.23903265039169e+26*cos(theta)**35 - 1.26913655623352e+26*cos(theta)**33 + 2.24115084177693e+25*cos(theta)**31 - 3.41571662217722e+24*cos(theta)**29 + 4.46197216410538e+23*cos(theta)**27 - 4.95461002720971e+22*cos(theta)**25 + 4.63047666094365e+21*cos(theta)**23 - 3.59911089160904e+20*cos(theta)**21 + 2.29312283749363e+19*cos(theta)**19 - 1.17648966460069e+18*cos(theta)**17 + 4.75349359434622e+16*cos(theta)**15 - 1.47015265804522e+15*cos(theta)**13 + 33529797464189.3*cos(theta)**11 - 535931084141.358*cos(theta)**9 + 5579386648.08817*cos(theta)**7 - 33756012.5640598*cos(theta)**5 + 97000.03610362*cos(theta)**3 - 83.5007484392712*cos(theta)

#@torch.jit.script
def Yl83_m1(theta, phi):
    return 0.0617432679594873*(1.0 - cos(theta)**2)**0.5*(4.96363337382821e+25*cos(theta)**82 - 9.99044026332332e+26*cos(theta)**80 + 9.68398504052199e+27*cos(theta)**78 - 6.02091243823759e+28*cos(theta)**76 + 2.6980503850593e+29*cos(theta)**74 - 9.28335552871995e+29*cos(theta)**72 + 2.55142545499013e+30*cos(theta)**70 - 5.75321426125225e+30*cos(theta)**68 + 1.08491904694806e+31*cos(theta)**66 - 1.73538505272453e+31*cos(theta)**64 + 2.3799566437365e+31*cos(theta)**62 - 2.82162884846754e+31*cos(theta)**60 + 2.91042136467806e+31*cos(theta)**58 - 2.62461893934142e+31*cos(theta)**56 + 2.07703657070185e+31*cos(theta)**54 - 1.44634517405077e+31*cos(theta)**52 + 8.87895231847836e+30*cos(theta)**50 - 4.81057788152852e+30*cos(theta)**48 + 2.30124336317395e+30*cos(theta)**46 - 9.71761273310909e+29*cos(theta)**44 + 3.61923686831543e+29*cos(theta)**42 - 1.18710969280746e+29*cos(theta)**40 + 3.4218239482255e+28*cos(theta)**38 - 8.6437018886185e+27*cos(theta)**36 + 1.90669894601879e+27*cos(theta)**34 - 3.6569507990309e+26*cos(theta)**32 + 6.06637992080043e+25*cos(theta)**30 - 8.64921424302912e+24*cos(theta)**28 + 1.05193146199003e+24*cos(theta)**26 - 1.08154927284644e+23*cos(theta)**24 + 9.29930215905349e+21*cos(theta)**22 - 6.59950475803796e+20*cos(theta)**20 + 3.80432616513111e+19*cos(theta)**18 - 1.74636034582976e+18*cos(theta)**16 + 6.22588358584585e+16*cos(theta)**14 - 1.66879353847415e+15*cos(theta)**12 + 32204787584588.8*cos(theta)**10 - 421161127958.877*cos(theta)**8 + 3410211562.42005*cos(theta)**6 - 14737301.4797755*cos(theta)**4 + 25409.1404823716*cos(theta)**2 - 7.29100157313388)*cos(phi)

#@torch.jit.script
def Yl83_m2(theta, phi):
    return 0.000739559675339581*(1.0 - cos(theta)**2)*(4.07017936653913e+27*cos(theta)**81 - 7.99235221065866e+28*cos(theta)**79 + 7.55350833160715e+29*cos(theta)**77 - 4.57589345306057e+30*cos(theta)**75 + 1.99655728494388e+31*cos(theta)**73 - 6.68401598067836e+31*cos(theta)**71 + 1.78599781849309e+32*cos(theta)**69 - 3.91218569765153e+32*cos(theta)**67 + 7.16046570985723e+32*cos(theta)**65 - 1.1106464337437e+33*cos(theta)**63 + 1.47557311911663e+33*cos(theta)**61 - 1.69297730908052e+33*cos(theta)**59 + 1.68804439151327e+33*cos(theta)**57 - 1.4697866060312e+33*cos(theta)**55 + 1.121599748179e+33*cos(theta)**53 - 7.52099490506402e+32*cos(theta)**51 + 4.43947615923918e+32*cos(theta)**49 - 2.30907738313369e+32*cos(theta)**47 + 1.05857194706002e+32*cos(theta)**45 - 4.275749602568e+31*cos(theta)**43 + 1.52007948469248e+31*cos(theta)**41 - 4.74843877122985e+30*cos(theta)**39 + 1.30029310032569e+30*cos(theta)**37 - 3.11173267990266e+29*cos(theta)**35 + 6.48277641646387e+28*cos(theta)**33 - 1.17022425568989e+28*cos(theta)**31 + 1.81991397624013e+27*cos(theta)**29 - 2.42177998804815e+26*cos(theta)**27 + 2.73502180117407e+25*cos(theta)**25 - 2.59571825483145e+24*cos(theta)**23 + 2.04584647499177e+23*cos(theta)**21 - 1.31990095160759e+22*cos(theta)**19 + 6.84778709723599e+20*cos(theta)**17 - 2.79417655332762e+19*cos(theta)**15 + 8.71623702018419e+17*cos(theta)**13 - 2.00255224616897e+16*cos(theta)**11 + 322047875845888.0*cos(theta)**9 - 3369289023671.01*cos(theta)**7 + 20461269374.5203*cos(theta)**5 - 58949205.9191021*cos(theta)**3 + 50818.2809647432*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl83_m3(theta, phi):
    return 8.86097452681129e-6*(1.0 - cos(theta)**2)**1.5*(3.2968452868967e+29*cos(theta)**80 - 6.31395824642034e+30*cos(theta)**78 + 5.81620141533751e+31*cos(theta)**76 - 3.43192008979542e+32*cos(theta)**74 + 1.45748681800903e+33*cos(theta)**72 - 4.74565134628164e+33*cos(theta)**70 + 1.23233849476023e+34*cos(theta)**68 - 2.62116441742652e+34*cos(theta)**66 + 4.6543027114072e+34*cos(theta)**64 - 6.99707253258532e+34*cos(theta)**62 + 9.00099602661145e+34*cos(theta)**60 - 9.98856612357509e+34*cos(theta)**58 + 9.62185303162565e+34*cos(theta)**56 - 8.08382633317158e+34*cos(theta)**54 + 5.94447866534868e+34*cos(theta)**52 - 3.83570740158265e+34*cos(theta)**50 + 2.1753433180272e+34*cos(theta)**48 - 1.08526637007284e+34*cos(theta)**46 + 4.76357376177008e+33*cos(theta)**44 - 1.83857232910424e+33*cos(theta)**42 + 6.23232588723918e+32*cos(theta)**40 - 1.85189112077964e+32*cos(theta)**38 + 4.81108447120505e+31*cos(theta)**36 - 1.08910643796593e+31*cos(theta)**34 + 2.13931621743308e+30*cos(theta)**32 - 3.62769519263865e+29*cos(theta)**30 + 5.27775053109637e+28*cos(theta)**28 - 6.53880596773002e+27*cos(theta)**26 + 6.83755450293519e+26*cos(theta)**24 - 5.97015198611234e+25*cos(theta)**22 + 4.29627759748271e+24*cos(theta)**20 - 2.50781180805443e+23*cos(theta)**18 + 1.16412380653012e+22*cos(theta)**16 - 4.19126482999143e+20*cos(theta)**14 + 1.13311081262394e+19*cos(theta)**12 - 2.20280747078587e+17*cos(theta)**10 + 2.89843088261299e+15*cos(theta)**8 - 23585023165697.1*cos(theta)**6 + 102306346872.602*cos(theta)**4 - 176847617.757306*cos(theta)**2 + 50818.2809647432)*cos(3*phi)

#@torch.jit.script
def Yl83_m4(theta, phi):
    return 1.06212802525071e-7*(1.0 - cos(theta)**2)**2*(2.63747622951736e+31*cos(theta)**79 - 4.92488743220786e+32*cos(theta)**77 + 4.42031307565651e+33*cos(theta)**75 - 2.53962086644861e+34*cos(theta)**73 + 1.0493905089665e+35*cos(theta)**71 - 3.32195594239715e+35*cos(theta)**69 + 8.37990176436957e+35*cos(theta)**67 - 1.72996851550151e+36*cos(theta)**65 + 2.97875373530061e+36*cos(theta)**63 - 4.3381849702029e+36*cos(theta)**61 + 5.40059761596687e+36*cos(theta)**59 - 5.79336835167355e+36*cos(theta)**57 + 5.38823769771037e+36*cos(theta)**55 - 4.36526621991265e+36*cos(theta)**53 + 3.09112890598131e+36*cos(theta)**51 - 1.91785370079133e+36*cos(theta)**49 + 1.04416479265306e+36*cos(theta)**47 - 4.99222530233504e+35*cos(theta)**45 + 2.09597245517883e+35*cos(theta)**43 - 7.72200378223781e+34*cos(theta)**41 + 2.49293035489567e+34*cos(theta)**39 - 7.03718625896264e+33*cos(theta)**37 + 1.73199040963382e+33*cos(theta)**35 - 3.70296188908416e+32*cos(theta)**33 + 6.84581189578585e+31*cos(theta)**31 - 1.0883085577916e+31*cos(theta)**29 + 1.47777014870698e+30*cos(theta)**27 - 1.7000895516098e+29*cos(theta)**25 + 1.64101308070444e+28*cos(theta)**23 - 1.31343343694472e+27*cos(theta)**21 + 8.59255519496543e+25*cos(theta)**19 - 4.51406125449797e+24*cos(theta)**17 + 1.86259809044819e+23*cos(theta)**15 - 5.867770761988e+21*cos(theta)**13 + 1.35973297514873e+20*cos(theta)**11 - 2.20280747078587e+18*cos(theta)**9 + 2.31874470609039e+16*cos(theta)**7 - 141510138994183.0*cos(theta)**5 + 409225387490.406*cos(theta)**3 - 353695235.514612*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl83_m5(theta, phi):
    return 1.27386083839294e-9*(1.0 - cos(theta)**2)**2.5*(2.08360622131871e+33*cos(theta)**78 - 3.79216332280006e+34*cos(theta)**76 + 3.31523480674238e+35*cos(theta)**74 - 1.85392323250749e+36*cos(theta)**72 + 7.45067261366217e+36*cos(theta)**70 - 2.29214960025403e+37*cos(theta)**68 + 5.61453418212761e+37*cos(theta)**66 - 1.12447953507598e+38*cos(theta)**64 + 1.87661485323938e+38*cos(theta)**62 - 2.64629283182377e+38*cos(theta)**60 + 3.18635259342045e+38*cos(theta)**58 - 3.30221996045392e+38*cos(theta)**56 + 2.9635307337407e+38*cos(theta)**54 - 2.31359109655371e+38*cos(theta)**52 + 1.57647574205047e+38*cos(theta)**50 - 9.3974831338775e+37*cos(theta)**48 + 4.90757452546936e+37*cos(theta)**46 - 2.24650138605077e+37*cos(theta)**44 + 9.01268155726899e+36*cos(theta)**42 - 3.1660215507175e+36*cos(theta)**40 + 9.72242838409312e+35*cos(theta)**38 - 2.60375891581618e+35*cos(theta)**36 + 6.06196643371837e+34*cos(theta)**34 - 1.22197742339777e+34*cos(theta)**32 + 2.12220168769361e+33*cos(theta)**30 - 3.15609481759563e+32*cos(theta)**28 + 3.98997940150886e+31*cos(theta)**26 - 4.25022387902451e+30*cos(theta)**24 + 3.77433008562022e+29*cos(theta)**22 - 2.7582102175839e+28*cos(theta)**20 + 1.63258548704343e+27*cos(theta)**18 - 7.67390413264654e+25*cos(theta)**16 + 2.79389713567228e+24*cos(theta)**14 - 7.6281019905844e+22*cos(theta)**12 + 1.49570627266361e+21*cos(theta)**10 - 1.98252672370728e+19*cos(theta)**8 + 1.62312129426327e+17*cos(theta)**6 - 707550694970913.0*cos(theta)**4 + 1227676162471.22*cos(theta)**2 - 353695235.514612)*cos(5*phi)

#@torch.jit.script
def Yl83_m6(theta, phi):
    return 1.52890211652784e-11*(1.0 - cos(theta)**2)**3*(1.6252128526286e+35*cos(theta)**77 - 2.88204412532804e+36*cos(theta)**75 + 2.45327375698936e+37*cos(theta)**73 - 1.33482472740539e+38*cos(theta)**71 + 5.21547082956352e+38*cos(theta)**69 - 1.55866172817274e+39*cos(theta)**67 + 3.70559256020423e+39*cos(theta)**65 - 7.19666902448627e+39*cos(theta)**63 + 1.16350120900842e+40*cos(theta)**61 - 1.58777569909426e+40*cos(theta)**59 + 1.84808450418386e+40*cos(theta)**57 - 1.8492431778542e+40*cos(theta)**55 + 1.60030659621998e+40*cos(theta)**53 - 1.20306737020793e+40*cos(theta)**51 + 7.88237871025235e+39*cos(theta)**49 - 4.5107919042612e+39*cos(theta)**47 + 2.25748428171591e+39*cos(theta)**45 - 9.88460609862338e+38*cos(theta)**43 + 3.78532625405297e+38*cos(theta)**41 - 1.266408620287e+38*cos(theta)**39 + 3.69452278595538e+37*cos(theta)**37 - 9.37353209693823e+36*cos(theta)**35 + 2.06106858746425e+36*cos(theta)**33 - 3.91032775487288e+35*cos(theta)**31 + 6.36660506308084e+34*cos(theta)**29 - 8.83706548926776e+33*cos(theta)**27 + 1.0373946443923e+33*cos(theta)**25 - 1.02005373096588e+32*cos(theta)**23 + 8.30352618836449e+30*cos(theta)**21 - 5.5164204351678e+29*cos(theta)**19 + 2.93865387667818e+28*cos(theta)**17 - 1.22782466122345e+27*cos(theta)**15 + 3.9114559899412e+25*cos(theta)**13 - 9.15372238870127e+23*cos(theta)**11 + 1.49570627266361e+22*cos(theta)**9 - 1.58602137896583e+20*cos(theta)**7 + 9.73872776557964e+17*cos(theta)**5 - 2.83020277988365e+15*cos(theta)**3 + 2455352324942.44*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl83_m7(theta, phi):
    return 1.83659359143261e-13*(1.0 - cos(theta)**2)**3.5*(1.25141389652402e+37*cos(theta)**76 - 2.16153309399603e+38*cos(theta)**74 + 1.79088984260223e+39*cos(theta)**72 - 9.47725556457828e+39*cos(theta)**70 + 3.59867487239883e+40*cos(theta)**68 - 1.04430335787574e+41*cos(theta)**66 + 2.40863516413275e+41*cos(theta)**64 - 4.53390148542635e+41*cos(theta)**62 + 7.09735737495134e+41*cos(theta)**60 - 9.36787662465613e+41*cos(theta)**58 + 1.0534081673848e+42*cos(theta)**56 - 1.01708374781981e+42*cos(theta)**54 + 8.48162495996589e+41*cos(theta)**52 - 6.13564358806043e+41*cos(theta)**50 + 3.86236556802365e+41*cos(theta)**48 - 2.12007219500276e+41*cos(theta)**46 + 1.01586792677216e+41*cos(theta)**44 - 4.25038062240805e+40*cos(theta)**42 + 1.55198376416172e+40*cos(theta)**40 - 4.9389936191193e+39*cos(theta)**38 + 1.36697343080349e+39*cos(theta)**36 - 3.28073623392838e+38*cos(theta)**34 + 6.80152633863201e+37*cos(theta)**32 - 1.21220160401059e+37*cos(theta)**30 + 1.84631546829344e+36*cos(theta)**28 - 2.3860076821023e+35*cos(theta)**26 + 2.59348661098076e+34*cos(theta)**24 - 2.34612358122153e+33*cos(theta)**22 + 1.74374049955654e+32*cos(theta)**20 - 1.04811988268188e+31*cos(theta)**18 + 4.9957115903529e+29*cos(theta)**16 - 1.84173699183517e+28*cos(theta)**14 + 5.08489278692356e+26*cos(theta)**12 - 1.00690946275714e+25*cos(theta)**10 + 1.34613564539725e+23*cos(theta)**8 - 1.11021496527608e+21*cos(theta)**6 + 4.86936388278982e+18*cos(theta)**4 - 8.49060833965095e+15*cos(theta)**2 + 2455352324942.44)*cos(7*phi)

#@torch.jit.script
def Yl83_m8(theta, phi):
    return 2.20843983544567e-15*(1.0 - cos(theta)**2)**4*(9.51074561358254e+38*cos(theta)**75 - 1.59953448955706e+40*cos(theta)**73 + 1.28944068667361e+41*cos(theta)**71 - 6.6340788952048e+41*cos(theta)**69 + 2.4470989132312e+42*cos(theta)**67 - 6.89240216197986e+42*cos(theta)**65 + 1.54152650504496e+43*cos(theta)**63 - 2.81101892096434e+43*cos(theta)**61 + 4.25841442497081e+43*cos(theta)**59 - 5.43336844230056e+43*cos(theta)**57 + 5.89908573735489e+43*cos(theta)**55 - 5.49225223822697e+43*cos(theta)**53 + 4.41044497918226e+43*cos(theta)**51 - 3.06782179403021e+43*cos(theta)**49 + 1.85393547265135e+43*cos(theta)**47 - 9.75233209701271e+42*cos(theta)**45 + 4.46981887779749e+42*cos(theta)**43 - 1.78515986141138e+42*cos(theta)**41 + 6.20793505664688e+41*cos(theta)**39 - 1.87681757526534e+41*cos(theta)**37 + 4.92110435089257e+40*cos(theta)**35 - 1.11545031953565e+40*cos(theta)**33 + 2.17648842836224e+39*cos(theta)**31 - 3.63660481203178e+38*cos(theta)**29 + 5.16968331122164e+37*cos(theta)**27 - 6.20361997346597e+36*cos(theta)**25 + 6.22436786635382e+35*cos(theta)**23 - 5.16147187868737e+34*cos(theta)**21 + 3.48748099911309e+33*cos(theta)**19 - 1.88661578882739e+32*cos(theta)**17 + 7.99313854456464e+30*cos(theta)**15 - 2.57843178856924e+29*cos(theta)**13 + 6.10187134430827e+27*cos(theta)**11 - 1.00690946275714e+26*cos(theta)**9 + 1.0769085163178e+24*cos(theta)**7 - 6.66128979165648e+21*cos(theta)**5 + 1.94774555311593e+19*cos(theta)**3 - 1.69812166793019e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl83_m9(theta, phi):
    return 2.65864913578723e-17*(1.0 - cos(theta)**2)**4.5*(7.13305921018691e+40*cos(theta)**74 - 1.16766017737666e+42*cos(theta)**72 + 9.15502887538262e+42*cos(theta)**70 - 4.57751443769131e+43*cos(theta)**68 + 1.63955627186491e+44*cos(theta)**66 - 4.48006140528691e+44*cos(theta)**64 + 9.71161698178323e+44*cos(theta)**62 - 1.71472154178824e+45*cos(theta)**60 + 2.51246451073278e+45*cos(theta)**58 - 3.09702001211132e+45*cos(theta)**56 + 3.24449715554519e+45*cos(theta)**54 - 2.91089368626029e+45*cos(theta)**52 + 2.24932693938295e+45*cos(theta)**50 - 1.50323267907481e+45*cos(theta)**48 + 8.71349672146136e+44*cos(theta)**46 - 4.38854944365572e+44*cos(theta)**44 + 1.92202211745292e+44*cos(theta)**42 - 7.31915543178667e+43*cos(theta)**40 + 2.42109467209228e+43*cos(theta)**38 - 6.94422502848174e+42*cos(theta)**36 + 1.7223865228124e+42*cos(theta)**34 - 3.68098605446764e+41*cos(theta)**32 + 6.74711412792295e+40*cos(theta)**30 - 1.05461539548921e+40*cos(theta)**28 + 1.39581449402984e+39*cos(theta)**26 - 1.55090499336649e+38*cos(theta)**24 + 1.43160460926138e+37*cos(theta)**22 - 1.08390909452435e+36*cos(theta)**20 + 6.62621389831486e+34*cos(theta)**18 - 3.20724684100656e+33*cos(theta)**16 + 1.1989707816847e+32*cos(theta)**14 - 3.35196132514001e+30*cos(theta)**12 + 6.7120584787391e+28*cos(theta)**10 - 9.06218516481426e+26*cos(theta)**8 + 7.53835961422458e+24*cos(theta)**6 - 3.33064489582824e+22*cos(theta)**4 + 5.84323665934779e+19*cos(theta)**2 - 1.69812166793019e+16)*cos(9*phi)

#@torch.jit.script
def Yl83_m10(theta, phi):
    return 3.20482037294078e-19*(1.0 - cos(theta)**2)**5*(5.27846381553831e+42*cos(theta)**73 - 8.40715327711193e+43*cos(theta)**71 + 6.40852021276783e+44*cos(theta)**69 - 3.11270981763009e+45*cos(theta)**67 + 1.08210713943084e+46*cos(theta)**65 - 2.86723929938362e+46*cos(theta)**63 + 6.02120252870561e+46*cos(theta)**61 - 1.02883292507295e+47*cos(theta)**59 + 1.45722941622501e+47*cos(theta)**57 - 1.73433120678234e+47*cos(theta)**55 + 1.7520284639944e+47*cos(theta)**53 - 1.51366471685535e+47*cos(theta)**51 + 1.12466346969148e+47*cos(theta)**49 - 7.21551685955907e+46*cos(theta)**47 + 4.00820849187223e+46*cos(theta)**45 - 1.93096175520852e+46*cos(theta)**43 + 8.07249289330227e+45*cos(theta)**41 - 2.92766217271467e+45*cos(theta)**39 + 9.20015975395067e+44*cos(theta)**37 - 2.49992101025343e+44*cos(theta)**35 + 5.85611417756216e+43*cos(theta)**33 - 1.17791553742965e+43*cos(theta)**31 + 2.02413423837689e+42*cos(theta)**29 - 2.9529231073698e+41*cos(theta)**27 + 3.62911768447759e+40*cos(theta)**25 - 3.72217198407958e+39*cos(theta)**23 + 3.14953014037503e+38*cos(theta)**21 - 2.16781818904869e+37*cos(theta)**19 + 1.19271850169668e+36*cos(theta)**17 - 5.1315949456105e+34*cos(theta)**15 + 1.67855909435857e+33*cos(theta)**13 - 4.02235359016801e+31*cos(theta)**11 + 6.7120584787391e+29*cos(theta)**9 - 7.24974813185141e+27*cos(theta)**7 + 4.52301576853475e+25*cos(theta)**5 - 1.3322579583313e+23*cos(theta)**3 + 1.16864733186956e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl83_m11(theta, phi):
    return 3.8688183217449e-21*(1.0 - cos(theta)**2)**5.5*(3.85327858534297e+44*cos(theta)**72 - 5.96907882674947e+45*cos(theta)**70 + 4.4218789468098e+46*cos(theta)**68 - 2.08551557781216e+47*cos(theta)**66 + 7.03369640630045e+47*cos(theta)**64 - 1.80636075861168e+48*cos(theta)**62 + 3.67293354251042e+48*cos(theta)**60 - 6.07011425793038e+48*cos(theta)**58 + 8.30620767248255e+48*cos(theta)**56 - 9.53882163730286e+48*cos(theta)**54 + 9.28575085917033e+48*cos(theta)**52 - 7.7196900559623e+48*cos(theta)**50 + 5.51085100148824e+48*cos(theta)**48 - 3.39129292399276e+48*cos(theta)**46 + 1.8036938213425e+48*cos(theta)**44 - 8.30313554739662e+47*cos(theta)**42 + 3.30972208625393e+47*cos(theta)**40 - 1.14178824735872e+47*cos(theta)**38 + 3.40405910896175e+46*cos(theta)**36 - 8.74972353588699e+45*cos(theta)**34 + 1.93251767859551e+45*cos(theta)**32 - 3.6515381660319e+44*cos(theta)**30 + 5.86998929129297e+43*cos(theta)**28 - 7.97289238989847e+42*cos(theta)**26 + 9.07279421119398e+41*cos(theta)**24 - 8.56099556338304e+40*cos(theta)**22 + 6.61401329478757e+39*cos(theta)**20 - 4.11885455919252e+38*cos(theta)**18 + 2.02762145288435e+37*cos(theta)**16 - 7.69739241841575e+35*cos(theta)**14 + 2.18212682266615e+34*cos(theta)**12 - 4.42458894918481e+32*cos(theta)**10 + 6.04085263086519e+30*cos(theta)**8 - 5.07482369229599e+28*cos(theta)**6 + 2.26150788426737e+26*cos(theta)**4 - 3.99677387499389e+23*cos(theta)**2 + 1.16864733186956e+20)*cos(11*phi)

#@torch.jit.script
def Yl83_m12(theta, phi):
    return 4.67789301402734e-23*(1.0 - cos(theta)**2)**6*(2.77436058144694e+46*cos(theta)**71 - 4.17835517872463e+47*cos(theta)**69 + 3.00687768383067e+48*cos(theta)**67 - 1.37644028135603e+49*cos(theta)**65 + 4.50156570003229e+49*cos(theta)**63 - 1.11994367033924e+50*cos(theta)**61 + 2.20376012550625e+50*cos(theta)**59 - 3.52066626959962e+50*cos(theta)**57 + 4.65147629659023e+50*cos(theta)**55 - 5.15096368414354e+50*cos(theta)**53 + 4.82859044676857e+50*cos(theta)**51 - 3.85984502798115e+50*cos(theta)**49 + 2.64520848071435e+50*cos(theta)**47 - 1.55999474503667e+50*cos(theta)**45 + 7.93625281390701e+49*cos(theta)**43 - 3.48731692990658e+49*cos(theta)**41 + 1.32388883450157e+49*cos(theta)**39 - 4.33879533996314e+48*cos(theta)**37 + 1.22546127922623e+48*cos(theta)**35 - 2.97490600220158e+47*cos(theta)**33 + 6.18405657150564e+46*cos(theta)**31 - 1.09546144980957e+46*cos(theta)**29 + 1.64359700156203e+45*cos(theta)**27 - 2.0729520213736e+44*cos(theta)**25 + 2.17747061068656e+43*cos(theta)**23 - 1.88341902394427e+42*cos(theta)**21 + 1.32280265895751e+41*cos(theta)**19 - 7.41393820654653e+39*cos(theta)**17 + 3.24419432461496e+38*cos(theta)**15 - 1.0776349385782e+37*cos(theta)**13 + 2.61855218719938e+35*cos(theta)**11 - 4.42458894918481e+33*cos(theta)**9 + 4.83268210469215e+31*cos(theta)**7 - 3.04489421537759e+29*cos(theta)**5 + 9.04603153706949e+26*cos(theta)**3 - 7.99354774998777e+23*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl83_m13(theta, phi):
    return 5.66611642730628e-25*(1.0 - cos(theta)**2)**6.5*(1.96979601282732e+48*cos(theta)**70 - 2.88306507331999e+49*cos(theta)**68 + 2.01460804816655e+50*cos(theta)**66 - 8.94686182881417e+50*cos(theta)**64 + 2.83598639102034e+51*cos(theta)**62 - 6.83165638906938e+51*cos(theta)**60 + 1.30021847404869e+52*cos(theta)**58 - 2.00677977367179e+52*cos(theta)**56 + 2.55831196312463e+52*cos(theta)**54 - 2.73001075259608e+52*cos(theta)**52 + 2.46258112785197e+52*cos(theta)**50 - 1.89132406371076e+52*cos(theta)**48 + 1.24324798593575e+52*cos(theta)**46 - 7.01997635266502e+51*cos(theta)**44 + 3.41258870998001e+51*cos(theta)**42 - 1.4297999412617e+51*cos(theta)**40 + 5.16316645455613e+50*cos(theta)**38 - 1.60535427578636e+50*cos(theta)**36 + 4.2891144772918e+49*cos(theta)**34 - 9.81718980726521e+48*cos(theta)**32 + 1.91705753716675e+48*cos(theta)**30 - 3.17683820444776e+47*cos(theta)**28 + 4.43771190421749e+46*cos(theta)**26 - 5.182380053434e+45*cos(theta)**24 + 5.00818240457908e+44*cos(theta)**22 - 3.95517995028296e+43*cos(theta)**20 + 2.51332505201927e+42*cos(theta)**18 - 1.26036949511291e+41*cos(theta)**16 + 4.86629148692243e+39*cos(theta)**14 - 1.40092542015167e+38*cos(theta)**12 + 2.88040740591931e+36*cos(theta)**10 - 3.98213005426633e+34*cos(theta)**8 + 3.38287747328451e+32*cos(theta)**6 - 1.5224471076888e+30*cos(theta)**4 + 2.71380946112085e+27*cos(theta)**2 - 7.99354774998777e+23)*cos(13*phi)

#@torch.jit.script
def Yl83_m14(theta, phi):
    return 6.87623336027961e-27*(1.0 - cos(theta)**2)**7*(1.37885720897913e+50*cos(theta)**69 - 1.9604842498576e+51*cos(theta)**67 + 1.32964131178992e+52*cos(theta)**65 - 5.72599157044107e+52*cos(theta)**63 + 1.75831156243261e+53*cos(theta)**61 - 4.09899383344163e+53*cos(theta)**59 + 7.54126714948239e+53*cos(theta)**57 - 1.1237966732562e+54*cos(theta)**55 + 1.3814884600873e+54*cos(theta)**53 - 1.41960559134996e+54*cos(theta)**51 + 1.23129056392599e+54*cos(theta)**49 - 9.07835550581166e+53*cos(theta)**47 + 5.71894073530443e+53*cos(theta)**45 - 3.08878959517261e+53*cos(theta)**43 + 1.43328725819161e+53*cos(theta)**41 - 5.71919976504679e+52*cos(theta)**39 + 1.96200325273133e+52*cos(theta)**37 - 5.7792753928309e+51*cos(theta)**35 + 1.45829892227921e+51*cos(theta)**33 - 3.14150073832487e+50*cos(theta)**31 + 5.75117261150025e+49*cos(theta)**29 - 8.89514697245371e+48*cos(theta)**27 + 1.15380509509655e+48*cos(theta)**25 - 1.24377121282416e+47*cos(theta)**23 + 1.1018001290074e+46*cos(theta)**21 - 7.91035990056593e+44*cos(theta)**19 + 4.52398509363469e+43*cos(theta)**17 - 2.01659119218066e+42*cos(theta)**15 + 6.81280808169141e+40*cos(theta)**13 - 1.681110504182e+39*cos(theta)**11 + 2.88040740591931e+37*cos(theta)**9 - 3.18570404341306e+35*cos(theta)**7 + 2.0297264839707e+33*cos(theta)**5 - 6.08978843075518e+30*cos(theta)**3 + 5.4276189222417e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl83_m15(theta, phi):
    return 8.36205507851314e-29*(1.0 - cos(theta)**2)**7.5*(9.51411474195598e+51*cos(theta)**68 - 1.31352444740459e+53*cos(theta)**66 + 8.64266852663449e+53*cos(theta)**64 - 3.60737468937787e+54*cos(theta)**62 + 1.07257005308389e+55*cos(theta)**60 - 2.41840636173056e+55*cos(theta)**58 + 4.29852227520496e+55*cos(theta)**56 - 6.1808817029091e+55*cos(theta)**54 + 7.32188883846268e+55*cos(theta)**52 - 7.2399885158848e+55*cos(theta)**50 + 6.03332376323733e+55*cos(theta)**48 - 4.26682708773148e+55*cos(theta)**46 + 2.57352333088699e+55*cos(theta)**44 - 1.32817952592422e+55*cos(theta)**42 + 5.87647775858558e+54*cos(theta)**40 - 2.23048790836825e+54*cos(theta)**38 + 7.25941203510592e+53*cos(theta)**36 - 2.02274638749081e+53*cos(theta)**34 + 4.8123864435214e+52*cos(theta)**32 - 9.73865228880708e+51*cos(theta)**30 + 1.66784005733507e+51*cos(theta)**28 - 2.4016896825625e+50*cos(theta)**26 + 2.88451273774137e+49*cos(theta)**24 - 2.86067378949557e+48*cos(theta)**22 + 2.31378027091553e+47*cos(theta)**20 - 1.50296838110753e+46*cos(theta)**18 + 7.69077465917898e+44*cos(theta)**16 - 3.02488678827099e+43*cos(theta)**14 + 8.85665050619883e+41*cos(theta)**12 - 1.8492215546002e+40*cos(theta)**10 + 2.59236666532738e+38*cos(theta)**8 - 2.22999283038915e+36*cos(theta)**6 + 1.01486324198535e+34*cos(theta)**4 - 1.82693652922656e+31*cos(theta)**2 + 5.4276189222417e+27)*cos(15*phi)

#@torch.jit.script
def Yl83_m16(theta, phi):
    return 1.01915671465815e-30*(1.0 - cos(theta)**2)**8*(6.46959802453006e+53*cos(theta)**67 - 8.66926135287028e+54*cos(theta)**65 + 5.53130785704607e+55*cos(theta)**63 - 2.23657230741428e+56*cos(theta)**61 + 6.43542031850336e+56*cos(theta)**59 - 1.40267568980373e+57*cos(theta)**57 + 2.40717247411478e+57*cos(theta)**55 - 3.33767611957091e+57*cos(theta)**53 + 3.80738219600059e+57*cos(theta)**51 - 3.6199942579424e+57*cos(theta)**49 + 2.89599540635392e+57*cos(theta)**47 - 1.96274046035648e+57*cos(theta)**45 + 1.13235026559028e+57*cos(theta)**43 - 5.57835400888173e+56*cos(theta)**41 + 2.35059110343423e+56*cos(theta)**39 - 8.47585405179935e+55*cos(theta)**37 + 2.61338833263813e+55*cos(theta)**35 - 6.87733771746877e+54*cos(theta)**33 + 1.53996366192685e+54*cos(theta)**31 - 2.92159568664213e+53*cos(theta)**29 + 4.6699521605382e+52*cos(theta)**27 - 6.24439317466251e+51*cos(theta)**25 + 6.92283057057928e+50*cos(theta)**23 - 6.29348233689025e+49*cos(theta)**21 + 4.62756054183107e+48*cos(theta)**19 - 2.70534308599355e+47*cos(theta)**17 + 1.23052394546864e+46*cos(theta)**15 - 4.23484150357938e+44*cos(theta)**13 + 1.06279806074386e+43*cos(theta)**11 - 1.8492215546002e+41*cos(theta)**9 + 2.07389333226191e+39*cos(theta)**7 - 1.33799569823349e+37*cos(theta)**5 + 4.05945296794141e+34*cos(theta)**3 - 3.65387305845311e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl83_m17(theta, phi):
    return 1.24509809541783e-32*(1.0 - cos(theta)**2)**8.5*(4.33463067643514e+55*cos(theta)**66 - 5.63501987936569e+56*cos(theta)**64 + 3.48472394993903e+57*cos(theta)**62 - 1.36430910752271e+58*cos(theta)**60 + 3.79689798791698e+58*cos(theta)**58 - 7.99525143188123e+58*cos(theta)**56 + 1.32394486076313e+59*cos(theta)**54 - 1.76896834337258e+59*cos(theta)**52 + 1.9417649199603e+59*cos(theta)**50 - 1.77379718639178e+59*cos(theta)**48 + 1.36111784098634e+59*cos(theta)**46 - 8.83233207160417e+58*cos(theta)**44 + 4.86910614203819e+58*cos(theta)**42 - 2.28712514364151e+58*cos(theta)**40 + 9.16730530339351e+57*cos(theta)**38 - 3.13606599916576e+57*cos(theta)**36 + 9.14685916423347e+56*cos(theta)**34 - 2.26952144676469e+56*cos(theta)**32 + 4.77388735197323e+55*cos(theta)**30 - 8.47262749126216e+54*cos(theta)**28 + 1.26088708334531e+54*cos(theta)**26 - 1.56109829366563e+53*cos(theta)**24 + 1.59225103123323e+52*cos(theta)**22 - 1.32163129074695e+51*cos(theta)**20 + 8.79236502947903e+49*cos(theta)**18 - 4.59908324618903e+48*cos(theta)**16 + 1.84578591820296e+47*cos(theta)**14 - 5.50529395465319e+45*cos(theta)**12 + 1.16907786681825e+44*cos(theta)**10 - 1.66429939914018e+42*cos(theta)**8 + 1.45172533258333e+40*cos(theta)**6 - 6.68997849116744e+37*cos(theta)**4 + 1.21783589038242e+35*cos(theta)**2 - 3.65387305845311e+31)*cos(17*phi)

#@torch.jit.script
def Yl83_m18(theta, phi):
    return 1.52500375883672e-34*(1.0 - cos(theta)**2)**9*(2.86085624644719e+57*cos(theta)**65 - 3.60641272279404e+58*cos(theta)**63 + 2.1605288489622e+59*cos(theta)**61 - 8.18585464513627e+59*cos(theta)**59 + 2.20220083299185e+60*cos(theta)**57 - 4.47734080185349e+60*cos(theta)**55 + 7.1493022481209e+60*cos(theta)**53 - 9.19863538553744e+60*cos(theta)**51 + 9.70882459980152e+60*cos(theta)**49 - 8.51422649468053e+60*cos(theta)**47 + 6.26114206853718e+60*cos(theta)**45 - 3.88622611150583e+60*cos(theta)**43 + 2.04502457965604e+60*cos(theta)**41 - 9.14850057456603e+59*cos(theta)**39 + 3.48357601528953e+59*cos(theta)**37 - 1.12898375969967e+59*cos(theta)**35 + 3.10993211583938e+58*cos(theta)**33 - 7.26246862964702e+57*cos(theta)**31 + 1.43216620559197e+57*cos(theta)**29 - 2.37233569755341e+56*cos(theta)**27 + 3.27830641669782e+55*cos(theta)**25 - 3.7466359047975e+54*cos(theta)**23 + 3.50295226871311e+53*cos(theta)**21 - 2.64326258149391e+52*cos(theta)**19 + 1.58262570530623e+51*cos(theta)**17 - 7.35853319390245e+49*cos(theta)**15 + 2.58410028548414e+48*cos(theta)**13 - 6.60635274558383e+46*cos(theta)**11 + 1.16907786681825e+45*cos(theta)**9 - 1.33143951931214e+43*cos(theta)**7 + 8.7103519955e+40*cos(theta)**5 - 2.67599139646697e+38*cos(theta)**3 + 2.43567178076484e+35*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl83_m19(theta, phi):
    return 1.87289810371175e-36*(1.0 - cos(theta)**2)**9.5*(1.85955656019068e+59*cos(theta)**64 - 2.27204001536024e+60*cos(theta)**62 + 1.31792259786694e+61*cos(theta)**60 - 4.8296542406304e+61*cos(theta)**58 + 1.25525447480535e+62*cos(theta)**56 - 2.46253744101942e+62*cos(theta)**54 + 3.78913019150408e+62*cos(theta)**52 - 4.69130404662409e+62*cos(theta)**50 + 4.75732405390274e+62*cos(theta)**48 - 4.00168645249985e+62*cos(theta)**46 + 2.81751393084173e+62*cos(theta)**44 - 1.67107722794751e+62*cos(theta)**42 + 8.38460077658977e+61*cos(theta)**40 - 3.56791522408075e+61*cos(theta)**38 + 1.28892312565713e+61*cos(theta)**36 - 3.95144315894886e+60*cos(theta)**34 + 1.02627759822699e+60*cos(theta)**32 - 2.25136527519058e+59*cos(theta)**30 + 4.15328199621671e+58*cos(theta)**28 - 6.4053063833942e+57*cos(theta)**26 + 8.19576604174454e+56*cos(theta)**24 - 8.61726258103426e+55*cos(theta)**22 + 7.35619976429754e+54*cos(theta)**20 - 5.02219890483842e+53*cos(theta)**18 + 2.69046369902058e+52*cos(theta)**16 - 1.10377997908537e+51*cos(theta)**14 + 3.35933037112938e+49*cos(theta)**12 - 7.26698802014222e+47*cos(theta)**10 + 1.05217008013642e+46*cos(theta)**8 - 9.320076635185e+43*cos(theta)**6 + 4.35517599775e+41*cos(theta)**4 - 8.02797418940092e+38*cos(theta)**2 + 2.43567178076484e+35)*cos(19*phi)

#@torch.jit.script
def Yl83_m20(theta, phi):
    return 2.30677667075696e-38*(1.0 - cos(theta)**2)**10*(1.19011619852203e+61*cos(theta)**63 - 1.40866480952335e+62*cos(theta)**61 + 7.90753558720164e+62*cos(theta)**59 - 2.80119945956563e+63*cos(theta)**57 + 7.02942505890998e+63*cos(theta)**55 - 1.32977021815049e+64*cos(theta)**53 + 1.97034769958212e+64*cos(theta)**51 - 2.34565202331205e+64*cos(theta)**49 + 2.28351554587332e+64*cos(theta)**47 - 1.84077576814993e+64*cos(theta)**45 + 1.23970612957036e+64*cos(theta)**43 - 7.01852435737953e+63*cos(theta)**41 + 3.35384031063591e+63*cos(theta)**39 - 1.35580778515069e+63*cos(theta)**37 + 4.64012325236566e+62*cos(theta)**35 - 1.34349067404261e+62*cos(theta)**33 + 3.28408831432638e+61*cos(theta)**31 - 6.75409582557173e+60*cos(theta)**29 + 1.16291895894068e+60*cos(theta)**27 - 1.66537965968249e+59*cos(theta)**25 + 1.96698385001869e+58*cos(theta)**23 - 1.89579776782754e+57*cos(theta)**21 + 1.47123995285951e+56*cos(theta)**19 - 9.03995802870916e+54*cos(theta)**17 + 4.30474191843293e+53*cos(theta)**15 - 1.54529197071951e+52*cos(theta)**13 + 4.03119644535525e+50*cos(theta)**11 - 7.26698802014222e+48*cos(theta)**9 + 8.41736064109137e+46*cos(theta)**7 - 5.592045981111e+44*cos(theta)**5 + 1.7420703991e+42*cos(theta)**3 - 1.60559483788018e+39*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl83_m21(theta, phi):
    return 2.84982771814728e-40*(1.0 - cos(theta)**2)**10.5*(7.49773205068881e+62*cos(theta)**62 - 8.59285533809244e+63*cos(theta)**60 + 4.66544599644896e+64*cos(theta)**58 - 1.59668369195241e+65*cos(theta)**56 + 3.86618378240049e+65*cos(theta)**54 - 7.04778215619758e+65*cos(theta)**52 + 1.00487732678688e+66*cos(theta)**50 - 1.1493694914229e+66*cos(theta)**48 + 1.07325230656046e+66*cos(theta)**46 - 8.28349095667468e+65*cos(theta)**44 + 5.33073635715255e+65*cos(theta)**42 - 2.87759498652561e+65*cos(theta)**40 + 1.307997721148e+65*cos(theta)**38 - 5.01648880505754e+64*cos(theta)**36 + 1.62404313832798e+64*cos(theta)**34 - 4.43351922434062e+63*cos(theta)**32 + 1.01806737744118e+63*cos(theta)**30 - 1.9586877894158e+62*cos(theta)**28 + 3.13988118913983e+61*cos(theta)**26 - 4.16344914920623e+60*cos(theta)**24 + 4.52406285504299e+59*cos(theta)**22 - 3.98117531243783e+58*cos(theta)**20 + 2.79535591043307e+57*cos(theta)**18 - 1.53679286488056e+56*cos(theta)**16 + 6.4571128776494e+54*cos(theta)**14 - 2.00887956193537e+53*cos(theta)**12 + 4.43431608989078e+51*cos(theta)**10 - 6.54028921812799e+49*cos(theta)**8 + 5.89215244876396e+47*cos(theta)**6 - 2.7960229905555e+45*cos(theta)**4 + 5.2262111973e+42*cos(theta)**2 - 1.60559483788018e+39)*cos(21*phi)

#@torch.jit.script
def Yl83_m22(theta, phi):
    return 3.53206032116106e-42*(1.0 - cos(theta)**2)**11*(4.64859387142706e+64*cos(theta)**61 - 5.15571320285547e+65*cos(theta)**59 + 2.7059586779404e+66*cos(theta)**57 - 8.9414286749335e+66*cos(theta)**55 + 2.08773924249626e+67*cos(theta)**53 - 3.66484672122274e+67*cos(theta)**51 + 5.0243866339344e+67*cos(theta)**49 - 5.51697355882993e+67*cos(theta)**47 + 4.93696061017811e+67*cos(theta)**45 - 3.64473602093686e+67*cos(theta)**43 + 2.23890927000407e+67*cos(theta)**41 - 1.15103799461024e+67*cos(theta)**39 + 4.97039134036242e+66*cos(theta)**37 - 1.80593596982071e+66*cos(theta)**35 + 5.52174667031513e+65*cos(theta)**33 - 1.418726151789e+65*cos(theta)**31 + 3.05420213232354e+64*cos(theta)**29 - 5.48432581036425e+63*cos(theta)**27 + 8.16369109176357e+62*cos(theta)**25 - 9.99227795809495e+61*cos(theta)**23 + 9.95293828109457e+60*cos(theta)**21 - 7.96235062487566e+59*cos(theta)**19 + 5.03164063877952e+58*cos(theta)**17 - 2.45886858380889e+57*cos(theta)**15 + 9.03995802870916e+55*cos(theta)**13 - 2.41065547432244e+54*cos(theta)**11 + 4.43431608989078e+52*cos(theta)**9 - 5.2322313745024e+50*cos(theta)**7 + 3.53529146925837e+48*cos(theta)**5 - 1.1184091962222e+46*cos(theta)**3 + 1.04524223946e+43*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl83_m23(theta, phi):
    return 4.39248474414302e-44*(1.0 - cos(theta)**2)**11.5*(2.83564226157051e+66*cos(theta)**60 - 3.04187078968473e+67*cos(theta)**58 + 1.54239644642603e+68*cos(theta)**56 - 4.91778577121342e+68*cos(theta)**54 + 1.10650179852302e+69*cos(theta)**52 - 1.8690718278236e+69*cos(theta)**50 + 2.46194945062786e+69*cos(theta)**48 - 2.59297757265007e+69*cos(theta)**46 + 2.22163227458015e+69*cos(theta)**44 - 1.56723648900285e+69*cos(theta)**42 + 9.17952800701669e+68*cos(theta)**40 - 4.48904817897995e+68*cos(theta)**38 + 1.83904479593409e+68*cos(theta)**36 - 6.3207758943725e+67*cos(theta)**34 + 1.82217640120399e+67*cos(theta)**32 - 4.39805107054589e+66*cos(theta)**30 + 8.85718618373826e+65*cos(theta)**28 - 1.48076796879835e+65*cos(theta)**26 + 2.04092277294089e+64*cos(theta)**24 - 2.29822393036184e+63*cos(theta)**22 + 2.09011703902986e+62*cos(theta)**20 - 1.51284661872637e+61*cos(theta)**18 + 8.55378908592518e+59*cos(theta)**16 - 3.68830287571334e+58*cos(theta)**14 + 1.17519454373219e+57*cos(theta)**12 - 2.65172102175469e+55*cos(theta)**10 + 3.9908844809017e+53*cos(theta)**8 - 3.66256196215168e+51*cos(theta)**6 + 1.76764573462919e+49*cos(theta)**4 - 3.3552275886666e+46*cos(theta)**2 + 1.04524223946e+43)*cos(23*phi)

#@torch.jit.script
def Yl83_m24(theta, phi):
    return 5.4820469133926e-46*(1.0 - cos(theta)**2)**12*(1.7013853569423e+68*cos(theta)**59 - 1.76428505801714e+69*cos(theta)**57 + 8.63742009998576e+69*cos(theta)**55 - 2.65560431645525e+70*cos(theta)**53 + 5.7538093523197e+70*cos(theta)**51 - 9.34535913911799e+70*cos(theta)**49 + 1.18173573630137e+71*cos(theta)**47 - 1.19276968341903e+71*cos(theta)**45 + 9.77518200815266e+70*cos(theta)**43 - 6.58239325381197e+70*cos(theta)**41 + 3.67181120280668e+70*cos(theta)**39 - 1.70583830801238e+70*cos(theta)**37 + 6.62056126536274e+69*cos(theta)**35 - 2.14906380408665e+69*cos(theta)**33 + 5.83096448385278e+68*cos(theta)**31 - 1.31941532116377e+68*cos(theta)**29 + 2.48001213144671e+67*cos(theta)**27 - 3.8499967188757e+66*cos(theta)**25 + 4.89821465505814e+65*cos(theta)**23 - 5.05609264679604e+64*cos(theta)**21 + 4.18023407805972e+63*cos(theta)**19 - 2.72312391370748e+62*cos(theta)**17 + 1.36860625374803e+61*cos(theta)**15 - 5.16362402599867e+59*cos(theta)**13 + 1.41023345247863e+58*cos(theta)**11 - 2.65172102175469e+56*cos(theta)**9 + 3.19270758472136e+54*cos(theta)**7 - 2.19753717729101e+52*cos(theta)**5 + 7.07058293851675e+49*cos(theta)**3 - 6.7104551773332e+46*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl83_m25(theta, phi):
    return 6.86759797962786e-48*(1.0 - cos(theta)**2)**12.5*(1.00381736059596e+70*cos(theta)**58 - 1.00564248306977e+71*cos(theta)**56 + 4.75058105499217e+71*cos(theta)**54 - 1.40747028772128e+72*cos(theta)**52 + 2.93444276968305e+72*cos(theta)**50 - 4.57922597816781e+72*cos(theta)**48 + 5.55415796061645e+72*cos(theta)**46 - 5.36746357538564e+72*cos(theta)**44 + 4.20332826350564e+72*cos(theta)**42 - 2.69878123406291e+72*cos(theta)**40 + 1.4320063690946e+72*cos(theta)**38 - 6.31160173964581e+71*cos(theta)**36 + 2.31719644287696e+71*cos(theta)**34 - 7.09191055348594e+70*cos(theta)**32 + 1.80759898999436e+70*cos(theta)**30 - 3.82630443137493e+69*cos(theta)**28 + 6.69603275490612e+68*cos(theta)**26 - 9.62499179718925e+67*cos(theta)**24 + 1.12658937066337e+67*cos(theta)**22 - 1.06177945582717e+66*cos(theta)**20 + 7.94244474831347e+64*cos(theta)**18 - 4.62931065330271e+63*cos(theta)**16 + 2.05290938062204e+62*cos(theta)**14 - 6.71271123379827e+60*cos(theta)**12 + 1.55125679772649e+59*cos(theta)**10 - 2.38654891957922e+57*cos(theta)**8 + 2.23489530930495e+55*cos(theta)**6 - 1.0987685886455e+53*cos(theta)**4 + 2.12117488155503e+50*cos(theta)**2 - 6.7104551773332e+46)*cos(25*phi)

#@torch.jit.script
def Yl83_m26(theta, phi):
    return 8.6372923270973e-50*(1.0 - cos(theta)**2)**13*(5.82214069145656e+71*cos(theta)**57 - 5.63159790519071e+72*cos(theta)**55 + 2.56531376969577e+73*cos(theta)**53 - 7.31884549615066e+73*cos(theta)**51 + 1.46722138484152e+74*cos(theta)**49 - 2.19802846952055e+74*cos(theta)**47 + 2.55491266188357e+74*cos(theta)**45 - 2.36168397316968e+74*cos(theta)**43 + 1.76539787067237e+74*cos(theta)**41 - 1.07951249362516e+74*cos(theta)**39 + 5.4416242025595e+73*cos(theta)**37 - 2.27217662627249e+73*cos(theta)**35 + 7.87846790578166e+72*cos(theta)**33 - 2.2694113771155e+72*cos(theta)**31 + 5.42279696998309e+71*cos(theta)**29 - 1.07136524078498e+71*cos(theta)**27 + 1.74096851627559e+70*cos(theta)**25 - 2.30999803132542e+69*cos(theta)**23 + 2.47849661545942e+68*cos(theta)**21 - 2.12355891165434e+67*cos(theta)**19 + 1.42964005469642e+66*cos(theta)**17 - 7.40689704528433e+64*cos(theta)**15 + 2.87407313287086e+63*cos(theta)**13 - 8.05525348055793e+61*cos(theta)**11 + 1.55125679772649e+60*cos(theta)**9 - 1.90923913566337e+58*cos(theta)**7 + 1.34093718558297e+56*cos(theta)**5 - 4.39507435458201e+53*cos(theta)**3 + 4.24234976311005e+50*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl83_m27(theta, phi):
    return 1.09079678195221e-51*(1.0 - cos(theta)**2)**13.5*(3.31862019413024e+73*cos(theta)**56 - 3.09737884785489e+74*cos(theta)**54 + 1.35961629793876e+75*cos(theta)**52 - 3.73261120303684e+75*cos(theta)**50 + 7.18938478572347e+75*cos(theta)**48 - 1.03307338067466e+76*cos(theta)**46 + 1.1497106978476e+76*cos(theta)**44 - 1.01552410846296e+76*cos(theta)**42 + 7.23813126975672e+75*cos(theta)**40 - 4.21009872513814e+75*cos(theta)**38 + 2.01340095494701e+75*cos(theta)**36 - 7.95261819195372e+74*cos(theta)**34 + 2.59989440890795e+74*cos(theta)**32 - 7.03517526905806e+73*cos(theta)**30 + 1.57261112129509e+73*cos(theta)**28 - 2.89268615011944e+72*cos(theta)**26 + 4.35242129068898e+71*cos(theta)**24 - 5.31299547204847e+70*cos(theta)**22 + 5.20484289246478e+69*cos(theta)**20 - 4.03476193214324e+68*cos(theta)**18 + 2.43038809298392e+67*cos(theta)**16 - 1.11103455679265e+66*cos(theta)**14 + 3.73629507273212e+64*cos(theta)**12 - 8.86077882861372e+62*cos(theta)**10 + 1.39613111795384e+61*cos(theta)**8 - 1.33646739496436e+59*cos(theta)**6 + 6.70468592791486e+56*cos(theta)**4 - 1.3185223063746e+54*cos(theta)**2 + 4.24234976311005e+50)*cos(27*phi)

#@torch.jit.script
def Yl83_m28(theta, phi):
    return 1.38352924961911e-53*(1.0 - cos(theta)**2)**14*(1.85842730871294e+75*cos(theta)**55 - 1.67258457784164e+76*cos(theta)**53 + 7.07000474928154e+76*cos(theta)**51 - 1.86630560151842e+77*cos(theta)**49 + 3.45090469714727e+77*cos(theta)**47 - 4.75213755110343e+77*cos(theta)**45 + 5.05872707052946e+77*cos(theta)**43 - 4.26520125554445e+77*cos(theta)**41 + 2.89525250790269e+77*cos(theta)**39 - 1.59983751555249e+77*cos(theta)**37 + 7.24824343780925e+76*cos(theta)**35 - 2.70389018526426e+76*cos(theta)**33 + 8.31966210850543e+75*cos(theta)**31 - 2.11055258071742e+75*cos(theta)**29 + 4.40331113962627e+74*cos(theta)**27 - 7.52098399031056e+73*cos(theta)**25 + 1.04458110976535e+73*cos(theta)**23 - 1.16885900385066e+72*cos(theta)**21 + 1.04096857849296e+71*cos(theta)**19 - 7.26257147785784e+69*cos(theta)**17 + 3.88862094877427e+68*cos(theta)**15 - 1.55544837950971e+67*cos(theta)**13 + 4.48355408727854e+65*cos(theta)**11 - 8.86077882861372e+63*cos(theta)**9 + 1.11690489436307e+62*cos(theta)**7 - 8.01880436978617e+59*cos(theta)**5 + 2.68187437116594e+57*cos(theta)**3 - 2.63704461274921e+54*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl83_m29(theta, phi):
    return 1.76277949085046e-55*(1.0 - cos(theta)**2)**14.5*(1.02213501979211e+77*cos(theta)**54 - 8.8646982625607e+77*cos(theta)**52 + 3.60570242213359e+78*cos(theta)**50 - 9.14489744744025e+78*cos(theta)**48 + 1.62192520765921e+79*cos(theta)**46 - 2.13846189799654e+79*cos(theta)**44 + 2.17525264032767e+79*cos(theta)**42 - 1.74873251477322e+79*cos(theta)**40 + 1.12914847808205e+79*cos(theta)**38 - 5.91939880754422e+78*cos(theta)**36 + 2.53688520323324e+78*cos(theta)**34 - 8.92283761137207e+77*cos(theta)**32 + 2.57909525363668e+77*cos(theta)**30 - 6.12060248408051e+76*cos(theta)**28 + 1.18889400769909e+76*cos(theta)**26 - 1.88024599757764e+75*cos(theta)**24 + 2.40253655246032e+74*cos(theta)**22 - 2.45460390808639e+73*cos(theta)**20 + 1.97784029913662e+72*cos(theta)**18 - 1.23463715123583e+71*cos(theta)**16 + 5.83293142316141e+69*cos(theta)**14 - 2.02208289336262e+68*cos(theta)**12 + 4.9319094960064e+66*cos(theta)**10 - 7.97470094575235e+64*cos(theta)**8 + 7.81833426054152e+62*cos(theta)**6 - 4.00940218489309e+60*cos(theta)**4 + 8.04562311349783e+57*cos(theta)**2 - 2.63704461274921e+54)*cos(29*phi)

#@torch.jit.script
def Yl83_m30(theta, phi):
    return 2.25663794985244e-57*(1.0 - cos(theta)**2)**15*(5.51952910687742e+78*cos(theta)**53 - 4.60964309653156e+79*cos(theta)**51 + 1.80285121106679e+80*cos(theta)**49 - 4.38955077477132e+80*cos(theta)**47 + 7.46085595523239e+80*cos(theta)**45 - 9.4092323511848e+80*cos(theta)**43 + 9.1360610893762e+80*cos(theta)**41 - 6.99493005909289e+80*cos(theta)**39 + 4.29076421671178e+80*cos(theta)**37 - 2.13098357071592e+80*cos(theta)**35 + 8.625409690993e+79*cos(theta)**33 - 2.85530803563906e+79*cos(theta)**31 + 7.73728576091005e+78*cos(theta)**29 - 1.71376869554254e+78*cos(theta)**27 + 3.09112442001764e+77*cos(theta)**25 - 4.51259039418633e+76*cos(theta)**23 + 5.2855804154127e+75*cos(theta)**21 - 4.90920781617278e+74*cos(theta)**19 + 3.56011253844591e+73*cos(theta)**17 - 1.97541944197733e+72*cos(theta)**15 + 8.16610399242598e+70*cos(theta)**13 - 2.42649947203515e+69*cos(theta)**11 + 4.9319094960064e+67*cos(theta)**9 - 6.37976075660188e+65*cos(theta)**7 + 4.69100055632491e+63*cos(theta)**5 - 1.60376087395723e+61*cos(theta)**3 + 1.60912462269957e+58*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl83_m31(theta, phi):
    return 2.90316371298274e-59*(1.0 - cos(theta)**2)**15.5*(2.92535042664503e+80*cos(theta)**52 - 2.3509179792311e+81*cos(theta)**50 + 8.83397093422728e+81*cos(theta)**48 - 2.06308886414252e+82*cos(theta)**46 + 3.35738517985457e+82*cos(theta)**44 - 4.04596991100946e+82*cos(theta)**42 + 3.74578504664424e+82*cos(theta)**40 - 2.72802272304623e+82*cos(theta)**38 + 1.58758276018336e+82*cos(theta)**36 - 7.45844249750572e+81*cos(theta)**34 + 2.84638519802769e+81*cos(theta)**32 - 8.8514549104811e+80*cos(theta)**30 + 2.24381287066391e+80*cos(theta)**28 - 4.62717547796486e+79*cos(theta)**26 + 7.7278110500441e+78*cos(theta)**24 - 1.03789579066286e+78*cos(theta)**22 + 1.10997188723667e+77*cos(theta)**20 - 9.32749485072829e+75*cos(theta)**18 + 6.05219131535805e+74*cos(theta)**16 - 2.963129162966e+73*cos(theta)**14 + 1.06159351901538e+72*cos(theta)**12 - 2.66914941923866e+70*cos(theta)**10 + 4.43871854640576e+68*cos(theta)**8 - 4.46583252962131e+66*cos(theta)**6 + 2.34550027816246e+64*cos(theta)**4 - 4.8112826218717e+61*cos(theta)**2 + 1.60912462269957e+58)*cos(31*phi)

#@torch.jit.script
def Yl83_m32(theta, phi):
    return 3.75423051100115e-61*(1.0 - cos(theta)**2)**16*(1.52118222185542e+82*cos(theta)**51 - 1.17545898961555e+83*cos(theta)**49 + 4.2403060484291e+83*cos(theta)**47 - 9.4902087750556e+83*cos(theta)**45 + 1.47724947913601e+84*cos(theta)**43 - 1.69930736262397e+84*cos(theta)**41 + 1.4983140186577e+84*cos(theta)**39 - 1.03664863475757e+84*cos(theta)**37 + 5.71529793666009e+83*cos(theta)**35 - 2.53587044915194e+83*cos(theta)**33 + 9.10843263368861e+82*cos(theta)**31 - 2.65543647314433e+82*cos(theta)**29 + 6.28267603785896e+81*cos(theta)**27 - 1.20306562427086e+81*cos(theta)**25 + 1.85467465201058e+80*cos(theta)**23 - 2.28337073945828e+79*cos(theta)**21 + 2.21994377447333e+78*cos(theta)**19 - 1.67894907313109e+77*cos(theta)**17 + 9.68350610457288e+75*cos(theta)**15 - 4.1483808281524e+74*cos(theta)**13 + 1.27391222281845e+73*cos(theta)**11 - 2.66914941923866e+71*cos(theta)**9 + 3.55097483712461e+69*cos(theta)**7 - 2.67949951777279e+67*cos(theta)**5 + 9.38200111264982e+64*cos(theta)**3 - 9.62256524374341e+61*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl83_m33(theta, phi):
    return 4.88097802358857e-63*(1.0 - cos(theta)**2)**16.5*(7.75802933146262e+83*cos(theta)**50 - 5.75974904911619e+84*cos(theta)**48 + 1.99294384276168e+85*cos(theta)**46 - 4.27059394877502e+85*cos(theta)**44 + 6.35217276028485e+85*cos(theta)**42 - 6.96716018675829e+85*cos(theta)**40 + 5.84342467276502e+85*cos(theta)**38 - 3.835599948603e+85*cos(theta)**36 + 2.00035427783103e+85*cos(theta)**34 - 8.36837248220141e+84*cos(theta)**32 + 2.82361411644347e+84*cos(theta)**30 - 7.70076577211855e+83*cos(theta)**28 + 1.69632253022192e+83*cos(theta)**26 - 3.00766406067716e+82*cos(theta)**24 + 4.26575169962434e+81*cos(theta)**22 - 4.7950785528624e+80*cos(theta)**20 + 4.21789317149933e+79*cos(theta)**18 - 2.85421342432286e+78*cos(theta)**16 + 1.45252591568593e+77*cos(theta)**14 - 5.39289507659811e+75*cos(theta)**12 + 1.4013034451003e+74*cos(theta)**10 - 2.4022344773148e+72*cos(theta)**8 + 2.48568238598722e+70*cos(theta)**6 - 1.33974975888639e+68*cos(theta)**4 + 2.81460033379495e+65*cos(theta)**2 - 9.62256524374341e+61)*cos(33*phi)

#@torch.jit.script
def Yl83_m34(theta, phi):
    return 6.38159030453734e-65*(1.0 - cos(theta)**2)**17*(3.87901466573131e+85*cos(theta)**49 - 2.76467954357577e+86*cos(theta)**47 + 9.16754167670371e+86*cos(theta)**45 - 1.87906133746101e+87*cos(theta)**43 + 2.66791255931964e+87*cos(theta)**41 - 2.78686407470332e+87*cos(theta)**39 + 2.22050137565071e+87*cos(theta)**37 - 1.38081598149708e+87*cos(theta)**35 + 6.80120454462551e+86*cos(theta)**33 - 2.67787919430445e+86*cos(theta)**31 + 8.47084234933041e+85*cos(theta)**29 - 2.1562144161932e+85*cos(theta)**27 + 4.41043857857699e+84*cos(theta)**25 - 7.21839374562519e+83*cos(theta)**23 + 9.38465373917355e+82*cos(theta)**21 - 9.59015710572479e+81*cos(theta)**19 + 7.5922077086988e+80*cos(theta)**17 - 4.56674147891657e+79*cos(theta)**15 + 2.0335362819603e+78*cos(theta)**13 - 6.47147409191774e+76*cos(theta)**11 + 1.4013034451003e+75*cos(theta)**9 - 1.92178758185184e+73*cos(theta)**7 + 1.49140943159233e+71*cos(theta)**5 - 5.35899903554558e+68*cos(theta)**3 + 5.62920066758989e+65*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl83_m35(theta, phi):
    return 8.39247150883301e-67*(1.0 - cos(theta)**2)**17.5*(1.90071718620834e+87*cos(theta)**48 - 1.29939938548061e+88*cos(theta)**46 + 4.12539375451667e+88*cos(theta)**44 - 8.07996375108234e+88*cos(theta)**42 + 1.09384414932105e+89*cos(theta)**40 - 1.08687698913429e+89*cos(theta)**38 + 8.21585508990762e+88*cos(theta)**36 - 4.83285593523978e+88*cos(theta)**34 + 2.24439749972642e+88*cos(theta)**32 - 8.3014255023438e+87*cos(theta)**30 + 2.45654428130582e+87*cos(theta)**28 - 5.82177892372163e+86*cos(theta)**26 + 1.10260964464425e+86*cos(theta)**24 - 1.66023056149379e+85*cos(theta)**22 + 1.97077728522645e+84*cos(theta)**20 - 1.82212985008771e+83*cos(theta)**18 + 1.2906753104788e+82*cos(theta)**16 - 6.85011221837485e+80*cos(theta)**14 + 2.6435971665484e+79*cos(theta)**12 - 7.11862150110951e+77*cos(theta)**10 + 1.26117310059027e+76*cos(theta)**8 - 1.34525130729629e+74*cos(theta)**6 + 7.45704715796167e+71*cos(theta)**4 - 1.60769971066367e+69*cos(theta)**2 + 5.62920066758989e+65)*cos(35*phi)

#@torch.jit.script
def Yl83_m36(theta, phi):
    return 1.11044173543872e-68*(1.0 - cos(theta)**2)**18*(9.12344249380005e+88*cos(theta)**47 - 5.97723717321082e+89*cos(theta)**45 + 1.81517325198733e+90*cos(theta)**43 - 3.39358477545458e+90*cos(theta)**41 + 4.37537659728421e+90*cos(theta)**39 - 4.13013255871032e+90*cos(theta)**37 + 2.95770783236674e+90*cos(theta)**35 - 1.64317101798152e+90*cos(theta)**33 + 7.18207199912454e+89*cos(theta)**31 - 2.49042765070314e+89*cos(theta)**29 + 6.87832398765629e+88*cos(theta)**27 - 1.51366252016762e+88*cos(theta)**25 + 2.64626314714619e+87*cos(theta)**23 - 3.65250723528635e+86*cos(theta)**21 + 3.94155457045289e+85*cos(theta)**19 - 3.27983373015788e+84*cos(theta)**17 + 2.06508049676607e+83*cos(theta)**15 - 9.59015710572479e+81*cos(theta)**13 + 3.17231659985807e+80*cos(theta)**11 - 7.11862150110951e+78*cos(theta)**9 + 1.00893848047221e+77*cos(theta)**7 - 8.07150784377771e+74*cos(theta)**5 + 2.98281886318467e+72*cos(theta)**3 - 3.21539942132735e+69*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl83_m37(theta, phi):
    return 1.47861880142803e-70*(1.0 - cos(theta)**2)**18.5*(4.28801797208602e+90*cos(theta)**46 - 2.68975672794487e+91*cos(theta)**44 + 7.80524498354554e+91*cos(theta)**42 - 1.39136975793638e+92*cos(theta)**40 + 1.70639687294084e+92*cos(theta)**38 - 1.52814904672282e+92*cos(theta)**36 + 1.03519774132836e+92*cos(theta)**34 - 5.42246435933903e+91*cos(theta)**32 + 2.22644231972861e+91*cos(theta)**30 - 7.22224018703911e+90*cos(theta)**28 + 1.8571474766672e+90*cos(theta)**26 - 3.78415630041906e+89*cos(theta)**24 + 6.08640523843625e+88*cos(theta)**22 - 7.67026519410133e+87*cos(theta)**20 + 7.48895368386049e+86*cos(theta)**18 - 5.5757173412684e+85*cos(theta)**16 + 3.09762074514911e+84*cos(theta)**14 - 1.24672042374422e+83*cos(theta)**12 + 3.48954825984388e+81*cos(theta)**10 - 6.40675935099856e+79*cos(theta)**8 + 7.0625693633055e+77*cos(theta)**6 - 4.03575392188886e+75*cos(theta)**4 + 8.94845658955401e+72*cos(theta)**2 - 3.21539942132735e+69)*cos(37*phi)

#@torch.jit.script
def Yl83_m38(theta, phi):
    return 1.98191316809053e-72*(1.0 - cos(theta)**2)**19*(1.97248826715957e+92*cos(theta)**45 - 1.18349296029574e+93*cos(theta)**43 + 3.27820289308913e+93*cos(theta)**41 - 5.56547903174551e+93*cos(theta)**39 + 6.4843081171752e+93*cos(theta)**37 - 5.50133656820214e+93*cos(theta)**35 + 3.51967232051642e+93*cos(theta)**33 - 1.73518859498849e+93*cos(theta)**31 + 6.67932695918582e+92*cos(theta)**29 - 2.02222725237095e+92*cos(theta)**27 + 4.82858343933472e+91*cos(theta)**25 - 9.08197512100574e+90*cos(theta)**23 + 1.33900915245597e+90*cos(theta)**21 - 1.53405303882027e+89*cos(theta)**19 + 1.34801166309489e+88*cos(theta)**17 - 8.92114774602943e+86*cos(theta)**15 + 4.33666904320875e+85*cos(theta)**13 - 1.49606450849307e+84*cos(theta)**11 + 3.48954825984388e+82*cos(theta)**9 - 5.12540748079885e+80*cos(theta)**7 + 4.2375416179833e+78*cos(theta)**5 - 1.61430156875554e+76*cos(theta)**3 + 1.7896913179108e+73*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl83_m39(theta, phi):
    return 2.67484395331603e-74*(1.0 - cos(theta)**2)**19.5*(8.87619720221806e+93*cos(theta)**44 - 5.08901972927169e+94*cos(theta)**42 + 1.34406318616654e+95*cos(theta)**40 - 2.17053682238075e+95*cos(theta)**38 + 2.39919400335482e+95*cos(theta)**36 - 1.92546779887075e+95*cos(theta)**34 + 1.16149186577042e+95*cos(theta)**32 - 5.37908464446432e+94*cos(theta)**30 + 1.93700481816389e+94*cos(theta)**28 - 5.46001358140157e+93*cos(theta)**26 + 1.20714585983368e+93*cos(theta)**24 - 2.08885427783132e+92*cos(theta)**22 + 2.81191922015755e+91*cos(theta)**20 - 2.9147007737585e+90*cos(theta)**18 + 2.29161982726131e+89*cos(theta)**16 - 1.33817216190442e+88*cos(theta)**14 + 5.63766975617138e+86*cos(theta)**12 - 1.64567095934237e+85*cos(theta)**10 + 3.14059343385949e+83*cos(theta)**8 - 3.58778523655919e+81*cos(theta)**6 + 2.11877080899165e+79*cos(theta)**4 - 4.84290470626663e+76*cos(theta)**2 + 1.7896913179108e+73)*cos(39*phi)

#@torch.jit.script
def Yl83_m40(theta, phi):
    return 3.63596385275829e-76*(1.0 - cos(theta)**2)**20*(3.90552676897595e+95*cos(theta)**43 - 2.13738828629411e+96*cos(theta)**41 + 5.37625274466617e+96*cos(theta)**39 - 8.24803992504685e+96*cos(theta)**37 + 8.63709841207736e+96*cos(theta)**35 - 6.54659051616055e+96*cos(theta)**33 + 3.71677397046534e+96*cos(theta)**31 - 1.61372539333929e+96*cos(theta)**29 + 5.42361349085889e+95*cos(theta)**27 - 1.41960353116441e+95*cos(theta)**25 + 2.89715006360083e+94*cos(theta)**23 - 4.5954794112289e+93*cos(theta)**21 + 5.62383844031509e+92*cos(theta)**19 - 5.24646139276531e+91*cos(theta)**17 + 3.6665917236181e+90*cos(theta)**15 - 1.87344102666618e+89*cos(theta)**13 + 6.76520370740565e+87*cos(theta)**11 - 1.64567095934237e+86*cos(theta)**9 + 2.5124747470876e+84*cos(theta)**7 - 2.15267114193552e+82*cos(theta)**5 + 8.4750832359666e+79*cos(theta)**3 - 9.68580941253326e+76*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl83_m41(theta, phi):
    return 4.97937101135538e-78*(1.0 - cos(theta)**2)**20.5*(1.67937651065966e+97*cos(theta)**42 - 8.76329197380585e+97*cos(theta)**40 + 2.0967385704198e+98*cos(theta)**38 - 3.05177477226733e+98*cos(theta)**36 + 3.02298444422708e+98*cos(theta)**34 - 2.16037487033298e+98*cos(theta)**32 + 1.15219993084426e+98*cos(theta)**30 - 4.67980364068395e+97*cos(theta)**28 + 1.4643756425319e+97*cos(theta)**26 - 3.54900882791102e+96*cos(theta)**24 + 6.66344514628191e+95*cos(theta)**22 - 9.6505067635807e+94*cos(theta)**20 + 1.06852930365987e+94*cos(theta)**18 - 8.91898436770102e+92*cos(theta)**16 + 5.49988758542715e+91*cos(theta)**14 - 2.43547333466604e+90*cos(theta)**12 + 7.44172407814622e+88*cos(theta)**10 - 1.48110386340814e+87*cos(theta)**8 + 1.75873232296132e+85*cos(theta)**6 - 1.07633557096776e+83*cos(theta)**4 + 2.54252497078998e+80*cos(theta)**2 - 9.68580941253326e+76)*cos(41*phi)

#@torch.jit.script
def Yl83_m42(theta, phi):
    return 6.87218488424811e-80*(1.0 - cos(theta)**2)**21*(7.05338134477056e+98*cos(theta)**41 - 3.50531678952234e+99*cos(theta)**39 + 7.96760656759526e+99*cos(theta)**37 - 1.09863891801624e+100*cos(theta)**35 + 1.02781471103721e+100*cos(theta)**33 - 6.91319958506554e+99*cos(theta)**31 + 3.45659979253277e+99*cos(theta)**29 - 1.31034501939151e+99*cos(theta)**27 + 3.80737667058294e+98*cos(theta)**25 - 8.51762118698644e+97*cos(theta)**23 + 1.46595793218202e+97*cos(theta)**21 - 1.93010135271614e+96*cos(theta)**19 + 1.92335274658776e+95*cos(theta)**17 - 1.42703749883216e+94*cos(theta)**15 + 7.699842619598e+92*cos(theta)**13 - 2.92256800159924e+91*cos(theta)**11 + 7.44172407814622e+89*cos(theta)**9 - 1.18488309072651e+88*cos(theta)**7 + 1.05523939377679e+86*cos(theta)**5 - 4.30534228387103e+83*cos(theta)**3 + 5.08504994157996e+80*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl83_m43(theta, phi):
    return 9.56131516798588e-82*(1.0 - cos(theta)**2)**21.5*(2.89188635135593e+100*cos(theta)**40 - 1.36707354791371e+101*cos(theta)**38 + 2.94801443001025e+101*cos(theta)**36 - 3.84523621305684e+101*cos(theta)**34 + 3.39178854642278e+101*cos(theta)**32 - 2.14309187137032e+101*cos(theta)**30 + 1.0024139398345e+101*cos(theta)**28 - 3.53793155235707e+100*cos(theta)**26 + 9.51844167645735e+99*cos(theta)**24 - 1.95905287300688e+99*cos(theta)**22 + 3.07851165758224e+98*cos(theta)**20 - 3.66719257016067e+97*cos(theta)**18 + 3.26969966919919e+96*cos(theta)**16 - 2.14055624824825e+95*cos(theta)**14 + 1.00097954054774e+94*cos(theta)**12 - 3.21482480175917e+92*cos(theta)**10 + 6.6975516703316e+90*cos(theta)**8 - 8.29418163508557e+88*cos(theta)**6 + 5.27619696888395e+86*cos(theta)**4 - 1.29160268516131e+84*cos(theta)**2 + 5.08504994157996e+80)*cos(43*phi)

#@torch.jit.script
def Yl83_m44(theta, phi):
    return 1.34148486702454e-83*(1.0 - cos(theta)**2)**22*(1.15675454054237e+102*cos(theta)**39 - 5.19487948207211e+102*cos(theta)**37 + 1.06128519480369e+103*cos(theta)**35 - 1.30738031243933e+103*cos(theta)**33 + 1.08537233485529e+103*cos(theta)**31 - 6.42927561411095e+102*cos(theta)**29 + 2.80675903153661e+102*cos(theta)**27 - 9.19862203612838e+101*cos(theta)**25 + 2.28442600234976e+101*cos(theta)**23 - 4.30991632061514e+100*cos(theta)**21 + 6.15702331516449e+99*cos(theta)**19 - 6.6009466262892e+98*cos(theta)**17 + 5.23151947071871e+97*cos(theta)**15 - 2.99677874754754e+96*cos(theta)**13 + 1.20117544865729e+95*cos(theta)**11 - 3.21482480175917e+93*cos(theta)**9 + 5.35804133626528e+91*cos(theta)**7 - 4.97650898105134e+89*cos(theta)**5 + 2.11047878755358e+87*cos(theta)**3 - 2.58320537032262e+84*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl83_m45(theta, phi):
    return 1.8986656332305e-85*(1.0 - cos(theta)**2)**22.5*(4.51134270811525e+103*cos(theta)**38 - 1.92210540836668e+104*cos(theta)**36 + 3.71449818181291e+104*cos(theta)**34 - 4.31435503104978e+104*cos(theta)**32 + 3.3646542380514e+104*cos(theta)**30 - 1.86448992809218e+104*cos(theta)**28 + 7.57824938514884e+103*cos(theta)**26 - 2.2996555090321e+103*cos(theta)**24 + 5.25417980540446e+102*cos(theta)**22 - 9.05082427329179e+101*cos(theta)**20 + 1.16983442988125e+101*cos(theta)**18 - 1.12216092646916e+100*cos(theta)**16 + 7.84727920607807e+98*cos(theta)**14 - 3.89581237181181e+97*cos(theta)**12 + 1.32129299352302e+96*cos(theta)**10 - 2.89334232158325e+94*cos(theta)**8 + 3.75062893538569e+92*cos(theta)**6 - 2.48825449052567e+90*cos(theta)**4 + 6.33143636266074e+87*cos(theta)**2 - 2.58320537032262e+84)*cos(45*phi)

#@torch.jit.script
def Yl83_m46(theta, phi):
    return 2.71182609860722e-87*(1.0 - cos(theta)**2)**23*(1.7143102290838e+105*cos(theta)**37 - 6.91957947012005e+105*cos(theta)**35 + 1.26292938181639e+106*cos(theta)**33 - 1.38059360993593e+106*cos(theta)**31 + 1.00939627141542e+106*cos(theta)**29 - 5.22057179865809e+105*cos(theta)**27 + 1.9703448401387e+105*cos(theta)**25 - 5.51917322167703e+104*cos(theta)**23 + 1.15591955718898e+104*cos(theta)**21 - 1.81016485465836e+103*cos(theta)**19 + 2.10570197378625e+102*cos(theta)**17 - 1.79545748235066e+101*cos(theta)**15 + 1.09861908885093e+100*cos(theta)**13 - 4.67497484617417e+98*cos(theta)**11 + 1.32129299352302e+97*cos(theta)**9 - 2.3146738572666e+95*cos(theta)**7 + 2.25037736123142e+93*cos(theta)**5 - 9.95301796210268e+90*cos(theta)**3 + 1.26628727253215e+88*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl83_m47(theta, phi):
    return 3.91011290495497e-89*(1.0 - cos(theta)**2)**23.5*(6.34294784761004e+106*cos(theta)**36 - 2.42185281454202e+107*cos(theta)**34 + 4.16766695999408e+107*cos(theta)**32 - 4.27984019080138e+107*cos(theta)**30 + 2.92724918710472e+107*cos(theta)**28 - 1.40955438563769e+107*cos(theta)**26 + 4.92586210034675e+106*cos(theta)**24 - 1.26940984098572e+106*cos(theta)**22 + 2.42743107009686e+105*cos(theta)**20 - 3.43931322385088e+104*cos(theta)**18 + 3.57969335543663e+103*cos(theta)**16 - 2.69318622352599e+102*cos(theta)**14 + 1.42820481550621e+101*cos(theta)**12 - 5.14247233079158e+99*cos(theta)**10 + 1.18916369417072e+98*cos(theta)**8 - 1.62027170008662e+96*cos(theta)**6 + 1.12518868061571e+94*cos(theta)**4 - 2.98590538863081e+91*cos(theta)**2 + 1.26628727253215e+88)*cos(47*phi)

#@torch.jit.script
def Yl83_m48(theta, phi):
    return 5.69380251176972e-91*(1.0 - cos(theta)**2)**24*(2.28346122513962e+108*cos(theta)**35 - 8.23429956944286e+108*cos(theta)**33 + 1.33365342719811e+109*cos(theta)**31 - 1.28395205724041e+109*cos(theta)**29 + 8.1962977238932e+108*cos(theta)**27 - 3.66484140265798e+108*cos(theta)**25 + 1.18220690408322e+108*cos(theta)**23 - 2.79270165016858e+107*cos(theta)**21 + 4.85486214019372e+106*cos(theta)**19 - 6.19076380293159e+105*cos(theta)**17 + 5.72750936869861e+104*cos(theta)**15 - 3.77046071293639e+103*cos(theta)**13 + 1.71384577860745e+102*cos(theta)**11 - 5.14247233079158e+100*cos(theta)**9 + 9.51330955336573e+98*cos(theta)**7 - 9.72163020051972e+96*cos(theta)**5 + 4.50075472246283e+94*cos(theta)**3 - 5.97181077726161e+91*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl83_m49(theta, phi):
    return 8.3768629824346e-93*(1.0 - cos(theta)**2)**24.5*(7.99211428798866e+109*cos(theta)**34 - 2.71731885791614e+110*cos(theta)**32 + 4.13432562431413e+110*cos(theta)**30 - 3.7234609659972e+110*cos(theta)**28 + 2.21300038545117e+110*cos(theta)**26 - 9.16210350664495e+109*cos(theta)**24 + 2.71907587939141e+109*cos(theta)**22 - 5.86467346535401e+108*cos(theta)**20 + 9.22423806636806e+107*cos(theta)**18 - 1.05242984649837e+107*cos(theta)**16 + 8.59126405304792e+105*cos(theta)**14 - 4.90159892681731e+104*cos(theta)**12 + 1.88523035646819e+103*cos(theta)**10 - 4.62822509771243e+101*cos(theta)**8 + 6.65931668735601e+99*cos(theta)**6 - 4.86081510025986e+97*cos(theta)**4 + 1.35022641673885e+95*cos(theta)**2 - 5.97181077726161e+91)*cos(49*phi)

#@torch.jit.script
def Yl83_m50(theta, phi):
    return 1.24570765398148e-94*(1.0 - cos(theta)**2)**25*(2.71731885791614e+111*cos(theta)**33 - 8.69542034533166e+111*cos(theta)**31 + 1.24029768729424e+112*cos(theta)**29 - 1.04256907047922e+112*cos(theta)**27 + 5.75380100217303e+111*cos(theta)**25 - 2.19890484159479e+111*cos(theta)**23 + 5.98196693466109e+110*cos(theta)**21 - 1.1729346930708e+110*cos(theta)**19 + 1.66036285194625e+109*cos(theta)**17 - 1.68388775439739e+108*cos(theta)**15 + 1.20277696742671e+107*cos(theta)**13 - 5.88191871218077e+105*cos(theta)**11 + 1.88523035646819e+104*cos(theta)**9 - 3.70258007816994e+102*cos(theta)**7 + 3.9955900124136e+100*cos(theta)**5 - 1.94432604010394e+98*cos(theta)**3 + 2.7004528334777e+95*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl83_m51(theta, phi):
    return 1.8732975441188e-96*(1.0 - cos(theta)**2)**25.5*(8.96715223112327e+112*cos(theta)**32 - 2.69558030705281e+113*cos(theta)**30 + 3.59686329315329e+113*cos(theta)**28 - 2.81493649029388e+113*cos(theta)**26 + 1.43845025054326e+113*cos(theta)**24 - 5.05748113566801e+112*cos(theta)**22 + 1.25621305627883e+112*cos(theta)**20 - 2.22857591683452e+111*cos(theta)**18 + 2.82261684830863e+110*cos(theta)**16 - 2.52583163159609e+109*cos(theta)**14 + 1.56361005765472e+108*cos(theta)**12 - 6.47011058339884e+106*cos(theta)**10 + 1.69670732082138e+105*cos(theta)**8 - 2.59180605471896e+103*cos(theta)**6 + 1.9977950062068e+101*cos(theta)**4 - 5.83297812031183e+98*cos(theta)**2 + 2.7004528334777e+95)*cos(51*phi)

#@torch.jit.script
def Yl83_m52(theta, phi):
    return 2.85013144953582e-98*(1.0 - cos(theta)**2)**26*(2.86948871395945e+114*cos(theta)**31 - 8.08674092115844e+114*cos(theta)**29 + 1.00712172208292e+115*cos(theta)**27 - 7.31883487476409e+114*cos(theta)**25 + 3.45228060130382e+114*cos(theta)**23 - 1.11264584984696e+114*cos(theta)**21 + 2.51242611255766e+113*cos(theta)**19 - 4.01143665030214e+112*cos(theta)**17 + 4.5161869572938e+111*cos(theta)**15 - 3.53616428423452e+110*cos(theta)**13 + 1.87633206918566e+109*cos(theta)**11 - 6.47011058339884e+107*cos(theta)**9 + 1.3573658566571e+106*cos(theta)**7 - 1.55508363283138e+104*cos(theta)**5 + 7.99118002482721e+101*cos(theta)**3 - 1.16659562406237e+99*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl83_m53(theta, phi):
    return 4.3894953091829e-100*(1.0 - cos(theta)**2)**26.5*(8.89541501327428e+115*cos(theta)**30 - 2.34515486713595e+116*cos(theta)**28 + 2.71922864962389e+116*cos(theta)**26 - 1.82970871869102e+116*cos(theta)**24 + 7.94024538299878e+115*cos(theta)**22 - 2.33655628467862e+115*cos(theta)**20 + 4.77360961385955e+114*cos(theta)**18 - 6.81944230551364e+113*cos(theta)**16 + 6.77428043594071e+112*cos(theta)**14 - 4.59701356950488e+111*cos(theta)**12 + 2.06396527610423e+110*cos(theta)**10 - 5.82309952505896e+108*cos(theta)**8 + 9.5015609965997e+106*cos(theta)**6 - 7.77541816415688e+104*cos(theta)**4 + 2.39735400744816e+102*cos(theta)**2 - 1.16659562406237e+99)*cos(53*phi)

#@torch.jit.script
def Yl83_m54(theta, phi):
    return 6.84689516530791e-102*(1.0 - cos(theta)**2)**27*(2.66862450398229e+117*cos(theta)**29 - 6.56643362798065e+117*cos(theta)**27 + 7.06999448902212e+117*cos(theta)**25 - 4.39130092485846e+117*cos(theta)**23 + 1.74685398425973e+117*cos(theta)**21 - 4.67311256935724e+116*cos(theta)**19 + 8.59249730494719e+115*cos(theta)**17 - 1.09111076888218e+115*cos(theta)**15 + 9.48399261031699e+113*cos(theta)**13 - 5.51641628340585e+112*cos(theta)**11 + 2.06396527610423e+111*cos(theta)**9 - 4.65847962004717e+109*cos(theta)**7 + 5.70093659795982e+107*cos(theta)**5 - 3.11016726566275e+105*cos(theta)**3 + 4.79470801489633e+102*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl83_m55(theta, phi):
    return 1.08231863529359e-103*(1.0 - cos(theta)**2)**27.5*(7.73901106154863e+118*cos(theta)**28 - 1.77293707955478e+119*cos(theta)**26 + 1.76749862225553e+119*cos(theta)**24 - 1.00999921271744e+119*cos(theta)**22 + 3.66839336694544e+118*cos(theta)**20 - 8.87891388177877e+117*cos(theta)**18 + 1.46072454184102e+117*cos(theta)**16 - 1.63666615332327e+116*cos(theta)**14 + 1.23291903934121e+115*cos(theta)**12 - 6.06805791174644e+113*cos(theta)**10 + 1.85756874849381e+112*cos(theta)**8 - 3.26093573403302e+110*cos(theta)**6 + 2.85046829897991e+108*cos(theta)**4 - 9.33050179698825e+105*cos(theta)**2 + 4.79470801489633e+102)*cos(55*phi)

#@torch.jit.script
def Yl83_m56(theta, phi):
    return 1.7348771235664e-105*(1.0 - cos(theta)**2)**28*(2.16692309723362e+120*cos(theta)**27 - 4.60963640684242e+120*cos(theta)**25 + 4.24199669341327e+120*cos(theta)**23 - 2.22199826797838e+120*cos(theta)**21 + 7.33678673389087e+119*cos(theta)**19 - 1.59820449872018e+119*cos(theta)**17 + 2.33715926694564e+118*cos(theta)**15 - 2.29133261465258e+117*cos(theta)**13 + 1.47950284720945e+116*cos(theta)**11 - 6.06805791174644e+114*cos(theta)**9 + 1.48605499879505e+113*cos(theta)**7 - 1.95656144041981e+111*cos(theta)**5 + 1.14018731959196e+109*cos(theta)**3 - 1.86610035939765e+106*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl83_m57(theta, phi):
    return 2.82177785240865e-107*(1.0 - cos(theta)**2)**28.5*(5.85069236253076e+121*cos(theta)**26 - 1.1524091017106e+122*cos(theta)**24 + 9.75659239485052e+121*cos(theta)**22 - 4.6661963627546e+121*cos(theta)**20 + 1.39398947943927e+121*cos(theta)**18 - 2.7169476478243e+120*cos(theta)**16 + 3.50573890041845e+119*cos(theta)**14 - 2.97873239904836e+118*cos(theta)**12 + 1.6274531319304e+117*cos(theta)**10 - 5.4612521205718e+115*cos(theta)**8 + 1.04023849915653e+114*cos(theta)**6 - 9.78280720209905e+111*cos(theta)**4 + 3.42056195877589e+109*cos(theta)**2 - 1.86610035939765e+106)*cos(57*phi)

#@torch.jit.script
def Yl83_m58(theta, phi):
    return 4.66043644840752e-109*(1.0 - cos(theta)**2)**29*(1.521180014258e+123*cos(theta)**25 - 2.76578184410545e+123*cos(theta)**23 + 2.14645032686711e+123*cos(theta)**21 - 9.33239272550919e+122*cos(theta)**19 + 2.50918106299068e+122*cos(theta)**17 - 4.34711623651888e+121*cos(theta)**15 + 4.90803446058584e+120*cos(theta)**13 - 3.57447887885803e+119*cos(theta)**11 + 1.6274531319304e+118*cos(theta)**9 - 4.36900169645744e+116*cos(theta)**7 + 6.2414309949392e+114*cos(theta)**5 - 3.91312288083962e+112*cos(theta)**3 + 6.84112391755179e+109*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl83_m59(theta, phi):
    return 7.82190277806005e-111*(1.0 - cos(theta)**2)**29.5*(3.802950035645e+124*cos(theta)**24 - 6.36129824144254e+124*cos(theta)**22 + 4.50754568642094e+124*cos(theta)**20 - 1.77315461784675e+124*cos(theta)**18 + 4.26560780708415e+123*cos(theta)**16 - 6.52067435477833e+122*cos(theta)**14 + 6.38044479876159e+121*cos(theta)**12 - 3.93192676674383e+120*cos(theta)**10 + 1.46470781873736e+119*cos(theta)**8 - 3.05830118752021e+117*cos(theta)**6 + 3.1207154974696e+115*cos(theta)**4 - 1.17393686425189e+113*cos(theta)**2 + 6.84112391755179e+109)*cos(59*phi)

#@torch.jit.script
def Yl83_m60(theta, phi):
    return 1.33517678946737e-112*(1.0 - cos(theta)**2)**30*(9.12708008554799e+125*cos(theta)**23 - 1.39948561311736e+126*cos(theta)**21 + 9.01509137284188e+125*cos(theta)**19 - 3.19167831212414e+125*cos(theta)**17 + 6.82497249133465e+124*cos(theta)**15 - 9.12894409668965e+123*cos(theta)**13 + 7.6565337585139e+122*cos(theta)**11 - 3.93192676674383e+121*cos(theta)**9 + 1.17176625498988e+120*cos(theta)**7 - 1.83498071251212e+118*cos(theta)**5 + 1.24828619898784e+116*cos(theta)**3 - 2.34787372850377e+113*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl83_m61(theta, phi):
    return 2.32003004931995e-114*(1.0 - cos(theta)**2)**30.5*(2.09922841967604e+127*cos(theta)**22 - 2.93891978754645e+127*cos(theta)**20 + 1.71286736083996e+127*cos(theta)**18 - 5.42585313061104e+126*cos(theta)**16 + 1.0237458737002e+126*cos(theta)**14 - 1.18676273256966e+125*cos(theta)**12 + 8.42218713436529e+123*cos(theta)**10 - 3.53873409006945e+122*cos(theta)**8 + 8.20236378492919e+120*cos(theta)**6 - 9.17490356256062e+118*cos(theta)**4 + 3.74485859696352e+116*cos(theta)**2 - 2.34787372850377e+113)*cos(61*phi)

#@torch.jit.script
def Yl83_m62(theta, phi):
    return 4.10769574780988e-116*(1.0 - cos(theta)**2)**31*(4.61830252328728e+128*cos(theta)**21 - 5.87783957509291e+128*cos(theta)**19 + 3.08316124951192e+128*cos(theta)**17 - 8.68136500897767e+127*cos(theta)**15 + 1.43324422318028e+127*cos(theta)**13 - 1.42411527908359e+126*cos(theta)**11 + 8.42218713436529e+124*cos(theta)**9 - 2.83098727205556e+123*cos(theta)**7 + 4.92141827095752e+121*cos(theta)**5 - 3.66996142502425e+119*cos(theta)**3 + 7.48971719392703e+116*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl83_m63(theta, phi):
    return 7.41843324752135e-118*(1.0 - cos(theta)**2)**31.5*(9.69843529890329e+129*cos(theta)**20 - 1.11678951926765e+130*cos(theta)**18 + 5.24137412417027e+129*cos(theta)**16 - 1.30220475134665e+129*cos(theta)**14 + 1.86321749013436e+128*cos(theta)**12 - 1.56652680699194e+127*cos(theta)**10 + 7.57996842092876e+125*cos(theta)**8 - 1.98169109043889e+124*cos(theta)**6 + 2.46070913547876e+122*cos(theta)**4 - 1.10098842750727e+120*cos(theta)**2 + 7.48971719392703e+116)*cos(63*phi)

#@torch.jit.script
def Yl83_m64(theta, phi):
    return 1.36816516298103e-119*(1.0 - cos(theta)**2)**32*(1.93968705978066e+131*cos(theta)**19 - 2.01022113468177e+131*cos(theta)**17 + 8.38619859867243e+130*cos(theta)**15 - 1.82308665188531e+130*cos(theta)**13 + 2.23586098816123e+129*cos(theta)**11 - 1.56652680699194e+128*cos(theta)**9 + 6.06397473674301e+126*cos(theta)**7 - 1.18901465426334e+125*cos(theta)**5 + 9.84283654191503e+122*cos(theta)**3 - 2.20197685501455e+120*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl83_m65(theta, phi):
    return 2.58006632149456e-121*(1.0 - cos(theta)**2)**32.5*(3.68540541358325e+132*cos(theta)**18 - 3.41737592895902e+132*cos(theta)**16 + 1.25792978980086e+132*cos(theta)**14 - 2.3700126474509e+131*cos(theta)**12 + 2.45944708697735e+130*cos(theta)**10 - 1.40987412629275e+129*cos(theta)**8 + 4.24478231572011e+127*cos(theta)**6 - 5.94507327131668e+125*cos(theta)**4 + 2.95285096257451e+123*cos(theta)**2 - 2.20197685501455e+120)*cos(65*phi)

#@torch.jit.script
def Yl83_m66(theta, phi):
    return 4.98197430209356e-123*(1.0 - cos(theta)**2)**33*(6.63372974444985e+133*cos(theta)**17 - 5.46780148633442e+133*cos(theta)**15 + 1.76110170572121e+133*cos(theta)**13 - 2.84401517694108e+132*cos(theta)**11 + 2.45944708697735e+131*cos(theta)**9 - 1.1278993010342e+130*cos(theta)**7 + 2.54686938943207e+128*cos(theta)**5 - 2.37802930852667e+126*cos(theta)**3 + 5.90570192514902e+123*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl83_m67(theta, phi):
    return 9.86577922878173e-125*(1.0 - cos(theta)**2)**33.5*(1.12773405655647e+135*cos(theta)**16 - 8.20170222950164e+134*cos(theta)**14 + 2.28943221743757e+134*cos(theta)**12 - 3.12841669463519e+133*cos(theta)**10 + 2.21350237827962e+132*cos(theta)**8 - 7.8952951072394e+130*cos(theta)**6 + 1.27343469471603e+129*cos(theta)**4 - 7.13408792558001e+126*cos(theta)**2 + 5.90570192514902e+123)*cos(67*phi)

#@torch.jit.script
def Yl83_m68(theta, phi):
    return 2.0071643182917e-126*(1.0 - cos(theta)**2)**34*(1.80437449049036e+136*cos(theta)**15 - 1.14823831213023e+136*cos(theta)**13 + 2.74731866092509e+135*cos(theta)**11 - 3.12841669463519e+134*cos(theta)**9 + 1.77080190262369e+133*cos(theta)**7 - 4.73717706434364e+131*cos(theta)**5 + 5.09373877886413e+129*cos(theta)**3 - 1.426817585116e+127*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl83_m69(theta, phi):
    return 4.20354309650058e-128*(1.0 - cos(theta)**2)**34.5*(2.70656173573554e+137*cos(theta)**14 - 1.4927098057693e+137*cos(theta)**12 + 3.0220505270176e+136*cos(theta)**10 - 2.81557502517167e+135*cos(theta)**8 + 1.23956133183659e+134*cos(theta)**6 - 2.36858853217182e+132*cos(theta)**4 + 1.52812163365924e+130*cos(theta)**2 - 1.426817585116e+127)*cos(69*phi)

#@torch.jit.script
def Yl83_m70(theta, phi):
    return 9.08250762421223e-130*(1.0 - cos(theta)**2)**35*(3.78918643002976e+138*cos(theta)**13 - 1.79125176692316e+138*cos(theta)**11 + 3.0220505270176e+137*cos(theta)**9 - 2.25246002013734e+136*cos(theta)**7 + 7.43736799101952e+134*cos(theta)**5 - 9.47435412868728e+132*cos(theta)**3 + 3.05624326731848e+130*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl83_m71(theta, phi):
    return 2.02989575112448e-131*(1.0 - cos(theta)**2)**35.5*(4.92594235903868e+139*cos(theta)**12 - 1.97037694361547e+139*cos(theta)**10 + 2.71984547431584e+138*cos(theta)**8 - 1.57672201409614e+137*cos(theta)**6 + 3.71868399550976e+135*cos(theta)**4 - 2.84230623860618e+133*cos(theta)**2 + 3.05624326731848e+130)*cos(71*phi)

#@torch.jit.script
def Yl83_m72(theta, phi):
    return 4.70670807067363e-133*(1.0 - cos(theta)**2)**36*(5.91113083084642e+140*cos(theta)**11 - 1.97037694361547e+140*cos(theta)**9 + 2.17587637945267e+139*cos(theta)**7 - 9.46033208457683e+137*cos(theta)**5 + 1.4874735982039e+136*cos(theta)**3 - 5.68461247721237e+133*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl83_m73(theta, phi):
    return 1.13621003504546e-134*(1.0 - cos(theta)**2)**36.5*(6.50224391393106e+141*cos(theta)**10 - 1.77333924925393e+141*cos(theta)**8 + 1.52311346561687e+140*cos(theta)**6 - 4.73016604228841e+138*cos(theta)**4 + 4.46242079461171e+136*cos(theta)**2 - 5.68461247721237e+133)*cos(73*phi)

#@torch.jit.script
def Yl83_m74(theta, phi):
    return 2.86753544254554e-136*(1.0 - cos(theta)**2)**37*(6.50224391393106e+142*cos(theta)**9 - 1.41867139940314e+142*cos(theta)**7 + 9.13868079370121e+140*cos(theta)**5 - 1.89206641691537e+139*cos(theta)**3 + 8.92484158922342e+136*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl83_m75(theta, phi):
    return 7.60429569649727e-138*(1.0 - cos(theta)**2)**37.5*(5.85201952253796e+143*cos(theta)**8 - 9.93069979582199e+142*cos(theta)**6 + 4.56934039685061e+141*cos(theta)**4 - 5.67619925074609e+139*cos(theta)**2 + 8.92484158922342e+136)*cos(75*phi)

#@torch.jit.script
def Yl83_m76(theta, phi):
    return 2.13213863903882e-139*(1.0 - cos(theta)**2)**38*(4.68161561803036e+144*cos(theta)**7 - 5.95841987749319e+143*cos(theta)**5 + 1.82773615874024e+142*cos(theta)**3 - 1.13523985014922e+140*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl83_m77(theta, phi):
    return 6.37098275111623e-141*(1.0 - cos(theta)**2)**38.5*(3.27713093262125e+145*cos(theta)**6 - 2.9792099387466e+144*cos(theta)**4 + 5.48320847622073e+142*cos(theta)**2 - 1.13523985014922e+140)*cos(77*phi)

#@torch.jit.script
def Yl83_m78(theta, phi):
    return 2.04983009988826e-142*(1.0 - cos(theta)**2)**39*(1.96627855957275e+146*cos(theta)**5 - 1.19168397549864e+145*cos(theta)**3 + 1.09664169524415e+143*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl83_m79(theta, phi):
    return 7.20236881335263e-144*(1.0 - cos(theta)**2)**39.5*(9.83139279786376e+146*cos(theta)**4 - 3.57505192649591e+145*cos(theta)**2 + 1.09664169524415e+143)*cos(79*phi)

#@torch.jit.script
def Yl83_m80(theta, phi):
    return 2.82066531886291e-145*(1.0 - cos(theta)**2)**40*(3.93255711914551e+147*cos(theta)**3 - 7.15010385299183e+145*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl83_m81(theta, phi):
    return 1.27165413378911e-146*(1.0 - cos(theta)**2)**40.5*(1.17976713574365e+148*cos(theta)**2 - 7.15010385299183e+145)*cos(81*phi)

#@torch.jit.script
def Yl83_m82(theta, phi):
    return 16.5172722476201*(1.0 - cos(theta)**2)**41*cos(82*phi)*cos(theta)

#@torch.jit.script
def Yl83_m83(theta, phi):
    return 1.2819889538225*(1.0 - cos(theta)**2)**41.5*cos(83*phi)

#@torch.jit.script
def Yl84_m_minus_84(theta, phi):
    return 1.28579873622986*(1.0 - cos(theta)**2)**42*sin(84*phi)

#@torch.jit.script
def Yl84_m_minus_83(theta, phi):
    return 16.6658563996924*(1.0 - cos(theta)**2)**41.5*sin(83*phi)*cos(theta)

#@torch.jit.script
def Yl84_m_minus_82(theta, phi):
    return 7.72961936139408e-149*(1.0 - cos(theta)**2)**41*(1.9702111166919e+150*cos(theta)**2 - 1.17976713574365e+148)*sin(82*phi)

#@torch.jit.script
def Yl84_m_minus_81(theta, phi):
    return 1.72493517863933e-147*(1.0 - cos(theta)**2)**40.5*(6.567370388973e+149*cos(theta)**3 - 1.17976713574365e+148*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl84_m_minus_80(theta, phi):
    return 4.4314387105487e-146*(1.0 - cos(theta)**2)**40*(1.64184259724325e+149*cos(theta)**4 - 5.89883567871826e+147*cos(theta)**2 + 1.78752596324796e+145)*sin(80*phi)

#@torch.jit.script
def Yl84_m_minus_79(theta, phi):
    return 1.26897093021025e-144*(1.0 - cos(theta)**2)**39.5*(3.2836851944865e+148*cos(theta)**5 - 1.96627855957275e+147*cos(theta)**3 + 1.78752596324796e+145*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl84_m_minus_78(theta, phi):
    return 3.96845171677929e-143*(1.0 - cos(theta)**2)**39*(5.4728086574775e+147*cos(theta)**6 - 4.91569639893188e+146*cos(theta)**4 + 8.93762981623979e+144*cos(theta)**2 - 1.82773615874024e+142)*sin(78*phi)

#@torch.jit.script
def Yl84_m_minus_77(theta, phi):
    return 1.33637280121287e-141*(1.0 - cos(theta)**2)**38.5*(7.81829808211071e+146*cos(theta)**7 - 9.83139279786376e+145*cos(theta)**5 + 2.9792099387466e+144*cos(theta)**3 - 1.82773615874024e+142*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl84_m_minus_76(theta, phi):
    return 4.7960705122028e-140*(1.0 - cos(theta)**2)**38*(9.77287260263839e+145*cos(theta)**8 - 1.63856546631063e+145*cos(theta)**6 + 7.44802484686649e+143*cos(theta)**4 - 9.13868079370121e+141*cos(theta)**2 + 1.41904981268652e+139)*sin(76*phi)

#@torch.jit.script
def Yl84_m_minus_75(theta, phi):
    return 1.81998079647975e-138*(1.0 - cos(theta)**2)**37.5*(1.08587473362649e+145*cos(theta)**9 - 2.34080780901518e+144*cos(theta)**7 + 1.4896049693733e+143*cos(theta)**5 - 3.04622693123374e+141*cos(theta)**3 + 1.41904981268652e+139*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl84_m_minus_74(theta, phi):
    return 7.25713776794442e-137*(1.0 - cos(theta)**2)**37*(1.08587473362649e+144*cos(theta)**10 - 2.92600976126898e+143*cos(theta)**8 + 2.4826749489555e+142*cos(theta)**6 - 7.61556732808434e+140*cos(theta)**4 + 7.09524906343262e+138*cos(theta)**2 - 8.92484158922342e+135)*sin(74*phi)

#@torch.jit.script
def Yl84_m_minus_73(theta, phi):
    return 3.02545190735408e-135*(1.0 - cos(theta)**2)**36.5*(9.87158848751352e+142*cos(theta)**11 - 3.25112195696553e+142*cos(theta)**9 + 3.54667849850785e+141*cos(theta)**7 - 1.52311346561687e+140*cos(theta)**5 + 2.36508302114421e+138*cos(theta)**3 - 8.92484158922342e+135*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl84_m_minus_72(theta, phi):
    return 1.31319948275783e-133*(1.0 - cos(theta)**2)**36*(8.2263237395946e+141*cos(theta)**12 - 3.25112195696553e+141*cos(theta)**10 + 4.43334812313481e+140*cos(theta)**8 - 2.53852244269478e+139*cos(theta)**6 + 5.91270755286052e+137*cos(theta)**4 - 4.46242079461171e+135*cos(theta)**2 + 4.73717706434364e+132)*sin(72*phi)

#@torch.jit.script
def Yl84_m_minus_71(theta, phi):
    return 5.91377338398529e-132*(1.0 - cos(theta)**2)**35.5*(6.32794133814969e+140*cos(theta)**13 - 2.95556541542321e+140*cos(theta)**11 + 4.92594235903868e+139*cos(theta)**9 - 3.62646063242112e+138*cos(theta)**7 + 1.1825415105721e+137*cos(theta)**5 - 1.4874735982039e+135*cos(theta)**3 + 4.73717706434364e+132*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl84_m_minus_70(theta, phi):
    return 2.75482836003585e-130*(1.0 - cos(theta)**2)**35*(4.51995809867835e+139*cos(theta)**14 - 2.46297117951934e+139*cos(theta)**12 + 4.92594235903868e+138*cos(theta)**10 - 4.5330757905264e+137*cos(theta)**8 + 1.97090251762017e+136*cos(theta)**6 - 3.71868399550976e+134*cos(theta)**4 + 2.36858853217182e+132*cos(theta)**2 - 2.18303090522748e+129)*sin(70*phi)

#@torch.jit.script
def Yl84_m_minus_69(theta, phi):
    return 1.32403826105689e-128*(1.0 - cos(theta)**2)**34.5*(3.0133053991189e+138*cos(theta)**15 - 1.89459321501488e+138*cos(theta)**13 + 4.47812941730789e+137*cos(theta)**11 - 5.03675087836266e+136*cos(theta)**9 + 2.81557502517167e+135*cos(theta)**7 - 7.43736799101952e+133*cos(theta)**5 + 7.8952951072394e+131*cos(theta)**3 - 2.18303090522748e+129*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl84_m_minus_68(theta, phi):
    return 6.55097952323603e-127*(1.0 - cos(theta)**2)**34*(1.88331587444931e+137*cos(theta)**16 - 1.35328086786777e+137*cos(theta)**14 + 3.73177451442324e+136*cos(theta)**12 - 5.03675087836266e+135*cos(theta)**10 + 3.51946878146459e+134*cos(theta)**8 - 1.23956133183659e+133*cos(theta)**6 + 1.97382377680985e+131*cos(theta)**4 - 1.09151545261374e+129*cos(theta)**2 + 8.91760990697502e+125)*sin(68*phi)

#@torch.jit.script
def Yl84_m_minus_67(theta, phi):
    return 3.33006335874572e-125*(1.0 - cos(theta)**2)**33.5*(1.10783286732313e+136*cos(theta)**17 - 9.0218724524518e+135*cos(theta)**15 + 2.87059578032557e+135*cos(theta)**13 - 4.57886443487515e+134*cos(theta)**11 + 3.91052086829399e+133*cos(theta)**9 - 1.77080190262369e+132*cos(theta)**7 + 3.9476475536197e+130*cos(theta)**5 - 3.63838484204581e+128*cos(theta)**3 + 8.91760990697502e+125*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl84_m_minus_66(theta, phi):
    return 1.73610993670686e-123*(1.0 - cos(theta)**2)**33*(6.15462704068403e+134*cos(theta)**18 - 5.63867028278237e+134*cos(theta)**16 + 2.05042555737541e+134*cos(theta)**14 - 3.81572036239596e+133*cos(theta)**12 + 3.91052086829399e+132*cos(theta)**10 - 2.21350237827962e+131*cos(theta)**8 + 6.57941258936617e+129*cos(theta)**6 - 9.09596210511452e+127*cos(theta)**4 + 4.45880495348751e+125*cos(theta)**2 - 3.28094551397168e+122)*sin(66*phi)

#@torch.jit.script
def Yl84_m_minus_65(theta, phi):
    return 9.26829082417413e-122*(1.0 - cos(theta)**2)**32.5*(3.2392773898337e+133*cos(theta)**19 - 3.31686487222493e+133*cos(theta)**17 + 1.36695037158361e+133*cos(theta)**15 - 2.93516950953535e+132*cos(theta)**13 + 3.55501897117636e+131*cos(theta)**11 - 2.45944708697735e+130*cos(theta)**9 + 9.39916084195167e+128*cos(theta)**7 - 1.8191924210229e+127*cos(theta)**5 + 1.48626831782917e+125*cos(theta)**3 - 3.28094551397168e+122*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl84_m_minus_64(theta, phi):
    return 5.05950215049249e-120*(1.0 - cos(theta)**2)**32*(1.61963869491685e+132*cos(theta)**20 - 1.84270270679163e+132*cos(theta)**18 + 8.54343982239754e+131*cos(theta)**16 - 2.09654964966811e+131*cos(theta)**14 + 2.96251580931363e+130*cos(theta)**12 - 2.45944708697735e+129*cos(theta)**10 + 1.17489510524396e+128*cos(theta)**8 - 3.03198736837151e+126*cos(theta)**6 + 3.71567079457292e+124*cos(theta)**4 - 1.64047275698584e+122*cos(theta)**2 + 1.10098842750727e+119)*sin(64*phi)

#@torch.jit.script
def Yl84_m_minus_63(theta, phi):
    return 2.82064408831893e-118*(1.0 - cos(theta)**2)**31.5*(7.71256521388976e+130*cos(theta)**21 - 9.69843529890329e+130*cos(theta)**19 + 5.02555283670443e+130*cos(theta)**17 - 1.39769976644541e+130*cos(theta)**15 + 2.27885831485664e+129*cos(theta)**13 - 2.23586098816123e+128*cos(theta)**11 + 1.30543900582662e+127*cos(theta)**9 - 4.33141052624501e+125*cos(theta)**7 + 7.43134158914585e+123*cos(theta)**5 - 5.46824252328613e+121*cos(theta)**3 + 1.10098842750727e+119*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl84_m_minus_62(theta, phi):
    return 1.60405146295186e-116*(1.0 - cos(theta)**2)**31*(3.50571146085898e+129*cos(theta)**22 - 4.84921764945165e+129*cos(theta)**20 + 2.79197379816913e+129*cos(theta)**18 - 8.73562354028378e+128*cos(theta)**16 + 1.62775593918331e+128*cos(theta)**14 - 1.86321749013436e+127*cos(theta)**12 + 1.30543900582662e+126*cos(theta)**10 - 5.41426315780626e+124*cos(theta)**8 + 1.23855693152431e+123*cos(theta)**6 - 1.36706063082153e+121*cos(theta)**4 + 5.50494213753637e+118*cos(theta)**2 - 3.40441690633047e+115)*sin(62*phi)

#@torch.jit.script
def Yl84_m_minus_61(theta, phi):
    return 9.29519796437372e-115*(1.0 - cos(theta)**2)**30.5*(1.52422237428651e+128*cos(theta)**23 - 2.30915126164364e+128*cos(theta)**21 + 1.46945989377323e+128*cos(theta)**19 - 5.13860208251987e+127*cos(theta)**17 + 1.08517062612221e+127*cos(theta)**15 - 1.43324422318028e+126*cos(theta)**13 + 1.18676273256966e+125*cos(theta)**11 - 6.01584795311807e+123*cos(theta)**9 + 1.76936704503473e+122*cos(theta)**7 - 2.73412126164306e+120*cos(theta)**5 + 1.83498071251212e+118*cos(theta)**3 - 3.40441690633047e+115*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl84_m_minus_60(theta, phi):
    return 5.48337901375787e-113*(1.0 - cos(theta)**2)**30*(6.35092655952714e+126*cos(theta)**24 - 1.04961420983802e+127*cos(theta)**22 + 7.34729946886613e+126*cos(theta)**20 - 2.85477893473326e+126*cos(theta)**18 + 6.78231641326381e+125*cos(theta)**16 - 1.0237458737002e+125*cos(theta)**14 + 9.88968943808046e+123*cos(theta)**12 - 6.01584795311807e+122*cos(theta)**10 + 2.21170880629341e+121*cos(theta)**8 - 4.55686876940511e+119*cos(theta)**6 + 4.58745178128031e+117*cos(theta)**4 - 1.70220845316524e+115*cos(theta)**2 + 9.78280720209905e+111)*sin(60*phi)

#@torch.jit.script
def Yl84_m_minus_59(theta, phi):
    return 3.29002740825472e-111*(1.0 - cos(theta)**2)**29.5*(2.54037062381086e+125*cos(theta)**25 - 4.56354004277399e+125*cos(theta)**23 + 3.4987140327934e+125*cos(theta)**21 - 1.50251522880698e+125*cos(theta)**19 + 3.98959789015518e+124*cos(theta)**17 - 6.82497249133465e+123*cos(theta)**15 + 7.60745341390805e+122*cos(theta)**13 - 5.46895268465279e+121*cos(theta)**11 + 2.4574542292149e+120*cos(theta)**9 - 6.50981252772158e+118*cos(theta)**7 + 9.17490356256062e+116*cos(theta)**5 - 5.67402817721745e+114*cos(theta)**3 + 9.78280720209905e+111*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl84_m_minus_58(theta, phi):
    return 2.00610753277077e-109*(1.0 - cos(theta)**2)**29*(9.77065624542637e+123*cos(theta)**26 - 1.9014750178225e+124*cos(theta)**24 + 1.59032456036063e+124*cos(theta)**22 - 7.5125761440349e+123*cos(theta)**20 + 2.21644327230843e+123*cos(theta)**18 - 4.26560780708415e+122*cos(theta)**16 + 5.4338952956486e+121*cos(theta)**14 - 4.55746057054399e+120*cos(theta)**12 + 2.4574542292149e+119*cos(theta)**10 - 8.13726565965198e+117*cos(theta)**8 + 1.5291505937601e+116*cos(theta)**6 - 1.41850704430436e+114*cos(theta)**4 + 4.89140360104953e+111*cos(theta)**2 - 2.63120150675069e+108)*sin(58*phi)

#@torch.jit.script
def Yl84_m_minus_57(theta, phi):
    return 1.24216778811374e-107*(1.0 - cos(theta)**2)**28.5*(3.61876157238014e+122*cos(theta)**27 - 7.60590007128999e+122*cos(theta)**25 + 6.91445461026363e+122*cos(theta)**23 - 3.57741721144519e+122*cos(theta)**21 + 1.16654909068865e+122*cos(theta)**19 - 2.50918106299068e+121*cos(theta)**17 + 3.62259686376574e+120*cos(theta)**15 - 3.50573890041845e+119*cos(theta)**13 + 2.23404929928627e+118*cos(theta)**11 - 9.0414062885022e+116*cos(theta)**9 + 2.18450084822872e+115*cos(theta)**7 - 2.83701408860873e+113*cos(theta)**5 + 1.63046786701651e+111*cos(theta)**3 - 2.63120150675069e+108*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl84_m_minus_56(theta, phi):
    return 7.80492681130998e-106*(1.0 - cos(theta)**2)**28*(1.29241484727862e+121*cos(theta)**28 - 2.92534618126538e+121*cos(theta)**26 + 2.88102275427651e+121*cos(theta)**24 - 1.62609873247509e+121*cos(theta)**22 + 5.83274545344325e+120*cos(theta)**20 - 1.39398947943927e+120*cos(theta)**18 + 2.26412303985359e+119*cos(theta)**16 - 2.50409921458461e+118*cos(theta)**14 + 1.86170774940522e+117*cos(theta)**12 - 9.0414062885022e+115*cos(theta)**10 + 2.7306260602859e+114*cos(theta)**8 - 4.72835681434788e+112*cos(theta)**6 + 4.07616966754127e+110*cos(theta)**4 - 1.31560075337534e+108*cos(theta)**2 + 6.66464414070589e+104)*sin(56*phi)

#@torch.jit.script
def Yl84_m_minus_55(theta, phi):
    return 4.97315335648737e-104*(1.0 - cos(theta)**2)**27.5*(4.45660292165042e+119*cos(theta)**29 - 1.08346154861681e+120*cos(theta)**27 + 1.1524091017106e+120*cos(theta)**25 - 7.06999448902212e+119*cos(theta)**23 + 2.77749783497297e+119*cos(theta)**21 - 7.33678673389087e+118*cos(theta)**19 + 1.33183708226681e+118*cos(theta)**17 - 1.66939947638974e+117*cos(theta)**15 + 1.43208288415787e+116*cos(theta)**13 - 8.21946026227472e+114*cos(theta)**11 + 3.03402895587322e+113*cos(theta)**9 - 6.75479544906839e+111*cos(theta)**7 + 8.15233933508254e+109*cos(theta)**5 - 4.38533584458448e+107*cos(theta)**3 + 6.66464414070589e+104*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl84_m_minus_54(theta, phi):
    return 3.21144049393384e-102*(1.0 - cos(theta)**2)**27*(1.48553430721681e+118*cos(theta)**30 - 3.86950553077431e+118*cos(theta)**28 + 4.43234269888694e+118*cos(theta)**26 - 2.94583103709255e+118*cos(theta)**24 + 1.26249901589681e+118*cos(theta)**22 - 3.66839336694544e+117*cos(theta)**20 + 7.3990949014823e+116*cos(theta)**18 - 1.04337467274359e+116*cos(theta)**16 + 1.02291634582705e+115*cos(theta)**14 - 6.84955021856227e+113*cos(theta)**12 + 3.03402895587322e+112*cos(theta)**10 - 8.44349431133549e+110*cos(theta)**8 + 1.35872322251376e+109*cos(theta)**6 - 1.09633396114612e+107*cos(theta)**4 + 3.33232207035295e+104*cos(theta)**2 - 1.59823600496544e+101)*sin(54*phi)

#@torch.jit.script
def Yl84_m_minus_53(theta, phi):
    return 2.10048831220557e-100*(1.0 - cos(theta)**2)**26.5*(4.79204615231228e+116*cos(theta)**31 - 1.33431225199114e+117*cos(theta)**29 + 1.64160840699516e+117*cos(theta)**27 - 1.17833241483702e+117*cos(theta)**25 + 5.48912615607307e+116*cos(theta)**23 - 1.74685398425973e+116*cos(theta)**21 + 3.89426047446437e+115*cos(theta)**19 - 6.13749807496228e+114*cos(theta)**17 + 6.81944230551364e+113*cos(theta)**15 - 5.26888478350944e+112*cos(theta)**13 + 2.75820814170293e+111*cos(theta)**11 - 9.38166034592832e+109*cos(theta)**9 + 1.94103317501965e+108*cos(theta)**7 - 2.19266792229224e+106*cos(theta)**5 + 1.11077402345098e+104*cos(theta)**3 - 1.59823600496544e+101*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl84_m_minus_52(theta, phi):
    return 1.39077073021898e-98*(1.0 - cos(theta)**2)**26*(1.49751442259759e+115*cos(theta)**32 - 4.44770750663714e+115*cos(theta)**30 + 5.86288716783987e+115*cos(theta)**28 - 4.53204774937315e+115*cos(theta)**26 + 2.28713589836378e+115*cos(theta)**24 - 7.94024538299878e+114*cos(theta)**22 + 1.94713023723219e+114*cos(theta)**20 - 3.40972115275682e+113*cos(theta)**18 + 4.26215144094603e+112*cos(theta)**16 - 3.76348913107817e+111*cos(theta)**14 + 2.29850678475244e+110*cos(theta)**12 - 9.38166034592832e+108*cos(theta)**10 + 2.42629146877457e+107*cos(theta)**8 - 3.65444653715373e+105*cos(theta)**6 + 2.77693505862746e+103*cos(theta)**4 - 7.99118002482721e+100*cos(theta)**2 + 3.6456113251949e+97)*sin(52*phi)

#@torch.jit.script
def Yl84_m_minus_51(theta, phi):
    return 9.31712594605429e-97*(1.0 - cos(theta)**2)**25.5*(4.53792249271996e+113*cos(theta)**33 - 1.43474435697972e+114*cos(theta)**31 + 2.02168523028961e+114*cos(theta)**29 - 1.67853620347154e+114*cos(theta)**27 + 9.14854359345512e+113*cos(theta)**25 - 3.45228060130382e+113*cos(theta)**23 + 9.27204874872469e+112*cos(theta)**21 - 1.79459008039833e+112*cos(theta)**19 + 2.50714790643884e+111*cos(theta)**17 - 2.50899275405211e+110*cos(theta)**15 + 1.76808214211726e+109*cos(theta)**13 - 8.52878213266211e+107*cos(theta)**11 + 2.69587940974952e+106*cos(theta)**9 - 5.22063791021962e+104*cos(theta)**7 + 5.55387011725491e+102*cos(theta)**5 - 2.6637266749424e+100*cos(theta)**3 + 3.6456113251949e+97*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl84_m_minus_50(theta, phi):
    return 6.3123098526323e-95*(1.0 - cos(theta)**2)**25*(1.33468308609411e+112*cos(theta)**34 - 4.48357611556164e+112*cos(theta)**32 + 6.73895076763203e+112*cos(theta)**30 - 5.99477215525549e+112*cos(theta)**28 + 3.51867061286735e+112*cos(theta)**26 - 1.43845025054326e+112*cos(theta)**24 + 4.21456761305668e+111*cos(theta)**22 - 8.97295040199164e+110*cos(theta)**20 + 1.39285994802158e+110*cos(theta)**18 - 1.56812047128257e+109*cos(theta)**16 + 1.26291581579804e+108*cos(theta)**14 - 7.10731844388509e+106*cos(theta)**12 + 2.69587940974952e+105*cos(theta)**10 - 6.52579738777452e+103*cos(theta)**8 + 9.25645019542485e+101*cos(theta)**6 - 6.65931668735601e+99*cos(theta)**4 + 1.82280566259745e+97*cos(theta)**2 - 7.94250833375794e+93)*sin(50*phi)

#@torch.jit.script
def Yl84_m_minus_49(theta, phi):
    return 4.3228954315221e-93*(1.0 - cos(theta)**2)**24.5*(3.81338024598316e+110*cos(theta)**35 - 1.35865942895807e+111*cos(theta)**33 + 2.17385508633291e+111*cos(theta)**31 - 2.06716281215707e+111*cos(theta)**29 + 1.30321133809902e+111*cos(theta)**27 - 5.75380100217303e+110*cos(theta)**25 + 1.83242070132899e+110*cos(theta)**23 - 4.27283352475792e+109*cos(theta)**21 + 7.33084183169251e+108*cos(theta)**19 - 9.22423806636806e+107*cos(theta)**17 + 8.41943877198696e+106*cos(theta)**15 - 5.46716803375777e+105*cos(theta)**13 + 2.45079946340865e+104*cos(theta)**11 - 7.25088598641613e+102*cos(theta)**9 + 1.32235002791784e+101*cos(theta)**7 - 1.3318633374712e+99*cos(theta)**5 + 6.07601887532483e+96*cos(theta)**3 - 7.94250833375794e+93*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl84_m_minus_48(theta, phi):
    return 2.9912437292547e-91*(1.0 - cos(theta)**2)**24*(1.05927229055088e+109*cos(theta)**36 - 3.99605714399433e+109*cos(theta)**34 + 6.79329714479036e+109*cos(theta)**32 - 6.89054270719022e+109*cos(theta)**30 + 4.6543262074965e+109*cos(theta)**28 - 2.21300038545117e+109*cos(theta)**26 + 7.63508625553746e+108*cos(theta)**24 - 1.94219705670815e+108*cos(theta)**22 + 3.66542091584626e+107*cos(theta)**20 - 5.12457670353781e+106*cos(theta)**18 + 5.26214923249185e+105*cos(theta)**16 - 3.90512002411269e+104*cos(theta)**14 + 2.04233288617388e+103*cos(theta)**12 - 7.25088598641613e+101*cos(theta)**10 + 1.65293753489729e+100*cos(theta)**8 - 2.21977222911867e+98*cos(theta)**6 + 1.51900471883121e+96*cos(theta)**4 - 3.97125416687897e+93*cos(theta)**2 + 1.65883632701711e+90)*sin(48*phi)

#@torch.jit.script
def Yl84_m_minus_47(theta, phi):
    return 2.09044925098607e-89*(1.0 - cos(theta)**2)**23.5*(2.86289808256994e+107*cos(theta)**37 - 1.14173061256981e+108*cos(theta)**35 + 2.05857489236071e+108*cos(theta)**33 - 2.22275571199684e+108*cos(theta)**31 + 1.60494007155052e+108*cos(theta)**29 - 8.19629772389321e+107*cos(theta)**27 + 3.05403450221498e+107*cos(theta)**25 - 8.44433502916585e+106*cos(theta)**23 + 1.74543853135536e+106*cos(theta)**21 - 2.69714563344095e+105*cos(theta)**19 + 3.09538190146579e+104*cos(theta)**17 - 2.60341334940846e+103*cos(theta)**15 + 1.57102529705683e+102*cos(theta)**13 - 6.59171453310558e+100*cos(theta)**11 + 1.83659726099699e+99*cos(theta)**9 - 3.17110318445524e+97*cos(theta)**7 + 3.03800943766241e+95*cos(theta)**5 - 1.32375138895966e+93*cos(theta)**3 + 1.65883632701711e+90*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl84_m_minus_46(theta, phi):
    return 1.47491528018325e-87*(1.0 - cos(theta)**2)**23*(7.53394232255247e+105*cos(theta)**38 - 3.17147392380502e+106*cos(theta)**36 + 6.05463203635504e+106*cos(theta)**34 - 6.94611159999014e+106*cos(theta)**32 + 5.34980023850172e+106*cos(theta)**30 - 2.92724918710472e+106*cos(theta)**28 + 1.17462865469807e+106*cos(theta)**26 - 3.51847292881911e+105*cos(theta)**24 + 7.93381150616073e+104*cos(theta)**22 - 1.34857281672048e+104*cos(theta)**20 + 1.71965661192544e+103*cos(theta)**18 - 1.62713334338029e+102*cos(theta)**16 + 1.12216092646916e+101*cos(theta)**14 - 5.49309544425465e+99*cos(theta)**12 + 1.83659726099699e+98*cos(theta)**10 - 3.96387898056905e+96*cos(theta)**8 + 5.06334906277069e+94*cos(theta)**6 - 3.30937847239914e+92*cos(theta)**4 + 8.29418163508557e+89*cos(theta)**2 - 3.33233492771618e+86)*sin(46*phi)

#@torch.jit.script
def Yl84_m_minus_45(theta, phi):
    return 1.05019768017504e-85*(1.0 - cos(theta)**2)**22.5*(1.93178008270576e+104*cos(theta)**39 - 8.57155114541898e+104*cos(theta)**37 + 1.72989486753001e+105*cos(theta)**35 - 2.10488230302732e+105*cos(theta)**33 + 1.72574201241991e+105*cos(theta)**31 - 1.00939627141542e+105*cos(theta)**29 + 4.35047649888174e+104*cos(theta)**27 - 1.40738917152764e+104*cos(theta)**25 + 3.44948326354814e+103*cos(theta)**23 - 6.42177531771656e+102*cos(theta)**21 + 9.05082427329179e+101*cos(theta)**19 - 9.57137260811934e+100*cos(theta)**17 + 7.48107284312776e+99*cos(theta)**15 - 4.22545803404204e+98*cos(theta)**13 + 1.66963387363363e+97*cos(theta)**11 - 4.40430997841006e+95*cos(theta)**9 + 7.23335580395813e+93*cos(theta)**7 - 6.61875694479828e+91*cos(theta)**5 + 2.76472721169519e+89*cos(theta)**3 - 3.33233492771618e+86*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl84_m_minus_44(theta, phi):
    return 7.54389969711715e-84*(1.0 - cos(theta)**2)**22*(4.8294502067644e+102*cos(theta)**40 - 2.25567135405763e+103*cos(theta)**38 + 4.8052635209167e+103*cos(theta)**36 - 6.19083030302151e+103*cos(theta)**34 + 5.39294378881222e+103*cos(theta)**32 - 3.3646542380514e+103*cos(theta)**30 + 1.55374160674348e+103*cos(theta)**28 - 5.41303527510632e+102*cos(theta)**26 + 1.43728469314506e+102*cos(theta)**24 - 2.91898878078025e+101*cos(theta)**22 + 4.5254121366459e+100*cos(theta)**20 - 5.31742922673296e+99*cos(theta)**18 + 4.67567052695485e+98*cos(theta)**16 - 3.01818431003003e+97*cos(theta)**14 + 1.39136156136136e+96*cos(theta)**12 - 4.40430997841006e+94*cos(theta)**10 + 9.04169475494766e+92*cos(theta)**8 - 1.10312615746638e+91*cos(theta)**6 + 6.91181802923797e+88*cos(theta)**4 - 1.66616746385809e+86*cos(theta)**2 + 6.45801342580655e+82)*sin(44*phi)

#@torch.jit.script
def Yl84_m_minus_43(theta, phi):
    return 5.46503337606992e-82*(1.0 - cos(theta)**2)**21.5*(1.17791468457668e+101*cos(theta)**41 - 5.78377270271186e+101*cos(theta)**39 + 1.29871987051803e+102*cos(theta)**37 - 1.76880865800615e+102*cos(theta)**35 + 1.63422539054916e+102*cos(theta)**33 - 1.08537233485529e+102*cos(theta)**31 + 5.35772967842579e+101*cos(theta)**29 - 2.00482787966901e+101*cos(theta)**27 + 5.74913877258024e+100*cos(theta)**25 - 1.26912555686098e+100*cos(theta)**23 + 2.15495816030757e+99*cos(theta)**21 - 2.7986469614384e+98*cos(theta)**19 + 2.7503944276205e+97*cos(theta)**17 - 2.01212287335335e+96*cos(theta)**15 + 1.07027812412412e+95*cos(theta)**13 - 4.00391816219096e+93*cos(theta)**11 + 1.00463275054974e+92*cos(theta)**9 - 1.57589451066626e+90*cos(theta)**7 + 1.38236360584759e+88*cos(theta)**5 - 5.55389154619363e+85*cos(theta)**3 + 6.45801342580655e+82*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl84_m_minus_42(theta, phi):
    return 3.99134551249965e-80*(1.0 - cos(theta)**2)**21*(2.80455877280163e+99*cos(theta)**42 - 1.44594317567797e+100*cos(theta)**40 + 3.41768386978428e+100*cos(theta)**38 - 4.91335738335041e+100*cos(theta)**36 + 4.80654526632105e+100*cos(theta)**34 - 3.39178854642278e+100*cos(theta)**32 + 1.7859098928086e+100*cos(theta)**30 - 7.16009957024645e+99*cos(theta)**28 + 2.21120722022317e+99*cos(theta)**26 - 5.28802315358742e+98*cos(theta)**24 + 9.79526436503441e+97*cos(theta)**22 - 1.3993234807192e+97*cos(theta)**20 + 1.52799690423361e+96*cos(theta)**18 - 1.25757679584584e+95*cos(theta)**16 + 7.64484374374373e+93*cos(theta)**14 - 3.33659846849247e+92*cos(theta)**12 + 1.00463275054974e+91*cos(theta)**10 - 1.96986813833282e+89*cos(theta)**8 + 2.30393934307932e+87*cos(theta)**6 - 1.38847288654841e+85*cos(theta)**4 + 3.22900671290327e+82*cos(theta)**2 - 1.21072617656666e+79)*sin(42*phi)

#@torch.jit.script
def Yl84_m_minus_41(theta, phi):
    return 2.93791228090321e-78*(1.0 - cos(theta)**2)**20.5*(6.52222970418983e+97*cos(theta)**43 - 3.52669067238528e+98*cos(theta)**41 + 8.76329197380585e+98*cos(theta)**39 - 1.32793442793254e+99*cos(theta)**37 + 1.3732986475203e+99*cos(theta)**35 - 1.02781471103721e+99*cos(theta)**33 + 5.76099965422128e+98*cos(theta)**31 - 2.46899985180912e+98*cos(theta)**29 + 8.18965637119692e+97*cos(theta)**27 - 2.11520926143497e+97*cos(theta)**25 + 4.25881059349322e+96*cos(theta)**23 - 6.66344514628191e+95*cos(theta)**21 + 8.04208896965058e+94*cos(theta)**19 - 7.39751056379908e+93*cos(theta)**17 + 5.09656249582916e+92*cos(theta)**15 - 2.56661420653267e+91*cos(theta)**13 + 9.13302500499763e+89*cos(theta)**11 - 2.18874237592536e+88*cos(theta)**9 + 3.29134191868475e+86*cos(theta)**7 - 2.77694577309682e+84*cos(theta)**5 + 1.07633557096776e+82*cos(theta)**3 - 1.21072617656666e+79*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl84_m_minus_40(theta, phi):
    return 2.17881406128541e-76*(1.0 - cos(theta)**2)**20*(1.48232493277042e+96*cos(theta)**44 - 8.39688255329829e+96*cos(theta)**42 + 2.19082299345146e+97*cos(theta)**40 - 3.49456428403301e+97*cos(theta)**38 + 3.81471846533417e+97*cos(theta)**36 - 3.02298444422708e+97*cos(theta)**34 + 1.80031239194415e+97*cos(theta)**32 - 8.2299995060304e+96*cos(theta)**30 + 2.92487727542747e+96*cos(theta)**28 - 8.13542023628833e+95*cos(theta)**26 + 1.77450441395551e+95*cos(theta)**24 - 3.02883870285541e+94*cos(theta)**22 + 4.02104448482529e+93*cos(theta)**20 - 4.10972809099949e+92*cos(theta)**18 + 3.18535155989322e+91*cos(theta)**16 - 1.83329586180905e+90*cos(theta)**14 + 7.61085417083136e+88*cos(theta)**12 - 2.18874237592536e+87*cos(theta)**10 + 4.11417739835594e+85*cos(theta)**8 - 4.62824295516136e+83*cos(theta)**6 + 2.6908389274194e+81*cos(theta)**4 - 6.05363088283328e+78*cos(theta)**2 + 2.20132032103029e+75)*sin(40*phi)

#@torch.jit.script
def Yl84_m_minus_39(theta, phi):
    return 1.62756097834137e-74*(1.0 - cos(theta)**2)**19.5*(3.29405540615648e+94*cos(theta)**45 - 1.95276338448797e+95*cos(theta)**43 + 5.34347071573527e+95*cos(theta)**41 - 8.96042124111028e+95*cos(theta)**39 + 1.03100499063086e+96*cos(theta)**37 - 8.63709841207736e+95*cos(theta)**35 + 5.45549209680046e+95*cos(theta)**33 - 2.65483855033239e+95*cos(theta)**31 + 1.00857837083706e+95*cos(theta)**29 - 3.01311860603272e+94*cos(theta)**27 + 7.09801765582203e+93*cos(theta)**25 - 1.31688639254583e+93*cos(theta)**23 + 1.91478308801204e+92*cos(theta)**21 - 2.16301478473657e+91*cos(theta)**19 + 1.8737362117019e+90*cos(theta)**17 - 1.22219724120603e+89*cos(theta)**15 + 5.85450320833182e+87*cos(theta)**13 - 1.98976579629578e+86*cos(theta)**11 + 4.57130822039549e+84*cos(theta)**9 - 6.61177565023051e+82*cos(theta)**7 + 5.38167785483879e+80*cos(theta)**5 - 2.01787696094443e+78*cos(theta)**3 + 2.20132032103029e+75*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl84_m_minus_38(theta, phi):
    return 1.22424613166005e-72*(1.0 - cos(theta)**2)**19*(7.16099001338366e+92*cos(theta)**46 - 4.43809860110903e+93*cos(theta)**44 + 1.27225493231792e+94*cos(theta)**42 - 2.24010531027757e+94*cos(theta)**40 + 2.71317102797594e+94*cos(theta)**38 - 2.39919400335482e+94*cos(theta)**36 + 1.60455649905896e+94*cos(theta)**34 - 8.29637046978871e+93*cos(theta)**32 + 3.3619279027902e+93*cos(theta)**30 - 1.07611378786883e+93*cos(theta)**28 + 2.73000679070078e+92*cos(theta)**26 - 5.48702663560763e+91*cos(theta)**24 + 8.70355949096383e+90*cos(theta)**22 - 1.08150739236829e+90*cos(theta)**20 + 1.04096456205661e+89*cos(theta)**18 - 7.6387327575377e+87*cos(theta)**16 + 4.1817880059513e+86*cos(theta)**14 - 1.65813816357982e+85*cos(theta)**12 + 4.57130822039549e+83*cos(theta)**10 - 8.26471956278814e+81*cos(theta)**8 + 8.96946309139798e+79*cos(theta)**6 - 5.04469240236107e+77*cos(theta)**4 + 1.10066016051514e+75*cos(theta)**2 - 3.89063329980609e+71)*sin(38*phi)

#@torch.jit.script
def Yl84_m_minus_37(theta, phi):
    return 9.2703810278393e-71*(1.0 - cos(theta)**2)**18.5*(1.52361489646461e+91*cos(theta)**47 - 9.86244133579785e+91*cos(theta)**45 + 2.95873240073935e+92*cos(theta)**43 - 5.46367148848188e+92*cos(theta)**41 + 6.95684878968189e+92*cos(theta)**39 - 6.4843081171752e+92*cos(theta)**37 + 4.58444714016845e+92*cos(theta)**35 - 2.51405165751173e+92*cos(theta)**33 + 1.08449287186781e+92*cos(theta)**31 - 3.71073719954768e+91*cos(theta)**29 + 1.01111362618548e+91*cos(theta)**27 - 2.19481065424305e+90*cos(theta)**25 + 3.78415630041906e+89*cos(theta)**23 - 5.15003520175375e+88*cos(theta)**21 + 5.47876085292952e+87*cos(theta)**19 - 4.4933722103163e+86*cos(theta)**17 + 2.7878586706342e+85*cos(theta)**15 - 1.2754908950614e+84*cos(theta)**13 + 4.15573474581408e+82*cos(theta)**11 - 9.18302173643127e+80*cos(theta)**9 + 1.28135187019971e+79*cos(theta)**7 - 1.00893848047221e+77*cos(theta)**5 + 3.66886720171714e+74*cos(theta)**3 - 3.89063329980609e+71*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl84_m_minus_36(theta, phi):
    return 7.06497921612571e-69*(1.0 - cos(theta)**2)**18*(3.17419770096793e+89*cos(theta)**48 - 2.14400898604301e+90*cos(theta)**46 + 6.72439181986217e+90*cos(theta)**44 - 1.30087416392426e+91*cos(theta)**42 + 1.73921219742047e+91*cos(theta)**40 - 1.70639687294084e+91*cos(theta)**38 + 1.27345753893568e+91*cos(theta)**36 - 7.39426958091686e+90*cos(theta)**34 + 3.38904022458689e+90*cos(theta)**32 - 1.23691239984923e+90*cos(theta)**30 + 3.61112009351955e+89*cos(theta)**28 - 8.44157943939636e+88*cos(theta)**26 + 1.57673179184127e+88*cos(theta)**24 - 2.34092509170625e+87*cos(theta)**22 + 2.73938042646476e+86*cos(theta)**20 - 2.49631789462016e+85*cos(theta)**18 + 1.74241166914637e+84*cos(theta)**16 - 9.11064925043856e+82*cos(theta)**14 + 3.4631122881784e+81*cos(theta)**12 - 9.18302173643127e+79*cos(theta)**10 + 1.60168983774964e+78*cos(theta)**8 - 1.68156413412036e+76*cos(theta)**6 + 9.17216800429286e+73*cos(theta)**4 - 1.94531664990304e+71*cos(theta)**2 + 6.69874879443197e+67)*sin(36*phi)

#@torch.jit.script
def Yl84_m_minus_35(theta, phi):
    return 5.41750787896811e-67*(1.0 - cos(theta)**2)**17.5*(6.47795449177129e+87*cos(theta)**49 - 4.56172124690002e+88*cos(theta)**47 + 1.4943092933027e+89*cos(theta)**45 - 3.02528875331222e+89*cos(theta)**43 + 4.24198096931823e+89*cos(theta)**41 - 4.37537659728421e+89*cos(theta)**39 + 3.4417771322586e+89*cos(theta)**37 - 2.11264845169053e+89*cos(theta)**35 + 1.02698188623845e+89*cos(theta)**33 - 3.99003999951363e+88*cos(theta)**31 + 1.24521382535157e+88*cos(theta)**29 - 3.12651090348013e+87*cos(theta)**27 + 6.3069271673651e+86*cos(theta)**25 - 1.01779351813315e+86*cos(theta)**23 + 1.30446686974512e+85*cos(theta)**21 - 1.3138515234843e+84*cos(theta)**19 + 1.02494804067434e+83*cos(theta)**17 - 6.07376616695904e+81*cos(theta)**15 + 2.663932529368e+80*cos(theta)**13 - 8.34820157857388e+78*cos(theta)**11 + 1.77965537527738e+77*cos(theta)**9 - 2.4022344773148e+75*cos(theta)**7 + 1.83443360085857e+73*cos(theta)**5 - 6.48438883301015e+70*cos(theta)**3 + 6.69874879443197e+67*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl84_m_minus_34(theta, phi):
    return 4.17886204762918e-65*(1.0 - cos(theta)**2)**17*(1.29559089835426e+86*cos(theta)**50 - 9.50358593104171e+86*cos(theta)**48 + 3.24849846370153e+87*cos(theta)**46 - 6.87565625752778e+87*cos(theta)**44 + 1.00999546888529e+88*cos(theta)**42 - 1.09384414932105e+88*cos(theta)**40 + 9.05730824278578e+87*cos(theta)**38 - 5.86846792136258e+87*cos(theta)**36 + 3.02053495952486e+87*cos(theta)**34 - 1.24688749984801e+87*cos(theta)**32 + 4.1507127511719e+86*cos(theta)**30 - 1.11661103695719e+86*cos(theta)**28 + 2.42574121821734e+85*cos(theta)**26 - 4.2408063255548e+84*cos(theta)**24 + 5.92939486247783e+83*cos(theta)**22 - 6.56925761742148e+82*cos(theta)**20 + 5.6941557815241e+81*cos(theta)**18 - 3.7961038543494e+80*cos(theta)**16 + 1.90280894954857e+79*cos(theta)**14 - 6.95683464881157e+77*cos(theta)**12 + 1.77965537527738e+76*cos(theta)**10 - 3.00279309664349e+74*cos(theta)**8 + 3.05738933476429e+72*cos(theta)**6 - 1.62109720825254e+70*cos(theta)**4 + 3.34937439721599e+67*cos(theta)**2 - 1.12584013351798e+64)*sin(34*phi)

#@torch.jit.script
def Yl84_m_minus_33(theta, phi):
    return 3.24178438615108e-63*(1.0 - cos(theta)**2)**16.5*(2.54037431049855e+84*cos(theta)**51 - 1.93950733286566e+85*cos(theta)**49 + 6.91169885893943e+85*cos(theta)**47 - 1.52792361278395e+86*cos(theta)**45 + 2.34882667182626e+86*cos(theta)**43 - 2.66791255931964e+86*cos(theta)**41 + 2.32238672891943e+86*cos(theta)**39 - 1.58607241117908e+86*cos(theta)**37 + 8.63009988435674e+85*cos(theta)**35 - 3.7784469692364e+85*cos(theta)**33 + 1.33893959715223e+85*cos(theta)**31 - 3.85038288605928e+84*cos(theta)**29 + 8.98422673413831e+83*cos(theta)**27 - 1.69632253022192e+83*cos(theta)**25 + 2.57799776629471e+82*cos(theta)**23 - 3.12821791305785e+81*cos(theta)**21 + 2.996924095539e+80*cos(theta)**19 - 2.23300226726435e+79*cos(theta)**17 + 1.26853929969905e+78*cos(theta)**15 - 5.35141126831659e+76*cos(theta)**13 + 1.61786852297943e+75*cos(theta)**11 - 3.33643677404833e+73*cos(theta)**9 + 4.36769904966326e+71*cos(theta)**7 - 3.24219441650507e+69*cos(theta)**5 + 1.11645813240533e+67*cos(theta)**3 - 1.12584013351798e+64*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl84_m_minus_32(theta, phi):
    return 2.52859182119784e-61*(1.0 - cos(theta)**2)**16*(4.8853352124972e+82*cos(theta)**52 - 3.87901466573131e+83*cos(theta)**50 + 1.43993726227905e+84*cos(theta)**48 - 3.32157307126946e+84*cos(theta)**46 + 5.33824243596877e+84*cos(theta)**44 - 6.35217276028486e+84*cos(theta)**42 + 5.80596682229858e+84*cos(theta)**40 - 4.17387476626073e+84*cos(theta)**38 + 2.39724996787687e+84*cos(theta)**36 - 1.11130793212835e+84*cos(theta)**34 + 4.18418624110071e+83*cos(theta)**32 - 1.28346096201976e+83*cos(theta)**30 + 3.2086524050494e+82*cos(theta)**28 - 6.52431742393046e+81*cos(theta)**26 + 1.07416573595613e+81*cos(theta)**24 - 1.42191723320811e+80*cos(theta)**22 + 1.4984620477695e+79*cos(theta)**20 - 1.24055681514686e+78*cos(theta)**18 + 7.92837062311904e+76*cos(theta)**16 - 3.82243662022614e+75*cos(theta)**14 + 1.34822376914953e+74*cos(theta)**12 - 3.33643677404833e+72*cos(theta)**10 + 5.45962381207908e+70*cos(theta)**8 - 5.40365736084179e+68*cos(theta)**6 + 2.79114533101332e+66*cos(theta)**4 - 5.62920066758989e+63*cos(theta)**2 + 1.8504933161045e+60)*sin(32*phi)

#@torch.jit.script
def Yl84_m_minus_31(theta, phi):
    return 1.9826481918361e-59*(1.0 - cos(theta)**2)**15.5*(9.21761360848529e+80*cos(theta)**53 - 7.60591110927708e+81*cos(theta)**51 + 2.93864747403887e+82*cos(theta)**49 - 7.06717674738183e+82*cos(theta)**47 + 1.18627609688195e+83*cos(theta)**45 - 1.47724947913601e+83*cos(theta)**43 + 1.41608946885331e+83*cos(theta)**41 - 1.07022429904121e+83*cos(theta)**39 + 6.47905396723479e+82*cos(theta)**37 - 3.17516552036672e+82*cos(theta)**35 + 1.26793522457597e+82*cos(theta)**33 - 4.14019665167664e+81*cos(theta)**31 + 1.10643186381014e+81*cos(theta)**29 - 2.41641386071498e+80*cos(theta)**27 + 4.29666294382452e+79*cos(theta)**25 - 6.18224884003528e+78*cos(theta)**23 + 7.13553356080714e+77*cos(theta)**21 - 6.5292463955098e+76*cos(theta)**19 + 4.66374742536414e+75*cos(theta)**17 - 2.54829108015076e+74*cos(theta)**15 + 1.0370952070381e+73*cos(theta)**13 - 3.03312434004393e+71*cos(theta)**11 + 6.06624868008787e+69*cos(theta)**9 - 7.71951051548827e+67*cos(theta)**7 + 5.58229066202664e+65*cos(theta)**5 - 1.87640022252996e+63*cos(theta)**3 + 1.8504933161045e+60*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl84_m_minus_30(theta, phi):
    return 1.56239722300668e-57*(1.0 - cos(theta)**2)**15*(1.70696548305283e+79*cos(theta)**54 - 1.46267521332252e+80*cos(theta)**52 + 5.87729494807774e+80*cos(theta)**50 - 1.47232848903788e+81*cos(theta)**48 + 2.57886108017815e+81*cos(theta)**46 - 3.35738517985457e+81*cos(theta)**44 + 3.37164159250789e+81*cos(theta)**42 - 2.67556074760303e+81*cos(theta)**40 + 1.70501420190389e+81*cos(theta)**38 - 8.81990422324089e+80*cos(theta)**36 + 3.72922124875286e+80*cos(theta)**34 - 1.29381145364895e+80*cos(theta)**32 + 3.68810621270046e+79*cos(theta)**30 - 8.63004950255352e+78*cos(theta)**28 + 1.65256267070174e+78*cos(theta)**26 - 2.57593701668137e+77*cos(theta)**24 + 3.24342434582143e+76*cos(theta)**22 - 3.2646231977549e+75*cos(theta)**20 + 2.59097079186897e+74*cos(theta)**18 - 1.59268192509422e+73*cos(theta)**16 + 7.40782290741499e+71*cos(theta)**14 - 2.52760361670328e+70*cos(theta)**12 + 6.06624868008787e+68*cos(theta)**10 - 9.64938814436034e+66*cos(theta)**8 + 9.30381777004441e+64*cos(theta)**6 - 4.69100055632491e+62*cos(theta)**4 + 9.25246658052251e+59*cos(theta)**2 - 2.9798604124066e+56)*sin(30*phi)

#@torch.jit.script
def Yl84_m_minus_29(theta, phi):
    return 1.23715817367941e-55*(1.0 - cos(theta)**2)**14.5*(3.1035736055506e+77*cos(theta)**55 - 2.75976455343871e+78*cos(theta)**53 + 1.15241077413289e+79*cos(theta)**51 - 3.00475201844466e+79*cos(theta)**49 + 5.48693846846415e+79*cos(theta)**47 - 7.46085595523239e+79*cos(theta)**45 + 7.84102695932066e+79*cos(theta)**43 - 6.525757920983e+79*cos(theta)**41 + 4.37183128693306e+79*cos(theta)**39 - 2.38375789817321e+79*cos(theta)**37 + 1.06549178535796e+79*cos(theta)**35 - 3.92064076863318e+78*cos(theta)**33 + 1.18971168151628e+78*cos(theta)**31 - 2.97587913881156e+77*cos(theta)**29 + 6.12060248408051e+76*cos(theta)**27 - 1.03037480667255e+76*cos(theta)**25 + 1.41018449818323e+75*cos(theta)**23 - 1.55458247512138e+74*cos(theta)**21 + 1.36366883782577e+73*cos(theta)**19 - 9.36871720643661e+71*cos(theta)**17 + 4.93854860494333e+70*cos(theta)**15 - 1.94431047438714e+69*cos(theta)**13 + 5.51477152735261e+67*cos(theta)**11 - 1.07215423826226e+66*cos(theta)**9 + 1.32911682429206e+64*cos(theta)**7 - 9.38200111264982e+61*cos(theta)**5 + 3.08415552684084e+59*cos(theta)**3 - 2.9798604124066e+56*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl84_m_minus_28(theta, phi):
    return 9.84143580679611e-54*(1.0 - cos(theta)**2)**14*(5.5420957241975e+75*cos(theta)**56 - 5.11067509896057e+76*cos(theta)**54 + 2.21617456564018e+77*cos(theta)**52 - 6.00950403688931e+77*cos(theta)**50 + 1.14311218093003e+78*cos(theta)**48 - 1.62192520765921e+78*cos(theta)**46 + 1.78205158166379e+78*cos(theta)**44 - 1.55375188594833e+78*cos(theta)**42 + 1.09295782173326e+78*cos(theta)**40 - 6.27304710045582e+77*cos(theta)**38 + 2.95969940377211e+77*cos(theta)**36 - 1.15312963783329e+77*cos(theta)**34 + 3.71784900473836e+76*cos(theta)**32 - 9.91959712937186e+75*cos(theta)**30 + 2.18592945860018e+75*cos(theta)**28 - 3.96298002566364e+74*cos(theta)**26 + 5.87576874243012e+73*cos(theta)**24 - 7.06628397782446e+72*cos(theta)**22 + 6.81834418912886e+71*cos(theta)**20 - 5.20484289246478e+70*cos(theta)**18 + 3.08659287808958e+69*cos(theta)**16 - 1.38879319599081e+68*cos(theta)**14 + 4.59564293946051e+66*cos(theta)**12 - 1.07215423826226e+65*cos(theta)**10 + 1.66139603036507e+63*cos(theta)**8 - 1.5636668521083e+61*cos(theta)**6 + 7.71038881710209e+58*cos(theta)**4 - 1.4899302062033e+56*cos(theta)**2 + 4.70900823705216e+52)*sin(28*phi)

#@torch.jit.script
def Yl84_m_minus_27(theta, phi):
    return 7.86330105103206e-52*(1.0 - cos(theta)**2)**13.5*(9.72297495473246e+73*cos(theta)**57 - 9.29213654356468e+74*cos(theta)**55 + 4.1814614446041e+75*cos(theta)**53 - 1.17833412488026e+76*cos(theta)**51 + 2.33288200189802e+76*cos(theta)**49 - 3.45090469714727e+76*cos(theta)**47 + 3.96011462591953e+76*cos(theta)**45 - 3.61337647894961e+76*cos(theta)**43 + 2.66575078471528e+76*cos(theta)**41 - 1.60847361550149e+76*cos(theta)**39 + 7.99918757776246e+75*cos(theta)**37 - 3.29465610809511e+75*cos(theta)**35 + 1.12662091052678e+75*cos(theta)**33 - 3.19987004173286e+74*cos(theta)**31 + 7.53768778827649e+73*cos(theta)**29 - 1.46777037987542e+73*cos(theta)**27 + 2.35030749697205e+72*cos(theta)**25 - 3.07229738166281e+71*cos(theta)**23 + 3.24683056625184e+70*cos(theta)**21 - 2.7393909960341e+69*cos(theta)**19 + 1.81564286946446e+68*cos(theta)**17 - 9.25862130660542e+66*cos(theta)**15 + 3.53510995343116e+65*cos(theta)**13 - 9.74685671147509e+63*cos(theta)**11 + 1.84599558929452e+62*cos(theta)**9 - 2.23380978872615e+60*cos(theta)**7 + 1.54207776342042e+58*cos(theta)**5 - 4.96643402067767e+55*cos(theta)**3 + 4.70900823705216e+52*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl84_m_minus_26(theta, phi):
    return 6.30928854160724e-50*(1.0 - cos(theta)**2)**13*(1.67637499219525e+72*cos(theta)**58 - 1.65931009706512e+73*cos(theta)**56 + 7.74344711963723e+73*cos(theta)**54 - 2.26602716323126e+74*cos(theta)**52 + 4.66576400379605e+74*cos(theta)**50 - 7.18938478572347e+74*cos(theta)**48 + 8.60894483895549e+74*cos(theta)**46 - 8.21221927034003e+74*cos(theta)**44 + 6.34702567789352e+74*cos(theta)**42 - 4.02118403875373e+74*cos(theta)**40 + 2.10504936256907e+74*cos(theta)**38 - 9.15182252248642e+73*cos(theta)**36 + 3.31359091331405e+73*cos(theta)**34 - 9.99959388041518e+72*cos(theta)**32 + 2.51256259609216e+72*cos(theta)**30 - 5.24203707098365e+71*cos(theta)**28 + 9.03964421912326e+70*cos(theta)**26 - 1.28012390902617e+70*cos(theta)**24 + 1.47583207556902e+69*cos(theta)**22 - 1.36969549801705e+68*cos(theta)**20 + 1.00869048303581e+67*cos(theta)**18 - 5.78663831662838e+65*cos(theta)**16 + 2.52507853816511e+64*cos(theta)**14 - 8.12238059289591e+62*cos(theta)**12 + 1.84599558929452e+61*cos(theta)**10 - 2.79226223590768e+59*cos(theta)**8 + 2.5701296057007e+57*cos(theta)**6 - 1.24160850516942e+55*cos(theta)**4 + 2.35450411852608e+52*cos(theta)**2 - 7.31439614329319e+48)*sin(26*phi)

#@torch.jit.script
def Yl84_m_minus_25(theta, phi):
    return 5.08279668233104e-48*(1.0 - cos(theta)**2)**12.5*(2.84131354609365e+70*cos(theta)**59 - 2.91107034572828e+71*cos(theta)**57 + 1.40789947629768e+72*cos(theta)**55 - 4.27552294949295e+72*cos(theta)**53 + 9.14855687018833e+72*cos(theta)**51 - 1.46722138484152e+73*cos(theta)**49 + 1.83169039126713e+73*cos(theta)**47 - 1.82493761563112e+73*cos(theta)**45 + 1.47605248323105e+73*cos(theta)**43 - 9.80776594817983e+72*cos(theta)**41 + 5.39756246812582e+72*cos(theta)**39 - 2.47346554661795e+72*cos(theta)**37 + 9.46740260946872e+71*cos(theta)**35 - 3.03017996376218e+71*cos(theta)**33 + 8.10504063255536e+70*cos(theta)**31 - 1.80759898999436e+70*cos(theta)**29 + 3.34801637745306e+69*cos(theta)**27 - 5.12049563610468e+68*cos(theta)**25 + 6.41666119812617e+67*cos(theta)**23 - 6.52235951436689e+66*cos(theta)**21 + 5.30889727913584e+65*cos(theta)**19 - 3.40390489213434e+64*cos(theta)**17 + 1.68338569211008e+63*cos(theta)**15 - 6.24798507145839e+61*cos(theta)**13 + 1.67817780844957e+60*cos(theta)**11 - 3.10251359545298e+58*cos(theta)**9 + 3.67161372242957e+56*cos(theta)**7 - 2.48321701033884e+54*cos(theta)**5 + 7.84834706175359e+51*cos(theta)**3 - 7.31439614329319e+48*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl84_m_minus_24(theta, phi):
    return 4.11047122146606e-46*(1.0 - cos(theta)**2)**12*(4.73552257682275e+68*cos(theta)**60 - 5.0190868029798e+69*cos(theta)**58 + 2.51410620767443e+70*cos(theta)**56 - 7.91763509165361e+70*cos(theta)**54 + 1.7593378596516e+71*cos(theta)**52 - 2.93444276968305e+71*cos(theta)**50 + 3.81602164847318e+71*cos(theta)**48 - 3.96725568615461e+71*cos(theta)**46 + 3.35466473461603e+71*cos(theta)**44 - 2.33518236861425e+71*cos(theta)**42 + 1.34939061703145e+71*cos(theta)**40 - 6.50911985952093e+70*cos(theta)**38 + 2.62983405818575e+70*cos(theta)**36 - 8.91229401106522e+69*cos(theta)**34 + 2.53282519767355e+69*cos(theta)**32 - 6.02532996664787e+68*cos(theta)**30 + 1.19572013480466e+68*cos(theta)**28 - 1.9694213985018e+67*cos(theta)**26 + 2.67360883255257e+66*cos(theta)**24 - 2.96470887016677e+65*cos(theta)**22 + 2.65444863956792e+64*cos(theta)**20 - 1.89105827340797e+63*cos(theta)**18 + 1.0521160575688e+62*cos(theta)**16 - 4.46284647961314e+60*cos(theta)**14 + 1.39848150704131e+59*cos(theta)**12 - 3.10251359545298e+57*cos(theta)**10 + 4.58951715303696e+55*cos(theta)**8 - 4.13869501723139e+53*cos(theta)**6 + 1.9620867654384e+51*cos(theta)**4 - 3.65719807164659e+48*cos(theta)**2 + 1.1184091962222e+45)*sin(24*phi)

#@torch.jit.script
def Yl84_m_minus_23(theta, phi):
    return 3.33632544108866e-44*(1.0 - cos(theta)**2)**11.5*(7.76315176528319e+66*cos(theta)**61 - 8.50692678471152e+67*cos(theta)**59 + 4.41071264504285e+68*cos(theta)**57 - 1.43957001666429e+69*cos(theta)**55 + 3.31950539556906e+69*cos(theta)**53 - 5.7538093523197e+69*cos(theta)**51 + 7.78779928259833e+69*cos(theta)**49 - 8.4409695450098e+69*cos(theta)**47 + 7.45481052136895e+69*cos(theta)**45 - 5.43065667119592e+69*cos(theta)**43 + 3.29119662690598e+69*cos(theta)**41 - 1.66900509218485e+69*cos(theta)**39 + 7.10765961671825e+68*cos(theta)**37 - 2.54636971744721e+68*cos(theta)**35 + 7.67522787173803e+67*cos(theta)**33 - 1.94365482795093e+67*cos(theta)**31 + 4.12317287863677e+66*cos(theta)**29 - 7.29415332778445e+65*cos(theta)**27 + 1.06944353302103e+65*cos(theta)**25 - 1.28900385659425e+64*cos(theta)**23 + 1.26402316169901e+63*cos(theta)**21 - 9.95293828109457e+61*cos(theta)**19 + 6.18891798569881e+60*cos(theta)**17 - 2.97523098640876e+59*cos(theta)**15 + 1.07575500541639e+58*cos(theta)**13 - 2.82046690495726e+56*cos(theta)**11 + 5.0994635033744e+54*cos(theta)**9 - 5.91242145318771e+52*cos(theta)**7 + 3.9241735308768e+50*cos(theta)**5 - 1.2190660238822e+48*cos(theta)**3 + 1.1184091962222e+45*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl84_m_minus_22(theta, phi):
    return 2.71741607884599e-42*(1.0 - cos(theta)**2)**11*(1.25212125246503e+65*cos(theta)**62 - 1.41782113078525e+66*cos(theta)**60 + 7.60467697421181e+66*cos(theta)**58 - 2.57066074404338e+67*cos(theta)**56 + 6.14723221401678e+67*cos(theta)**54 - 1.10650179852302e+68*cos(theta)**52 + 1.55755985651967e+68*cos(theta)**50 - 1.75853532187704e+68*cos(theta)**48 + 1.62061098290629e+68*cos(theta)**46 - 1.23424015254453e+68*cos(theta)**44 + 7.83618244501425e+67*cos(theta)**42 - 4.17251273046213e+67*cos(theta)**40 + 1.87043674124165e+67*cos(theta)**38 - 7.07324921513113e+66*cos(theta)**36 + 2.25741996227589e+66*cos(theta)**34 - 6.07392133734665e+65*cos(theta)**32 + 1.37439095954559e+65*cos(theta)**30 - 2.60505475992302e+64*cos(theta)**28 + 4.11324435777318e+63*cos(theta)**26 - 5.37084940247603e+62*cos(theta)**24 + 5.74555982590459e+61*cos(theta)**22 - 4.97646914054729e+60*cos(theta)**20 + 3.43828776983267e+59*cos(theta)**18 - 1.85951936650547e+58*cos(theta)**16 + 7.68396432440278e+56*cos(theta)**14 - 2.35038908746438e+55*cos(theta)**12 + 5.0994635033744e+53*cos(theta)**10 - 7.39052681648463e+51*cos(theta)**8 + 6.54028921812799e+49*cos(theta)**6 - 3.0476650597055e+47*cos(theta)**4 + 5.592045981111e+44*cos(theta)**2 - 1.68587457977419e+41)*sin(22*phi)

#@torch.jit.script
def Yl84_m_minus_21(theta, phi):
    return 2.2206460832857e-40*(1.0 - cos(theta)**2)**10.5*(1.98749405153179e+63*cos(theta)**63 - 2.32429693571353e+64*cos(theta)**61 + 1.28892830071387e+65*cos(theta)**59 - 4.50993112990067e+65*cos(theta)**57 + 1.11767858436669e+66*cos(theta)**55 - 2.08773924249626e+66*cos(theta)**53 + 3.05403893435228e+66*cos(theta)**51 - 3.58884759566743e+66*cos(theta)**49 + 3.44810847426871e+66*cos(theta)**47 - 2.74275589454339e+66*cos(theta)**45 + 1.82236801046843e+66*cos(theta)**43 - 1.01768603182003e+66*cos(theta)**41 + 4.79599164420935e+65*cos(theta)**39 - 1.91168897706247e+65*cos(theta)**37 + 6.44977132078826e+64*cos(theta)**35 - 1.84058222343838e+64*cos(theta)**33 + 4.43351922434062e+63*cos(theta)**31 - 8.9829474480104e+62*cos(theta)**29 + 1.52342383621229e+62*cos(theta)**27 - 2.14833976099041e+61*cos(theta)**25 + 2.49806948952374e+60*cos(theta)**23 - 2.36974720978442e+59*cos(theta)**21 + 1.80962514201719e+58*cos(theta)**19 - 1.09383492147381e+57*cos(theta)**17 + 5.12264288293519e+55*cos(theta)**15 - 1.80799160574183e+54*cos(theta)**13 + 4.63587591215854e+52*cos(theta)**11 - 8.2116964627607e+50*cos(theta)**9 + 9.34327031161142e+48*cos(theta)**7 - 6.09533011941099e+46*cos(theta)**5 + 1.864015327037e+44*cos(theta)**3 - 1.68587457977419e+41*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl84_m_minus_20(theta, phi):
    return 1.82038808672397e-38*(1.0 - cos(theta)**2)**10*(3.10545945551843e+61*cos(theta)**64 - 3.7488660253444e+62*cos(theta)**62 + 2.14821383452311e+63*cos(theta)**60 - 7.77574332741494e+63*cos(theta)**58 + 1.99585461494051e+64*cos(theta)**56 - 3.86618378240049e+64*cos(theta)**54 + 5.87315179683132e+64*cos(theta)**52 - 7.17769519133486e+64*cos(theta)**50 + 7.18355932139314e+64*cos(theta)**48 - 5.96251281422477e+64*cos(theta)**46 + 4.14174547833734e+64*cos(theta)**44 - 2.42306198052389e+64*cos(theta)**42 + 1.19899791105234e+64*cos(theta)**40 - 5.03076046595386e+63*cos(theta)**38 + 1.79160314466341e+63*cos(theta)**36 - 5.41347712775993e+62*cos(theta)**34 + 1.38547475760644e+62*cos(theta)**32 - 2.99431581600347e+61*cos(theta)**30 + 5.44079941504389e+60*cos(theta)**28 - 8.26284523457851e+59*cos(theta)**26 + 1.04086228730156e+59*cos(theta)**24 - 1.07715782262928e+58*cos(theta)**22 + 9.04812571008598e+56*cos(theta)**20 - 6.07686067485449e+55*cos(theta)**18 + 3.20165180183449e+54*cos(theta)**16 - 1.29142257552988e+53*cos(theta)**14 + 3.86322992679879e+51*cos(theta)**12 - 8.2116964627607e+49*cos(theta)**10 + 1.16790878895143e+48*cos(theta)**8 - 1.01588835323517e+46*cos(theta)**6 + 4.6600383175925e+43*cos(theta)**4 - 8.42937289887097e+40*cos(theta)**2 + 2.50874193418779e+37)*sin(20*phi)

#@torch.jit.script
def Yl84_m_minus_19(theta, phi):
    return 1.4967088706658e-36*(1.0 - cos(theta)**2)**9.5*(4.77762993156681e+59*cos(theta)**65 - 5.95058099261016e+60*cos(theta)**63 + 3.52166202380838e+61*cos(theta)**61 - 1.31792259786694e+62*cos(theta)**59 + 3.50149932445704e+62*cos(theta)**57 - 7.02942505890998e+62*cos(theta)**55 + 1.10814184845874e+63*cos(theta)**53 - 1.40739121398723e+63*cos(theta)**51 + 1.46603251457003e+63*cos(theta)**49 - 1.2686197477074e+63*cos(theta)**47 + 9.20387884074965e+62*cos(theta)**45 - 5.63502786168346e+62*cos(theta)**43 + 2.92438514890814e+62*cos(theta)**41 - 1.28993858101381e+62*cos(theta)**39 + 4.84217066125245e+61*cos(theta)**37 - 1.54670775078855e+61*cos(theta)**35 + 4.19840835638316e+60*cos(theta)**33 - 9.65908327743054e+59*cos(theta)**31 + 1.87613772932548e+59*cos(theta)**29 - 3.06031304984389e+58*cos(theta)**27 + 4.16344914920623e+57*cos(theta)**25 - 4.68329488099688e+56*cos(theta)**23 + 4.30863129051713e+55*cos(theta)**21 - 3.19834772360763e+54*cos(theta)**19 + 1.88332458931441e+53*cos(theta)**17 - 8.60948383686587e+51*cos(theta)**15 + 2.97171532830676e+50*cos(theta)**13 - 7.46517860250973e+48*cos(theta)**11 + 1.29767643216825e+47*cos(theta)**9 - 1.45126907605024e+45*cos(theta)**7 + 9.320076635185e+42*cos(theta)**5 - 2.80979096629032e+40*cos(theta)**3 + 2.50874193418779e+37*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl84_m_minus_18(theta, phi):
    return 1.23403623695234e-34*(1.0 - cos(theta)**2)**9*(7.23883322964669e+57*cos(theta)**66 - 9.29778280095338e+58*cos(theta)**64 + 5.68010003840061e+59*cos(theta)**62 - 2.19653766311157e+60*cos(theta)**60 + 6.037067800788e+60*cos(theta)**58 - 1.25525447480535e+61*cos(theta)**56 + 2.05211453418285e+61*cos(theta)**54 - 2.70652156536005e+61*cos(theta)**52 + 2.93206502914006e+61*cos(theta)**50 - 2.64295780772375e+61*cos(theta)**48 + 2.00084322624992e+61*cos(theta)**46 - 1.2806881503826e+61*cos(theta)**44 + 6.96282178311462e+60*cos(theta)**42 - 3.22484645253453e+60*cos(theta)**40 + 1.2742554371717e+60*cos(theta)**38 - 4.29641041885709e+59*cos(theta)**36 + 1.23482598717152e+59*cos(theta)**34 - 3.01846352419704e+58*cos(theta)**32 + 6.25379243108494e+57*cos(theta)**30 - 1.09296894637282e+57*cos(theta)**28 + 1.60132659584855e+56*cos(theta)**26 - 1.95137286708203e+55*cos(theta)**24 + 1.95846876841688e+54*cos(theta)**22 - 1.59917386180381e+53*cos(theta)**20 + 1.046291438508e+52*cos(theta)**18 - 5.38092739804117e+50*cos(theta)**16 + 2.1226538059334e+49*cos(theta)**14 - 6.22098216875811e+47*cos(theta)**12 + 1.29767643216825e+46*cos(theta)**10 - 1.8140863450628e+44*cos(theta)**8 + 1.55334610586417e+42*cos(theta)**6 - 7.02447741572581e+39*cos(theta)**4 + 1.25437096709389e+37*cos(theta)**2 - 3.69041178903764e+33)*sin(18*phi)

#@torch.jit.script
def Yl84_m_minus_17(theta, phi):
    return 1.02015320892099e-32*(1.0 - cos(theta)**2)**8.5*(1.08042287009652e+56*cos(theta)**67 - 1.4304281232236e+57*cos(theta)**65 + 9.0160318069851e+57*cos(theta)**63 - 3.60088141493699e+58*cos(theta)**61 + 1.02323183064203e+59*cos(theta)**59 - 2.20220083299185e+59*cos(theta)**57 + 3.73111733487791e+59*cos(theta)**55 - 5.1066444629435e+59*cos(theta)**53 + 5.7491471159609e+59*cos(theta)**51 - 5.39379144433418e+59*cos(theta)**49 + 4.25711324734026e+59*cos(theta)**47 - 2.8459736675169e+59*cos(theta)**45 + 1.6192608797941e+59*cos(theta)**43 - 7.86547915252324e+58*cos(theta)**41 + 3.26732163377358e+58*cos(theta)**39 - 1.16119200509651e+58*cos(theta)**37 + 3.52807424906148e+57*cos(theta)**35 - 9.14685916423347e+56*cos(theta)**33 + 2.01735239712417e+56*cos(theta)**31 - 3.76885843576834e+55*cos(theta)**29 + 5.93083924388351e+54*cos(theta)**27 - 7.80549146832814e+53*cos(theta)**25 + 8.51508160181251e+52*cos(theta)**23 - 7.61511362763721e+51*cos(theta)**21 + 5.50679704477897e+50*cos(theta)**19 - 3.16525141061245e+49*cos(theta)**17 + 1.41510253728893e+48*cos(theta)**15 - 4.7853708990447e+46*cos(theta)**13 + 1.17970584742568e+45*cos(theta)**11 - 2.01565149451422e+43*cos(theta)**9 + 2.21906586552024e+41*cos(theta)**7 - 1.40489548314516e+39*cos(theta)**5 + 4.18123655697965e+36*cos(theta)**3 - 3.69041178903764e+33*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl84_m_minus_16(theta, phi):
    return 8.45435623126083e-31*(1.0 - cos(theta)**2)**8*(1.58885716190665e+54*cos(theta)**68 - 2.16731533821757e+55*cos(theta)**66 + 1.40875496984142e+56*cos(theta)**64 - 5.80787324989838e+56*cos(theta)**62 + 1.70538638440339e+57*cos(theta)**60 - 3.79689798791698e+57*cos(theta)**58 + 6.66270952656769e+57*cos(theta)**56 - 9.45674900545092e+57*cos(theta)**54 + 1.10560521460787e+58*cos(theta)**52 - 1.07875828886684e+58*cos(theta)**50 + 8.86898593195888e+57*cos(theta)**48 - 6.18689927721065e+57*cos(theta)**46 + 3.6801383631684e+57*cos(theta)**44 - 1.87273313155315e+57*cos(theta)**42 + 8.16830408443396e+56*cos(theta)**40 - 3.0557684344645e+56*cos(theta)**38 + 9.800206247393e+55*cos(theta)**36 - 2.69025269536278e+55*cos(theta)**34 + 6.30422624101304e+54*cos(theta)**32 - 1.25628614525611e+54*cos(theta)**30 + 2.11815687281554e+53*cos(theta)**28 - 3.00211210320313e+52*cos(theta)**26 + 3.54795066742188e+51*cos(theta)**24 - 3.46141528528964e+50*cos(theta)**22 + 2.75339852238949e+49*cos(theta)**20 - 1.75847300589581e+48*cos(theta)**18 + 8.84439085805583e+46*cos(theta)**16 - 3.41812207074621e+45*cos(theta)**14 + 9.8308820618807e+43*cos(theta)**12 - 2.01565149451422e+42*cos(theta)**10 + 2.7738323319003e+40*cos(theta)**8 - 2.3414924719086e+38*cos(theta)**6 + 1.04530913924491e+36*cos(theta)**4 - 1.84520589451882e+33*cos(theta)**2 + 5.37334273301928e+29)*sin(16*phi)

#@torch.jit.script
def Yl84_m_minus_15(theta, phi):
    return 7.02271572162013e-29*(1.0 - cos(theta)**2)**7.5*(2.30269153899514e+52*cos(theta)**69 - 3.23479901226503e+53*cos(theta)**67 + 2.16731533821757e+54*cos(theta)**65 - 9.21884642841012e+54*cos(theta)**63 + 2.79571538426785e+55*cos(theta)**61 - 6.43542031850336e+55*cos(theta)**59 + 1.16889640816977e+56*cos(theta)**57 - 1.71940891008199e+56*cos(theta)**55 + 2.08604757473182e+56*cos(theta)**53 - 2.11521233111144e+56*cos(theta)**51 + 1.8099971289712e+56*cos(theta)**49 - 1.31636154834269e+56*cos(theta)**47 + 8.17808525148534e+55*cos(theta)**45 - 4.35519332919338e+55*cos(theta)**43 + 1.99226928888633e+55*cos(theta)**41 - 7.83530367811411e+54*cos(theta)**39 + 2.6487043911873e+54*cos(theta)**37 - 7.6864362724651e+53*cos(theta)**35 + 1.91037158818577e+53*cos(theta)**33 - 4.05253595243908e+52*cos(theta)**31 + 7.30398921660531e+51*cos(theta)**29 - 1.11189337155671e+51*cos(theta)**27 + 1.41918026696875e+50*cos(theta)**25 - 1.50496316751723e+49*cos(theta)**23 + 1.3111421535188e+48*cos(theta)**21 - 9.25512108366214e+46*cos(theta)**19 + 5.2025828576799e+45*cos(theta)**17 - 2.27874804716414e+44*cos(theta)**15 + 7.56221697067746e+42*cos(theta)**13 - 1.83241044955838e+41*cos(theta)**11 + 3.08203592433367e+39*cos(theta)**9 - 3.34498924558372e+37*cos(theta)**7 + 2.09061827848982e+35*cos(theta)**5 - 6.15068631506274e+32*cos(theta)**3 + 5.37334273301928e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl84_m_minus_14(theta, phi):
    return 5.84617357952503e-27*(1.0 - cos(theta)**2)**7*(3.28955934142163e+50*cos(theta)**70 - 4.75705737097799e+51*cos(theta)**68 + 3.28381111851147e+52*cos(theta)**66 - 1.44044475443908e+53*cos(theta)**64 + 4.50921836172234e+53*cos(theta)**62 - 1.07257005308389e+54*cos(theta)**60 + 2.01533863477547e+54*cos(theta)**58 - 3.07037305371783e+54*cos(theta)**56 + 3.86305106431819e+54*cos(theta)**54 - 4.06771602136816e+54*cos(theta)**52 + 3.6199942579424e+54*cos(theta)**50 - 2.74241989238061e+54*cos(theta)**48 + 1.77784461988812e+54*cos(theta)**46 - 9.89816665725767e+53*cos(theta)**44 + 4.74349830687222e+53*cos(theta)**42 - 1.95882591952853e+53*cos(theta)**40 + 6.97027471365078e+52*cos(theta)**38 - 2.13512118679586e+52*cos(theta)**36 + 5.61873996525226e+51*cos(theta)**34 - 1.26641748513721e+51*cos(theta)**32 + 2.43466307220177e+50*cos(theta)**30 - 3.97104775555969e+49*cos(theta)**28 + 5.45838564218751e+48*cos(theta)**26 - 6.27067986465514e+47*cos(theta)**24 + 5.9597370614491e+46*cos(theta)**22 - 4.62756054183107e+45*cos(theta)**20 + 2.89032380982217e+44*cos(theta)**18 - 1.42421752947759e+43*cos(theta)**16 + 5.4015835504839e+41*cos(theta)**14 - 1.52700870796532e+40*cos(theta)**12 + 3.08203592433366e+38*cos(theta)**10 - 4.18123655697965e+36*cos(theta)**8 + 3.48436379748304e+34*cos(theta)**6 - 1.53767157876568e+32*cos(theta)**4 + 2.68667136650964e+29*cos(theta)**2 - 7.75374131748814e+25)*sin(14*phi)

#@torch.jit.script
def Yl84_m_minus_13(theta, phi):
    return 4.87656388599221e-25*(1.0 - cos(theta)**2)**6.5*(4.63318217101638e+48*cos(theta)**71 - 6.89428604489563e+49*cos(theta)**69 + 4.90121062464399e+50*cos(theta)**67 - 2.2160688529832e+51*cos(theta)**65 + 7.15748946305133e+51*cos(theta)**63 - 1.75831156243261e+52*cos(theta)**61 + 3.41582819453469e+52*cos(theta)**59 - 5.38661939248742e+52*cos(theta)**57 + 7.02372920785125e+52*cos(theta)**55 - 7.67493588937388e+52*cos(theta)**53 + 7.0980279567498e+52*cos(theta)**51 - 5.59677529057267e+52*cos(theta)**49 + 3.78264812742153e+52*cos(theta)**47 - 2.1995925905017e+52*cos(theta)**45 + 1.10313914113307e+52*cos(theta)**43 - 4.77762419397202e+51*cos(theta)**41 + 1.78724992657712e+51*cos(theta)**39 - 5.77059780215097e+50*cos(theta)**37 + 1.60535427578636e+50*cos(theta)**35 - 3.83762874284004e+49*cos(theta)**33 + 7.85375184581217e+48*cos(theta)**31 - 1.36932681226196e+48*cos(theta)**29 + 2.0216243119213e+47*cos(theta)**27 - 2.50827194586206e+46*cos(theta)**25 + 2.591190026717e+45*cos(theta)**23 - 2.20360025801479e+44*cos(theta)**21 + 1.52122305780114e+43*cos(theta)**19 - 8.37775017339758e+41*cos(theta)**17 + 3.6010557003226e+40*cos(theta)**15 - 1.17462208305024e+39*cos(theta)**13 + 2.80185084030333e+37*cos(theta)**11 - 4.64581839664405e+35*cos(theta)**9 + 4.97766256783291e+33*cos(theta)**7 - 3.07534315753137e+31*cos(theta)**5 + 8.9555712216988e+28*cos(theta)**3 - 7.75374131748814e+25*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl84_m_minus_12(theta, phi):
    return 4.0753605157556e-23*(1.0 - cos(theta)**2)**6*(6.43497523752275e+46*cos(theta)**72 - 9.84898006413662e+47*cos(theta)**70 + 7.20766268329998e+48*cos(theta)**68 - 3.35768008027758e+49*cos(theta)**66 + 1.11835772860177e+50*cos(theta)**64 - 2.83598639102034e+50*cos(theta)**62 + 5.69304699089115e+50*cos(theta)**60 - 9.28727481463349e+50*cos(theta)**58 + 1.25423735854487e+51*cos(theta)**56 - 1.42128442395813e+51*cos(theta)**54 + 1.36500537629804e+51*cos(theta)**52 - 1.11935505811453e+51*cos(theta)**50 + 7.88051693212818e+50*cos(theta)**48 - 4.78172302282979e+50*cos(theta)**46 + 2.50713441166608e+50*cos(theta)**44 - 1.13752956999334e+50*cos(theta)**42 + 4.46812481644281e+49*cos(theta)**40 - 1.5185783689871e+49*cos(theta)**38 + 4.45931743273989e+48*cos(theta)**36 - 1.12871433612942e+48*cos(theta)**34 + 2.4542974518163e+47*cos(theta)**32 - 4.56442270753988e+46*cos(theta)**30 + 7.22008682829035e+45*cos(theta)**28 - 9.64719979177714e+44*cos(theta)**26 + 1.07966251113208e+44*cos(theta)**24 - 1.00163648091582e+43*cos(theta)**22 + 7.6061152890057e+41*cos(theta)**20 - 4.65430565188755e+40*cos(theta)**18 + 2.25065981270163e+39*cos(theta)**16 - 8.39015773607316e+37*cos(theta)**14 + 2.33487570025278e+36*cos(theta)**12 - 4.64581839664405e+34*cos(theta)**10 + 6.22207820979114e+32*cos(theta)**8 - 5.12557192921895e+30*cos(theta)**6 + 2.2388928054247e+28*cos(theta)**4 - 3.87687065874407e+25*cos(theta)**2 + 1.11021496527608e+22)*sin(12*phi)

#@torch.jit.script
def Yl84_m_minus_11(theta, phi):
    return 3.41163907587431e-21*(1.0 - cos(theta)**2)**5.5*(8.81503457194898e+44*cos(theta)**73 - 1.38718029072347e+46*cos(theta)**71 + 1.04458879468116e+47*cos(theta)**69 - 5.01146280638445e+47*cos(theta)**67 + 1.72055035169503e+48*cos(theta)**65 - 4.50156570003229e+48*cos(theta)**63 + 9.33286391949369e+48*cos(theta)**61 - 1.57411437536161e+49*cos(theta)**59 + 2.20041641849976e+49*cos(theta)**57 - 2.58415349810568e+49*cos(theta)**55 + 2.57548184207177e+49*cos(theta)**53 - 2.19481383944026e+49*cos(theta)**51 + 1.60826876165881e+49*cos(theta)**49 - 1.01738787719783e+49*cos(theta)**47 + 5.57140980370239e+48*cos(theta)**45 - 2.64541760463567e+48*cos(theta)**43 + 1.08978654059581e+48*cos(theta)**41 - 3.89379068971051e+47*cos(theta)**39 + 1.20522092776754e+47*cos(theta)**37 - 3.22489810322692e+46*cos(theta)**35 + 7.43726500550394e+45*cos(theta)**33 - 1.47239442178706e+45*cos(theta)**31 + 2.48968511320357e+44*cos(theta)**29 - 3.57303695991746e+43*cos(theta)**27 + 4.31865004452833e+42*cos(theta)**25 - 4.35494122137311e+41*cos(theta)**23 + 3.62195966143129e+40*cos(theta)**21 - 2.44963455362502e+39*cos(theta)**19 + 1.32391753688331e+38*cos(theta)**17 - 5.59343849071544e+36*cos(theta)**15 + 1.79605823096367e+35*cos(theta)**13 - 4.22347126967641e+33*cos(theta)**11 + 6.91342023310127e+31*cos(theta)**9 - 7.32224561316992e+29*cos(theta)**7 + 4.4777856108494e+27*cos(theta)**5 - 1.29229021958136e+25*cos(theta)**3 + 1.11021496527608e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl84_m_minus_10(theta, phi):
    return 2.86049203326541e-19*(1.0 - cos(theta)**2)**5*(1.19122088810121e+43*cos(theta)**74 - 1.92663929267148e+44*cos(theta)**72 + 1.49226970668737e+45*cos(theta)**70 - 7.36979824468301e+45*cos(theta)**68 + 2.6068944722652e+46*cos(theta)**66 - 7.03369640630045e+46*cos(theta)**64 + 1.5053006321764e+47*cos(theta)**62 - 2.62352395893601e+47*cos(theta)**60 + 3.79382141120649e+47*cos(theta)**58 - 4.61455981804586e+47*cos(theta)**56 + 4.76941081865143e+47*cos(theta)**54 - 4.22079584507742e+47*cos(theta)**52 + 3.21653752331762e+47*cos(theta)**50 - 2.11955807749548e+47*cos(theta)**48 + 1.21117604428313e+47*cos(theta)**46 - 6.01231273780834e+46*cos(theta)**44 + 2.59472985856145e+46*cos(theta)**42 - 9.73447672427627e+45*cos(theta)**40 + 3.17163402044089e+45*cos(theta)**38 - 8.95805028674145e+44*cos(theta)**36 + 2.18743088397175e+44*cos(theta)**34 - 4.60123256808455e+43*cos(theta)**32 + 8.29895037734523e+42*cos(theta)**30 - 1.27608462854195e+42*cos(theta)**28 + 1.66101924789551e+41*cos(theta)**26 - 1.8145588422388e+40*cos(theta)**24 + 1.64634530065058e+39*cos(theta)**22 - 1.22481727681251e+38*cos(theta)**20 + 7.3550974271295e+36*cos(theta)**18 - 3.49589905669715e+35*cos(theta)**16 + 1.28289873640262e+34*cos(theta)**14 - 3.51955939139701e+32*cos(theta)**12 + 6.91342023310127e+30*cos(theta)**10 - 9.1528070164624e+28*cos(theta)**8 + 7.46297601808233e+26*cos(theta)**6 - 3.23072554895339e+24*cos(theta)**4 + 5.5510748263804e+21*cos(theta)**2 - 1.57925315117508e+18)*sin(10*phi)

#@torch.jit.script
def Yl84_m_minus_9(theta, phi):
    return 2.40179148637518e-17*(1.0 - cos(theta)**2)**4.5*(1.58829451746828e+41*cos(theta)**75 - 2.63923190776915e+42*cos(theta)**73 + 2.10178831927798e+43*cos(theta)**71 - 1.06808670212797e+44*cos(theta)**69 + 3.89088727203761e+44*cos(theta)**67 - 1.08210713943084e+45*cos(theta)**65 + 2.38936608281968e+45*cos(theta)**63 - 4.30085894907543e+45*cos(theta)**61 + 6.43020578170592e+45*cos(theta)**59 - 8.09571897902783e+45*cos(theta)**57 + 8.67165603391169e+45*cos(theta)**55 - 7.9637657454291e+45*cos(theta)**53 + 6.30693632023064e+45*cos(theta)**51 - 4.3256287295826e+45*cos(theta)**49 + 2.57697030698538e+45*cos(theta)**47 - 1.33606949729074e+45*cos(theta)**45 + 6.03425548502662e+44*cos(theta)**43 - 2.37426261567714e+44*cos(theta)**41 + 8.13239492420741e+43*cos(theta)**39 - 2.42109467209228e+43*cos(theta)**37 + 6.24980252563357e+42*cos(theta)**35 - 1.39431289941956e+42*cos(theta)**33 + 2.67708076688556e+41*cos(theta)**31 - 4.40029182255845e+40*cos(theta)**29 + 6.15192314035375e+39*cos(theta)**27 - 7.25823536895519e+38*cos(theta)**25 + 7.15802304630689e+37*cos(theta)**23 - 5.83246322291672e+36*cos(theta)**21 + 3.87110390901553e+35*cos(theta)**19 - 2.05641120982185e+34*cos(theta)**17 + 8.55265824268416e+32*cos(theta)**15 - 2.7073533779977e+31*cos(theta)**13 + 6.28492748463752e+29*cos(theta)**11 - 1.01697855738471e+28*cos(theta)**9 + 1.06613943115462e+26*cos(theta)**7 - 6.46145109790678e+23*cos(theta)**5 + 1.85035827546013e+21*cos(theta)**3 - 1.57925315117508e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl84_m_minus_8(theta, phi):
    return 2.01921968511511e-15*(1.0 - cos(theta)**2)**4*(2.08986120719511e+39*cos(theta)**76 - 3.56652960509345e+40*cos(theta)**74 + 2.91915044344164e+41*cos(theta)**72 - 1.5258381458971e+42*cos(theta)**70 + 5.72189304711414e+42*cos(theta)**68 - 1.63955627186491e+43*cos(theta)**66 + 3.73338450440576e+43*cos(theta)**64 - 6.93686927270231e+43*cos(theta)**62 + 1.07170096361765e+44*cos(theta)**60 - 1.39581361707376e+44*cos(theta)**58 + 1.54851000605566e+44*cos(theta)**56 - 1.47477143433872e+44*cos(theta)**54 + 1.21287236927512e+44*cos(theta)**52 - 8.65125745916521e+43*cos(theta)**50 + 5.36868813955288e+43*cos(theta)**48 - 2.90449890715379e+43*cos(theta)**46 + 1.37142170114241e+43*cos(theta)**44 - 5.65300622780271e+42*cos(theta)**42 + 2.03309873105185e+42*cos(theta)**40 - 6.3713017686639e+41*cos(theta)**38 + 1.73605625712044e+41*cos(theta)**36 - 4.10092029241048e+40*cos(theta)**34 + 8.36587739651737e+39*cos(theta)**32 - 1.46676394085282e+39*cos(theta)**30 + 2.1971154072692e+38*cos(theta)**28 - 2.79162898805969e+37*cos(theta)**26 + 2.98250960262787e+36*cos(theta)**24 - 2.65111964678033e+35*cos(theta)**22 + 1.93555195450776e+34*cos(theta)**20 - 1.14245067212325e+33*cos(theta)**18 + 5.3454114016776e+31*cos(theta)**16 - 1.93382384142693e+30*cos(theta)**14 + 5.23743957053127e+28*cos(theta)**12 - 1.01697855738471e+27*cos(theta)**10 + 1.33267428894327e+25*cos(theta)**8 - 1.0769085163178e+23*cos(theta)**6 + 4.62589568865033e+20*cos(theta)**4 - 7.89626575587539e+17*cos(theta)**2 + 223437061569762.0)*sin(8*phi)

#@torch.jit.script
def Yl84_m_minus_7(theta, phi):
    return 1.6995065695896e-13*(1.0 - cos(theta)**2)**3.5*(2.71410546388975e+37*cos(theta)**77 - 4.75537280679127e+38*cos(theta)**75 + 3.99883622389266e+39*cos(theta)**73 - 2.14906781112268e+40*cos(theta)**71 + 8.292598619006e+40*cos(theta)**69 - 2.4470989132312e+41*cos(theta)**67 + 5.74366846831655e+41*cos(theta)**65 - 1.1010903607464e+42*cos(theta)**63 + 1.75688682560271e+42*cos(theta)**61 - 2.36578579165045e+42*cos(theta)**59 + 2.71668422115028e+42*cos(theta)**57 - 2.68140260788859e+42*cos(theta)**55 + 2.28843843259457e+42*cos(theta)**53 - 1.69632499199318e+42*cos(theta)**51 + 1.09565064072508e+42*cos(theta)**49 - 6.17978490883784e+41*cos(theta)**47 + 3.04760378031647e+41*cos(theta)**45 - 1.31465261111691e+41*cos(theta)**43 + 4.9587773928094e+40*cos(theta)**41 - 1.63366712017023e+40*cos(theta)**39 + 4.69204393816334e+39*cos(theta)**37 - 1.17169151211728e+39*cos(theta)**35 + 2.53511436258102e+38*cos(theta)**33 - 4.73149658339618e+37*cos(theta)**31 + 7.5762600250662e+36*cos(theta)**29 - 1.03393666224433e+36*cos(theta)**27 + 1.19300384105115e+35*cos(theta)**25 - 1.15266071599145e+34*cos(theta)**23 + 9.21691406908458e+32*cos(theta)**21 - 6.01289827433291e+31*cos(theta)**19 + 3.14435964804565e+30*cos(theta)**17 - 1.28921589428462e+29*cos(theta)**15 + 4.02879966963943e+27*cos(theta)**13 - 9.24525961258829e+25*cos(theta)**11 + 1.48074920993697e+24*cos(theta)**9 - 1.53844073759685e+22*cos(theta)**7 + 9.25179137730066e+19*cos(theta)**5 - 2.6320885852918e+17*cos(theta)**3 + 223437061569762.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl84_m_minus_6(theta, phi):
    return 1.43182798105761e-11*(1.0 - cos(theta)**2)**3*(3.47962238960225e+35*cos(theta)**78 - 6.25706948262009e+36*cos(theta)**76 + 5.40383273499008e+37*cos(theta)**74 - 2.98481640433706e+38*cos(theta)**72 + 1.18465694557229e+39*cos(theta)**70 - 3.59867487239883e+39*cos(theta)**68 + 8.7025279822978e+39*cos(theta)**66 - 1.72045368866625e+40*cos(theta)**64 + 2.83368842839147e+40*cos(theta)**62 - 3.94297631941741e+40*cos(theta)**60 + 4.68393831232807e+40*cos(theta)**58 - 4.78821894265819e+40*cos(theta)**56 + 4.2378489492492e+40*cos(theta)**54 - 3.26216344614073e+40*cos(theta)**52 + 2.19130128145015e+40*cos(theta)**50 - 1.28745518934122e+40*cos(theta)**48 + 6.62522560938364e+39*cos(theta)**46 - 2.98784684344752e+39*cos(theta)**44 + 1.18066128400224e+39*cos(theta)**42 - 4.08416780042558e+38*cos(theta)**40 + 1.23474840477983e+38*cos(theta)**38 - 3.25469864477022e+37*cos(theta)**36 + 7.45621871347359e+36*cos(theta)**34 - 1.47859268231131e+36*cos(theta)**32 + 2.5254200083554e+35*cos(theta)**30 - 3.69263093658689e+34*cos(theta)**28 + 4.58847631173519e+33*cos(theta)**26 - 4.8027529832977e+32*cos(theta)**24 + 4.18950639503845e+31*cos(theta)**22 - 3.00644913716645e+30*cos(theta)**20 + 1.74686647113647e+29*cos(theta)**18 - 8.05759933927887e+27*cos(theta)**16 + 2.87771404974245e+26*cos(theta)**14 - 7.70438301049024e+24*cos(theta)**12 + 1.48074920993697e+23*cos(theta)**10 - 1.92305092199607e+21*cos(theta)**8 + 1.54196522955011e+19*cos(theta)**6 - 6.58022146322949e+16*cos(theta)**4 + 111718530784881.0*cos(theta)**2 - 31478875960.8005)*sin(6*phi)

#@torch.jit.script
def Yl84_m_minus_5(theta, phi):
    return 1.20732903641816e-9*(1.0 - cos(theta)**2)**2.5*(4.40458530329399e+33*cos(theta)**79 - 8.12606426314298e+34*cos(theta)**77 + 7.20511031332011e+35*cos(theta)**75 - 4.08878959498227e+36*cos(theta)**73 + 1.66853090925674e+37*cos(theta)**71 - 5.21547082956352e+37*cos(theta)**69 + 1.29888477347728e+38*cos(theta)**67 - 2.6468518287173e+38*cos(theta)**65 + 4.49791814030392e+38*cos(theta)**63 - 6.46389560560232e+38*cos(theta)**61 + 7.9388784954713e+38*cos(theta)**59 - 8.40038410992665e+38*cos(theta)**57 + 7.70517990772582e+38*cos(theta)**55 - 6.15502537007684e+38*cos(theta)**53 + 4.29666917931403e+38*cos(theta)**51 - 2.62745957008412e+38*cos(theta)**49 + 1.40962247008162e+38*cos(theta)**47 - 6.63965965210561e+37*cos(theta)**45 + 2.74572391628427e+37*cos(theta)**43 - 9.96138487908678e+36*cos(theta)**41 + 3.1660215507175e+36*cos(theta)**39 - 8.7964828237033e+35*cos(theta)**37 + 2.1303482038496e+35*cos(theta)**35 - 4.48058388579184e+34*cos(theta)**33 + 8.14651615598516e+33*cos(theta)**31 - 1.27332101261617e+33*cos(theta)**29 + 1.69943567101303e+32*cos(theta)**27 - 1.92110119331908e+31*cos(theta)**25 + 1.82152451958193e+30*cos(theta)**23 - 1.43164244626974e+29*cos(theta)**21 + 9.19403405861301e+27*cos(theta)**19 - 4.73976431722286e+26*cos(theta)**17 + 1.91847603316164e+25*cos(theta)**15 - 5.92644846960788e+23*cos(theta)**13 + 1.34613564539725e+22*cos(theta)**11 - 2.1367232466623e+20*cos(theta)**9 + 2.20280747078587e+18*cos(theta)**7 - 1.3160442926459e+16*cos(theta)**5 + 37239510261627.0*cos(theta)**3 - 31478875960.8005*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl84_m_minus_4(theta, phi):
    return 1.01874535697151e-7*(1.0 - cos(theta)**2)**2*(5.50573162911748e+31*cos(theta)**80 - 1.04180311065936e+33*cos(theta)**78 + 9.48040830700014e+33*cos(theta)**76 - 5.52539134457063e+34*cos(theta)**74 + 2.31740404063436e+35*cos(theta)**72 - 7.45067261366217e+35*cos(theta)**70 + 1.91012466687836e+36*cos(theta)**68 - 4.01038155866258e+36*cos(theta)**66 + 7.02799709422487e+36*cos(theta)**64 - 1.04256380735521e+37*cos(theta)**62 + 1.32314641591188e+37*cos(theta)**60 - 1.44834208791839e+37*cos(theta)**58 + 1.37592498352247e+37*cos(theta)**56 - 1.13981951297719e+37*cos(theta)**54 + 8.26282534483467e+36*cos(theta)**52 - 5.25491914016823e+36*cos(theta)**50 + 2.93671347933672e+36*cos(theta)**48 - 1.44340427219687e+36*cos(theta)**46 + 6.2402816279188e+35*cos(theta)**44 - 2.37175830454447e+35*cos(theta)**42 + 7.91505387679376e+34*cos(theta)**40 - 2.31486390097455e+34*cos(theta)**38 + 5.91763389958222e+33*cos(theta)**36 - 1.31781878993878e+33*cos(theta)**34 + 2.54578629874536e+32*cos(theta)**32 - 4.24440337538723e+31*cos(theta)**30 + 6.06941311076083e+30*cos(theta)**28 - 7.38885074353492e+29*cos(theta)**26 + 7.58968549825806e+28*cos(theta)**24 - 6.50746566486245e+27*cos(theta)**22 + 4.5970170293065e+26*cos(theta)**20 - 2.63320239845715e+25*cos(theta)**18 + 1.19904752072602e+24*cos(theta)**16 - 4.23317747829134e+22*cos(theta)**14 + 1.12177970449771e+21*cos(theta)**12 - 2.1367232466623e+19*cos(theta)**10 + 2.75350933848234e+17*cos(theta)**8 - 2.19340715440983e+15*cos(theta)**6 + 9309877565406.75*cos(theta)**4 - 15739437980.4002*cos(theta)**2 + 4421190.44393265)*sin(4*phi)

#@torch.jit.script
def Yl84_m_minus_3(theta, phi):
    return 8.60101069965504e-6*(1.0 - cos(theta)**2)**1.5*(6.79719954212035e+29*cos(theta)**81 - 1.31873811475868e+31*cos(theta)**79 + 1.23122185805197e+32*cos(theta)**77 - 7.36718845942751e+32*cos(theta)**75 + 3.17452608306077e+33*cos(theta)**73 - 1.0493905089665e+34*cos(theta)**71 + 2.76829661866429e+34*cos(theta)**69 - 5.98564411740684e+34*cos(theta)**67 + 1.08123032218844e+35*cos(theta)**65 - 1.65486318627811e+35*cos(theta)**63 + 2.16909248510145e+35*cos(theta)**61 - 2.45481709816676e+35*cos(theta)**59 + 2.41390347986398e+35*cos(theta)**57 - 2.07239911450399e+35*cos(theta)**55 + 1.5590236499688e+35*cos(theta)**53 - 1.03037630199377e+35*cos(theta)**51 + 5.99329281497289e+34*cos(theta)**49 - 3.07107291956781e+34*cos(theta)**47 + 1.38672925064862e+34*cos(theta)**45 - 5.51571698731272e+33*cos(theta)**43 + 1.93050094555945e+33*cos(theta)**41 - 5.93554846403731e+32*cos(theta)**39 + 1.5993605134006e+32*cos(theta)**37 - 3.76519654268222e+31*cos(theta)**35 + 7.71450393559201e+30*cos(theta)**33 - 1.36916237915717e+30*cos(theta)**31 + 2.09290107267615e+29*cos(theta)**29 - 2.73661138649441e+28*cos(theta)**27 + 3.03587419930322e+27*cos(theta)**25 - 2.82933289776628e+26*cos(theta)**23 + 2.18905572824119e+25*cos(theta)**21 - 1.38589599918797e+24*cos(theta)**19 + 7.05322071015307e+22*cos(theta)**17 - 2.82211831886089e+21*cos(theta)**15 + 8.62907464998235e+19*cos(theta)**13 - 1.94247567878391e+18*cos(theta)**11 + 3.05945482053593e+16*cos(theta)**9 - 313343879201404.0*cos(theta)**7 + 1861975513081.35*cos(theta)**5 - 5246479326.80008*cos(theta)**3 + 4421190.44393265*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl84_m_minus_2(theta, phi):
    return 0.000726467249768708*(1.0 - cos(theta)**2)*(8.28926773429311e+27*cos(theta)**82 - 1.64842264344835e+29*cos(theta)**80 + 1.57848956160508e+30*cos(theta)**78 - 9.69366902556251e+30*cos(theta)**76 + 4.28990011224428e+31*cos(theta)**74 - 1.45748681800903e+32*cos(theta)**72 + 3.9547094552347e+32*cos(theta)**70 - 8.80241781971594e+32*cos(theta)**68 + 1.63822776089158e+33*cos(theta)**66 - 2.58572372855955e+33*cos(theta)**64 + 3.49853626629266e+33*cos(theta)**62 - 4.09136183027793e+33*cos(theta)**60 + 4.16190255148962e+33*cos(theta)**58 - 3.70071270447141e+33*cos(theta)**56 + 2.88708083327557e+33*cos(theta)**54 - 1.98149288844956e+33*cos(theta)**52 + 1.19865856299458e+33*cos(theta)**50 - 6.39806858243294e+32*cos(theta)**48 + 3.01462880575788e+32*cos(theta)**46 - 1.25357204257107e+32*cos(theta)**44 + 4.5964308227606e+31*cos(theta)**42 - 1.48388711600933e+31*cos(theta)**40 + 4.20884345631737e+30*cos(theta)**38 - 1.04588792852284e+30*cos(theta)**36 + 2.26897174576236e+29*cos(theta)**34 - 4.27863243486616e+28*cos(theta)**32 + 6.97633690892049e+27*cos(theta)**30 - 9.77361209462291e+26*cos(theta)**28 + 1.16764392280893e+26*cos(theta)**26 - 1.17888870740262e+25*cos(theta)**24 + 9.95025331018724e+23*cos(theta)**22 - 6.92947999593986e+22*cos(theta)**20 + 3.91845595008504e+21*cos(theta)**18 - 1.76382394928806e+20*cos(theta)**16 + 6.16362474998739e+18*cos(theta)**14 - 1.61872973231992e+17*cos(theta)**12 + 3.05945482053593e+15*cos(theta)**10 - 39167984900175.5*cos(theta)**8 + 310329252180.225*cos(theta)**6 - 1311619831.70002*cos(theta)**4 + 2210595.22196633*cos(theta)**2 - 619.73513371638)*sin(2*phi)

#@torch.jit.script
def Yl84_m_minus_1(theta, phi):
    return 0.0613768099421411*(1.0 - cos(theta)**2)**0.5*(9.98706955938929e+25*cos(theta)**83 - 2.03508968326957e+27*cos(theta)**81 + 1.99808805266466e+28*cos(theta)**79 - 1.25891805526786e+29*cos(theta)**77 + 5.71986681632571e+29*cos(theta)**75 - 1.99655728494388e+30*cos(theta)**73 + 5.57001331723197e+30*cos(theta)**71 - 1.27571272749506e+31*cos(theta)**69 + 2.44511606103221e+31*cos(theta)**67 - 3.97803650547624e+31*cos(theta)**65 + 5.55323216871851e+31*cos(theta)**63 - 6.70715054143923e+31*cos(theta)**61 + 7.05407212116885e+31*cos(theta)**59 - 6.4924784288972e+31*cos(theta)**57 + 5.24923787868285e+31*cos(theta)**55 - 3.73866582726332e+31*cos(theta)**53 + 2.35031090783251e+31*cos(theta)**51 - 1.30572828212917e+31*cos(theta)**49 + 6.41410384203803e+30*cos(theta)**47 - 2.78571565015794e+30*cos(theta)**45 + 1.068937400642e+30*cos(theta)**43 - 3.61923686831543e+29*cos(theta)**41 + 1.07919062982497e+29*cos(theta)**39 - 2.82672413114281e+28*cos(theta)**37 + 6.48277641646387e+27*cos(theta)**35 - 1.29655528329277e+27*cos(theta)**33 + 2.25043126094209e+26*cos(theta)**31 - 3.37021106711135e+25*cos(theta)**29 + 4.32460712151456e+24*cos(theta)**27 - 4.71555482961047e+23*cos(theta)**25 + 4.32619709138575e+22*cos(theta)**23 - 3.29975237901898e+21*cos(theta)**21 + 2.06234523688686e+20*cos(theta)**19 - 1.03754349958121e+19*cos(theta)**17 + 4.10908316665826e+17*cos(theta)**15 - 1.24517671716917e+16*cos(theta)**13 + 278132256412358.0*cos(theta)**11 - 4351998322241.73*cos(theta)**9 + 44332750311.4607*cos(theta)**7 - 262323966.340004*cos(theta)**5 + 736865.073988776*cos(theta)**3 - 619.73513371638*cos(theta))*sin(phi)

#@torch.jit.script
def Yl84_m0(theta, phi):
    return 1.3697682065322e+25*cos(theta)**84 - 2.85928860357561e+26*cos(theta)**82 + 2.87748407650745e+27*cos(theta)**80 - 1.85947846252833e+28*cos(theta)**78 + 8.67082891765929e+28*cos(theta)**76 - 3.10841036670805e+29*cos(theta)**74 + 8.91275626377754e+29*cos(theta)**72 - 2.09963179817653e+30*cos(theta)**70 + 4.14265587630419e+30*cos(theta)**68 - 6.9440545152472e+30*cos(theta)**66 + 9.99664223839278e+30*cos(theta)**64 - 1.24633461673468e+31*cos(theta)**62 + 1.35449354037085e+31*cos(theta)**60 - 1.28964688889533e+31*cos(theta)**58 + 1.0799322732239e+31*cos(theta)**56 - 7.97647818112616e+30*cos(theta)**54 + 5.20727202426621e+30*cos(theta)**52 - 3.00864605846492e+30*cos(theta)**50 + 1.53951187202152e+30*cos(theta)**48 - 6.97697626211442e+29*cos(theta)**46 + 2.79890326794125e+29*cos(theta)**44 - 9.92786835947665e+28*cos(theta)**42 + 3.10832533000342e+28*cos(theta)**40 - 8.57014406999881e+27*cos(theta)**38 + 2.07465953209682e+27*cos(theta)**36 - 4.39339665620503e+26*cos(theta)**34 + 8.10222065789291e+25*cos(theta)**32 - 1.29426777659094e+25*cos(theta)**30 + 1.77941366250651e+24*cos(theta)**28 - 2.0895258292248e+23*cos(theta)**26 + 2.07674585473412e+22*cos(theta)**24 - 1.72801283058975e+21*cos(theta)**22 + 1.18800882103045e+20*cos(theta)**20 - 6.64082600752531e+18*cos(theta)**18 + 2.958783864739e+17*cos(theta)**16 - 1.02468705272346e+16*cos(theta)**14 + 267028985675359.0*cos(theta)**12 - 5013915520504.6*cos(theta)**10 + 63844425133.7598*cos(theta)**8 - 503703551.351162*cos(theta)**6 + 2122346.42423242*cos(theta)**4 - 3569.96875396539*cos(theta)**2 + 0.999991247609352

#@torch.jit.script
def Yl84_m1(theta, phi):
    return 0.0613768099421411*(1.0 - cos(theta)**2)**0.5*(9.98706955938929e+25*cos(theta)**83 - 2.03508968326957e+27*cos(theta)**81 + 1.99808805266466e+28*cos(theta)**79 - 1.25891805526786e+29*cos(theta)**77 + 5.71986681632571e+29*cos(theta)**75 - 1.99655728494388e+30*cos(theta)**73 + 5.57001331723197e+30*cos(theta)**71 - 1.27571272749506e+31*cos(theta)**69 + 2.44511606103221e+31*cos(theta)**67 - 3.97803650547624e+31*cos(theta)**65 + 5.55323216871851e+31*cos(theta)**63 - 6.70715054143923e+31*cos(theta)**61 + 7.05407212116885e+31*cos(theta)**59 - 6.4924784288972e+31*cos(theta)**57 + 5.24923787868285e+31*cos(theta)**55 - 3.73866582726332e+31*cos(theta)**53 + 2.35031090783251e+31*cos(theta)**51 - 1.30572828212917e+31*cos(theta)**49 + 6.41410384203803e+30*cos(theta)**47 - 2.78571565015794e+30*cos(theta)**45 + 1.068937400642e+30*cos(theta)**43 - 3.61923686831543e+29*cos(theta)**41 + 1.07919062982497e+29*cos(theta)**39 - 2.82672413114281e+28*cos(theta)**37 + 6.48277641646387e+27*cos(theta)**35 - 1.29655528329277e+27*cos(theta)**33 + 2.25043126094209e+26*cos(theta)**31 - 3.37021106711135e+25*cos(theta)**29 + 4.32460712151456e+24*cos(theta)**27 - 4.71555482961047e+23*cos(theta)**25 + 4.32619709138575e+22*cos(theta)**23 - 3.29975237901898e+21*cos(theta)**21 + 2.06234523688686e+20*cos(theta)**19 - 1.03754349958121e+19*cos(theta)**17 + 4.10908316665826e+17*cos(theta)**15 - 1.24517671716917e+16*cos(theta)**13 + 278132256412358.0*cos(theta)**11 - 4351998322241.73*cos(theta)**9 + 44332750311.4607*cos(theta)**7 - 262323966.340004*cos(theta)**5 + 736865.073988776*cos(theta)**3 - 619.73513371638*cos(theta))*cos(phi)

#@torch.jit.script
def Yl84_m2(theta, phi):
    return 0.000726467249768708*(1.0 - cos(theta)**2)*(8.28926773429311e+27*cos(theta)**82 - 1.64842264344835e+29*cos(theta)**80 + 1.57848956160508e+30*cos(theta)**78 - 9.69366902556251e+30*cos(theta)**76 + 4.28990011224428e+31*cos(theta)**74 - 1.45748681800903e+32*cos(theta)**72 + 3.9547094552347e+32*cos(theta)**70 - 8.80241781971594e+32*cos(theta)**68 + 1.63822776089158e+33*cos(theta)**66 - 2.58572372855955e+33*cos(theta)**64 + 3.49853626629266e+33*cos(theta)**62 - 4.09136183027793e+33*cos(theta)**60 + 4.16190255148962e+33*cos(theta)**58 - 3.70071270447141e+33*cos(theta)**56 + 2.88708083327557e+33*cos(theta)**54 - 1.98149288844956e+33*cos(theta)**52 + 1.19865856299458e+33*cos(theta)**50 - 6.39806858243294e+32*cos(theta)**48 + 3.01462880575788e+32*cos(theta)**46 - 1.25357204257107e+32*cos(theta)**44 + 4.5964308227606e+31*cos(theta)**42 - 1.48388711600933e+31*cos(theta)**40 + 4.20884345631737e+30*cos(theta)**38 - 1.04588792852284e+30*cos(theta)**36 + 2.26897174576236e+29*cos(theta)**34 - 4.27863243486616e+28*cos(theta)**32 + 6.97633690892049e+27*cos(theta)**30 - 9.77361209462291e+26*cos(theta)**28 + 1.16764392280893e+26*cos(theta)**26 - 1.17888870740262e+25*cos(theta)**24 + 9.95025331018724e+23*cos(theta)**22 - 6.92947999593986e+22*cos(theta)**20 + 3.91845595008504e+21*cos(theta)**18 - 1.76382394928806e+20*cos(theta)**16 + 6.16362474998739e+18*cos(theta)**14 - 1.61872973231992e+17*cos(theta)**12 + 3.05945482053593e+15*cos(theta)**10 - 39167984900175.5*cos(theta)**8 + 310329252180.225*cos(theta)**6 - 1311619831.70002*cos(theta)**4 + 2210595.22196633*cos(theta)**2 - 619.73513371638)*cos(2*phi)

#@torch.jit.script
def Yl84_m3(theta, phi):
    return 8.60101069965504e-6*(1.0 - cos(theta)**2)**1.5*(6.79719954212035e+29*cos(theta)**81 - 1.31873811475868e+31*cos(theta)**79 + 1.23122185805197e+32*cos(theta)**77 - 7.36718845942751e+32*cos(theta)**75 + 3.17452608306077e+33*cos(theta)**73 - 1.0493905089665e+34*cos(theta)**71 + 2.76829661866429e+34*cos(theta)**69 - 5.98564411740684e+34*cos(theta)**67 + 1.08123032218844e+35*cos(theta)**65 - 1.65486318627811e+35*cos(theta)**63 + 2.16909248510145e+35*cos(theta)**61 - 2.45481709816676e+35*cos(theta)**59 + 2.41390347986398e+35*cos(theta)**57 - 2.07239911450399e+35*cos(theta)**55 + 1.5590236499688e+35*cos(theta)**53 - 1.03037630199377e+35*cos(theta)**51 + 5.99329281497289e+34*cos(theta)**49 - 3.07107291956781e+34*cos(theta)**47 + 1.38672925064862e+34*cos(theta)**45 - 5.51571698731272e+33*cos(theta)**43 + 1.93050094555945e+33*cos(theta)**41 - 5.93554846403731e+32*cos(theta)**39 + 1.5993605134006e+32*cos(theta)**37 - 3.76519654268222e+31*cos(theta)**35 + 7.71450393559201e+30*cos(theta)**33 - 1.36916237915717e+30*cos(theta)**31 + 2.09290107267615e+29*cos(theta)**29 - 2.73661138649441e+28*cos(theta)**27 + 3.03587419930322e+27*cos(theta)**25 - 2.82933289776628e+26*cos(theta)**23 + 2.18905572824119e+25*cos(theta)**21 - 1.38589599918797e+24*cos(theta)**19 + 7.05322071015307e+22*cos(theta)**17 - 2.82211831886089e+21*cos(theta)**15 + 8.62907464998235e+19*cos(theta)**13 - 1.94247567878391e+18*cos(theta)**11 + 3.05945482053593e+16*cos(theta)**9 - 313343879201404.0*cos(theta)**7 + 1861975513081.35*cos(theta)**5 - 5246479326.80008*cos(theta)**3 + 4421190.44393265*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl84_m4(theta, phi):
    return 1.01874535697151e-7*(1.0 - cos(theta)**2)**2*(5.50573162911748e+31*cos(theta)**80 - 1.04180311065936e+33*cos(theta)**78 + 9.48040830700014e+33*cos(theta)**76 - 5.52539134457063e+34*cos(theta)**74 + 2.31740404063436e+35*cos(theta)**72 - 7.45067261366217e+35*cos(theta)**70 + 1.91012466687836e+36*cos(theta)**68 - 4.01038155866258e+36*cos(theta)**66 + 7.02799709422487e+36*cos(theta)**64 - 1.04256380735521e+37*cos(theta)**62 + 1.32314641591188e+37*cos(theta)**60 - 1.44834208791839e+37*cos(theta)**58 + 1.37592498352247e+37*cos(theta)**56 - 1.13981951297719e+37*cos(theta)**54 + 8.26282534483467e+36*cos(theta)**52 - 5.25491914016823e+36*cos(theta)**50 + 2.93671347933672e+36*cos(theta)**48 - 1.44340427219687e+36*cos(theta)**46 + 6.2402816279188e+35*cos(theta)**44 - 2.37175830454447e+35*cos(theta)**42 + 7.91505387679376e+34*cos(theta)**40 - 2.31486390097455e+34*cos(theta)**38 + 5.91763389958222e+33*cos(theta)**36 - 1.31781878993878e+33*cos(theta)**34 + 2.54578629874536e+32*cos(theta)**32 - 4.24440337538723e+31*cos(theta)**30 + 6.06941311076083e+30*cos(theta)**28 - 7.38885074353492e+29*cos(theta)**26 + 7.58968549825806e+28*cos(theta)**24 - 6.50746566486245e+27*cos(theta)**22 + 4.5970170293065e+26*cos(theta)**20 - 2.63320239845715e+25*cos(theta)**18 + 1.19904752072602e+24*cos(theta)**16 - 4.23317747829134e+22*cos(theta)**14 + 1.12177970449771e+21*cos(theta)**12 - 2.1367232466623e+19*cos(theta)**10 + 2.75350933848234e+17*cos(theta)**8 - 2.19340715440983e+15*cos(theta)**6 + 9309877565406.75*cos(theta)**4 - 15739437980.4002*cos(theta)**2 + 4421190.44393265)*cos(4*phi)

#@torch.jit.script
def Yl84_m5(theta, phi):
    return 1.20732903641816e-9*(1.0 - cos(theta)**2)**2.5*(4.40458530329399e+33*cos(theta)**79 - 8.12606426314298e+34*cos(theta)**77 + 7.20511031332011e+35*cos(theta)**75 - 4.08878959498227e+36*cos(theta)**73 + 1.66853090925674e+37*cos(theta)**71 - 5.21547082956352e+37*cos(theta)**69 + 1.29888477347728e+38*cos(theta)**67 - 2.6468518287173e+38*cos(theta)**65 + 4.49791814030392e+38*cos(theta)**63 - 6.46389560560232e+38*cos(theta)**61 + 7.9388784954713e+38*cos(theta)**59 - 8.40038410992665e+38*cos(theta)**57 + 7.70517990772582e+38*cos(theta)**55 - 6.15502537007684e+38*cos(theta)**53 + 4.29666917931403e+38*cos(theta)**51 - 2.62745957008412e+38*cos(theta)**49 + 1.40962247008162e+38*cos(theta)**47 - 6.63965965210561e+37*cos(theta)**45 + 2.74572391628427e+37*cos(theta)**43 - 9.96138487908678e+36*cos(theta)**41 + 3.1660215507175e+36*cos(theta)**39 - 8.7964828237033e+35*cos(theta)**37 + 2.1303482038496e+35*cos(theta)**35 - 4.48058388579184e+34*cos(theta)**33 + 8.14651615598516e+33*cos(theta)**31 - 1.27332101261617e+33*cos(theta)**29 + 1.69943567101303e+32*cos(theta)**27 - 1.92110119331908e+31*cos(theta)**25 + 1.82152451958193e+30*cos(theta)**23 - 1.43164244626974e+29*cos(theta)**21 + 9.19403405861301e+27*cos(theta)**19 - 4.73976431722286e+26*cos(theta)**17 + 1.91847603316164e+25*cos(theta)**15 - 5.92644846960788e+23*cos(theta)**13 + 1.34613564539725e+22*cos(theta)**11 - 2.1367232466623e+20*cos(theta)**9 + 2.20280747078587e+18*cos(theta)**7 - 1.3160442926459e+16*cos(theta)**5 + 37239510261627.0*cos(theta)**3 - 31478875960.8005*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl84_m6(theta, phi):
    return 1.43182798105761e-11*(1.0 - cos(theta)**2)**3*(3.47962238960225e+35*cos(theta)**78 - 6.25706948262009e+36*cos(theta)**76 + 5.40383273499008e+37*cos(theta)**74 - 2.98481640433706e+38*cos(theta)**72 + 1.18465694557229e+39*cos(theta)**70 - 3.59867487239883e+39*cos(theta)**68 + 8.7025279822978e+39*cos(theta)**66 - 1.72045368866625e+40*cos(theta)**64 + 2.83368842839147e+40*cos(theta)**62 - 3.94297631941741e+40*cos(theta)**60 + 4.68393831232807e+40*cos(theta)**58 - 4.78821894265819e+40*cos(theta)**56 + 4.2378489492492e+40*cos(theta)**54 - 3.26216344614073e+40*cos(theta)**52 + 2.19130128145015e+40*cos(theta)**50 - 1.28745518934122e+40*cos(theta)**48 + 6.62522560938364e+39*cos(theta)**46 - 2.98784684344752e+39*cos(theta)**44 + 1.18066128400224e+39*cos(theta)**42 - 4.08416780042558e+38*cos(theta)**40 + 1.23474840477983e+38*cos(theta)**38 - 3.25469864477022e+37*cos(theta)**36 + 7.45621871347359e+36*cos(theta)**34 - 1.47859268231131e+36*cos(theta)**32 + 2.5254200083554e+35*cos(theta)**30 - 3.69263093658689e+34*cos(theta)**28 + 4.58847631173519e+33*cos(theta)**26 - 4.8027529832977e+32*cos(theta)**24 + 4.18950639503845e+31*cos(theta)**22 - 3.00644913716645e+30*cos(theta)**20 + 1.74686647113647e+29*cos(theta)**18 - 8.05759933927887e+27*cos(theta)**16 + 2.87771404974245e+26*cos(theta)**14 - 7.70438301049024e+24*cos(theta)**12 + 1.48074920993697e+23*cos(theta)**10 - 1.92305092199607e+21*cos(theta)**8 + 1.54196522955011e+19*cos(theta)**6 - 6.58022146322949e+16*cos(theta)**4 + 111718530784881.0*cos(theta)**2 - 31478875960.8005)*cos(6*phi)

#@torch.jit.script
def Yl84_m7(theta, phi):
    return 1.6995065695896e-13*(1.0 - cos(theta)**2)**3.5*(2.71410546388975e+37*cos(theta)**77 - 4.75537280679127e+38*cos(theta)**75 + 3.99883622389266e+39*cos(theta)**73 - 2.14906781112268e+40*cos(theta)**71 + 8.292598619006e+40*cos(theta)**69 - 2.4470989132312e+41*cos(theta)**67 + 5.74366846831655e+41*cos(theta)**65 - 1.1010903607464e+42*cos(theta)**63 + 1.75688682560271e+42*cos(theta)**61 - 2.36578579165045e+42*cos(theta)**59 + 2.71668422115028e+42*cos(theta)**57 - 2.68140260788859e+42*cos(theta)**55 + 2.28843843259457e+42*cos(theta)**53 - 1.69632499199318e+42*cos(theta)**51 + 1.09565064072508e+42*cos(theta)**49 - 6.17978490883784e+41*cos(theta)**47 + 3.04760378031647e+41*cos(theta)**45 - 1.31465261111691e+41*cos(theta)**43 + 4.9587773928094e+40*cos(theta)**41 - 1.63366712017023e+40*cos(theta)**39 + 4.69204393816334e+39*cos(theta)**37 - 1.17169151211728e+39*cos(theta)**35 + 2.53511436258102e+38*cos(theta)**33 - 4.73149658339618e+37*cos(theta)**31 + 7.5762600250662e+36*cos(theta)**29 - 1.03393666224433e+36*cos(theta)**27 + 1.19300384105115e+35*cos(theta)**25 - 1.15266071599145e+34*cos(theta)**23 + 9.21691406908458e+32*cos(theta)**21 - 6.01289827433291e+31*cos(theta)**19 + 3.14435964804565e+30*cos(theta)**17 - 1.28921589428462e+29*cos(theta)**15 + 4.02879966963943e+27*cos(theta)**13 - 9.24525961258829e+25*cos(theta)**11 + 1.48074920993697e+24*cos(theta)**9 - 1.53844073759685e+22*cos(theta)**7 + 9.25179137730066e+19*cos(theta)**5 - 2.6320885852918e+17*cos(theta)**3 + 223437061569762.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl84_m8(theta, phi):
    return 2.01921968511511e-15*(1.0 - cos(theta)**2)**4*(2.08986120719511e+39*cos(theta)**76 - 3.56652960509345e+40*cos(theta)**74 + 2.91915044344164e+41*cos(theta)**72 - 1.5258381458971e+42*cos(theta)**70 + 5.72189304711414e+42*cos(theta)**68 - 1.63955627186491e+43*cos(theta)**66 + 3.73338450440576e+43*cos(theta)**64 - 6.93686927270231e+43*cos(theta)**62 + 1.07170096361765e+44*cos(theta)**60 - 1.39581361707376e+44*cos(theta)**58 + 1.54851000605566e+44*cos(theta)**56 - 1.47477143433872e+44*cos(theta)**54 + 1.21287236927512e+44*cos(theta)**52 - 8.65125745916521e+43*cos(theta)**50 + 5.36868813955288e+43*cos(theta)**48 - 2.90449890715379e+43*cos(theta)**46 + 1.37142170114241e+43*cos(theta)**44 - 5.65300622780271e+42*cos(theta)**42 + 2.03309873105185e+42*cos(theta)**40 - 6.3713017686639e+41*cos(theta)**38 + 1.73605625712044e+41*cos(theta)**36 - 4.10092029241048e+40*cos(theta)**34 + 8.36587739651737e+39*cos(theta)**32 - 1.46676394085282e+39*cos(theta)**30 + 2.1971154072692e+38*cos(theta)**28 - 2.79162898805969e+37*cos(theta)**26 + 2.98250960262787e+36*cos(theta)**24 - 2.65111964678033e+35*cos(theta)**22 + 1.93555195450776e+34*cos(theta)**20 - 1.14245067212325e+33*cos(theta)**18 + 5.3454114016776e+31*cos(theta)**16 - 1.93382384142693e+30*cos(theta)**14 + 5.23743957053127e+28*cos(theta)**12 - 1.01697855738471e+27*cos(theta)**10 + 1.33267428894327e+25*cos(theta)**8 - 1.0769085163178e+23*cos(theta)**6 + 4.62589568865033e+20*cos(theta)**4 - 7.89626575587539e+17*cos(theta)**2 + 223437061569762.0)*cos(8*phi)

#@torch.jit.script
def Yl84_m9(theta, phi):
    return 2.40179148637518e-17*(1.0 - cos(theta)**2)**4.5*(1.58829451746828e+41*cos(theta)**75 - 2.63923190776915e+42*cos(theta)**73 + 2.10178831927798e+43*cos(theta)**71 - 1.06808670212797e+44*cos(theta)**69 + 3.89088727203761e+44*cos(theta)**67 - 1.08210713943084e+45*cos(theta)**65 + 2.38936608281968e+45*cos(theta)**63 - 4.30085894907543e+45*cos(theta)**61 + 6.43020578170592e+45*cos(theta)**59 - 8.09571897902783e+45*cos(theta)**57 + 8.67165603391169e+45*cos(theta)**55 - 7.9637657454291e+45*cos(theta)**53 + 6.30693632023064e+45*cos(theta)**51 - 4.3256287295826e+45*cos(theta)**49 + 2.57697030698538e+45*cos(theta)**47 - 1.33606949729074e+45*cos(theta)**45 + 6.03425548502662e+44*cos(theta)**43 - 2.37426261567714e+44*cos(theta)**41 + 8.13239492420741e+43*cos(theta)**39 - 2.42109467209228e+43*cos(theta)**37 + 6.24980252563357e+42*cos(theta)**35 - 1.39431289941956e+42*cos(theta)**33 + 2.67708076688556e+41*cos(theta)**31 - 4.40029182255845e+40*cos(theta)**29 + 6.15192314035375e+39*cos(theta)**27 - 7.25823536895519e+38*cos(theta)**25 + 7.15802304630689e+37*cos(theta)**23 - 5.83246322291672e+36*cos(theta)**21 + 3.87110390901553e+35*cos(theta)**19 - 2.05641120982185e+34*cos(theta)**17 + 8.55265824268416e+32*cos(theta)**15 - 2.7073533779977e+31*cos(theta)**13 + 6.28492748463752e+29*cos(theta)**11 - 1.01697855738471e+28*cos(theta)**9 + 1.06613943115462e+26*cos(theta)**7 - 6.46145109790678e+23*cos(theta)**5 + 1.85035827546013e+21*cos(theta)**3 - 1.57925315117508e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl84_m10(theta, phi):
    return 2.86049203326541e-19*(1.0 - cos(theta)**2)**5*(1.19122088810121e+43*cos(theta)**74 - 1.92663929267148e+44*cos(theta)**72 + 1.49226970668737e+45*cos(theta)**70 - 7.36979824468301e+45*cos(theta)**68 + 2.6068944722652e+46*cos(theta)**66 - 7.03369640630045e+46*cos(theta)**64 + 1.5053006321764e+47*cos(theta)**62 - 2.62352395893601e+47*cos(theta)**60 + 3.79382141120649e+47*cos(theta)**58 - 4.61455981804586e+47*cos(theta)**56 + 4.76941081865143e+47*cos(theta)**54 - 4.22079584507742e+47*cos(theta)**52 + 3.21653752331762e+47*cos(theta)**50 - 2.11955807749548e+47*cos(theta)**48 + 1.21117604428313e+47*cos(theta)**46 - 6.01231273780834e+46*cos(theta)**44 + 2.59472985856145e+46*cos(theta)**42 - 9.73447672427627e+45*cos(theta)**40 + 3.17163402044089e+45*cos(theta)**38 - 8.95805028674145e+44*cos(theta)**36 + 2.18743088397175e+44*cos(theta)**34 - 4.60123256808455e+43*cos(theta)**32 + 8.29895037734523e+42*cos(theta)**30 - 1.27608462854195e+42*cos(theta)**28 + 1.66101924789551e+41*cos(theta)**26 - 1.8145588422388e+40*cos(theta)**24 + 1.64634530065058e+39*cos(theta)**22 - 1.22481727681251e+38*cos(theta)**20 + 7.3550974271295e+36*cos(theta)**18 - 3.49589905669715e+35*cos(theta)**16 + 1.28289873640262e+34*cos(theta)**14 - 3.51955939139701e+32*cos(theta)**12 + 6.91342023310127e+30*cos(theta)**10 - 9.1528070164624e+28*cos(theta)**8 + 7.46297601808233e+26*cos(theta)**6 - 3.23072554895339e+24*cos(theta)**4 + 5.5510748263804e+21*cos(theta)**2 - 1.57925315117508e+18)*cos(10*phi)

#@torch.jit.script
def Yl84_m11(theta, phi):
    return 3.41163907587431e-21*(1.0 - cos(theta)**2)**5.5*(8.81503457194898e+44*cos(theta)**73 - 1.38718029072347e+46*cos(theta)**71 + 1.04458879468116e+47*cos(theta)**69 - 5.01146280638445e+47*cos(theta)**67 + 1.72055035169503e+48*cos(theta)**65 - 4.50156570003229e+48*cos(theta)**63 + 9.33286391949369e+48*cos(theta)**61 - 1.57411437536161e+49*cos(theta)**59 + 2.20041641849976e+49*cos(theta)**57 - 2.58415349810568e+49*cos(theta)**55 + 2.57548184207177e+49*cos(theta)**53 - 2.19481383944026e+49*cos(theta)**51 + 1.60826876165881e+49*cos(theta)**49 - 1.01738787719783e+49*cos(theta)**47 + 5.57140980370239e+48*cos(theta)**45 - 2.64541760463567e+48*cos(theta)**43 + 1.08978654059581e+48*cos(theta)**41 - 3.89379068971051e+47*cos(theta)**39 + 1.20522092776754e+47*cos(theta)**37 - 3.22489810322692e+46*cos(theta)**35 + 7.43726500550394e+45*cos(theta)**33 - 1.47239442178706e+45*cos(theta)**31 + 2.48968511320357e+44*cos(theta)**29 - 3.57303695991746e+43*cos(theta)**27 + 4.31865004452833e+42*cos(theta)**25 - 4.35494122137311e+41*cos(theta)**23 + 3.62195966143129e+40*cos(theta)**21 - 2.44963455362502e+39*cos(theta)**19 + 1.32391753688331e+38*cos(theta)**17 - 5.59343849071544e+36*cos(theta)**15 + 1.79605823096367e+35*cos(theta)**13 - 4.22347126967641e+33*cos(theta)**11 + 6.91342023310127e+31*cos(theta)**9 - 7.32224561316992e+29*cos(theta)**7 + 4.4777856108494e+27*cos(theta)**5 - 1.29229021958136e+25*cos(theta)**3 + 1.11021496527608e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl84_m12(theta, phi):
    return 4.0753605157556e-23*(1.0 - cos(theta)**2)**6*(6.43497523752275e+46*cos(theta)**72 - 9.84898006413662e+47*cos(theta)**70 + 7.20766268329998e+48*cos(theta)**68 - 3.35768008027758e+49*cos(theta)**66 + 1.11835772860177e+50*cos(theta)**64 - 2.83598639102034e+50*cos(theta)**62 + 5.69304699089115e+50*cos(theta)**60 - 9.28727481463349e+50*cos(theta)**58 + 1.25423735854487e+51*cos(theta)**56 - 1.42128442395813e+51*cos(theta)**54 + 1.36500537629804e+51*cos(theta)**52 - 1.11935505811453e+51*cos(theta)**50 + 7.88051693212818e+50*cos(theta)**48 - 4.78172302282979e+50*cos(theta)**46 + 2.50713441166608e+50*cos(theta)**44 - 1.13752956999334e+50*cos(theta)**42 + 4.46812481644281e+49*cos(theta)**40 - 1.5185783689871e+49*cos(theta)**38 + 4.45931743273989e+48*cos(theta)**36 - 1.12871433612942e+48*cos(theta)**34 + 2.4542974518163e+47*cos(theta)**32 - 4.56442270753988e+46*cos(theta)**30 + 7.22008682829035e+45*cos(theta)**28 - 9.64719979177714e+44*cos(theta)**26 + 1.07966251113208e+44*cos(theta)**24 - 1.00163648091582e+43*cos(theta)**22 + 7.6061152890057e+41*cos(theta)**20 - 4.65430565188755e+40*cos(theta)**18 + 2.25065981270163e+39*cos(theta)**16 - 8.39015773607316e+37*cos(theta)**14 + 2.33487570025278e+36*cos(theta)**12 - 4.64581839664405e+34*cos(theta)**10 + 6.22207820979114e+32*cos(theta)**8 - 5.12557192921895e+30*cos(theta)**6 + 2.2388928054247e+28*cos(theta)**4 - 3.87687065874407e+25*cos(theta)**2 + 1.11021496527608e+22)*cos(12*phi)

#@torch.jit.script
def Yl84_m13(theta, phi):
    return 4.87656388599221e-25*(1.0 - cos(theta)**2)**6.5*(4.63318217101638e+48*cos(theta)**71 - 6.89428604489563e+49*cos(theta)**69 + 4.90121062464399e+50*cos(theta)**67 - 2.2160688529832e+51*cos(theta)**65 + 7.15748946305133e+51*cos(theta)**63 - 1.75831156243261e+52*cos(theta)**61 + 3.41582819453469e+52*cos(theta)**59 - 5.38661939248742e+52*cos(theta)**57 + 7.02372920785125e+52*cos(theta)**55 - 7.67493588937388e+52*cos(theta)**53 + 7.0980279567498e+52*cos(theta)**51 - 5.59677529057267e+52*cos(theta)**49 + 3.78264812742153e+52*cos(theta)**47 - 2.1995925905017e+52*cos(theta)**45 + 1.10313914113307e+52*cos(theta)**43 - 4.77762419397202e+51*cos(theta)**41 + 1.78724992657712e+51*cos(theta)**39 - 5.77059780215097e+50*cos(theta)**37 + 1.60535427578636e+50*cos(theta)**35 - 3.83762874284004e+49*cos(theta)**33 + 7.85375184581217e+48*cos(theta)**31 - 1.36932681226196e+48*cos(theta)**29 + 2.0216243119213e+47*cos(theta)**27 - 2.50827194586206e+46*cos(theta)**25 + 2.591190026717e+45*cos(theta)**23 - 2.20360025801479e+44*cos(theta)**21 + 1.52122305780114e+43*cos(theta)**19 - 8.37775017339758e+41*cos(theta)**17 + 3.6010557003226e+40*cos(theta)**15 - 1.17462208305024e+39*cos(theta)**13 + 2.80185084030333e+37*cos(theta)**11 - 4.64581839664405e+35*cos(theta)**9 + 4.97766256783291e+33*cos(theta)**7 - 3.07534315753137e+31*cos(theta)**5 + 8.9555712216988e+28*cos(theta)**3 - 7.75374131748814e+25*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl84_m14(theta, phi):
    return 5.84617357952503e-27*(1.0 - cos(theta)**2)**7*(3.28955934142163e+50*cos(theta)**70 - 4.75705737097799e+51*cos(theta)**68 + 3.28381111851147e+52*cos(theta)**66 - 1.44044475443908e+53*cos(theta)**64 + 4.50921836172234e+53*cos(theta)**62 - 1.07257005308389e+54*cos(theta)**60 + 2.01533863477547e+54*cos(theta)**58 - 3.07037305371783e+54*cos(theta)**56 + 3.86305106431819e+54*cos(theta)**54 - 4.06771602136816e+54*cos(theta)**52 + 3.6199942579424e+54*cos(theta)**50 - 2.74241989238061e+54*cos(theta)**48 + 1.77784461988812e+54*cos(theta)**46 - 9.89816665725767e+53*cos(theta)**44 + 4.74349830687222e+53*cos(theta)**42 - 1.95882591952853e+53*cos(theta)**40 + 6.97027471365078e+52*cos(theta)**38 - 2.13512118679586e+52*cos(theta)**36 + 5.61873996525226e+51*cos(theta)**34 - 1.26641748513721e+51*cos(theta)**32 + 2.43466307220177e+50*cos(theta)**30 - 3.97104775555969e+49*cos(theta)**28 + 5.45838564218751e+48*cos(theta)**26 - 6.27067986465514e+47*cos(theta)**24 + 5.9597370614491e+46*cos(theta)**22 - 4.62756054183107e+45*cos(theta)**20 + 2.89032380982217e+44*cos(theta)**18 - 1.42421752947759e+43*cos(theta)**16 + 5.4015835504839e+41*cos(theta)**14 - 1.52700870796532e+40*cos(theta)**12 + 3.08203592433366e+38*cos(theta)**10 - 4.18123655697965e+36*cos(theta)**8 + 3.48436379748304e+34*cos(theta)**6 - 1.53767157876568e+32*cos(theta)**4 + 2.68667136650964e+29*cos(theta)**2 - 7.75374131748814e+25)*cos(14*phi)

#@torch.jit.script
def Yl84_m15(theta, phi):
    return 7.02271572162013e-29*(1.0 - cos(theta)**2)**7.5*(2.30269153899514e+52*cos(theta)**69 - 3.23479901226503e+53*cos(theta)**67 + 2.16731533821757e+54*cos(theta)**65 - 9.21884642841012e+54*cos(theta)**63 + 2.79571538426785e+55*cos(theta)**61 - 6.43542031850336e+55*cos(theta)**59 + 1.16889640816977e+56*cos(theta)**57 - 1.71940891008199e+56*cos(theta)**55 + 2.08604757473182e+56*cos(theta)**53 - 2.11521233111144e+56*cos(theta)**51 + 1.8099971289712e+56*cos(theta)**49 - 1.31636154834269e+56*cos(theta)**47 + 8.17808525148534e+55*cos(theta)**45 - 4.35519332919338e+55*cos(theta)**43 + 1.99226928888633e+55*cos(theta)**41 - 7.83530367811411e+54*cos(theta)**39 + 2.6487043911873e+54*cos(theta)**37 - 7.6864362724651e+53*cos(theta)**35 + 1.91037158818577e+53*cos(theta)**33 - 4.05253595243908e+52*cos(theta)**31 + 7.30398921660531e+51*cos(theta)**29 - 1.11189337155671e+51*cos(theta)**27 + 1.41918026696875e+50*cos(theta)**25 - 1.50496316751723e+49*cos(theta)**23 + 1.3111421535188e+48*cos(theta)**21 - 9.25512108366214e+46*cos(theta)**19 + 5.2025828576799e+45*cos(theta)**17 - 2.27874804716414e+44*cos(theta)**15 + 7.56221697067746e+42*cos(theta)**13 - 1.83241044955838e+41*cos(theta)**11 + 3.08203592433367e+39*cos(theta)**9 - 3.34498924558372e+37*cos(theta)**7 + 2.09061827848982e+35*cos(theta)**5 - 6.15068631506274e+32*cos(theta)**3 + 5.37334273301928e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl84_m16(theta, phi):
    return 8.45435623126083e-31*(1.0 - cos(theta)**2)**8*(1.58885716190665e+54*cos(theta)**68 - 2.16731533821757e+55*cos(theta)**66 + 1.40875496984142e+56*cos(theta)**64 - 5.80787324989838e+56*cos(theta)**62 + 1.70538638440339e+57*cos(theta)**60 - 3.79689798791698e+57*cos(theta)**58 + 6.66270952656769e+57*cos(theta)**56 - 9.45674900545092e+57*cos(theta)**54 + 1.10560521460787e+58*cos(theta)**52 - 1.07875828886684e+58*cos(theta)**50 + 8.86898593195888e+57*cos(theta)**48 - 6.18689927721065e+57*cos(theta)**46 + 3.6801383631684e+57*cos(theta)**44 - 1.87273313155315e+57*cos(theta)**42 + 8.16830408443396e+56*cos(theta)**40 - 3.0557684344645e+56*cos(theta)**38 + 9.800206247393e+55*cos(theta)**36 - 2.69025269536278e+55*cos(theta)**34 + 6.30422624101304e+54*cos(theta)**32 - 1.25628614525611e+54*cos(theta)**30 + 2.11815687281554e+53*cos(theta)**28 - 3.00211210320313e+52*cos(theta)**26 + 3.54795066742188e+51*cos(theta)**24 - 3.46141528528964e+50*cos(theta)**22 + 2.75339852238949e+49*cos(theta)**20 - 1.75847300589581e+48*cos(theta)**18 + 8.84439085805583e+46*cos(theta)**16 - 3.41812207074621e+45*cos(theta)**14 + 9.8308820618807e+43*cos(theta)**12 - 2.01565149451422e+42*cos(theta)**10 + 2.7738323319003e+40*cos(theta)**8 - 2.3414924719086e+38*cos(theta)**6 + 1.04530913924491e+36*cos(theta)**4 - 1.84520589451882e+33*cos(theta)**2 + 5.37334273301928e+29)*cos(16*phi)

#@torch.jit.script
def Yl84_m17(theta, phi):
    return 1.02015320892099e-32*(1.0 - cos(theta)**2)**8.5*(1.08042287009652e+56*cos(theta)**67 - 1.4304281232236e+57*cos(theta)**65 + 9.0160318069851e+57*cos(theta)**63 - 3.60088141493699e+58*cos(theta)**61 + 1.02323183064203e+59*cos(theta)**59 - 2.20220083299185e+59*cos(theta)**57 + 3.73111733487791e+59*cos(theta)**55 - 5.1066444629435e+59*cos(theta)**53 + 5.7491471159609e+59*cos(theta)**51 - 5.39379144433418e+59*cos(theta)**49 + 4.25711324734026e+59*cos(theta)**47 - 2.8459736675169e+59*cos(theta)**45 + 1.6192608797941e+59*cos(theta)**43 - 7.86547915252324e+58*cos(theta)**41 + 3.26732163377358e+58*cos(theta)**39 - 1.16119200509651e+58*cos(theta)**37 + 3.52807424906148e+57*cos(theta)**35 - 9.14685916423347e+56*cos(theta)**33 + 2.01735239712417e+56*cos(theta)**31 - 3.76885843576834e+55*cos(theta)**29 + 5.93083924388351e+54*cos(theta)**27 - 7.80549146832814e+53*cos(theta)**25 + 8.51508160181251e+52*cos(theta)**23 - 7.61511362763721e+51*cos(theta)**21 + 5.50679704477897e+50*cos(theta)**19 - 3.16525141061245e+49*cos(theta)**17 + 1.41510253728893e+48*cos(theta)**15 - 4.7853708990447e+46*cos(theta)**13 + 1.17970584742568e+45*cos(theta)**11 - 2.01565149451422e+43*cos(theta)**9 + 2.21906586552024e+41*cos(theta)**7 - 1.40489548314516e+39*cos(theta)**5 + 4.18123655697965e+36*cos(theta)**3 - 3.69041178903764e+33*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl84_m18(theta, phi):
    return 1.23403623695234e-34*(1.0 - cos(theta)**2)**9*(7.23883322964669e+57*cos(theta)**66 - 9.29778280095338e+58*cos(theta)**64 + 5.68010003840061e+59*cos(theta)**62 - 2.19653766311157e+60*cos(theta)**60 + 6.037067800788e+60*cos(theta)**58 - 1.25525447480535e+61*cos(theta)**56 + 2.05211453418285e+61*cos(theta)**54 - 2.70652156536005e+61*cos(theta)**52 + 2.93206502914006e+61*cos(theta)**50 - 2.64295780772375e+61*cos(theta)**48 + 2.00084322624992e+61*cos(theta)**46 - 1.2806881503826e+61*cos(theta)**44 + 6.96282178311462e+60*cos(theta)**42 - 3.22484645253453e+60*cos(theta)**40 + 1.2742554371717e+60*cos(theta)**38 - 4.29641041885709e+59*cos(theta)**36 + 1.23482598717152e+59*cos(theta)**34 - 3.01846352419704e+58*cos(theta)**32 + 6.25379243108494e+57*cos(theta)**30 - 1.09296894637282e+57*cos(theta)**28 + 1.60132659584855e+56*cos(theta)**26 - 1.95137286708203e+55*cos(theta)**24 + 1.95846876841688e+54*cos(theta)**22 - 1.59917386180381e+53*cos(theta)**20 + 1.046291438508e+52*cos(theta)**18 - 5.38092739804117e+50*cos(theta)**16 + 2.1226538059334e+49*cos(theta)**14 - 6.22098216875811e+47*cos(theta)**12 + 1.29767643216825e+46*cos(theta)**10 - 1.8140863450628e+44*cos(theta)**8 + 1.55334610586417e+42*cos(theta)**6 - 7.02447741572581e+39*cos(theta)**4 + 1.25437096709389e+37*cos(theta)**2 - 3.69041178903764e+33)*cos(18*phi)

#@torch.jit.script
def Yl84_m19(theta, phi):
    return 1.4967088706658e-36*(1.0 - cos(theta)**2)**9.5*(4.77762993156681e+59*cos(theta)**65 - 5.95058099261016e+60*cos(theta)**63 + 3.52166202380838e+61*cos(theta)**61 - 1.31792259786694e+62*cos(theta)**59 + 3.50149932445704e+62*cos(theta)**57 - 7.02942505890998e+62*cos(theta)**55 + 1.10814184845874e+63*cos(theta)**53 - 1.40739121398723e+63*cos(theta)**51 + 1.46603251457003e+63*cos(theta)**49 - 1.2686197477074e+63*cos(theta)**47 + 9.20387884074965e+62*cos(theta)**45 - 5.63502786168346e+62*cos(theta)**43 + 2.92438514890814e+62*cos(theta)**41 - 1.28993858101381e+62*cos(theta)**39 + 4.84217066125245e+61*cos(theta)**37 - 1.54670775078855e+61*cos(theta)**35 + 4.19840835638316e+60*cos(theta)**33 - 9.65908327743054e+59*cos(theta)**31 + 1.87613772932548e+59*cos(theta)**29 - 3.06031304984389e+58*cos(theta)**27 + 4.16344914920623e+57*cos(theta)**25 - 4.68329488099688e+56*cos(theta)**23 + 4.30863129051713e+55*cos(theta)**21 - 3.19834772360763e+54*cos(theta)**19 + 1.88332458931441e+53*cos(theta)**17 - 8.60948383686587e+51*cos(theta)**15 + 2.97171532830676e+50*cos(theta)**13 - 7.46517860250973e+48*cos(theta)**11 + 1.29767643216825e+47*cos(theta)**9 - 1.45126907605024e+45*cos(theta)**7 + 9.320076635185e+42*cos(theta)**5 - 2.80979096629032e+40*cos(theta)**3 + 2.50874193418779e+37*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl84_m20(theta, phi):
    return 1.82038808672397e-38*(1.0 - cos(theta)**2)**10*(3.10545945551843e+61*cos(theta)**64 - 3.7488660253444e+62*cos(theta)**62 + 2.14821383452311e+63*cos(theta)**60 - 7.77574332741494e+63*cos(theta)**58 + 1.99585461494051e+64*cos(theta)**56 - 3.86618378240049e+64*cos(theta)**54 + 5.87315179683132e+64*cos(theta)**52 - 7.17769519133486e+64*cos(theta)**50 + 7.18355932139314e+64*cos(theta)**48 - 5.96251281422477e+64*cos(theta)**46 + 4.14174547833734e+64*cos(theta)**44 - 2.42306198052389e+64*cos(theta)**42 + 1.19899791105234e+64*cos(theta)**40 - 5.03076046595386e+63*cos(theta)**38 + 1.79160314466341e+63*cos(theta)**36 - 5.41347712775993e+62*cos(theta)**34 + 1.38547475760644e+62*cos(theta)**32 - 2.99431581600347e+61*cos(theta)**30 + 5.44079941504389e+60*cos(theta)**28 - 8.26284523457851e+59*cos(theta)**26 + 1.04086228730156e+59*cos(theta)**24 - 1.07715782262928e+58*cos(theta)**22 + 9.04812571008598e+56*cos(theta)**20 - 6.07686067485449e+55*cos(theta)**18 + 3.20165180183449e+54*cos(theta)**16 - 1.29142257552988e+53*cos(theta)**14 + 3.86322992679879e+51*cos(theta)**12 - 8.2116964627607e+49*cos(theta)**10 + 1.16790878895143e+48*cos(theta)**8 - 1.01588835323517e+46*cos(theta)**6 + 4.6600383175925e+43*cos(theta)**4 - 8.42937289887097e+40*cos(theta)**2 + 2.50874193418779e+37)*cos(20*phi)

#@torch.jit.script
def Yl84_m21(theta, phi):
    return 2.2206460832857e-40*(1.0 - cos(theta)**2)**10.5*(1.98749405153179e+63*cos(theta)**63 - 2.32429693571353e+64*cos(theta)**61 + 1.28892830071387e+65*cos(theta)**59 - 4.50993112990067e+65*cos(theta)**57 + 1.11767858436669e+66*cos(theta)**55 - 2.08773924249626e+66*cos(theta)**53 + 3.05403893435228e+66*cos(theta)**51 - 3.58884759566743e+66*cos(theta)**49 + 3.44810847426871e+66*cos(theta)**47 - 2.74275589454339e+66*cos(theta)**45 + 1.82236801046843e+66*cos(theta)**43 - 1.01768603182003e+66*cos(theta)**41 + 4.79599164420935e+65*cos(theta)**39 - 1.91168897706247e+65*cos(theta)**37 + 6.44977132078826e+64*cos(theta)**35 - 1.84058222343838e+64*cos(theta)**33 + 4.43351922434062e+63*cos(theta)**31 - 8.9829474480104e+62*cos(theta)**29 + 1.52342383621229e+62*cos(theta)**27 - 2.14833976099041e+61*cos(theta)**25 + 2.49806948952374e+60*cos(theta)**23 - 2.36974720978442e+59*cos(theta)**21 + 1.80962514201719e+58*cos(theta)**19 - 1.09383492147381e+57*cos(theta)**17 + 5.12264288293519e+55*cos(theta)**15 - 1.80799160574183e+54*cos(theta)**13 + 4.63587591215854e+52*cos(theta)**11 - 8.2116964627607e+50*cos(theta)**9 + 9.34327031161142e+48*cos(theta)**7 - 6.09533011941099e+46*cos(theta)**5 + 1.864015327037e+44*cos(theta)**3 - 1.68587457977419e+41*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl84_m22(theta, phi):
    return 2.71741607884599e-42*(1.0 - cos(theta)**2)**11*(1.25212125246503e+65*cos(theta)**62 - 1.41782113078525e+66*cos(theta)**60 + 7.60467697421181e+66*cos(theta)**58 - 2.57066074404338e+67*cos(theta)**56 + 6.14723221401678e+67*cos(theta)**54 - 1.10650179852302e+68*cos(theta)**52 + 1.55755985651967e+68*cos(theta)**50 - 1.75853532187704e+68*cos(theta)**48 + 1.62061098290629e+68*cos(theta)**46 - 1.23424015254453e+68*cos(theta)**44 + 7.83618244501425e+67*cos(theta)**42 - 4.17251273046213e+67*cos(theta)**40 + 1.87043674124165e+67*cos(theta)**38 - 7.07324921513113e+66*cos(theta)**36 + 2.25741996227589e+66*cos(theta)**34 - 6.07392133734665e+65*cos(theta)**32 + 1.37439095954559e+65*cos(theta)**30 - 2.60505475992302e+64*cos(theta)**28 + 4.11324435777318e+63*cos(theta)**26 - 5.37084940247603e+62*cos(theta)**24 + 5.74555982590459e+61*cos(theta)**22 - 4.97646914054729e+60*cos(theta)**20 + 3.43828776983267e+59*cos(theta)**18 - 1.85951936650547e+58*cos(theta)**16 + 7.68396432440278e+56*cos(theta)**14 - 2.35038908746438e+55*cos(theta)**12 + 5.0994635033744e+53*cos(theta)**10 - 7.39052681648463e+51*cos(theta)**8 + 6.54028921812799e+49*cos(theta)**6 - 3.0476650597055e+47*cos(theta)**4 + 5.592045981111e+44*cos(theta)**2 - 1.68587457977419e+41)*cos(22*phi)

#@torch.jit.script
def Yl84_m23(theta, phi):
    return 3.33632544108866e-44*(1.0 - cos(theta)**2)**11.5*(7.76315176528319e+66*cos(theta)**61 - 8.50692678471152e+67*cos(theta)**59 + 4.41071264504285e+68*cos(theta)**57 - 1.43957001666429e+69*cos(theta)**55 + 3.31950539556906e+69*cos(theta)**53 - 5.7538093523197e+69*cos(theta)**51 + 7.78779928259833e+69*cos(theta)**49 - 8.4409695450098e+69*cos(theta)**47 + 7.45481052136895e+69*cos(theta)**45 - 5.43065667119592e+69*cos(theta)**43 + 3.29119662690598e+69*cos(theta)**41 - 1.66900509218485e+69*cos(theta)**39 + 7.10765961671825e+68*cos(theta)**37 - 2.54636971744721e+68*cos(theta)**35 + 7.67522787173803e+67*cos(theta)**33 - 1.94365482795093e+67*cos(theta)**31 + 4.12317287863677e+66*cos(theta)**29 - 7.29415332778445e+65*cos(theta)**27 + 1.06944353302103e+65*cos(theta)**25 - 1.28900385659425e+64*cos(theta)**23 + 1.26402316169901e+63*cos(theta)**21 - 9.95293828109457e+61*cos(theta)**19 + 6.18891798569881e+60*cos(theta)**17 - 2.97523098640876e+59*cos(theta)**15 + 1.07575500541639e+58*cos(theta)**13 - 2.82046690495726e+56*cos(theta)**11 + 5.0994635033744e+54*cos(theta)**9 - 5.91242145318771e+52*cos(theta)**7 + 3.9241735308768e+50*cos(theta)**5 - 1.2190660238822e+48*cos(theta)**3 + 1.1184091962222e+45*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl84_m24(theta, phi):
    return 4.11047122146606e-46*(1.0 - cos(theta)**2)**12*(4.73552257682275e+68*cos(theta)**60 - 5.0190868029798e+69*cos(theta)**58 + 2.51410620767443e+70*cos(theta)**56 - 7.91763509165361e+70*cos(theta)**54 + 1.7593378596516e+71*cos(theta)**52 - 2.93444276968305e+71*cos(theta)**50 + 3.81602164847318e+71*cos(theta)**48 - 3.96725568615461e+71*cos(theta)**46 + 3.35466473461603e+71*cos(theta)**44 - 2.33518236861425e+71*cos(theta)**42 + 1.34939061703145e+71*cos(theta)**40 - 6.50911985952093e+70*cos(theta)**38 + 2.62983405818575e+70*cos(theta)**36 - 8.91229401106522e+69*cos(theta)**34 + 2.53282519767355e+69*cos(theta)**32 - 6.02532996664787e+68*cos(theta)**30 + 1.19572013480466e+68*cos(theta)**28 - 1.9694213985018e+67*cos(theta)**26 + 2.67360883255257e+66*cos(theta)**24 - 2.96470887016677e+65*cos(theta)**22 + 2.65444863956792e+64*cos(theta)**20 - 1.89105827340797e+63*cos(theta)**18 + 1.0521160575688e+62*cos(theta)**16 - 4.46284647961314e+60*cos(theta)**14 + 1.39848150704131e+59*cos(theta)**12 - 3.10251359545298e+57*cos(theta)**10 + 4.58951715303696e+55*cos(theta)**8 - 4.13869501723139e+53*cos(theta)**6 + 1.9620867654384e+51*cos(theta)**4 - 3.65719807164659e+48*cos(theta)**2 + 1.1184091962222e+45)*cos(24*phi)

#@torch.jit.script
def Yl84_m25(theta, phi):
    return 5.08279668233104e-48*(1.0 - cos(theta)**2)**12.5*(2.84131354609365e+70*cos(theta)**59 - 2.91107034572828e+71*cos(theta)**57 + 1.40789947629768e+72*cos(theta)**55 - 4.27552294949295e+72*cos(theta)**53 + 9.14855687018833e+72*cos(theta)**51 - 1.46722138484152e+73*cos(theta)**49 + 1.83169039126713e+73*cos(theta)**47 - 1.82493761563112e+73*cos(theta)**45 + 1.47605248323105e+73*cos(theta)**43 - 9.80776594817983e+72*cos(theta)**41 + 5.39756246812582e+72*cos(theta)**39 - 2.47346554661795e+72*cos(theta)**37 + 9.46740260946872e+71*cos(theta)**35 - 3.03017996376218e+71*cos(theta)**33 + 8.10504063255536e+70*cos(theta)**31 - 1.80759898999436e+70*cos(theta)**29 + 3.34801637745306e+69*cos(theta)**27 - 5.12049563610468e+68*cos(theta)**25 + 6.41666119812617e+67*cos(theta)**23 - 6.52235951436689e+66*cos(theta)**21 + 5.30889727913584e+65*cos(theta)**19 - 3.40390489213434e+64*cos(theta)**17 + 1.68338569211008e+63*cos(theta)**15 - 6.24798507145839e+61*cos(theta)**13 + 1.67817780844957e+60*cos(theta)**11 - 3.10251359545298e+58*cos(theta)**9 + 3.67161372242957e+56*cos(theta)**7 - 2.48321701033884e+54*cos(theta)**5 + 7.84834706175359e+51*cos(theta)**3 - 7.31439614329319e+48*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl84_m26(theta, phi):
    return 6.30928854160724e-50*(1.0 - cos(theta)**2)**13*(1.67637499219525e+72*cos(theta)**58 - 1.65931009706512e+73*cos(theta)**56 + 7.74344711963723e+73*cos(theta)**54 - 2.26602716323126e+74*cos(theta)**52 + 4.66576400379605e+74*cos(theta)**50 - 7.18938478572347e+74*cos(theta)**48 + 8.60894483895549e+74*cos(theta)**46 - 8.21221927034003e+74*cos(theta)**44 + 6.34702567789352e+74*cos(theta)**42 - 4.02118403875373e+74*cos(theta)**40 + 2.10504936256907e+74*cos(theta)**38 - 9.15182252248642e+73*cos(theta)**36 + 3.31359091331405e+73*cos(theta)**34 - 9.99959388041518e+72*cos(theta)**32 + 2.51256259609216e+72*cos(theta)**30 - 5.24203707098365e+71*cos(theta)**28 + 9.03964421912326e+70*cos(theta)**26 - 1.28012390902617e+70*cos(theta)**24 + 1.47583207556902e+69*cos(theta)**22 - 1.36969549801705e+68*cos(theta)**20 + 1.00869048303581e+67*cos(theta)**18 - 5.78663831662838e+65*cos(theta)**16 + 2.52507853816511e+64*cos(theta)**14 - 8.12238059289591e+62*cos(theta)**12 + 1.84599558929452e+61*cos(theta)**10 - 2.79226223590768e+59*cos(theta)**8 + 2.5701296057007e+57*cos(theta)**6 - 1.24160850516942e+55*cos(theta)**4 + 2.35450411852608e+52*cos(theta)**2 - 7.31439614329319e+48)*cos(26*phi)

#@torch.jit.script
def Yl84_m27(theta, phi):
    return 7.86330105103206e-52*(1.0 - cos(theta)**2)**13.5*(9.72297495473246e+73*cos(theta)**57 - 9.29213654356468e+74*cos(theta)**55 + 4.1814614446041e+75*cos(theta)**53 - 1.17833412488026e+76*cos(theta)**51 + 2.33288200189802e+76*cos(theta)**49 - 3.45090469714727e+76*cos(theta)**47 + 3.96011462591953e+76*cos(theta)**45 - 3.61337647894961e+76*cos(theta)**43 + 2.66575078471528e+76*cos(theta)**41 - 1.60847361550149e+76*cos(theta)**39 + 7.99918757776246e+75*cos(theta)**37 - 3.29465610809511e+75*cos(theta)**35 + 1.12662091052678e+75*cos(theta)**33 - 3.19987004173286e+74*cos(theta)**31 + 7.53768778827649e+73*cos(theta)**29 - 1.46777037987542e+73*cos(theta)**27 + 2.35030749697205e+72*cos(theta)**25 - 3.07229738166281e+71*cos(theta)**23 + 3.24683056625184e+70*cos(theta)**21 - 2.7393909960341e+69*cos(theta)**19 + 1.81564286946446e+68*cos(theta)**17 - 9.25862130660542e+66*cos(theta)**15 + 3.53510995343116e+65*cos(theta)**13 - 9.74685671147509e+63*cos(theta)**11 + 1.84599558929452e+62*cos(theta)**9 - 2.23380978872615e+60*cos(theta)**7 + 1.54207776342042e+58*cos(theta)**5 - 4.96643402067767e+55*cos(theta)**3 + 4.70900823705216e+52*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl84_m28(theta, phi):
    return 9.84143580679611e-54*(1.0 - cos(theta)**2)**14*(5.5420957241975e+75*cos(theta)**56 - 5.11067509896057e+76*cos(theta)**54 + 2.21617456564018e+77*cos(theta)**52 - 6.00950403688931e+77*cos(theta)**50 + 1.14311218093003e+78*cos(theta)**48 - 1.62192520765921e+78*cos(theta)**46 + 1.78205158166379e+78*cos(theta)**44 - 1.55375188594833e+78*cos(theta)**42 + 1.09295782173326e+78*cos(theta)**40 - 6.27304710045582e+77*cos(theta)**38 + 2.95969940377211e+77*cos(theta)**36 - 1.15312963783329e+77*cos(theta)**34 + 3.71784900473836e+76*cos(theta)**32 - 9.91959712937186e+75*cos(theta)**30 + 2.18592945860018e+75*cos(theta)**28 - 3.96298002566364e+74*cos(theta)**26 + 5.87576874243012e+73*cos(theta)**24 - 7.06628397782446e+72*cos(theta)**22 + 6.81834418912886e+71*cos(theta)**20 - 5.20484289246478e+70*cos(theta)**18 + 3.08659287808958e+69*cos(theta)**16 - 1.38879319599081e+68*cos(theta)**14 + 4.59564293946051e+66*cos(theta)**12 - 1.07215423826226e+65*cos(theta)**10 + 1.66139603036507e+63*cos(theta)**8 - 1.5636668521083e+61*cos(theta)**6 + 7.71038881710209e+58*cos(theta)**4 - 1.4899302062033e+56*cos(theta)**2 + 4.70900823705216e+52)*cos(28*phi)

#@torch.jit.script
def Yl84_m29(theta, phi):
    return 1.23715817367941e-55*(1.0 - cos(theta)**2)**14.5*(3.1035736055506e+77*cos(theta)**55 - 2.75976455343871e+78*cos(theta)**53 + 1.15241077413289e+79*cos(theta)**51 - 3.00475201844466e+79*cos(theta)**49 + 5.48693846846415e+79*cos(theta)**47 - 7.46085595523239e+79*cos(theta)**45 + 7.84102695932066e+79*cos(theta)**43 - 6.525757920983e+79*cos(theta)**41 + 4.37183128693306e+79*cos(theta)**39 - 2.38375789817321e+79*cos(theta)**37 + 1.06549178535796e+79*cos(theta)**35 - 3.92064076863318e+78*cos(theta)**33 + 1.18971168151628e+78*cos(theta)**31 - 2.97587913881156e+77*cos(theta)**29 + 6.12060248408051e+76*cos(theta)**27 - 1.03037480667255e+76*cos(theta)**25 + 1.41018449818323e+75*cos(theta)**23 - 1.55458247512138e+74*cos(theta)**21 + 1.36366883782577e+73*cos(theta)**19 - 9.36871720643661e+71*cos(theta)**17 + 4.93854860494333e+70*cos(theta)**15 - 1.94431047438714e+69*cos(theta)**13 + 5.51477152735261e+67*cos(theta)**11 - 1.07215423826226e+66*cos(theta)**9 + 1.32911682429206e+64*cos(theta)**7 - 9.38200111264982e+61*cos(theta)**5 + 3.08415552684084e+59*cos(theta)**3 - 2.9798604124066e+56*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl84_m30(theta, phi):
    return 1.56239722300668e-57*(1.0 - cos(theta)**2)**15*(1.70696548305283e+79*cos(theta)**54 - 1.46267521332252e+80*cos(theta)**52 + 5.87729494807774e+80*cos(theta)**50 - 1.47232848903788e+81*cos(theta)**48 + 2.57886108017815e+81*cos(theta)**46 - 3.35738517985457e+81*cos(theta)**44 + 3.37164159250789e+81*cos(theta)**42 - 2.67556074760303e+81*cos(theta)**40 + 1.70501420190389e+81*cos(theta)**38 - 8.81990422324089e+80*cos(theta)**36 + 3.72922124875286e+80*cos(theta)**34 - 1.29381145364895e+80*cos(theta)**32 + 3.68810621270046e+79*cos(theta)**30 - 8.63004950255352e+78*cos(theta)**28 + 1.65256267070174e+78*cos(theta)**26 - 2.57593701668137e+77*cos(theta)**24 + 3.24342434582143e+76*cos(theta)**22 - 3.2646231977549e+75*cos(theta)**20 + 2.59097079186897e+74*cos(theta)**18 - 1.59268192509422e+73*cos(theta)**16 + 7.40782290741499e+71*cos(theta)**14 - 2.52760361670328e+70*cos(theta)**12 + 6.06624868008787e+68*cos(theta)**10 - 9.64938814436034e+66*cos(theta)**8 + 9.30381777004441e+64*cos(theta)**6 - 4.69100055632491e+62*cos(theta)**4 + 9.25246658052251e+59*cos(theta)**2 - 2.9798604124066e+56)*cos(30*phi)

#@torch.jit.script
def Yl84_m31(theta, phi):
    return 1.9826481918361e-59*(1.0 - cos(theta)**2)**15.5*(9.21761360848529e+80*cos(theta)**53 - 7.60591110927708e+81*cos(theta)**51 + 2.93864747403887e+82*cos(theta)**49 - 7.06717674738183e+82*cos(theta)**47 + 1.18627609688195e+83*cos(theta)**45 - 1.47724947913601e+83*cos(theta)**43 + 1.41608946885331e+83*cos(theta)**41 - 1.07022429904121e+83*cos(theta)**39 + 6.47905396723479e+82*cos(theta)**37 - 3.17516552036672e+82*cos(theta)**35 + 1.26793522457597e+82*cos(theta)**33 - 4.14019665167664e+81*cos(theta)**31 + 1.10643186381014e+81*cos(theta)**29 - 2.41641386071498e+80*cos(theta)**27 + 4.29666294382452e+79*cos(theta)**25 - 6.18224884003528e+78*cos(theta)**23 + 7.13553356080714e+77*cos(theta)**21 - 6.5292463955098e+76*cos(theta)**19 + 4.66374742536414e+75*cos(theta)**17 - 2.54829108015076e+74*cos(theta)**15 + 1.0370952070381e+73*cos(theta)**13 - 3.03312434004393e+71*cos(theta)**11 + 6.06624868008787e+69*cos(theta)**9 - 7.71951051548827e+67*cos(theta)**7 + 5.58229066202664e+65*cos(theta)**5 - 1.87640022252996e+63*cos(theta)**3 + 1.8504933161045e+60*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl84_m32(theta, phi):
    return 2.52859182119784e-61*(1.0 - cos(theta)**2)**16*(4.8853352124972e+82*cos(theta)**52 - 3.87901466573131e+83*cos(theta)**50 + 1.43993726227905e+84*cos(theta)**48 - 3.32157307126946e+84*cos(theta)**46 + 5.33824243596877e+84*cos(theta)**44 - 6.35217276028486e+84*cos(theta)**42 + 5.80596682229858e+84*cos(theta)**40 - 4.17387476626073e+84*cos(theta)**38 + 2.39724996787687e+84*cos(theta)**36 - 1.11130793212835e+84*cos(theta)**34 + 4.18418624110071e+83*cos(theta)**32 - 1.28346096201976e+83*cos(theta)**30 + 3.2086524050494e+82*cos(theta)**28 - 6.52431742393046e+81*cos(theta)**26 + 1.07416573595613e+81*cos(theta)**24 - 1.42191723320811e+80*cos(theta)**22 + 1.4984620477695e+79*cos(theta)**20 - 1.24055681514686e+78*cos(theta)**18 + 7.92837062311904e+76*cos(theta)**16 - 3.82243662022614e+75*cos(theta)**14 + 1.34822376914953e+74*cos(theta)**12 - 3.33643677404833e+72*cos(theta)**10 + 5.45962381207908e+70*cos(theta)**8 - 5.40365736084179e+68*cos(theta)**6 + 2.79114533101332e+66*cos(theta)**4 - 5.62920066758989e+63*cos(theta)**2 + 1.8504933161045e+60)*cos(32*phi)

#@torch.jit.script
def Yl84_m33(theta, phi):
    return 3.24178438615108e-63*(1.0 - cos(theta)**2)**16.5*(2.54037431049855e+84*cos(theta)**51 - 1.93950733286566e+85*cos(theta)**49 + 6.91169885893943e+85*cos(theta)**47 - 1.52792361278395e+86*cos(theta)**45 + 2.34882667182626e+86*cos(theta)**43 - 2.66791255931964e+86*cos(theta)**41 + 2.32238672891943e+86*cos(theta)**39 - 1.58607241117908e+86*cos(theta)**37 + 8.63009988435674e+85*cos(theta)**35 - 3.7784469692364e+85*cos(theta)**33 + 1.33893959715223e+85*cos(theta)**31 - 3.85038288605928e+84*cos(theta)**29 + 8.98422673413831e+83*cos(theta)**27 - 1.69632253022192e+83*cos(theta)**25 + 2.57799776629471e+82*cos(theta)**23 - 3.12821791305785e+81*cos(theta)**21 + 2.996924095539e+80*cos(theta)**19 - 2.23300226726435e+79*cos(theta)**17 + 1.26853929969905e+78*cos(theta)**15 - 5.35141126831659e+76*cos(theta)**13 + 1.61786852297943e+75*cos(theta)**11 - 3.33643677404833e+73*cos(theta)**9 + 4.36769904966326e+71*cos(theta)**7 - 3.24219441650507e+69*cos(theta)**5 + 1.11645813240533e+67*cos(theta)**3 - 1.12584013351798e+64*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl84_m34(theta, phi):
    return 4.17886204762918e-65*(1.0 - cos(theta)**2)**17*(1.29559089835426e+86*cos(theta)**50 - 9.50358593104171e+86*cos(theta)**48 + 3.24849846370153e+87*cos(theta)**46 - 6.87565625752778e+87*cos(theta)**44 + 1.00999546888529e+88*cos(theta)**42 - 1.09384414932105e+88*cos(theta)**40 + 9.05730824278578e+87*cos(theta)**38 - 5.86846792136258e+87*cos(theta)**36 + 3.02053495952486e+87*cos(theta)**34 - 1.24688749984801e+87*cos(theta)**32 + 4.1507127511719e+86*cos(theta)**30 - 1.11661103695719e+86*cos(theta)**28 + 2.42574121821734e+85*cos(theta)**26 - 4.2408063255548e+84*cos(theta)**24 + 5.92939486247783e+83*cos(theta)**22 - 6.56925761742148e+82*cos(theta)**20 + 5.6941557815241e+81*cos(theta)**18 - 3.7961038543494e+80*cos(theta)**16 + 1.90280894954857e+79*cos(theta)**14 - 6.95683464881157e+77*cos(theta)**12 + 1.77965537527738e+76*cos(theta)**10 - 3.00279309664349e+74*cos(theta)**8 + 3.05738933476429e+72*cos(theta)**6 - 1.62109720825254e+70*cos(theta)**4 + 3.34937439721599e+67*cos(theta)**2 - 1.12584013351798e+64)*cos(34*phi)

#@torch.jit.script
def Yl84_m35(theta, phi):
    return 5.41750787896811e-67*(1.0 - cos(theta)**2)**17.5*(6.47795449177129e+87*cos(theta)**49 - 4.56172124690002e+88*cos(theta)**47 + 1.4943092933027e+89*cos(theta)**45 - 3.02528875331222e+89*cos(theta)**43 + 4.24198096931823e+89*cos(theta)**41 - 4.37537659728421e+89*cos(theta)**39 + 3.4417771322586e+89*cos(theta)**37 - 2.11264845169053e+89*cos(theta)**35 + 1.02698188623845e+89*cos(theta)**33 - 3.99003999951363e+88*cos(theta)**31 + 1.24521382535157e+88*cos(theta)**29 - 3.12651090348013e+87*cos(theta)**27 + 6.3069271673651e+86*cos(theta)**25 - 1.01779351813315e+86*cos(theta)**23 + 1.30446686974512e+85*cos(theta)**21 - 1.3138515234843e+84*cos(theta)**19 + 1.02494804067434e+83*cos(theta)**17 - 6.07376616695904e+81*cos(theta)**15 + 2.663932529368e+80*cos(theta)**13 - 8.34820157857388e+78*cos(theta)**11 + 1.77965537527738e+77*cos(theta)**9 - 2.4022344773148e+75*cos(theta)**7 + 1.83443360085857e+73*cos(theta)**5 - 6.48438883301015e+70*cos(theta)**3 + 6.69874879443197e+67*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl84_m36(theta, phi):
    return 7.06497921612571e-69*(1.0 - cos(theta)**2)**18*(3.17419770096793e+89*cos(theta)**48 - 2.14400898604301e+90*cos(theta)**46 + 6.72439181986217e+90*cos(theta)**44 - 1.30087416392426e+91*cos(theta)**42 + 1.73921219742047e+91*cos(theta)**40 - 1.70639687294084e+91*cos(theta)**38 + 1.27345753893568e+91*cos(theta)**36 - 7.39426958091686e+90*cos(theta)**34 + 3.38904022458689e+90*cos(theta)**32 - 1.23691239984923e+90*cos(theta)**30 + 3.61112009351955e+89*cos(theta)**28 - 8.44157943939636e+88*cos(theta)**26 + 1.57673179184127e+88*cos(theta)**24 - 2.34092509170625e+87*cos(theta)**22 + 2.73938042646476e+86*cos(theta)**20 - 2.49631789462016e+85*cos(theta)**18 + 1.74241166914637e+84*cos(theta)**16 - 9.11064925043856e+82*cos(theta)**14 + 3.4631122881784e+81*cos(theta)**12 - 9.18302173643127e+79*cos(theta)**10 + 1.60168983774964e+78*cos(theta)**8 - 1.68156413412036e+76*cos(theta)**6 + 9.17216800429286e+73*cos(theta)**4 - 1.94531664990304e+71*cos(theta)**2 + 6.69874879443197e+67)*cos(36*phi)

#@torch.jit.script
def Yl84_m37(theta, phi):
    return 9.2703810278393e-71*(1.0 - cos(theta)**2)**18.5*(1.52361489646461e+91*cos(theta)**47 - 9.86244133579785e+91*cos(theta)**45 + 2.95873240073935e+92*cos(theta)**43 - 5.46367148848188e+92*cos(theta)**41 + 6.95684878968189e+92*cos(theta)**39 - 6.4843081171752e+92*cos(theta)**37 + 4.58444714016845e+92*cos(theta)**35 - 2.51405165751173e+92*cos(theta)**33 + 1.08449287186781e+92*cos(theta)**31 - 3.71073719954768e+91*cos(theta)**29 + 1.01111362618548e+91*cos(theta)**27 - 2.19481065424305e+90*cos(theta)**25 + 3.78415630041906e+89*cos(theta)**23 - 5.15003520175375e+88*cos(theta)**21 + 5.47876085292952e+87*cos(theta)**19 - 4.4933722103163e+86*cos(theta)**17 + 2.7878586706342e+85*cos(theta)**15 - 1.2754908950614e+84*cos(theta)**13 + 4.15573474581408e+82*cos(theta)**11 - 9.18302173643127e+80*cos(theta)**9 + 1.28135187019971e+79*cos(theta)**7 - 1.00893848047221e+77*cos(theta)**5 + 3.66886720171714e+74*cos(theta)**3 - 3.89063329980609e+71*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl84_m38(theta, phi):
    return 1.22424613166005e-72*(1.0 - cos(theta)**2)**19*(7.16099001338366e+92*cos(theta)**46 - 4.43809860110903e+93*cos(theta)**44 + 1.27225493231792e+94*cos(theta)**42 - 2.24010531027757e+94*cos(theta)**40 + 2.71317102797594e+94*cos(theta)**38 - 2.39919400335482e+94*cos(theta)**36 + 1.60455649905896e+94*cos(theta)**34 - 8.29637046978871e+93*cos(theta)**32 + 3.3619279027902e+93*cos(theta)**30 - 1.07611378786883e+93*cos(theta)**28 + 2.73000679070078e+92*cos(theta)**26 - 5.48702663560763e+91*cos(theta)**24 + 8.70355949096383e+90*cos(theta)**22 - 1.08150739236829e+90*cos(theta)**20 + 1.04096456205661e+89*cos(theta)**18 - 7.6387327575377e+87*cos(theta)**16 + 4.1817880059513e+86*cos(theta)**14 - 1.65813816357982e+85*cos(theta)**12 + 4.57130822039549e+83*cos(theta)**10 - 8.26471956278814e+81*cos(theta)**8 + 8.96946309139798e+79*cos(theta)**6 - 5.04469240236107e+77*cos(theta)**4 + 1.10066016051514e+75*cos(theta)**2 - 3.89063329980609e+71)*cos(38*phi)

#@torch.jit.script
def Yl84_m39(theta, phi):
    return 1.62756097834137e-74*(1.0 - cos(theta)**2)**19.5*(3.29405540615648e+94*cos(theta)**45 - 1.95276338448797e+95*cos(theta)**43 + 5.34347071573527e+95*cos(theta)**41 - 8.96042124111028e+95*cos(theta)**39 + 1.03100499063086e+96*cos(theta)**37 - 8.63709841207736e+95*cos(theta)**35 + 5.45549209680046e+95*cos(theta)**33 - 2.65483855033239e+95*cos(theta)**31 + 1.00857837083706e+95*cos(theta)**29 - 3.01311860603272e+94*cos(theta)**27 + 7.09801765582203e+93*cos(theta)**25 - 1.31688639254583e+93*cos(theta)**23 + 1.91478308801204e+92*cos(theta)**21 - 2.16301478473657e+91*cos(theta)**19 + 1.8737362117019e+90*cos(theta)**17 - 1.22219724120603e+89*cos(theta)**15 + 5.85450320833182e+87*cos(theta)**13 - 1.98976579629578e+86*cos(theta)**11 + 4.57130822039549e+84*cos(theta)**9 - 6.61177565023051e+82*cos(theta)**7 + 5.38167785483879e+80*cos(theta)**5 - 2.01787696094443e+78*cos(theta)**3 + 2.20132032103029e+75*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl84_m40(theta, phi):
    return 2.17881406128541e-76*(1.0 - cos(theta)**2)**20*(1.48232493277042e+96*cos(theta)**44 - 8.39688255329829e+96*cos(theta)**42 + 2.19082299345146e+97*cos(theta)**40 - 3.49456428403301e+97*cos(theta)**38 + 3.81471846533417e+97*cos(theta)**36 - 3.02298444422708e+97*cos(theta)**34 + 1.80031239194415e+97*cos(theta)**32 - 8.2299995060304e+96*cos(theta)**30 + 2.92487727542747e+96*cos(theta)**28 - 8.13542023628833e+95*cos(theta)**26 + 1.77450441395551e+95*cos(theta)**24 - 3.02883870285541e+94*cos(theta)**22 + 4.02104448482529e+93*cos(theta)**20 - 4.10972809099949e+92*cos(theta)**18 + 3.18535155989322e+91*cos(theta)**16 - 1.83329586180905e+90*cos(theta)**14 + 7.61085417083136e+88*cos(theta)**12 - 2.18874237592536e+87*cos(theta)**10 + 4.11417739835594e+85*cos(theta)**8 - 4.62824295516136e+83*cos(theta)**6 + 2.6908389274194e+81*cos(theta)**4 - 6.05363088283328e+78*cos(theta)**2 + 2.20132032103029e+75)*cos(40*phi)

#@torch.jit.script
def Yl84_m41(theta, phi):
    return 2.93791228090321e-78*(1.0 - cos(theta)**2)**20.5*(6.52222970418983e+97*cos(theta)**43 - 3.52669067238528e+98*cos(theta)**41 + 8.76329197380585e+98*cos(theta)**39 - 1.32793442793254e+99*cos(theta)**37 + 1.3732986475203e+99*cos(theta)**35 - 1.02781471103721e+99*cos(theta)**33 + 5.76099965422128e+98*cos(theta)**31 - 2.46899985180912e+98*cos(theta)**29 + 8.18965637119692e+97*cos(theta)**27 - 2.11520926143497e+97*cos(theta)**25 + 4.25881059349322e+96*cos(theta)**23 - 6.66344514628191e+95*cos(theta)**21 + 8.04208896965058e+94*cos(theta)**19 - 7.39751056379908e+93*cos(theta)**17 + 5.09656249582916e+92*cos(theta)**15 - 2.56661420653267e+91*cos(theta)**13 + 9.13302500499763e+89*cos(theta)**11 - 2.18874237592536e+88*cos(theta)**9 + 3.29134191868475e+86*cos(theta)**7 - 2.77694577309682e+84*cos(theta)**5 + 1.07633557096776e+82*cos(theta)**3 - 1.21072617656666e+79*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl84_m42(theta, phi):
    return 3.99134551249965e-80*(1.0 - cos(theta)**2)**21*(2.80455877280163e+99*cos(theta)**42 - 1.44594317567797e+100*cos(theta)**40 + 3.41768386978428e+100*cos(theta)**38 - 4.91335738335041e+100*cos(theta)**36 + 4.80654526632105e+100*cos(theta)**34 - 3.39178854642278e+100*cos(theta)**32 + 1.7859098928086e+100*cos(theta)**30 - 7.16009957024645e+99*cos(theta)**28 + 2.21120722022317e+99*cos(theta)**26 - 5.28802315358742e+98*cos(theta)**24 + 9.79526436503441e+97*cos(theta)**22 - 1.3993234807192e+97*cos(theta)**20 + 1.52799690423361e+96*cos(theta)**18 - 1.25757679584584e+95*cos(theta)**16 + 7.64484374374373e+93*cos(theta)**14 - 3.33659846849247e+92*cos(theta)**12 + 1.00463275054974e+91*cos(theta)**10 - 1.96986813833282e+89*cos(theta)**8 + 2.30393934307932e+87*cos(theta)**6 - 1.38847288654841e+85*cos(theta)**4 + 3.22900671290327e+82*cos(theta)**2 - 1.21072617656666e+79)*cos(42*phi)

#@torch.jit.script
def Yl84_m43(theta, phi):
    return 5.46503337606992e-82*(1.0 - cos(theta)**2)**21.5*(1.17791468457668e+101*cos(theta)**41 - 5.78377270271186e+101*cos(theta)**39 + 1.29871987051803e+102*cos(theta)**37 - 1.76880865800615e+102*cos(theta)**35 + 1.63422539054916e+102*cos(theta)**33 - 1.08537233485529e+102*cos(theta)**31 + 5.35772967842579e+101*cos(theta)**29 - 2.00482787966901e+101*cos(theta)**27 + 5.74913877258024e+100*cos(theta)**25 - 1.26912555686098e+100*cos(theta)**23 + 2.15495816030757e+99*cos(theta)**21 - 2.7986469614384e+98*cos(theta)**19 + 2.7503944276205e+97*cos(theta)**17 - 2.01212287335335e+96*cos(theta)**15 + 1.07027812412412e+95*cos(theta)**13 - 4.00391816219096e+93*cos(theta)**11 + 1.00463275054974e+92*cos(theta)**9 - 1.57589451066626e+90*cos(theta)**7 + 1.38236360584759e+88*cos(theta)**5 - 5.55389154619363e+85*cos(theta)**3 + 6.45801342580655e+82*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl84_m44(theta, phi):
    return 7.54389969711715e-84*(1.0 - cos(theta)**2)**22*(4.8294502067644e+102*cos(theta)**40 - 2.25567135405763e+103*cos(theta)**38 + 4.8052635209167e+103*cos(theta)**36 - 6.19083030302151e+103*cos(theta)**34 + 5.39294378881222e+103*cos(theta)**32 - 3.3646542380514e+103*cos(theta)**30 + 1.55374160674348e+103*cos(theta)**28 - 5.41303527510632e+102*cos(theta)**26 + 1.43728469314506e+102*cos(theta)**24 - 2.91898878078025e+101*cos(theta)**22 + 4.5254121366459e+100*cos(theta)**20 - 5.31742922673296e+99*cos(theta)**18 + 4.67567052695485e+98*cos(theta)**16 - 3.01818431003003e+97*cos(theta)**14 + 1.39136156136136e+96*cos(theta)**12 - 4.40430997841006e+94*cos(theta)**10 + 9.04169475494766e+92*cos(theta)**8 - 1.10312615746638e+91*cos(theta)**6 + 6.91181802923797e+88*cos(theta)**4 - 1.66616746385809e+86*cos(theta)**2 + 6.45801342580655e+82)*cos(44*phi)

#@torch.jit.script
def Yl84_m45(theta, phi):
    return 1.05019768017504e-85*(1.0 - cos(theta)**2)**22.5*(1.93178008270576e+104*cos(theta)**39 - 8.57155114541898e+104*cos(theta)**37 + 1.72989486753001e+105*cos(theta)**35 - 2.10488230302732e+105*cos(theta)**33 + 1.72574201241991e+105*cos(theta)**31 - 1.00939627141542e+105*cos(theta)**29 + 4.35047649888174e+104*cos(theta)**27 - 1.40738917152764e+104*cos(theta)**25 + 3.44948326354814e+103*cos(theta)**23 - 6.42177531771656e+102*cos(theta)**21 + 9.05082427329179e+101*cos(theta)**19 - 9.57137260811934e+100*cos(theta)**17 + 7.48107284312776e+99*cos(theta)**15 - 4.22545803404204e+98*cos(theta)**13 + 1.66963387363363e+97*cos(theta)**11 - 4.40430997841006e+95*cos(theta)**9 + 7.23335580395813e+93*cos(theta)**7 - 6.61875694479828e+91*cos(theta)**5 + 2.76472721169519e+89*cos(theta)**3 - 3.33233492771618e+86*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl84_m46(theta, phi):
    return 1.47491528018325e-87*(1.0 - cos(theta)**2)**23*(7.53394232255247e+105*cos(theta)**38 - 3.17147392380502e+106*cos(theta)**36 + 6.05463203635504e+106*cos(theta)**34 - 6.94611159999014e+106*cos(theta)**32 + 5.34980023850172e+106*cos(theta)**30 - 2.92724918710472e+106*cos(theta)**28 + 1.17462865469807e+106*cos(theta)**26 - 3.51847292881911e+105*cos(theta)**24 + 7.93381150616073e+104*cos(theta)**22 - 1.34857281672048e+104*cos(theta)**20 + 1.71965661192544e+103*cos(theta)**18 - 1.62713334338029e+102*cos(theta)**16 + 1.12216092646916e+101*cos(theta)**14 - 5.49309544425465e+99*cos(theta)**12 + 1.83659726099699e+98*cos(theta)**10 - 3.96387898056905e+96*cos(theta)**8 + 5.06334906277069e+94*cos(theta)**6 - 3.30937847239914e+92*cos(theta)**4 + 8.29418163508557e+89*cos(theta)**2 - 3.33233492771618e+86)*cos(46*phi)

#@torch.jit.script
def Yl84_m47(theta, phi):
    return 2.09044925098607e-89*(1.0 - cos(theta)**2)**23.5*(2.86289808256994e+107*cos(theta)**37 - 1.14173061256981e+108*cos(theta)**35 + 2.05857489236071e+108*cos(theta)**33 - 2.22275571199684e+108*cos(theta)**31 + 1.60494007155052e+108*cos(theta)**29 - 8.19629772389321e+107*cos(theta)**27 + 3.05403450221498e+107*cos(theta)**25 - 8.44433502916585e+106*cos(theta)**23 + 1.74543853135536e+106*cos(theta)**21 - 2.69714563344095e+105*cos(theta)**19 + 3.09538190146579e+104*cos(theta)**17 - 2.60341334940846e+103*cos(theta)**15 + 1.57102529705683e+102*cos(theta)**13 - 6.59171453310558e+100*cos(theta)**11 + 1.83659726099699e+99*cos(theta)**9 - 3.17110318445524e+97*cos(theta)**7 + 3.03800943766241e+95*cos(theta)**5 - 1.32375138895966e+93*cos(theta)**3 + 1.65883632701711e+90*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl84_m48(theta, phi):
    return 2.9912437292547e-91*(1.0 - cos(theta)**2)**24*(1.05927229055088e+109*cos(theta)**36 - 3.99605714399433e+109*cos(theta)**34 + 6.79329714479036e+109*cos(theta)**32 - 6.89054270719022e+109*cos(theta)**30 + 4.6543262074965e+109*cos(theta)**28 - 2.21300038545117e+109*cos(theta)**26 + 7.63508625553746e+108*cos(theta)**24 - 1.94219705670815e+108*cos(theta)**22 + 3.66542091584626e+107*cos(theta)**20 - 5.12457670353781e+106*cos(theta)**18 + 5.26214923249185e+105*cos(theta)**16 - 3.90512002411269e+104*cos(theta)**14 + 2.04233288617388e+103*cos(theta)**12 - 7.25088598641613e+101*cos(theta)**10 + 1.65293753489729e+100*cos(theta)**8 - 2.21977222911867e+98*cos(theta)**6 + 1.51900471883121e+96*cos(theta)**4 - 3.97125416687897e+93*cos(theta)**2 + 1.65883632701711e+90)*cos(48*phi)

#@torch.jit.script
def Yl84_m49(theta, phi):
    return 4.3228954315221e-93*(1.0 - cos(theta)**2)**24.5*(3.81338024598316e+110*cos(theta)**35 - 1.35865942895807e+111*cos(theta)**33 + 2.17385508633291e+111*cos(theta)**31 - 2.06716281215707e+111*cos(theta)**29 + 1.30321133809902e+111*cos(theta)**27 - 5.75380100217303e+110*cos(theta)**25 + 1.83242070132899e+110*cos(theta)**23 - 4.27283352475792e+109*cos(theta)**21 + 7.33084183169251e+108*cos(theta)**19 - 9.22423806636806e+107*cos(theta)**17 + 8.41943877198696e+106*cos(theta)**15 - 5.46716803375777e+105*cos(theta)**13 + 2.45079946340865e+104*cos(theta)**11 - 7.25088598641613e+102*cos(theta)**9 + 1.32235002791784e+101*cos(theta)**7 - 1.3318633374712e+99*cos(theta)**5 + 6.07601887532483e+96*cos(theta)**3 - 7.94250833375794e+93*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl84_m50(theta, phi):
    return 6.3123098526323e-95*(1.0 - cos(theta)**2)**25*(1.33468308609411e+112*cos(theta)**34 - 4.48357611556164e+112*cos(theta)**32 + 6.73895076763203e+112*cos(theta)**30 - 5.99477215525549e+112*cos(theta)**28 + 3.51867061286735e+112*cos(theta)**26 - 1.43845025054326e+112*cos(theta)**24 + 4.21456761305668e+111*cos(theta)**22 - 8.97295040199164e+110*cos(theta)**20 + 1.39285994802158e+110*cos(theta)**18 - 1.56812047128257e+109*cos(theta)**16 + 1.26291581579804e+108*cos(theta)**14 - 7.10731844388509e+106*cos(theta)**12 + 2.69587940974952e+105*cos(theta)**10 - 6.52579738777452e+103*cos(theta)**8 + 9.25645019542485e+101*cos(theta)**6 - 6.65931668735601e+99*cos(theta)**4 + 1.82280566259745e+97*cos(theta)**2 - 7.94250833375794e+93)*cos(50*phi)

#@torch.jit.script
def Yl84_m51(theta, phi):
    return 9.31712594605429e-97*(1.0 - cos(theta)**2)**25.5*(4.53792249271996e+113*cos(theta)**33 - 1.43474435697972e+114*cos(theta)**31 + 2.02168523028961e+114*cos(theta)**29 - 1.67853620347154e+114*cos(theta)**27 + 9.14854359345512e+113*cos(theta)**25 - 3.45228060130382e+113*cos(theta)**23 + 9.27204874872469e+112*cos(theta)**21 - 1.79459008039833e+112*cos(theta)**19 + 2.50714790643884e+111*cos(theta)**17 - 2.50899275405211e+110*cos(theta)**15 + 1.76808214211726e+109*cos(theta)**13 - 8.52878213266211e+107*cos(theta)**11 + 2.69587940974952e+106*cos(theta)**9 - 5.22063791021962e+104*cos(theta)**7 + 5.55387011725491e+102*cos(theta)**5 - 2.6637266749424e+100*cos(theta)**3 + 3.6456113251949e+97*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl84_m52(theta, phi):
    return 1.39077073021898e-98*(1.0 - cos(theta)**2)**26*(1.49751442259759e+115*cos(theta)**32 - 4.44770750663714e+115*cos(theta)**30 + 5.86288716783987e+115*cos(theta)**28 - 4.53204774937315e+115*cos(theta)**26 + 2.28713589836378e+115*cos(theta)**24 - 7.94024538299878e+114*cos(theta)**22 + 1.94713023723219e+114*cos(theta)**20 - 3.40972115275682e+113*cos(theta)**18 + 4.26215144094603e+112*cos(theta)**16 - 3.76348913107817e+111*cos(theta)**14 + 2.29850678475244e+110*cos(theta)**12 - 9.38166034592832e+108*cos(theta)**10 + 2.42629146877457e+107*cos(theta)**8 - 3.65444653715373e+105*cos(theta)**6 + 2.77693505862746e+103*cos(theta)**4 - 7.99118002482721e+100*cos(theta)**2 + 3.6456113251949e+97)*cos(52*phi)

#@torch.jit.script
def Yl84_m53(theta, phi):
    return 2.10048831220557e-100*(1.0 - cos(theta)**2)**26.5*(4.79204615231228e+116*cos(theta)**31 - 1.33431225199114e+117*cos(theta)**29 + 1.64160840699516e+117*cos(theta)**27 - 1.17833241483702e+117*cos(theta)**25 + 5.48912615607307e+116*cos(theta)**23 - 1.74685398425973e+116*cos(theta)**21 + 3.89426047446437e+115*cos(theta)**19 - 6.13749807496228e+114*cos(theta)**17 + 6.81944230551364e+113*cos(theta)**15 - 5.26888478350944e+112*cos(theta)**13 + 2.75820814170293e+111*cos(theta)**11 - 9.38166034592832e+109*cos(theta)**9 + 1.94103317501965e+108*cos(theta)**7 - 2.19266792229224e+106*cos(theta)**5 + 1.11077402345098e+104*cos(theta)**3 - 1.59823600496544e+101*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl84_m54(theta, phi):
    return 3.21144049393384e-102*(1.0 - cos(theta)**2)**27*(1.48553430721681e+118*cos(theta)**30 - 3.86950553077431e+118*cos(theta)**28 + 4.43234269888694e+118*cos(theta)**26 - 2.94583103709255e+118*cos(theta)**24 + 1.26249901589681e+118*cos(theta)**22 - 3.66839336694544e+117*cos(theta)**20 + 7.3990949014823e+116*cos(theta)**18 - 1.04337467274359e+116*cos(theta)**16 + 1.02291634582705e+115*cos(theta)**14 - 6.84955021856227e+113*cos(theta)**12 + 3.03402895587322e+112*cos(theta)**10 - 8.44349431133549e+110*cos(theta)**8 + 1.35872322251376e+109*cos(theta)**6 - 1.09633396114612e+107*cos(theta)**4 + 3.33232207035295e+104*cos(theta)**2 - 1.59823600496544e+101)*cos(54*phi)

#@torch.jit.script
def Yl84_m55(theta, phi):
    return 4.97315335648737e-104*(1.0 - cos(theta)**2)**27.5*(4.45660292165042e+119*cos(theta)**29 - 1.08346154861681e+120*cos(theta)**27 + 1.1524091017106e+120*cos(theta)**25 - 7.06999448902212e+119*cos(theta)**23 + 2.77749783497297e+119*cos(theta)**21 - 7.33678673389087e+118*cos(theta)**19 + 1.33183708226681e+118*cos(theta)**17 - 1.66939947638974e+117*cos(theta)**15 + 1.43208288415787e+116*cos(theta)**13 - 8.21946026227472e+114*cos(theta)**11 + 3.03402895587322e+113*cos(theta)**9 - 6.75479544906839e+111*cos(theta)**7 + 8.15233933508254e+109*cos(theta)**5 - 4.38533584458448e+107*cos(theta)**3 + 6.66464414070589e+104*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl84_m56(theta, phi):
    return 7.80492681130998e-106*(1.0 - cos(theta)**2)**28*(1.29241484727862e+121*cos(theta)**28 - 2.92534618126538e+121*cos(theta)**26 + 2.88102275427651e+121*cos(theta)**24 - 1.62609873247509e+121*cos(theta)**22 + 5.83274545344325e+120*cos(theta)**20 - 1.39398947943927e+120*cos(theta)**18 + 2.26412303985359e+119*cos(theta)**16 - 2.50409921458461e+118*cos(theta)**14 + 1.86170774940522e+117*cos(theta)**12 - 9.0414062885022e+115*cos(theta)**10 + 2.7306260602859e+114*cos(theta)**8 - 4.72835681434788e+112*cos(theta)**6 + 4.07616966754127e+110*cos(theta)**4 - 1.31560075337534e+108*cos(theta)**2 + 6.66464414070589e+104)*cos(56*phi)

#@torch.jit.script
def Yl84_m57(theta, phi):
    return 1.24216778811374e-107*(1.0 - cos(theta)**2)**28.5*(3.61876157238014e+122*cos(theta)**27 - 7.60590007128999e+122*cos(theta)**25 + 6.91445461026363e+122*cos(theta)**23 - 3.57741721144519e+122*cos(theta)**21 + 1.16654909068865e+122*cos(theta)**19 - 2.50918106299068e+121*cos(theta)**17 + 3.62259686376574e+120*cos(theta)**15 - 3.50573890041845e+119*cos(theta)**13 + 2.23404929928627e+118*cos(theta)**11 - 9.0414062885022e+116*cos(theta)**9 + 2.18450084822872e+115*cos(theta)**7 - 2.83701408860873e+113*cos(theta)**5 + 1.63046786701651e+111*cos(theta)**3 - 2.63120150675069e+108*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl84_m58(theta, phi):
    return 2.00610753277077e-109*(1.0 - cos(theta)**2)**29*(9.77065624542637e+123*cos(theta)**26 - 1.9014750178225e+124*cos(theta)**24 + 1.59032456036063e+124*cos(theta)**22 - 7.5125761440349e+123*cos(theta)**20 + 2.21644327230843e+123*cos(theta)**18 - 4.26560780708415e+122*cos(theta)**16 + 5.4338952956486e+121*cos(theta)**14 - 4.55746057054399e+120*cos(theta)**12 + 2.4574542292149e+119*cos(theta)**10 - 8.13726565965198e+117*cos(theta)**8 + 1.5291505937601e+116*cos(theta)**6 - 1.41850704430436e+114*cos(theta)**4 + 4.89140360104953e+111*cos(theta)**2 - 2.63120150675069e+108)*cos(58*phi)

#@torch.jit.script
def Yl84_m59(theta, phi):
    return 3.29002740825472e-111*(1.0 - cos(theta)**2)**29.5*(2.54037062381086e+125*cos(theta)**25 - 4.56354004277399e+125*cos(theta)**23 + 3.4987140327934e+125*cos(theta)**21 - 1.50251522880698e+125*cos(theta)**19 + 3.98959789015518e+124*cos(theta)**17 - 6.82497249133465e+123*cos(theta)**15 + 7.60745341390805e+122*cos(theta)**13 - 5.46895268465279e+121*cos(theta)**11 + 2.4574542292149e+120*cos(theta)**9 - 6.50981252772158e+118*cos(theta)**7 + 9.17490356256062e+116*cos(theta)**5 - 5.67402817721745e+114*cos(theta)**3 + 9.78280720209905e+111*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl84_m60(theta, phi):
    return 5.48337901375787e-113*(1.0 - cos(theta)**2)**30*(6.35092655952714e+126*cos(theta)**24 - 1.04961420983802e+127*cos(theta)**22 + 7.34729946886613e+126*cos(theta)**20 - 2.85477893473326e+126*cos(theta)**18 + 6.78231641326381e+125*cos(theta)**16 - 1.0237458737002e+125*cos(theta)**14 + 9.88968943808046e+123*cos(theta)**12 - 6.01584795311807e+122*cos(theta)**10 + 2.21170880629341e+121*cos(theta)**8 - 4.55686876940511e+119*cos(theta)**6 + 4.58745178128031e+117*cos(theta)**4 - 1.70220845316524e+115*cos(theta)**2 + 9.78280720209905e+111)*cos(60*phi)

#@torch.jit.script
def Yl84_m61(theta, phi):
    return 9.29519796437372e-115*(1.0 - cos(theta)**2)**30.5*(1.52422237428651e+128*cos(theta)**23 - 2.30915126164364e+128*cos(theta)**21 + 1.46945989377323e+128*cos(theta)**19 - 5.13860208251987e+127*cos(theta)**17 + 1.08517062612221e+127*cos(theta)**15 - 1.43324422318028e+126*cos(theta)**13 + 1.18676273256966e+125*cos(theta)**11 - 6.01584795311807e+123*cos(theta)**9 + 1.76936704503473e+122*cos(theta)**7 - 2.73412126164306e+120*cos(theta)**5 + 1.83498071251212e+118*cos(theta)**3 - 3.40441690633047e+115*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl84_m62(theta, phi):
    return 1.60405146295186e-116*(1.0 - cos(theta)**2)**31*(3.50571146085898e+129*cos(theta)**22 - 4.84921764945165e+129*cos(theta)**20 + 2.79197379816913e+129*cos(theta)**18 - 8.73562354028378e+128*cos(theta)**16 + 1.62775593918331e+128*cos(theta)**14 - 1.86321749013436e+127*cos(theta)**12 + 1.30543900582662e+126*cos(theta)**10 - 5.41426315780626e+124*cos(theta)**8 + 1.23855693152431e+123*cos(theta)**6 - 1.36706063082153e+121*cos(theta)**4 + 5.50494213753637e+118*cos(theta)**2 - 3.40441690633047e+115)*cos(62*phi)

#@torch.jit.script
def Yl84_m63(theta, phi):
    return 2.82064408831893e-118*(1.0 - cos(theta)**2)**31.5*(7.71256521388976e+130*cos(theta)**21 - 9.69843529890329e+130*cos(theta)**19 + 5.02555283670443e+130*cos(theta)**17 - 1.39769976644541e+130*cos(theta)**15 + 2.27885831485664e+129*cos(theta)**13 - 2.23586098816123e+128*cos(theta)**11 + 1.30543900582662e+127*cos(theta)**9 - 4.33141052624501e+125*cos(theta)**7 + 7.43134158914585e+123*cos(theta)**5 - 5.46824252328613e+121*cos(theta)**3 + 1.10098842750727e+119*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl84_m64(theta, phi):
    return 5.05950215049249e-120*(1.0 - cos(theta)**2)**32*(1.61963869491685e+132*cos(theta)**20 - 1.84270270679163e+132*cos(theta)**18 + 8.54343982239754e+131*cos(theta)**16 - 2.09654964966811e+131*cos(theta)**14 + 2.96251580931363e+130*cos(theta)**12 - 2.45944708697735e+129*cos(theta)**10 + 1.17489510524396e+128*cos(theta)**8 - 3.03198736837151e+126*cos(theta)**6 + 3.71567079457292e+124*cos(theta)**4 - 1.64047275698584e+122*cos(theta)**2 + 1.10098842750727e+119)*cos(64*phi)

#@torch.jit.script
def Yl84_m65(theta, phi):
    return 9.26829082417413e-122*(1.0 - cos(theta)**2)**32.5*(3.2392773898337e+133*cos(theta)**19 - 3.31686487222493e+133*cos(theta)**17 + 1.36695037158361e+133*cos(theta)**15 - 2.93516950953535e+132*cos(theta)**13 + 3.55501897117636e+131*cos(theta)**11 - 2.45944708697735e+130*cos(theta)**9 + 9.39916084195167e+128*cos(theta)**7 - 1.8191924210229e+127*cos(theta)**5 + 1.48626831782917e+125*cos(theta)**3 - 3.28094551397168e+122*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl84_m66(theta, phi):
    return 1.73610993670686e-123*(1.0 - cos(theta)**2)**33*(6.15462704068403e+134*cos(theta)**18 - 5.63867028278237e+134*cos(theta)**16 + 2.05042555737541e+134*cos(theta)**14 - 3.81572036239596e+133*cos(theta)**12 + 3.91052086829399e+132*cos(theta)**10 - 2.21350237827962e+131*cos(theta)**8 + 6.57941258936617e+129*cos(theta)**6 - 9.09596210511452e+127*cos(theta)**4 + 4.45880495348751e+125*cos(theta)**2 - 3.28094551397168e+122)*cos(66*phi)

#@torch.jit.script
def Yl84_m67(theta, phi):
    return 3.33006335874572e-125*(1.0 - cos(theta)**2)**33.5*(1.10783286732313e+136*cos(theta)**17 - 9.0218724524518e+135*cos(theta)**15 + 2.87059578032557e+135*cos(theta)**13 - 4.57886443487515e+134*cos(theta)**11 + 3.91052086829399e+133*cos(theta)**9 - 1.77080190262369e+132*cos(theta)**7 + 3.9476475536197e+130*cos(theta)**5 - 3.63838484204581e+128*cos(theta)**3 + 8.91760990697502e+125*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl84_m68(theta, phi):
    return 6.55097952323603e-127*(1.0 - cos(theta)**2)**34*(1.88331587444931e+137*cos(theta)**16 - 1.35328086786777e+137*cos(theta)**14 + 3.73177451442324e+136*cos(theta)**12 - 5.03675087836266e+135*cos(theta)**10 + 3.51946878146459e+134*cos(theta)**8 - 1.23956133183659e+133*cos(theta)**6 + 1.97382377680985e+131*cos(theta)**4 - 1.09151545261374e+129*cos(theta)**2 + 8.91760990697502e+125)*cos(68*phi)

#@torch.jit.script
def Yl84_m69(theta, phi):
    return 1.32403826105689e-128*(1.0 - cos(theta)**2)**34.5*(3.0133053991189e+138*cos(theta)**15 - 1.89459321501488e+138*cos(theta)**13 + 4.47812941730789e+137*cos(theta)**11 - 5.03675087836266e+136*cos(theta)**9 + 2.81557502517167e+135*cos(theta)**7 - 7.43736799101952e+133*cos(theta)**5 + 7.8952951072394e+131*cos(theta)**3 - 2.18303090522748e+129*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl84_m70(theta, phi):
    return 2.75482836003585e-130*(1.0 - cos(theta)**2)**35*(4.51995809867835e+139*cos(theta)**14 - 2.46297117951934e+139*cos(theta)**12 + 4.92594235903868e+138*cos(theta)**10 - 4.5330757905264e+137*cos(theta)**8 + 1.97090251762017e+136*cos(theta)**6 - 3.71868399550976e+134*cos(theta)**4 + 2.36858853217182e+132*cos(theta)**2 - 2.18303090522748e+129)*cos(70*phi)

#@torch.jit.script
def Yl84_m71(theta, phi):
    return 5.91377338398529e-132*(1.0 - cos(theta)**2)**35.5*(6.32794133814969e+140*cos(theta)**13 - 2.95556541542321e+140*cos(theta)**11 + 4.92594235903868e+139*cos(theta)**9 - 3.62646063242112e+138*cos(theta)**7 + 1.1825415105721e+137*cos(theta)**5 - 1.4874735982039e+135*cos(theta)**3 + 4.73717706434364e+132*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl84_m72(theta, phi):
    return 1.31319948275783e-133*(1.0 - cos(theta)**2)**36*(8.2263237395946e+141*cos(theta)**12 - 3.25112195696553e+141*cos(theta)**10 + 4.43334812313481e+140*cos(theta)**8 - 2.53852244269478e+139*cos(theta)**6 + 5.91270755286052e+137*cos(theta)**4 - 4.46242079461171e+135*cos(theta)**2 + 4.73717706434364e+132)*cos(72*phi)

#@torch.jit.script
def Yl84_m73(theta, phi):
    return 3.02545190735408e-135*(1.0 - cos(theta)**2)**36.5*(9.87158848751352e+142*cos(theta)**11 - 3.25112195696553e+142*cos(theta)**9 + 3.54667849850785e+141*cos(theta)**7 - 1.52311346561687e+140*cos(theta)**5 + 2.36508302114421e+138*cos(theta)**3 - 8.92484158922342e+135*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl84_m74(theta, phi):
    return 7.25713776794442e-137*(1.0 - cos(theta)**2)**37*(1.08587473362649e+144*cos(theta)**10 - 2.92600976126898e+143*cos(theta)**8 + 2.4826749489555e+142*cos(theta)**6 - 7.61556732808434e+140*cos(theta)**4 + 7.09524906343262e+138*cos(theta)**2 - 8.92484158922342e+135)*cos(74*phi)

#@torch.jit.script
def Yl84_m75(theta, phi):
    return 1.81998079647975e-138*(1.0 - cos(theta)**2)**37.5*(1.08587473362649e+145*cos(theta)**9 - 2.34080780901518e+144*cos(theta)**7 + 1.4896049693733e+143*cos(theta)**5 - 3.04622693123374e+141*cos(theta)**3 + 1.41904981268652e+139*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl84_m76(theta, phi):
    return 4.7960705122028e-140*(1.0 - cos(theta)**2)**38*(9.77287260263839e+145*cos(theta)**8 - 1.63856546631063e+145*cos(theta)**6 + 7.44802484686649e+143*cos(theta)**4 - 9.13868079370121e+141*cos(theta)**2 + 1.41904981268652e+139)*cos(76*phi)

#@torch.jit.script
def Yl84_m77(theta, phi):
    return 1.33637280121287e-141*(1.0 - cos(theta)**2)**38.5*(7.81829808211071e+146*cos(theta)**7 - 9.83139279786376e+145*cos(theta)**5 + 2.9792099387466e+144*cos(theta)**3 - 1.82773615874024e+142*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl84_m78(theta, phi):
    return 3.96845171677929e-143*(1.0 - cos(theta)**2)**39*(5.4728086574775e+147*cos(theta)**6 - 4.91569639893188e+146*cos(theta)**4 + 8.93762981623979e+144*cos(theta)**2 - 1.82773615874024e+142)*cos(78*phi)

#@torch.jit.script
def Yl84_m79(theta, phi):
    return 1.26897093021025e-144*(1.0 - cos(theta)**2)**39.5*(3.2836851944865e+148*cos(theta)**5 - 1.96627855957275e+147*cos(theta)**3 + 1.78752596324796e+145*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl84_m80(theta, phi):
    return 4.4314387105487e-146*(1.0 - cos(theta)**2)**40*(1.64184259724325e+149*cos(theta)**4 - 5.89883567871826e+147*cos(theta)**2 + 1.78752596324796e+145)*cos(80*phi)

#@torch.jit.script
def Yl84_m81(theta, phi):
    return 1.72493517863933e-147*(1.0 - cos(theta)**2)**40.5*(6.567370388973e+149*cos(theta)**3 - 1.17976713574365e+148*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl84_m82(theta, phi):
    return 7.72961936139408e-149*(1.0 - cos(theta)**2)**41*(1.9702111166919e+150*cos(theta)**2 - 1.17976713574365e+148)*cos(82*phi)

#@torch.jit.script
def Yl84_m83(theta, phi):
    return 16.6658563996924*(1.0 - cos(theta)**2)**41.5*cos(83*phi)*cos(theta)

#@torch.jit.script
def Yl84_m84(theta, phi):
    return 1.28579873622986*(1.0 - cos(theta)**2)**42*cos(84*phi)

#@torch.jit.script
def Yl85_m_minus_85(theta, phi):
    return 1.28957495210276*(1.0 - cos(theta)**2)**42.5*sin(85*phi)

#@torch.jit.script
def Yl85_m_minus_84(theta, phi):
    return 16.8140002588748*(1.0 - cos(theta)**2)**42*sin(84*phi)*cos(theta)

#@torch.jit.script
def Yl85_m_minus_83(theta, phi):
    return 4.6419444015591e-151*(1.0 - cos(theta)**2)**41.5*(3.32965678720931e+152*cos(theta)**2 - 1.9702111166919e+150)*sin(83*phi)

#@torch.jit.script
def Yl85_m_minus_82(theta, phi):
    return 1.04211393354525e-149*(1.0 - cos(theta)**2)**41*(1.10988559573644e+152*cos(theta)**3 - 1.9702111166919e+150*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl85_m_minus_81(theta, phi):
    return 2.69341598890101e-148*(1.0 - cos(theta)**2)**40.5*(2.77471398934109e+151*cos(theta)**4 - 9.85105558345949e+149*cos(theta)**2 + 2.94941783935913e+147)*sin(81*phi)

#@torch.jit.script
def Yl85_m_minus_80(theta, phi):
    return 7.75965620507256e-147*(1.0 - cos(theta)**2)**40*(5.54942797868218e+150*cos(theta)**5 - 3.2836851944865e+149*cos(theta)**3 + 2.94941783935913e+147*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl85_m_minus_79(theta, phi):
    return 2.44151882599156e-145*(1.0 - cos(theta)**2)**39.5*(9.24904663113697e+149*cos(theta)**6 - 8.20921298621624e+148*cos(theta)**4 + 1.47470891967956e+147*cos(theta)**2 - 2.9792099387466e+144)*sin(79*phi)

#@torch.jit.script
def Yl85_m_minus_78(theta, phi):
    return 8.27239038970388e-144*(1.0 - cos(theta)**2)**39*(1.32129237587671e+149*cos(theta)**7 - 1.64184259724325e+148*cos(theta)**5 + 4.91569639893188e+146*cos(theta)**3 - 2.9792099387466e+144*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl85_m_minus_77(theta, phi):
    return 2.9872379442991e-142*(1.0 - cos(theta)**2)**38.5*(1.65161546984589e+148*cos(theta)**8 - 2.73640432873875e+147*cos(theta)**6 + 1.22892409973297e+146*cos(theta)**4 - 1.4896049693733e+144*cos(theta)**2 + 2.2846701984253e+141)*sin(77*phi)

#@torch.jit.script
def Yl85_m_minus_76(theta, phi):
    return 1.1406399520131e-140*(1.0 - cos(theta)**2)**38*(1.83512829982876e+147*cos(theta)**9 - 3.90914904105535e+146*cos(theta)**7 + 2.45784819946594e+145*cos(theta)**5 - 4.96534989791099e+143*cos(theta)**3 + 2.2846701984253e+141*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl85_m_minus_75(theta, phi):
    return 4.57679559867686e-139*(1.0 - cos(theta)**2)**37.5*(1.83512829982876e+146*cos(theta)**10 - 4.88643630131919e+145*cos(theta)**8 + 4.09641366577657e+144*cos(theta)**6 - 1.24133747447775e+143*cos(theta)**4 + 1.14233509921265e+141*cos(theta)**2 - 1.41904981268652e+138)*sin(75*phi)

#@torch.jit.script
def Yl85_m_minus_74(theta, phi):
    return 1.9200734880634e-137*(1.0 - cos(theta)**2)**37*(1.66829845438979e+145*cos(theta)**11 - 5.42937366813244e+144*cos(theta)**9 + 5.85201952253796e+143*cos(theta)**7 - 2.4826749489555e+142*cos(theta)**5 + 3.80778366404217e+140*cos(theta)**3 - 1.41904981268652e+138*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl85_m_minus_73(theta, phi):
    return 8.38700759315741e-136*(1.0 - cos(theta)**2)**36.5*(1.39024871199149e+144*cos(theta)**12 - 5.42937366813244e+143*cos(theta)**10 + 7.31502440317244e+142*cos(theta)**8 - 4.13779158159249e+141*cos(theta)**6 + 9.51945916010543e+139*cos(theta)**4 - 7.09524906343262e+137*cos(theta)**2 + 7.43736799101952e+134)*sin(73*phi)

#@torch.jit.script
def Yl85_m_minus_72(theta, phi):
    return 3.8010821503779e-134*(1.0 - cos(theta)**2)**36*(1.0694220861473e+143*cos(theta)**13 - 4.93579424375676e+142*cos(theta)**11 + 8.12780489241383e+141*cos(theta)**9 - 5.91113083084642e+140*cos(theta)**7 + 1.90389183202109e+139*cos(theta)**5 - 2.36508302114421e+137*cos(theta)**3 + 7.43736799101952e+134*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl85_m_minus_71(theta, phi):
    return 1.78205498455012e-132*(1.0 - cos(theta)**2)**35.5*(7.63872918676641e+141*cos(theta)**14 - 4.1131618697973e+141*cos(theta)**12 + 8.12780489241383e+140*cos(theta)**10 - 7.38891353855802e+139*cos(theta)**8 + 3.17315305336848e+138*cos(theta)**6 - 5.91270755286052e+136*cos(theta)**4 + 3.71868399550976e+134*cos(theta)**2 - 3.3836979031026e+131)*sin(71*phi)

#@torch.jit.script
def Yl85_m_minus_70(theta, phi):
    return 8.62043196424997e-131*(1.0 - cos(theta)**2)**35*(5.09248612451094e+140*cos(theta)**15 - 3.16397066907485e+140*cos(theta)**13 + 7.38891353855802e+139*cos(theta)**11 - 8.20990393173114e+138*cos(theta)**9 + 4.5330757905264e+137*cos(theta)**7 - 1.1825415105721e+136*cos(theta)**5 + 1.23956133183659e+134*cos(theta)**3 - 3.3836979031026e+131*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl85_m_minus_69(theta, phi):
    return 4.2929404978482e-129*(1.0 - cos(theta)**2)**34.5*(3.18280382781934e+139*cos(theta)**16 - 2.25997904933918e+139*cos(theta)**14 + 6.15742794879835e+138*cos(theta)**12 - 8.20990393173114e+137*cos(theta)**10 + 5.66634473815799e+136*cos(theta)**8 - 1.97090251762017e+135*cos(theta)**6 + 3.09890332959146e+133*cos(theta)**4 - 1.6918489515513e+131*cos(theta)**2 + 1.36439431576718e+128)*sin(69*phi)

#@torch.jit.script
def Yl85_m_minus_68(theta, phi):
    return 2.19654290176847e-127*(1.0 - cos(theta)**2)**34*(1.87223754577608e+138*cos(theta)**17 - 1.50665269955945e+138*cos(theta)**15 + 4.7364830375372e+137*cos(theta)**13 - 7.46354902884649e+136*cos(theta)**11 + 6.29593859795333e+135*cos(theta)**9 - 2.81557502517167e+134*cos(theta)**7 + 6.19780665918293e+132*cos(theta)**5 - 5.639496505171e+130*cos(theta)**3 + 1.36439431576718e+128*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl85_m_minus_67(theta, phi):
    return 1.15271423956583e-125*(1.0 - cos(theta)**2)**33.5*(1.0401319698756e+137*cos(theta)**18 - 9.41657937224657e+136*cos(theta)**16 + 3.38320216966942e+136*cos(theta)**14 - 6.21962419070541e+135*cos(theta)**12 + 6.29593859795333e+134*cos(theta)**10 - 3.51946878146459e+133*cos(theta)**8 + 1.03296777653049e+132*cos(theta)**6 - 1.40987412629275e+130*cos(theta)**4 + 6.82197157883589e+127*cos(theta)**2 - 4.95422772609723e+124)*sin(67*phi)

#@torch.jit.script
def Yl85_m_minus_66(theta, phi):
    return 6.19469962231141e-124*(1.0 - cos(theta)**2)**33*(5.47437878881895e+135*cos(theta)**19 - 5.53916433661563e+135*cos(theta)**17 + 2.25546811311295e+135*cos(theta)**15 - 4.78432630054262e+134*cos(theta)**13 + 5.72358054359393e+133*cos(theta)**11 - 3.91052086829399e+132*cos(theta)**9 + 1.47566825218641e+131*cos(theta)**7 - 2.8197482525855e+129*cos(theta)**5 + 2.27399052627863e+127*cos(theta)**3 - 4.95422772609723e+124*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl85_m_minus_65(theta, phi):
    return 3.4042678552107e-122*(1.0 - cos(theta)**2)**32.5*(2.73718939440948e+134*cos(theta)**20 - 3.07731352034202e+134*cos(theta)**18 + 1.40966757069559e+134*cos(theta)**16 - 3.41737592895901e+133*cos(theta)**14 + 4.76965045299494e+132*cos(theta)**12 - 3.91052086829399e+131*cos(theta)**10 + 1.84458531523301e+130*cos(theta)**8 - 4.69958042097583e+128*cos(theta)**6 + 5.68497631569657e+126*cos(theta)**4 - 2.47711386304862e+124*cos(theta)**2 + 1.64047275698584e+121)*sin(65*phi)

#@torch.jit.script
def Yl85_m_minus_64(theta, phi):
    return 1.91064059505093e-120*(1.0 - cos(theta)**2)**32*(1.30342352114737e+133*cos(theta)**21 - 1.61963869491685e+133*cos(theta)**19 + 8.29216218056232e+132*cos(theta)**17 - 2.27825061930601e+132*cos(theta)**15 + 3.66896188691919e+131*cos(theta)**13 - 3.55501897117636e+130*cos(theta)**11 + 2.04953923914779e+129*cos(theta)**9 - 6.71368631567976e+127*cos(theta)**7 + 1.13699526313931e+126*cos(theta)**5 - 8.25704621016205e+123*cos(theta)**3 + 1.64047275698584e+121*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl85_m_minus_63(theta, phi):
    return 1.09391474305682e-118*(1.0 - cos(theta)**2)**31.5*(5.92465236885168e+131*cos(theta)**22 - 8.09819347458425e+131*cos(theta)**20 + 4.60675676697906e+131*cos(theta)**18 - 1.42390663706626e+131*cos(theta)**16 + 2.62068706208513e+130*cos(theta)**14 - 2.96251580931363e+129*cos(theta)**12 + 2.04953923914779e+128*cos(theta)**10 - 8.3921078945997e+126*cos(theta)**8 + 1.89499210523219e+125*cos(theta)**6 - 2.06426155254051e+123*cos(theta)**4 + 8.20236378492919e+120*cos(theta)**2 - 5.00449285230579e+117)*sin(63*phi)

#@torch.jit.script
def Yl85_m_minus_62(theta, phi):
    return 6.38231523753122e-117*(1.0 - cos(theta)**2)**31*(2.57593581254421e+130*cos(theta)**23 - 3.85628260694488e+130*cos(theta)**21 + 2.42460882472582e+130*cos(theta)**19 - 8.37592139450739e+129*cos(theta)**17 + 1.74712470805676e+129*cos(theta)**15 - 2.27885831485664e+128*cos(theta)**13 + 1.86321749013436e+127*cos(theta)**11 - 9.324564327333e+125*cos(theta)**9 + 2.70713157890313e+124*cos(theta)**7 - 4.12852310508103e+122*cos(theta)**5 + 2.73412126164306e+120*cos(theta)**3 - 5.00449285230579e+117*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl85_m_minus_61(theta, phi):
    return 3.79090184266799e-115*(1.0 - cos(theta)**2)**30.5*(1.07330658856009e+129*cos(theta)**24 - 1.75285573042949e+129*cos(theta)**22 + 1.21230441236291e+129*cos(theta)**20 - 4.65328966361522e+128*cos(theta)**18 + 1.09195294253547e+128*cos(theta)**16 - 1.62775593918331e+127*cos(theta)**14 + 1.55268124177863e+126*cos(theta)**12 - 9.32456432733301e+124*cos(theta)**10 + 3.38391447362891e+123*cos(theta)**8 - 6.88087184180171e+121*cos(theta)**6 + 6.83530315410766e+119*cos(theta)**4 - 2.5022464261529e+117*cos(theta)**2 + 1.41850704430436e+114)*sin(61*phi)

#@torch.jit.script
def Yl85_m_minus_60(theta, phi):
    return 2.29028206231709e-113*(1.0 - cos(theta)**2)**30*(4.29322635424035e+127*cos(theta)**25 - 7.62111187143257e+127*cos(theta)**23 + 5.7728781541091e+127*cos(theta)**21 - 2.44909982295538e+127*cos(theta)**19 + 6.42325260314984e+126*cos(theta)**17 - 1.08517062612221e+126*cos(theta)**15 + 1.19437018598356e+125*cos(theta)**13 - 8.47687666121182e+123*cos(theta)**11 + 3.75990497069879e+122*cos(theta)**9 - 9.82981691685959e+120*cos(theta)**7 + 1.36706063082153e+119*cos(theta)**5 - 8.34082142050965e+116*cos(theta)**3 + 1.41850704430436e+114*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl85_m_minus_59(theta, phi):
    return 1.40624064644506e-111*(1.0 - cos(theta)**2)**29.5*(1.65124090547706e+126*cos(theta)**26 - 3.17546327976357e+126*cos(theta)**24 + 2.62403552459505e+126*cos(theta)**22 - 1.22454991147769e+126*cos(theta)**20 + 3.56847366841658e+125*cos(theta)**18 - 6.78231641326381e+124*cos(theta)**16 + 8.53121561416831e+123*cos(theta)**14 - 7.06406388434318e+122*cos(theta)**12 + 3.75990497069879e+121*cos(theta)**10 - 1.22872711460745e+120*cos(theta)**8 + 2.27843438470255e+118*cos(theta)**6 - 2.08520535512741e+116*cos(theta)**4 + 7.09253522152181e+113*cos(theta)**2 - 3.76261815465348e+110)*sin(59*phi)

#@torch.jit.script
def Yl85_m_minus_58(theta, phi):
    return 8.76844889032084e-110*(1.0 - cos(theta)**2)**29*(6.11570705732243e+124*cos(theta)**27 - 1.27018531190543e+125*cos(theta)**25 + 1.1408850106935e+125*cos(theta)**23 - 5.83119005465566e+124*cos(theta)**21 + 1.87814403600872e+124*cos(theta)**19 - 3.98959789015518e+123*cos(theta)**17 + 5.68747707611221e+122*cos(theta)**15 - 5.4338952956486e+121*cos(theta)**13 + 3.41809542790799e+120*cos(theta)**11 - 1.36525234956383e+119*cos(theta)**9 + 3.25490626386079e+117*cos(theta)**7 - 4.17041071025483e+115*cos(theta)**5 + 2.36417840717394e+113*cos(theta)**3 - 3.76261815465348e+110*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl85_m_minus_57(theta, phi):
    return 5.54842614218162e-108*(1.0 - cos(theta)**2)**28.5*(2.18418109190087e+123*cos(theta)**28 - 4.88532812271319e+123*cos(theta)**26 + 4.75368754455624e+123*cos(theta)**24 - 2.65054093393439e+123*cos(theta)**22 + 9.39072018004362e+122*cos(theta)**20 - 2.21644327230843e+122*cos(theta)**18 + 3.55467317257013e+121*cos(theta)**16 - 3.88135378260615e+120*cos(theta)**14 + 2.84841285658999e+119*cos(theta)**12 - 1.36525234956383e+118*cos(theta)**10 + 4.06863282982599e+116*cos(theta)**8 - 6.95068451709138e+114*cos(theta)**6 + 5.91044601793484e+112*cos(theta)**4 - 1.88130907732674e+110*cos(theta)**2 + 9.39714823839531e+106)*sin(57*phi)

#@torch.jit.script
def Yl85_m_minus_56(theta, phi):
    return 3.56051631753453e-106*(1.0 - cos(theta)**2)**28*(7.5316589375892e+121*cos(theta)**29 - 1.80938078619007e+122*cos(theta)**27 + 1.9014750178225e+122*cos(theta)**25 - 1.1524091017106e+122*cos(theta)**23 + 4.47177151430649e+121*cos(theta)**21 - 1.16654909068865e+121*cos(theta)**19 + 2.0909842191589e+120*cos(theta)**17 - 2.5875691884041e+119*cos(theta)**15 + 2.19108681276153e+118*cos(theta)**13 - 1.24113849960348e+117*cos(theta)**11 + 4.5207031442511e+115*cos(theta)**9 - 9.92954931013054e+113*cos(theta)**7 + 1.18208920358697e+112*cos(theta)**5 - 6.2710302577558e+109*cos(theta)**3 + 9.39714823839531e+106*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl85_m_minus_55(theta, phi):
    return 2.31570463083329e-104*(1.0 - cos(theta)**2)**27.5*(2.5105529791964e+120*cos(theta)**30 - 6.4620742363931e+120*cos(theta)**28 + 7.31336545316345e+120*cos(theta)**26 - 4.80170459046085e+120*cos(theta)**24 + 2.03262341559386e+120*cos(theta)**22 - 5.83274545344324e+119*cos(theta)**20 + 1.16165789953272e+119*cos(theta)**18 - 1.61723074275256e+118*cos(theta)**16 + 1.56506200911538e+117*cos(theta)**14 - 1.0342820830029e+116*cos(theta)**12 + 4.5207031442511e+114*cos(theta)**10 - 1.24119366376632e+113*cos(theta)**8 + 1.97014867264495e+111*cos(theta)**6 - 1.56775756443895e+109*cos(theta)**4 + 4.69857411919765e+106*cos(theta)**2 - 2.22154804690196e+103)*sin(55*phi)

#@torch.jit.script
def Yl85_m_minus_54(theta, phi):
    return 1.52555555938551e-102*(1.0 - cos(theta)**2)**27*(8.09855799740775e+118*cos(theta)**31 - 2.22830146082521e+119*cos(theta)**29 + 2.70865387154202e+119*cos(theta)**27 - 1.92068183618434e+119*cos(theta)**25 + 8.83749311127764e+118*cos(theta)**23 - 2.77749783497297e+118*cos(theta)**21 + 6.11398894490906e+117*cos(theta)**19 - 9.51312201619153e+116*cos(theta)**17 + 1.04337467274359e+116*cos(theta)**15 - 7.95601602309925e+114*cos(theta)**13 + 4.10973013113736e+113*cos(theta)**11 - 1.37910407085146e+112*cos(theta)**9 + 2.8144981037785e+110*cos(theta)**7 - 3.1355151288779e+108*cos(theta)**5 + 1.56619137306588e+106*cos(theta)**3 - 2.22154804690196e+103*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl85_m_minus_53(theta, phi):
    return 1.01744377307574e-100*(1.0 - cos(theta)**2)**26.5*(2.53079937418992e+117*cos(theta)**32 - 7.42767153608403e+117*cos(theta)**30 + 9.67376382693578e+117*cos(theta)**28 - 7.38723783147824e+117*cos(theta)**26 + 3.68228879636568e+117*cos(theta)**24 - 1.26249901589681e+117*cos(theta)**22 + 3.05699447245453e+116*cos(theta)**20 - 5.28506778677307e+115*cos(theta)**18 + 6.52109170464742e+114*cos(theta)**16 - 5.68286858792804e+113*cos(theta)**14 + 3.42477510928113e+112*cos(theta)**12 - 1.37910407085146e+111*cos(theta)**10 + 3.51812262972312e+109*cos(theta)**8 - 5.22585854812984e+107*cos(theta)**6 + 3.91547843266471e+105*cos(theta)**4 - 1.11077402345098e+103*cos(theta)**2 + 4.99448751551701e+99)*sin(53*phi)

#@torch.jit.script
def Yl85_m_minus_52(theta, phi):
    return 6.86604951923717e-99*(1.0 - cos(theta)**2)**26*(7.66908901269673e+115*cos(theta)**33 - 2.39602307615614e+116*cos(theta)**31 + 3.33578062997786e+116*cos(theta)**29 - 2.73601401165861e+116*cos(theta)**27 + 1.47291551854627e+116*cos(theta)**25 - 5.48912615607307e+115*cos(theta)**23 + 1.45571165354978e+115*cos(theta)**21 - 2.78161462461741e+114*cos(theta)**19 + 3.83593629685143e+113*cos(theta)**17 - 3.78857905861869e+112*cos(theta)**15 + 2.63444239175472e+111*cos(theta)**13 - 1.25373097350133e+110*cos(theta)**11 + 3.9090251441368e+108*cos(theta)**9 - 7.46551221161405e+106*cos(theta)**7 + 7.83095686532942e+104*cos(theta)**5 - 3.70258007816994e+102*cos(theta)**3 + 4.99448751551701e+99*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl85_m_minus_51(theta, phi):
    return 4.68604735881824e-97*(1.0 - cos(theta)**2)**25.5*(2.25561441549904e+114*cos(theta)**34 - 7.48757211298793e+114*cos(theta)**32 + 1.11192687665929e+115*cos(theta)**30 - 9.77147861306645e+114*cos(theta)**28 + 5.66505968671644e+114*cos(theta)**26 - 2.28713589836378e+114*cos(theta)**24 + 6.61687115249898e+113*cos(theta)**22 - 1.3908073123087e+113*cos(theta)**20 + 2.13107572047301e+112*cos(theta)**18 - 2.36786191163668e+111*cos(theta)**16 + 1.88174456553909e+110*cos(theta)**14 - 1.04477581125111e+109*cos(theta)**12 + 3.9090251441368e+107*cos(theta)**10 - 9.33189026451756e+105*cos(theta)**8 + 1.3051594775549e+104*cos(theta)**6 - 9.25645019542485e+101*cos(theta)**4 + 2.4972437577585e+99*cos(theta)**2 - 1.07223862505732e+96)*sin(51*phi)

#@torch.jit.script
def Yl85_m_minus_50(theta, phi):
    return 3.23303309110278e-95*(1.0 - cos(theta)**2)**25*(6.44461261571154e+112*cos(theta)**35 - 2.26896124635998e+113*cos(theta)**33 + 3.58686089244931e+113*cos(theta)**31 - 3.36947538381602e+113*cos(theta)**29 + 2.09817025433942e+113*cos(theta)**27 - 9.14854359345512e+112*cos(theta)**25 + 2.87690050108651e+112*cos(theta)**23 - 6.62289196337478e+111*cos(theta)**21 + 1.12161880024895e+111*cos(theta)**19 - 1.39285994802158e+110*cos(theta)**17 + 1.25449637702606e+109*cos(theta)**15 - 8.03673700962391e+107*cos(theta)**13 + 3.55365922194255e+106*cos(theta)**11 - 1.03687669605751e+105*cos(theta)**9 + 1.86451353936415e+103*cos(theta)**7 - 1.85129003908497e+101*cos(theta)**5 + 8.32414585919501e+98*cos(theta)**3 - 1.07223862505732e+96*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl85_m_minus_49(theta, phi):
    return 2.25386699752414e-93*(1.0 - cos(theta)**2)**24.5*(1.79017017103098e+111*cos(theta)**36 - 6.67341543047053e+111*cos(theta)**34 + 1.12089402889041e+112*cos(theta)**32 - 1.12315846127201e+112*cos(theta)**30 + 7.49346519406936e+111*cos(theta)**28 - 3.51867061286735e+111*cos(theta)**26 + 1.19870854211938e+111*cos(theta)**24 - 3.01040543789763e+110*cos(theta)**22 + 5.60809400124477e+109*cos(theta)**20 - 7.7381108223421e+108*cos(theta)**18 + 7.84060235641285e+107*cos(theta)**16 - 5.74052643544565e+106*cos(theta)**14 + 2.96138268495212e+105*cos(theta)**12 - 1.03687669605751e+104*cos(theta)**10 + 2.33064192420519e+102*cos(theta)**8 - 3.08548339847495e+100*cos(theta)**6 + 2.08103646479875e+98*cos(theta)**4 - 5.36119312528661e+95*cos(theta)**2 + 2.20625231493276e+92)*sin(49*phi)

#@torch.jit.script
def Yl85_m_minus_48(theta, phi):
    return 1.58701687836192e-91*(1.0 - cos(theta)**2)**24*(4.8382977595432e+109*cos(theta)**37 - 1.90669012299158e+110*cos(theta)**35 + 3.39664857239518e+110*cos(theta)**33 - 3.62309181055486e+110*cos(theta)**31 + 2.58395351519633e+110*cos(theta)**29 - 1.30321133809902e+110*cos(theta)**27 + 4.79483416847752e+109*cos(theta)**25 - 1.30887192952071e+109*cos(theta)**23 + 2.6705209529737e+108*cos(theta)**21 - 4.07268990649584e+107*cos(theta)**19 + 4.61211903318403e+106*cos(theta)**17 - 3.82701762363044e+105*cos(theta)**15 + 2.2779866807324e+104*cos(theta)**13 - 9.42615178234097e+102*cos(theta)**11 + 2.58960213800576e+101*cos(theta)**9 - 4.40783342639279e+99*cos(theta)**7 + 4.16207292959751e+97*cos(theta)**5 - 1.78706437509554e+95*cos(theta)**3 + 2.20625231493276e+92*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl85_m_minus_47(theta, phi):
    return 1.12823395091298e-89*(1.0 - cos(theta)**2)**23.5*(1.27323625251137e+108*cos(theta)**38 - 5.29636145275439e+108*cos(theta)**36 + 9.99014285998582e+108*cos(theta)**34 - 1.13221619079839e+109*cos(theta)**32 + 8.61317838398777e+108*cos(theta)**30 - 4.6543262074965e+108*cos(theta)**28 + 1.84416698787597e+108*cos(theta)**26 - 5.45363303966961e+107*cos(theta)**24 + 1.21387316044259e+107*cos(theta)**22 - 2.03634495324792e+106*cos(theta)**20 + 2.56228835176891e+105*cos(theta)**18 - 2.39188601476902e+104*cos(theta)**16 + 1.62713334338029e+103*cos(theta)**14 - 7.85512648528415e+101*cos(theta)**12 + 2.58960213800576e+100*cos(theta)**10 - 5.50979178299098e+98*cos(theta)**8 + 6.93678821599584e+96*cos(theta)**6 - 4.46766093773884e+94*cos(theta)**4 + 1.10312615746638e+92*cos(theta)**2 - 4.36535875530819e+88)*sin(47*phi)

#@torch.jit.script
def Yl85_m_minus_46(theta, phi):
    return 8.09502945854216e-88*(1.0 - cos(theta)**2)**23*(3.26470833977274e+106*cos(theta)**39 - 1.43144904128497e+107*cos(theta)**37 + 2.85432653142452e+107*cos(theta)**35 - 3.43095815393452e+107*cos(theta)**33 + 2.77844463999606e+107*cos(theta)**31 - 1.60494007155052e+107*cos(theta)**29 + 6.83024810324434e+106*cos(theta)**27 - 2.18145321586785e+106*cos(theta)**25 + 5.27770939322866e+105*cos(theta)**23 - 9.696880729752e+104*cos(theta)**21 + 1.34857281672048e+104*cos(theta)**19 - 1.40699177339354e+103*cos(theta)**17 + 1.08475556225352e+102*cos(theta)**15 - 6.04240498868011e+100*cos(theta)**13 + 2.35418376182342e+99*cos(theta)**11 - 6.12199086998998e+97*cos(theta)**9 + 9.90969745142263e+95*cos(theta)**7 - 8.93532187547768e+93*cos(theta)**5 + 3.6770871915546e+91*cos(theta)**3 - 4.36535875530819e+88*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl85_m_minus_45(theta, phi):
    return 5.8598173191461e-86*(1.0 - cos(theta)**2)**22.5*(8.16177084943184e+104*cos(theta)**40 - 3.76697116127623e+105*cos(theta)**38 + 7.92868480951255e+105*cos(theta)**36 - 1.00910533939251e+106*cos(theta)**34 + 8.68263949998767e+105*cos(theta)**32 - 5.34980023850172e+105*cos(theta)**30 + 2.43937432258726e+105*cos(theta)**28 - 8.39020467641479e+104*cos(theta)**26 + 2.19904558051194e+104*cos(theta)**24 - 4.40767305897818e+103*cos(theta)**22 + 6.74286408360239e+102*cos(theta)**20 - 7.81662096329746e+101*cos(theta)**18 + 6.77972226408453e+100*cos(theta)**16 - 4.31600356334294e+99*cos(theta)**14 + 1.96181980151952e+98*cos(theta)**12 - 6.12199086998998e+96*cos(theta)**10 + 1.23871218142783e+95*cos(theta)**8 - 1.48922031257961e+93*cos(theta)**6 + 9.19271797888651e+90*cos(theta)**4 - 2.1826793776541e+88*cos(theta)**2 + 8.33083731929045e+84)*sin(45*phi)

#@torch.jit.script
def Yl85_m_minus_44(theta, phi):
    return 4.27806798150012e-84*(1.0 - cos(theta)**2)**22*(1.9906758169346e+103*cos(theta)**41 - 9.65890041352881e+103*cos(theta)**39 + 2.14288778635474e+104*cos(theta)**37 - 2.88315811255002e+104*cos(theta)**35 + 2.63110287878414e+104*cos(theta)**33 - 1.72574201241991e+104*cos(theta)**31 + 8.41163559512849e+103*cos(theta)**29 - 3.10748321348696e+103*cos(theta)**27 + 8.79618232204776e+102*cos(theta)**25 - 1.91637959086008e+102*cos(theta)**23 + 3.21088765885828e+101*cos(theta)**21 - 4.11401103331445e+100*cos(theta)**19 + 3.98807192004972e+99*cos(theta)**17 - 2.87733570889529e+98*cos(theta)**15 + 1.50909215501501e+97*cos(theta)**13 - 5.56544624544544e+95*cos(theta)**11 + 1.37634686825314e+94*cos(theta)**9 - 2.12745758939945e+92*cos(theta)**7 + 1.8385435957773e+90*cos(theta)**5 - 7.27559792551366e+87*cos(theta)**3 + 8.33083731929045e+84*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl85_m_minus_43(theta, phi):
    return 3.14896027468108e-82*(1.0 - cos(theta)**2)**21.5*(4.73970432603475e+101*cos(theta)**42 - 2.4147251033822e+102*cos(theta)**40 + 5.63917838514406e+102*cos(theta)**38 - 8.00877253486117e+102*cos(theta)**36 + 7.73853787877689e+102*cos(theta)**34 - 5.39294378881222e+102*cos(theta)**32 + 2.8038785317095e+102*cos(theta)**30 - 1.1098154333882e+102*cos(theta)**28 + 3.38314704694145e+101*cos(theta)**26 - 7.984914961917e+100*cos(theta)**24 + 1.45949439039013e+100*cos(theta)**22 - 2.05700551665723e+99*cos(theta)**20 + 2.21559551113874e+98*cos(theta)**18 - 1.79833481805956e+97*cos(theta)**16 + 1.07792296786787e+96*cos(theta)**14 - 4.63787187120453e+94*cos(theta)**12 + 1.37634686825314e+93*cos(theta)**10 - 2.65932198674931e+91*cos(theta)**8 + 3.0642393262955e+89*cos(theta)**6 - 1.81889948137841e+87*cos(theta)**4 + 4.16541865964522e+84*cos(theta)**2 - 1.53762224423965e+81)*sin(43*phi)

#@torch.jit.script
def Yl85_m_minus_42(theta, phi):
    return 2.3361804995891e-80*(1.0 - cos(theta)**2)**21*(1.10225682000808e+100*cos(theta)**43 - 5.88957342288342e+100*cos(theta)**41 + 1.44594317567797e+101*cos(theta)**39 - 2.16453311753004e+101*cos(theta)**37 + 2.21101082250768e+101*cos(theta)**35 - 1.63422539054916e+101*cos(theta)**33 + 9.04476945712741e+100*cos(theta)**31 - 3.82694977030414e+100*cos(theta)**29 + 1.25301742479313e+100*cos(theta)**27 - 3.1939659847668e+99*cos(theta)**25 + 6.3456277843049e+98*cos(theta)**23 - 9.79526436503441e+97*cos(theta)**21 + 1.16610290059933e+97*cos(theta)**19 - 1.05784401062327e+96*cos(theta)**17 + 7.18615311911911e+94*cos(theta)**15 - 3.56759374708041e+93*cos(theta)**13 + 1.25122442568468e+92*cos(theta)**11 - 2.95480220749923e+90*cos(theta)**9 + 4.37748475185072e+88*cos(theta)**7 - 3.63779896275683e+86*cos(theta)**5 + 1.38847288654841e+84*cos(theta)**3 - 1.53762224423965e+81*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl85_m_minus_41(theta, phi):
    return 1.74636328859084e-78*(1.0 - cos(theta)**2)**20.5*(2.505129136382e+98*cos(theta)**44 - 1.40227938640081e+99*cos(theta)**42 + 3.61485793919491e+99*cos(theta)**40 - 5.6961397829738e+99*cos(theta)**38 + 6.14169672918801e+99*cos(theta)**36 - 4.80654526632105e+99*cos(theta)**34 + 2.82649045535232e+99*cos(theta)**32 - 1.27564992343471e+99*cos(theta)**30 + 4.47506223140403e+98*cos(theta)**28 - 1.22844845567954e+98*cos(theta)**26 + 2.64401157679371e+97*cos(theta)**24 - 4.45239289319746e+96*cos(theta)**22 + 5.83051450299667e+95*cos(theta)**20 - 5.87691117012927e+94*cos(theta)**18 + 4.49134569944944e+93*cos(theta)**16 - 2.54828124791458e+92*cos(theta)**14 + 1.0426870214039e+91*cos(theta)**12 - 2.95480220749923e+89*cos(theta)**10 + 5.4718559398134e+87*cos(theta)**8 - 6.06299827126138e+85*cos(theta)**6 + 3.47118221637102e+83*cos(theta)**4 - 7.68811122119827e+80*cos(theta)**2 + 2.75165040128786e+77)*sin(41*phi)

#@torch.jit.script
def Yl85_m_minus_40(theta, phi):
    return 1.31500111983349e-76*(1.0 - cos(theta)**2)**20*(5.56695363640445e+96*cos(theta)**45 - 3.26111485209492e+97*cos(theta)**43 + 8.8167266809632e+97*cos(theta)**41 - 1.46054866230097e+98*cos(theta)**39 + 1.65991803491568e+98*cos(theta)**37 - 1.3732986475203e+98*cos(theta)**35 + 8.56512259197672e+97*cos(theta)**33 - 4.1149997530152e+97*cos(theta)**31 + 1.5431249073807e+97*cos(theta)**29 - 4.5498090951094e+96*cos(theta)**27 + 1.05760463071748e+96*cos(theta)**25 - 1.93582299704237e+95*cos(theta)**23 + 2.77643547761746e+94*cos(theta)**21 - 3.0931111421733e+93*cos(theta)**19 + 2.64196805849967e+92*cos(theta)**17 - 1.69885416527639e+91*cos(theta)**15 + 8.02066939541459e+89*cos(theta)**13 - 2.6861838249993e+88*cos(theta)**11 + 6.079839933126e+86*cos(theta)**9 - 8.66142610180197e+84*cos(theta)**7 + 6.94236443274204e+82*cos(theta)**5 - 2.56270374039942e+80*cos(theta)**3 + 2.75165040128786e+77*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl85_m_minus_39(theta, phi):
    return 9.97148970048567e-75*(1.0 - cos(theta)**2)**19.5*(1.21020731226184e+95*cos(theta)**46 - 7.41162466385208e+95*cos(theta)**44 + 2.09922063832457e+96*cos(theta)**42 - 3.65137165575244e+96*cos(theta)**40 + 4.36820535504126e+96*cos(theta)**38 - 3.81471846533417e+96*cos(theta)**36 + 2.51915370352256e+96*cos(theta)**34 - 1.28593742281725e+96*cos(theta)**32 + 5.143749691269e+95*cos(theta)**30 - 1.62493181968193e+95*cos(theta)**28 + 4.06771011814417e+94*cos(theta)**26 - 8.06592915434322e+93*cos(theta)**24 + 1.26201612618976e+93*cos(theta)**22 - 1.54655557108665e+92*cos(theta)**20 + 1.46776003249982e+91*cos(theta)**18 - 1.06178385329774e+90*cos(theta)**16 + 5.72904956815328e+88*cos(theta)**14 - 2.23848652083275e+87*cos(theta)**12 + 6.079839933126e+85*cos(theta)**10 - 1.08267826272525e+84*cos(theta)**8 + 1.15706073879034e+82*cos(theta)**6 - 6.40675935099856e+79*cos(theta)**4 + 1.37582520064393e+77*cos(theta)**2 - 4.78547895876149e+73)*sin(39*phi)

#@torch.jit.script
def Yl85_m_minus_38(theta, phi):
    return 7.61236872927005e-73*(1.0 - cos(theta)**2)**19*(2.57490917502519e+93*cos(theta)**47 - 1.64702770307824e+94*cos(theta)**45 + 4.88190846121993e+94*cos(theta)**43 - 8.90578452622546e+94*cos(theta)**41 + 1.12005265513878e+95*cos(theta)**39 - 1.03100499063086e+95*cos(theta)**37 + 7.19758201006447e+94*cos(theta)**35 - 3.89678006914318e+94*cos(theta)**33 + 1.65927409395774e+94*cos(theta)**31 - 5.603213171317e+93*cos(theta)**29 + 1.50655930301636e+93*cos(theta)**27 - 3.22637166173729e+92*cos(theta)**25 + 5.48702663560763e+91*cos(theta)**23 - 7.36455033850786e+90*cos(theta)**21 + 7.72505280263062e+89*cos(theta)**19 - 6.24578737233965e+88*cos(theta)**17 + 3.81936637876885e+87*cos(theta)**15 - 1.72191270833289e+86*cos(theta)**13 + 5.52712721193272e+84*cos(theta)**11 - 1.2029758474725e+83*cos(theta)**9 + 1.65294391255763e+81*cos(theta)**7 - 1.28135187019971e+79*cos(theta)**5 + 4.58608400214643e+76*cos(theta)**3 - 4.78547895876149e+73*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl85_m_minus_37(theta, phi):
    return 5.8491531257598e-71*(1.0 - cos(theta)**2)**18.5*(5.36439411463581e+91*cos(theta)**48 - 3.58049500669183e+92*cos(theta)**46 + 1.10952465027726e+93*cos(theta)**44 - 2.12042488719654e+93*cos(theta)**42 + 2.80013163784696e+93*cos(theta)**40 - 2.71317102797594e+93*cos(theta)**38 + 1.99932833612902e+93*cos(theta)**36 - 1.14611178504211e+93*cos(theta)**34 + 5.18523154361795e+92*cos(theta)**32 - 1.86773772377233e+92*cos(theta)**30 + 5.38056893934414e+91*cos(theta)**28 - 1.24091217759126e+91*cos(theta)**26 + 2.28626109816985e+90*cos(theta)**24 - 3.34752288113994e+89*cos(theta)**22 + 3.86252640131531e+88*cos(theta)**20 - 3.46988187352203e+87*cos(theta)**18 + 2.38710398673053e+86*cos(theta)**16 - 1.22993764880921e+85*cos(theta)**14 + 4.60593934327727e+83*cos(theta)**12 - 1.2029758474725e+82*cos(theta)**10 + 2.06617989069704e+80*cos(theta)**8 - 2.13558645033285e+78*cos(theta)**6 + 1.14652100053661e+76*cos(theta)**4 - 2.39273947938075e+73*cos(theta)**2 + 8.10548604126269e+69)*sin(37*phi)

#@torch.jit.script
def Yl85_m_minus_36(theta, phi):
    return 4.52242055431784e-69*(1.0 - cos(theta)**2)**18*(1.09477430910935e+90*cos(theta)**49 - 7.61807448232304e+90*cos(theta)**47 + 2.46561033394946e+91*cos(theta)**45 - 4.93122066789892e+91*cos(theta)**43 + 6.82958936060234e+91*cos(theta)**41 - 6.95684878968189e+91*cos(theta)**39 + 5.403590097646e+91*cos(theta)**37 - 3.27460510012032e+91*cos(theta)**35 + 1.57128228594483e+91*cos(theta)**33 - 6.02496039926559e+90*cos(theta)**31 + 1.85536859977384e+90*cos(theta)**29 - 4.5959710281158e+89*cos(theta)**27 + 9.14504439267939e+88*cos(theta)**25 - 1.45544473093041e+88*cos(theta)**23 + 1.83929828634062e+87*cos(theta)**21 - 1.82625361764317e+86*cos(theta)**19 + 1.40417881572384e+85*cos(theta)**17 - 8.1995843253947e+83*cos(theta)**15 + 3.54303026405944e+82*cos(theta)**13 - 1.09361440679318e+81*cos(theta)**11 + 2.29575543410782e+79*cos(theta)**9 - 3.05083778618979e+77*cos(theta)**7 + 2.29304200107321e+75*cos(theta)**5 - 7.97579826460248e+72*cos(theta)**3 + 8.10548604126269e+69*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl85_m_minus_35(theta, phi):
    return 3.51761766546913e-67*(1.0 - cos(theta)**2)**17.5*(2.1895486182187e+88*cos(theta)**50 - 1.58709885048397e+89*cos(theta)**48 + 5.36002246510753e+89*cos(theta)**46 - 1.12073196997703e+90*cos(theta)**44 + 1.62609270490532e+90*cos(theta)**42 - 1.73921219742047e+90*cos(theta)**40 + 1.42199739411737e+90*cos(theta)**38 - 9.09612527811201e+89*cos(theta)**36 + 4.62141848807304e+89*cos(theta)**34 - 1.8828001247705e+89*cos(theta)**32 + 6.18456199924613e+88*cos(theta)**30 - 1.64141822432707e+88*cos(theta)**28 + 3.51732476641515e+87*cos(theta)**26 - 6.06435304554336e+86*cos(theta)**24 + 8.36044675609375e+85*cos(theta)**22 - 9.13126808821586e+84*cos(theta)**20 + 7.80099342068801e+83*cos(theta)**18 - 5.12474020337169e+82*cos(theta)**16 + 2.5307359028996e+81*cos(theta)**14 - 9.11345338994315e+79*cos(theta)**12 + 2.29575543410782e+78*cos(theta)**10 - 3.81354723273724e+76*cos(theta)**8 + 3.82173666845536e+74*cos(theta)**6 - 1.99394956615062e+72*cos(theta)**4 + 4.05274302063134e+69*cos(theta)**2 - 1.33974975888639e+66)*sin(35*phi)

#@torch.jit.script
def Yl85_m_minus_34(theta, phi):
    return 2.75184738543716e-65*(1.0 - cos(theta)**2)**17*(4.29323258474254e+86*cos(theta)**51 - 3.23897724588565e+87*cos(theta)**49 + 1.14043031172501e+88*cos(theta)**47 - 2.49051548883784e+88*cos(theta)**45 + 3.78161094164028e+88*cos(theta)**43 - 4.24198096931823e+88*cos(theta)**41 + 3.64614716440351e+88*cos(theta)**39 - 2.45841223732757e+88*cos(theta)**37 + 1.32040528230658e+88*cos(theta)**35 - 5.70545492354696e+87*cos(theta)**33 + 1.99501999975682e+87*cos(theta)**31 - 5.66006284250714e+86*cos(theta)**29 + 1.30271287645006e+86*cos(theta)**27 - 2.42574121821734e+85*cos(theta)**25 + 3.63497685047554e+84*cos(theta)**23 - 4.34822289915041e+83*cos(theta)**21 + 4.10578601088843e+82*cos(theta)**19 - 3.01455306080688e+81*cos(theta)**17 + 1.68715726859973e+80*cos(theta)**15 - 7.01034876149473e+78*cos(theta)**13 + 2.08705039464347e+77*cos(theta)**11 - 4.23727470304138e+75*cos(theta)**9 + 5.45962381207908e+73*cos(theta)**7 - 3.98789913230124e+71*cos(theta)**5 + 1.35091434021045e+69*cos(theta)**3 - 1.33974975888639e+66*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl85_m_minus_33(theta, phi):
    return 2.16470887267962e-63*(1.0 - cos(theta)**2)**16.5*(8.25621650912027e+84*cos(theta)**52 - 6.47795449177129e+85*cos(theta)**50 + 2.37589648276043e+86*cos(theta)**48 - 5.41416410616922e+86*cos(theta)**46 + 8.59457032190973e+86*cos(theta)**44 - 1.00999546888529e+87*cos(theta)**42 + 9.11536791100877e+86*cos(theta)**40 - 6.46950588770413e+86*cos(theta)**38 + 3.66779245085162e+86*cos(theta)**36 - 1.67807497751381e+86*cos(theta)**34 + 6.23443749924005e+85*cos(theta)**32 - 1.88668761416905e+85*cos(theta)**30 + 4.65254598732163e+84*cos(theta)**28 - 9.32977391622056e+83*cos(theta)**26 + 1.51457368769814e+83*cos(theta)**24 - 1.97646495415928e+82*cos(theta)**22 + 2.05289300544421e+81*cos(theta)**20 - 1.67475170044826e+80*cos(theta)**18 + 1.05447329287483e+79*cos(theta)**16 - 5.00739197249624e+77*cos(theta)**14 + 1.73920866220289e+76*cos(theta)**12 - 4.23727470304138e+74*cos(theta)**10 + 6.82452976509885e+72*cos(theta)**8 - 6.6464985538354e+70*cos(theta)**6 + 3.37728585052612e+68*cos(theta)**4 - 6.69874879443197e+65*cos(theta)**2 + 2.16507717984227e+62)*sin(33*phi)

#@torch.jit.script
def Yl85_m_minus_32(theta, phi):
    return 1.71190017245824e-61*(1.0 - cos(theta)**2)**16*(1.55777669983401e+83*cos(theta)**53 - 1.27018715524927e+84*cos(theta)**51 + 4.84876833216414e+84*cos(theta)**49 - 1.15194980982324e+85*cos(theta)**47 + 1.90990451597994e+85*cos(theta)**45 - 2.34882667182626e+85*cos(theta)**43 + 2.2232604660997e+85*cos(theta)**41 - 1.65884766351388e+85*cos(theta)**39 + 9.91295256986923e+84*cos(theta)**37 - 4.79449993575375e+84*cos(theta)**35 + 1.8892234846182e+84*cos(theta)**33 - 6.08608907796466e+83*cos(theta)**31 + 1.6043262025247e+83*cos(theta)**29 - 3.45547182082243e+82*cos(theta)**27 + 6.05829475079257e+81*cos(theta)**25 - 8.59332588764903e+80*cos(theta)**23 + 9.77568097830578e+79*cos(theta)**21 - 8.81448263393823e+78*cos(theta)**19 + 6.20278407573431e+77*cos(theta)**17 - 3.33826131499749e+76*cos(theta)**15 + 1.33785281707915e+75*cos(theta)**13 - 3.8520679118558e+73*cos(theta)**11 + 7.58281085010983e+71*cos(theta)**9 - 9.49499793405058e+69*cos(theta)**7 + 6.75457170105224e+67*cos(theta)**5 - 2.23291626481066e+65*cos(theta)**3 + 2.16507717984227e+62*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl85_m_minus_31(theta, phi):
    return 1.36071836551589e-59*(1.0 - cos(theta)**2)**15.5*(2.88477166635928e+81*cos(theta)**54 - 2.4426676062486e+82*cos(theta)**52 + 9.69753666432828e+82*cos(theta)**50 - 2.39989543713175e+83*cos(theta)**48 + 4.15196633908682e+83*cos(theta)**46 - 5.33824243596877e+83*cos(theta)**44 + 5.29347730023738e+83*cos(theta)**42 - 4.1471191587847e+83*cos(theta)**40 + 2.60867172891296e+83*cos(theta)**38 - 1.33180553770937e+83*cos(theta)**36 + 5.55653966064176e+82*cos(theta)**34 - 1.90190283686396e+82*cos(theta)**32 + 5.34775400841566e+81*cos(theta)**30 - 1.23409707886515e+81*cos(theta)**28 + 2.33011336568945e+80*cos(theta)**26 - 3.5805524531871e+79*cos(theta)**24 + 4.44349135377536e+78*cos(theta)**22 - 4.40724131696912e+77*cos(theta)**20 + 3.44599115318573e+76*cos(theta)**18 - 2.08641332187343e+75*cos(theta)**16 + 9.55609155056534e+73*cos(theta)**14 - 3.21005659321316e+72*cos(theta)**12 + 7.58281085010983e+70*cos(theta)**10 - 1.18687474175632e+69*cos(theta)**8 + 1.12576195017537e+67*cos(theta)**6 - 5.58229066202664e+64*cos(theta)**4 + 1.08253858992113e+62*cos(theta)**2 - 3.42683947426759e+58)*sin(31*phi)

#@torch.jit.script
def Yl85_m_minus_30(theta, phi):
    return 1.08687246354893e-57*(1.0 - cos(theta)**2)**15*(5.24503939338052e+79*cos(theta)**55 - 4.60880680424264e+80*cos(theta)**53 + 1.90147777731927e+81*cos(theta)**51 - 4.89774579006479e+81*cos(theta)**49 + 8.83397093422728e+81*cos(theta)**47 - 1.18627609688195e+82*cos(theta)**45 + 1.23104123261334e+82*cos(theta)**43 - 1.01149247775237e+82*cos(theta)**41 + 6.68890186900758e+81*cos(theta)**39 - 3.59947442624155e+81*cos(theta)**37 + 1.58758276018336e+81*cos(theta)**35 - 5.76334192989078e+80*cos(theta)**33 + 1.7250819381986e+80*cos(theta)**31 - 4.25550716850053e+79*cos(theta)**29 + 8.63004950255352e+78*cos(theta)**27 - 1.43222098127484e+78*cos(theta)**25 + 1.93195276251102e+77*cos(theta)**23 - 2.09868634141386e+76*cos(theta)**21 + 1.81367955430828e+75*cos(theta)**19 - 1.2273019540432e+74*cos(theta)**17 + 6.37072770037689e+72*cos(theta)**15 - 2.46927430247166e+71*cos(theta)**13 + 6.89346440919076e+69*cos(theta)**11 - 1.31874971306258e+68*cos(theta)**9 + 1.60823135739339e+66*cos(theta)**7 - 1.11645813240533e+64*cos(theta)**5 + 3.60846196640378e+61*cos(theta)**3 - 3.42683947426759e+58*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl85_m_minus_29(theta, phi):
    return 8.72210919618343e-56*(1.0 - cos(theta)**2)**14.5*(9.36614177389378e+77*cos(theta)**56 - 8.53482741526415e+78*cos(theta)**54 + 3.65668803330629e+79*cos(theta)**52 - 9.79549158012957e+79*cos(theta)**50 + 1.84041061129735e+80*cos(theta)**48 - 2.57886108017815e+80*cos(theta)**46 + 2.79782098321215e+80*cos(theta)**44 - 2.40831542321992e+80*cos(theta)**42 + 1.67222546725189e+80*cos(theta)**40 - 9.47230112168829e+79*cos(theta)**38 + 4.40995211162044e+79*cos(theta)**36 - 1.69510056761494e+79*cos(theta)**34 + 5.39088105687063e+78*cos(theta)**32 - 1.41850238950018e+78*cos(theta)**30 + 3.08216053662626e+77*cos(theta)**28 - 5.50854223567246e+76*cos(theta)**26 + 8.04980317712927e+75*cos(theta)**24 - 9.53948337006302e+74*cos(theta)**22 + 9.06839777154139e+73*cos(theta)**20 - 6.81834418912886e+72*cos(theta)**18 + 3.98170481273556e+71*cos(theta)**16 - 1.76376735890833e+70*cos(theta)**14 + 5.74455367432563e+68*cos(theta)**12 - 1.31874971306258e+67*cos(theta)**10 + 2.01028919674174e+65*cos(theta)**8 - 1.86076355400888e+63*cos(theta)**6 + 9.02115491600944e+60*cos(theta)**4 - 1.7134197371338e+58*cos(theta)**2 + 5.32117930786894e+54)*sin(29*phi)

#@torch.jit.script
def Yl85_m_minus_28(theta, phi):
    return 7.03090731711277e-54*(1.0 - cos(theta)**2)**14*(1.64318276734979e+76*cos(theta)**57 - 1.5517868027753e+77*cos(theta)**55 + 6.89941138359677e+77*cos(theta)**53 - 1.92068462355482e+78*cos(theta)**51 + 3.75594002305582e+78*cos(theta)**49 - 5.48693846846415e+78*cos(theta)**47 + 6.21737996269366e+78*cos(theta)**45 - 5.6007335423719e+78*cos(theta)**43 + 4.07859870061438e+78*cos(theta)**41 - 2.42879515940725e+78*cos(theta)**39 + 1.19187894908661e+78*cos(theta)**37 - 4.84314447889982e+77*cos(theta)**35 + 1.63360032026383e+77*cos(theta)**33 - 4.57581415967799e+76*cos(theta)**31 + 1.06281397814698e+76*cos(theta)**29 - 2.04020082802684e+75*cos(theta)**27 + 3.21992127085171e+74*cos(theta)**25 - 4.14760146524479e+73*cos(theta)**23 + 4.31828465311495e+72*cos(theta)**21 - 3.58860220480467e+71*cos(theta)**19 + 2.34217930160915e+70*cos(theta)**17 - 1.17584490593889e+69*cos(theta)**15 + 4.41888744178895e+67*cos(theta)**13 - 1.19886337551144e+66*cos(theta)**11 + 2.23365466304638e+64*cos(theta)**9 - 2.65823364858412e+62*cos(theta)**7 + 1.80423098320189e+60*cos(theta)**5 - 5.71139912377932e+57*cos(theta)**3 + 5.32117930786894e+54*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl85_m_minus_27(theta, phi):
    return 5.69199606972627e-52*(1.0 - cos(theta)**2)**13.5*(2.83307373680998e+74*cos(theta)**58 - 2.77104786209875e+75*cos(theta)**56 + 1.27766877474014e+76*cos(theta)**54 - 3.69362427606696e+76*cos(theta)**52 + 7.51188004611164e+76*cos(theta)**50 - 1.14311218093003e+77*cos(theta)**48 + 1.35160433971601e+77*cos(theta)**46 - 1.27289398690271e+77*cos(theta)**44 + 9.71094928717709e+76*cos(theta)**42 - 6.07198789851814e+76*cos(theta)**40 + 3.13652355022791e+76*cos(theta)**38 - 1.3453179108055e+76*cos(theta)**36 + 4.80470682430537e+75*cos(theta)**34 - 1.42994192489937e+75*cos(theta)**32 + 3.54271326048995e+74*cos(theta)**30 - 7.28643152866727e+73*cos(theta)**28 + 1.23843125801989e+73*cos(theta)**26 - 1.72816727718533e+72*cos(theta)**24 + 1.96285666050679e+71*cos(theta)**22 - 1.79430110240233e+70*cos(theta)**20 + 1.3012107231162e+69*cos(theta)**18 - 7.34903066211805e+67*cos(theta)**16 + 3.15634817270639e+66*cos(theta)**14 - 9.99052812926197e+64*cos(theta)**12 + 2.23365466304638e+63*cos(theta)**10 - 3.32279206073014e+61*cos(theta)**8 + 3.00705163866981e+59*cos(theta)**6 - 1.42784978094483e+57*cos(theta)**4 + 2.66058965393447e+54*cos(theta)**2 - 8.11897971905544e+50)*sin(27*phi)

#@torch.jit.script
def Yl85_m_minus_26(theta, phi):
    return 4.62700116333901e-50*(1.0 - cos(theta)**2)**13*(4.80181989289826e+72*cos(theta)**59 - 4.86148747736623e+73*cos(theta)**57 + 2.32303413589117e+74*cos(theta)**55 - 6.96910240767351e+74*cos(theta)**53 + 1.47291765610032e+75*cos(theta)**51 - 2.33288200189802e+75*cos(theta)**49 + 2.87575391428939e+75*cos(theta)**47 - 2.82865330422823e+75*cos(theta)**45 + 2.25836029934351e+75*cos(theta)**43 - 1.48097265817516e+75*cos(theta)**41 + 8.04236807750746e+74*cos(theta)**39 - 3.63599435352839e+74*cos(theta)**37 + 1.37277337837296e+74*cos(theta)**35 - 4.33315734817991e+73*cos(theta)**33 + 1.14281072919031e+73*cos(theta)**31 - 2.51256259609216e+72*cos(theta)**29 + 4.58678243711069e+71*cos(theta)**27 - 6.91266910874132e+70*cos(theta)**25 + 8.5341593935078e+69*cos(theta)**23 - 8.54429096382063e+68*cos(theta)**21 + 6.84847749008524e+67*cos(theta)**19 - 4.32295921301062e+66*cos(theta)**17 + 2.10423211513759e+65*cos(theta)**15 - 7.68502163789382e+63*cos(theta)**13 + 2.03059514822398e+62*cos(theta)**11 - 3.69199117858905e+60*cos(theta)**9 + 4.29578805524259e+58*cos(theta)**7 - 2.85569956188966e+56*cos(theta)**5 + 8.86863217978156e+53*cos(theta)**3 - 8.11897971905544e+50*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl85_m_minus_25(theta, phi):
    return 3.77604119202241e-48*(1.0 - cos(theta)**2)**12.5*(8.00303315483044e+70*cos(theta)**60 - 8.38187496097626e+71*cos(theta)**58 + 4.1482752426628e+72*cos(theta)**56 - 1.29057451993954e+73*cos(theta)**54 + 2.83253395403908e+73*cos(theta)**52 - 4.66576400379605e+73*cos(theta)**50 + 5.99115398810289e+73*cos(theta)**48 - 6.14924631353964e+73*cos(theta)**46 + 5.13263704396252e+73*cos(theta)**44 - 3.52612537660751e+73*cos(theta)**42 + 2.01059201937687e+73*cos(theta)**40 - 9.56840619349576e+72*cos(theta)**38 + 3.81325938436934e+72*cos(theta)**36 - 1.27445804358233e+72*cos(theta)**34 + 3.57128352871971e+71*cos(theta)**32 - 8.37520865364054e+70*cos(theta)**30 + 1.63813658468239e+70*cos(theta)**28 - 2.65871888797743e+69*cos(theta)**26 + 3.55589974729492e+68*cos(theta)**24 - 3.88376861991847e+67*cos(theta)**22 + 3.42423874504262e+66*cos(theta)**20 - 2.40164400722812e+65*cos(theta)**18 + 1.315145071961e+64*cos(theta)**16 - 5.48930116992416e+62*cos(theta)**14 + 1.69216262351998e+61*cos(theta)**12 - 3.69199117858905e+59*cos(theta)**10 + 5.36973506905324e+57*cos(theta)**8 - 4.7594992698161e+55*cos(theta)**6 + 2.21715804494539e+53*cos(theta)**4 - 4.05948985952772e+50*cos(theta)**2 + 1.2190660238822e+47)*sin(25*phi)

#@torch.jit.script
def Yl85_m_minus_24(theta, phi):
    return 3.09312864802992e-46*(1.0 - cos(theta)**2)**12*(1.31197264833286e+69*cos(theta)**61 - 1.42065677304682e+70*cos(theta)**59 + 7.2776758643207e+70*cos(theta)**57 - 2.3464991271628e+71*cos(theta)**55 + 5.34440368686619e+71*cos(theta)**53 - 9.14855687018833e+71*cos(theta)**51 + 1.22268448736794e+72*cos(theta)**49 - 1.30835027947652e+72*cos(theta)**47 + 1.14058600976945e+72*cos(theta)**45 - 8.20029157350584e+71*cos(theta)**43 + 4.90388297408992e+71*cos(theta)**41 - 2.45343748551173e+71*cos(theta)**39 + 1.03061064442415e+71*cos(theta)**37 - 3.64130869594951e+70*cos(theta)**35 + 1.08220712991506e+70*cos(theta)**33 - 2.70168021085179e+69*cos(theta)**31 + 5.64874684373238e+68*cos(theta)**29 - 9.847106992509e+67*cos(theta)**27 + 1.42235989891797e+67*cos(theta)**25 - 1.68859505213846e+66*cos(theta)**23 + 1.63058987859172e+65*cos(theta)**21 - 1.26402316169901e+64*cos(theta)**19 + 7.73614748212351e+62*cos(theta)**17 - 3.65953411328277e+61*cos(theta)**15 + 1.30166355655383e+60*cos(theta)**13 - 3.35635561689914e+58*cos(theta)**11 + 5.96637229894804e+56*cos(theta)**9 - 6.79928467116586e+54*cos(theta)**7 + 4.43431608989078e+52*cos(theta)**5 - 1.35316328650924e+50*cos(theta)**3 + 1.2190660238822e+47*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl85_m_minus_23(theta, phi):
    return 2.54276998926749e-44*(1.0 - cos(theta)**2)**11.5*(2.1160849166659e+67*cos(theta)**62 - 2.36776128841137e+68*cos(theta)**60 + 1.25477170074495e+69*cos(theta)**58 - 4.19017701279071e+69*cos(theta)**56 + 9.89704386456701e+69*cos(theta)**54 - 1.7593378596516e+70*cos(theta)**52 + 2.44536897473587e+70*cos(theta)**50 - 2.72572974890941e+70*cos(theta)**48 + 2.47953480384663e+70*cos(theta)**46 - 1.86370263034224e+70*cos(theta)**44 + 1.16759118430712e+70*cos(theta)**42 - 6.13359371377934e+69*cos(theta)**40 + 2.71213327480039e+69*cos(theta)**38 - 1.01147463776375e+69*cos(theta)**36 + 3.18296214680901e+68*cos(theta)**34 - 8.44275065891184e+67*cos(theta)**32 + 1.88291561457746e+67*cos(theta)**30 - 3.51682392589607e+66*cos(theta)**28 + 5.47061499583833e+65*cos(theta)**26 - 7.0358127172436e+64*cos(theta)**24 + 7.41177217541693e+63*cos(theta)**22 - 6.32011580849505e+62*cos(theta)**20 + 4.29785971229084e+61*cos(theta)**18 - 2.28720882080173e+60*cos(theta)**16 + 9.29759683252737e+58*cos(theta)**14 - 2.79696301408261e+57*cos(theta)**12 + 5.96637229894804e+55*cos(theta)**10 - 8.49910583895733e+53*cos(theta)**8 + 7.39052681648463e+51*cos(theta)**6 - 3.3829082162731e+49*cos(theta)**4 + 6.09533011941099e+46*cos(theta)**2 - 1.80388580035839e+43)*sin(23*phi)

#@torch.jit.script
def Yl85_m_minus_22(theta, phi):
    return 2.09743847112246e-42*(1.0 - cos(theta)**2)**11*(3.35886494708873e+65*cos(theta)**63 - 3.8815758826416e+66*cos(theta)**61 + 2.12673169617788e+67*cos(theta)**59 - 7.35118774173809e+67*cos(theta)**57 + 1.79946252083037e+68*cos(theta)**55 - 3.31950539556906e+68*cos(theta)**53 + 4.79484112693309e+68*cos(theta)**51 - 5.56271377328452e+68*cos(theta)**49 + 5.27560596563112e+68*cos(theta)**47 - 4.14156140076053e+68*cos(theta)**45 + 2.71532833559796e+68*cos(theta)**43 - 1.49599846677545e+68*cos(theta)**41 + 6.95418788410355e+67*cos(theta)**39 - 2.73371523719933e+67*cos(theta)**37 + 9.09417756231145e+66*cos(theta)**35 - 2.55840929057934e+66*cos(theta)**33 + 6.07392133734665e+65*cos(theta)**31 - 1.2126979054814e+65*cos(theta)**29 + 2.02615370216235e+64*cos(theta)**27 - 2.81432508689744e+63*cos(theta)**25 + 3.22250964148562e+62*cos(theta)**23 - 3.00957895642622e+61*cos(theta)**21 + 2.26203142752149e+60*cos(theta)**19 - 1.34541695341278e+59*cos(theta)**17 + 6.19839788835158e+57*cos(theta)**15 - 2.15151001083278e+56*cos(theta)**13 + 5.42397481722549e+54*cos(theta)**11 - 9.44345093217481e+52*cos(theta)**9 + 1.05578954521209e+51*cos(theta)**7 - 6.7658164325462e+48*cos(theta)**5 + 2.03177670647033e+46*cos(theta)**3 - 1.80388580035839e+43*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl85_m_minus_21(theta, phi):
    return 1.73568577984927e-40*(1.0 - cos(theta)**2)**10.5*(5.24822647982615e+63*cos(theta)**64 - 6.26060626232515e+64*cos(theta)**62 + 3.54455282696313e+65*cos(theta)**60 - 1.26744616236864e+66*cos(theta)**58 + 3.21332593005422e+66*cos(theta)**56 - 6.14723221401678e+66*cos(theta)**54 + 9.22084832102517e+66*cos(theta)**52 - 1.1125427546569e+67*cos(theta)**50 + 1.09908457617315e+67*cos(theta)**48 - 9.0033943494794e+66*cos(theta)**46 + 6.17120076272264e+66*cos(theta)**44 - 3.56190111137011e+66*cos(theta)**42 + 1.73854697102589e+66*cos(theta)**40 - 7.19398746631402e+65*cos(theta)**38 + 2.5261604339754e+65*cos(theta)**36 - 7.52473320758631e+64*cos(theta)**34 + 1.89810041792083e+64*cos(theta)**32 - 4.04232635160468e+63*cos(theta)**30 + 7.23626322200838e+62*cos(theta)**28 - 1.08243272572979e+62*cos(theta)**26 + 1.34271235061901e+61*cos(theta)**24 - 1.36799043473919e+60*cos(theta)**22 + 1.13101571376075e+59*cos(theta)**20 - 7.47453863007102e+57*cos(theta)**18 + 3.87399868021974e+56*cos(theta)**16 - 1.53679286488056e+55*cos(theta)**14 + 4.51997901435458e+53*cos(theta)**12 - 9.44345093217481e+51*cos(theta)**10 + 1.31973693151511e+50*cos(theta)**8 - 1.12763607209103e+48*cos(theta)**6 + 5.07944176617583e+45*cos(theta)**4 - 9.01942900179194e+42*cos(theta)**2 + 2.63417903089718e+39)*sin(21*phi)

#@torch.jit.script
def Yl85_m_minus_20(theta, phi):
    return 1.44072375286506e-38*(1.0 - cos(theta)**2)**10*(8.07419458434792e+61*cos(theta)**65 - 9.93747025765897e+62*cos(theta)**63 + 5.81074233928382e+63*cos(theta)**61 - 2.14821383452311e+64*cos(theta)**59 + 5.63741391237583e+64*cos(theta)**57 - 1.11767858436669e+65*cos(theta)**55 + 1.73978270208022e+65*cos(theta)**53 - 2.1814563816802e+65*cos(theta)**51 + 2.24302974729214e+65*cos(theta)**49 - 1.91561581903817e+65*cos(theta)**47 + 1.3713779472717e+65*cos(theta)**45 - 8.28349095667468e+64*cos(theta)**43 + 4.2403584659168e+64*cos(theta)**41 - 1.84461217084975e+64*cos(theta)**39 + 6.82746063236596e+63*cos(theta)**37 - 2.14992377359609e+63*cos(theta)**35 + 5.75181944824493e+62*cos(theta)**33 - 1.30397624245312e+62*cos(theta)**31 + 2.49526318000289e+61*cos(theta)**29 - 4.0090100952955e+60*cos(theta)**27 + 5.37084940247603e+59*cos(theta)**25 - 5.94778449886604e+58*cos(theta)**23 + 5.38578911314641e+57*cos(theta)**21 - 3.93396770003738e+56*cos(theta)**19 + 2.27882275307043e+55*cos(theta)**17 - 1.02452857658704e+54*cos(theta)**15 + 3.47690693411891e+52*cos(theta)**13 - 8.58495539288619e+50*cos(theta)**11 + 1.46637436835013e+49*cos(theta)**9 - 1.61090867441576e+47*cos(theta)**7 + 1.01588835323517e+45*cos(theta)**5 - 3.00647633393065e+42*cos(theta)**3 + 2.63417903089718e+39*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl85_m_minus_19(theta, phi):
    return 1.19935385017276e-36*(1.0 - cos(theta)**2)**9.5*(1.22336281581029e+60*cos(theta)**66 - 1.55272972775921e+61*cos(theta)**64 + 9.37216506336101e+61*cos(theta)**62 - 3.58035639087185e+62*cos(theta)**60 + 9.71967915926868e+62*cos(theta)**58 - 1.99585461494051e+63*cos(theta)**56 + 3.22181981866707e+63*cos(theta)**54 - 4.19510842630808e+63*cos(theta)**52 + 4.48605949458429e+63*cos(theta)**50 - 3.99086628966286e+63*cos(theta)**48 + 2.98125640711239e+63*cos(theta)**46 - 1.88261158106243e+63*cos(theta)**44 + 1.00960915855162e+63*cos(theta)**42 - 4.61153042712437e+62*cos(theta)**40 + 1.79670016641209e+62*cos(theta)**38 - 5.97201048221136e+61*cos(theta)**36 + 1.69171160242498e+61*cos(theta)**34 - 4.07492575766601e+60*cos(theta)**32 + 8.31754393334296e+59*cos(theta)**30 - 1.43178931974839e+59*cos(theta)**28 + 2.06571130864463e+58*cos(theta)**26 - 2.47824354119418e+57*cos(theta)**24 + 2.4480859605211e+56*cos(theta)**22 - 1.96698385001869e+55*cos(theta)**20 + 1.26601264059469e+54*cos(theta)**18 - 6.40330360366899e+52*cos(theta)**16 + 2.48350495294208e+51*cos(theta)**14 - 7.15412949407183e+49*cos(theta)**12 + 1.46637436835013e+48*cos(theta)**10 - 2.0136358430197e+46*cos(theta)**8 + 1.69314725539194e+44*cos(theta)**6 - 7.51619083482662e+41*cos(theta)**4 + 1.31708951544859e+39*cos(theta)**2 - 3.80112414270877e+35)*sin(19*phi)

#@torch.jit.script
def Yl85_m_minus_18(theta, phi):
    return 1.00115519358469e-34*(1.0 - cos(theta)**2)**9*(1.82591465046312e+58*cos(theta)**67 - 2.38881496578341e+59*cos(theta)**65 + 1.48764524815254e+60*cos(theta)**63 - 5.8694367063473e+60*cos(theta)**61 + 1.64740324733367e+61*cos(theta)**59 - 3.50149932445704e+61*cos(theta)**57 + 5.85785421575832e+61*cos(theta)**55 - 7.91529891756242e+61*cos(theta)**53 + 8.79619508742017e+61*cos(theta)**51 - 8.14462508094461e+61*cos(theta)**49 + 6.34309873853699e+61*cos(theta)**47 - 4.18358129124984e+61*cos(theta)**45 + 2.34792827570144e+61*cos(theta)**43 - 1.12476351881082e+61*cos(theta)**41 + 4.60692350362075e+60*cos(theta)**39 - 1.61405688708415e+60*cos(theta)**37 + 4.83346172121423e+59*cos(theta)**35 - 1.23482598717152e+59*cos(theta)**33 + 2.68307868817515e+58*cos(theta)**31 - 4.93720455085653e+57*cos(theta)**29 + 7.65078262460973e+56*cos(theta)**27 - 9.91297416477673e+55*cos(theta)**25 + 1.06438520022656e+55*cos(theta)**23 - 9.36658976199376e+53*cos(theta)**21 + 6.66322442418255e+52*cos(theta)**19 - 3.76664917862882e+51*cos(theta)**17 + 1.65566996862805e+50*cos(theta)**15 - 5.5031765339014e+48*cos(theta)**13 + 1.33306760759102e+47*cos(theta)**11 - 2.23737315891078e+45*cos(theta)**9 + 2.41878179341706e+43*cos(theta)**7 - 1.50323816696532e+41*cos(theta)**5 + 4.39029838482863e+38*cos(theta)**3 - 3.80112414270877e+35*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl85_m_minus_17(theta, phi):
    return 8.37865818516174e-33*(1.0 - cos(theta)**2)**8.5*(2.68516860362224e+56*cos(theta)**68 - 3.61941661482334e+57*cos(theta)**66 + 2.32444570023835e+58*cos(theta)**64 - 9.46683339733435e+58*cos(theta)**62 + 2.74567207888946e+59*cos(theta)**60 - 6.037067800788e+59*cos(theta)**58 + 1.04604539567113e+60*cos(theta)**56 - 1.46579609584489e+60*cos(theta)**54 + 1.69157597835003e+60*cos(theta)**52 - 1.62892501618892e+60*cos(theta)**50 + 1.32147890386187e+60*cos(theta)**48 - 9.09474193749965e+59*cos(theta)**46 + 5.33620062659418e+59*cos(theta)**44 - 2.67800837812101e+59*cos(theta)**42 + 1.15173087590519e+59*cos(theta)**40 - 4.24751812390566e+58*cos(theta)**38 + 1.34262825589284e+58*cos(theta)**36 - 3.63184113873976e+57*cos(theta)**34 + 8.38462090054734e+56*cos(theta)**32 - 1.64573485028551e+56*cos(theta)**30 + 2.73242236593205e+55*cos(theta)**28 - 3.81268237106797e+54*cos(theta)**26 + 4.43493833427735e+53*cos(theta)**24 - 4.25754080090626e+52*cos(theta)**22 + 3.33161221209128e+51*cos(theta)**20 - 2.09258287701601e+50*cos(theta)**18 + 1.03479373039253e+49*cos(theta)**16 - 3.93084038135815e+47*cos(theta)**14 + 1.11088967299252e+46*cos(theta)**12 - 2.23737315891078e+44*cos(theta)**10 + 3.02347724177133e+42*cos(theta)**8 - 2.5053969449422e+40*cos(theta)**6 + 1.09757459620716e+38*cos(theta)**4 - 1.90056207135439e+35*cos(theta)**2 + 5.42707616034947e+31)*sin(17*phi)

#@torch.jit.script
def Yl85_m_minus_16(theta, phi):
    return 7.02909000923895e-31*(1.0 - cos(theta)**2)**8*(3.89154870090179e+54*cos(theta)**69 - 5.4021143504826e+55*cos(theta)**67 + 3.57607030805899e+56*cos(theta)**65 - 1.50267196783085e+57*cos(theta)**63 + 4.50110176867124e+57*cos(theta)**61 - 1.02323183064203e+58*cos(theta)**59 + 1.83516736082654e+58*cos(theta)**57 - 2.66508381062708e+58*cos(theta)**55 + 3.19165278933969e+58*cos(theta)**53 - 3.19397061997828e+58*cos(theta)**51 + 2.69689572216709e+58*cos(theta)**49 - 1.93505147606376e+58*cos(theta)**47 + 1.18582236146537e+58*cos(theta)**45 - 6.22792646074653e+57*cos(theta)**43 + 2.80909969732973e+57*cos(theta)**41 - 1.08910721125786e+57*cos(theta)**39 + 3.6287250159266e+56*cos(theta)**37 - 1.03766889678279e+56*cos(theta)**35 + 2.54079421228707e+55*cos(theta)**33 - 5.30882209769519e+54*cos(theta)**31 + 9.42214608942085e+53*cos(theta)**29 - 1.41210458187703e+53*cos(theta)**27 + 1.77397533371094e+52*cos(theta)**25 - 1.8511046960462e+51*cos(theta)**23 + 1.58648200575775e+50*cos(theta)**21 - 1.10135940895579e+49*cos(theta)**19 + 6.08702194348548e+47*cos(theta)**17 - 2.62056025423876e+46*cos(theta)**15 + 8.54530517686553e+44*cos(theta)**13 - 2.0339755990098e+43*cos(theta)**11 + 3.35941915752369e+41*cos(theta)**9 - 3.57913849277458e+39*cos(theta)**7 + 2.19514919241431e+37*cos(theta)**5 - 6.33520690451462e+34*cos(theta)**3 + 5.42707616034947e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl85_m_minus_15(theta, phi):
    return 5.91029028010417e-29*(1.0 - cos(theta)**2)**7.5*(5.55935528700256e+52*cos(theta)**70 - 7.94428580953324e+53*cos(theta)**68 + 5.41828834554393e+54*cos(theta)**66 - 2.3479249497357e+55*cos(theta)**64 + 7.25984156237297e+55*cos(theta)**62 - 1.70538638440339e+56*cos(theta)**60 + 3.16408165659748e+56*cos(theta)**58 - 4.75907823326264e+56*cos(theta)**56 + 5.91046812840683e+56*cos(theta)**54 - 6.14225119226592e+56*cos(theta)**52 + 5.39379144433418e+56*cos(theta)**50 - 4.03135724179949e+56*cos(theta)**48 + 2.57787469883777e+56*cos(theta)**46 - 1.41543783198785e+56*cos(theta)**44 + 6.68833261268983e+55*cos(theta)**42 - 2.72276802814465e+55*cos(theta)**40 + 9.54927635770157e+54*cos(theta)**38 - 2.88241360217441e+54*cos(theta)**36 + 7.47292415378551e+53*cos(theta)**34 - 1.65900690552975e+53*cos(theta)**32 + 3.14071536314029e+52*cos(theta)**30 - 5.04323064956081e+51*cos(theta)**28 + 6.82298205273438e+50*cos(theta)**26 - 7.71293623352583e+49*cos(theta)**24 + 7.21128184435341e+48*cos(theta)**22 - 5.50679704477897e+47*cos(theta)**20 + 3.38167885749193e+46*cos(theta)**18 - 1.63785015889923e+45*cos(theta)**16 + 6.10378941204681e+43*cos(theta)**14 - 1.6949796658415e+42*cos(theta)**12 + 3.35941915752369e+40*cos(theta)**10 - 4.47392311596822e+38*cos(theta)**8 + 3.65858198735719e+36*cos(theta)**6 - 1.58380172612865e+34*cos(theta)**4 + 2.71353808017474e+31*cos(theta)**2 - 7.67620390431326e+27)*sin(15*phi)

#@torch.jit.script
def Yl85_m_minus_14(theta, phi):
    return 4.98009911031062e-27*(1.0 - cos(theta)**2)**7*(7.83007786901769e+50*cos(theta)**71 - 1.15134576949757e+52*cos(theta)**69 + 8.08699753066258e+52*cos(theta)**67 - 3.61219223036262e+53*cos(theta)**65 + 1.15235580355126e+54*cos(theta)**63 - 2.79571538426785e+54*cos(theta)**61 + 5.36285026541946e+54*cos(theta)**59 - 8.34926005835551e+54*cos(theta)**57 + 1.07463056880124e+55*cos(theta)**55 - 1.15891531929546e+55*cos(theta)**53 + 1.05760616555572e+55*cos(theta)**51 - 8.22725967714182e+54*cos(theta)**49 + 5.48483978476121e+54*cos(theta)**47 - 3.14541740441744e+54*cos(theta)**45 + 1.55542618899763e+54*cos(theta)**43 - 6.6408976296211e+53*cos(theta)**41 + 2.44853239941066e+53*cos(theta)**39 - 7.79030703290381e+52*cos(theta)**37 + 2.13512118679586e+52*cos(theta)**35 - 5.02729365312045e+51*cos(theta)**33 + 1.01313398810977e+51*cos(theta)**31 - 1.73904505157269e+50*cos(theta)**29 + 2.52703038990162e+49*cos(theta)**27 - 3.08517449341033e+48*cos(theta)**25 + 3.13533993232757e+47*cos(theta)**23 - 2.62228430703761e+46*cos(theta)**21 + 1.77983097762733e+45*cos(theta)**19 - 9.63441269940722e+43*cos(theta)**17 + 4.06919294136454e+42*cos(theta)**15 - 1.30383051218577e+41*cos(theta)**13 + 3.05401741593063e+39*cos(theta)**11 - 4.97102568440914e+37*cos(theta)**9 + 5.22654569622456e+35*cos(theta)**7 - 3.16760345225731e+33*cos(theta)**5 + 9.04512693391579e+30*cos(theta)**3 - 7.67620390431326e+27*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl85_m_minus_13(theta, phi):
    return 4.20457236344704e-25*(1.0 - cos(theta)**2)**6.5*(1.08751081514135e+49*cos(theta)**72 - 1.64477967071082e+50*cos(theta)**70 + 1.1892643427445e+51*cos(theta)**68 - 5.47301853085245e+51*cos(theta)**66 + 1.80055594304885e+52*cos(theta)**64 - 4.50921836172234e+52*cos(theta)**62 + 8.93808377569911e+52*cos(theta)**60 - 1.43952759626819e+53*cos(theta)**58 + 1.91898315857364e+53*cos(theta)**56 - 2.14613948017677e+53*cos(theta)**54 + 2.03385801068408e+53*cos(theta)**52 - 1.64545193542836e+53*cos(theta)**50 + 1.14267495515859e+53*cos(theta)**48 - 6.8378639226466e+52*cos(theta)**46 + 3.53505952044917e+52*cos(theta)**44 - 1.58116610229074e+52*cos(theta)**42 + 6.12133099852665e+51*cos(theta)**40 - 2.05008079813258e+51*cos(theta)**38 + 5.93089218554406e+50*cos(theta)**36 - 1.47861578032954e+50*cos(theta)**34 + 3.16604371284303e+49*cos(theta)**32 - 5.79681683857565e+48*cos(theta)**30 + 9.02510853536294e+47*cos(theta)**28 - 1.18660557438859e+47*cos(theta)**26 + 1.30639163846982e+46*cos(theta)**24 - 1.19194741228982e+45*cos(theta)**22 + 8.89915488813667e+43*cos(theta)**20 - 5.35245149967068e+42*cos(theta)**18 + 2.54324558835284e+41*cos(theta)**16 - 9.31307508704121e+39*cos(theta)**14 + 2.54501451327553e+38*cos(theta)**12 - 4.97102568440914e+36*cos(theta)**10 + 6.5331821202807e+34*cos(theta)**8 - 5.27933908709551e+32*cos(theta)**6 + 2.26128173347895e+30*cos(theta)**4 - 3.83810195215663e+27*cos(theta)**2 + 1.0769085163178e+24)*sin(13*phi)

#@torch.jit.script
def Yl85_m_minus_12(theta, phi):
    return 3.55628288167851e-23*(1.0 - cos(theta)**2)**6*(1.48974084265938e+47*cos(theta)**73 - 2.31659108550819e+48*cos(theta)**71 + 1.72357151122391e+49*cos(theta)**69 - 8.16868437440665e+49*cos(theta)**67 + 2.770086066229e+50*cos(theta)**65 - 7.15748946305133e+50*cos(theta)**63 + 1.46525963536051e+51*cos(theta)**61 - 2.43987728181049e+51*cos(theta)**59 + 3.36663712030464e+51*cos(theta)**57 - 3.90207178213958e+51*cos(theta)**55 + 3.83746794468694e+51*cos(theta)**53 - 3.22637634397718e+51*cos(theta)**51 + 2.33198970440528e+51*cos(theta)**49 - 1.45486466439289e+51*cos(theta)**47 + 7.85568782322037e+50*cos(theta)**45 - 3.67713047044358e+50*cos(theta)**43 + 1.49300756061626e+50*cos(theta)**41 - 5.25661743110919e+49*cos(theta)**39 + 1.60294383393083e+49*cos(theta)**37 - 4.22461651522727e+48*cos(theta)**35 + 9.59407185710009e+47*cos(theta)**33 - 1.86994091566956e+47*cos(theta)**31 + 3.11210639150446e+46*cos(theta)**29 - 4.39483546069848e+45*cos(theta)**27 + 5.22556655387929e+44*cos(theta)**25 - 5.182380053434e+43*cos(theta)**23 + 4.2376928038746e+42*cos(theta)**21 - 2.81707973666878e+41*cos(theta)**19 + 1.49602681667814e+40*cos(theta)**17 - 6.20871672469414e+38*cos(theta)**15 + 1.9577034717504e+37*cos(theta)**13 - 4.51911425855376e+35*cos(theta)**11 + 7.25909124475633e+33*cos(theta)**9 - 7.54191298156502e+31*cos(theta)**7 + 4.52256346695789e+29*cos(theta)**5 - 1.27936731738554e+27*cos(theta)**3 + 1.0769085163178e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl85_m_minus_11(theta, phi):
    return 3.0129923311217e-21*(1.0 - cos(theta)**2)**5.5*(2.01316330089105e+45*cos(theta)**74 - 3.21748761876138e+46*cos(theta)**72 + 2.46224501603416e+47*cos(theta)**70 - 1.20127711388333e+48*cos(theta)**68 + 4.19710010034697e+48*cos(theta)**66 - 1.11835772860177e+49*cos(theta)**64 + 2.36332199251695e+49*cos(theta)**62 - 4.06646213635082e+49*cos(theta)**60 + 5.80454675914593e+49*cos(theta)**58 - 6.96798532524925e+49*cos(theta)**56 + 7.10642211979063e+49*cos(theta)**54 - 6.20456989226381e+49*cos(theta)**52 + 4.66397940881055e+49*cos(theta)**50 - 3.03096805081853e+49*cos(theta)**48 + 1.70775822243921e+49*cos(theta)**46 - 8.35711470555359e+48*cos(theta)**44 + 3.55477990622918e+48*cos(theta)**42 - 1.3141543577773e+48*cos(theta)**40 + 4.21827324718638e+47*cos(theta)**38 - 1.17350458756313e+47*cos(theta)**36 + 2.82178584032356e+46*cos(theta)**34 - 5.84356536146738e+45*cos(theta)**32 + 1.03736879716815e+45*cos(theta)**30 - 1.5695840931066e+44*cos(theta)**28 + 2.00983328995357e+43*cos(theta)**26 - 2.15932502226417e+42*cos(theta)**24 + 1.92622400176118e+41*cos(theta)**22 - 1.40853986833439e+40*cos(theta)**20 + 8.31126009265633e+38*cos(theta)**18 - 3.88044795293384e+37*cos(theta)**16 + 1.39835962267886e+36*cos(theta)**14 - 3.7659285487948e+34*cos(theta)**12 + 7.25909124475633e+32*cos(theta)**10 - 9.42739122695628e+30*cos(theta)**8 + 7.53760577826316e+28*cos(theta)**6 - 3.19841829346386e+26*cos(theta)**4 + 5.38454258158898e+23*cos(theta)**2 - 1.50029049361632e+20)*sin(11*phi)

#@torch.jit.script
def Yl85_m_minus_10(theta, phi):
    return 2.55660877079906e-19*(1.0 - cos(theta)**2)**5*(2.6842177345214e+43*cos(theta)**75 - 4.40751728597449e+44*cos(theta)**73 + 3.46795072680867e+45*cos(theta)**71 - 1.74098132446859e+46*cos(theta)**69 + 6.26432850798056e+46*cos(theta)**67 - 1.72055035169503e+47*cos(theta)**65 + 3.7513047500269e+47*cos(theta)**63 - 6.66633137106692e+47*cos(theta)**61 + 9.83821484601005e+47*cos(theta)**59 - 1.2224535658332e+48*cos(theta)**57 + 1.29207674905284e+48*cos(theta)**55 - 1.17067356457808e+48*cos(theta)**53 + 9.14505766433442e+47*cos(theta)**51 - 6.18564908330312e+47*cos(theta)**49 + 3.63352813284939e+47*cos(theta)**47 - 1.85713660123413e+47*cos(theta)**45 + 8.26693001448646e+46*cos(theta)**43 - 3.20525453116414e+46*cos(theta)**41 + 1.08160852491959e+46*cos(theta)**39 - 3.17163402044089e+45*cos(theta)**37 + 8.0622452580673e+44*cos(theta)**35 - 1.77077738226284e+44*cos(theta)**33 + 3.34635095860695e+43*cos(theta)**31 - 5.41235894174689e+42*cos(theta)**29 + 7.44382699982804e+41*cos(theta)**27 - 8.63730008905667e+40*cos(theta)**25 + 8.37488696417906e+39*cos(theta)**23 - 6.70733270635423e+38*cos(theta)**21 + 4.37434741718754e+37*cos(theta)**19 - 2.28261644290226e+36*cos(theta)**17 + 9.32239748452574e+34*cos(theta)**15 - 2.89686811445754e+33*cos(theta)**13 + 6.59917385886939e+31*cos(theta)**11 - 1.04748791410625e+30*cos(theta)**9 + 1.07680082546617e+28*cos(theta)**7 - 6.39683658692771e+25*cos(theta)**5 + 1.79484752719633e+23*cos(theta)**3 - 1.50029049361632e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl85_m_minus_9(theta, phi):
    return 2.17236538128397e-17*(1.0 - cos(theta)**2)**4.5*(3.53186544015974e+41*cos(theta)**76 - 5.95610444050607e+42*cos(theta)**74 + 4.81659823167871e+43*cos(theta)**72 - 2.48711617781228e+44*cos(theta)**70 + 9.21224780585376e+44*cos(theta)**68 - 2.6068944722652e+45*cos(theta)**66 + 5.86141367191704e+45*cos(theta)**64 - 1.07521473726886e+46*cos(theta)**62 + 1.63970247433501e+46*cos(theta)**60 - 2.10767856178138e+46*cos(theta)**58 + 2.30727990902293e+46*cos(theta)**56 - 2.16791400847792e+46*cos(theta)**54 + 1.75866493544893e+46*cos(theta)**52 - 1.23712981666062e+46*cos(theta)**50 + 7.56985027676956e+45*cos(theta)**48 - 4.03725348094376e+45*cos(theta)**46 + 1.87884773056511e+45*cos(theta)**44 - 7.63155840753366e+44*cos(theta)**42 + 2.70402131229896e+44*cos(theta)**40 - 8.34640531694971e+43*cos(theta)**38 + 2.23951257168536e+43*cos(theta)**36 - 5.20816877136131e+42*cos(theta)**34 + 1.04573467456467e+42*cos(theta)**32 - 1.80411964724896e+41*cos(theta)**30 + 2.65850964279573e+40*cos(theta)**28 - 3.32203849579103e+39*cos(theta)**26 + 3.48953623507461e+38*cos(theta)**24 - 3.04878759379738e+37*cos(theta)**22 + 2.18717370859377e+36*cos(theta)**20 - 1.26812024605681e+35*cos(theta)**18 + 5.82649842782859e+33*cos(theta)**16 - 2.06919151032681e+32*cos(theta)**14 + 5.49931154905783e+30*cos(theta)**12 - 1.04748791410625e+29*cos(theta)**10 + 1.34600103183271e+27*cos(theta)**8 - 1.06613943115462e+25*cos(theta)**6 + 4.48711881799082e+22*cos(theta)**4 - 7.50145246808162e+19*cos(theta)**2 + 2.07796467259879e+16)*sin(9*phi)

#@torch.jit.script
def Yl85_m_minus_8(theta, phi):
    return 1.84817104808673e-15*(1.0 - cos(theta)**2)**4*(4.58683823397368e+39*cos(theta)**77 - 7.94147258734142e+40*cos(theta)**75 + 6.59807976942289e+41*cos(theta)**73 - 3.50298053212997e+42*cos(theta)**71 + 1.33510837765997e+43*cos(theta)**69 - 3.89088727203761e+43*cos(theta)**67 + 9.01755949525698e+43*cos(theta)**65 - 1.70669005915692e+44*cos(theta)**63 + 2.68803684317215e+44*cos(theta)**61 - 3.57233654539218e+44*cos(theta)**59 + 4.04785948951392e+44*cos(theta)**57 - 3.94166183359622e+44*cos(theta)**55 + 3.31823572726213e+44*cos(theta)**53 - 2.42574473855024e+44*cos(theta)**51 + 1.54486740342236e+44*cos(theta)**49 - 8.5899010232846e+43*cos(theta)**47 + 4.17521717903357e+43*cos(theta)**45 - 1.77478102500783e+43*cos(theta)**43 + 6.5951739324365e+42*cos(theta)**41 - 2.140103927423e+42*cos(theta)**39 + 6.05273668023071e+41*cos(theta)**37 - 1.48804822038894e+41*cos(theta)**35 + 3.16889295322628e+40*cos(theta)**33 - 5.8197407975773e+39*cos(theta)**31 + 9.1672746303301e+38*cos(theta)**29 - 1.23038462807075e+38*cos(theta)**27 + 1.39581449402984e+37*cos(theta)**25 - 1.32555982339016e+36*cos(theta)**23 + 1.04151128980656e+35*cos(theta)**21 - 6.67431708450953e+33*cos(theta)**19 + 3.42735201636976e+32*cos(theta)**17 - 1.37946100688454e+31*cos(theta)**15 + 4.23023965312141e+29*cos(theta)**13 - 9.52261740096594e+27*cos(theta)**11 + 1.49555670203634e+26*cos(theta)**9 - 1.52305633022088e+24*cos(theta)**7 + 8.97423763598164e+21*cos(theta)**5 - 2.50048415602721e+19*cos(theta)**3 + 2.07796467259879e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl85_m_minus_7(theta, phi):
    return 1.57409499591163e-13*(1.0 - cos(theta)**2)**3.5*(5.8805618384278e+37*cos(theta)**78 - 1.04493060359756e+39*cos(theta)**76 + 8.91632401273363e+39*cos(theta)**74 - 4.8652507390694e+40*cos(theta)**72 + 1.90729768237138e+41*cos(theta)**70 - 5.72189304711414e+41*cos(theta)**68 + 1.36629689322075e+42*cos(theta)**66 - 2.66670321743268e+42*cos(theta)**64 + 4.33554329543894e+42*cos(theta)**62 - 5.95389424232029e+42*cos(theta)**60 + 6.97906808536882e+42*cos(theta)**58 - 7.03868184570754e+42*cos(theta)**56 + 6.14488097641135e+42*cos(theta)**54 - 4.66489372798124e+42*cos(theta)**52 + 3.08973480684472e+42*cos(theta)**50 - 1.78956271318429e+42*cos(theta)**48 + 9.07655908485558e+41*cos(theta)**46 - 4.03359323865416e+41*cos(theta)**44 + 1.57027950772298e+41*cos(theta)**42 - 5.35025981855751e+40*cos(theta)**40 + 1.59282544216598e+40*cos(theta)**38 - 4.13346727885818e+39*cos(theta)**36 + 9.32027339184199e+38*cos(theta)**34 - 1.81866899924291e+38*cos(theta)**32 + 3.05575821011003e+37*cos(theta)**30 - 4.3942308145384e+36*cos(theta)**28 + 5.36851728473017e+35*cos(theta)**26 - 5.52316593079235e+34*cos(theta)**24 + 4.73414222639344e+33*cos(theta)**22 - 3.33715854225476e+32*cos(theta)**20 + 1.90408445353875e+31*cos(theta)**18 - 8.62163129302839e+29*cos(theta)**16 + 3.02159975222958e+28*cos(theta)**14 - 7.93551450080495e+26*cos(theta)**12 + 1.49555670203634e+25*cos(theta)**10 - 1.90382041277611e+23*cos(theta)**8 + 1.49570627266361e+21*cos(theta)**6 - 6.25121039006802e+18*cos(theta)**4 + 1.03898233629939e+16*cos(theta)**2 - 2864577712432.85)*sin(7*phi)

#@torch.jit.script
def Yl85_m_minus_6(theta, phi):
    return 1.34195637440744e-11*(1.0 - cos(theta)**2)**3*(7.44374916256684e+35*cos(theta)**79 - 1.35705273194488e+37*cos(theta)**77 + 1.18884320169782e+38*cos(theta)**75 - 6.6647270398211e+38*cos(theta)**73 + 2.68633476390335e+39*cos(theta)**71 - 8.29259861900599e+39*cos(theta)**69 + 2.03924909435934e+40*cos(theta)**67 - 4.10262033451182e+40*cos(theta)**65 + 6.88181475466499e+40*cos(theta)**63 - 9.7604823644595e+40*cos(theta)**61 + 1.18289289582522e+41*cos(theta)**59 - 1.23485646415922e+41*cos(theta)**57 + 1.11725108662024e+41*cos(theta)**55 - 8.80168627920988e+40*cos(theta)**53 + 6.05830354283278e+40*cos(theta)**51 - 3.65216880241692e+40*cos(theta)**49 + 1.93118278401183e+40*cos(theta)**47 - 8.96354053034257e+39*cos(theta)**45 + 3.65181280865808e+39*cos(theta)**43 - 1.30494141916037e+39*cos(theta)**41 + 4.08416780042558e+38*cos(theta)**39 - 1.11715331861032e+38*cos(theta)**37 + 2.662935254812e+37*cos(theta)**35 - 5.51111817952396e+36*cos(theta)**33 + 9.85728454874204e+35*cos(theta)**31 - 1.51525200501324e+35*cos(theta)**29 + 1.98833973508525e+34*cos(theta)**27 - 2.20926637231694e+33*cos(theta)**25 + 2.05832270712758e+32*cos(theta)**23 - 1.58912311535941e+31*cos(theta)**21 + 1.00214971238882e+30*cos(theta)**19 - 5.07154781942846e+28*cos(theta)**17 + 2.01439983481972e+27*cos(theta)**15 - 6.10424192369611e+25*cos(theta)**13 + 1.35959700185122e+24*cos(theta)**11 - 2.11535601419567e+22*cos(theta)**9 + 2.1367232466623e+20*cos(theta)**7 - 1.2502420780136e+18*cos(theta)**5 + 3.46327445433131e+15*cos(theta)**3 - 2864577712432.85*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl85_m_minus_5(theta, phi):
    return 1.14499631050571e-9*(1.0 - cos(theta)**2)**2.5*(9.30468645320855e+33*cos(theta)**80 - 1.73981119480112e+35*cos(theta)**78 + 1.56426737065502e+36*cos(theta)**76 - 9.00638789165013e+36*cos(theta)**74 + 3.73102050542132e+37*cos(theta)**72 - 1.18465694557228e+38*cos(theta)**70 + 2.99889572699902e+38*cos(theta)**68 - 6.216091415927e+38*cos(theta)**66 + 1.0752835554164e+39*cos(theta)**64 - 1.57427134910637e+39*cos(theta)**62 + 1.97148815970871e+39*cos(theta)**60 - 2.12906286924003e+39*cos(theta)**58 + 1.99509122610758e+39*cos(theta)**56 - 1.62994190355739e+39*cos(theta)**54 + 1.16505837362169e+39*cos(theta)**52 - 7.30433760483385e+38*cos(theta)**50 + 4.0232974666913e+38*cos(theta)**48 - 1.94859576746578e+38*cos(theta)**46 + 8.29957456513201e+37*cos(theta)**44 - 3.10700337895326e+37*cos(theta)**42 + 1.02104195010639e+37*cos(theta)**40 - 2.93987715423768e+36*cos(theta)**38 + 7.39704237447777e+35*cos(theta)**36 - 1.62091711162469e+35*cos(theta)**34 + 3.08040142148189e+34*cos(theta)**32 - 5.0508400167108e+33*cos(theta)**30 + 7.10121333959017e+32*cos(theta)**28 - 8.49717835506516e+31*cos(theta)**26 + 8.5763446130316e+30*cos(theta)**24 - 7.22328688799732e+29*cos(theta)**22 + 5.01074856194409e+28*cos(theta)**20 - 2.81752656634915e+27*cos(theta)**18 + 1.25899989676232e+26*cos(theta)**16 - 4.36017280264008e+24*cos(theta)**14 + 1.13299750154268e+23*cos(theta)**12 - 2.11535601419567e+21*cos(theta)**10 + 2.67090405832787e+19*cos(theta)**8 - 2.08373679668934e+17*cos(theta)**6 + 865818613582828.0*cos(theta)**4 - 1432288856216.42*cos(theta)**2 + 393485949.510006)*sin(5*phi)

#@torch.jit.script
def Yl85_m_minus_4(theta, phi):
    return 9.77614988495605e-8*(1.0 - cos(theta)**2)**2*(1.14872672261834e+32*cos(theta)**81 - 2.20229265164699e+33*cos(theta)**79 + 2.03151606578574e+34*cos(theta)**77 - 1.20085171888668e+35*cos(theta)**75 + 5.11098699372784e+35*cos(theta)**73 - 1.66853090925674e+36*cos(theta)**71 + 4.34622569130293e+36*cos(theta)**69 - 9.2777483819806e+36*cos(theta)**67 + 1.65428239294831e+37*cos(theta)**65 - 2.49884341127995e+37*cos(theta)**63 + 3.23194780280116e+37*cos(theta)**61 - 3.60858113430514e+37*cos(theta)**59 + 3.50016004580277e+37*cos(theta)**57 - 2.9635307337407e+37*cos(theta)**55 + 2.19822334645602e+37*cos(theta)**53 - 1.43222305977134e+37*cos(theta)**51 + 8.21081115651287e+36*cos(theta)**49 - 4.14594844141654e+36*cos(theta)**47 + 1.84434990336267e+36*cos(theta)**45 - 7.22558925337967e+35*cos(theta)**43 + 2.49034621977169e+35*cos(theta)**41 - 7.53814654932739e+34*cos(theta)**39 + 1.99920064175075e+34*cos(theta)**37 - 4.63119174749913e+33*cos(theta)**35 + 9.33454976206633e+32*cos(theta)**33 - 1.62930323119703e+32*cos(theta)**31 + 2.44869425503109e+31*cos(theta)**29 - 3.14710309446858e+30*cos(theta)**27 + 3.43053784521264e+29*cos(theta)**25 - 3.14055951652057e+28*cos(theta)**23 + 2.3860707437829e+27*cos(theta)**21 - 1.48290871913113e+26*cos(theta)**19 + 7.40588174566073e+24*cos(theta)**17 - 2.90678186842672e+23*cos(theta)**15 + 8.71536539648217e+21*cos(theta)**13 - 1.92305092199607e+20*cos(theta)**11 + 2.96767117591986e+18*cos(theta)**9 - 2.97676685241334e+16*cos(theta)**7 + 173163722716566.0*cos(theta)**5 - 477429618738.808*cos(theta)**3 + 393485949.510006*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl85_m_minus_3(theta, phi):
    return 8.3516018330059e-6*(1.0 - cos(theta)**2)**1.5*(1.40088624709554e+30*cos(theta)**82 - 2.75286581455874e+31*cos(theta)**80 + 2.60450777664839e+32*cos(theta)**78 - 1.58006805116669e+33*cos(theta)**76 + 6.90673918071329e+33*cos(theta)**74 - 2.31740404063436e+34*cos(theta)**72 + 6.20889384471848e+34*cos(theta)**70 - 1.36437476205597e+35*cos(theta)**68 + 2.50648847416411e+35*cos(theta)**66 - 3.90444283012493e+35*cos(theta)**64 + 5.21281903677606e+35*cos(theta)**62 - 6.01430189050856e+35*cos(theta)**60 + 6.03475869965995e+35*cos(theta)**58 - 5.29201916739411e+35*cos(theta)**56 + 4.07078397491855e+35*cos(theta)**54 - 2.75427511494489e+35*cos(theta)**52 + 1.64216223130257e+35*cos(theta)**50 - 8.63739258628447e+34*cos(theta)**48 + 4.00945631165797e+34*cos(theta)**46 - 1.64217937576811e+34*cos(theta)**44 + 5.92939576136118e+33*cos(theta)**42 - 1.88453663733185e+33*cos(theta)**40 + 5.26105432039671e+32*cos(theta)**38 - 1.28644215208309e+32*cos(theta)**36 + 2.74545581237245e+31*cos(theta)**34 - 5.09157259749073e+30*cos(theta)**32 + 8.16231418343697e+29*cos(theta)**30 - 1.12396539088163e+29*cos(theta)**28 + 1.31943763277409e+28*cos(theta)**26 - 1.30856646521691e+27*cos(theta)**24 + 1.08457761081041e+26*cos(theta)**22 - 7.41454359565565e+24*cos(theta)**20 + 4.11437874758929e+23*cos(theta)**18 - 1.8167386677667e+22*cos(theta)**16 + 6.22526099748727e+20*cos(theta)**14 - 1.60254243499672e+19*cos(theta)**12 + 2.96767117591986e+17*cos(theta)**10 - 3.72095856551668e+15*cos(theta)**8 + 28860620452760.9*cos(theta)**6 - 119357404684.702*cos(theta)**4 + 196742974.755003*cos(theta)**2 - 53916.9566333251)*sin(3*phi)

#@torch.jit.script
def Yl85_m_minus_2(theta, phi):
    return 0.000713756642844956*(1.0 - cos(theta)**2)*(1.68781475553679e+28*cos(theta)**83 - 3.39859977106017e+29*cos(theta)**81 + 3.2968452868967e+30*cos(theta)**79 - 2.05203643008661e+31*cos(theta)**77 + 9.20898557428439e+31*cos(theta)**75 - 3.17452608306077e+32*cos(theta)**73 + 8.74492090805419e+32*cos(theta)**71 - 1.97735472761735e+33*cos(theta)**69 + 3.74102757337927e+33*cos(theta)**67 - 6.00683512326912e+33*cos(theta)**65 + 8.27431593139057e+33*cos(theta)**63 - 9.85951129591567e+33*cos(theta)**61 + 1.02284045756948e+34*cos(theta)**59 - 9.284244153323e+33*cos(theta)**57 + 7.40142540894281e+33*cos(theta)**55 - 5.19674549989602e+33*cos(theta)**53 + 3.21992594373054e+33*cos(theta)**51 - 1.76273318087438e+33*cos(theta)**49 + 8.53075810991058e+32*cos(theta)**47 - 3.6492875017069e+32*cos(theta)**45 + 1.37892924682818e+32*cos(theta)**43 - 4.5964308227606e+31*cos(theta)**41 + 1.34898828728121e+31*cos(theta)**39 - 3.47687068130565e+30*cos(theta)**37 + 7.84415946392129e+29*cos(theta)**35 - 1.5429007871184e+29*cos(theta)**33 + 2.63300457530225e+28*cos(theta)**31 - 3.87574272717805e+27*cos(theta)**29 + 4.88680604731145e+26*cos(theta)**27 - 5.23426586086762e+25*cos(theta)**25 + 4.71555482961047e+24*cos(theta)**23 - 3.53073504555031e+23*cos(theta)**21 + 2.16546249873121e+22*cos(theta)**19 - 1.06866980456865e+21*cos(theta)**17 + 4.15017399832484e+19*cos(theta)**15 - 1.23272494999748e+18*cos(theta)**13 + 2.69788288719987e+16*cos(theta)**11 - 413439840612964.0*cos(theta)**9 + 4122945778965.85*cos(theta)**7 - 23871480936.9404*cos(theta)**5 + 65580991.585001*cos(theta)**3 - 53916.9566333251*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl85_m_minus_1(theta, phi):
    return 0.0610168007057101*(1.0 - cos(theta)**2)**0.5*(2.00930328040094e+26*cos(theta)**84 - 4.14463386714655e+27*cos(theta)**82 + 4.12105660862087e+28*cos(theta)**80 - 2.63081593600847e+29*cos(theta)**78 + 1.21170862819531e+30*cos(theta)**76 - 4.28990011224428e+30*cos(theta)**74 + 1.21457234834086e+31*cos(theta)**72 - 2.82479246802478e+31*cos(theta)**70 + 5.50151113732246e+31*cos(theta)**68 - 9.10126533828654e+31*cos(theta)**66 + 1.29286186427978e+32*cos(theta)**64 - 1.59024375740575e+32*cos(theta)**62 + 1.70473409594914e+32*cos(theta)**60 - 1.60073175057293e+32*cos(theta)**58 + 1.32168310873979e+32*cos(theta)**56 - 9.62360277758522e+31*cos(theta)**54 + 6.19216527640488e+31*cos(theta)**52 - 3.52546636174876e+31*cos(theta)**50 + 1.77724127289804e+31*cos(theta)**48 - 7.93323369936283e+30*cos(theta)**46 + 3.13393010642768e+30*cos(theta)**44 - 1.09438829113348e+30*cos(theta)**42 + 3.37247071820302e+29*cos(theta)**40 - 9.14965968764645e+28*cos(theta)**38 + 2.17893318442258e+28*cos(theta)**36 - 4.53794349152471e+27*cos(theta)**34 + 8.22813929781953e+26*cos(theta)**32 - 1.29191424239268e+26*cos(theta)**30 + 1.74528787403981e+25*cos(theta)**28 - 2.01317917725678e+24*cos(theta)**26 + 1.9648145123377e+23*cos(theta)**24 - 1.60487956615923e+22*cos(theta)**22 + 1.0827312493656e+21*cos(theta)**20 - 5.93705446982582e+19*cos(theta)**18 + 2.59385874895303e+18*cos(theta)**16 - 8.8051782142677e+16*cos(theta)**14 + 2.24823573933322e+15*cos(theta)**12 - 41343984061296.4*cos(theta)**10 + 515368222370.731*cos(theta)**8 - 3978580156.15673*cos(theta)**6 + 16395247.8962503*cos(theta)**4 - 26958.4783166625*cos(theta)**2 + 7.37779921090929)*sin(phi)

#@torch.jit.script
def Yl85_m0(theta, phi):
    return 2.73948901583064e+25*cos(theta)**85 - 5.78696792101502e+26*cos(theta)**83 + 5.89612330395632e+27*cos(theta)**81 - 3.85928070804414e+28*cos(theta)**79 + 1.82368770881656e+29*cos(theta)**77 - 6.62870836769846e+29*cos(theta)**75 + 1.92816202519531e+30*cos(theta)**73 - 4.61074595287831e+30*cos(theta)**71 + 9.24008362330856e+30*cos(theta)**69 - 1.57423646915627e+31*cos(theta)**67 + 2.30505750549968e+31*cos(theta)**65 - 2.92527126994468e+31*cos(theta)**63 + 3.23869319172447e+31*cos(theta)**61 - 3.14419551239034e+31*cos(theta)**59 + 2.68717208876117e+31*cos(theta)**57 - 2.02776673932049e+31*cos(theta)**55 + 1.35397194599412e+31*cos(theta)**53 - 8.01104912657749e+30*cos(theta)**51 + 4.20332824542646e+30*cos(theta)**49 - 1.95611951587713e+30*cos(theta)**47 + 8.07085952924878e+29*cos(theta)**45 - 2.9494835488949e+29*cos(theta)**43 + 9.53251125501825e+28*cos(theta)**41 - 2.71883799273564e+28*cos(theta)**39 + 6.82472544924495e+27*cos(theta)**37 - 1.50256765262715e+27*cos(theta)**35 + 2.88955317812914e+26*cos(theta)**33 - 4.82964253894329e+25*cos(theta)**31 + 6.97448379071003e+24*cos(theta)**29 - 8.64095336902128e+23*cos(theta)**27 + 9.10803192950892e+22*cos(theta)**25 - 8.08644444762555e+21*cos(theta)**23 + 5.97508891719996e+20*cos(theta)**21 - 3.62126601042422e+19*cos(theta)**19 + 1.76823668698613e+18*cos(theta)**17 - 6.80283421301593e+16*cos(theta)**15 + 2.00420199878415e+15*cos(theta)**13 - 43557468906426.3*cos(theta)**11 + 663617947327.824*cos(theta)**9 - 6586778633.52679*cos(theta)**7 + 38000645.9626546*cos(theta)**5 - 104139.890278582*cos(theta)**3 + 85.5007309347964*cos(theta)

#@torch.jit.script
def Yl85_m1(theta, phi):
    return 0.0610168007057101*(1.0 - cos(theta)**2)**0.5*(2.00930328040094e+26*cos(theta)**84 - 4.14463386714655e+27*cos(theta)**82 + 4.12105660862087e+28*cos(theta)**80 - 2.63081593600847e+29*cos(theta)**78 + 1.21170862819531e+30*cos(theta)**76 - 4.28990011224428e+30*cos(theta)**74 + 1.21457234834086e+31*cos(theta)**72 - 2.82479246802478e+31*cos(theta)**70 + 5.50151113732246e+31*cos(theta)**68 - 9.10126533828654e+31*cos(theta)**66 + 1.29286186427978e+32*cos(theta)**64 - 1.59024375740575e+32*cos(theta)**62 + 1.70473409594914e+32*cos(theta)**60 - 1.60073175057293e+32*cos(theta)**58 + 1.32168310873979e+32*cos(theta)**56 - 9.62360277758522e+31*cos(theta)**54 + 6.19216527640488e+31*cos(theta)**52 - 3.52546636174876e+31*cos(theta)**50 + 1.77724127289804e+31*cos(theta)**48 - 7.93323369936283e+30*cos(theta)**46 + 3.13393010642768e+30*cos(theta)**44 - 1.09438829113348e+30*cos(theta)**42 + 3.37247071820302e+29*cos(theta)**40 - 9.14965968764645e+28*cos(theta)**38 + 2.17893318442258e+28*cos(theta)**36 - 4.53794349152471e+27*cos(theta)**34 + 8.22813929781953e+26*cos(theta)**32 - 1.29191424239268e+26*cos(theta)**30 + 1.74528787403981e+25*cos(theta)**28 - 2.01317917725678e+24*cos(theta)**26 + 1.9648145123377e+23*cos(theta)**24 - 1.60487956615923e+22*cos(theta)**22 + 1.0827312493656e+21*cos(theta)**20 - 5.93705446982582e+19*cos(theta)**18 + 2.59385874895303e+18*cos(theta)**16 - 8.8051782142677e+16*cos(theta)**14 + 2.24823573933322e+15*cos(theta)**12 - 41343984061296.4*cos(theta)**10 + 515368222370.731*cos(theta)**8 - 3978580156.15673*cos(theta)**6 + 16395247.8962503*cos(theta)**4 - 26958.4783166625*cos(theta)**2 + 7.37779921090929)*cos(phi)

#@torch.jit.script
def Yl85_m2(theta, phi):
    return 0.000713756642844956*(1.0 - cos(theta)**2)*(1.68781475553679e+28*cos(theta)**83 - 3.39859977106017e+29*cos(theta)**81 + 3.2968452868967e+30*cos(theta)**79 - 2.05203643008661e+31*cos(theta)**77 + 9.20898557428439e+31*cos(theta)**75 - 3.17452608306077e+32*cos(theta)**73 + 8.74492090805419e+32*cos(theta)**71 - 1.97735472761735e+33*cos(theta)**69 + 3.74102757337927e+33*cos(theta)**67 - 6.00683512326912e+33*cos(theta)**65 + 8.27431593139057e+33*cos(theta)**63 - 9.85951129591567e+33*cos(theta)**61 + 1.02284045756948e+34*cos(theta)**59 - 9.284244153323e+33*cos(theta)**57 + 7.40142540894281e+33*cos(theta)**55 - 5.19674549989602e+33*cos(theta)**53 + 3.21992594373054e+33*cos(theta)**51 - 1.76273318087438e+33*cos(theta)**49 + 8.53075810991058e+32*cos(theta)**47 - 3.6492875017069e+32*cos(theta)**45 + 1.37892924682818e+32*cos(theta)**43 - 4.5964308227606e+31*cos(theta)**41 + 1.34898828728121e+31*cos(theta)**39 - 3.47687068130565e+30*cos(theta)**37 + 7.84415946392129e+29*cos(theta)**35 - 1.5429007871184e+29*cos(theta)**33 + 2.63300457530225e+28*cos(theta)**31 - 3.87574272717805e+27*cos(theta)**29 + 4.88680604731145e+26*cos(theta)**27 - 5.23426586086762e+25*cos(theta)**25 + 4.71555482961047e+24*cos(theta)**23 - 3.53073504555031e+23*cos(theta)**21 + 2.16546249873121e+22*cos(theta)**19 - 1.06866980456865e+21*cos(theta)**17 + 4.15017399832484e+19*cos(theta)**15 - 1.23272494999748e+18*cos(theta)**13 + 2.69788288719987e+16*cos(theta)**11 - 413439840612964.0*cos(theta)**9 + 4122945778965.85*cos(theta)**7 - 23871480936.9404*cos(theta)**5 + 65580991.585001*cos(theta)**3 - 53916.9566333251*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl85_m3(theta, phi):
    return 8.3516018330059e-6*(1.0 - cos(theta)**2)**1.5*(1.40088624709554e+30*cos(theta)**82 - 2.75286581455874e+31*cos(theta)**80 + 2.60450777664839e+32*cos(theta)**78 - 1.58006805116669e+33*cos(theta)**76 + 6.90673918071329e+33*cos(theta)**74 - 2.31740404063436e+34*cos(theta)**72 + 6.20889384471848e+34*cos(theta)**70 - 1.36437476205597e+35*cos(theta)**68 + 2.50648847416411e+35*cos(theta)**66 - 3.90444283012493e+35*cos(theta)**64 + 5.21281903677606e+35*cos(theta)**62 - 6.01430189050856e+35*cos(theta)**60 + 6.03475869965995e+35*cos(theta)**58 - 5.29201916739411e+35*cos(theta)**56 + 4.07078397491855e+35*cos(theta)**54 - 2.75427511494489e+35*cos(theta)**52 + 1.64216223130257e+35*cos(theta)**50 - 8.63739258628447e+34*cos(theta)**48 + 4.00945631165797e+34*cos(theta)**46 - 1.64217937576811e+34*cos(theta)**44 + 5.92939576136118e+33*cos(theta)**42 - 1.88453663733185e+33*cos(theta)**40 + 5.26105432039671e+32*cos(theta)**38 - 1.28644215208309e+32*cos(theta)**36 + 2.74545581237245e+31*cos(theta)**34 - 5.09157259749073e+30*cos(theta)**32 + 8.16231418343697e+29*cos(theta)**30 - 1.12396539088163e+29*cos(theta)**28 + 1.31943763277409e+28*cos(theta)**26 - 1.30856646521691e+27*cos(theta)**24 + 1.08457761081041e+26*cos(theta)**22 - 7.41454359565565e+24*cos(theta)**20 + 4.11437874758929e+23*cos(theta)**18 - 1.8167386677667e+22*cos(theta)**16 + 6.22526099748727e+20*cos(theta)**14 - 1.60254243499672e+19*cos(theta)**12 + 2.96767117591986e+17*cos(theta)**10 - 3.72095856551668e+15*cos(theta)**8 + 28860620452760.9*cos(theta)**6 - 119357404684.702*cos(theta)**4 + 196742974.755003*cos(theta)**2 - 53916.9566333251)*cos(3*phi)

#@torch.jit.script
def Yl85_m4(theta, phi):
    return 9.77614988495605e-8*(1.0 - cos(theta)**2)**2*(1.14872672261834e+32*cos(theta)**81 - 2.20229265164699e+33*cos(theta)**79 + 2.03151606578574e+34*cos(theta)**77 - 1.20085171888668e+35*cos(theta)**75 + 5.11098699372784e+35*cos(theta)**73 - 1.66853090925674e+36*cos(theta)**71 + 4.34622569130293e+36*cos(theta)**69 - 9.2777483819806e+36*cos(theta)**67 + 1.65428239294831e+37*cos(theta)**65 - 2.49884341127995e+37*cos(theta)**63 + 3.23194780280116e+37*cos(theta)**61 - 3.60858113430514e+37*cos(theta)**59 + 3.50016004580277e+37*cos(theta)**57 - 2.9635307337407e+37*cos(theta)**55 + 2.19822334645602e+37*cos(theta)**53 - 1.43222305977134e+37*cos(theta)**51 + 8.21081115651287e+36*cos(theta)**49 - 4.14594844141654e+36*cos(theta)**47 + 1.84434990336267e+36*cos(theta)**45 - 7.22558925337967e+35*cos(theta)**43 + 2.49034621977169e+35*cos(theta)**41 - 7.53814654932739e+34*cos(theta)**39 + 1.99920064175075e+34*cos(theta)**37 - 4.63119174749913e+33*cos(theta)**35 + 9.33454976206633e+32*cos(theta)**33 - 1.62930323119703e+32*cos(theta)**31 + 2.44869425503109e+31*cos(theta)**29 - 3.14710309446858e+30*cos(theta)**27 + 3.43053784521264e+29*cos(theta)**25 - 3.14055951652057e+28*cos(theta)**23 + 2.3860707437829e+27*cos(theta)**21 - 1.48290871913113e+26*cos(theta)**19 + 7.40588174566073e+24*cos(theta)**17 - 2.90678186842672e+23*cos(theta)**15 + 8.71536539648217e+21*cos(theta)**13 - 1.92305092199607e+20*cos(theta)**11 + 2.96767117591986e+18*cos(theta)**9 - 2.97676685241334e+16*cos(theta)**7 + 173163722716566.0*cos(theta)**5 - 477429618738.808*cos(theta)**3 + 393485949.510006*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl85_m5(theta, phi):
    return 1.14499631050571e-9*(1.0 - cos(theta)**2)**2.5*(9.30468645320855e+33*cos(theta)**80 - 1.73981119480112e+35*cos(theta)**78 + 1.56426737065502e+36*cos(theta)**76 - 9.00638789165013e+36*cos(theta)**74 + 3.73102050542132e+37*cos(theta)**72 - 1.18465694557228e+38*cos(theta)**70 + 2.99889572699902e+38*cos(theta)**68 - 6.216091415927e+38*cos(theta)**66 + 1.0752835554164e+39*cos(theta)**64 - 1.57427134910637e+39*cos(theta)**62 + 1.97148815970871e+39*cos(theta)**60 - 2.12906286924003e+39*cos(theta)**58 + 1.99509122610758e+39*cos(theta)**56 - 1.62994190355739e+39*cos(theta)**54 + 1.16505837362169e+39*cos(theta)**52 - 7.30433760483385e+38*cos(theta)**50 + 4.0232974666913e+38*cos(theta)**48 - 1.94859576746578e+38*cos(theta)**46 + 8.29957456513201e+37*cos(theta)**44 - 3.10700337895326e+37*cos(theta)**42 + 1.02104195010639e+37*cos(theta)**40 - 2.93987715423768e+36*cos(theta)**38 + 7.39704237447777e+35*cos(theta)**36 - 1.62091711162469e+35*cos(theta)**34 + 3.08040142148189e+34*cos(theta)**32 - 5.0508400167108e+33*cos(theta)**30 + 7.10121333959017e+32*cos(theta)**28 - 8.49717835506516e+31*cos(theta)**26 + 8.5763446130316e+30*cos(theta)**24 - 7.22328688799732e+29*cos(theta)**22 + 5.01074856194409e+28*cos(theta)**20 - 2.81752656634915e+27*cos(theta)**18 + 1.25899989676232e+26*cos(theta)**16 - 4.36017280264008e+24*cos(theta)**14 + 1.13299750154268e+23*cos(theta)**12 - 2.11535601419567e+21*cos(theta)**10 + 2.67090405832787e+19*cos(theta)**8 - 2.08373679668934e+17*cos(theta)**6 + 865818613582828.0*cos(theta)**4 - 1432288856216.42*cos(theta)**2 + 393485949.510006)*cos(5*phi)

#@torch.jit.script
def Yl85_m6(theta, phi):
    return 1.34195637440744e-11*(1.0 - cos(theta)**2)**3*(7.44374916256684e+35*cos(theta)**79 - 1.35705273194488e+37*cos(theta)**77 + 1.18884320169782e+38*cos(theta)**75 - 6.6647270398211e+38*cos(theta)**73 + 2.68633476390335e+39*cos(theta)**71 - 8.29259861900599e+39*cos(theta)**69 + 2.03924909435934e+40*cos(theta)**67 - 4.10262033451182e+40*cos(theta)**65 + 6.88181475466499e+40*cos(theta)**63 - 9.7604823644595e+40*cos(theta)**61 + 1.18289289582522e+41*cos(theta)**59 - 1.23485646415922e+41*cos(theta)**57 + 1.11725108662024e+41*cos(theta)**55 - 8.80168627920988e+40*cos(theta)**53 + 6.05830354283278e+40*cos(theta)**51 - 3.65216880241692e+40*cos(theta)**49 + 1.93118278401183e+40*cos(theta)**47 - 8.96354053034257e+39*cos(theta)**45 + 3.65181280865808e+39*cos(theta)**43 - 1.30494141916037e+39*cos(theta)**41 + 4.08416780042558e+38*cos(theta)**39 - 1.11715331861032e+38*cos(theta)**37 + 2.662935254812e+37*cos(theta)**35 - 5.51111817952396e+36*cos(theta)**33 + 9.85728454874204e+35*cos(theta)**31 - 1.51525200501324e+35*cos(theta)**29 + 1.98833973508525e+34*cos(theta)**27 - 2.20926637231694e+33*cos(theta)**25 + 2.05832270712758e+32*cos(theta)**23 - 1.58912311535941e+31*cos(theta)**21 + 1.00214971238882e+30*cos(theta)**19 - 5.07154781942846e+28*cos(theta)**17 + 2.01439983481972e+27*cos(theta)**15 - 6.10424192369611e+25*cos(theta)**13 + 1.35959700185122e+24*cos(theta)**11 - 2.11535601419567e+22*cos(theta)**9 + 2.1367232466623e+20*cos(theta)**7 - 1.2502420780136e+18*cos(theta)**5 + 3.46327445433131e+15*cos(theta)**3 - 2864577712432.85*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl85_m7(theta, phi):
    return 1.57409499591163e-13*(1.0 - cos(theta)**2)**3.5*(5.8805618384278e+37*cos(theta)**78 - 1.04493060359756e+39*cos(theta)**76 + 8.91632401273363e+39*cos(theta)**74 - 4.8652507390694e+40*cos(theta)**72 + 1.90729768237138e+41*cos(theta)**70 - 5.72189304711414e+41*cos(theta)**68 + 1.36629689322075e+42*cos(theta)**66 - 2.66670321743268e+42*cos(theta)**64 + 4.33554329543894e+42*cos(theta)**62 - 5.95389424232029e+42*cos(theta)**60 + 6.97906808536882e+42*cos(theta)**58 - 7.03868184570754e+42*cos(theta)**56 + 6.14488097641135e+42*cos(theta)**54 - 4.66489372798124e+42*cos(theta)**52 + 3.08973480684472e+42*cos(theta)**50 - 1.78956271318429e+42*cos(theta)**48 + 9.07655908485558e+41*cos(theta)**46 - 4.03359323865416e+41*cos(theta)**44 + 1.57027950772298e+41*cos(theta)**42 - 5.35025981855751e+40*cos(theta)**40 + 1.59282544216598e+40*cos(theta)**38 - 4.13346727885818e+39*cos(theta)**36 + 9.32027339184199e+38*cos(theta)**34 - 1.81866899924291e+38*cos(theta)**32 + 3.05575821011003e+37*cos(theta)**30 - 4.3942308145384e+36*cos(theta)**28 + 5.36851728473017e+35*cos(theta)**26 - 5.52316593079235e+34*cos(theta)**24 + 4.73414222639344e+33*cos(theta)**22 - 3.33715854225476e+32*cos(theta)**20 + 1.90408445353875e+31*cos(theta)**18 - 8.62163129302839e+29*cos(theta)**16 + 3.02159975222958e+28*cos(theta)**14 - 7.93551450080495e+26*cos(theta)**12 + 1.49555670203634e+25*cos(theta)**10 - 1.90382041277611e+23*cos(theta)**8 + 1.49570627266361e+21*cos(theta)**6 - 6.25121039006802e+18*cos(theta)**4 + 1.03898233629939e+16*cos(theta)**2 - 2864577712432.85)*cos(7*phi)

#@torch.jit.script
def Yl85_m8(theta, phi):
    return 1.84817104808673e-15*(1.0 - cos(theta)**2)**4*(4.58683823397368e+39*cos(theta)**77 - 7.94147258734142e+40*cos(theta)**75 + 6.59807976942289e+41*cos(theta)**73 - 3.50298053212997e+42*cos(theta)**71 + 1.33510837765997e+43*cos(theta)**69 - 3.89088727203761e+43*cos(theta)**67 + 9.01755949525698e+43*cos(theta)**65 - 1.70669005915692e+44*cos(theta)**63 + 2.68803684317215e+44*cos(theta)**61 - 3.57233654539218e+44*cos(theta)**59 + 4.04785948951392e+44*cos(theta)**57 - 3.94166183359622e+44*cos(theta)**55 + 3.31823572726213e+44*cos(theta)**53 - 2.42574473855024e+44*cos(theta)**51 + 1.54486740342236e+44*cos(theta)**49 - 8.5899010232846e+43*cos(theta)**47 + 4.17521717903357e+43*cos(theta)**45 - 1.77478102500783e+43*cos(theta)**43 + 6.5951739324365e+42*cos(theta)**41 - 2.140103927423e+42*cos(theta)**39 + 6.05273668023071e+41*cos(theta)**37 - 1.48804822038894e+41*cos(theta)**35 + 3.16889295322628e+40*cos(theta)**33 - 5.8197407975773e+39*cos(theta)**31 + 9.1672746303301e+38*cos(theta)**29 - 1.23038462807075e+38*cos(theta)**27 + 1.39581449402984e+37*cos(theta)**25 - 1.32555982339016e+36*cos(theta)**23 + 1.04151128980656e+35*cos(theta)**21 - 6.67431708450953e+33*cos(theta)**19 + 3.42735201636976e+32*cos(theta)**17 - 1.37946100688454e+31*cos(theta)**15 + 4.23023965312141e+29*cos(theta)**13 - 9.52261740096594e+27*cos(theta)**11 + 1.49555670203634e+26*cos(theta)**9 - 1.52305633022088e+24*cos(theta)**7 + 8.97423763598164e+21*cos(theta)**5 - 2.50048415602721e+19*cos(theta)**3 + 2.07796467259879e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl85_m9(theta, phi):
    return 2.17236538128397e-17*(1.0 - cos(theta)**2)**4.5*(3.53186544015974e+41*cos(theta)**76 - 5.95610444050607e+42*cos(theta)**74 + 4.81659823167871e+43*cos(theta)**72 - 2.48711617781228e+44*cos(theta)**70 + 9.21224780585376e+44*cos(theta)**68 - 2.6068944722652e+45*cos(theta)**66 + 5.86141367191704e+45*cos(theta)**64 - 1.07521473726886e+46*cos(theta)**62 + 1.63970247433501e+46*cos(theta)**60 - 2.10767856178138e+46*cos(theta)**58 + 2.30727990902293e+46*cos(theta)**56 - 2.16791400847792e+46*cos(theta)**54 + 1.75866493544893e+46*cos(theta)**52 - 1.23712981666062e+46*cos(theta)**50 + 7.56985027676956e+45*cos(theta)**48 - 4.03725348094376e+45*cos(theta)**46 + 1.87884773056511e+45*cos(theta)**44 - 7.63155840753366e+44*cos(theta)**42 + 2.70402131229896e+44*cos(theta)**40 - 8.34640531694971e+43*cos(theta)**38 + 2.23951257168536e+43*cos(theta)**36 - 5.20816877136131e+42*cos(theta)**34 + 1.04573467456467e+42*cos(theta)**32 - 1.80411964724896e+41*cos(theta)**30 + 2.65850964279573e+40*cos(theta)**28 - 3.32203849579103e+39*cos(theta)**26 + 3.48953623507461e+38*cos(theta)**24 - 3.04878759379738e+37*cos(theta)**22 + 2.18717370859377e+36*cos(theta)**20 - 1.26812024605681e+35*cos(theta)**18 + 5.82649842782859e+33*cos(theta)**16 - 2.06919151032681e+32*cos(theta)**14 + 5.49931154905783e+30*cos(theta)**12 - 1.04748791410625e+29*cos(theta)**10 + 1.34600103183271e+27*cos(theta)**8 - 1.06613943115462e+25*cos(theta)**6 + 4.48711881799082e+22*cos(theta)**4 - 7.50145246808162e+19*cos(theta)**2 + 2.07796467259879e+16)*cos(9*phi)

#@torch.jit.script
def Yl85_m10(theta, phi):
    return 2.55660877079906e-19*(1.0 - cos(theta)**2)**5*(2.6842177345214e+43*cos(theta)**75 - 4.40751728597449e+44*cos(theta)**73 + 3.46795072680867e+45*cos(theta)**71 - 1.74098132446859e+46*cos(theta)**69 + 6.26432850798056e+46*cos(theta)**67 - 1.72055035169503e+47*cos(theta)**65 + 3.7513047500269e+47*cos(theta)**63 - 6.66633137106692e+47*cos(theta)**61 + 9.83821484601005e+47*cos(theta)**59 - 1.2224535658332e+48*cos(theta)**57 + 1.29207674905284e+48*cos(theta)**55 - 1.17067356457808e+48*cos(theta)**53 + 9.14505766433442e+47*cos(theta)**51 - 6.18564908330312e+47*cos(theta)**49 + 3.63352813284939e+47*cos(theta)**47 - 1.85713660123413e+47*cos(theta)**45 + 8.26693001448646e+46*cos(theta)**43 - 3.20525453116414e+46*cos(theta)**41 + 1.08160852491959e+46*cos(theta)**39 - 3.17163402044089e+45*cos(theta)**37 + 8.0622452580673e+44*cos(theta)**35 - 1.77077738226284e+44*cos(theta)**33 + 3.34635095860695e+43*cos(theta)**31 - 5.41235894174689e+42*cos(theta)**29 + 7.44382699982804e+41*cos(theta)**27 - 8.63730008905667e+40*cos(theta)**25 + 8.37488696417906e+39*cos(theta)**23 - 6.70733270635423e+38*cos(theta)**21 + 4.37434741718754e+37*cos(theta)**19 - 2.28261644290226e+36*cos(theta)**17 + 9.32239748452574e+34*cos(theta)**15 - 2.89686811445754e+33*cos(theta)**13 + 6.59917385886939e+31*cos(theta)**11 - 1.04748791410625e+30*cos(theta)**9 + 1.07680082546617e+28*cos(theta)**7 - 6.39683658692771e+25*cos(theta)**5 + 1.79484752719633e+23*cos(theta)**3 - 1.50029049361632e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl85_m11(theta, phi):
    return 3.0129923311217e-21*(1.0 - cos(theta)**2)**5.5*(2.01316330089105e+45*cos(theta)**74 - 3.21748761876138e+46*cos(theta)**72 + 2.46224501603416e+47*cos(theta)**70 - 1.20127711388333e+48*cos(theta)**68 + 4.19710010034697e+48*cos(theta)**66 - 1.11835772860177e+49*cos(theta)**64 + 2.36332199251695e+49*cos(theta)**62 - 4.06646213635082e+49*cos(theta)**60 + 5.80454675914593e+49*cos(theta)**58 - 6.96798532524925e+49*cos(theta)**56 + 7.10642211979063e+49*cos(theta)**54 - 6.20456989226381e+49*cos(theta)**52 + 4.66397940881055e+49*cos(theta)**50 - 3.03096805081853e+49*cos(theta)**48 + 1.70775822243921e+49*cos(theta)**46 - 8.35711470555359e+48*cos(theta)**44 + 3.55477990622918e+48*cos(theta)**42 - 1.3141543577773e+48*cos(theta)**40 + 4.21827324718638e+47*cos(theta)**38 - 1.17350458756313e+47*cos(theta)**36 + 2.82178584032356e+46*cos(theta)**34 - 5.84356536146738e+45*cos(theta)**32 + 1.03736879716815e+45*cos(theta)**30 - 1.5695840931066e+44*cos(theta)**28 + 2.00983328995357e+43*cos(theta)**26 - 2.15932502226417e+42*cos(theta)**24 + 1.92622400176118e+41*cos(theta)**22 - 1.40853986833439e+40*cos(theta)**20 + 8.31126009265633e+38*cos(theta)**18 - 3.88044795293384e+37*cos(theta)**16 + 1.39835962267886e+36*cos(theta)**14 - 3.7659285487948e+34*cos(theta)**12 + 7.25909124475633e+32*cos(theta)**10 - 9.42739122695628e+30*cos(theta)**8 + 7.53760577826316e+28*cos(theta)**6 - 3.19841829346386e+26*cos(theta)**4 + 5.38454258158898e+23*cos(theta)**2 - 1.50029049361632e+20)*cos(11*phi)

#@torch.jit.script
def Yl85_m12(theta, phi):
    return 3.55628288167851e-23*(1.0 - cos(theta)**2)**6*(1.48974084265938e+47*cos(theta)**73 - 2.31659108550819e+48*cos(theta)**71 + 1.72357151122391e+49*cos(theta)**69 - 8.16868437440665e+49*cos(theta)**67 + 2.770086066229e+50*cos(theta)**65 - 7.15748946305133e+50*cos(theta)**63 + 1.46525963536051e+51*cos(theta)**61 - 2.43987728181049e+51*cos(theta)**59 + 3.36663712030464e+51*cos(theta)**57 - 3.90207178213958e+51*cos(theta)**55 + 3.83746794468694e+51*cos(theta)**53 - 3.22637634397718e+51*cos(theta)**51 + 2.33198970440528e+51*cos(theta)**49 - 1.45486466439289e+51*cos(theta)**47 + 7.85568782322037e+50*cos(theta)**45 - 3.67713047044358e+50*cos(theta)**43 + 1.49300756061626e+50*cos(theta)**41 - 5.25661743110919e+49*cos(theta)**39 + 1.60294383393083e+49*cos(theta)**37 - 4.22461651522727e+48*cos(theta)**35 + 9.59407185710009e+47*cos(theta)**33 - 1.86994091566956e+47*cos(theta)**31 + 3.11210639150446e+46*cos(theta)**29 - 4.39483546069848e+45*cos(theta)**27 + 5.22556655387929e+44*cos(theta)**25 - 5.182380053434e+43*cos(theta)**23 + 4.2376928038746e+42*cos(theta)**21 - 2.81707973666878e+41*cos(theta)**19 + 1.49602681667814e+40*cos(theta)**17 - 6.20871672469414e+38*cos(theta)**15 + 1.9577034717504e+37*cos(theta)**13 - 4.51911425855376e+35*cos(theta)**11 + 7.25909124475633e+33*cos(theta)**9 - 7.54191298156502e+31*cos(theta)**7 + 4.52256346695789e+29*cos(theta)**5 - 1.27936731738554e+27*cos(theta)**3 + 1.0769085163178e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl85_m13(theta, phi):
    return 4.20457236344704e-25*(1.0 - cos(theta)**2)**6.5*(1.08751081514135e+49*cos(theta)**72 - 1.64477967071082e+50*cos(theta)**70 + 1.1892643427445e+51*cos(theta)**68 - 5.47301853085245e+51*cos(theta)**66 + 1.80055594304885e+52*cos(theta)**64 - 4.50921836172234e+52*cos(theta)**62 + 8.93808377569911e+52*cos(theta)**60 - 1.43952759626819e+53*cos(theta)**58 + 1.91898315857364e+53*cos(theta)**56 - 2.14613948017677e+53*cos(theta)**54 + 2.03385801068408e+53*cos(theta)**52 - 1.64545193542836e+53*cos(theta)**50 + 1.14267495515859e+53*cos(theta)**48 - 6.8378639226466e+52*cos(theta)**46 + 3.53505952044917e+52*cos(theta)**44 - 1.58116610229074e+52*cos(theta)**42 + 6.12133099852665e+51*cos(theta)**40 - 2.05008079813258e+51*cos(theta)**38 + 5.93089218554406e+50*cos(theta)**36 - 1.47861578032954e+50*cos(theta)**34 + 3.16604371284303e+49*cos(theta)**32 - 5.79681683857565e+48*cos(theta)**30 + 9.02510853536294e+47*cos(theta)**28 - 1.18660557438859e+47*cos(theta)**26 + 1.30639163846982e+46*cos(theta)**24 - 1.19194741228982e+45*cos(theta)**22 + 8.89915488813667e+43*cos(theta)**20 - 5.35245149967068e+42*cos(theta)**18 + 2.54324558835284e+41*cos(theta)**16 - 9.31307508704121e+39*cos(theta)**14 + 2.54501451327553e+38*cos(theta)**12 - 4.97102568440914e+36*cos(theta)**10 + 6.5331821202807e+34*cos(theta)**8 - 5.27933908709551e+32*cos(theta)**6 + 2.26128173347895e+30*cos(theta)**4 - 3.83810195215663e+27*cos(theta)**2 + 1.0769085163178e+24)*cos(13*phi)

#@torch.jit.script
def Yl85_m14(theta, phi):
    return 4.98009911031062e-27*(1.0 - cos(theta)**2)**7*(7.83007786901769e+50*cos(theta)**71 - 1.15134576949757e+52*cos(theta)**69 + 8.08699753066258e+52*cos(theta)**67 - 3.61219223036262e+53*cos(theta)**65 + 1.15235580355126e+54*cos(theta)**63 - 2.79571538426785e+54*cos(theta)**61 + 5.36285026541946e+54*cos(theta)**59 - 8.34926005835551e+54*cos(theta)**57 + 1.07463056880124e+55*cos(theta)**55 - 1.15891531929546e+55*cos(theta)**53 + 1.05760616555572e+55*cos(theta)**51 - 8.22725967714182e+54*cos(theta)**49 + 5.48483978476121e+54*cos(theta)**47 - 3.14541740441744e+54*cos(theta)**45 + 1.55542618899763e+54*cos(theta)**43 - 6.6408976296211e+53*cos(theta)**41 + 2.44853239941066e+53*cos(theta)**39 - 7.79030703290381e+52*cos(theta)**37 + 2.13512118679586e+52*cos(theta)**35 - 5.02729365312045e+51*cos(theta)**33 + 1.01313398810977e+51*cos(theta)**31 - 1.73904505157269e+50*cos(theta)**29 + 2.52703038990162e+49*cos(theta)**27 - 3.08517449341033e+48*cos(theta)**25 + 3.13533993232757e+47*cos(theta)**23 - 2.62228430703761e+46*cos(theta)**21 + 1.77983097762733e+45*cos(theta)**19 - 9.63441269940722e+43*cos(theta)**17 + 4.06919294136454e+42*cos(theta)**15 - 1.30383051218577e+41*cos(theta)**13 + 3.05401741593063e+39*cos(theta)**11 - 4.97102568440914e+37*cos(theta)**9 + 5.22654569622456e+35*cos(theta)**7 - 3.16760345225731e+33*cos(theta)**5 + 9.04512693391579e+30*cos(theta)**3 - 7.67620390431326e+27*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl85_m15(theta, phi):
    return 5.91029028010417e-29*(1.0 - cos(theta)**2)**7.5*(5.55935528700256e+52*cos(theta)**70 - 7.94428580953324e+53*cos(theta)**68 + 5.41828834554393e+54*cos(theta)**66 - 2.3479249497357e+55*cos(theta)**64 + 7.25984156237297e+55*cos(theta)**62 - 1.70538638440339e+56*cos(theta)**60 + 3.16408165659748e+56*cos(theta)**58 - 4.75907823326264e+56*cos(theta)**56 + 5.91046812840683e+56*cos(theta)**54 - 6.14225119226592e+56*cos(theta)**52 + 5.39379144433418e+56*cos(theta)**50 - 4.03135724179949e+56*cos(theta)**48 + 2.57787469883777e+56*cos(theta)**46 - 1.41543783198785e+56*cos(theta)**44 + 6.68833261268983e+55*cos(theta)**42 - 2.72276802814465e+55*cos(theta)**40 + 9.54927635770157e+54*cos(theta)**38 - 2.88241360217441e+54*cos(theta)**36 + 7.47292415378551e+53*cos(theta)**34 - 1.65900690552975e+53*cos(theta)**32 + 3.14071536314029e+52*cos(theta)**30 - 5.04323064956081e+51*cos(theta)**28 + 6.82298205273438e+50*cos(theta)**26 - 7.71293623352583e+49*cos(theta)**24 + 7.21128184435341e+48*cos(theta)**22 - 5.50679704477897e+47*cos(theta)**20 + 3.38167885749193e+46*cos(theta)**18 - 1.63785015889923e+45*cos(theta)**16 + 6.10378941204681e+43*cos(theta)**14 - 1.6949796658415e+42*cos(theta)**12 + 3.35941915752369e+40*cos(theta)**10 - 4.47392311596822e+38*cos(theta)**8 + 3.65858198735719e+36*cos(theta)**6 - 1.58380172612865e+34*cos(theta)**4 + 2.71353808017474e+31*cos(theta)**2 - 7.67620390431326e+27)*cos(15*phi)

#@torch.jit.script
def Yl85_m16(theta, phi):
    return 7.02909000923895e-31*(1.0 - cos(theta)**2)**8*(3.89154870090179e+54*cos(theta)**69 - 5.4021143504826e+55*cos(theta)**67 + 3.57607030805899e+56*cos(theta)**65 - 1.50267196783085e+57*cos(theta)**63 + 4.50110176867124e+57*cos(theta)**61 - 1.02323183064203e+58*cos(theta)**59 + 1.83516736082654e+58*cos(theta)**57 - 2.66508381062708e+58*cos(theta)**55 + 3.19165278933969e+58*cos(theta)**53 - 3.19397061997828e+58*cos(theta)**51 + 2.69689572216709e+58*cos(theta)**49 - 1.93505147606376e+58*cos(theta)**47 + 1.18582236146537e+58*cos(theta)**45 - 6.22792646074653e+57*cos(theta)**43 + 2.80909969732973e+57*cos(theta)**41 - 1.08910721125786e+57*cos(theta)**39 + 3.6287250159266e+56*cos(theta)**37 - 1.03766889678279e+56*cos(theta)**35 + 2.54079421228707e+55*cos(theta)**33 - 5.30882209769519e+54*cos(theta)**31 + 9.42214608942085e+53*cos(theta)**29 - 1.41210458187703e+53*cos(theta)**27 + 1.77397533371094e+52*cos(theta)**25 - 1.8511046960462e+51*cos(theta)**23 + 1.58648200575775e+50*cos(theta)**21 - 1.10135940895579e+49*cos(theta)**19 + 6.08702194348548e+47*cos(theta)**17 - 2.62056025423876e+46*cos(theta)**15 + 8.54530517686553e+44*cos(theta)**13 - 2.0339755990098e+43*cos(theta)**11 + 3.35941915752369e+41*cos(theta)**9 - 3.57913849277458e+39*cos(theta)**7 + 2.19514919241431e+37*cos(theta)**5 - 6.33520690451462e+34*cos(theta)**3 + 5.42707616034947e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl85_m17(theta, phi):
    return 8.37865818516174e-33*(1.0 - cos(theta)**2)**8.5*(2.68516860362224e+56*cos(theta)**68 - 3.61941661482334e+57*cos(theta)**66 + 2.32444570023835e+58*cos(theta)**64 - 9.46683339733435e+58*cos(theta)**62 + 2.74567207888946e+59*cos(theta)**60 - 6.037067800788e+59*cos(theta)**58 + 1.04604539567113e+60*cos(theta)**56 - 1.46579609584489e+60*cos(theta)**54 + 1.69157597835003e+60*cos(theta)**52 - 1.62892501618892e+60*cos(theta)**50 + 1.32147890386187e+60*cos(theta)**48 - 9.09474193749965e+59*cos(theta)**46 + 5.33620062659418e+59*cos(theta)**44 - 2.67800837812101e+59*cos(theta)**42 + 1.15173087590519e+59*cos(theta)**40 - 4.24751812390566e+58*cos(theta)**38 + 1.34262825589284e+58*cos(theta)**36 - 3.63184113873976e+57*cos(theta)**34 + 8.38462090054734e+56*cos(theta)**32 - 1.64573485028551e+56*cos(theta)**30 + 2.73242236593205e+55*cos(theta)**28 - 3.81268237106797e+54*cos(theta)**26 + 4.43493833427735e+53*cos(theta)**24 - 4.25754080090626e+52*cos(theta)**22 + 3.33161221209128e+51*cos(theta)**20 - 2.09258287701601e+50*cos(theta)**18 + 1.03479373039253e+49*cos(theta)**16 - 3.93084038135815e+47*cos(theta)**14 + 1.11088967299252e+46*cos(theta)**12 - 2.23737315891078e+44*cos(theta)**10 + 3.02347724177133e+42*cos(theta)**8 - 2.5053969449422e+40*cos(theta)**6 + 1.09757459620716e+38*cos(theta)**4 - 1.90056207135439e+35*cos(theta)**2 + 5.42707616034947e+31)*cos(17*phi)

#@torch.jit.script
def Yl85_m18(theta, phi):
    return 1.00115519358469e-34*(1.0 - cos(theta)**2)**9*(1.82591465046312e+58*cos(theta)**67 - 2.38881496578341e+59*cos(theta)**65 + 1.48764524815254e+60*cos(theta)**63 - 5.8694367063473e+60*cos(theta)**61 + 1.64740324733367e+61*cos(theta)**59 - 3.50149932445704e+61*cos(theta)**57 + 5.85785421575832e+61*cos(theta)**55 - 7.91529891756242e+61*cos(theta)**53 + 8.79619508742017e+61*cos(theta)**51 - 8.14462508094461e+61*cos(theta)**49 + 6.34309873853699e+61*cos(theta)**47 - 4.18358129124984e+61*cos(theta)**45 + 2.34792827570144e+61*cos(theta)**43 - 1.12476351881082e+61*cos(theta)**41 + 4.60692350362075e+60*cos(theta)**39 - 1.61405688708415e+60*cos(theta)**37 + 4.83346172121423e+59*cos(theta)**35 - 1.23482598717152e+59*cos(theta)**33 + 2.68307868817515e+58*cos(theta)**31 - 4.93720455085653e+57*cos(theta)**29 + 7.65078262460973e+56*cos(theta)**27 - 9.91297416477673e+55*cos(theta)**25 + 1.06438520022656e+55*cos(theta)**23 - 9.36658976199376e+53*cos(theta)**21 + 6.66322442418255e+52*cos(theta)**19 - 3.76664917862882e+51*cos(theta)**17 + 1.65566996862805e+50*cos(theta)**15 - 5.5031765339014e+48*cos(theta)**13 + 1.33306760759102e+47*cos(theta)**11 - 2.23737315891078e+45*cos(theta)**9 + 2.41878179341706e+43*cos(theta)**7 - 1.50323816696532e+41*cos(theta)**5 + 4.39029838482863e+38*cos(theta)**3 - 3.80112414270877e+35*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl85_m19(theta, phi):
    return 1.19935385017276e-36*(1.0 - cos(theta)**2)**9.5*(1.22336281581029e+60*cos(theta)**66 - 1.55272972775921e+61*cos(theta)**64 + 9.37216506336101e+61*cos(theta)**62 - 3.58035639087185e+62*cos(theta)**60 + 9.71967915926868e+62*cos(theta)**58 - 1.99585461494051e+63*cos(theta)**56 + 3.22181981866707e+63*cos(theta)**54 - 4.19510842630808e+63*cos(theta)**52 + 4.48605949458429e+63*cos(theta)**50 - 3.99086628966286e+63*cos(theta)**48 + 2.98125640711239e+63*cos(theta)**46 - 1.88261158106243e+63*cos(theta)**44 + 1.00960915855162e+63*cos(theta)**42 - 4.61153042712437e+62*cos(theta)**40 + 1.79670016641209e+62*cos(theta)**38 - 5.97201048221136e+61*cos(theta)**36 + 1.69171160242498e+61*cos(theta)**34 - 4.07492575766601e+60*cos(theta)**32 + 8.31754393334296e+59*cos(theta)**30 - 1.43178931974839e+59*cos(theta)**28 + 2.06571130864463e+58*cos(theta)**26 - 2.47824354119418e+57*cos(theta)**24 + 2.4480859605211e+56*cos(theta)**22 - 1.96698385001869e+55*cos(theta)**20 + 1.26601264059469e+54*cos(theta)**18 - 6.40330360366899e+52*cos(theta)**16 + 2.48350495294208e+51*cos(theta)**14 - 7.15412949407183e+49*cos(theta)**12 + 1.46637436835013e+48*cos(theta)**10 - 2.0136358430197e+46*cos(theta)**8 + 1.69314725539194e+44*cos(theta)**6 - 7.51619083482662e+41*cos(theta)**4 + 1.31708951544859e+39*cos(theta)**2 - 3.80112414270877e+35)*cos(19*phi)

#@torch.jit.script
def Yl85_m20(theta, phi):
    return 1.44072375286506e-38*(1.0 - cos(theta)**2)**10*(8.07419458434792e+61*cos(theta)**65 - 9.93747025765897e+62*cos(theta)**63 + 5.81074233928382e+63*cos(theta)**61 - 2.14821383452311e+64*cos(theta)**59 + 5.63741391237583e+64*cos(theta)**57 - 1.11767858436669e+65*cos(theta)**55 + 1.73978270208022e+65*cos(theta)**53 - 2.1814563816802e+65*cos(theta)**51 + 2.24302974729214e+65*cos(theta)**49 - 1.91561581903817e+65*cos(theta)**47 + 1.3713779472717e+65*cos(theta)**45 - 8.28349095667468e+64*cos(theta)**43 + 4.2403584659168e+64*cos(theta)**41 - 1.84461217084975e+64*cos(theta)**39 + 6.82746063236596e+63*cos(theta)**37 - 2.14992377359609e+63*cos(theta)**35 + 5.75181944824493e+62*cos(theta)**33 - 1.30397624245312e+62*cos(theta)**31 + 2.49526318000289e+61*cos(theta)**29 - 4.0090100952955e+60*cos(theta)**27 + 5.37084940247603e+59*cos(theta)**25 - 5.94778449886604e+58*cos(theta)**23 + 5.38578911314641e+57*cos(theta)**21 - 3.93396770003738e+56*cos(theta)**19 + 2.27882275307043e+55*cos(theta)**17 - 1.02452857658704e+54*cos(theta)**15 + 3.47690693411891e+52*cos(theta)**13 - 8.58495539288619e+50*cos(theta)**11 + 1.46637436835013e+49*cos(theta)**9 - 1.61090867441576e+47*cos(theta)**7 + 1.01588835323517e+45*cos(theta)**5 - 3.00647633393065e+42*cos(theta)**3 + 2.63417903089718e+39*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl85_m21(theta, phi):
    return 1.73568577984927e-40*(1.0 - cos(theta)**2)**10.5*(5.24822647982615e+63*cos(theta)**64 - 6.26060626232515e+64*cos(theta)**62 + 3.54455282696313e+65*cos(theta)**60 - 1.26744616236864e+66*cos(theta)**58 + 3.21332593005422e+66*cos(theta)**56 - 6.14723221401678e+66*cos(theta)**54 + 9.22084832102517e+66*cos(theta)**52 - 1.1125427546569e+67*cos(theta)**50 + 1.09908457617315e+67*cos(theta)**48 - 9.0033943494794e+66*cos(theta)**46 + 6.17120076272264e+66*cos(theta)**44 - 3.56190111137011e+66*cos(theta)**42 + 1.73854697102589e+66*cos(theta)**40 - 7.19398746631402e+65*cos(theta)**38 + 2.5261604339754e+65*cos(theta)**36 - 7.52473320758631e+64*cos(theta)**34 + 1.89810041792083e+64*cos(theta)**32 - 4.04232635160468e+63*cos(theta)**30 + 7.23626322200838e+62*cos(theta)**28 - 1.08243272572979e+62*cos(theta)**26 + 1.34271235061901e+61*cos(theta)**24 - 1.36799043473919e+60*cos(theta)**22 + 1.13101571376075e+59*cos(theta)**20 - 7.47453863007102e+57*cos(theta)**18 + 3.87399868021974e+56*cos(theta)**16 - 1.53679286488056e+55*cos(theta)**14 + 4.51997901435458e+53*cos(theta)**12 - 9.44345093217481e+51*cos(theta)**10 + 1.31973693151511e+50*cos(theta)**8 - 1.12763607209103e+48*cos(theta)**6 + 5.07944176617583e+45*cos(theta)**4 - 9.01942900179194e+42*cos(theta)**2 + 2.63417903089718e+39)*cos(21*phi)

#@torch.jit.script
def Yl85_m22(theta, phi):
    return 2.09743847112246e-42*(1.0 - cos(theta)**2)**11*(3.35886494708873e+65*cos(theta)**63 - 3.8815758826416e+66*cos(theta)**61 + 2.12673169617788e+67*cos(theta)**59 - 7.35118774173809e+67*cos(theta)**57 + 1.79946252083037e+68*cos(theta)**55 - 3.31950539556906e+68*cos(theta)**53 + 4.79484112693309e+68*cos(theta)**51 - 5.56271377328452e+68*cos(theta)**49 + 5.27560596563112e+68*cos(theta)**47 - 4.14156140076053e+68*cos(theta)**45 + 2.71532833559796e+68*cos(theta)**43 - 1.49599846677545e+68*cos(theta)**41 + 6.95418788410355e+67*cos(theta)**39 - 2.73371523719933e+67*cos(theta)**37 + 9.09417756231145e+66*cos(theta)**35 - 2.55840929057934e+66*cos(theta)**33 + 6.07392133734665e+65*cos(theta)**31 - 1.2126979054814e+65*cos(theta)**29 + 2.02615370216235e+64*cos(theta)**27 - 2.81432508689744e+63*cos(theta)**25 + 3.22250964148562e+62*cos(theta)**23 - 3.00957895642622e+61*cos(theta)**21 + 2.26203142752149e+60*cos(theta)**19 - 1.34541695341278e+59*cos(theta)**17 + 6.19839788835158e+57*cos(theta)**15 - 2.15151001083278e+56*cos(theta)**13 + 5.42397481722549e+54*cos(theta)**11 - 9.44345093217481e+52*cos(theta)**9 + 1.05578954521209e+51*cos(theta)**7 - 6.7658164325462e+48*cos(theta)**5 + 2.03177670647033e+46*cos(theta)**3 - 1.80388580035839e+43*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl85_m23(theta, phi):
    return 2.54276998926749e-44*(1.0 - cos(theta)**2)**11.5*(2.1160849166659e+67*cos(theta)**62 - 2.36776128841137e+68*cos(theta)**60 + 1.25477170074495e+69*cos(theta)**58 - 4.19017701279071e+69*cos(theta)**56 + 9.89704386456701e+69*cos(theta)**54 - 1.7593378596516e+70*cos(theta)**52 + 2.44536897473587e+70*cos(theta)**50 - 2.72572974890941e+70*cos(theta)**48 + 2.47953480384663e+70*cos(theta)**46 - 1.86370263034224e+70*cos(theta)**44 + 1.16759118430712e+70*cos(theta)**42 - 6.13359371377934e+69*cos(theta)**40 + 2.71213327480039e+69*cos(theta)**38 - 1.01147463776375e+69*cos(theta)**36 + 3.18296214680901e+68*cos(theta)**34 - 8.44275065891184e+67*cos(theta)**32 + 1.88291561457746e+67*cos(theta)**30 - 3.51682392589607e+66*cos(theta)**28 + 5.47061499583833e+65*cos(theta)**26 - 7.0358127172436e+64*cos(theta)**24 + 7.41177217541693e+63*cos(theta)**22 - 6.32011580849505e+62*cos(theta)**20 + 4.29785971229084e+61*cos(theta)**18 - 2.28720882080173e+60*cos(theta)**16 + 9.29759683252737e+58*cos(theta)**14 - 2.79696301408261e+57*cos(theta)**12 + 5.96637229894804e+55*cos(theta)**10 - 8.49910583895733e+53*cos(theta)**8 + 7.39052681648463e+51*cos(theta)**6 - 3.3829082162731e+49*cos(theta)**4 + 6.09533011941099e+46*cos(theta)**2 - 1.80388580035839e+43)*cos(23*phi)

#@torch.jit.script
def Yl85_m24(theta, phi):
    return 3.09312864802992e-46*(1.0 - cos(theta)**2)**12*(1.31197264833286e+69*cos(theta)**61 - 1.42065677304682e+70*cos(theta)**59 + 7.2776758643207e+70*cos(theta)**57 - 2.3464991271628e+71*cos(theta)**55 + 5.34440368686619e+71*cos(theta)**53 - 9.14855687018833e+71*cos(theta)**51 + 1.22268448736794e+72*cos(theta)**49 - 1.30835027947652e+72*cos(theta)**47 + 1.14058600976945e+72*cos(theta)**45 - 8.20029157350584e+71*cos(theta)**43 + 4.90388297408992e+71*cos(theta)**41 - 2.45343748551173e+71*cos(theta)**39 + 1.03061064442415e+71*cos(theta)**37 - 3.64130869594951e+70*cos(theta)**35 + 1.08220712991506e+70*cos(theta)**33 - 2.70168021085179e+69*cos(theta)**31 + 5.64874684373238e+68*cos(theta)**29 - 9.847106992509e+67*cos(theta)**27 + 1.42235989891797e+67*cos(theta)**25 - 1.68859505213846e+66*cos(theta)**23 + 1.63058987859172e+65*cos(theta)**21 - 1.26402316169901e+64*cos(theta)**19 + 7.73614748212351e+62*cos(theta)**17 - 3.65953411328277e+61*cos(theta)**15 + 1.30166355655383e+60*cos(theta)**13 - 3.35635561689914e+58*cos(theta)**11 + 5.96637229894804e+56*cos(theta)**9 - 6.79928467116586e+54*cos(theta)**7 + 4.43431608989078e+52*cos(theta)**5 - 1.35316328650924e+50*cos(theta)**3 + 1.2190660238822e+47*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl85_m25(theta, phi):
    return 3.77604119202241e-48*(1.0 - cos(theta)**2)**12.5*(8.00303315483044e+70*cos(theta)**60 - 8.38187496097626e+71*cos(theta)**58 + 4.1482752426628e+72*cos(theta)**56 - 1.29057451993954e+73*cos(theta)**54 + 2.83253395403908e+73*cos(theta)**52 - 4.66576400379605e+73*cos(theta)**50 + 5.99115398810289e+73*cos(theta)**48 - 6.14924631353964e+73*cos(theta)**46 + 5.13263704396252e+73*cos(theta)**44 - 3.52612537660751e+73*cos(theta)**42 + 2.01059201937687e+73*cos(theta)**40 - 9.56840619349576e+72*cos(theta)**38 + 3.81325938436934e+72*cos(theta)**36 - 1.27445804358233e+72*cos(theta)**34 + 3.57128352871971e+71*cos(theta)**32 - 8.37520865364054e+70*cos(theta)**30 + 1.63813658468239e+70*cos(theta)**28 - 2.65871888797743e+69*cos(theta)**26 + 3.55589974729492e+68*cos(theta)**24 - 3.88376861991847e+67*cos(theta)**22 + 3.42423874504262e+66*cos(theta)**20 - 2.40164400722812e+65*cos(theta)**18 + 1.315145071961e+64*cos(theta)**16 - 5.48930116992416e+62*cos(theta)**14 + 1.69216262351998e+61*cos(theta)**12 - 3.69199117858905e+59*cos(theta)**10 + 5.36973506905324e+57*cos(theta)**8 - 4.7594992698161e+55*cos(theta)**6 + 2.21715804494539e+53*cos(theta)**4 - 4.05948985952772e+50*cos(theta)**2 + 1.2190660238822e+47)*cos(25*phi)

#@torch.jit.script
def Yl85_m26(theta, phi):
    return 4.62700116333901e-50*(1.0 - cos(theta)**2)**13*(4.80181989289826e+72*cos(theta)**59 - 4.86148747736623e+73*cos(theta)**57 + 2.32303413589117e+74*cos(theta)**55 - 6.96910240767351e+74*cos(theta)**53 + 1.47291765610032e+75*cos(theta)**51 - 2.33288200189802e+75*cos(theta)**49 + 2.87575391428939e+75*cos(theta)**47 - 2.82865330422823e+75*cos(theta)**45 + 2.25836029934351e+75*cos(theta)**43 - 1.48097265817516e+75*cos(theta)**41 + 8.04236807750746e+74*cos(theta)**39 - 3.63599435352839e+74*cos(theta)**37 + 1.37277337837296e+74*cos(theta)**35 - 4.33315734817991e+73*cos(theta)**33 + 1.14281072919031e+73*cos(theta)**31 - 2.51256259609216e+72*cos(theta)**29 + 4.58678243711069e+71*cos(theta)**27 - 6.91266910874132e+70*cos(theta)**25 + 8.5341593935078e+69*cos(theta)**23 - 8.54429096382063e+68*cos(theta)**21 + 6.84847749008524e+67*cos(theta)**19 - 4.32295921301062e+66*cos(theta)**17 + 2.10423211513759e+65*cos(theta)**15 - 7.68502163789382e+63*cos(theta)**13 + 2.03059514822398e+62*cos(theta)**11 - 3.69199117858905e+60*cos(theta)**9 + 4.29578805524259e+58*cos(theta)**7 - 2.85569956188966e+56*cos(theta)**5 + 8.86863217978156e+53*cos(theta)**3 - 8.11897971905544e+50*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl85_m27(theta, phi):
    return 5.69199606972627e-52*(1.0 - cos(theta)**2)**13.5*(2.83307373680998e+74*cos(theta)**58 - 2.77104786209875e+75*cos(theta)**56 + 1.27766877474014e+76*cos(theta)**54 - 3.69362427606696e+76*cos(theta)**52 + 7.51188004611164e+76*cos(theta)**50 - 1.14311218093003e+77*cos(theta)**48 + 1.35160433971601e+77*cos(theta)**46 - 1.27289398690271e+77*cos(theta)**44 + 9.71094928717709e+76*cos(theta)**42 - 6.07198789851814e+76*cos(theta)**40 + 3.13652355022791e+76*cos(theta)**38 - 1.3453179108055e+76*cos(theta)**36 + 4.80470682430537e+75*cos(theta)**34 - 1.42994192489937e+75*cos(theta)**32 + 3.54271326048995e+74*cos(theta)**30 - 7.28643152866727e+73*cos(theta)**28 + 1.23843125801989e+73*cos(theta)**26 - 1.72816727718533e+72*cos(theta)**24 + 1.96285666050679e+71*cos(theta)**22 - 1.79430110240233e+70*cos(theta)**20 + 1.3012107231162e+69*cos(theta)**18 - 7.34903066211805e+67*cos(theta)**16 + 3.15634817270639e+66*cos(theta)**14 - 9.99052812926197e+64*cos(theta)**12 + 2.23365466304638e+63*cos(theta)**10 - 3.32279206073014e+61*cos(theta)**8 + 3.00705163866981e+59*cos(theta)**6 - 1.42784978094483e+57*cos(theta)**4 + 2.66058965393447e+54*cos(theta)**2 - 8.11897971905544e+50)*cos(27*phi)

#@torch.jit.script
def Yl85_m28(theta, phi):
    return 7.03090731711277e-54*(1.0 - cos(theta)**2)**14*(1.64318276734979e+76*cos(theta)**57 - 1.5517868027753e+77*cos(theta)**55 + 6.89941138359677e+77*cos(theta)**53 - 1.92068462355482e+78*cos(theta)**51 + 3.75594002305582e+78*cos(theta)**49 - 5.48693846846415e+78*cos(theta)**47 + 6.21737996269366e+78*cos(theta)**45 - 5.6007335423719e+78*cos(theta)**43 + 4.07859870061438e+78*cos(theta)**41 - 2.42879515940725e+78*cos(theta)**39 + 1.19187894908661e+78*cos(theta)**37 - 4.84314447889982e+77*cos(theta)**35 + 1.63360032026383e+77*cos(theta)**33 - 4.57581415967799e+76*cos(theta)**31 + 1.06281397814698e+76*cos(theta)**29 - 2.04020082802684e+75*cos(theta)**27 + 3.21992127085171e+74*cos(theta)**25 - 4.14760146524479e+73*cos(theta)**23 + 4.31828465311495e+72*cos(theta)**21 - 3.58860220480467e+71*cos(theta)**19 + 2.34217930160915e+70*cos(theta)**17 - 1.17584490593889e+69*cos(theta)**15 + 4.41888744178895e+67*cos(theta)**13 - 1.19886337551144e+66*cos(theta)**11 + 2.23365466304638e+64*cos(theta)**9 - 2.65823364858412e+62*cos(theta)**7 + 1.80423098320189e+60*cos(theta)**5 - 5.71139912377932e+57*cos(theta)**3 + 5.32117930786894e+54*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl85_m29(theta, phi):
    return 8.72210919618343e-56*(1.0 - cos(theta)**2)**14.5*(9.36614177389378e+77*cos(theta)**56 - 8.53482741526415e+78*cos(theta)**54 + 3.65668803330629e+79*cos(theta)**52 - 9.79549158012957e+79*cos(theta)**50 + 1.84041061129735e+80*cos(theta)**48 - 2.57886108017815e+80*cos(theta)**46 + 2.79782098321215e+80*cos(theta)**44 - 2.40831542321992e+80*cos(theta)**42 + 1.67222546725189e+80*cos(theta)**40 - 9.47230112168829e+79*cos(theta)**38 + 4.40995211162044e+79*cos(theta)**36 - 1.69510056761494e+79*cos(theta)**34 + 5.39088105687063e+78*cos(theta)**32 - 1.41850238950018e+78*cos(theta)**30 + 3.08216053662626e+77*cos(theta)**28 - 5.50854223567246e+76*cos(theta)**26 + 8.04980317712927e+75*cos(theta)**24 - 9.53948337006302e+74*cos(theta)**22 + 9.06839777154139e+73*cos(theta)**20 - 6.81834418912886e+72*cos(theta)**18 + 3.98170481273556e+71*cos(theta)**16 - 1.76376735890833e+70*cos(theta)**14 + 5.74455367432563e+68*cos(theta)**12 - 1.31874971306258e+67*cos(theta)**10 + 2.01028919674174e+65*cos(theta)**8 - 1.86076355400888e+63*cos(theta)**6 + 9.02115491600944e+60*cos(theta)**4 - 1.7134197371338e+58*cos(theta)**2 + 5.32117930786894e+54)*cos(29*phi)

#@torch.jit.script
def Yl85_m30(theta, phi):
    return 1.08687246354893e-57*(1.0 - cos(theta)**2)**15*(5.24503939338052e+79*cos(theta)**55 - 4.60880680424264e+80*cos(theta)**53 + 1.90147777731927e+81*cos(theta)**51 - 4.89774579006479e+81*cos(theta)**49 + 8.83397093422728e+81*cos(theta)**47 - 1.18627609688195e+82*cos(theta)**45 + 1.23104123261334e+82*cos(theta)**43 - 1.01149247775237e+82*cos(theta)**41 + 6.68890186900758e+81*cos(theta)**39 - 3.59947442624155e+81*cos(theta)**37 + 1.58758276018336e+81*cos(theta)**35 - 5.76334192989078e+80*cos(theta)**33 + 1.7250819381986e+80*cos(theta)**31 - 4.25550716850053e+79*cos(theta)**29 + 8.63004950255352e+78*cos(theta)**27 - 1.43222098127484e+78*cos(theta)**25 + 1.93195276251102e+77*cos(theta)**23 - 2.09868634141386e+76*cos(theta)**21 + 1.81367955430828e+75*cos(theta)**19 - 1.2273019540432e+74*cos(theta)**17 + 6.37072770037689e+72*cos(theta)**15 - 2.46927430247166e+71*cos(theta)**13 + 6.89346440919076e+69*cos(theta)**11 - 1.31874971306258e+68*cos(theta)**9 + 1.60823135739339e+66*cos(theta)**7 - 1.11645813240533e+64*cos(theta)**5 + 3.60846196640378e+61*cos(theta)**3 - 3.42683947426759e+58*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl85_m31(theta, phi):
    return 1.36071836551589e-59*(1.0 - cos(theta)**2)**15.5*(2.88477166635928e+81*cos(theta)**54 - 2.4426676062486e+82*cos(theta)**52 + 9.69753666432828e+82*cos(theta)**50 - 2.39989543713175e+83*cos(theta)**48 + 4.15196633908682e+83*cos(theta)**46 - 5.33824243596877e+83*cos(theta)**44 + 5.29347730023738e+83*cos(theta)**42 - 4.1471191587847e+83*cos(theta)**40 + 2.60867172891296e+83*cos(theta)**38 - 1.33180553770937e+83*cos(theta)**36 + 5.55653966064176e+82*cos(theta)**34 - 1.90190283686396e+82*cos(theta)**32 + 5.34775400841566e+81*cos(theta)**30 - 1.23409707886515e+81*cos(theta)**28 + 2.33011336568945e+80*cos(theta)**26 - 3.5805524531871e+79*cos(theta)**24 + 4.44349135377536e+78*cos(theta)**22 - 4.40724131696912e+77*cos(theta)**20 + 3.44599115318573e+76*cos(theta)**18 - 2.08641332187343e+75*cos(theta)**16 + 9.55609155056534e+73*cos(theta)**14 - 3.21005659321316e+72*cos(theta)**12 + 7.58281085010983e+70*cos(theta)**10 - 1.18687474175632e+69*cos(theta)**8 + 1.12576195017537e+67*cos(theta)**6 - 5.58229066202664e+64*cos(theta)**4 + 1.08253858992113e+62*cos(theta)**2 - 3.42683947426759e+58)*cos(31*phi)

#@torch.jit.script
def Yl85_m32(theta, phi):
    return 1.71190017245824e-61*(1.0 - cos(theta)**2)**16*(1.55777669983401e+83*cos(theta)**53 - 1.27018715524927e+84*cos(theta)**51 + 4.84876833216414e+84*cos(theta)**49 - 1.15194980982324e+85*cos(theta)**47 + 1.90990451597994e+85*cos(theta)**45 - 2.34882667182626e+85*cos(theta)**43 + 2.2232604660997e+85*cos(theta)**41 - 1.65884766351388e+85*cos(theta)**39 + 9.91295256986923e+84*cos(theta)**37 - 4.79449993575375e+84*cos(theta)**35 + 1.8892234846182e+84*cos(theta)**33 - 6.08608907796466e+83*cos(theta)**31 + 1.6043262025247e+83*cos(theta)**29 - 3.45547182082243e+82*cos(theta)**27 + 6.05829475079257e+81*cos(theta)**25 - 8.59332588764903e+80*cos(theta)**23 + 9.77568097830578e+79*cos(theta)**21 - 8.81448263393823e+78*cos(theta)**19 + 6.20278407573431e+77*cos(theta)**17 - 3.33826131499749e+76*cos(theta)**15 + 1.33785281707915e+75*cos(theta)**13 - 3.8520679118558e+73*cos(theta)**11 + 7.58281085010983e+71*cos(theta)**9 - 9.49499793405058e+69*cos(theta)**7 + 6.75457170105224e+67*cos(theta)**5 - 2.23291626481066e+65*cos(theta)**3 + 2.16507717984227e+62*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl85_m33(theta, phi):
    return 2.16470887267962e-63*(1.0 - cos(theta)**2)**16.5*(8.25621650912027e+84*cos(theta)**52 - 6.47795449177129e+85*cos(theta)**50 + 2.37589648276043e+86*cos(theta)**48 - 5.41416410616922e+86*cos(theta)**46 + 8.59457032190973e+86*cos(theta)**44 - 1.00999546888529e+87*cos(theta)**42 + 9.11536791100877e+86*cos(theta)**40 - 6.46950588770413e+86*cos(theta)**38 + 3.66779245085162e+86*cos(theta)**36 - 1.67807497751381e+86*cos(theta)**34 + 6.23443749924005e+85*cos(theta)**32 - 1.88668761416905e+85*cos(theta)**30 + 4.65254598732163e+84*cos(theta)**28 - 9.32977391622056e+83*cos(theta)**26 + 1.51457368769814e+83*cos(theta)**24 - 1.97646495415928e+82*cos(theta)**22 + 2.05289300544421e+81*cos(theta)**20 - 1.67475170044826e+80*cos(theta)**18 + 1.05447329287483e+79*cos(theta)**16 - 5.00739197249624e+77*cos(theta)**14 + 1.73920866220289e+76*cos(theta)**12 - 4.23727470304138e+74*cos(theta)**10 + 6.82452976509885e+72*cos(theta)**8 - 6.6464985538354e+70*cos(theta)**6 + 3.37728585052612e+68*cos(theta)**4 - 6.69874879443197e+65*cos(theta)**2 + 2.16507717984227e+62)*cos(33*phi)

#@torch.jit.script
def Yl85_m34(theta, phi):
    return 2.75184738543716e-65*(1.0 - cos(theta)**2)**17*(4.29323258474254e+86*cos(theta)**51 - 3.23897724588565e+87*cos(theta)**49 + 1.14043031172501e+88*cos(theta)**47 - 2.49051548883784e+88*cos(theta)**45 + 3.78161094164028e+88*cos(theta)**43 - 4.24198096931823e+88*cos(theta)**41 + 3.64614716440351e+88*cos(theta)**39 - 2.45841223732757e+88*cos(theta)**37 + 1.32040528230658e+88*cos(theta)**35 - 5.70545492354696e+87*cos(theta)**33 + 1.99501999975682e+87*cos(theta)**31 - 5.66006284250714e+86*cos(theta)**29 + 1.30271287645006e+86*cos(theta)**27 - 2.42574121821734e+85*cos(theta)**25 + 3.63497685047554e+84*cos(theta)**23 - 4.34822289915041e+83*cos(theta)**21 + 4.10578601088843e+82*cos(theta)**19 - 3.01455306080688e+81*cos(theta)**17 + 1.68715726859973e+80*cos(theta)**15 - 7.01034876149473e+78*cos(theta)**13 + 2.08705039464347e+77*cos(theta)**11 - 4.23727470304138e+75*cos(theta)**9 + 5.45962381207908e+73*cos(theta)**7 - 3.98789913230124e+71*cos(theta)**5 + 1.35091434021045e+69*cos(theta)**3 - 1.33974975888639e+66*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl85_m35(theta, phi):
    return 3.51761766546913e-67*(1.0 - cos(theta)**2)**17.5*(2.1895486182187e+88*cos(theta)**50 - 1.58709885048397e+89*cos(theta)**48 + 5.36002246510753e+89*cos(theta)**46 - 1.12073196997703e+90*cos(theta)**44 + 1.62609270490532e+90*cos(theta)**42 - 1.73921219742047e+90*cos(theta)**40 + 1.42199739411737e+90*cos(theta)**38 - 9.09612527811201e+89*cos(theta)**36 + 4.62141848807304e+89*cos(theta)**34 - 1.8828001247705e+89*cos(theta)**32 + 6.18456199924613e+88*cos(theta)**30 - 1.64141822432707e+88*cos(theta)**28 + 3.51732476641515e+87*cos(theta)**26 - 6.06435304554336e+86*cos(theta)**24 + 8.36044675609375e+85*cos(theta)**22 - 9.13126808821586e+84*cos(theta)**20 + 7.80099342068801e+83*cos(theta)**18 - 5.12474020337169e+82*cos(theta)**16 + 2.5307359028996e+81*cos(theta)**14 - 9.11345338994315e+79*cos(theta)**12 + 2.29575543410782e+78*cos(theta)**10 - 3.81354723273724e+76*cos(theta)**8 + 3.82173666845536e+74*cos(theta)**6 - 1.99394956615062e+72*cos(theta)**4 + 4.05274302063134e+69*cos(theta)**2 - 1.33974975888639e+66)*cos(35*phi)

#@torch.jit.script
def Yl85_m36(theta, phi):
    return 4.52242055431784e-69*(1.0 - cos(theta)**2)**18*(1.09477430910935e+90*cos(theta)**49 - 7.61807448232304e+90*cos(theta)**47 + 2.46561033394946e+91*cos(theta)**45 - 4.93122066789892e+91*cos(theta)**43 + 6.82958936060234e+91*cos(theta)**41 - 6.95684878968189e+91*cos(theta)**39 + 5.403590097646e+91*cos(theta)**37 - 3.27460510012032e+91*cos(theta)**35 + 1.57128228594483e+91*cos(theta)**33 - 6.02496039926559e+90*cos(theta)**31 + 1.85536859977384e+90*cos(theta)**29 - 4.5959710281158e+89*cos(theta)**27 + 9.14504439267939e+88*cos(theta)**25 - 1.45544473093041e+88*cos(theta)**23 + 1.83929828634062e+87*cos(theta)**21 - 1.82625361764317e+86*cos(theta)**19 + 1.40417881572384e+85*cos(theta)**17 - 8.1995843253947e+83*cos(theta)**15 + 3.54303026405944e+82*cos(theta)**13 - 1.09361440679318e+81*cos(theta)**11 + 2.29575543410782e+79*cos(theta)**9 - 3.05083778618979e+77*cos(theta)**7 + 2.29304200107321e+75*cos(theta)**5 - 7.97579826460248e+72*cos(theta)**3 + 8.10548604126269e+69*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl85_m37(theta, phi):
    return 5.8491531257598e-71*(1.0 - cos(theta)**2)**18.5*(5.36439411463581e+91*cos(theta)**48 - 3.58049500669183e+92*cos(theta)**46 + 1.10952465027726e+93*cos(theta)**44 - 2.12042488719654e+93*cos(theta)**42 + 2.80013163784696e+93*cos(theta)**40 - 2.71317102797594e+93*cos(theta)**38 + 1.99932833612902e+93*cos(theta)**36 - 1.14611178504211e+93*cos(theta)**34 + 5.18523154361795e+92*cos(theta)**32 - 1.86773772377233e+92*cos(theta)**30 + 5.38056893934414e+91*cos(theta)**28 - 1.24091217759126e+91*cos(theta)**26 + 2.28626109816985e+90*cos(theta)**24 - 3.34752288113994e+89*cos(theta)**22 + 3.86252640131531e+88*cos(theta)**20 - 3.46988187352203e+87*cos(theta)**18 + 2.38710398673053e+86*cos(theta)**16 - 1.22993764880921e+85*cos(theta)**14 + 4.60593934327727e+83*cos(theta)**12 - 1.2029758474725e+82*cos(theta)**10 + 2.06617989069704e+80*cos(theta)**8 - 2.13558645033285e+78*cos(theta)**6 + 1.14652100053661e+76*cos(theta)**4 - 2.39273947938075e+73*cos(theta)**2 + 8.10548604126269e+69)*cos(37*phi)

#@torch.jit.script
def Yl85_m38(theta, phi):
    return 7.61236872927005e-73*(1.0 - cos(theta)**2)**19*(2.57490917502519e+93*cos(theta)**47 - 1.64702770307824e+94*cos(theta)**45 + 4.88190846121993e+94*cos(theta)**43 - 8.90578452622546e+94*cos(theta)**41 + 1.12005265513878e+95*cos(theta)**39 - 1.03100499063086e+95*cos(theta)**37 + 7.19758201006447e+94*cos(theta)**35 - 3.89678006914318e+94*cos(theta)**33 + 1.65927409395774e+94*cos(theta)**31 - 5.603213171317e+93*cos(theta)**29 + 1.50655930301636e+93*cos(theta)**27 - 3.22637166173729e+92*cos(theta)**25 + 5.48702663560763e+91*cos(theta)**23 - 7.36455033850786e+90*cos(theta)**21 + 7.72505280263062e+89*cos(theta)**19 - 6.24578737233965e+88*cos(theta)**17 + 3.81936637876885e+87*cos(theta)**15 - 1.72191270833289e+86*cos(theta)**13 + 5.52712721193272e+84*cos(theta)**11 - 1.2029758474725e+83*cos(theta)**9 + 1.65294391255763e+81*cos(theta)**7 - 1.28135187019971e+79*cos(theta)**5 + 4.58608400214643e+76*cos(theta)**3 - 4.78547895876149e+73*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl85_m39(theta, phi):
    return 9.97148970048567e-75*(1.0 - cos(theta)**2)**19.5*(1.21020731226184e+95*cos(theta)**46 - 7.41162466385208e+95*cos(theta)**44 + 2.09922063832457e+96*cos(theta)**42 - 3.65137165575244e+96*cos(theta)**40 + 4.36820535504126e+96*cos(theta)**38 - 3.81471846533417e+96*cos(theta)**36 + 2.51915370352256e+96*cos(theta)**34 - 1.28593742281725e+96*cos(theta)**32 + 5.143749691269e+95*cos(theta)**30 - 1.62493181968193e+95*cos(theta)**28 + 4.06771011814417e+94*cos(theta)**26 - 8.06592915434322e+93*cos(theta)**24 + 1.26201612618976e+93*cos(theta)**22 - 1.54655557108665e+92*cos(theta)**20 + 1.46776003249982e+91*cos(theta)**18 - 1.06178385329774e+90*cos(theta)**16 + 5.72904956815328e+88*cos(theta)**14 - 2.23848652083275e+87*cos(theta)**12 + 6.079839933126e+85*cos(theta)**10 - 1.08267826272525e+84*cos(theta)**8 + 1.15706073879034e+82*cos(theta)**6 - 6.40675935099856e+79*cos(theta)**4 + 1.37582520064393e+77*cos(theta)**2 - 4.78547895876149e+73)*cos(39*phi)

#@torch.jit.script
def Yl85_m40(theta, phi):
    return 1.31500111983349e-76*(1.0 - cos(theta)**2)**20*(5.56695363640445e+96*cos(theta)**45 - 3.26111485209492e+97*cos(theta)**43 + 8.8167266809632e+97*cos(theta)**41 - 1.46054866230097e+98*cos(theta)**39 + 1.65991803491568e+98*cos(theta)**37 - 1.3732986475203e+98*cos(theta)**35 + 8.56512259197672e+97*cos(theta)**33 - 4.1149997530152e+97*cos(theta)**31 + 1.5431249073807e+97*cos(theta)**29 - 4.5498090951094e+96*cos(theta)**27 + 1.05760463071748e+96*cos(theta)**25 - 1.93582299704237e+95*cos(theta)**23 + 2.77643547761746e+94*cos(theta)**21 - 3.0931111421733e+93*cos(theta)**19 + 2.64196805849967e+92*cos(theta)**17 - 1.69885416527639e+91*cos(theta)**15 + 8.02066939541459e+89*cos(theta)**13 - 2.6861838249993e+88*cos(theta)**11 + 6.079839933126e+86*cos(theta)**9 - 8.66142610180197e+84*cos(theta)**7 + 6.94236443274204e+82*cos(theta)**5 - 2.56270374039942e+80*cos(theta)**3 + 2.75165040128786e+77*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl85_m41(theta, phi):
    return 1.74636328859084e-78*(1.0 - cos(theta)**2)**20.5*(2.505129136382e+98*cos(theta)**44 - 1.40227938640081e+99*cos(theta)**42 + 3.61485793919491e+99*cos(theta)**40 - 5.6961397829738e+99*cos(theta)**38 + 6.14169672918801e+99*cos(theta)**36 - 4.80654526632105e+99*cos(theta)**34 + 2.82649045535232e+99*cos(theta)**32 - 1.27564992343471e+99*cos(theta)**30 + 4.47506223140403e+98*cos(theta)**28 - 1.22844845567954e+98*cos(theta)**26 + 2.64401157679371e+97*cos(theta)**24 - 4.45239289319746e+96*cos(theta)**22 + 5.83051450299667e+95*cos(theta)**20 - 5.87691117012927e+94*cos(theta)**18 + 4.49134569944944e+93*cos(theta)**16 - 2.54828124791458e+92*cos(theta)**14 + 1.0426870214039e+91*cos(theta)**12 - 2.95480220749923e+89*cos(theta)**10 + 5.4718559398134e+87*cos(theta)**8 - 6.06299827126138e+85*cos(theta)**6 + 3.47118221637102e+83*cos(theta)**4 - 7.68811122119827e+80*cos(theta)**2 + 2.75165040128786e+77)*cos(41*phi)

#@torch.jit.script
def Yl85_m42(theta, phi):
    return 2.3361804995891e-80*(1.0 - cos(theta)**2)**21*(1.10225682000808e+100*cos(theta)**43 - 5.88957342288342e+100*cos(theta)**41 + 1.44594317567797e+101*cos(theta)**39 - 2.16453311753004e+101*cos(theta)**37 + 2.21101082250768e+101*cos(theta)**35 - 1.63422539054916e+101*cos(theta)**33 + 9.04476945712741e+100*cos(theta)**31 - 3.82694977030414e+100*cos(theta)**29 + 1.25301742479313e+100*cos(theta)**27 - 3.1939659847668e+99*cos(theta)**25 + 6.3456277843049e+98*cos(theta)**23 - 9.79526436503441e+97*cos(theta)**21 + 1.16610290059933e+97*cos(theta)**19 - 1.05784401062327e+96*cos(theta)**17 + 7.18615311911911e+94*cos(theta)**15 - 3.56759374708041e+93*cos(theta)**13 + 1.25122442568468e+92*cos(theta)**11 - 2.95480220749923e+90*cos(theta)**9 + 4.37748475185072e+88*cos(theta)**7 - 3.63779896275683e+86*cos(theta)**5 + 1.38847288654841e+84*cos(theta)**3 - 1.53762224423965e+81*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl85_m43(theta, phi):
    return 3.14896027468108e-82*(1.0 - cos(theta)**2)**21.5*(4.73970432603475e+101*cos(theta)**42 - 2.4147251033822e+102*cos(theta)**40 + 5.63917838514406e+102*cos(theta)**38 - 8.00877253486117e+102*cos(theta)**36 + 7.73853787877689e+102*cos(theta)**34 - 5.39294378881222e+102*cos(theta)**32 + 2.8038785317095e+102*cos(theta)**30 - 1.1098154333882e+102*cos(theta)**28 + 3.38314704694145e+101*cos(theta)**26 - 7.984914961917e+100*cos(theta)**24 + 1.45949439039013e+100*cos(theta)**22 - 2.05700551665723e+99*cos(theta)**20 + 2.21559551113874e+98*cos(theta)**18 - 1.79833481805956e+97*cos(theta)**16 + 1.07792296786787e+96*cos(theta)**14 - 4.63787187120453e+94*cos(theta)**12 + 1.37634686825314e+93*cos(theta)**10 - 2.65932198674931e+91*cos(theta)**8 + 3.0642393262955e+89*cos(theta)**6 - 1.81889948137841e+87*cos(theta)**4 + 4.16541865964522e+84*cos(theta)**2 - 1.53762224423965e+81)*cos(43*phi)

#@torch.jit.script
def Yl85_m44(theta, phi):
    return 4.27806798150012e-84*(1.0 - cos(theta)**2)**22*(1.9906758169346e+103*cos(theta)**41 - 9.65890041352881e+103*cos(theta)**39 + 2.14288778635474e+104*cos(theta)**37 - 2.88315811255002e+104*cos(theta)**35 + 2.63110287878414e+104*cos(theta)**33 - 1.72574201241991e+104*cos(theta)**31 + 8.41163559512849e+103*cos(theta)**29 - 3.10748321348696e+103*cos(theta)**27 + 8.79618232204776e+102*cos(theta)**25 - 1.91637959086008e+102*cos(theta)**23 + 3.21088765885828e+101*cos(theta)**21 - 4.11401103331445e+100*cos(theta)**19 + 3.98807192004972e+99*cos(theta)**17 - 2.87733570889529e+98*cos(theta)**15 + 1.50909215501501e+97*cos(theta)**13 - 5.56544624544544e+95*cos(theta)**11 + 1.37634686825314e+94*cos(theta)**9 - 2.12745758939945e+92*cos(theta)**7 + 1.8385435957773e+90*cos(theta)**5 - 7.27559792551366e+87*cos(theta)**3 + 8.33083731929045e+84*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl85_m45(theta, phi):
    return 5.8598173191461e-86*(1.0 - cos(theta)**2)**22.5*(8.16177084943184e+104*cos(theta)**40 - 3.76697116127623e+105*cos(theta)**38 + 7.92868480951255e+105*cos(theta)**36 - 1.00910533939251e+106*cos(theta)**34 + 8.68263949998767e+105*cos(theta)**32 - 5.34980023850172e+105*cos(theta)**30 + 2.43937432258726e+105*cos(theta)**28 - 8.39020467641479e+104*cos(theta)**26 + 2.19904558051194e+104*cos(theta)**24 - 4.40767305897818e+103*cos(theta)**22 + 6.74286408360239e+102*cos(theta)**20 - 7.81662096329746e+101*cos(theta)**18 + 6.77972226408453e+100*cos(theta)**16 - 4.31600356334294e+99*cos(theta)**14 + 1.96181980151952e+98*cos(theta)**12 - 6.12199086998998e+96*cos(theta)**10 + 1.23871218142783e+95*cos(theta)**8 - 1.48922031257961e+93*cos(theta)**6 + 9.19271797888651e+90*cos(theta)**4 - 2.1826793776541e+88*cos(theta)**2 + 8.33083731929045e+84)*cos(45*phi)

#@torch.jit.script
def Yl85_m46(theta, phi):
    return 8.09502945854216e-88*(1.0 - cos(theta)**2)**23*(3.26470833977274e+106*cos(theta)**39 - 1.43144904128497e+107*cos(theta)**37 + 2.85432653142452e+107*cos(theta)**35 - 3.43095815393452e+107*cos(theta)**33 + 2.77844463999606e+107*cos(theta)**31 - 1.60494007155052e+107*cos(theta)**29 + 6.83024810324434e+106*cos(theta)**27 - 2.18145321586785e+106*cos(theta)**25 + 5.27770939322866e+105*cos(theta)**23 - 9.696880729752e+104*cos(theta)**21 + 1.34857281672048e+104*cos(theta)**19 - 1.40699177339354e+103*cos(theta)**17 + 1.08475556225352e+102*cos(theta)**15 - 6.04240498868011e+100*cos(theta)**13 + 2.35418376182342e+99*cos(theta)**11 - 6.12199086998998e+97*cos(theta)**9 + 9.90969745142263e+95*cos(theta)**7 - 8.93532187547768e+93*cos(theta)**5 + 3.6770871915546e+91*cos(theta)**3 - 4.36535875530819e+88*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl85_m47(theta, phi):
    return 1.12823395091298e-89*(1.0 - cos(theta)**2)**23.5*(1.27323625251137e+108*cos(theta)**38 - 5.29636145275439e+108*cos(theta)**36 + 9.99014285998582e+108*cos(theta)**34 - 1.13221619079839e+109*cos(theta)**32 + 8.61317838398777e+108*cos(theta)**30 - 4.6543262074965e+108*cos(theta)**28 + 1.84416698787597e+108*cos(theta)**26 - 5.45363303966961e+107*cos(theta)**24 + 1.21387316044259e+107*cos(theta)**22 - 2.03634495324792e+106*cos(theta)**20 + 2.56228835176891e+105*cos(theta)**18 - 2.39188601476902e+104*cos(theta)**16 + 1.62713334338029e+103*cos(theta)**14 - 7.85512648528415e+101*cos(theta)**12 + 2.58960213800576e+100*cos(theta)**10 - 5.50979178299098e+98*cos(theta)**8 + 6.93678821599584e+96*cos(theta)**6 - 4.46766093773884e+94*cos(theta)**4 + 1.10312615746638e+92*cos(theta)**2 - 4.36535875530819e+88)*cos(47*phi)

#@torch.jit.script
def Yl85_m48(theta, phi):
    return 1.58701687836192e-91*(1.0 - cos(theta)**2)**24*(4.8382977595432e+109*cos(theta)**37 - 1.90669012299158e+110*cos(theta)**35 + 3.39664857239518e+110*cos(theta)**33 - 3.62309181055486e+110*cos(theta)**31 + 2.58395351519633e+110*cos(theta)**29 - 1.30321133809902e+110*cos(theta)**27 + 4.79483416847752e+109*cos(theta)**25 - 1.30887192952071e+109*cos(theta)**23 + 2.6705209529737e+108*cos(theta)**21 - 4.07268990649584e+107*cos(theta)**19 + 4.61211903318403e+106*cos(theta)**17 - 3.82701762363044e+105*cos(theta)**15 + 2.2779866807324e+104*cos(theta)**13 - 9.42615178234097e+102*cos(theta)**11 + 2.58960213800576e+101*cos(theta)**9 - 4.40783342639279e+99*cos(theta)**7 + 4.16207292959751e+97*cos(theta)**5 - 1.78706437509554e+95*cos(theta)**3 + 2.20625231493276e+92*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl85_m49(theta, phi):
    return 2.25386699752414e-93*(1.0 - cos(theta)**2)**24.5*(1.79017017103098e+111*cos(theta)**36 - 6.67341543047053e+111*cos(theta)**34 + 1.12089402889041e+112*cos(theta)**32 - 1.12315846127201e+112*cos(theta)**30 + 7.49346519406936e+111*cos(theta)**28 - 3.51867061286735e+111*cos(theta)**26 + 1.19870854211938e+111*cos(theta)**24 - 3.01040543789763e+110*cos(theta)**22 + 5.60809400124477e+109*cos(theta)**20 - 7.7381108223421e+108*cos(theta)**18 + 7.84060235641285e+107*cos(theta)**16 - 5.74052643544565e+106*cos(theta)**14 + 2.96138268495212e+105*cos(theta)**12 - 1.03687669605751e+104*cos(theta)**10 + 2.33064192420519e+102*cos(theta)**8 - 3.08548339847495e+100*cos(theta)**6 + 2.08103646479875e+98*cos(theta)**4 - 5.36119312528661e+95*cos(theta)**2 + 2.20625231493276e+92)*cos(49*phi)

#@torch.jit.script
def Yl85_m50(theta, phi):
    return 3.23303309110278e-95*(1.0 - cos(theta)**2)**25*(6.44461261571154e+112*cos(theta)**35 - 2.26896124635998e+113*cos(theta)**33 + 3.58686089244931e+113*cos(theta)**31 - 3.36947538381602e+113*cos(theta)**29 + 2.09817025433942e+113*cos(theta)**27 - 9.14854359345512e+112*cos(theta)**25 + 2.87690050108651e+112*cos(theta)**23 - 6.62289196337478e+111*cos(theta)**21 + 1.12161880024895e+111*cos(theta)**19 - 1.39285994802158e+110*cos(theta)**17 + 1.25449637702606e+109*cos(theta)**15 - 8.03673700962391e+107*cos(theta)**13 + 3.55365922194255e+106*cos(theta)**11 - 1.03687669605751e+105*cos(theta)**9 + 1.86451353936415e+103*cos(theta)**7 - 1.85129003908497e+101*cos(theta)**5 + 8.32414585919501e+98*cos(theta)**3 - 1.07223862505732e+96*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl85_m51(theta, phi):
    return 4.68604735881824e-97*(1.0 - cos(theta)**2)**25.5*(2.25561441549904e+114*cos(theta)**34 - 7.48757211298793e+114*cos(theta)**32 + 1.11192687665929e+115*cos(theta)**30 - 9.77147861306645e+114*cos(theta)**28 + 5.66505968671644e+114*cos(theta)**26 - 2.28713589836378e+114*cos(theta)**24 + 6.61687115249898e+113*cos(theta)**22 - 1.3908073123087e+113*cos(theta)**20 + 2.13107572047301e+112*cos(theta)**18 - 2.36786191163668e+111*cos(theta)**16 + 1.88174456553909e+110*cos(theta)**14 - 1.04477581125111e+109*cos(theta)**12 + 3.9090251441368e+107*cos(theta)**10 - 9.33189026451756e+105*cos(theta)**8 + 1.3051594775549e+104*cos(theta)**6 - 9.25645019542485e+101*cos(theta)**4 + 2.4972437577585e+99*cos(theta)**2 - 1.07223862505732e+96)*cos(51*phi)

#@torch.jit.script
def Yl85_m52(theta, phi):
    return 6.86604951923717e-99*(1.0 - cos(theta)**2)**26*(7.66908901269673e+115*cos(theta)**33 - 2.39602307615614e+116*cos(theta)**31 + 3.33578062997786e+116*cos(theta)**29 - 2.73601401165861e+116*cos(theta)**27 + 1.47291551854627e+116*cos(theta)**25 - 5.48912615607307e+115*cos(theta)**23 + 1.45571165354978e+115*cos(theta)**21 - 2.78161462461741e+114*cos(theta)**19 + 3.83593629685143e+113*cos(theta)**17 - 3.78857905861869e+112*cos(theta)**15 + 2.63444239175472e+111*cos(theta)**13 - 1.25373097350133e+110*cos(theta)**11 + 3.9090251441368e+108*cos(theta)**9 - 7.46551221161405e+106*cos(theta)**7 + 7.83095686532942e+104*cos(theta)**5 - 3.70258007816994e+102*cos(theta)**3 + 4.99448751551701e+99*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl85_m53(theta, phi):
    return 1.01744377307574e-100*(1.0 - cos(theta)**2)**26.5*(2.53079937418992e+117*cos(theta)**32 - 7.42767153608403e+117*cos(theta)**30 + 9.67376382693578e+117*cos(theta)**28 - 7.38723783147824e+117*cos(theta)**26 + 3.68228879636568e+117*cos(theta)**24 - 1.26249901589681e+117*cos(theta)**22 + 3.05699447245453e+116*cos(theta)**20 - 5.28506778677307e+115*cos(theta)**18 + 6.52109170464742e+114*cos(theta)**16 - 5.68286858792804e+113*cos(theta)**14 + 3.42477510928113e+112*cos(theta)**12 - 1.37910407085146e+111*cos(theta)**10 + 3.51812262972312e+109*cos(theta)**8 - 5.22585854812984e+107*cos(theta)**6 + 3.91547843266471e+105*cos(theta)**4 - 1.11077402345098e+103*cos(theta)**2 + 4.99448751551701e+99)*cos(53*phi)

#@torch.jit.script
def Yl85_m54(theta, phi):
    return 1.52555555938551e-102*(1.0 - cos(theta)**2)**27*(8.09855799740775e+118*cos(theta)**31 - 2.22830146082521e+119*cos(theta)**29 + 2.70865387154202e+119*cos(theta)**27 - 1.92068183618434e+119*cos(theta)**25 + 8.83749311127764e+118*cos(theta)**23 - 2.77749783497297e+118*cos(theta)**21 + 6.11398894490906e+117*cos(theta)**19 - 9.51312201619153e+116*cos(theta)**17 + 1.04337467274359e+116*cos(theta)**15 - 7.95601602309925e+114*cos(theta)**13 + 4.10973013113736e+113*cos(theta)**11 - 1.37910407085146e+112*cos(theta)**9 + 2.8144981037785e+110*cos(theta)**7 - 3.1355151288779e+108*cos(theta)**5 + 1.56619137306588e+106*cos(theta)**3 - 2.22154804690196e+103*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl85_m55(theta, phi):
    return 2.31570463083329e-104*(1.0 - cos(theta)**2)**27.5*(2.5105529791964e+120*cos(theta)**30 - 6.4620742363931e+120*cos(theta)**28 + 7.31336545316345e+120*cos(theta)**26 - 4.80170459046085e+120*cos(theta)**24 + 2.03262341559386e+120*cos(theta)**22 - 5.83274545344324e+119*cos(theta)**20 + 1.16165789953272e+119*cos(theta)**18 - 1.61723074275256e+118*cos(theta)**16 + 1.56506200911538e+117*cos(theta)**14 - 1.0342820830029e+116*cos(theta)**12 + 4.5207031442511e+114*cos(theta)**10 - 1.24119366376632e+113*cos(theta)**8 + 1.97014867264495e+111*cos(theta)**6 - 1.56775756443895e+109*cos(theta)**4 + 4.69857411919765e+106*cos(theta)**2 - 2.22154804690196e+103)*cos(55*phi)

#@torch.jit.script
def Yl85_m56(theta, phi):
    return 3.56051631753453e-106*(1.0 - cos(theta)**2)**28*(7.5316589375892e+121*cos(theta)**29 - 1.80938078619007e+122*cos(theta)**27 + 1.9014750178225e+122*cos(theta)**25 - 1.1524091017106e+122*cos(theta)**23 + 4.47177151430649e+121*cos(theta)**21 - 1.16654909068865e+121*cos(theta)**19 + 2.0909842191589e+120*cos(theta)**17 - 2.5875691884041e+119*cos(theta)**15 + 2.19108681276153e+118*cos(theta)**13 - 1.24113849960348e+117*cos(theta)**11 + 4.5207031442511e+115*cos(theta)**9 - 9.92954931013054e+113*cos(theta)**7 + 1.18208920358697e+112*cos(theta)**5 - 6.2710302577558e+109*cos(theta)**3 + 9.39714823839531e+106*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl85_m57(theta, phi):
    return 5.54842614218162e-108*(1.0 - cos(theta)**2)**28.5*(2.18418109190087e+123*cos(theta)**28 - 4.88532812271319e+123*cos(theta)**26 + 4.75368754455624e+123*cos(theta)**24 - 2.65054093393439e+123*cos(theta)**22 + 9.39072018004362e+122*cos(theta)**20 - 2.21644327230843e+122*cos(theta)**18 + 3.55467317257013e+121*cos(theta)**16 - 3.88135378260615e+120*cos(theta)**14 + 2.84841285658999e+119*cos(theta)**12 - 1.36525234956383e+118*cos(theta)**10 + 4.06863282982599e+116*cos(theta)**8 - 6.95068451709138e+114*cos(theta)**6 + 5.91044601793484e+112*cos(theta)**4 - 1.88130907732674e+110*cos(theta)**2 + 9.39714823839531e+106)*cos(57*phi)

#@torch.jit.script
def Yl85_m58(theta, phi):
    return 8.76844889032084e-110*(1.0 - cos(theta)**2)**29*(6.11570705732243e+124*cos(theta)**27 - 1.27018531190543e+125*cos(theta)**25 + 1.1408850106935e+125*cos(theta)**23 - 5.83119005465566e+124*cos(theta)**21 + 1.87814403600872e+124*cos(theta)**19 - 3.98959789015518e+123*cos(theta)**17 + 5.68747707611221e+122*cos(theta)**15 - 5.4338952956486e+121*cos(theta)**13 + 3.41809542790799e+120*cos(theta)**11 - 1.36525234956383e+119*cos(theta)**9 + 3.25490626386079e+117*cos(theta)**7 - 4.17041071025483e+115*cos(theta)**5 + 2.36417840717394e+113*cos(theta)**3 - 3.76261815465348e+110*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl85_m59(theta, phi):
    return 1.40624064644506e-111*(1.0 - cos(theta)**2)**29.5*(1.65124090547706e+126*cos(theta)**26 - 3.17546327976357e+126*cos(theta)**24 + 2.62403552459505e+126*cos(theta)**22 - 1.22454991147769e+126*cos(theta)**20 + 3.56847366841658e+125*cos(theta)**18 - 6.78231641326381e+124*cos(theta)**16 + 8.53121561416831e+123*cos(theta)**14 - 7.06406388434318e+122*cos(theta)**12 + 3.75990497069879e+121*cos(theta)**10 - 1.22872711460745e+120*cos(theta)**8 + 2.27843438470255e+118*cos(theta)**6 - 2.08520535512741e+116*cos(theta)**4 + 7.09253522152181e+113*cos(theta)**2 - 3.76261815465348e+110)*cos(59*phi)

#@torch.jit.script
def Yl85_m60(theta, phi):
    return 2.29028206231709e-113*(1.0 - cos(theta)**2)**30*(4.29322635424035e+127*cos(theta)**25 - 7.62111187143257e+127*cos(theta)**23 + 5.7728781541091e+127*cos(theta)**21 - 2.44909982295538e+127*cos(theta)**19 + 6.42325260314984e+126*cos(theta)**17 - 1.08517062612221e+126*cos(theta)**15 + 1.19437018598356e+125*cos(theta)**13 - 8.47687666121182e+123*cos(theta)**11 + 3.75990497069879e+122*cos(theta)**9 - 9.82981691685959e+120*cos(theta)**7 + 1.36706063082153e+119*cos(theta)**5 - 8.34082142050965e+116*cos(theta)**3 + 1.41850704430436e+114*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl85_m61(theta, phi):
    return 3.79090184266799e-115*(1.0 - cos(theta)**2)**30.5*(1.07330658856009e+129*cos(theta)**24 - 1.75285573042949e+129*cos(theta)**22 + 1.21230441236291e+129*cos(theta)**20 - 4.65328966361522e+128*cos(theta)**18 + 1.09195294253547e+128*cos(theta)**16 - 1.62775593918331e+127*cos(theta)**14 + 1.55268124177863e+126*cos(theta)**12 - 9.32456432733301e+124*cos(theta)**10 + 3.38391447362891e+123*cos(theta)**8 - 6.88087184180171e+121*cos(theta)**6 + 6.83530315410766e+119*cos(theta)**4 - 2.5022464261529e+117*cos(theta)**2 + 1.41850704430436e+114)*cos(61*phi)

#@torch.jit.script
def Yl85_m62(theta, phi):
    return 6.38231523753122e-117*(1.0 - cos(theta)**2)**31*(2.57593581254421e+130*cos(theta)**23 - 3.85628260694488e+130*cos(theta)**21 + 2.42460882472582e+130*cos(theta)**19 - 8.37592139450739e+129*cos(theta)**17 + 1.74712470805676e+129*cos(theta)**15 - 2.27885831485664e+128*cos(theta)**13 + 1.86321749013436e+127*cos(theta)**11 - 9.324564327333e+125*cos(theta)**9 + 2.70713157890313e+124*cos(theta)**7 - 4.12852310508103e+122*cos(theta)**5 + 2.73412126164306e+120*cos(theta)**3 - 5.00449285230579e+117*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl85_m63(theta, phi):
    return 1.09391474305682e-118*(1.0 - cos(theta)**2)**31.5*(5.92465236885168e+131*cos(theta)**22 - 8.09819347458425e+131*cos(theta)**20 + 4.60675676697906e+131*cos(theta)**18 - 1.42390663706626e+131*cos(theta)**16 + 2.62068706208513e+130*cos(theta)**14 - 2.96251580931363e+129*cos(theta)**12 + 2.04953923914779e+128*cos(theta)**10 - 8.3921078945997e+126*cos(theta)**8 + 1.89499210523219e+125*cos(theta)**6 - 2.06426155254051e+123*cos(theta)**4 + 8.20236378492919e+120*cos(theta)**2 - 5.00449285230579e+117)*cos(63*phi)

#@torch.jit.script
def Yl85_m64(theta, phi):
    return 1.91064059505093e-120*(1.0 - cos(theta)**2)**32*(1.30342352114737e+133*cos(theta)**21 - 1.61963869491685e+133*cos(theta)**19 + 8.29216218056232e+132*cos(theta)**17 - 2.27825061930601e+132*cos(theta)**15 + 3.66896188691919e+131*cos(theta)**13 - 3.55501897117636e+130*cos(theta)**11 + 2.04953923914779e+129*cos(theta)**9 - 6.71368631567976e+127*cos(theta)**7 + 1.13699526313931e+126*cos(theta)**5 - 8.25704621016205e+123*cos(theta)**3 + 1.64047275698584e+121*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl85_m65(theta, phi):
    return 3.4042678552107e-122*(1.0 - cos(theta)**2)**32.5*(2.73718939440948e+134*cos(theta)**20 - 3.07731352034202e+134*cos(theta)**18 + 1.40966757069559e+134*cos(theta)**16 - 3.41737592895901e+133*cos(theta)**14 + 4.76965045299494e+132*cos(theta)**12 - 3.91052086829399e+131*cos(theta)**10 + 1.84458531523301e+130*cos(theta)**8 - 4.69958042097583e+128*cos(theta)**6 + 5.68497631569657e+126*cos(theta)**4 - 2.47711386304862e+124*cos(theta)**2 + 1.64047275698584e+121)*cos(65*phi)

#@torch.jit.script
def Yl85_m66(theta, phi):
    return 6.19469962231141e-124*(1.0 - cos(theta)**2)**33*(5.47437878881895e+135*cos(theta)**19 - 5.53916433661563e+135*cos(theta)**17 + 2.25546811311295e+135*cos(theta)**15 - 4.78432630054262e+134*cos(theta)**13 + 5.72358054359393e+133*cos(theta)**11 - 3.91052086829399e+132*cos(theta)**9 + 1.47566825218641e+131*cos(theta)**7 - 2.8197482525855e+129*cos(theta)**5 + 2.27399052627863e+127*cos(theta)**3 - 4.95422772609723e+124*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl85_m67(theta, phi):
    return 1.15271423956583e-125*(1.0 - cos(theta)**2)**33.5*(1.0401319698756e+137*cos(theta)**18 - 9.41657937224657e+136*cos(theta)**16 + 3.38320216966942e+136*cos(theta)**14 - 6.21962419070541e+135*cos(theta)**12 + 6.29593859795333e+134*cos(theta)**10 - 3.51946878146459e+133*cos(theta)**8 + 1.03296777653049e+132*cos(theta)**6 - 1.40987412629275e+130*cos(theta)**4 + 6.82197157883589e+127*cos(theta)**2 - 4.95422772609723e+124)*cos(67*phi)

#@torch.jit.script
def Yl85_m68(theta, phi):
    return 2.19654290176847e-127*(1.0 - cos(theta)**2)**34*(1.87223754577608e+138*cos(theta)**17 - 1.50665269955945e+138*cos(theta)**15 + 4.7364830375372e+137*cos(theta)**13 - 7.46354902884649e+136*cos(theta)**11 + 6.29593859795333e+135*cos(theta)**9 - 2.81557502517167e+134*cos(theta)**7 + 6.19780665918293e+132*cos(theta)**5 - 5.639496505171e+130*cos(theta)**3 + 1.36439431576718e+128*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl85_m69(theta, phi):
    return 4.2929404978482e-129*(1.0 - cos(theta)**2)**34.5*(3.18280382781934e+139*cos(theta)**16 - 2.25997904933918e+139*cos(theta)**14 + 6.15742794879835e+138*cos(theta)**12 - 8.20990393173114e+137*cos(theta)**10 + 5.66634473815799e+136*cos(theta)**8 - 1.97090251762017e+135*cos(theta)**6 + 3.09890332959146e+133*cos(theta)**4 - 1.6918489515513e+131*cos(theta)**2 + 1.36439431576718e+128)*cos(69*phi)

#@torch.jit.script
def Yl85_m70(theta, phi):
    return 8.62043196424997e-131*(1.0 - cos(theta)**2)**35*(5.09248612451094e+140*cos(theta)**15 - 3.16397066907485e+140*cos(theta)**13 + 7.38891353855802e+139*cos(theta)**11 - 8.20990393173114e+138*cos(theta)**9 + 4.5330757905264e+137*cos(theta)**7 - 1.1825415105721e+136*cos(theta)**5 + 1.23956133183659e+134*cos(theta)**3 - 3.3836979031026e+131*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl85_m71(theta, phi):
    return 1.78205498455012e-132*(1.0 - cos(theta)**2)**35.5*(7.63872918676641e+141*cos(theta)**14 - 4.1131618697973e+141*cos(theta)**12 + 8.12780489241383e+140*cos(theta)**10 - 7.38891353855802e+139*cos(theta)**8 + 3.17315305336848e+138*cos(theta)**6 - 5.91270755286052e+136*cos(theta)**4 + 3.71868399550976e+134*cos(theta)**2 - 3.3836979031026e+131)*cos(71*phi)

#@torch.jit.script
def Yl85_m72(theta, phi):
    return 3.8010821503779e-134*(1.0 - cos(theta)**2)**36*(1.0694220861473e+143*cos(theta)**13 - 4.93579424375676e+142*cos(theta)**11 + 8.12780489241383e+141*cos(theta)**9 - 5.91113083084642e+140*cos(theta)**7 + 1.90389183202109e+139*cos(theta)**5 - 2.36508302114421e+137*cos(theta)**3 + 7.43736799101952e+134*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl85_m73(theta, phi):
    return 8.38700759315741e-136*(1.0 - cos(theta)**2)**36.5*(1.39024871199149e+144*cos(theta)**12 - 5.42937366813244e+143*cos(theta)**10 + 7.31502440317244e+142*cos(theta)**8 - 4.13779158159249e+141*cos(theta)**6 + 9.51945916010543e+139*cos(theta)**4 - 7.09524906343262e+137*cos(theta)**2 + 7.43736799101952e+134)*cos(73*phi)

#@torch.jit.script
def Yl85_m74(theta, phi):
    return 1.9200734880634e-137*(1.0 - cos(theta)**2)**37*(1.66829845438979e+145*cos(theta)**11 - 5.42937366813244e+144*cos(theta)**9 + 5.85201952253796e+143*cos(theta)**7 - 2.4826749489555e+142*cos(theta)**5 + 3.80778366404217e+140*cos(theta)**3 - 1.41904981268652e+138*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl85_m75(theta, phi):
    return 4.57679559867686e-139*(1.0 - cos(theta)**2)**37.5*(1.83512829982876e+146*cos(theta)**10 - 4.88643630131919e+145*cos(theta)**8 + 4.09641366577657e+144*cos(theta)**6 - 1.24133747447775e+143*cos(theta)**4 + 1.14233509921265e+141*cos(theta)**2 - 1.41904981268652e+138)*cos(75*phi)

#@torch.jit.script
def Yl85_m76(theta, phi):
    return 1.1406399520131e-140*(1.0 - cos(theta)**2)**38*(1.83512829982876e+147*cos(theta)**9 - 3.90914904105535e+146*cos(theta)**7 + 2.45784819946594e+145*cos(theta)**5 - 4.96534989791099e+143*cos(theta)**3 + 2.2846701984253e+141*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl85_m77(theta, phi):
    return 2.9872379442991e-142*(1.0 - cos(theta)**2)**38.5*(1.65161546984589e+148*cos(theta)**8 - 2.73640432873875e+147*cos(theta)**6 + 1.22892409973297e+146*cos(theta)**4 - 1.4896049693733e+144*cos(theta)**2 + 2.2846701984253e+141)*cos(77*phi)

#@torch.jit.script
def Yl85_m78(theta, phi):
    return 8.27239038970388e-144*(1.0 - cos(theta)**2)**39*(1.32129237587671e+149*cos(theta)**7 - 1.64184259724325e+148*cos(theta)**5 + 4.91569639893188e+146*cos(theta)**3 - 2.9792099387466e+144*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl85_m79(theta, phi):
    return 2.44151882599156e-145*(1.0 - cos(theta)**2)**39.5*(9.24904663113697e+149*cos(theta)**6 - 8.20921298621624e+148*cos(theta)**4 + 1.47470891967956e+147*cos(theta)**2 - 2.9792099387466e+144)*cos(79*phi)

#@torch.jit.script
def Yl85_m80(theta, phi):
    return 7.75965620507256e-147*(1.0 - cos(theta)**2)**40*(5.54942797868218e+150*cos(theta)**5 - 3.2836851944865e+149*cos(theta)**3 + 2.94941783935913e+147*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl85_m81(theta, phi):
    return 2.69341598890101e-148*(1.0 - cos(theta)**2)**40.5*(2.77471398934109e+151*cos(theta)**4 - 9.85105558345949e+149*cos(theta)**2 + 2.94941783935913e+147)*cos(81*phi)

#@torch.jit.script
def Yl85_m82(theta, phi):
    return 1.04211393354525e-149*(1.0 - cos(theta)**2)**41*(1.10988559573644e+152*cos(theta)**3 - 1.9702111166919e+150*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl85_m83(theta, phi):
    return 4.6419444015591e-151*(1.0 - cos(theta)**2)**41.5*(3.32965678720931e+152*cos(theta)**2 - 1.9702111166919e+150)*cos(83*phi)

#@torch.jit.script
def Yl85_m84(theta, phi):
    return 16.8140002588748*(1.0 - cos(theta)**2)**42*cos(84*phi)*cos(theta)

#@torch.jit.script
def Yl85_m85(theta, phi):
    return 1.28957495210276*(1.0 - cos(theta)**2)**42.5*cos(85*phi)

#@torch.jit.script
def Yl86_m_minus_86(theta, phi):
    return 1.29331828349511*(1.0 - cos(theta)**2)**43*sin(86*phi)

#@torch.jit.script
def Yl86_m_minus_85(theta, phi):
    return 16.96171027275*(1.0 - cos(theta)**2)**42.5*sin(85*phi)*cos(theta)

#@torch.jit.script
def Yl86_m_minus_84(theta, phi):
    return 2.75459095946835e-153*(1.0 - cos(theta)**2)**42*(5.69371310612792e+154*cos(theta)**2 - 3.32965678720931e+152)*sin(84*phi)

#@torch.jit.script
def Yl86_m_minus_83(theta, phi):
    return 6.22074223106233e-152*(1.0 - cos(theta)**2)**41.5*(1.89790436870931e+154*cos(theta)**3 - 3.32965678720931e+152*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl86_m_minus_82(theta, phi):
    return 1.61739298007621e-150*(1.0 - cos(theta)**2)**41*(4.74476092177326e+153*cos(theta)**4 - 1.66482839360465e+152*cos(theta)**2 + 4.92552779172975e+149)*sin(82*phi)

#@torch.jit.script
def Yl86_m_minus_81(theta, phi):
    return 4.68765020418527e-149*(1.0 - cos(theta)**2)**40.5*(9.48952184354653e+152*cos(theta)**5 - 5.54942797868218e+151*cos(theta)**3 + 4.92552779172975e+149*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl86_m_minus_80(theta, phi):
    return 1.4838467766475e-147*(1.0 - cos(theta)**2)**40*(1.58158697392442e+152*cos(theta)**6 - 1.38735699467055e+151*cos(theta)**4 + 2.46276389586487e+149*cos(theta)**2 - 4.91569639893188e+146)*sin(80*phi)

#@torch.jit.script
def Yl86_m_minus_79(theta, phi):
    return 5.0581548613413e-146*(1.0 - cos(theta)**2)**39.5*(2.25940996274917e+151*cos(theta)**7 - 2.77471398934109e+150*cos(theta)**5 + 8.20921298621624e+148*cos(theta)**3 - 4.91569639893188e+146*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl86_m_minus_78(theta, phi):
    return 1.83771892284239e-144*(1.0 - cos(theta)**2)**39*(2.82426245343647e+150*cos(theta)**8 - 4.62452331556848e+149*cos(theta)**6 + 2.05230324655406e+148*cos(theta)**4 - 2.45784819946594e+146*cos(theta)**2 + 3.72401242343324e+143)*sin(78*phi)

#@torch.jit.script
def Yl86_m_minus_77(theta, phi):
    return 7.06028554586467e-143*(1.0 - cos(theta)**2)**38.5*(3.13806939270719e+149*cos(theta)**9 - 6.60646187938355e+148*cos(theta)**7 + 4.10460649310812e+147*cos(theta)**5 - 8.19282733155314e+145*cos(theta)**3 + 3.72401242343324e+143*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl86_m_minus_76(theta, phi):
    return 2.85046733260192e-141*(1.0 - cos(theta)**2)**38*(3.13806939270719e+148*cos(theta)**10 - 8.25807734922944e+147*cos(theta)**8 + 6.84101082184687e+146*cos(theta)**6 - 2.04820683288828e+145*cos(theta)**4 + 1.86200621171662e+143*cos(theta)**2 - 2.2846701984253e+140)*sin(76*phi)

#@torch.jit.script
def Yl86_m_minus_75(theta, phi):
    return 1.20328892097281e-139*(1.0 - cos(theta)**2)**37.5*(2.85279035700653e+147*cos(theta)**11 - 9.17564149914382e+146*cos(theta)**9 + 9.77287260263839e+145*cos(theta)**7 - 4.09641366577657e+144*cos(theta)**5 + 6.20668737238874e+142*cos(theta)**3 - 2.2846701984253e+140*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl86_m_minus_74(theta, phi):
    return 5.2889989291103e-138*(1.0 - cos(theta)**2)**37*(2.37732529750544e+146*cos(theta)**12 - 9.17564149914382e+145*cos(theta)**10 + 1.2216090753298e+145*cos(theta)**8 - 6.82735610962761e+143*cos(theta)**6 + 1.55167184309719e+142*cos(theta)**4 - 1.14233509921265e+140*cos(theta)**2 + 1.1825415105721e+137)*sin(74*phi)

#@torch.jit.script
def Yl86_m_minus_73(theta, phi):
    return 2.41215464093889e-136*(1.0 - cos(theta)**2)**36.5*(1.82871176731188e+145*cos(theta)**13 - 8.34149227194893e+144*cos(theta)**11 + 1.35734341703311e+144*cos(theta)**9 - 9.75336587089659e+142*cos(theta)**7 + 3.10334368619437e+141*cos(theta)**5 - 3.80778366404217e+139*cos(theta)**3 + 1.1825415105721e+137*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl86_m_minus_72(theta, phi):
    return 1.13806672766906e-134*(1.0 - cos(theta)**2)**36*(1.30622269093706e+144*cos(theta)**14 - 6.95124355995744e+143*cos(theta)**12 + 1.35734341703311e+143*cos(theta)**10 - 1.21917073386207e+142*cos(theta)**8 + 5.17223947699062e+140*cos(theta)**6 - 9.51945916010543e+138*cos(theta)**4 + 5.91270755286052e+136*cos(theta)**2 - 5.31240570787108e+133)*sin(72*phi)

#@torch.jit.script
def Yl86_m_minus_71(theta, phi):
    return 5.54040993754688e-133*(1.0 - cos(theta)**2)**35.5*(8.70815127291371e+142*cos(theta)**15 - 5.34711043073649e+142*cos(theta)**13 + 1.23394856093919e+142*cos(theta)**11 - 1.35463414873564e+141*cos(theta)**9 + 7.38891353855802e+139*cos(theta)**7 - 1.90389183202109e+138*cos(theta)**5 + 1.97090251762017e+136*cos(theta)**3 - 5.31240570787108e+133*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl86_m_minus_70(theta, phi):
    return 2.77684550159859e-131*(1.0 - cos(theta)**2)**35*(5.44259454557107e+141*cos(theta)**16 - 3.81936459338321e+141*cos(theta)**14 + 1.02829046744933e+141*cos(theta)**12 - 1.35463414873564e+140*cos(theta)**10 + 9.23614192319753e+138*cos(theta)**8 - 3.17315305336848e+137*cos(theta)**6 + 4.92725629405043e+135*cos(theta)**4 - 2.65620285393554e+133*cos(theta)**2 + 2.11481118943913e+130)*sin(70*phi)

#@torch.jit.script
def Yl86_m_minus_69(theta, phi):
    return 1.43000803257229e-129*(1.0 - cos(theta)**2)**34.5*(3.2015262032771e+140*cos(theta)**17 - 2.54624306225547e+140*cos(theta)**15 + 7.90992667268712e+139*cos(theta)**13 - 1.23148558975967e+139*cos(theta)**11 + 1.02623799146639e+138*cos(theta)**9 - 4.5330757905264e+136*cos(theta)**7 + 9.85451258810086e+134*cos(theta)**5 - 8.85400951311847e+132*cos(theta)**3 + 2.11481118943913e+130*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl86_m_minus_68(theta, phi):
    return 7.55336686206047e-128*(1.0 - cos(theta)**2)**34*(1.77862566848728e+139*cos(theta)**18 - 1.59140191390967e+139*cos(theta)**16 + 5.64994762334794e+138*cos(theta)**14 - 1.02623799146639e+138*cos(theta)**12 + 1.02623799146639e+137*cos(theta)**10 - 5.66634473815799e+135*cos(theta)**8 + 1.64241876468348e+134*cos(theta)**6 - 2.21350237827962e+132*cos(theta)**4 + 1.05740559471956e+130*cos(theta)**2 - 7.57996842092876e+126)*sin(68*phi)

#@torch.jit.script
def Yl86_m_minus_67(theta, phi):
    return 4.08580597787152e-126*(1.0 - cos(theta)**2)**33.5*(9.36118772888041e+137*cos(theta)**19 - 9.36118772888041e+137*cos(theta)**17 + 3.76663174889863e+137*cos(theta)**15 - 7.89413839589533e+136*cos(theta)**13 + 9.32943628605811e+135*cos(theta)**11 - 6.29593859795333e+134*cos(theta)**9 + 2.34631252097639e+133*cos(theta)**7 - 4.42700475655924e+131*cos(theta)**5 + 3.52468531573188e+129*cos(theta)**3 - 7.57996842092876e+126*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl86_m_minus_66(theta, phi):
    return 2.26015619141157e-124*(1.0 - cos(theta)**2)**33*(4.68059386444021e+136*cos(theta)**20 - 5.20065984937801e+136*cos(theta)**18 + 2.35414484306164e+136*cos(theta)**16 - 5.63867028278238e+135*cos(theta)**14 + 7.77453023838176e+134*cos(theta)**12 - 6.29593859795333e+133*cos(theta)**10 + 2.93289065122049e+132*cos(theta)**8 - 7.37834126093206e+130*cos(theta)**6 + 8.81171328932969e+128*cos(theta)**4 - 3.78998421046438e+126*cos(theta)**2 + 2.47711386304862e+123)*sin(66*phi)

#@torch.jit.script
def Yl86_m_minus_65(theta, phi):
    return 1.27693824371294e-122*(1.0 - cos(theta)**2)**32.5*(2.228854221162e+135*cos(theta)**21 - 2.73718939440948e+135*cos(theta)**19 + 1.38479108415391e+135*cos(theta)**17 - 3.75911352185492e+134*cos(theta)**15 + 5.98040787567828e+133*cos(theta)**13 - 5.72358054359393e+132*cos(theta)**11 + 3.25876739024499e+131*cos(theta)**9 - 1.05404875156172e+130*cos(theta)**7 + 1.76234265786594e+128*cos(theta)**5 - 1.26332807015479e+126*cos(theta)**3 + 2.47711386304862e+123*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl86_m_minus_64(theta, phi):
    return 7.35986262532712e-121*(1.0 - cos(theta)**2)**32*(1.01311555507364e+134*cos(theta)**22 - 1.36859469720474e+134*cos(theta)**20 + 7.69328380085504e+133*cos(theta)**18 - 2.34944595115932e+133*cos(theta)**16 + 4.27171991119877e+132*cos(theta)**14 - 4.76965045299494e+131*cos(theta)**12 + 3.25876739024499e+130*cos(theta)**10 - 1.31756093945215e+129*cos(theta)**8 + 2.9372377631099e+127*cos(theta)**6 - 3.15832017538699e+125*cos(theta)**4 + 1.23855693152431e+123*cos(theta)**2 - 7.45669434993563e+119)*sin(64*phi)

#@torch.jit.script
def Yl86_m_minus_63(theta, phi):
    return 4.32294047645489e-119*(1.0 - cos(theta)**2)**31.5*(4.4048502394506e+132*cos(theta)**23 - 6.51711760573685e+132*cos(theta)**21 + 4.04909673729212e+132*cos(theta)**19 - 1.38202703009372e+132*cos(theta)**17 + 2.84781327413251e+131*cos(theta)**15 - 3.66896188691919e+130*cos(theta)**13 + 2.96251580931363e+129*cos(theta)**11 - 1.46395659939128e+128*cos(theta)**9 + 4.19605394729985e+126*cos(theta)**7 - 6.31664035077397e+124*cos(theta)**5 + 4.12852310508103e+122*cos(theta)**3 - 7.45669434993563e+119*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl86_m_minus_62(theta, phi):
    return 2.58510394688469e-117*(1.0 - cos(theta)**2)**31*(1.83535426643775e+131*cos(theta)**24 - 2.96232618442584e+131*cos(theta)**22 + 2.02454836864606e+131*cos(theta)**20 - 7.67792794496511e+130*cos(theta)**18 + 1.77988329633282e+130*cos(theta)**16 - 2.62068706208513e+129*cos(theta)**14 + 2.46876317442802e+128*cos(theta)**12 - 1.46395659939128e+127*cos(theta)**10 + 5.24506743412481e+125*cos(theta)**8 - 1.05277339179566e+124*cos(theta)**6 + 1.03213077627026e+122*cos(theta)**4 - 3.72834717496781e+119*cos(theta)**2 + 2.08520535512741e+116)*sin(62*phi)

#@torch.jit.script
def Yl86_m_minus_61(theta, phi):
    return 1.57245734250362e-115*(1.0 - cos(theta)**2)**30.5*(7.341417065751e+129*cos(theta)**25 - 1.2879679062721e+130*cos(theta)**23 + 9.6407065173622e+129*cos(theta)**21 - 4.04101470787637e+129*cos(theta)**19 + 1.04699017431342e+129*cos(theta)**17 - 1.74712470805676e+128*cos(theta)**15 + 1.89904859571387e+127*cos(theta)**13 - 1.33086963581026e+126*cos(theta)**11 + 5.82785270458313e+124*cos(theta)**9 - 1.50396198827952e+123*cos(theta)**7 + 2.06426155254051e+121*cos(theta)**5 - 1.24278239165594e+119*cos(theta)**3 + 2.08520535512741e+116*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl86_m_minus_60(theta, phi):
    return 9.72129705504536e-114*(1.0 - cos(theta)**2)**30*(2.82362194836577e+128*cos(theta)**26 - 5.36653294280044e+128*cos(theta)**24 + 4.38213932607373e+128*cos(theta)**22 - 2.02050735393819e+128*cos(theta)**20 + 5.81661207951902e+127*cos(theta)**18 - 1.09195294253547e+127*cos(theta)**16 + 1.35646328265276e+126*cos(theta)**14 - 1.10905802984188e+125*cos(theta)**12 + 5.82785270458313e+123*cos(theta)**10 - 1.8799524853494e+122*cos(theta)**8 + 3.44043592090086e+120*cos(theta)**6 - 3.10695597913985e+118*cos(theta)**4 + 1.04260267756371e+116*cos(theta)**2 - 5.45579632424755e+112)*sin(60*phi)

#@torch.jit.script
def Yl86_m_minus_59(theta, phi):
    return 6.10355024536255e-112*(1.0 - cos(theta)**2)**29.5*(1.04578590680214e+127*cos(theta)**27 - 2.14661317712017e+127*cos(theta)**25 + 1.90527796785814e+127*cos(theta)**23 - 9.62146359018184e+126*cos(theta)**21 + 3.06137477869422e+126*cos(theta)**19 - 6.42325260314984e+125*cos(theta)**17 + 9.04308855101841e+124*cos(theta)**15 - 8.53121561416831e+123*cos(theta)**13 + 5.29804791325739e+122*cos(theta)**11 - 2.08883609483266e+121*cos(theta)**9 + 4.91490845842979e+119*cos(theta)**7 - 6.21391195827969e+117*cos(theta)**5 + 3.47534225854569e+115*cos(theta)**3 - 5.45579632424755e+112*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl86_m_minus_58(theta, phi):
    return 3.88906803651622e-110*(1.0 - cos(theta)**2)**29*(3.73494966715049e+125*cos(theta)**28 - 8.25620452738529e+125*cos(theta)**26 + 7.93865819940893e+125*cos(theta)**24 - 4.37339254099175e+125*cos(theta)**22 + 1.53068738934711e+125*cos(theta)**20 - 3.56847366841658e+124*cos(theta)**18 + 5.6519303443865e+123*cos(theta)**16 - 6.09372543869165e+122*cos(theta)**14 + 4.41503992771449e+121*cos(theta)**12 - 2.08883609483266e+120*cos(theta)**10 + 6.14363557303724e+118*cos(theta)**8 - 1.03565199304662e+117*cos(theta)**6 + 8.68835564636422e+114*cos(theta)**4 - 2.72789816212377e+112*cos(theta)**2 + 1.34379219809053e+109)*sin(58*phi)

#@torch.jit.script
def Yl86_m_minus_57(theta, phi):
    return 2.51319267873586e-108*(1.0 - cos(theta)**2)**28.5*(1.28791367832775e+124*cos(theta)**29 - 3.05785352866122e+124*cos(theta)**27 + 3.17546327976357e+124*cos(theta)**25 - 1.9014750178225e+124*cos(theta)**23 + 7.28898756831957e+123*cos(theta)**21 - 1.87814403600872e+123*cos(theta)**19 + 3.32466490846265e+122*cos(theta)**17 - 4.06248362579443e+121*cos(theta)**15 + 3.39618455978038e+120*cos(theta)**13 - 1.89894190439333e+119*cos(theta)**11 + 6.82626174781916e+117*cos(theta)**9 - 1.47950284720945e+116*cos(theta)**7 + 1.73767112927284e+114*cos(theta)**5 - 9.09299387374591e+111*cos(theta)**3 + 1.34379219809053e+109*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl86_m_minus_56(theta, phi):
    return 1.64609324218092e-106*(1.0 - cos(theta)**2)**28*(4.29304559442585e+122*cos(theta)**30 - 1.09209054595043e+123*cos(theta)**28 + 1.2213320306783e+123*cos(theta)**26 - 7.92281257426041e+122*cos(theta)**24 + 3.31317616741799e+122*cos(theta)**22 - 9.39072018004362e+121*cos(theta)**20 + 1.84703606025703e+121*cos(theta)**18 - 2.53905226612152e+120*cos(theta)**16 + 2.42584611412884e+119*cos(theta)**14 - 1.58245158699444e+118*cos(theta)**12 + 6.82626174781916e+116*cos(theta)**10 - 1.84937855901181e+115*cos(theta)**8 + 2.89611854878807e+113*cos(theta)**6 - 2.27324846843648e+111*cos(theta)**4 + 6.71896099045265e+108*cos(theta)**2 - 3.13238274613177e+105)*sin(56*phi)

#@torch.jit.script
def Yl86_m_minus_55(theta, phi):
    return 1.09214286055077e-104*(1.0 - cos(theta)**2)**27.5*(1.38485341755672e+121*cos(theta)**31 - 3.7658294687946e+121*cos(theta)**29 + 4.52345196547517e+121*cos(theta)**27 - 3.16912502970416e+121*cos(theta)**25 + 1.44051137713826e+121*cos(theta)**23 - 4.47177151430649e+120*cos(theta)**21 + 9.72124242240541e+119*cos(theta)**19 - 1.49356015654207e+119*cos(theta)**17 + 1.61723074275256e+118*cos(theta)**15 - 1.21727045153419e+117*cos(theta)**13 + 6.20569249801742e+115*cos(theta)**11 - 2.05486506556868e+114*cos(theta)**9 + 4.13731221255439e+112*cos(theta)**7 - 4.54649693687296e+110*cos(theta)**5 + 2.23965366348422e+108*cos(theta)**3 - 3.13238274613177e+105*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl86_m_minus_54(theta, phi):
    return 7.33607895109391e-103*(1.0 - cos(theta)**2)**27*(4.32766692986476e+119*cos(theta)**32 - 1.2552764895982e+120*cos(theta)**30 + 1.61551855909828e+120*cos(theta)**28 - 1.21889424219391e+120*cos(theta)**26 + 6.00213073807607e+119*cos(theta)**24 - 2.03262341559386e+119*cos(theta)**22 + 4.8606212112027e+118*cos(theta)**20 - 8.29755642523373e+117*cos(theta)**18 + 1.01076921422035e+117*cos(theta)**16 - 8.6947889395299e+115*cos(theta)**14 + 5.17141041501451e+114*cos(theta)**12 - 2.05486506556868e+113*cos(theta)**10 + 5.17164026569299e+111*cos(theta)**8 - 7.57749489478826e+109*cos(theta)**6 + 5.59913415871054e+107*cos(theta)**4 - 1.56619137306588e+105*cos(theta)**2 + 6.94233764656864e+101)*sin(54*phi)

#@torch.jit.script
def Yl86_m_minus_53(theta, phi):
    return 4.98637554963799e-101*(1.0 - cos(theta)**2)**26.5*(1.31141422117114e+118*cos(theta)**33 - 4.04927899870387e+118*cos(theta)**31 + 5.57075365206302e+118*cos(theta)**29 - 4.5144231192367e+118*cos(theta)**27 + 2.40085229523043e+118*cos(theta)**25 - 8.83749311127764e+117*cos(theta)**23 + 2.31458152914414e+117*cos(theta)**21 - 4.36713496064933e+116*cos(theta)**19 + 5.94570126011971e+115*cos(theta)**17 - 5.7965259596866e+114*cos(theta)**15 + 3.97800801154963e+113*cos(theta)**13 - 1.86805915051698e+112*cos(theta)**11 + 5.7462669618811e+110*cos(theta)**9 - 1.08249927068404e+109*cos(theta)**7 + 1.11982683174211e+107*cos(theta)**5 - 5.22063791021962e+104*cos(theta)**3 + 6.94233764656864e+101*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl86_m_minus_52(theta, phi):
    return 3.42792919621603e-99*(1.0 - cos(theta)**2)**26*(3.85710065050336e+116*cos(theta)**34 - 1.26539968709496e+117*cos(theta)**32 + 1.85691788402101e+117*cos(theta)**30 - 1.61229397115596e+117*cos(theta)**28 + 9.23404728934779e+116*cos(theta)**26 - 3.68228879636568e+116*cos(theta)**24 + 1.05208251324734e+116*cos(theta)**22 - 2.18356748032466e+115*cos(theta)**20 + 3.30316736673317e+114*cos(theta)**18 - 3.62282872480412e+113*cos(theta)**16 + 2.84143429396402e+112*cos(theta)**14 - 1.55671595876415e+111*cos(theta)**12 + 5.7462669618811e+109*cos(theta)**10 - 1.35312408835505e+108*cos(theta)**8 + 1.86637805290351e+106*cos(theta)**6 - 1.3051594775549e+104*cos(theta)**4 + 3.47116882328432e+101*cos(theta)**2 - 1.46896691632853e+98)*sin(52*phi)

#@torch.jit.script
def Yl86_m_minus_51(theta, phi):
    return 2.38234913716956e-97*(1.0 - cos(theta)**2)**25.5*(1.10202875728667e+115*cos(theta)**35 - 3.83454450634836e+115*cos(theta)**33 + 5.99005769039035e+115*cos(theta)**31 - 5.55963438329643e+115*cos(theta)**29 + 3.42001751457326e+115*cos(theta)**27 - 1.47291551854627e+115*cos(theta)**25 + 4.57427179672756e+114*cos(theta)**23 - 1.03979403824984e+114*cos(theta)**21 + 1.73850914038588e+113*cos(theta)**19 - 2.13107572047301e+112*cos(theta)**17 + 1.89428952930935e+111*cos(theta)**15 - 1.19747381443396e+110*cos(theta)**13 + 5.22387905625554e+108*cos(theta)**11 - 1.50347120928339e+107*cos(theta)**9 + 2.66625436129073e+105*cos(theta)**7 - 2.61031895510981e+103*cos(theta)**5 + 1.15705627442811e+101*cos(theta)**3 - 1.46896691632853e+98*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl86_m_minus_50(theta, phi):
    return 1.67308090398789e-95*(1.0 - cos(theta)**2)**25*(3.06119099246298e+113*cos(theta)**36 - 1.12780720774952e+114*cos(theta)**34 + 1.87189302824698e+114*cos(theta)**32 - 1.85321146109881e+114*cos(theta)**30 + 1.22143482663331e+114*cos(theta)**28 - 5.66505968671644e+113*cos(theta)**26 + 1.90594658196982e+113*cos(theta)**24 - 4.72633653749927e+112*cos(theta)**22 + 8.6925457019294e+111*cos(theta)**20 - 1.18393095581834e+111*cos(theta)**18 + 1.18393095581834e+110*cos(theta)**16 - 8.55338438881402e+108*cos(theta)**14 + 4.35323254687962e+107*cos(theta)**12 - 1.50347120928339e+106*cos(theta)**10 + 3.33281795161342e+104*cos(theta)**8 - 4.35053159184968e+102*cos(theta)**6 + 2.89264068607027e+100*cos(theta)**4 - 7.34483458164266e+97*cos(theta)**2 + 2.97844062515923e+94)*sin(50*phi)

#@torch.jit.script
def Yl86_m_minus_49(theta, phi):
    return 1.18682656471811e-93*(1.0 - cos(theta)**2)**24.5*(8.27348916881887e+111*cos(theta)**37 - 3.22230630785577e+112*cos(theta)**35 + 5.67240311589995e+112*cos(theta)**33 - 5.97810148741551e+112*cos(theta)**31 + 4.21184422977002e+112*cos(theta)**29 - 2.09817025433942e+112*cos(theta)**27 + 7.62378632787926e+111*cos(theta)**25 - 2.05492892934751e+111*cos(theta)**23 + 4.13930747710924e+110*cos(theta)**21 - 6.23121555693864e+109*cos(theta)**19 + 6.96429974010789e+108*cos(theta)**17 - 5.70225625920935e+107*cos(theta)**15 + 3.34864042067663e+106*cos(theta)**13 - 1.36679200843944e+105*cos(theta)**11 + 3.70313105734824e+103*cos(theta)**9 - 6.21504513121383e+101*cos(theta)**7 + 5.78528137214053e+99*cos(theta)**5 - 2.44827819388089e+97*cos(theta)**3 + 2.97844062515923e+94*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl86_m_minus_48(theta, phi):
    return 8.50052876115164e-92*(1.0 - cos(theta)**2)**24*(2.17723399179444e+110*cos(theta)**38 - 8.95085085515491e+110*cos(theta)**36 + 1.66835385761763e+111*cos(theta)**34 - 1.86815671481735e+111*cos(theta)**32 + 1.40394807659001e+111*cos(theta)**30 - 7.49346519406936e+110*cos(theta)**28 + 2.93222551072279e+110*cos(theta)**26 - 8.5622038722813e+109*cos(theta)**24 + 1.88150339868602e+109*cos(theta)**22 - 3.11560777846932e+108*cos(theta)**20 + 3.86905541117105e+107*cos(theta)**18 - 3.56391016200584e+106*cos(theta)**16 + 2.39188601476902e+105*cos(theta)**14 - 1.1389933403662e+104*cos(theta)**12 + 3.70313105734824e+102*cos(theta)**10 - 7.76880641401729e+100*cos(theta)**8 + 9.64213562023422e+98*cos(theta)**6 - 6.12069548470221e+96*cos(theta)**4 + 1.48922031257961e+94*cos(theta)**2 - 5.8059271445599e+90)*sin(48*phi)

#@torch.jit.script
def Yl86_m_minus_47(theta, phi):
    return 6.14512390159355e-90*(1.0 - cos(theta)**2)**23.5*(5.58265126101138e+108*cos(theta)**39 - 2.4191488797716e+109*cos(theta)**37 + 4.76672530747895e+109*cos(theta)**35 - 5.66108095399196e+109*cos(theta)**33 + 4.52886476319357e+109*cos(theta)**31 - 2.58395351519633e+109*cos(theta)**29 + 1.08600944841585e+109*cos(theta)**27 - 3.42488154891252e+108*cos(theta)**25 + 8.18044955950442e+107*cos(theta)**23 - 1.48362275165206e+107*cos(theta)**21 + 2.03634495324792e+106*cos(theta)**19 - 2.09641774235638e+105*cos(theta)**17 + 1.59459067651268e+104*cos(theta)**15 - 8.76148723358616e+102*cos(theta)**13 + 3.36648277940749e+101*cos(theta)**11 - 8.63200712668587e+99*cos(theta)**9 + 1.37744794574775e+98*cos(theta)**7 - 1.22413909694044e+96*cos(theta)**5 + 4.96406770859871e+93*cos(theta)**3 - 5.8059271445599e+90*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl86_m_minus_46(theta, phi):
    return 4.48215075733493e-88*(1.0 - cos(theta)**2)**23*(1.39566281525285e+107*cos(theta)**40 - 6.36618126255684e+107*cos(theta)**38 + 1.3240903631886e+108*cos(theta)**36 - 1.66502380999764e+108*cos(theta)**34 + 1.41527023849799e+108*cos(theta)**32 - 8.61317838398777e+107*cos(theta)**30 + 3.87860517291375e+107*cos(theta)**28 - 1.31726213419712e+107*cos(theta)**26 + 3.40852064979351e+106*cos(theta)**24 - 6.74373978023662e+105*cos(theta)**22 + 1.01817247662396e+105*cos(theta)**20 - 1.16467652353132e+104*cos(theta)**18 + 9.96619172820426e+102*cos(theta)**16 - 6.25820516684726e+101*cos(theta)**14 + 2.80540231617291e+100*cos(theta)**12 - 8.63200712668587e+98*cos(theta)**10 + 1.72180993218468e+97*cos(theta)**8 - 2.04023182823407e+95*cos(theta)**6 + 1.24101692714968e+93*cos(theta)**4 - 2.90296357227995e+90*cos(theta)**2 + 1.09133968882705e+87)*sin(46*phi)

#@torch.jit.script
def Yl86_m_minus_45(theta, phi):
    return 3.29735232158954e-86*(1.0 - cos(theta)**2)**22.5*(3.40405564695816e+105*cos(theta)**41 - 1.63235416988637e+106*cos(theta)**39 + 3.57862260321242e+106*cos(theta)**37 - 4.75721088570753e+106*cos(theta)**35 + 4.28869769241815e+106*cos(theta)**33 - 2.77844463999606e+106*cos(theta)**31 + 1.33745005962543e+106*cos(theta)**29 - 4.87874864517453e+105*cos(theta)**27 + 1.3634082599174e+105*cos(theta)**25 - 2.93206077401592e+104*cos(theta)**23 + 4.848440364876e+103*cos(theta)**21 - 6.12987643963853e+102*cos(theta)**19 + 5.86246572247309e+101*cos(theta)**17 - 4.17213677789817e+100*cos(theta)**15 + 2.15800178167147e+99*cos(theta)**13 - 7.84727920607807e+97*cos(theta)**11 + 1.91312214687187e+96*cos(theta)**9 - 2.91461689747724e+94*cos(theta)**7 + 2.48203385429936e+92*cos(theta)**5 - 9.67654524093316e+89*cos(theta)**3 + 1.09133968882705e+87*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl86_m_minus_44(theta, phi):
    return 2.44582650436353e-84*(1.0 - cos(theta)**2)**22*(8.10489439751943e+103*cos(theta)**42 - 4.08088542471592e+104*cos(theta)**40 + 9.41742790319059e+104*cos(theta)**38 - 1.32144746825209e+105*cos(theta)**36 + 1.26138167424063e+105*cos(theta)**34 - 8.68263949998767e+104*cos(theta)**32 + 4.4581668654181e+104*cos(theta)**30 - 1.74241023041947e+104*cos(theta)**28 + 5.24387792275924e+103*cos(theta)**26 - 1.2216919891733e+103*cos(theta)**24 + 2.20383652948909e+102*cos(theta)**22 - 3.06493821981927e+101*cos(theta)**20 + 3.25692540137394e+100*cos(theta)**18 - 2.60758548618636e+99*cos(theta)**16 + 1.54142984405105e+98*cos(theta)**14 - 6.53939933839839e+96*cos(theta)**12 + 1.91312214687187e+95*cos(theta)**10 - 3.64327112184656e+93*cos(theta)**8 + 4.13672309049893e+91*cos(theta)**6 - 2.41913631023329e+89*cos(theta)**4 + 5.45669844413524e+86*cos(theta)**2 - 1.98353269506915e+83)*sin(44*phi)

#@torch.jit.script
def Yl86_m_minus_43(theta, phi):
    return 1.82865404459152e-82*(1.0 - cos(theta)**2)**21.5*(1.88485916221382e+102*cos(theta)**43 - 9.95337908467298e+102*cos(theta)**41 + 2.4147251033822e+103*cos(theta)**39 - 3.57147964392457e+103*cos(theta)**37 + 3.60394764068752e+103*cos(theta)**35 - 2.63110287878414e+103*cos(theta)**33 + 1.43811834368326e+103*cos(theta)**31 - 6.0083111393775e+102*cos(theta)**29 + 1.94217700842935e+102*cos(theta)**27 - 4.8867679566932e+101*cos(theta)**25 + 9.5818979543004e+100*cos(theta)**23 - 1.45949439039013e+100*cos(theta)**21 + 1.71417126388102e+99*cos(theta)**19 - 1.53387381540374e+98*cos(theta)**17 + 1.02761989603403e+97*cos(theta)**15 - 5.03030718338338e+95*cos(theta)**13 + 1.7392019517017e+94*cos(theta)**11 - 4.04807902427395e+92*cos(theta)**9 + 5.90960441499847e+90*cos(theta)**7 - 4.83827262046658e+88*cos(theta)**5 + 1.81889948137841e+86*cos(theta)**3 - 1.98353269506915e+83*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl86_m_minus_42(theta, phi):
    return 1.37769392789582e-80*(1.0 - cos(theta)**2)**21*(4.28377082321323e+100*cos(theta)**44 - 2.36985216301738e+101*cos(theta)**42 + 6.03681275845551e+101*cos(theta)**40 - 9.39863064190677e+101*cos(theta)**38 + 1.00109656685765e+102*cos(theta)**36 - 7.73853787877689e+101*cos(theta)**34 + 4.49411982401018e+101*cos(theta)**32 - 2.0027703797925e+101*cos(theta)**30 + 6.93634645867625e+100*cos(theta)**28 - 1.87952613718969e+100*cos(theta)**26 + 3.9924574809585e+99*cos(theta)**24 - 6.63406541086421e+98*cos(theta)**22 + 8.57085631940511e+97*cos(theta)**20 - 8.52152119668744e+96*cos(theta)**18 + 6.4226243502127e+95*cos(theta)**16 - 3.59307655955955e+94*cos(theta)**14 + 1.44933495975142e+93*cos(theta)**12 - 4.04807902427395e+91*cos(theta)**10 + 7.38700551874809e+89*cos(theta)**8 - 8.06378770077764e+87*cos(theta)**6 + 4.54724870344604e+85*cos(theta)**4 - 9.91766347534577e+82*cos(theta)**2 + 3.49459600963558e+79)*sin(42*phi)

#@torch.jit.script
def Yl86_m_minus_41(theta, phi):
    return 1.0455961753763e-78*(1.0 - cos(theta)**2)**20.5*(9.51949071825162e+98*cos(theta)**45 - 5.51128410004041e+99*cos(theta)**43 + 1.47239335572085e+100*cos(theta)**41 - 2.40990529279661e+100*cos(theta)**39 + 2.70566639691256e+100*cos(theta)**37 - 2.21101082250768e+100*cos(theta)**35 + 1.3618544921243e+100*cos(theta)**33 - 6.46054961223387e+99*cos(theta)**31 + 2.39184360644009e+99*cos(theta)**29 - 6.96120791551738e+98*cos(theta)**27 + 1.5969829923834e+98*cos(theta)**25 - 2.88437626559314e+97*cos(theta)**23 + 4.08136015209767e+96*cos(theta)**21 - 4.48501115615129e+95*cos(theta)**19 + 3.77801432365453e+94*cos(theta)**17 - 2.3953843730397e+93*cos(theta)**15 + 1.11487304596263e+92*cos(theta)**13 - 3.68007184024905e+90*cos(theta)**11 + 8.2077839097201e+88*cos(theta)**9 - 1.15196967153966e+87*cos(theta)**7 + 9.09449740689207e+84*cos(theta)**5 - 3.30588782511526e+82*cos(theta)**3 + 3.49459600963558e+79*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl86_m_minus_40(theta, phi):
    return 7.99180286079389e-77*(1.0 - cos(theta)**2)**20*(2.06945450396774e+97*cos(theta)**46 - 1.252564568191e+98*cos(theta)**44 + 3.50569846600204e+98*cos(theta)**42 - 6.02476323199152e+98*cos(theta)**40 + 7.12017472871725e+98*cos(theta)**38 - 6.14169672918801e+98*cos(theta)**36 + 4.00545438860088e+98*cos(theta)**34 - 2.01892175382308e+98*cos(theta)**32 + 7.97281202146695e+97*cos(theta)**30 - 2.48614568411335e+97*cos(theta)**28 + 6.14224227839769e+96*cos(theta)**26 - 1.20182344399714e+96*cos(theta)**24 + 1.85516370549894e+95*cos(theta)**22 - 2.24250557807564e+94*cos(theta)**20 + 2.09889684647474e+93*cos(theta)**18 - 1.49711523314981e+92*cos(theta)**16 + 7.96337889973305e+90*cos(theta)**14 - 3.06672653354087e+89*cos(theta)**12 + 8.2077839097201e+87*cos(theta)**10 - 1.43996208942458e+86*cos(theta)**8 + 1.51574956781535e+84*cos(theta)**6 - 8.26471956278814e+81*cos(theta)**4 + 1.74729800481779e+79*cos(theta)**2 - 5.98184869845186e+75)*sin(40*phi)

#@torch.jit.script
def Yl86_m_minus_39(theta, phi):
    return 6.15005449230678e-75*(1.0 - cos(theta)**2)**19.5*(4.40309468929307e+95*cos(theta)**47 - 2.78347681820223e+96*cos(theta)**45 + 8.15278713023729e+96*cos(theta)**43 - 1.4694544468272e+97*cos(theta)**41 + 1.82568582787622e+97*cos(theta)**39 - 1.65991803491568e+97*cos(theta)**37 + 1.14441553960025e+97*cos(theta)**35 - 6.1179447085548e+96*cos(theta)**33 + 2.5718748456345e+96*cos(theta)**31 - 8.572916152115e+95*cos(theta)**29 + 2.2749045475547e+95*cos(theta)**27 - 4.80729377598856e+94*cos(theta)**25 + 8.06592915434322e+93*cos(theta)**23 - 1.06785979908364e+93*cos(theta)**21 + 1.10468255077618e+92*cos(theta)**19 - 8.80656019499891e+90*cos(theta)**17 + 5.3089192664887e+89*cos(theta)**15 - 2.35902041041606e+88*cos(theta)**13 + 7.46162173610918e+86*cos(theta)**11 - 1.59995787713842e+85*cos(theta)**9 + 2.16535652545049e+83*cos(theta)**7 - 1.65294391255763e+81*cos(theta)**5 + 5.82432668272596e+78*cos(theta)**3 - 5.98184869845186e+75*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl86_m_minus_38(theta, phi):
    return 4.76381172539445e-73*(1.0 - cos(theta)**2)**19*(9.17311393602723e+93*cos(theta)**48 - 6.05103656130919e+94*cos(theta)**46 + 1.85290616596302e+95*cos(theta)**44 - 3.49870106387429e+95*cos(theta)**42 + 4.56421456969055e+95*cos(theta)**40 - 4.36820535504126e+95*cos(theta)**38 + 3.17893205444514e+95*cos(theta)**36 - 1.79939550251612e+95*cos(theta)**34 + 8.03710889260782e+94*cos(theta)**32 - 2.85763871737167e+94*cos(theta)**30 + 8.12465909840964e+93*cos(theta)**28 - 1.84895914461098e+93*cos(theta)**26 + 3.36080381430968e+92*cos(theta)**24 - 4.85390817765291e+91*cos(theta)**22 + 5.52341275388089e+90*cos(theta)**20 - 4.89253344166606e+89*cos(theta)**18 + 3.31807454155544e+88*cos(theta)**16 - 1.68501457886861e+87*cos(theta)**14 + 6.21801811342431e+85*cos(theta)**12 - 1.59995787713842e+84*cos(theta)**10 + 2.70669565681312e+82*cos(theta)**8 - 2.75490652092938e+80*cos(theta)**6 + 1.45608167068149e+78*cos(theta)**4 - 2.99092434922593e+75*cos(theta)**2 + 9.9697478307531e+71)*sin(38*phi)

#@torch.jit.script
def Yl86_m_minus_37(theta, phi):
    return 3.71332936182363e-71*(1.0 - cos(theta)**2)**18.5*(1.87206406857699e+92*cos(theta)**49 - 1.28745458751259e+93*cos(theta)**47 + 4.1175692576956e+93*cos(theta)**45 - 8.13651410203322e+93*cos(theta)**43 + 1.11322306577818e+94*cos(theta)**41 - 1.12005265513878e+94*cos(theta)**39 + 8.59170825525714e+93*cos(theta)**37 - 5.14113000718891e+93*cos(theta)**35 + 2.43548754321449e+93*cos(theta)**33 - 9.21818941087635e+92*cos(theta)**31 + 2.8016065856585e+92*cos(theta)**29 - 6.84799683189254e+91*cos(theta)**27 + 1.34432152572387e+91*cos(theta)**25 - 2.11039485984909e+90*cos(theta)**23 + 2.63019654946709e+89*cos(theta)**21 - 2.57501760087687e+88*cos(theta)**19 + 1.95180855385614e+87*cos(theta)**17 - 1.12334305257907e+86*cos(theta)**15 + 4.78309085648024e+84*cos(theta)**13 - 1.45450716103493e+83*cos(theta)**11 + 3.00743961868124e+81*cos(theta)**9 - 3.93558074418483e+79*cos(theta)**7 + 2.91216334136298e+77*cos(theta)**5 - 9.9697478307531e+74*cos(theta)**3 + 9.9697478307531e+71*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl86_m_minus_36(theta, phi):
    return 2.9120647647107e-69*(1.0 - cos(theta)**2)**18*(3.74412813715397e+90*cos(theta)**50 - 2.6821970573179e+91*cos(theta)**48 + 8.95123751672957e+91*cos(theta)**46 - 1.8492077504621e+92*cos(theta)**44 + 2.65053110899567e+92*cos(theta)**42 - 2.80013163784696e+92*cos(theta)**40 + 2.26097585664661e+92*cos(theta)**38 - 1.42809166866359e+92*cos(theta)**36 + 7.1631986565132e+91*cos(theta)**34 - 2.88068419089886e+91*cos(theta)**32 + 9.33868861886166e+90*cos(theta)**30 - 2.44571315424733e+90*cos(theta)**28 + 5.17046740663027e+89*cos(theta)**26 - 8.79331191603787e+88*cos(theta)**24 + 1.19554388612141e+88*cos(theta)**22 - 1.28750880043844e+87*cos(theta)**20 + 1.08433808547563e+86*cos(theta)**18 - 7.02089407861921e+84*cos(theta)**16 + 3.41649346891446e+83*cos(theta)**14 - 1.21208930086244e+82*cos(theta)**12 + 3.00743961868124e+80*cos(theta)**10 - 4.91947593023104e+78*cos(theta)**8 + 4.8536055689383e+76*cos(theta)**6 - 2.49243695768828e+74*cos(theta)**4 + 4.98487391537655e+71*cos(theta)**2 - 1.62109720825254e+68)*sin(36*phi)

#@torch.jit.script
def Yl86_m_minus_35(theta, phi):
    return 2.29702664477922e-67*(1.0 - cos(theta)**2)**17.5*(7.34142771990975e+88*cos(theta)**51 - 5.47387154554674e+89*cos(theta)**49 + 1.90451862058076e+90*cos(theta)**47 - 4.10935055658244e+90*cos(theta)**45 + 6.16402583487365e+90*cos(theta)**43 - 6.82958936060234e+90*cos(theta)**41 + 5.79737399140158e+90*cos(theta)**39 - 3.85970721260428e+90*cos(theta)**37 + 2.0466281875752e+90*cos(theta)**35 - 8.72934603302685e+89*cos(theta)**33 + 3.01248019963279e+89*cos(theta)**31 - 8.43349363533563e+88*cos(theta)**29 + 1.91498792838158e+88*cos(theta)**27 - 3.51732476641515e+87*cos(theta)**25 + 5.19801689618002e+86*cos(theta)**23 - 6.13099428780208e+85*cos(theta)**21 + 5.70704255513491e+84*cos(theta)**19 - 4.12993769330542e+83*cos(theta)**17 + 2.27766231260964e+82*cos(theta)**15 - 9.323763852788e+80*cos(theta)**13 + 2.73403601698295e+79*cos(theta)**11 - 5.46608436692337e+77*cos(theta)**9 + 6.93372224134043e+75*cos(theta)**7 - 4.98487391537655e+73*cos(theta)**5 + 1.66162463845885e+71*cos(theta)**3 - 1.62109720825254e+68*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl86_m_minus_34(theta, phi):
    return 1.82205041674886e-65*(1.0 - cos(theta)**2)**17*(1.41181302305957e+87*cos(theta)**52 - 1.09477430910935e+88*cos(theta)**50 + 3.96774712620992e+88*cos(theta)**48 - 8.93337077517921e+88*cos(theta)**46 + 1.40091496247129e+89*cos(theta)**44 - 1.62609270490532e+89*cos(theta)**42 + 1.44934349785039e+89*cos(theta)**40 - 1.01571242436955e+89*cos(theta)**38 + 5.68507829882e+88*cos(theta)**36 - 2.56745471559613e+88*cos(theta)**34 + 9.41400062385248e+87*cos(theta)**32 - 2.81116454511188e+87*cos(theta)**30 + 6.83924260136279e+86*cos(theta)**28 - 1.35281721785198e+86*cos(theta)**26 + 2.16584037340834e+85*cos(theta)**24 - 2.78681558536458e+84*cos(theta)**22 + 2.85352127756746e+83*cos(theta)**20 - 2.29440982961412e+82*cos(theta)**18 + 1.42353894538102e+81*cos(theta)**16 - 6.65983132342e+79*cos(theta)**14 + 2.27836334748579e+78*cos(theta)**12 - 5.46608436692337e+76*cos(theta)**10 + 8.66715280167554e+74*cos(theta)**8 - 8.30812319229425e+72*cos(theta)**6 + 4.15406159614713e+70*cos(theta)**4 - 8.10548604126269e+67*cos(theta)**2 + 2.5764418440123e+64)*sin(34*phi)

#@torch.jit.script
def Yl86_m_minus_33(theta, phi):
    return 1.45307806764369e-63*(1.0 - cos(theta)**2)**16.5*(2.66379815671616e+85*cos(theta)**53 - 2.14661629237127e+86*cos(theta)**51 + 8.09744311471411e+86*cos(theta)**49 - 1.90071718620834e+87*cos(theta)**47 + 3.1131443610473e+87*cos(theta)**45 - 3.78161094164028e+87*cos(theta)**43 + 3.53498414109852e+87*cos(theta)**41 - 2.60439083171679e+87*cos(theta)**39 + 1.53650764832973e+87*cos(theta)**37 - 7.33558490170323e+86*cos(theta)**35 + 2.85272746177348e+86*cos(theta)**33 - 9.06827272616735e+85*cos(theta)**31 + 2.35835951771131e+85*cos(theta)**29 - 5.01043414019252e+84*cos(theta)**27 + 8.66336149363337e+83*cos(theta)**25 - 1.21165895015851e+83*cos(theta)**23 + 1.3588196559845e+82*cos(theta)**21 - 1.20758412084954e+81*cos(theta)**19 + 8.37375850224132e+79*cos(theta)**17 - 4.43988754894666e+78*cos(theta)**15 + 1.75258719037368e+77*cos(theta)**13 - 4.96916760629398e+75*cos(theta)**11 + 9.63016977963949e+73*cos(theta)**9 - 1.18687474175632e+72*cos(theta)**7 + 8.30812319229425e+69*cos(theta)**5 - 2.7018286804209e+67*cos(theta)**3 + 2.5764418440123e+64*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl86_m_minus_32(theta, phi):
    return 1.16482131268735e-61*(1.0 - cos(theta)**2)**16*(4.93295954947438e+83*cos(theta)**54 - 4.12810825456014e+84*cos(theta)**52 + 1.61948862294282e+85*cos(theta)**50 - 3.95982747126738e+85*cos(theta)**48 + 6.76770513271152e+85*cos(theta)**46 - 8.59457032190973e+85*cos(theta)**44 + 8.41662890737743e+85*cos(theta)**42 - 6.51097707929198e+85*cos(theta)**40 + 4.04344117981508e+85*cos(theta)**38 - 2.03766247269534e+85*cos(theta)**36 + 8.39037488756906e+84*cos(theta)**34 - 2.8338352269273e+84*cos(theta)**32 + 7.86119839237102e+83*cos(theta)**30 - 1.78944076435447e+83*cos(theta)**28 + 3.33206211293591e+82*cos(theta)**26 - 5.04857895899381e+81*cos(theta)**24 + 6.17645298174774e+80*cos(theta)**22 - 6.03792060424769e+79*cos(theta)**20 + 4.65208805680073e+78*cos(theta)**18 - 2.77492971809167e+77*cos(theta)**16 + 1.25184799312406e+76*cos(theta)**14 - 4.14097300524498e+74*cos(theta)**12 + 9.63016977963949e+72*cos(theta)**10 - 1.4835934271954e+71*cos(theta)**8 + 1.38468719871571e+69*cos(theta)**6 - 6.75457170105224e+66*cos(theta)**4 + 1.28822092200615e+64*cos(theta)**2 - 4.00940218489309e+60)*sin(32*phi)

#@torch.jit.script
def Yl86_m_minus_31(theta, phi):
    return 9.38386295791054e-60*(1.0 - cos(theta)**2)**15.5*(8.96901736268068e+81*cos(theta)**55 - 7.78888349917007e+82*cos(theta)**53 + 3.17546788812318e+83*cos(theta)**51 - 8.0812805536069e+83*cos(theta)**49 + 1.43993726227905e+84*cos(theta)**47 - 1.90990451597994e+84*cos(theta)**45 + 1.95735555985522e+84*cos(theta)**43 - 1.58804319007121e+84*cos(theta)**41 + 1.03677978969617e+84*cos(theta)**39 - 5.50719587214957e+83*cos(theta)**37 + 2.39724996787687e+83*cos(theta)**35 - 8.58737947553726e+82*cos(theta)**33 + 2.53587044915194e+82*cos(theta)**31 - 6.17048539432576e+81*cos(theta)**29 + 1.23409707886515e+81*cos(theta)**27 - 2.01943158359752e+80*cos(theta)**25 + 2.68541433989032e+79*cos(theta)**23 - 2.87520028773699e+78*cos(theta)**21 + 2.44846739831618e+77*cos(theta)**19 - 1.63231159887745e+76*cos(theta)**17 + 8.34565328749373e+74*cos(theta)**15 - 3.18536385018845e+73*cos(theta)**13 + 8.75469979967226e+71*cos(theta)**11 - 1.64843714132823e+70*cos(theta)**9 + 1.97812456959387e+68*cos(theta)**7 - 1.35091434021045e+66*cos(theta)**5 + 4.2940697400205e+63*cos(theta)**3 - 4.00940218489309e+60*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl86_m_minus_30(theta, phi):
    return 7.59571394967033e-58*(1.0 - cos(theta)**2)**15*(1.60161024333584e+80*cos(theta)**56 - 1.44238583317964e+81*cos(theta)**54 + 6.1066690156215e+81*cos(theta)**52 - 1.61625611072138e+82*cos(theta)**50 + 2.99986929641468e+82*cos(theta)**48 - 4.15196633908682e+82*cos(theta)**46 + 4.44853536330731e+82*cos(theta)**44 - 3.78105521445527e+82*cos(theta)**42 + 2.59194947424044e+82*cos(theta)**40 - 1.44926207161831e+82*cos(theta)**38 + 6.65902768854687e+81*cos(theta)**36 - 2.52569984574625e+81*cos(theta)**34 + 7.92459515359982e+80*cos(theta)**32 - 2.05682846477525e+80*cos(theta)**30 + 4.40748956737555e+79*cos(theta)**28 - 7.76704455229817e+78*cos(theta)**26 + 1.11892264162097e+78*cos(theta)**24 - 1.30690922169863e+77*cos(theta)**22 + 1.22423369915809e+76*cos(theta)**20 - 9.06839777154139e+74*cos(theta)**18 + 5.21603330468358e+73*cos(theta)**16 - 2.27525989299175e+72*cos(theta)**14 + 7.29558316639355e+70*cos(theta)**12 - 1.64843714132822e+69*cos(theta)**10 + 2.47265571199234e+67*cos(theta)**8 - 2.25152390035075e+65*cos(theta)**6 + 1.07351743500512e+63*cos(theta)**4 - 2.00470109244654e+60*cos(theta)**2 + 6.11935620404928e+56)*sin(30*phi)

#@torch.jit.script
def Yl86_m_minus_29(theta, phi):
    return 6.1763944427092e-56*(1.0 - cos(theta)**2)**14.5*(2.80984253216813e+78*cos(theta)**57 - 2.62251969669026e+79*cos(theta)**55 + 1.15220170106066e+80*cos(theta)**53 - 3.16912962886545e+80*cos(theta)**51 + 6.12218223758098e+80*cos(theta)**49 - 8.83397093422729e+80*cos(theta)**47 + 9.88563414068291e+80*cos(theta)**45 - 8.79315166152389e+80*cos(theta)**43 + 6.32182798595228e+80*cos(theta)**41 - 3.7160565938931e+80*cos(theta)**39 + 1.79973721312078e+80*cos(theta)**37 - 7.21628527356073e+79*cos(theta)**35 + 2.40139247078783e+79*cos(theta)**33 - 6.63493053153308e+78*cos(theta)**31 + 1.51982398875019e+78*cos(theta)**29 - 2.87668316751784e+77*cos(theta)**27 + 4.47569056648387e+76*cos(theta)**25 - 5.68221400738536e+75*cos(theta)**23 + 5.82968428170518e+74*cos(theta)**21 - 4.7728409323902e+73*cos(theta)**19 + 3.06825488510799e+72*cos(theta)**17 - 1.51683992866117e+71*cos(theta)**15 + 5.61198705107196e+69*cos(theta)**13 - 1.4985792193893e+68*cos(theta)**11 + 2.74739523554704e+66*cos(theta)**9 - 3.21646271478678e+64*cos(theta)**7 + 2.14703487001025e+62*cos(theta)**5 - 6.68233697482181e+59*cos(theta)**3 + 6.11935620404928e+56*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl86_m_minus_28(theta, phi):
    return 5.04426553861479e-54*(1.0 - cos(theta)**2)**14*(4.84455608994506e+76*cos(theta)**58 - 4.68307088694689e+77*cos(theta)**56 + 2.13370685381604e+78*cos(theta)**54 - 6.09448005551048e+78*cos(theta)**52 + 1.2244364475162e+79*cos(theta)**50 - 1.84041061129735e+79*cos(theta)**48 + 2.14905090014846e+79*cos(theta)**46 - 1.99844355943725e+79*cos(theta)**44 + 1.50519713951245e+79*cos(theta)**42 - 9.29014148473275e+78*cos(theta)**40 + 4.73615056084415e+78*cos(theta)**38 - 2.0045236871002e+78*cos(theta)**36 + 7.0629190317289e+77*cos(theta)**34 - 2.07341579110409e+77*cos(theta)**32 + 5.06607996250063e+76*cos(theta)**30 - 1.02738684554209e+76*cos(theta)**28 + 1.72141944864764e+75*cos(theta)**26 - 2.3675891697439e+74*cos(theta)**24 + 2.64985649168417e+73*cos(theta)**22 - 2.3864204661951e+72*cos(theta)**20 + 1.70458604728222e+71*cos(theta)**18 - 9.48024955413228e+69*cos(theta)**16 + 4.00856217933712e+68*cos(theta)**14 - 1.24881601615775e+67*cos(theta)**12 + 2.74739523554704e+65*cos(theta)**10 - 4.02057839348348e+63*cos(theta)**8 + 3.57839145001708e+61*cos(theta)**6 - 1.67058424370545e+59*cos(theta)**4 + 3.05967810202464e+56*cos(theta)**2 - 9.17444708253265e+52)*sin(28*phi)

#@torch.jit.script
def Yl86_m_minus_27(theta, phi):
    return 4.13691285026172e-52*(1.0 - cos(theta)**2)**13.5*(8.21111201685603e+74*cos(theta)**59 - 8.21591383674893e+75*cos(theta)**57 + 3.87946700693825e+76*cos(theta)**55 - 1.14990189726613e+77*cos(theta)**53 + 2.40085577944352e+77*cos(theta)**51 - 3.75594002305582e+77*cos(theta)**49 + 4.57244872372013e+77*cos(theta)**47 - 4.44098568763833e+77*cos(theta)**45 + 3.50045846398244e+77*cos(theta)**43 - 2.26588816700799e+77*cos(theta)**41 + 1.21439757970363e+77*cos(theta)**39 - 5.4176315867573e+76*cos(theta)**37 + 2.01797686620826e+76*cos(theta)**35 - 6.28307815486087e+75*cos(theta)**33 + 1.63421934274214e+75*cos(theta)**31 - 3.54271326048995e+74*cos(theta)**29 + 6.37562758758386e+73*cos(theta)**27 - 9.47035667897561e+72*cos(theta)**25 + 1.15211151812355e+72*cos(theta)**23 - 1.13639069818814e+71*cos(theta)**21 + 8.97150551201166e+69*cos(theta)**19 - 5.5766173847837e+68*cos(theta)**17 + 2.67237478622474e+67*cos(theta)**15 - 9.60627704736728e+65*cos(theta)**13 + 2.49763203231549e+64*cos(theta)**11 - 4.46730932609275e+62*cos(theta)**9 + 5.11198778573868e+60*cos(theta)**7 - 3.3411684874109e+58*cos(theta)**5 + 1.01989270067488e+56*cos(theta)**3 - 9.17444708253265e+52*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl86_m_minus_26(theta, phi):
    return 3.4063652911847e-50*(1.0 - cos(theta)**2)**13*(1.36851866947601e+73*cos(theta)**60 - 1.41653686840499e+74*cos(theta)**58 + 6.92761965524688e+74*cos(theta)**56 - 2.12944795790024e+75*cos(theta)**54 + 4.6170303450837e+75*cos(theta)**52 - 7.51188004611164e+75*cos(theta)**50 + 9.5259348410836e+75*cos(theta)**48 - 9.65431671225723e+75*cos(theta)**46 + 7.95558741814191e+75*cos(theta)**44 - 5.39497182620949e+75*cos(theta)**42 + 3.03599394925907e+75*cos(theta)**40 - 1.42569252283087e+75*cos(theta)**38 + 5.60549129502293e+74*cos(theta)**36 - 1.84796416319437e+74*cos(theta)**34 + 5.10693544606918e+73*cos(theta)**32 - 1.18090442016332e+73*cos(theta)**30 + 2.27700985270852e+72*cos(theta)**28 - 3.64244487652908e+71*cos(theta)**26 + 4.80046465884814e+70*cos(theta)**24 - 5.16541226449156e+69*cos(theta)**22 + 4.48575275600583e+68*cos(theta)**20 - 3.09812076932428e+67*cos(theta)**18 + 1.67023424139047e+66*cos(theta)**16 - 6.8616264624052e+64*cos(theta)**14 + 2.08136002692958e+63*cos(theta)**12 - 4.46730932609275e+61*cos(theta)**10 + 6.38998473217336e+59*cos(theta)**8 - 5.56861414568484e+57*cos(theta)**6 + 2.5497317516872e+55*cos(theta)**4 - 4.58722354126632e+52*cos(theta)**2 + 1.35316328650924e+49)*sin(26*phi)

#@torch.jit.script
def Yl86_m_minus_25(theta, phi):
    return 2.81556234105056e-48*(1.0 - cos(theta)**2)**12.5*(2.24347322864919e+71*cos(theta)**61 - 2.40090994644913e+72*cos(theta)**59 + 1.21537186934156e+73*cos(theta)**57 - 3.87172355981862e+73*cos(theta)**55 + 8.71137800959188e+73*cos(theta)**53 - 1.47291765610032e+74*cos(theta)**51 + 1.94406833491502e+74*cos(theta)**49 - 2.05410993877813e+74*cos(theta)**47 + 1.76790831514265e+74*cos(theta)**45 - 1.25464461074639e+74*cos(theta)**43 + 7.40486329087577e+73*cos(theta)**41 - 3.65562185341248e+73*cos(theta)**39 + 1.5149976473035e+73*cos(theta)**37 - 5.27989760912678e+72*cos(theta)**35 + 1.54755619577854e+72*cos(theta)**33 - 3.80936909730102e+71*cos(theta)**31 + 7.85175811278801e+70*cos(theta)**29 - 1.34905365797373e+70*cos(theta)**27 + 1.92018586353926e+69*cos(theta)**25 - 2.24583141934416e+68*cos(theta)**23 + 2.13607274095516e+67*cos(theta)**21 - 1.63058987859172e+66*cos(theta)**19 + 9.82490730229686e+64*cos(theta)**17 - 4.57441764160347e+63*cos(theta)**15 + 1.60104617456121e+62*cos(theta)**13 - 4.06119029644796e+60*cos(theta)**11 + 7.09998303574817e+58*cos(theta)**9 - 7.95516306526406e+56*cos(theta)**7 + 5.0994635033744e+54*cos(theta)**5 - 1.52907451375544e+52*cos(theta)**3 + 1.35316328650924e+49*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl86_m_minus_24(theta, phi):
    return 2.33572915599019e-46*(1.0 - cos(theta)**2)**12*(3.61850520749869e+69*cos(theta)**62 - 4.00151657741522e+70*cos(theta)**60 + 2.09546874024406e+71*cos(theta)**58 - 6.91379207110467e+71*cos(theta)**56 + 1.61321814992442e+72*cos(theta)**54 - 2.83253395403908e+72*cos(theta)**52 + 3.88813666983004e+72*cos(theta)**50 - 4.27939570578778e+72*cos(theta)**48 + 3.84327894596227e+72*cos(theta)**46 - 2.85146502442362e+72*cos(theta)**44 + 1.76306268830376e+72*cos(theta)**42 - 9.13905463353121e+71*cos(theta)**40 + 3.98683591395657e+71*cos(theta)**38 - 1.46663822475744e+71*cos(theta)**36 + 4.55163586993688e+70*cos(theta)**34 - 1.19042784290657e+70*cos(theta)**32 + 2.61725270426267e+69*cos(theta)**30 - 4.81804877847762e+68*cos(theta)**28 + 7.38533024438175e+67*cos(theta)**26 - 9.35763091393399e+66*cos(theta)**24 + 9.70942154979617e+65*cos(theta)**22 - 8.15294939295862e+64*cos(theta)**20 + 5.45828183460936e+63*cos(theta)**18 - 2.85901102600217e+62*cos(theta)**16 + 1.14360441040087e+61*cos(theta)**14 - 3.38432524703996e+59*cos(theta)**12 + 7.09998303574817e+57*cos(theta)**10 - 9.94395383158007e+55*cos(theta)**8 + 8.49910583895733e+53*cos(theta)**6 - 3.8226862843886e+51*cos(theta)**4 + 6.7658164325462e+48*cos(theta)**2 - 1.96623552239064e+45)*sin(24*phi)

#@torch.jit.script
def Yl86_m_minus_23(theta, phi):
    return 1.94441561099186e-44*(1.0 - cos(theta)**2)**11.5*(5.74365905952173e+67*cos(theta)**63 - 6.5598632416643e+68*cos(theta)**61 + 3.55164193261706e+69*cos(theta)**59 - 1.21294597738678e+70*cos(theta)**57 + 2.9331239089535e+70*cos(theta)**55 - 5.34440368686619e+70*cos(theta)**53 + 7.62379739182361e+70*cos(theta)**51 - 8.73346062405669e+70*cos(theta)**49 + 8.17718924672824e+70*cos(theta)**47 - 6.3365889431636e+70*cos(theta)**45 + 4.10014578675292e+70*cos(theta)**43 - 2.22903771549542e+70*cos(theta)**41 + 1.02226561896322e+70*cos(theta)**39 - 3.96388709393903e+69*cos(theta)**37 + 1.30046739141054e+69*cos(theta)**35 - 3.60735709971688e+68*cos(theta)**33 + 8.44275065891184e+67*cos(theta)**31 - 1.66139613050952e+67*cos(theta)**29 + 2.73530749791917e+66*cos(theta)**27 - 3.7430523655736e+65*cos(theta)**25 + 4.22148763034616e+64*cos(theta)**23 - 3.88235685378982e+63*cos(theta)**21 + 2.8727799129523e+62*cos(theta)**19 - 1.68177119176598e+61*cos(theta)**17 + 7.62402940267244e+59*cos(theta)**15 - 2.60332711310766e+58*cos(theta)**13 + 6.45453003249834e+56*cos(theta)**11 - 1.10488375906445e+55*cos(theta)**9 + 1.2141579769939e+53*cos(theta)**7 - 7.64537256877721e+50*cos(theta)**5 + 2.25527214418207e+48*cos(theta)**3 - 1.96623552239064e+45*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl86_m_minus_22(theta, phi):
    return 1.62402359675725e-42*(1.0 - cos(theta)**2)**11*(8.97446728050271e+65*cos(theta)**64 - 1.05804245833295e+67*cos(theta)**62 + 5.91940322102843e+67*cos(theta)**60 - 2.09128616790825e+68*cos(theta)**58 + 5.23772126598839e+68*cos(theta)**56 - 9.89704386456701e+68*cos(theta)**54 + 1.466114883043e+69*cos(theta)**52 - 1.74669212481134e+69*cos(theta)**50 + 1.70358109306838e+69*cos(theta)**48 - 1.37751933547035e+69*cos(theta)**46 + 9.31851315171118e+68*cos(theta)**44 - 5.30723265594147e+68*cos(theta)**42 + 2.55566404740806e+68*cos(theta)**40 - 1.04312818261553e+68*cos(theta)**38 + 3.61240942058483e+67*cos(theta)**36 - 1.06098738226967e+67*cos(theta)**34 + 2.63835958090995e+66*cos(theta)**32 - 5.53798710169841e+65*cos(theta)**30 + 9.76895534971131e+64*cos(theta)**28 - 1.43963552522061e+64*cos(theta)**26 + 1.7589531793109e+63*cos(theta)**24 - 1.76470766081355e+62*cos(theta)**22 + 1.43638995647615e+61*cos(theta)**20 - 9.34317328758878e+59*cos(theta)**18 + 4.76501837667028e+58*cos(theta)**16 - 1.85951936650547e+57*cos(theta)**14 + 5.37877502708195e+55*cos(theta)**12 - 1.10488375906445e+54*cos(theta)**10 + 1.51769747124238e+52*cos(theta)**8 - 1.27422876146287e+50*cos(theta)**6 + 5.63818036045517e+47*cos(theta)**4 - 9.83117761195321e+44*cos(theta)**2 + 2.81857156305998e+41)*sin(22*phi)

#@torch.jit.script
def Yl86_m_minus_21(theta, phi):
    return 1.36069532051179e-40*(1.0 - cos(theta)**2)**10.5*(1.38068727392349e+64*cos(theta)**65 - 1.67943247354437e+65*cos(theta)**63 + 9.70393970660399e+65*cos(theta)**61 - 3.54455282696313e+66*cos(theta)**59 + 9.18898467717261e+66*cos(theta)**57 - 1.79946252083037e+67*cos(theta)**55 + 2.76625449630755e+67*cos(theta)**53 - 3.42488651923792e+67*cos(theta)**51 + 3.47669610830282e+67*cos(theta)**49 - 2.9308922031284e+67*cos(theta)**47 + 2.07078070038026e+67*cos(theta)**45 - 1.23424015254453e+67*cos(theta)**43 + 6.2333269448977e+66*cos(theta)**41 - 2.67468764773214e+66*cos(theta)**39 + 9.76326870428332e+65*cos(theta)**37 - 3.03139252077048e+65*cos(theta)**35 + 7.99502903306045e+64*cos(theta)**33 - 1.78644745216078e+64*cos(theta)**31 + 3.3686052930039e+63*cos(theta)**29 - 5.33198342674302e+62*cos(theta)**27 + 7.0358127172436e+61*cos(theta)**25 - 7.67264200353719e+60*cos(theta)**23 + 6.83995217369595e+59*cos(theta)**21 - 4.91745962504673e+58*cos(theta)**19 + 2.80295198627663e+57*cos(theta)**17 - 1.23967957767032e+56*cos(theta)**15 + 4.1375192516015e+54*cos(theta)**13 - 1.00443978096768e+53*cos(theta)**11 + 1.68633052360264e+51*cos(theta)**9 - 1.82032680208981e+49*cos(theta)**7 + 1.12763607209103e+47*cos(theta)**5 - 3.2770592039844e+44*cos(theta)**3 + 2.81857156305998e+41*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl86_m_minus_20(theta, phi):
    return 1.1434699285799e-38*(1.0 - cos(theta)**2)**10*(2.0919504150356e+62*cos(theta)**66 - 2.62411323991307e+63*cos(theta)**64 + 1.56515156558129e+64*cos(theta)**62 - 5.90758804493856e+64*cos(theta)**60 + 1.58430770296079e+65*cos(theta)**58 - 3.21332593005422e+65*cos(theta)**56 + 5.12269351168065e+65*cos(theta)**54 - 6.58632022930369e+65*cos(theta)**52 + 6.95339221660565e+65*cos(theta)**50 - 6.10602542318417e+65*cos(theta)**48 + 4.5016971747397e+65*cos(theta)**46 - 2.80509125578302e+65*cos(theta)**44 + 1.48412546307088e+65*cos(theta)**42 - 6.68671911933034e+64*cos(theta)**40 + 2.56928123796929e+64*cos(theta)**38 - 8.42053477991801e+63*cos(theta)**36 + 2.35147912737072e+63*cos(theta)**34 - 5.58264828800243e+62*cos(theta)**32 + 1.1228684310013e+62*cos(theta)**30 - 1.90427979526536e+61*cos(theta)**28 + 2.70608181432446e+60*cos(theta)**26 - 3.1969341681405e+59*cos(theta)**24 + 3.10906916986179e+58*cos(theta)**22 - 2.45872981252336e+57*cos(theta)**20 + 1.55719554793146e+56*cos(theta)**18 - 7.74799736043947e+54*cos(theta)**16 + 2.95537089400107e+53*cos(theta)**14 - 8.37033150806404e+51*cos(theta)**12 + 1.68633052360264e+50*cos(theta)**10 - 2.27540850261226e+48*cos(theta)**8 + 1.87939345348506e+46*cos(theta)**6 - 8.19264800996101e+43*cos(theta)**4 + 1.40928578152999e+41*cos(theta)**2 - 3.99118034984421e+37)*sin(20*phi)

#@torch.jit.script
def Yl86_m_minus_19(theta, phi):
    return 9.63640583292203e-37*(1.0 - cos(theta)**2)**9.5*(3.12231405229193e+60*cos(theta)**67 - 4.03709729217396e+61*cos(theta)**65 + 2.48436756441474e+62*cos(theta)**63 - 9.68457056547304e+62*cos(theta)**61 + 2.68526729315389e+63*cos(theta)**59 - 5.63741391237583e+63*cos(theta)**57 + 9.31398820305572e+63*cos(theta)**55 - 1.2427019300573e+64*cos(theta)**53 + 1.36341023855013e+64*cos(theta)**51 - 1.24612763738452e+64*cos(theta)**49 + 9.57807909519086e+63*cos(theta)**47 - 6.23353612396226e+63*cos(theta)**45 + 3.45145456528112e+63*cos(theta)**43 - 1.63090710227569e+63*cos(theta)**41 + 6.58790061017768e+62*cos(theta)**39 - 2.27582021078865e+62*cos(theta)**37 + 6.71851179248777e+61*cos(theta)**35 - 1.69171160242498e+61*cos(theta)**33 + 3.62215622903645e+60*cos(theta)**31 - 6.56648205263918e+59*cos(theta)**29 + 1.00225252382388e+59*cos(theta)**27 - 1.2787736672562e+58*cos(theta)**25 + 1.35176920428774e+57*cos(theta)**23 - 1.17082372024922e+56*cos(theta)**21 + 8.19576604174454e+54*cos(theta)**19 - 4.55764550614087e+53*cos(theta)**17 + 1.97024726266738e+52*cos(theta)**15 - 6.43871654466464e+50*cos(theta)**13 + 1.53302774872968e+49*cos(theta)**11 - 2.52823166956918e+47*cos(theta)**9 + 2.68484779069294e+45*cos(theta)**7 - 1.6385296019922e+43*cos(theta)**5 + 4.69761927176663e+40*cos(theta)**3 - 3.99118034984421e+37*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl86_m_minus_18(theta, phi):
    return 8.14262037718918e-35*(1.0 - cos(theta)**2)**9*(4.59163831219402e+58*cos(theta)**68 - 6.11681407905145e+59*cos(theta)**66 + 3.88182431939804e+60*cos(theta)**64 - 1.56202751056017e+61*cos(theta)**62 + 4.47544548858981e+61*cos(theta)**60 - 9.71967915926868e+61*cos(theta)**58 + 1.66321217911709e+62*cos(theta)**56 - 2.30129987047648e+62*cos(theta)**54 + 2.62194276644255e+62*cos(theta)**52 - 2.49225527476905e+62*cos(theta)**50 + 1.99543314483143e+62*cos(theta)**48 - 1.35511654868745e+62*cos(theta)**46 + 7.84421492109345e+61*cos(theta)**44 - 3.88311214827546e+61*cos(theta)**42 + 1.64697515254442e+61*cos(theta)**40 - 5.98900055470698e+60*cos(theta)**38 + 1.86625327569105e+60*cos(theta)**36 - 4.97562236007347e+59*cos(theta)**34 + 1.13192382157389e+59*cos(theta)**32 - 2.18882735087973e+58*cos(theta)**30 + 3.57947329937098e+57*cos(theta)**28 - 4.91836025867769e+56*cos(theta)**26 + 5.63237168453223e+55*cos(theta)**24 - 5.32192600113282e+54*cos(theta)**22 + 4.09788302087227e+53*cos(theta)**20 - 2.53202528118937e+52*cos(theta)**18 + 1.23140453916711e+51*cos(theta)**16 - 4.59908324618903e+49*cos(theta)**14 + 1.2775231239414e+48*cos(theta)**12 - 2.52823166956918e+46*cos(theta)**10 + 3.35605973836617e+44*cos(theta)**8 - 2.730882669987e+42*cos(theta)**6 + 1.17440481794166e+40*cos(theta)**4 - 1.9955901749221e+37*cos(theta)**2 + 5.58988844515996e+33)*sin(18*phi)

#@torch.jit.script
def Yl86_m_minus_17(theta, phi):
    return 6.89771748603804e-33*(1.0 - cos(theta)**2)**8.5*(6.65454827854206e+56*cos(theta)**69 - 9.1295732523156e+57*cos(theta)**67 + 5.97203741445852e+58*cos(theta)**65 - 2.4794087469209e+59*cos(theta)**63 + 7.33679588293412e+59*cos(theta)**61 - 1.64740324733367e+60*cos(theta)**59 + 2.9179161037142e+60*cos(theta)**57 - 4.18418158268451e+60*cos(theta)**55 + 4.94706182347651e+60*cos(theta)**53 - 4.88677504856676e+60*cos(theta)**51 + 4.0723125404723e+60*cos(theta)**49 - 2.883226699335e+60*cos(theta)**47 + 1.7431588713541e+60*cos(theta)**45 - 9.03049336808246e+59*cos(theta)**43 + 4.01701256718151e+59*cos(theta)**41 - 1.53564116787358e+59*cos(theta)**39 + 5.04392777213797e+58*cos(theta)**37 - 1.42160638859242e+58*cos(theta)**35 + 3.43007218658755e+57*cos(theta)**33 - 7.0607333899346e+56*cos(theta)**31 + 1.23430113771413e+56*cos(theta)**29 - 1.82161491062137e+55*cos(theta)**27 + 2.25294867381289e+54*cos(theta)**25 - 2.31388087005775e+53*cos(theta)**23 + 1.95137286708203e+52*cos(theta)**21 - 1.33264488483651e+51*cos(theta)**19 + 7.24355611274772e+49*cos(theta)**17 - 3.06605549745935e+48*cos(theta)**15 + 9.82710095339537e+46*cos(theta)**13 - 2.29839242688107e+45*cos(theta)**11 + 3.7289552648513e+43*cos(theta)**9 - 3.90126095712429e+41*cos(theta)**7 + 2.34880963588332e+39*cos(theta)**5 - 6.65196724974035e+36*cos(theta)**3 + 5.58988844515996e+33*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl86_m_minus_16(theta, phi):
    return 5.85697047959929e-31*(1.0 - cos(theta)**2)**8*(9.50649754077437e+54*cos(theta)**70 - 1.34258430181112e+56*cos(theta)**68 + 9.04854153705836e+56*cos(theta)**66 - 3.87407616706391e+57*cos(theta)**64 + 1.18335417466679e+58*cos(theta)**62 - 2.74567207888946e+58*cos(theta)**60 + 5.03088983399e+58*cos(theta)**58 - 7.47175282622234e+58*cos(theta)**56 + 9.16122559903058e+58*cos(theta)**54 - 9.39764432416685e+58*cos(theta)**52 + 8.14462508094461e+58*cos(theta)**50 - 6.00672229028124e+58*cos(theta)**48 + 3.78947580729152e+58*cos(theta)**46 - 2.05238485638238e+58*cos(theta)**44 + 9.56431563614645e+57*cos(theta)**42 - 3.83910291968396e+57*cos(theta)**40 + 1.32734941372052e+57*cos(theta)**38 - 3.94890663497894e+56*cos(theta)**36 + 1.00884476076104e+56*cos(theta)**34 - 2.20647918435456e+55*cos(theta)**32 + 4.11433712571377e+54*cos(theta)**30 - 6.50576753793345e+53*cos(theta)**28 + 8.66518720697267e+52*cos(theta)**26 - 9.64117029190728e+51*cos(theta)**24 + 8.8698766685547e+50*cos(theta)**22 - 6.66322442418255e+49*cos(theta)**20 + 4.0241978404154e+48*cos(theta)**18 - 1.9162846859121e+47*cos(theta)**16 + 7.01935782385383e+45*cos(theta)**14 - 1.9153270224009e+44*cos(theta)**12 + 3.7289552648513e+42*cos(theta)**10 - 4.87657619640536e+40*cos(theta)**8 + 3.9146827264722e+38*cos(theta)**6 - 1.66299181243509e+36*cos(theta)**4 + 2.79494422257998e+33*cos(theta)**2 - 7.75296594335639e+29)*sin(16*phi)

#@torch.jit.script
def Yl86_m_minus_15(theta, phi):
    return 4.98427843690956e-29*(1.0 - cos(theta)**2)**7.5*(1.33894331560202e+53*cos(theta)**71 - 1.94577435045089e+54*cos(theta)**69 + 1.35052858762065e+55*cos(theta)**67 - 5.96011718009832e+55*cos(theta)**65 + 1.87833995978856e+56*cos(theta)**63 - 4.50110176867124e+56*cos(theta)**61 + 8.52693192201695e+56*cos(theta)**59 - 1.31083382916181e+57*cos(theta)**57 + 1.66567738164192e+57*cos(theta)**55 - 1.77314043852205e+57*cos(theta)**53 + 1.59698530998914e+57*cos(theta)**51 - 1.22586169189413e+57*cos(theta)**49 + 8.06271448359898e+56*cos(theta)**47 - 4.56085523640528e+56*cos(theta)**45 + 2.22425945026662e+56*cos(theta)**43 - 9.36366565776576e+55*cos(theta)**41 + 3.40346003518082e+55*cos(theta)**39 - 1.06727206350782e+55*cos(theta)**37 + 2.88241360217441e+54*cos(theta)**35 - 6.68630055865019e+53*cos(theta)**33 + 1.3272055244238e+53*cos(theta)**31 - 2.24336811652877e+52*cos(theta)**29 + 3.20932859517506e+51*cos(theta)**27 - 3.85646811676291e+50*cos(theta)**25 + 3.85646811676291e+49*cos(theta)**23 - 3.1729640115155e+48*cos(theta)**21 + 2.11799886337653e+47*cos(theta)**19 - 1.12722628583064e+46*cos(theta)**17 + 4.67957188256922e+44*cos(theta)**15 - 1.47332847876992e+43*cos(theta)**13 + 3.389959331683e+41*cos(theta)**11 - 5.41841799600596e+39*cos(theta)**9 + 5.59240389496028e+37*cos(theta)**7 - 3.32598362487017e+35*cos(theta)**5 + 9.31648074193326e+32*cos(theta)**3 - 7.75296594335639e+29*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl86_m_minus_14(theta, phi):
    return 4.25039439739959e-27*(1.0 - cos(theta)**2)**7*(1.8596434938917e+51*cos(theta)**72 - 2.77967764350128e+52*cos(theta)**70 + 1.98607145238331e+53*cos(theta)**68 - 9.03048057590655e+53*cos(theta)**66 + 2.93490618716963e+54*cos(theta)**64 - 7.25984156237297e+54*cos(theta)**62 + 1.42115532033616e+55*cos(theta)**60 - 2.26005832614106e+55*cos(theta)**58 + 2.97442389578915e+55*cos(theta)**56 - 3.28359340467046e+55*cos(theta)**54 + 3.07112559613296e+55*cos(theta)**52 - 2.45172338378826e+55*cos(theta)**50 + 1.67973218408312e+55*cos(theta)**48 - 9.91490268783758e+54*cos(theta)**46 + 5.05513511424231e+54*cos(theta)**44 - 2.22944420422994e+54*cos(theta)**42 + 8.50865008795204e+53*cos(theta)**40 - 2.80861069344164e+53*cos(theta)**38 + 8.00670445048448e+52*cos(theta)**36 - 1.96655898783829e+52*cos(theta)**34 + 4.14751726382437e+51*cos(theta)**32 - 7.47789372176258e+50*cos(theta)**30 + 1.14618878399109e+50*cos(theta)**28 - 1.48325696798574e+49*cos(theta)**26 + 1.60686171531788e+48*cos(theta)**24 - 1.44225636887068e+47*cos(theta)**22 + 1.05899943168826e+46*cos(theta)**20 - 6.26236825461469e+44*cos(theta)**18 + 2.92473242660576e+43*cos(theta)**16 - 1.05237748483566e+42*cos(theta)**14 + 2.82496610973583e+40*cos(theta)**12 - 5.41841799600596e+38*cos(theta)**10 + 6.99050486870035e+36*cos(theta)**8 - 5.54330604145029e+34*cos(theta)**6 + 2.32912018548332e+32*cos(theta)**4 - 3.87648297167819e+29*cos(theta)**2 + 1.06613943115462e+26)*sin(14*phi)

#@torch.jit.script
def Yl86_m_minus_13(theta, phi):
    return 3.63153856504587e-25*(1.0 - cos(theta)**2)**6.5*(2.54745684094753e+49*cos(theta)**73 - 3.91503893450884e+50*cos(theta)**71 + 2.87836442374393e+51*cos(theta)**69 - 1.3478329217771e+52*cos(theta)**67 + 4.51524028795327e+52*cos(theta)**65 - 1.15235580355126e+53*cos(theta)**63 + 2.32976282022321e+53*cos(theta)**61 - 3.83060733244247e+53*cos(theta)**59 + 5.21828753647219e+53*cos(theta)**57 - 5.97016982667356e+53*cos(theta)**55 + 5.79457659647728e+53*cos(theta)**53 - 4.807300752526e+53*cos(theta)**51 + 3.42802486547576e+53*cos(theta)**49 - 2.1095537633697e+53*cos(theta)**47 + 1.12336335872051e+53*cos(theta)**45 - 5.18475396332545e+52*cos(theta)**43 + 2.0752805092566e+52*cos(theta)**41 - 7.20156588061959e+51*cos(theta)**39 + 2.16397417580661e+51*cos(theta)**37 - 5.61873996525226e+50*cos(theta)**35 + 1.25682341328011e+50*cos(theta)**33 - 2.41222378121374e+49*cos(theta)**31 + 3.95237511721067e+48*cos(theta)**29 - 5.49354432587309e+47*cos(theta)**27 + 6.42744686127152e+46*cos(theta)**25 - 6.27067986465514e+45*cos(theta)**23 + 5.04285443661078e+44*cos(theta)**21 - 3.29598329190247e+43*cos(theta)**19 + 1.72043083917986e+42*cos(theta)**17 - 7.01584989890438e+40*cos(theta)**15 + 2.17305085364295e+39*cos(theta)**13 - 4.9258345418236e+37*cos(theta)**11 + 7.76722763188928e+35*cos(theta)**9 - 7.91900863064327e+33*cos(theta)**7 + 4.65824037096663e+31*cos(theta)**5 - 1.2921609905594e+29*cos(theta)**3 + 1.06613943115462e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl86_m_minus_12(theta, phi):
    return 3.10830851158339e-23*(1.0 - cos(theta)**2)**6*(3.4425092445237e+47*cos(theta)**74 - 5.43755407570673e+48*cos(theta)**72 + 4.11194917677704e+49*cos(theta)**70 - 1.98210723790749e+50*cos(theta)**68 + 6.84127316356557e+50*cos(theta)**66 - 1.80055594304885e+51*cos(theta)**64 + 3.75768196810195e+51*cos(theta)**62 - 6.38434555407079e+51*cos(theta)**60 + 8.99704747667619e+51*cos(theta)**58 - 1.06610175476314e+52*cos(theta)**56 + 1.07306974008839e+52*cos(theta)**54 - 9.24480913947308e+51*cos(theta)**52 + 6.85604973095152e+51*cos(theta)**50 - 4.39490367368687e+51*cos(theta)**48 + 2.44209425808807e+51*cos(theta)**46 - 1.17835317348306e+51*cos(theta)**44 + 4.94114406965856e+50*cos(theta)**42 - 1.8003914701549e+50*cos(theta)**40 + 5.69466888370162e+49*cos(theta)**38 - 1.56076110145896e+49*cos(theta)**36 + 3.69653945082386e+48*cos(theta)**34 - 7.53819931629293e+47*cos(theta)**32 + 1.31745837240356e+47*cos(theta)**30 - 1.96198011638325e+46*cos(theta)**28 + 2.47209494664289e+45*cos(theta)**26 - 2.61278327693964e+44*cos(theta)**24 + 2.29220656209581e+43*cos(theta)**22 - 1.64799164595123e+42*cos(theta)**20 + 9.55794910655478e+40*cos(theta)**18 - 4.38490618681524e+39*cos(theta)**16 + 1.55217918117354e+38*cos(theta)**14 - 4.10486211818633e+36*cos(theta)**12 + 7.76722763188928e+34*cos(theta)**10 - 9.89876078830409e+32*cos(theta)**8 + 7.76373395161105e+30*cos(theta)**6 - 3.2304024763985e+28*cos(theta)**4 + 5.3306971557731e+25*cos(theta)**2 - 1.45528177880783e+22)*sin(12*phi)

#@torch.jit.script
def Yl86_m_minus_11(theta, phi):
    return 2.66481943578521e-21*(1.0 - cos(theta)**2)**5.5*(4.59001232603159e+45*cos(theta)**75 - 7.44870421329689e+46*cos(theta)**73 + 5.79147771377048e+47*cos(theta)**71 - 2.87261918537318e+48*cos(theta)**69 + 1.02108554680083e+49*cos(theta)**67 - 2.770086066229e+49*cos(theta)**65 + 5.96457455254278e+49*cos(theta)**63 - 1.04661402525751e+50*cos(theta)**61 + 1.52492330113156e+50*cos(theta)**59 - 1.8703539557248e+50*cos(theta)**57 + 1.95103589106979e+50*cos(theta)**55 - 1.74430361122134e+50*cos(theta)**53 + 1.34432347665716e+50*cos(theta)**51 - 8.96919117078953e+49*cos(theta)**49 + 5.19594522997462e+49*cos(theta)**47 - 2.61856260774012e+49*cos(theta)**45 + 1.14910327201362e+49*cos(theta)**43 - 4.39119870769487e+48*cos(theta)**41 + 1.46017150864144e+48*cos(theta)**39 - 4.21827324718638e+47*cos(theta)**37 + 1.05615412880682e+47*cos(theta)**35 - 2.28430282311907e+46*cos(theta)**33 + 4.24986571743083e+45*cos(theta)**31 - 6.76544867718361e+44*cos(theta)**29 + 9.15590720978849e+43*cos(theta)**27 - 1.04511331077586e+43*cos(theta)**25 + 9.96611548737308e+41*cos(theta)**23 - 7.84757926643445e+40*cos(theta)**21 + 5.03049952976567e+39*cos(theta)**19 - 2.57935658047955e+38*cos(theta)**17 + 1.03478612078236e+37*cos(theta)**15 - 3.15758624475872e+35*cos(theta)**13 + 7.06111602899025e+33*cos(theta)**11 - 1.09986230981157e+32*cos(theta)**9 + 1.10910485023015e+30*cos(theta)**7 - 6.46080495279699e+27*cos(theta)**5 + 1.77689905192437e+25*cos(theta)**3 - 1.45528177880783e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl86_m_minus_10(theta, phi):
    return 2.28802334065883e-19*(1.0 - cos(theta)**2)**5*(6.03948990267315e+43*cos(theta)**76 - 1.00658165044553e+45*cos(theta)**74 + 8.04371904690344e+45*cos(theta)**72 - 4.10374169339026e+46*cos(theta)**70 + 1.50159639235416e+47*cos(theta)**68 - 4.19710010034697e+47*cos(theta)**66 + 9.31964773834809e+47*cos(theta)**64 - 1.68808713751211e+48*cos(theta)**62 + 2.54153883521926e+48*cos(theta)**60 - 3.22474819952552e+48*cos(theta)**58 + 3.48399266262463e+48*cos(theta)**56 - 3.2301918726321e+48*cos(theta)**54 + 2.58523745510992e+48*cos(theta)**52 - 1.79383823415791e+48*cos(theta)**50 + 1.08248858957805e+48*cos(theta)**48 - 5.69252740813071e+47*cos(theta)**46 + 2.6115983454855e+47*cos(theta)**44 - 1.04552350183211e+47*cos(theta)**42 + 3.6504287716036e+46*cos(theta)**40 - 1.11007190715431e+46*cos(theta)**38 + 2.93376146890782e+45*cos(theta)**36 - 6.71853771505608e+44*cos(theta)**34 + 1.32808303669713e+44*cos(theta)**32 - 2.2551495590612e+43*cos(theta)**30 + 3.26996686063875e+42*cos(theta)**28 - 4.01966657990714e+41*cos(theta)**26 + 4.15254811973878e+40*cos(theta)**24 - 3.56708148474293e+39*cos(theta)**22 + 2.51524976488284e+38*cos(theta)**20 - 1.4329758780442e+37*cos(theta)**18 + 6.46741325488973e+35*cos(theta)**16 - 2.25541874625623e+34*cos(theta)**14 + 5.88426335749188e+32*cos(theta)**12 - 1.09986230981157e+31*cos(theta)**10 + 1.38638106278769e+29*cos(theta)**8 - 1.07680082546617e+27*cos(theta)**6 + 4.44224762981091e+24*cos(theta)**4 - 7.27640889403917e+21*cos(theta)**2 + 1.97406643896885e+18)*sin(10*phi)

#@torch.jit.script
def Yl86_m_minus_9(theta, phi):
    return 1.96716790255173e-17*(1.0 - cos(theta)**2)**4.5*(7.843493380095e+41*cos(theta)**77 - 1.3421088672607e+43*cos(theta)**75 + 1.10187932149362e+44*cos(theta)**73 - 5.77991787801445e+44*cos(theta)**71 + 2.17622665558574e+45*cos(theta)**69 - 6.26432850798056e+45*cos(theta)**67 + 1.43379195974586e+46*cos(theta)**65 - 2.67950339287636e+46*cos(theta)**63 + 4.16645710691683e+46*cos(theta)**61 - 5.46567491445003e+46*cos(theta)**59 + 6.11226782916601e+46*cos(theta)**57 - 5.87307613205837e+46*cos(theta)**55 + 4.87780651907533e+46*cos(theta)**53 - 3.51732987089785e+46*cos(theta)**51 + 2.20916038689397e+46*cos(theta)**49 - 1.21117604428313e+46*cos(theta)**47 + 5.80355187885666e+45*cos(theta)**45 - 2.43145000426072e+45*cos(theta)**43 + 8.90348480878927e+44*cos(theta)**41 - 2.84633822347259e+44*cos(theta)**39 + 7.92908505110223e+43*cos(theta)**37 - 1.91958220430174e+43*cos(theta)**35 + 4.02449405059737e+42*cos(theta)**33 - 7.27467599697163e+41*cos(theta)**31 + 1.1275747795306e+41*cos(theta)**29 - 1.48876539996561e+40*cos(theta)**27 + 1.66101924789551e+39*cos(theta)**25 - 1.55090499336649e+38*cos(theta)**23 + 1.19773798327754e+37*cos(theta)**21 - 7.54197830549576e+35*cos(theta)**19 + 3.80436073817043e+34*cos(theta)**17 - 1.50361249750415e+33*cos(theta)**15 + 4.5263564288399e+31*cos(theta)**13 - 9.99874827101423e+29*cos(theta)**11 + 1.54042340309743e+28*cos(theta)**9 - 1.53828689352309e+26*cos(theta)**7 + 8.88449525962183e+23*cos(theta)**5 - 2.42546963134639e+21*cos(theta)**3 + 1.97406643896885e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl86_m_minus_8(theta, phi):
    return 1.69336482236135e-15*(1.0 - cos(theta)**2)**4*(1.00557607437115e+40*cos(theta)**78 - 1.76593272007987e+41*cos(theta)**76 + 1.48902611012652e+42*cos(theta)**74 - 8.02766371946451e+42*cos(theta)**72 + 3.10889522226535e+43*cos(theta)**70 - 9.21224780585376e+43*cos(theta)**68 + 2.172412060221e+44*cos(theta)**66 - 4.18672405136931e+44*cos(theta)**64 + 6.72009210793036e+44*cos(theta)**62 - 9.10945819075005e+44*cos(theta)**60 + 1.05383928089069e+45*cos(theta)**58 - 1.04876359501042e+45*cos(theta)**56 + 9.03297503532468e+44*cos(theta)**54 - 6.7640959055728e+44*cos(theta)**52 + 4.41832077378794e+44*cos(theta)**50 - 2.52328342558985e+44*cos(theta)**48 + 1.26164171279493e+44*cos(theta)**46 - 5.52602273695619e+43*cos(theta)**44 + 2.11987733542602e+43*cos(theta)**42 - 7.11584555868148e+42*cos(theta)**40 + 2.08660132923743e+42*cos(theta)**38 - 5.33217278972705e+41*cos(theta)**36 + 1.18367472076393e+41*cos(theta)**34 - 2.27333624905363e+40*cos(theta)**32 + 3.75858259843534e+39*cos(theta)**30 - 5.31701928559146e+38*cos(theta)**28 + 6.3885355688289e+37*cos(theta)**26 - 6.46210413902705e+36*cos(theta)**24 + 5.44426356035246e+35*cos(theta)**22 - 3.77098915274788e+34*cos(theta)**20 + 2.11353374342802e+33*cos(theta)**18 - 9.39757810940095e+31*cos(theta)**16 + 3.23311173488565e+30*cos(theta)**14 - 8.33229022584519e+28*cos(theta)**12 + 1.54042340309743e+27*cos(theta)**10 - 1.92285861690387e+25*cos(theta)**8 + 1.48074920993697e+23*cos(theta)**6 - 6.06367407836597e+20*cos(theta)**4 + 9.87033219484423e+17*cos(theta)**2 - 266405727256255.0)*sin(8*phi)

#@torch.jit.script
def Yl86_m_minus_7(theta, phi):
    return 1.4592443015096e-13*(1.0 - cos(theta)**2)**3.5*(1.27288110679893e+38*cos(theta)**79 - 2.29341911698684e+39*cos(theta)**77 + 1.98536814683536e+40*cos(theta)**75 - 1.09967996157048e+41*cos(theta)**73 + 4.37872566516246e+41*cos(theta)**71 - 1.33510837765997e+42*cos(theta)**69 + 3.24240606003134e+42*cos(theta)**67 - 6.44111392518356e+42*cos(theta)**65 + 1.06668128697307e+43*cos(theta)**63 - 1.4933538017623e+43*cos(theta)**61 + 1.78616827269609e+43*cos(theta)**59 - 1.83993613159723e+43*cos(theta)**57 + 1.64235909733176e+43*cos(theta)**55 - 1.27624451048543e+43*cos(theta)**53 + 8.66337406625087e+42*cos(theta)**51 - 5.14955801140786e+42*cos(theta)**49 + 2.68434406977644e+42*cos(theta)**47 - 1.22800505265693e+42*cos(theta)**45 + 4.92994729168841e+41*cos(theta)**43 - 1.73557208748329e+41*cos(theta)**41 + 5.35025981855751e+40*cos(theta)**39 - 1.44112778100731e+40*cos(theta)**37 + 3.38192777361124e+39*cos(theta)**35 - 6.88889772440495e+38*cos(theta)**33 + 1.21244599949527e+38*cos(theta)**31 - 1.83345492606602e+37*cos(theta)**29 + 2.36612428475144e+36*cos(theta)**27 - 2.58484165561082e+35*cos(theta)**25 + 2.36707111319672e+34*cos(theta)**23 - 1.79570912035613e+33*cos(theta)**21 + 1.11238618075159e+32*cos(theta)**19 - 5.52798712317703e+30*cos(theta)**17 + 2.1554078232571e+29*cos(theta)**15 - 6.40945401988092e+27*cos(theta)**13 + 1.40038491190676e+26*cos(theta)**11 - 2.13650957433763e+24*cos(theta)**9 + 2.11535601419567e+22*cos(theta)**7 - 1.21273481567319e+20*cos(theta)**5 + 3.29011073161474e+17*cos(theta)**3 - 266405727256255.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl86_m_minus_6(theta, phi):
    return 1.25867751430906e-11*(1.0 - cos(theta)**2)**3*(1.59110138349866e+36*cos(theta)**80 - 2.9402809192139e+37*cos(theta)**78 + 2.61232650899389e+38*cos(theta)**76 - 1.48605400212227e+39*cos(theta)**74 + 6.08156342383675e+39*cos(theta)**72 - 1.90729768237138e+40*cos(theta)**70 + 4.76824420592845e+40*cos(theta)**68 - 9.75926352300539e+40*cos(theta)**66 + 1.66668951089543e+41*cos(theta)**64 - 2.40863516413275e+41*cos(theta)**62 + 2.97694712116015e+41*cos(theta)**60 - 3.17230367516765e+41*cos(theta)**58 + 2.93278410237814e+41*cos(theta)**56 - 2.36341576015821e+41*cos(theta)**54 + 1.66603347427901e+41*cos(theta)**52 - 1.02991160228157e+41*cos(theta)**50 + 5.59238347870091e+40*cos(theta)**48 - 2.66957620142811e+40*cos(theta)**46 + 1.12044256629282e+40*cos(theta)**44 - 4.13231449400783e+39*cos(theta)**42 + 1.33756495463938e+39*cos(theta)**40 - 3.79244152896661e+38*cos(theta)**38 + 9.39424381558677e+37*cos(theta)**36 - 2.02614638953087e+37*cos(theta)**34 + 3.78889374842272e+36*cos(theta)**32 - 6.11151642022007e+35*cos(theta)**30 + 8.4504438741123e+34*cos(theta)**28 - 9.94169867542623e+33*cos(theta)**26 + 9.86279630498634e+32*cos(theta)**24 - 8.16231418343697e+31*cos(theta)**22 + 5.56193090375794e+30*cos(theta)**20 - 3.07110395732057e+29*cos(theta)**18 + 1.34712988953569e+28*cos(theta)**16 - 4.57818144277208e+26*cos(theta)**14 + 1.16698742658896e+25*cos(theta)**12 - 2.13650957433763e+23*cos(theta)**10 + 2.64419501774459e+21*cos(theta)**8 - 2.02122469278866e+19*cos(theta)**6 + 8.22527682903686e+16*cos(theta)**4 - 133202863628127.0*cos(theta)**2 + 35807221405.4106)*sin(6*phi)

#@torch.jit.script
def Yl86_m_minus_5(theta, phi):
    return 1.0865529541455e-9*(1.0 - cos(theta)**2)**2.5*(1.96432269567736e+34*cos(theta)**81 - 3.72187458128342e+35*cos(theta)**79 + 3.39263182986219e+36*cos(theta)**77 - 1.98140533616303e+37*cos(theta)**75 + 8.33090879977637e+37*cos(theta)**73 - 2.68633476390335e+38*cos(theta)**71 + 6.91049884917166e+38*cos(theta)**69 - 1.45660649597095e+39*cos(theta)**67 + 2.56413770906989e+39*cos(theta)**65 - 3.82323041925833e+39*cos(theta)**63 + 4.88024118222975e+39*cos(theta)**61 - 5.37678589011465e+39*cos(theta)**59 + 5.14523526733007e+39*cos(theta)**57 - 4.29711956392402e+39*cos(theta)**55 + 3.1434593854321e+39*cos(theta)**53 - 2.01943451427759e+39*cos(theta)**51 + 1.14130275075529e+39*cos(theta)**49 - 5.67994936474067e+38*cos(theta)**47 + 2.4898723695396e+38*cos(theta)**45 - 9.61003370699495e+37*cos(theta)**43 + 3.26235354790092e+37*cos(theta)**41 - 9.72420904863233e+36*cos(theta)**39 + 2.53898481502345e+36*cos(theta)**37 - 5.78898968437391e+35*cos(theta)**35 + 1.14814962073416e+35*cos(theta)**33 - 1.97145690974841e+34*cos(theta)**31 + 2.913946163487e+33*cos(theta)**29 - 3.68211062052823e+32*cos(theta)**27 + 3.94511852199454e+31*cos(theta)**25 - 3.54883225366825e+30*cos(theta)**23 + 2.64853852559902e+29*cos(theta)**21 - 1.61637050385293e+28*cos(theta)**19 + 7.92429346785698e+26*cos(theta)**17 - 3.05212096184806e+25*cos(theta)**15 + 8.97682635837664e+23*cos(theta)**13 - 1.94228143121603e+22*cos(theta)**11 + 2.93799446416066e+20*cos(theta)**9 - 2.88746384684094e+18*cos(theta)**7 + 1.64505536580737e+16*cos(theta)**5 - 44400954542709.1*cos(theta)**3 + 35807221405.4106*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl86_m_minus_4(theta, phi):
    return 9.38595611430988e-8*(1.0 - cos(theta)**2)**2*(2.39551548253337e+32*cos(theta)**82 - 4.65234322660427e+33*cos(theta)**80 + 4.34952798700281e+34*cos(theta)**78 - 2.60711228442504e+35*cos(theta)**76 + 1.12579848645627e+36*cos(theta)**74 - 3.73102050542132e+36*cos(theta)**72 + 9.87214121310238e+36*cos(theta)**70 - 2.14206837642787e+37*cos(theta)**68 + 3.88505713495438e+37*cos(theta)**66 - 5.97379753009114e+37*cos(theta)**64 + 7.87135674553185e+37*cos(theta)**62 - 8.96130981685775e+37*cos(theta)**60 + 8.87109528850013e+37*cos(theta)**58 - 7.67342779272146e+37*cos(theta)**56 + 5.82122108413352e+37*cos(theta)**54 - 3.88352791207229e+37*cos(theta)**52 + 2.28260550151058e+37*cos(theta)**50 - 1.18332278432097e+37*cos(theta)**48 + 5.41276602073827e+36*cos(theta)**46 - 2.18409856977158e+36*cos(theta)**44 + 7.76750844738314e+35*cos(theta)**42 - 2.43105226215808e+35*cos(theta)**40 + 6.68153898690382e+34*cos(theta)**38 - 1.60805269010386e+34*cos(theta)**36 + 3.37691064921811e+33*cos(theta)**34 - 6.16080284296378e+32*cos(theta)**32 + 9.71315387829e+31*cos(theta)**30 - 1.31503950733151e+31*cos(theta)**28 + 1.51735327769021e+30*cos(theta)**26 - 1.4786801056951e+29*cos(theta)**24 + 1.20388114799955e+28*cos(theta)**22 - 8.08185251926466e+26*cos(theta)**20 + 4.40238525992054e+25*cos(theta)**18 - 1.90757560115504e+24*cos(theta)**16 + 6.41201882741188e+22*cos(theta)**14 - 1.61856785934669e+21*cos(theta)**12 + 2.93799446416066e+19*cos(theta)**10 - 3.60932980855118e+17*cos(theta)**8 + 2.74175894301229e+15*cos(theta)**6 - 11100238635677.3*cos(theta)**4 + 17903610702.7053*cos(theta)**2 - 4798609.14036593)*sin(4*phi)

#@torch.jit.script
def Yl86_m_minus_3(theta, phi):
    return 8.11220319138235e-6*(1.0 - cos(theta)**2)**1.5*(2.88616323196791e+30*cos(theta)**83 - 5.74363361309169e+31*cos(theta)**81 + 5.50573162911748e+32*cos(theta)**79 - 3.38586010964291e+33*cos(theta)**77 + 1.50106464860836e+34*cos(theta)**75 - 5.11098699372784e+34*cos(theta)**73 + 1.39044242438062e+35*cos(theta)**71 - 3.10444692235924e+35*cos(theta)**69 + 5.79859273873788e+35*cos(theta)**67 - 9.19045773860175e+35*cos(theta)**65 + 1.24942170563998e+36*cos(theta)**63 - 1.46906718309144e+36*cos(theta)**61 + 1.50357547262714e+36*cos(theta)**59 - 1.34621540223184e+36*cos(theta)**57 + 1.05840383347882e+36*cos(theta)**55 - 7.32741115485338e+35*cos(theta)**53 + 4.47569706178544e+35*cos(theta)**51 - 2.4149444577979e+35*cos(theta)**49 + 1.15165234483793e+35*cos(theta)**47 - 4.85355237727018e+34*cos(theta)**45 + 1.80639731334492e+34*cos(theta)**43 - 5.92939576136118e+33*cos(theta)**41 + 1.71321512484713e+33*cos(theta)**39 - 4.34608835163206e+32*cos(theta)**37 + 9.64831614062318e+31*cos(theta)**35 - 1.86690995241327e+31*cos(theta)**33 + 3.13327544460968e+30*cos(theta)**31 - 4.53461899079832e+29*cos(theta)**29 + 5.61982695440817e+28*cos(theta)**27 - 5.91472042278042e+27*cos(theta)**25 + 5.23426586086762e+26*cos(theta)**23 - 3.84850119964984e+25*cos(theta)**21 + 2.31704487364239e+24*cos(theta)**19 - 1.12210329479708e+23*cos(theta)**17 + 4.27467921827459e+21*cos(theta)**15 - 1.24505219949745e+20*cos(theta)**13 + 2.67090405832787e+18*cos(theta)**11 - 4.01036645394575e+16*cos(theta)**9 + 391679849001755.0*cos(theta)**7 - 2220047727135.46*cos(theta)**5 + 5967870234.2351*cos(theta)**3 - 4798609.14036593*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl86_m_minus_2(theta, phi):
    return 0.000701412443903169*(1.0 - cos(theta)**2)*(3.43590860948561e+28*cos(theta)**84 - 7.00443123547768e+29*cos(theta)**82 + 6.88216453639685e+30*cos(theta)**80 - 4.34084629441398e+31*cos(theta)**78 + 1.97508506395836e+32*cos(theta)**76 - 6.90673918071329e+32*cos(theta)**74 + 1.93117003386197e+33*cos(theta)**72 - 4.43492417479891e+33*cos(theta)**70 + 8.52734226284982e+33*cos(theta)**68 - 1.39249359675784e+34*cos(theta)**66 + 1.95222141506246e+34*cos(theta)**64 - 2.36946319853457e+34*cos(theta)**62 + 2.50595912104523e+34*cos(theta)**60 - 2.32106103833075e+34*cos(theta)**58 + 1.8900068454979e+34*cos(theta)**56 - 1.35692799163952e+34*cos(theta)**54 + 8.60710973420278e+33*cos(theta)**52 - 4.8298889155958e+33*cos(theta)**50 + 2.39927571841235e+33*cos(theta)**48 - 1.05512008201526e+33*cos(theta)**46 + 4.10544843942026e+32*cos(theta)**44 - 1.41176089556218e+32*cos(theta)**42 + 4.28303781211783e+31*cos(theta)**40 - 1.14370746095581e+31*cos(theta)**38 + 2.68008781683977e+30*cos(theta)**36 - 5.4909116247449e+29*cos(theta)**34 + 9.79148576440524e+28*cos(theta)**32 - 1.51153966359944e+28*cos(theta)**30 + 2.00708105514578e+27*cos(theta)**28 - 2.27489247030016e+26*cos(theta)**26 + 2.18094410869484e+25*cos(theta)**24 - 1.74931872711356e+24*cos(theta)**22 + 1.1585224368212e+23*cos(theta)**20 - 6.23390719331711e+21*cos(theta)**18 + 2.67167451142162e+20*cos(theta)**16 - 8.89322999641038e+18*cos(theta)**14 + 2.22575338193989e+17*cos(theta)**12 - 4.01036645394575e+15*cos(theta)**10 + 48959981125219.4*cos(theta)**8 - 370007954522.576*cos(theta)**6 + 1491967558.55877*cos(theta)**4 - 2399304.57018296*cos(theta)**2 + 641.868531349108)*sin(2*phi)

#@torch.jit.script
def Yl86_m_minus_1(theta, phi):
    return 0.0606630532955388*(1.0 - cos(theta)**2)**0.5*(4.04224542292424e+26*cos(theta)**85 - 8.43907377768395e+27*cos(theta)**83 + 8.49649942765044e+28*cos(theta)**81 - 5.49474214482783e+29*cos(theta)**79 + 2.56504553760826e+30*cos(theta)**77 - 9.20898557428439e+30*cos(theta)**75 + 2.64543840255064e+31*cos(theta)**73 - 6.24637207718156e+31*cos(theta)**71 + 1.23584670476084e+32*cos(theta)**69 - 2.07834865187737e+32*cos(theta)**67 + 3.00341756163456e+32*cos(theta)**65 - 3.76105269608662e+32*cos(theta)**63 + 4.10812970663153e+32*cos(theta)**61 - 3.93400175988263e+32*cos(theta)**59 + 3.31580148332964e+32*cos(theta)**57 - 2.46714180298094e+32*cos(theta)**55 + 1.62398296871751e+32*cos(theta)**53 - 9.47037042273687e+31*cos(theta)**51 + 4.89648105798439e+31*cos(theta)**49 - 2.24493634471331e+31*cos(theta)**47 + 9.12321875426725e+30*cos(theta)**45 - 3.28316487340043e+30*cos(theta)**43 + 1.04464336880923e+30*cos(theta)**41 - 2.93258323322002e+29*cos(theta)**39 + 7.24348058605344e+28*cos(theta)**37 - 1.56883189278426e+28*cos(theta)**35 + 2.96711689830462e+27*cos(theta)**33 - 4.87593439870787e+26*cos(theta)**31 + 6.92096915567509e+25*cos(theta)**29 - 8.42552766777837e+24*cos(theta)**27 + 8.72377643477937e+23*cos(theta)**25 - 7.60573359614592e+22*cos(theta)**23 + 5.51677350867236e+21*cos(theta)**21 - 3.28100378595637e+20*cos(theta)**19 + 1.57157324201272e+19*cos(theta)**17 - 5.92881999760692e+17*cos(theta)**15 + 1.71211798610761e+16*cos(theta)**13 - 364578768540523.0*cos(theta)**11 + 5439997902802.16*cos(theta)**9 - 52858279217.5108*cos(theta)**7 + 298393511.711755*cos(theta)**5 - 799768.190060988*cos(theta)**3 + 641.868531349108*cos(theta))*sin(phi)

#@torch.jit.script
def Yl86_m0(theta, phi):
    return 5.47888543051991e+25*cos(theta)**86 - 1.17107171044154e+27*cos(theta)**84 + 1.20779762798793e+28*cos(theta)**82 - 8.00617948612357e+28*cos(theta)**80 + 3.83326169335613e+29*cos(theta)**78 - 1.41242759081576e+30*cos(theta)**76 + 4.16710003501545e+30*cos(theta)**74 - 1.01126120346601e+31*cos(theta)**72 + 2.05794875482415e+31*cos(theta)**70 - 3.56268547878159e+31*cos(theta)**68 + 5.3044428239637e+31*cos(theta)**66 - 6.85010828260213e+31*cos(theta)**64 + 7.72361202333663e+31*cos(theta)**62 - 7.64277882581348e+31*cos(theta)**60 + 6.66390074960092e+31*cos(theta)**58 - 5.13539764060155e+31*cos(theta)**56 + 3.50554626175815e+31*cos(theta)**54 - 2.12291015682434e+31*cos(theta)**52 + 1.14151616705153e+31*cos(theta)**50 - 5.45168539819931e+30*cos(theta)**48 + 2.31184252976272e+30*cos(theta)**46 - 8.69777178591207e+29*cos(theta)**44 + 2.89925726197069e+29*cos(theta)**42 - 8.54591065579173e+28*cos(theta)**40 + 2.22193677050585e+28*cos(theta)**38 - 5.07974487696134e+27*cos(theta)**36 + 1.01724070962671e+27*cos(theta)**34 - 1.7761345723641e+26*cos(theta)**32 + 2.68914147708363e+25*cos(theta)**30 - 3.5075758396743e+24*cos(theta)**28 + 3.91110226370762e+23*cos(theta)**26 - 3.6940082409328e+22*cos(theta)**24 + 2.92301110807756e+21*cos(theta)**22 - 1.91225025762083e+20*cos(theta)**20 + 1.01772422674498e+19*cos(theta)**18 - 4.3193288957554e+17*cos(theta)**16 + 1.42552108770805e+16*cos(theta)**14 - 354142557961870.0*cos(theta)**12 + 6341130989007.97*cos(theta)**10 - 77017785291.5948*cos(theta)**8 + 579703760.259316*cos(theta)**6 - 2330623.53360754*cos(theta)**4 + 3740.96875378418*cos(theta)**2 - 0.999991647630093

#@torch.jit.script
def Yl86_m1(theta, phi):
    return 0.0606630532955388*(1.0 - cos(theta)**2)**0.5*(4.04224542292424e+26*cos(theta)**85 - 8.43907377768395e+27*cos(theta)**83 + 8.49649942765044e+28*cos(theta)**81 - 5.49474214482783e+29*cos(theta)**79 + 2.56504553760826e+30*cos(theta)**77 - 9.20898557428439e+30*cos(theta)**75 + 2.64543840255064e+31*cos(theta)**73 - 6.24637207718156e+31*cos(theta)**71 + 1.23584670476084e+32*cos(theta)**69 - 2.07834865187737e+32*cos(theta)**67 + 3.00341756163456e+32*cos(theta)**65 - 3.76105269608662e+32*cos(theta)**63 + 4.10812970663153e+32*cos(theta)**61 - 3.93400175988263e+32*cos(theta)**59 + 3.31580148332964e+32*cos(theta)**57 - 2.46714180298094e+32*cos(theta)**55 + 1.62398296871751e+32*cos(theta)**53 - 9.47037042273687e+31*cos(theta)**51 + 4.89648105798439e+31*cos(theta)**49 - 2.24493634471331e+31*cos(theta)**47 + 9.12321875426725e+30*cos(theta)**45 - 3.28316487340043e+30*cos(theta)**43 + 1.04464336880923e+30*cos(theta)**41 - 2.93258323322002e+29*cos(theta)**39 + 7.24348058605344e+28*cos(theta)**37 - 1.56883189278426e+28*cos(theta)**35 + 2.96711689830462e+27*cos(theta)**33 - 4.87593439870787e+26*cos(theta)**31 + 6.92096915567509e+25*cos(theta)**29 - 8.42552766777837e+24*cos(theta)**27 + 8.72377643477937e+23*cos(theta)**25 - 7.60573359614592e+22*cos(theta)**23 + 5.51677350867236e+21*cos(theta)**21 - 3.28100378595637e+20*cos(theta)**19 + 1.57157324201272e+19*cos(theta)**17 - 5.92881999760692e+17*cos(theta)**15 + 1.71211798610761e+16*cos(theta)**13 - 364578768540523.0*cos(theta)**11 + 5439997902802.16*cos(theta)**9 - 52858279217.5108*cos(theta)**7 + 298393511.711755*cos(theta)**5 - 799768.190060988*cos(theta)**3 + 641.868531349108*cos(theta))*cos(phi)

#@torch.jit.script
def Yl86_m2(theta, phi):
    return 0.000701412443903169*(1.0 - cos(theta)**2)*(3.43590860948561e+28*cos(theta)**84 - 7.00443123547768e+29*cos(theta)**82 + 6.88216453639685e+30*cos(theta)**80 - 4.34084629441398e+31*cos(theta)**78 + 1.97508506395836e+32*cos(theta)**76 - 6.90673918071329e+32*cos(theta)**74 + 1.93117003386197e+33*cos(theta)**72 - 4.43492417479891e+33*cos(theta)**70 + 8.52734226284982e+33*cos(theta)**68 - 1.39249359675784e+34*cos(theta)**66 + 1.95222141506246e+34*cos(theta)**64 - 2.36946319853457e+34*cos(theta)**62 + 2.50595912104523e+34*cos(theta)**60 - 2.32106103833075e+34*cos(theta)**58 + 1.8900068454979e+34*cos(theta)**56 - 1.35692799163952e+34*cos(theta)**54 + 8.60710973420278e+33*cos(theta)**52 - 4.8298889155958e+33*cos(theta)**50 + 2.39927571841235e+33*cos(theta)**48 - 1.05512008201526e+33*cos(theta)**46 + 4.10544843942026e+32*cos(theta)**44 - 1.41176089556218e+32*cos(theta)**42 + 4.28303781211783e+31*cos(theta)**40 - 1.14370746095581e+31*cos(theta)**38 + 2.68008781683977e+30*cos(theta)**36 - 5.4909116247449e+29*cos(theta)**34 + 9.79148576440524e+28*cos(theta)**32 - 1.51153966359944e+28*cos(theta)**30 + 2.00708105514578e+27*cos(theta)**28 - 2.27489247030016e+26*cos(theta)**26 + 2.18094410869484e+25*cos(theta)**24 - 1.74931872711356e+24*cos(theta)**22 + 1.1585224368212e+23*cos(theta)**20 - 6.23390719331711e+21*cos(theta)**18 + 2.67167451142162e+20*cos(theta)**16 - 8.89322999641038e+18*cos(theta)**14 + 2.22575338193989e+17*cos(theta)**12 - 4.01036645394575e+15*cos(theta)**10 + 48959981125219.4*cos(theta)**8 - 370007954522.576*cos(theta)**6 + 1491967558.55877*cos(theta)**4 - 2399304.57018296*cos(theta)**2 + 641.868531349108)*cos(2*phi)

#@torch.jit.script
def Yl86_m3(theta, phi):
    return 8.11220319138235e-6*(1.0 - cos(theta)**2)**1.5*(2.88616323196791e+30*cos(theta)**83 - 5.74363361309169e+31*cos(theta)**81 + 5.50573162911748e+32*cos(theta)**79 - 3.38586010964291e+33*cos(theta)**77 + 1.50106464860836e+34*cos(theta)**75 - 5.11098699372784e+34*cos(theta)**73 + 1.39044242438062e+35*cos(theta)**71 - 3.10444692235924e+35*cos(theta)**69 + 5.79859273873788e+35*cos(theta)**67 - 9.19045773860175e+35*cos(theta)**65 + 1.24942170563998e+36*cos(theta)**63 - 1.46906718309144e+36*cos(theta)**61 + 1.50357547262714e+36*cos(theta)**59 - 1.34621540223184e+36*cos(theta)**57 + 1.05840383347882e+36*cos(theta)**55 - 7.32741115485338e+35*cos(theta)**53 + 4.47569706178544e+35*cos(theta)**51 - 2.4149444577979e+35*cos(theta)**49 + 1.15165234483793e+35*cos(theta)**47 - 4.85355237727018e+34*cos(theta)**45 + 1.80639731334492e+34*cos(theta)**43 - 5.92939576136118e+33*cos(theta)**41 + 1.71321512484713e+33*cos(theta)**39 - 4.34608835163206e+32*cos(theta)**37 + 9.64831614062318e+31*cos(theta)**35 - 1.86690995241327e+31*cos(theta)**33 + 3.13327544460968e+30*cos(theta)**31 - 4.53461899079832e+29*cos(theta)**29 + 5.61982695440817e+28*cos(theta)**27 - 5.91472042278042e+27*cos(theta)**25 + 5.23426586086762e+26*cos(theta)**23 - 3.84850119964984e+25*cos(theta)**21 + 2.31704487364239e+24*cos(theta)**19 - 1.12210329479708e+23*cos(theta)**17 + 4.27467921827459e+21*cos(theta)**15 - 1.24505219949745e+20*cos(theta)**13 + 2.67090405832787e+18*cos(theta)**11 - 4.01036645394575e+16*cos(theta)**9 + 391679849001755.0*cos(theta)**7 - 2220047727135.46*cos(theta)**5 + 5967870234.2351*cos(theta)**3 - 4798609.14036593*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl86_m4(theta, phi):
    return 9.38595611430988e-8*(1.0 - cos(theta)**2)**2*(2.39551548253337e+32*cos(theta)**82 - 4.65234322660427e+33*cos(theta)**80 + 4.34952798700281e+34*cos(theta)**78 - 2.60711228442504e+35*cos(theta)**76 + 1.12579848645627e+36*cos(theta)**74 - 3.73102050542132e+36*cos(theta)**72 + 9.87214121310238e+36*cos(theta)**70 - 2.14206837642787e+37*cos(theta)**68 + 3.88505713495438e+37*cos(theta)**66 - 5.97379753009114e+37*cos(theta)**64 + 7.87135674553185e+37*cos(theta)**62 - 8.96130981685775e+37*cos(theta)**60 + 8.87109528850013e+37*cos(theta)**58 - 7.67342779272146e+37*cos(theta)**56 + 5.82122108413352e+37*cos(theta)**54 - 3.88352791207229e+37*cos(theta)**52 + 2.28260550151058e+37*cos(theta)**50 - 1.18332278432097e+37*cos(theta)**48 + 5.41276602073827e+36*cos(theta)**46 - 2.18409856977158e+36*cos(theta)**44 + 7.76750844738314e+35*cos(theta)**42 - 2.43105226215808e+35*cos(theta)**40 + 6.68153898690382e+34*cos(theta)**38 - 1.60805269010386e+34*cos(theta)**36 + 3.37691064921811e+33*cos(theta)**34 - 6.16080284296378e+32*cos(theta)**32 + 9.71315387829e+31*cos(theta)**30 - 1.31503950733151e+31*cos(theta)**28 + 1.51735327769021e+30*cos(theta)**26 - 1.4786801056951e+29*cos(theta)**24 + 1.20388114799955e+28*cos(theta)**22 - 8.08185251926466e+26*cos(theta)**20 + 4.40238525992054e+25*cos(theta)**18 - 1.90757560115504e+24*cos(theta)**16 + 6.41201882741188e+22*cos(theta)**14 - 1.61856785934669e+21*cos(theta)**12 + 2.93799446416066e+19*cos(theta)**10 - 3.60932980855118e+17*cos(theta)**8 + 2.74175894301229e+15*cos(theta)**6 - 11100238635677.3*cos(theta)**4 + 17903610702.7053*cos(theta)**2 - 4798609.14036593)*cos(4*phi)

#@torch.jit.script
def Yl86_m5(theta, phi):
    return 1.0865529541455e-9*(1.0 - cos(theta)**2)**2.5*(1.96432269567736e+34*cos(theta)**81 - 3.72187458128342e+35*cos(theta)**79 + 3.39263182986219e+36*cos(theta)**77 - 1.98140533616303e+37*cos(theta)**75 + 8.33090879977637e+37*cos(theta)**73 - 2.68633476390335e+38*cos(theta)**71 + 6.91049884917166e+38*cos(theta)**69 - 1.45660649597095e+39*cos(theta)**67 + 2.56413770906989e+39*cos(theta)**65 - 3.82323041925833e+39*cos(theta)**63 + 4.88024118222975e+39*cos(theta)**61 - 5.37678589011465e+39*cos(theta)**59 + 5.14523526733007e+39*cos(theta)**57 - 4.29711956392402e+39*cos(theta)**55 + 3.1434593854321e+39*cos(theta)**53 - 2.01943451427759e+39*cos(theta)**51 + 1.14130275075529e+39*cos(theta)**49 - 5.67994936474067e+38*cos(theta)**47 + 2.4898723695396e+38*cos(theta)**45 - 9.61003370699495e+37*cos(theta)**43 + 3.26235354790092e+37*cos(theta)**41 - 9.72420904863233e+36*cos(theta)**39 + 2.53898481502345e+36*cos(theta)**37 - 5.78898968437391e+35*cos(theta)**35 + 1.14814962073416e+35*cos(theta)**33 - 1.97145690974841e+34*cos(theta)**31 + 2.913946163487e+33*cos(theta)**29 - 3.68211062052823e+32*cos(theta)**27 + 3.94511852199454e+31*cos(theta)**25 - 3.54883225366825e+30*cos(theta)**23 + 2.64853852559902e+29*cos(theta)**21 - 1.61637050385293e+28*cos(theta)**19 + 7.92429346785698e+26*cos(theta)**17 - 3.05212096184806e+25*cos(theta)**15 + 8.97682635837664e+23*cos(theta)**13 - 1.94228143121603e+22*cos(theta)**11 + 2.93799446416066e+20*cos(theta)**9 - 2.88746384684094e+18*cos(theta)**7 + 1.64505536580737e+16*cos(theta)**5 - 44400954542709.1*cos(theta)**3 + 35807221405.4106*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl86_m6(theta, phi):
    return 1.25867751430906e-11*(1.0 - cos(theta)**2)**3*(1.59110138349866e+36*cos(theta)**80 - 2.9402809192139e+37*cos(theta)**78 + 2.61232650899389e+38*cos(theta)**76 - 1.48605400212227e+39*cos(theta)**74 + 6.08156342383675e+39*cos(theta)**72 - 1.90729768237138e+40*cos(theta)**70 + 4.76824420592845e+40*cos(theta)**68 - 9.75926352300539e+40*cos(theta)**66 + 1.66668951089543e+41*cos(theta)**64 - 2.40863516413275e+41*cos(theta)**62 + 2.97694712116015e+41*cos(theta)**60 - 3.17230367516765e+41*cos(theta)**58 + 2.93278410237814e+41*cos(theta)**56 - 2.36341576015821e+41*cos(theta)**54 + 1.66603347427901e+41*cos(theta)**52 - 1.02991160228157e+41*cos(theta)**50 + 5.59238347870091e+40*cos(theta)**48 - 2.66957620142811e+40*cos(theta)**46 + 1.12044256629282e+40*cos(theta)**44 - 4.13231449400783e+39*cos(theta)**42 + 1.33756495463938e+39*cos(theta)**40 - 3.79244152896661e+38*cos(theta)**38 + 9.39424381558677e+37*cos(theta)**36 - 2.02614638953087e+37*cos(theta)**34 + 3.78889374842272e+36*cos(theta)**32 - 6.11151642022007e+35*cos(theta)**30 + 8.4504438741123e+34*cos(theta)**28 - 9.94169867542623e+33*cos(theta)**26 + 9.86279630498634e+32*cos(theta)**24 - 8.16231418343697e+31*cos(theta)**22 + 5.56193090375794e+30*cos(theta)**20 - 3.07110395732057e+29*cos(theta)**18 + 1.34712988953569e+28*cos(theta)**16 - 4.57818144277208e+26*cos(theta)**14 + 1.16698742658896e+25*cos(theta)**12 - 2.13650957433763e+23*cos(theta)**10 + 2.64419501774459e+21*cos(theta)**8 - 2.02122469278866e+19*cos(theta)**6 + 8.22527682903686e+16*cos(theta)**4 - 133202863628127.0*cos(theta)**2 + 35807221405.4106)*cos(6*phi)

#@torch.jit.script
def Yl86_m7(theta, phi):
    return 1.4592443015096e-13*(1.0 - cos(theta)**2)**3.5*(1.27288110679893e+38*cos(theta)**79 - 2.29341911698684e+39*cos(theta)**77 + 1.98536814683536e+40*cos(theta)**75 - 1.09967996157048e+41*cos(theta)**73 + 4.37872566516246e+41*cos(theta)**71 - 1.33510837765997e+42*cos(theta)**69 + 3.24240606003134e+42*cos(theta)**67 - 6.44111392518356e+42*cos(theta)**65 + 1.06668128697307e+43*cos(theta)**63 - 1.4933538017623e+43*cos(theta)**61 + 1.78616827269609e+43*cos(theta)**59 - 1.83993613159723e+43*cos(theta)**57 + 1.64235909733176e+43*cos(theta)**55 - 1.27624451048543e+43*cos(theta)**53 + 8.66337406625087e+42*cos(theta)**51 - 5.14955801140786e+42*cos(theta)**49 + 2.68434406977644e+42*cos(theta)**47 - 1.22800505265693e+42*cos(theta)**45 + 4.92994729168841e+41*cos(theta)**43 - 1.73557208748329e+41*cos(theta)**41 + 5.35025981855751e+40*cos(theta)**39 - 1.44112778100731e+40*cos(theta)**37 + 3.38192777361124e+39*cos(theta)**35 - 6.88889772440495e+38*cos(theta)**33 + 1.21244599949527e+38*cos(theta)**31 - 1.83345492606602e+37*cos(theta)**29 + 2.36612428475144e+36*cos(theta)**27 - 2.58484165561082e+35*cos(theta)**25 + 2.36707111319672e+34*cos(theta)**23 - 1.79570912035613e+33*cos(theta)**21 + 1.11238618075159e+32*cos(theta)**19 - 5.52798712317703e+30*cos(theta)**17 + 2.1554078232571e+29*cos(theta)**15 - 6.40945401988092e+27*cos(theta)**13 + 1.40038491190676e+26*cos(theta)**11 - 2.13650957433763e+24*cos(theta)**9 + 2.11535601419567e+22*cos(theta)**7 - 1.21273481567319e+20*cos(theta)**5 + 3.29011073161474e+17*cos(theta)**3 - 266405727256255.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl86_m8(theta, phi):
    return 1.69336482236135e-15*(1.0 - cos(theta)**2)**4*(1.00557607437115e+40*cos(theta)**78 - 1.76593272007987e+41*cos(theta)**76 + 1.48902611012652e+42*cos(theta)**74 - 8.02766371946451e+42*cos(theta)**72 + 3.10889522226535e+43*cos(theta)**70 - 9.21224780585376e+43*cos(theta)**68 + 2.172412060221e+44*cos(theta)**66 - 4.18672405136931e+44*cos(theta)**64 + 6.72009210793036e+44*cos(theta)**62 - 9.10945819075005e+44*cos(theta)**60 + 1.05383928089069e+45*cos(theta)**58 - 1.04876359501042e+45*cos(theta)**56 + 9.03297503532468e+44*cos(theta)**54 - 6.7640959055728e+44*cos(theta)**52 + 4.41832077378794e+44*cos(theta)**50 - 2.52328342558985e+44*cos(theta)**48 + 1.26164171279493e+44*cos(theta)**46 - 5.52602273695619e+43*cos(theta)**44 + 2.11987733542602e+43*cos(theta)**42 - 7.11584555868148e+42*cos(theta)**40 + 2.08660132923743e+42*cos(theta)**38 - 5.33217278972705e+41*cos(theta)**36 + 1.18367472076393e+41*cos(theta)**34 - 2.27333624905363e+40*cos(theta)**32 + 3.75858259843534e+39*cos(theta)**30 - 5.31701928559146e+38*cos(theta)**28 + 6.3885355688289e+37*cos(theta)**26 - 6.46210413902705e+36*cos(theta)**24 + 5.44426356035246e+35*cos(theta)**22 - 3.77098915274788e+34*cos(theta)**20 + 2.11353374342802e+33*cos(theta)**18 - 9.39757810940095e+31*cos(theta)**16 + 3.23311173488565e+30*cos(theta)**14 - 8.33229022584519e+28*cos(theta)**12 + 1.54042340309743e+27*cos(theta)**10 - 1.92285861690387e+25*cos(theta)**8 + 1.48074920993697e+23*cos(theta)**6 - 6.06367407836597e+20*cos(theta)**4 + 9.87033219484423e+17*cos(theta)**2 - 266405727256255.0)*cos(8*phi)

#@torch.jit.script
def Yl86_m9(theta, phi):
    return 1.96716790255173e-17*(1.0 - cos(theta)**2)**4.5*(7.843493380095e+41*cos(theta)**77 - 1.3421088672607e+43*cos(theta)**75 + 1.10187932149362e+44*cos(theta)**73 - 5.77991787801445e+44*cos(theta)**71 + 2.17622665558574e+45*cos(theta)**69 - 6.26432850798056e+45*cos(theta)**67 + 1.43379195974586e+46*cos(theta)**65 - 2.67950339287636e+46*cos(theta)**63 + 4.16645710691683e+46*cos(theta)**61 - 5.46567491445003e+46*cos(theta)**59 + 6.11226782916601e+46*cos(theta)**57 - 5.87307613205837e+46*cos(theta)**55 + 4.87780651907533e+46*cos(theta)**53 - 3.51732987089785e+46*cos(theta)**51 + 2.20916038689397e+46*cos(theta)**49 - 1.21117604428313e+46*cos(theta)**47 + 5.80355187885666e+45*cos(theta)**45 - 2.43145000426072e+45*cos(theta)**43 + 8.90348480878927e+44*cos(theta)**41 - 2.84633822347259e+44*cos(theta)**39 + 7.92908505110223e+43*cos(theta)**37 - 1.91958220430174e+43*cos(theta)**35 + 4.02449405059737e+42*cos(theta)**33 - 7.27467599697163e+41*cos(theta)**31 + 1.1275747795306e+41*cos(theta)**29 - 1.48876539996561e+40*cos(theta)**27 + 1.66101924789551e+39*cos(theta)**25 - 1.55090499336649e+38*cos(theta)**23 + 1.19773798327754e+37*cos(theta)**21 - 7.54197830549576e+35*cos(theta)**19 + 3.80436073817043e+34*cos(theta)**17 - 1.50361249750415e+33*cos(theta)**15 + 4.5263564288399e+31*cos(theta)**13 - 9.99874827101423e+29*cos(theta)**11 + 1.54042340309743e+28*cos(theta)**9 - 1.53828689352309e+26*cos(theta)**7 + 8.88449525962183e+23*cos(theta)**5 - 2.42546963134639e+21*cos(theta)**3 + 1.97406643896885e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl86_m10(theta, phi):
    return 2.28802334065883e-19*(1.0 - cos(theta)**2)**5*(6.03948990267315e+43*cos(theta)**76 - 1.00658165044553e+45*cos(theta)**74 + 8.04371904690344e+45*cos(theta)**72 - 4.10374169339026e+46*cos(theta)**70 + 1.50159639235416e+47*cos(theta)**68 - 4.19710010034697e+47*cos(theta)**66 + 9.31964773834809e+47*cos(theta)**64 - 1.68808713751211e+48*cos(theta)**62 + 2.54153883521926e+48*cos(theta)**60 - 3.22474819952552e+48*cos(theta)**58 + 3.48399266262463e+48*cos(theta)**56 - 3.2301918726321e+48*cos(theta)**54 + 2.58523745510992e+48*cos(theta)**52 - 1.79383823415791e+48*cos(theta)**50 + 1.08248858957805e+48*cos(theta)**48 - 5.69252740813071e+47*cos(theta)**46 + 2.6115983454855e+47*cos(theta)**44 - 1.04552350183211e+47*cos(theta)**42 + 3.6504287716036e+46*cos(theta)**40 - 1.11007190715431e+46*cos(theta)**38 + 2.93376146890782e+45*cos(theta)**36 - 6.71853771505608e+44*cos(theta)**34 + 1.32808303669713e+44*cos(theta)**32 - 2.2551495590612e+43*cos(theta)**30 + 3.26996686063875e+42*cos(theta)**28 - 4.01966657990714e+41*cos(theta)**26 + 4.15254811973878e+40*cos(theta)**24 - 3.56708148474293e+39*cos(theta)**22 + 2.51524976488284e+38*cos(theta)**20 - 1.4329758780442e+37*cos(theta)**18 + 6.46741325488973e+35*cos(theta)**16 - 2.25541874625623e+34*cos(theta)**14 + 5.88426335749188e+32*cos(theta)**12 - 1.09986230981157e+31*cos(theta)**10 + 1.38638106278769e+29*cos(theta)**8 - 1.07680082546617e+27*cos(theta)**6 + 4.44224762981091e+24*cos(theta)**4 - 7.27640889403917e+21*cos(theta)**2 + 1.97406643896885e+18)*cos(10*phi)

#@torch.jit.script
def Yl86_m11(theta, phi):
    return 2.66481943578521e-21*(1.0 - cos(theta)**2)**5.5*(4.59001232603159e+45*cos(theta)**75 - 7.44870421329689e+46*cos(theta)**73 + 5.79147771377048e+47*cos(theta)**71 - 2.87261918537318e+48*cos(theta)**69 + 1.02108554680083e+49*cos(theta)**67 - 2.770086066229e+49*cos(theta)**65 + 5.96457455254278e+49*cos(theta)**63 - 1.04661402525751e+50*cos(theta)**61 + 1.52492330113156e+50*cos(theta)**59 - 1.8703539557248e+50*cos(theta)**57 + 1.95103589106979e+50*cos(theta)**55 - 1.74430361122134e+50*cos(theta)**53 + 1.34432347665716e+50*cos(theta)**51 - 8.96919117078953e+49*cos(theta)**49 + 5.19594522997462e+49*cos(theta)**47 - 2.61856260774012e+49*cos(theta)**45 + 1.14910327201362e+49*cos(theta)**43 - 4.39119870769487e+48*cos(theta)**41 + 1.46017150864144e+48*cos(theta)**39 - 4.21827324718638e+47*cos(theta)**37 + 1.05615412880682e+47*cos(theta)**35 - 2.28430282311907e+46*cos(theta)**33 + 4.24986571743083e+45*cos(theta)**31 - 6.76544867718361e+44*cos(theta)**29 + 9.15590720978849e+43*cos(theta)**27 - 1.04511331077586e+43*cos(theta)**25 + 9.96611548737308e+41*cos(theta)**23 - 7.84757926643445e+40*cos(theta)**21 + 5.03049952976567e+39*cos(theta)**19 - 2.57935658047955e+38*cos(theta)**17 + 1.03478612078236e+37*cos(theta)**15 - 3.15758624475872e+35*cos(theta)**13 + 7.06111602899025e+33*cos(theta)**11 - 1.09986230981157e+32*cos(theta)**9 + 1.10910485023015e+30*cos(theta)**7 - 6.46080495279699e+27*cos(theta)**5 + 1.77689905192437e+25*cos(theta)**3 - 1.45528177880783e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl86_m12(theta, phi):
    return 3.10830851158339e-23*(1.0 - cos(theta)**2)**6*(3.4425092445237e+47*cos(theta)**74 - 5.43755407570673e+48*cos(theta)**72 + 4.11194917677704e+49*cos(theta)**70 - 1.98210723790749e+50*cos(theta)**68 + 6.84127316356557e+50*cos(theta)**66 - 1.80055594304885e+51*cos(theta)**64 + 3.75768196810195e+51*cos(theta)**62 - 6.38434555407079e+51*cos(theta)**60 + 8.99704747667619e+51*cos(theta)**58 - 1.06610175476314e+52*cos(theta)**56 + 1.07306974008839e+52*cos(theta)**54 - 9.24480913947308e+51*cos(theta)**52 + 6.85604973095152e+51*cos(theta)**50 - 4.39490367368687e+51*cos(theta)**48 + 2.44209425808807e+51*cos(theta)**46 - 1.17835317348306e+51*cos(theta)**44 + 4.94114406965856e+50*cos(theta)**42 - 1.8003914701549e+50*cos(theta)**40 + 5.69466888370162e+49*cos(theta)**38 - 1.56076110145896e+49*cos(theta)**36 + 3.69653945082386e+48*cos(theta)**34 - 7.53819931629293e+47*cos(theta)**32 + 1.31745837240356e+47*cos(theta)**30 - 1.96198011638325e+46*cos(theta)**28 + 2.47209494664289e+45*cos(theta)**26 - 2.61278327693964e+44*cos(theta)**24 + 2.29220656209581e+43*cos(theta)**22 - 1.64799164595123e+42*cos(theta)**20 + 9.55794910655478e+40*cos(theta)**18 - 4.38490618681524e+39*cos(theta)**16 + 1.55217918117354e+38*cos(theta)**14 - 4.10486211818633e+36*cos(theta)**12 + 7.76722763188928e+34*cos(theta)**10 - 9.89876078830409e+32*cos(theta)**8 + 7.76373395161105e+30*cos(theta)**6 - 3.2304024763985e+28*cos(theta)**4 + 5.3306971557731e+25*cos(theta)**2 - 1.45528177880783e+22)*cos(12*phi)

#@torch.jit.script
def Yl86_m13(theta, phi):
    return 3.63153856504587e-25*(1.0 - cos(theta)**2)**6.5*(2.54745684094753e+49*cos(theta)**73 - 3.91503893450884e+50*cos(theta)**71 + 2.87836442374393e+51*cos(theta)**69 - 1.3478329217771e+52*cos(theta)**67 + 4.51524028795327e+52*cos(theta)**65 - 1.15235580355126e+53*cos(theta)**63 + 2.32976282022321e+53*cos(theta)**61 - 3.83060733244247e+53*cos(theta)**59 + 5.21828753647219e+53*cos(theta)**57 - 5.97016982667356e+53*cos(theta)**55 + 5.79457659647728e+53*cos(theta)**53 - 4.807300752526e+53*cos(theta)**51 + 3.42802486547576e+53*cos(theta)**49 - 2.1095537633697e+53*cos(theta)**47 + 1.12336335872051e+53*cos(theta)**45 - 5.18475396332545e+52*cos(theta)**43 + 2.0752805092566e+52*cos(theta)**41 - 7.20156588061959e+51*cos(theta)**39 + 2.16397417580661e+51*cos(theta)**37 - 5.61873996525226e+50*cos(theta)**35 + 1.25682341328011e+50*cos(theta)**33 - 2.41222378121374e+49*cos(theta)**31 + 3.95237511721067e+48*cos(theta)**29 - 5.49354432587309e+47*cos(theta)**27 + 6.42744686127152e+46*cos(theta)**25 - 6.27067986465514e+45*cos(theta)**23 + 5.04285443661078e+44*cos(theta)**21 - 3.29598329190247e+43*cos(theta)**19 + 1.72043083917986e+42*cos(theta)**17 - 7.01584989890438e+40*cos(theta)**15 + 2.17305085364295e+39*cos(theta)**13 - 4.9258345418236e+37*cos(theta)**11 + 7.76722763188928e+35*cos(theta)**9 - 7.91900863064327e+33*cos(theta)**7 + 4.65824037096663e+31*cos(theta)**5 - 1.2921609905594e+29*cos(theta)**3 + 1.06613943115462e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl86_m14(theta, phi):
    return 4.25039439739959e-27*(1.0 - cos(theta)**2)**7*(1.8596434938917e+51*cos(theta)**72 - 2.77967764350128e+52*cos(theta)**70 + 1.98607145238331e+53*cos(theta)**68 - 9.03048057590655e+53*cos(theta)**66 + 2.93490618716963e+54*cos(theta)**64 - 7.25984156237297e+54*cos(theta)**62 + 1.42115532033616e+55*cos(theta)**60 - 2.26005832614106e+55*cos(theta)**58 + 2.97442389578915e+55*cos(theta)**56 - 3.28359340467046e+55*cos(theta)**54 + 3.07112559613296e+55*cos(theta)**52 - 2.45172338378826e+55*cos(theta)**50 + 1.67973218408312e+55*cos(theta)**48 - 9.91490268783758e+54*cos(theta)**46 + 5.05513511424231e+54*cos(theta)**44 - 2.22944420422994e+54*cos(theta)**42 + 8.50865008795204e+53*cos(theta)**40 - 2.80861069344164e+53*cos(theta)**38 + 8.00670445048448e+52*cos(theta)**36 - 1.96655898783829e+52*cos(theta)**34 + 4.14751726382437e+51*cos(theta)**32 - 7.47789372176258e+50*cos(theta)**30 + 1.14618878399109e+50*cos(theta)**28 - 1.48325696798574e+49*cos(theta)**26 + 1.60686171531788e+48*cos(theta)**24 - 1.44225636887068e+47*cos(theta)**22 + 1.05899943168826e+46*cos(theta)**20 - 6.26236825461469e+44*cos(theta)**18 + 2.92473242660576e+43*cos(theta)**16 - 1.05237748483566e+42*cos(theta)**14 + 2.82496610973583e+40*cos(theta)**12 - 5.41841799600596e+38*cos(theta)**10 + 6.99050486870035e+36*cos(theta)**8 - 5.54330604145029e+34*cos(theta)**6 + 2.32912018548332e+32*cos(theta)**4 - 3.87648297167819e+29*cos(theta)**2 + 1.06613943115462e+26)*cos(14*phi)

#@torch.jit.script
def Yl86_m15(theta, phi):
    return 4.98427843690956e-29*(1.0 - cos(theta)**2)**7.5*(1.33894331560202e+53*cos(theta)**71 - 1.94577435045089e+54*cos(theta)**69 + 1.35052858762065e+55*cos(theta)**67 - 5.96011718009832e+55*cos(theta)**65 + 1.87833995978856e+56*cos(theta)**63 - 4.50110176867124e+56*cos(theta)**61 + 8.52693192201695e+56*cos(theta)**59 - 1.31083382916181e+57*cos(theta)**57 + 1.66567738164192e+57*cos(theta)**55 - 1.77314043852205e+57*cos(theta)**53 + 1.59698530998914e+57*cos(theta)**51 - 1.22586169189413e+57*cos(theta)**49 + 8.06271448359898e+56*cos(theta)**47 - 4.56085523640528e+56*cos(theta)**45 + 2.22425945026662e+56*cos(theta)**43 - 9.36366565776576e+55*cos(theta)**41 + 3.40346003518082e+55*cos(theta)**39 - 1.06727206350782e+55*cos(theta)**37 + 2.88241360217441e+54*cos(theta)**35 - 6.68630055865019e+53*cos(theta)**33 + 1.3272055244238e+53*cos(theta)**31 - 2.24336811652877e+52*cos(theta)**29 + 3.20932859517506e+51*cos(theta)**27 - 3.85646811676291e+50*cos(theta)**25 + 3.85646811676291e+49*cos(theta)**23 - 3.1729640115155e+48*cos(theta)**21 + 2.11799886337653e+47*cos(theta)**19 - 1.12722628583064e+46*cos(theta)**17 + 4.67957188256922e+44*cos(theta)**15 - 1.47332847876992e+43*cos(theta)**13 + 3.389959331683e+41*cos(theta)**11 - 5.41841799600596e+39*cos(theta)**9 + 5.59240389496028e+37*cos(theta)**7 - 3.32598362487017e+35*cos(theta)**5 + 9.31648074193326e+32*cos(theta)**3 - 7.75296594335639e+29*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl86_m16(theta, phi):
    return 5.85697047959929e-31*(1.0 - cos(theta)**2)**8*(9.50649754077437e+54*cos(theta)**70 - 1.34258430181112e+56*cos(theta)**68 + 9.04854153705836e+56*cos(theta)**66 - 3.87407616706391e+57*cos(theta)**64 + 1.18335417466679e+58*cos(theta)**62 - 2.74567207888946e+58*cos(theta)**60 + 5.03088983399e+58*cos(theta)**58 - 7.47175282622234e+58*cos(theta)**56 + 9.16122559903058e+58*cos(theta)**54 - 9.39764432416685e+58*cos(theta)**52 + 8.14462508094461e+58*cos(theta)**50 - 6.00672229028124e+58*cos(theta)**48 + 3.78947580729152e+58*cos(theta)**46 - 2.05238485638238e+58*cos(theta)**44 + 9.56431563614645e+57*cos(theta)**42 - 3.83910291968396e+57*cos(theta)**40 + 1.32734941372052e+57*cos(theta)**38 - 3.94890663497894e+56*cos(theta)**36 + 1.00884476076104e+56*cos(theta)**34 - 2.20647918435456e+55*cos(theta)**32 + 4.11433712571377e+54*cos(theta)**30 - 6.50576753793345e+53*cos(theta)**28 + 8.66518720697267e+52*cos(theta)**26 - 9.64117029190728e+51*cos(theta)**24 + 8.8698766685547e+50*cos(theta)**22 - 6.66322442418255e+49*cos(theta)**20 + 4.0241978404154e+48*cos(theta)**18 - 1.9162846859121e+47*cos(theta)**16 + 7.01935782385383e+45*cos(theta)**14 - 1.9153270224009e+44*cos(theta)**12 + 3.7289552648513e+42*cos(theta)**10 - 4.87657619640536e+40*cos(theta)**8 + 3.9146827264722e+38*cos(theta)**6 - 1.66299181243509e+36*cos(theta)**4 + 2.79494422257998e+33*cos(theta)**2 - 7.75296594335639e+29)*cos(16*phi)

#@torch.jit.script
def Yl86_m17(theta, phi):
    return 6.89771748603804e-33*(1.0 - cos(theta)**2)**8.5*(6.65454827854206e+56*cos(theta)**69 - 9.1295732523156e+57*cos(theta)**67 + 5.97203741445852e+58*cos(theta)**65 - 2.4794087469209e+59*cos(theta)**63 + 7.33679588293412e+59*cos(theta)**61 - 1.64740324733367e+60*cos(theta)**59 + 2.9179161037142e+60*cos(theta)**57 - 4.18418158268451e+60*cos(theta)**55 + 4.94706182347651e+60*cos(theta)**53 - 4.88677504856676e+60*cos(theta)**51 + 4.0723125404723e+60*cos(theta)**49 - 2.883226699335e+60*cos(theta)**47 + 1.7431588713541e+60*cos(theta)**45 - 9.03049336808246e+59*cos(theta)**43 + 4.01701256718151e+59*cos(theta)**41 - 1.53564116787358e+59*cos(theta)**39 + 5.04392777213797e+58*cos(theta)**37 - 1.42160638859242e+58*cos(theta)**35 + 3.43007218658755e+57*cos(theta)**33 - 7.0607333899346e+56*cos(theta)**31 + 1.23430113771413e+56*cos(theta)**29 - 1.82161491062137e+55*cos(theta)**27 + 2.25294867381289e+54*cos(theta)**25 - 2.31388087005775e+53*cos(theta)**23 + 1.95137286708203e+52*cos(theta)**21 - 1.33264488483651e+51*cos(theta)**19 + 7.24355611274772e+49*cos(theta)**17 - 3.06605549745935e+48*cos(theta)**15 + 9.82710095339537e+46*cos(theta)**13 - 2.29839242688107e+45*cos(theta)**11 + 3.7289552648513e+43*cos(theta)**9 - 3.90126095712429e+41*cos(theta)**7 + 2.34880963588332e+39*cos(theta)**5 - 6.65196724974035e+36*cos(theta)**3 + 5.58988844515996e+33*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl86_m18(theta, phi):
    return 8.14262037718918e-35*(1.0 - cos(theta)**2)**9*(4.59163831219402e+58*cos(theta)**68 - 6.11681407905145e+59*cos(theta)**66 + 3.88182431939804e+60*cos(theta)**64 - 1.56202751056017e+61*cos(theta)**62 + 4.47544548858981e+61*cos(theta)**60 - 9.71967915926868e+61*cos(theta)**58 + 1.66321217911709e+62*cos(theta)**56 - 2.30129987047648e+62*cos(theta)**54 + 2.62194276644255e+62*cos(theta)**52 - 2.49225527476905e+62*cos(theta)**50 + 1.99543314483143e+62*cos(theta)**48 - 1.35511654868745e+62*cos(theta)**46 + 7.84421492109345e+61*cos(theta)**44 - 3.88311214827546e+61*cos(theta)**42 + 1.64697515254442e+61*cos(theta)**40 - 5.98900055470698e+60*cos(theta)**38 + 1.86625327569105e+60*cos(theta)**36 - 4.97562236007347e+59*cos(theta)**34 + 1.13192382157389e+59*cos(theta)**32 - 2.18882735087973e+58*cos(theta)**30 + 3.57947329937098e+57*cos(theta)**28 - 4.91836025867769e+56*cos(theta)**26 + 5.63237168453223e+55*cos(theta)**24 - 5.32192600113282e+54*cos(theta)**22 + 4.09788302087227e+53*cos(theta)**20 - 2.53202528118937e+52*cos(theta)**18 + 1.23140453916711e+51*cos(theta)**16 - 4.59908324618903e+49*cos(theta)**14 + 1.2775231239414e+48*cos(theta)**12 - 2.52823166956918e+46*cos(theta)**10 + 3.35605973836617e+44*cos(theta)**8 - 2.730882669987e+42*cos(theta)**6 + 1.17440481794166e+40*cos(theta)**4 - 1.9955901749221e+37*cos(theta)**2 + 5.58988844515996e+33)*cos(18*phi)

#@torch.jit.script
def Yl86_m19(theta, phi):
    return 9.63640583292203e-37*(1.0 - cos(theta)**2)**9.5*(3.12231405229193e+60*cos(theta)**67 - 4.03709729217396e+61*cos(theta)**65 + 2.48436756441474e+62*cos(theta)**63 - 9.68457056547304e+62*cos(theta)**61 + 2.68526729315389e+63*cos(theta)**59 - 5.63741391237583e+63*cos(theta)**57 + 9.31398820305572e+63*cos(theta)**55 - 1.2427019300573e+64*cos(theta)**53 + 1.36341023855013e+64*cos(theta)**51 - 1.24612763738452e+64*cos(theta)**49 + 9.57807909519086e+63*cos(theta)**47 - 6.23353612396226e+63*cos(theta)**45 + 3.45145456528112e+63*cos(theta)**43 - 1.63090710227569e+63*cos(theta)**41 + 6.58790061017768e+62*cos(theta)**39 - 2.27582021078865e+62*cos(theta)**37 + 6.71851179248777e+61*cos(theta)**35 - 1.69171160242498e+61*cos(theta)**33 + 3.62215622903645e+60*cos(theta)**31 - 6.56648205263918e+59*cos(theta)**29 + 1.00225252382388e+59*cos(theta)**27 - 1.2787736672562e+58*cos(theta)**25 + 1.35176920428774e+57*cos(theta)**23 - 1.17082372024922e+56*cos(theta)**21 + 8.19576604174454e+54*cos(theta)**19 - 4.55764550614087e+53*cos(theta)**17 + 1.97024726266738e+52*cos(theta)**15 - 6.43871654466464e+50*cos(theta)**13 + 1.53302774872968e+49*cos(theta)**11 - 2.52823166956918e+47*cos(theta)**9 + 2.68484779069294e+45*cos(theta)**7 - 1.6385296019922e+43*cos(theta)**5 + 4.69761927176663e+40*cos(theta)**3 - 3.99118034984421e+37*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl86_m20(theta, phi):
    return 1.1434699285799e-38*(1.0 - cos(theta)**2)**10*(2.0919504150356e+62*cos(theta)**66 - 2.62411323991307e+63*cos(theta)**64 + 1.56515156558129e+64*cos(theta)**62 - 5.90758804493856e+64*cos(theta)**60 + 1.58430770296079e+65*cos(theta)**58 - 3.21332593005422e+65*cos(theta)**56 + 5.12269351168065e+65*cos(theta)**54 - 6.58632022930369e+65*cos(theta)**52 + 6.95339221660565e+65*cos(theta)**50 - 6.10602542318417e+65*cos(theta)**48 + 4.5016971747397e+65*cos(theta)**46 - 2.80509125578302e+65*cos(theta)**44 + 1.48412546307088e+65*cos(theta)**42 - 6.68671911933034e+64*cos(theta)**40 + 2.56928123796929e+64*cos(theta)**38 - 8.42053477991801e+63*cos(theta)**36 + 2.35147912737072e+63*cos(theta)**34 - 5.58264828800243e+62*cos(theta)**32 + 1.1228684310013e+62*cos(theta)**30 - 1.90427979526536e+61*cos(theta)**28 + 2.70608181432446e+60*cos(theta)**26 - 3.1969341681405e+59*cos(theta)**24 + 3.10906916986179e+58*cos(theta)**22 - 2.45872981252336e+57*cos(theta)**20 + 1.55719554793146e+56*cos(theta)**18 - 7.74799736043947e+54*cos(theta)**16 + 2.95537089400107e+53*cos(theta)**14 - 8.37033150806404e+51*cos(theta)**12 + 1.68633052360264e+50*cos(theta)**10 - 2.27540850261226e+48*cos(theta)**8 + 1.87939345348506e+46*cos(theta)**6 - 8.19264800996101e+43*cos(theta)**4 + 1.40928578152999e+41*cos(theta)**2 - 3.99118034984421e+37)*cos(20*phi)

#@torch.jit.script
def Yl86_m21(theta, phi):
    return 1.36069532051179e-40*(1.0 - cos(theta)**2)**10.5*(1.38068727392349e+64*cos(theta)**65 - 1.67943247354437e+65*cos(theta)**63 + 9.70393970660399e+65*cos(theta)**61 - 3.54455282696313e+66*cos(theta)**59 + 9.18898467717261e+66*cos(theta)**57 - 1.79946252083037e+67*cos(theta)**55 + 2.76625449630755e+67*cos(theta)**53 - 3.42488651923792e+67*cos(theta)**51 + 3.47669610830282e+67*cos(theta)**49 - 2.9308922031284e+67*cos(theta)**47 + 2.07078070038026e+67*cos(theta)**45 - 1.23424015254453e+67*cos(theta)**43 + 6.2333269448977e+66*cos(theta)**41 - 2.67468764773214e+66*cos(theta)**39 + 9.76326870428332e+65*cos(theta)**37 - 3.03139252077048e+65*cos(theta)**35 + 7.99502903306045e+64*cos(theta)**33 - 1.78644745216078e+64*cos(theta)**31 + 3.3686052930039e+63*cos(theta)**29 - 5.33198342674302e+62*cos(theta)**27 + 7.0358127172436e+61*cos(theta)**25 - 7.67264200353719e+60*cos(theta)**23 + 6.83995217369595e+59*cos(theta)**21 - 4.91745962504673e+58*cos(theta)**19 + 2.80295198627663e+57*cos(theta)**17 - 1.23967957767032e+56*cos(theta)**15 + 4.1375192516015e+54*cos(theta)**13 - 1.00443978096768e+53*cos(theta)**11 + 1.68633052360264e+51*cos(theta)**9 - 1.82032680208981e+49*cos(theta)**7 + 1.12763607209103e+47*cos(theta)**5 - 3.2770592039844e+44*cos(theta)**3 + 2.81857156305998e+41*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl86_m22(theta, phi):
    return 1.62402359675725e-42*(1.0 - cos(theta)**2)**11*(8.97446728050271e+65*cos(theta)**64 - 1.05804245833295e+67*cos(theta)**62 + 5.91940322102843e+67*cos(theta)**60 - 2.09128616790825e+68*cos(theta)**58 + 5.23772126598839e+68*cos(theta)**56 - 9.89704386456701e+68*cos(theta)**54 + 1.466114883043e+69*cos(theta)**52 - 1.74669212481134e+69*cos(theta)**50 + 1.70358109306838e+69*cos(theta)**48 - 1.37751933547035e+69*cos(theta)**46 + 9.31851315171118e+68*cos(theta)**44 - 5.30723265594147e+68*cos(theta)**42 + 2.55566404740806e+68*cos(theta)**40 - 1.04312818261553e+68*cos(theta)**38 + 3.61240942058483e+67*cos(theta)**36 - 1.06098738226967e+67*cos(theta)**34 + 2.63835958090995e+66*cos(theta)**32 - 5.53798710169841e+65*cos(theta)**30 + 9.76895534971131e+64*cos(theta)**28 - 1.43963552522061e+64*cos(theta)**26 + 1.7589531793109e+63*cos(theta)**24 - 1.76470766081355e+62*cos(theta)**22 + 1.43638995647615e+61*cos(theta)**20 - 9.34317328758878e+59*cos(theta)**18 + 4.76501837667028e+58*cos(theta)**16 - 1.85951936650547e+57*cos(theta)**14 + 5.37877502708195e+55*cos(theta)**12 - 1.10488375906445e+54*cos(theta)**10 + 1.51769747124238e+52*cos(theta)**8 - 1.27422876146287e+50*cos(theta)**6 + 5.63818036045517e+47*cos(theta)**4 - 9.83117761195321e+44*cos(theta)**2 + 2.81857156305998e+41)*cos(22*phi)

#@torch.jit.script
def Yl86_m23(theta, phi):
    return 1.94441561099186e-44*(1.0 - cos(theta)**2)**11.5*(5.74365905952173e+67*cos(theta)**63 - 6.5598632416643e+68*cos(theta)**61 + 3.55164193261706e+69*cos(theta)**59 - 1.21294597738678e+70*cos(theta)**57 + 2.9331239089535e+70*cos(theta)**55 - 5.34440368686619e+70*cos(theta)**53 + 7.62379739182361e+70*cos(theta)**51 - 8.73346062405669e+70*cos(theta)**49 + 8.17718924672824e+70*cos(theta)**47 - 6.3365889431636e+70*cos(theta)**45 + 4.10014578675292e+70*cos(theta)**43 - 2.22903771549542e+70*cos(theta)**41 + 1.02226561896322e+70*cos(theta)**39 - 3.96388709393903e+69*cos(theta)**37 + 1.30046739141054e+69*cos(theta)**35 - 3.60735709971688e+68*cos(theta)**33 + 8.44275065891184e+67*cos(theta)**31 - 1.66139613050952e+67*cos(theta)**29 + 2.73530749791917e+66*cos(theta)**27 - 3.7430523655736e+65*cos(theta)**25 + 4.22148763034616e+64*cos(theta)**23 - 3.88235685378982e+63*cos(theta)**21 + 2.8727799129523e+62*cos(theta)**19 - 1.68177119176598e+61*cos(theta)**17 + 7.62402940267244e+59*cos(theta)**15 - 2.60332711310766e+58*cos(theta)**13 + 6.45453003249834e+56*cos(theta)**11 - 1.10488375906445e+55*cos(theta)**9 + 1.2141579769939e+53*cos(theta)**7 - 7.64537256877721e+50*cos(theta)**5 + 2.25527214418207e+48*cos(theta)**3 - 1.96623552239064e+45*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl86_m24(theta, phi):
    return 2.33572915599019e-46*(1.0 - cos(theta)**2)**12*(3.61850520749869e+69*cos(theta)**62 - 4.00151657741522e+70*cos(theta)**60 + 2.09546874024406e+71*cos(theta)**58 - 6.91379207110467e+71*cos(theta)**56 + 1.61321814992442e+72*cos(theta)**54 - 2.83253395403908e+72*cos(theta)**52 + 3.88813666983004e+72*cos(theta)**50 - 4.27939570578778e+72*cos(theta)**48 + 3.84327894596227e+72*cos(theta)**46 - 2.85146502442362e+72*cos(theta)**44 + 1.76306268830376e+72*cos(theta)**42 - 9.13905463353121e+71*cos(theta)**40 + 3.98683591395657e+71*cos(theta)**38 - 1.46663822475744e+71*cos(theta)**36 + 4.55163586993688e+70*cos(theta)**34 - 1.19042784290657e+70*cos(theta)**32 + 2.61725270426267e+69*cos(theta)**30 - 4.81804877847762e+68*cos(theta)**28 + 7.38533024438175e+67*cos(theta)**26 - 9.35763091393399e+66*cos(theta)**24 + 9.70942154979617e+65*cos(theta)**22 - 8.15294939295862e+64*cos(theta)**20 + 5.45828183460936e+63*cos(theta)**18 - 2.85901102600217e+62*cos(theta)**16 + 1.14360441040087e+61*cos(theta)**14 - 3.38432524703996e+59*cos(theta)**12 + 7.09998303574817e+57*cos(theta)**10 - 9.94395383158007e+55*cos(theta)**8 + 8.49910583895733e+53*cos(theta)**6 - 3.8226862843886e+51*cos(theta)**4 + 6.7658164325462e+48*cos(theta)**2 - 1.96623552239064e+45)*cos(24*phi)

#@torch.jit.script
def Yl86_m25(theta, phi):
    return 2.81556234105056e-48*(1.0 - cos(theta)**2)**12.5*(2.24347322864919e+71*cos(theta)**61 - 2.40090994644913e+72*cos(theta)**59 + 1.21537186934156e+73*cos(theta)**57 - 3.87172355981862e+73*cos(theta)**55 + 8.71137800959188e+73*cos(theta)**53 - 1.47291765610032e+74*cos(theta)**51 + 1.94406833491502e+74*cos(theta)**49 - 2.05410993877813e+74*cos(theta)**47 + 1.76790831514265e+74*cos(theta)**45 - 1.25464461074639e+74*cos(theta)**43 + 7.40486329087577e+73*cos(theta)**41 - 3.65562185341248e+73*cos(theta)**39 + 1.5149976473035e+73*cos(theta)**37 - 5.27989760912678e+72*cos(theta)**35 + 1.54755619577854e+72*cos(theta)**33 - 3.80936909730102e+71*cos(theta)**31 + 7.85175811278801e+70*cos(theta)**29 - 1.34905365797373e+70*cos(theta)**27 + 1.92018586353926e+69*cos(theta)**25 - 2.24583141934416e+68*cos(theta)**23 + 2.13607274095516e+67*cos(theta)**21 - 1.63058987859172e+66*cos(theta)**19 + 9.82490730229686e+64*cos(theta)**17 - 4.57441764160347e+63*cos(theta)**15 + 1.60104617456121e+62*cos(theta)**13 - 4.06119029644796e+60*cos(theta)**11 + 7.09998303574817e+58*cos(theta)**9 - 7.95516306526406e+56*cos(theta)**7 + 5.0994635033744e+54*cos(theta)**5 - 1.52907451375544e+52*cos(theta)**3 + 1.35316328650924e+49*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl86_m26(theta, phi):
    return 3.4063652911847e-50*(1.0 - cos(theta)**2)**13*(1.36851866947601e+73*cos(theta)**60 - 1.41653686840499e+74*cos(theta)**58 + 6.92761965524688e+74*cos(theta)**56 - 2.12944795790024e+75*cos(theta)**54 + 4.6170303450837e+75*cos(theta)**52 - 7.51188004611164e+75*cos(theta)**50 + 9.5259348410836e+75*cos(theta)**48 - 9.65431671225723e+75*cos(theta)**46 + 7.95558741814191e+75*cos(theta)**44 - 5.39497182620949e+75*cos(theta)**42 + 3.03599394925907e+75*cos(theta)**40 - 1.42569252283087e+75*cos(theta)**38 + 5.60549129502293e+74*cos(theta)**36 - 1.84796416319437e+74*cos(theta)**34 + 5.10693544606918e+73*cos(theta)**32 - 1.18090442016332e+73*cos(theta)**30 + 2.27700985270852e+72*cos(theta)**28 - 3.64244487652908e+71*cos(theta)**26 + 4.80046465884814e+70*cos(theta)**24 - 5.16541226449156e+69*cos(theta)**22 + 4.48575275600583e+68*cos(theta)**20 - 3.09812076932428e+67*cos(theta)**18 + 1.67023424139047e+66*cos(theta)**16 - 6.8616264624052e+64*cos(theta)**14 + 2.08136002692958e+63*cos(theta)**12 - 4.46730932609275e+61*cos(theta)**10 + 6.38998473217336e+59*cos(theta)**8 - 5.56861414568484e+57*cos(theta)**6 + 2.5497317516872e+55*cos(theta)**4 - 4.58722354126632e+52*cos(theta)**2 + 1.35316328650924e+49)*cos(26*phi)

#@torch.jit.script
def Yl86_m27(theta, phi):
    return 4.13691285026172e-52*(1.0 - cos(theta)**2)**13.5*(8.21111201685603e+74*cos(theta)**59 - 8.21591383674893e+75*cos(theta)**57 + 3.87946700693825e+76*cos(theta)**55 - 1.14990189726613e+77*cos(theta)**53 + 2.40085577944352e+77*cos(theta)**51 - 3.75594002305582e+77*cos(theta)**49 + 4.57244872372013e+77*cos(theta)**47 - 4.44098568763833e+77*cos(theta)**45 + 3.50045846398244e+77*cos(theta)**43 - 2.26588816700799e+77*cos(theta)**41 + 1.21439757970363e+77*cos(theta)**39 - 5.4176315867573e+76*cos(theta)**37 + 2.01797686620826e+76*cos(theta)**35 - 6.28307815486087e+75*cos(theta)**33 + 1.63421934274214e+75*cos(theta)**31 - 3.54271326048995e+74*cos(theta)**29 + 6.37562758758386e+73*cos(theta)**27 - 9.47035667897561e+72*cos(theta)**25 + 1.15211151812355e+72*cos(theta)**23 - 1.13639069818814e+71*cos(theta)**21 + 8.97150551201166e+69*cos(theta)**19 - 5.5766173847837e+68*cos(theta)**17 + 2.67237478622474e+67*cos(theta)**15 - 9.60627704736728e+65*cos(theta)**13 + 2.49763203231549e+64*cos(theta)**11 - 4.46730932609275e+62*cos(theta)**9 + 5.11198778573868e+60*cos(theta)**7 - 3.3411684874109e+58*cos(theta)**5 + 1.01989270067488e+56*cos(theta)**3 - 9.17444708253265e+52*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl86_m28(theta, phi):
    return 5.04426553861479e-54*(1.0 - cos(theta)**2)**14*(4.84455608994506e+76*cos(theta)**58 - 4.68307088694689e+77*cos(theta)**56 + 2.13370685381604e+78*cos(theta)**54 - 6.09448005551048e+78*cos(theta)**52 + 1.2244364475162e+79*cos(theta)**50 - 1.84041061129735e+79*cos(theta)**48 + 2.14905090014846e+79*cos(theta)**46 - 1.99844355943725e+79*cos(theta)**44 + 1.50519713951245e+79*cos(theta)**42 - 9.29014148473275e+78*cos(theta)**40 + 4.73615056084415e+78*cos(theta)**38 - 2.0045236871002e+78*cos(theta)**36 + 7.0629190317289e+77*cos(theta)**34 - 2.07341579110409e+77*cos(theta)**32 + 5.06607996250063e+76*cos(theta)**30 - 1.02738684554209e+76*cos(theta)**28 + 1.72141944864764e+75*cos(theta)**26 - 2.3675891697439e+74*cos(theta)**24 + 2.64985649168417e+73*cos(theta)**22 - 2.3864204661951e+72*cos(theta)**20 + 1.70458604728222e+71*cos(theta)**18 - 9.48024955413228e+69*cos(theta)**16 + 4.00856217933712e+68*cos(theta)**14 - 1.24881601615775e+67*cos(theta)**12 + 2.74739523554704e+65*cos(theta)**10 - 4.02057839348348e+63*cos(theta)**8 + 3.57839145001708e+61*cos(theta)**6 - 1.67058424370545e+59*cos(theta)**4 + 3.05967810202464e+56*cos(theta)**2 - 9.17444708253265e+52)*cos(28*phi)

#@torch.jit.script
def Yl86_m29(theta, phi):
    return 6.1763944427092e-56*(1.0 - cos(theta)**2)**14.5*(2.80984253216813e+78*cos(theta)**57 - 2.62251969669026e+79*cos(theta)**55 + 1.15220170106066e+80*cos(theta)**53 - 3.16912962886545e+80*cos(theta)**51 + 6.12218223758098e+80*cos(theta)**49 - 8.83397093422729e+80*cos(theta)**47 + 9.88563414068291e+80*cos(theta)**45 - 8.79315166152389e+80*cos(theta)**43 + 6.32182798595228e+80*cos(theta)**41 - 3.7160565938931e+80*cos(theta)**39 + 1.79973721312078e+80*cos(theta)**37 - 7.21628527356073e+79*cos(theta)**35 + 2.40139247078783e+79*cos(theta)**33 - 6.63493053153308e+78*cos(theta)**31 + 1.51982398875019e+78*cos(theta)**29 - 2.87668316751784e+77*cos(theta)**27 + 4.47569056648387e+76*cos(theta)**25 - 5.68221400738536e+75*cos(theta)**23 + 5.82968428170518e+74*cos(theta)**21 - 4.7728409323902e+73*cos(theta)**19 + 3.06825488510799e+72*cos(theta)**17 - 1.51683992866117e+71*cos(theta)**15 + 5.61198705107196e+69*cos(theta)**13 - 1.4985792193893e+68*cos(theta)**11 + 2.74739523554704e+66*cos(theta)**9 - 3.21646271478678e+64*cos(theta)**7 + 2.14703487001025e+62*cos(theta)**5 - 6.68233697482181e+59*cos(theta)**3 + 6.11935620404928e+56*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl86_m30(theta, phi):
    return 7.59571394967033e-58*(1.0 - cos(theta)**2)**15*(1.60161024333584e+80*cos(theta)**56 - 1.44238583317964e+81*cos(theta)**54 + 6.1066690156215e+81*cos(theta)**52 - 1.61625611072138e+82*cos(theta)**50 + 2.99986929641468e+82*cos(theta)**48 - 4.15196633908682e+82*cos(theta)**46 + 4.44853536330731e+82*cos(theta)**44 - 3.78105521445527e+82*cos(theta)**42 + 2.59194947424044e+82*cos(theta)**40 - 1.44926207161831e+82*cos(theta)**38 + 6.65902768854687e+81*cos(theta)**36 - 2.52569984574625e+81*cos(theta)**34 + 7.92459515359982e+80*cos(theta)**32 - 2.05682846477525e+80*cos(theta)**30 + 4.40748956737555e+79*cos(theta)**28 - 7.76704455229817e+78*cos(theta)**26 + 1.11892264162097e+78*cos(theta)**24 - 1.30690922169863e+77*cos(theta)**22 + 1.22423369915809e+76*cos(theta)**20 - 9.06839777154139e+74*cos(theta)**18 + 5.21603330468358e+73*cos(theta)**16 - 2.27525989299175e+72*cos(theta)**14 + 7.29558316639355e+70*cos(theta)**12 - 1.64843714132822e+69*cos(theta)**10 + 2.47265571199234e+67*cos(theta)**8 - 2.25152390035075e+65*cos(theta)**6 + 1.07351743500512e+63*cos(theta)**4 - 2.00470109244654e+60*cos(theta)**2 + 6.11935620404928e+56)*cos(30*phi)

#@torch.jit.script
def Yl86_m31(theta, phi):
    return 9.38386295791054e-60*(1.0 - cos(theta)**2)**15.5*(8.96901736268068e+81*cos(theta)**55 - 7.78888349917007e+82*cos(theta)**53 + 3.17546788812318e+83*cos(theta)**51 - 8.0812805536069e+83*cos(theta)**49 + 1.43993726227905e+84*cos(theta)**47 - 1.90990451597994e+84*cos(theta)**45 + 1.95735555985522e+84*cos(theta)**43 - 1.58804319007121e+84*cos(theta)**41 + 1.03677978969617e+84*cos(theta)**39 - 5.50719587214957e+83*cos(theta)**37 + 2.39724996787687e+83*cos(theta)**35 - 8.58737947553726e+82*cos(theta)**33 + 2.53587044915194e+82*cos(theta)**31 - 6.17048539432576e+81*cos(theta)**29 + 1.23409707886515e+81*cos(theta)**27 - 2.01943158359752e+80*cos(theta)**25 + 2.68541433989032e+79*cos(theta)**23 - 2.87520028773699e+78*cos(theta)**21 + 2.44846739831618e+77*cos(theta)**19 - 1.63231159887745e+76*cos(theta)**17 + 8.34565328749373e+74*cos(theta)**15 - 3.18536385018845e+73*cos(theta)**13 + 8.75469979967226e+71*cos(theta)**11 - 1.64843714132823e+70*cos(theta)**9 + 1.97812456959387e+68*cos(theta)**7 - 1.35091434021045e+66*cos(theta)**5 + 4.2940697400205e+63*cos(theta)**3 - 4.00940218489309e+60*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl86_m32(theta, phi):
    return 1.16482131268735e-61*(1.0 - cos(theta)**2)**16*(4.93295954947438e+83*cos(theta)**54 - 4.12810825456014e+84*cos(theta)**52 + 1.61948862294282e+85*cos(theta)**50 - 3.95982747126738e+85*cos(theta)**48 + 6.76770513271152e+85*cos(theta)**46 - 8.59457032190973e+85*cos(theta)**44 + 8.41662890737743e+85*cos(theta)**42 - 6.51097707929198e+85*cos(theta)**40 + 4.04344117981508e+85*cos(theta)**38 - 2.03766247269534e+85*cos(theta)**36 + 8.39037488756906e+84*cos(theta)**34 - 2.8338352269273e+84*cos(theta)**32 + 7.86119839237102e+83*cos(theta)**30 - 1.78944076435447e+83*cos(theta)**28 + 3.33206211293591e+82*cos(theta)**26 - 5.04857895899381e+81*cos(theta)**24 + 6.17645298174774e+80*cos(theta)**22 - 6.03792060424769e+79*cos(theta)**20 + 4.65208805680073e+78*cos(theta)**18 - 2.77492971809167e+77*cos(theta)**16 + 1.25184799312406e+76*cos(theta)**14 - 4.14097300524498e+74*cos(theta)**12 + 9.63016977963949e+72*cos(theta)**10 - 1.4835934271954e+71*cos(theta)**8 + 1.38468719871571e+69*cos(theta)**6 - 6.75457170105224e+66*cos(theta)**4 + 1.28822092200615e+64*cos(theta)**2 - 4.00940218489309e+60)*cos(32*phi)

#@torch.jit.script
def Yl86_m33(theta, phi):
    return 1.45307806764369e-63*(1.0 - cos(theta)**2)**16.5*(2.66379815671616e+85*cos(theta)**53 - 2.14661629237127e+86*cos(theta)**51 + 8.09744311471411e+86*cos(theta)**49 - 1.90071718620834e+87*cos(theta)**47 + 3.1131443610473e+87*cos(theta)**45 - 3.78161094164028e+87*cos(theta)**43 + 3.53498414109852e+87*cos(theta)**41 - 2.60439083171679e+87*cos(theta)**39 + 1.53650764832973e+87*cos(theta)**37 - 7.33558490170323e+86*cos(theta)**35 + 2.85272746177348e+86*cos(theta)**33 - 9.06827272616735e+85*cos(theta)**31 + 2.35835951771131e+85*cos(theta)**29 - 5.01043414019252e+84*cos(theta)**27 + 8.66336149363337e+83*cos(theta)**25 - 1.21165895015851e+83*cos(theta)**23 + 1.3588196559845e+82*cos(theta)**21 - 1.20758412084954e+81*cos(theta)**19 + 8.37375850224132e+79*cos(theta)**17 - 4.43988754894666e+78*cos(theta)**15 + 1.75258719037368e+77*cos(theta)**13 - 4.96916760629398e+75*cos(theta)**11 + 9.63016977963949e+73*cos(theta)**9 - 1.18687474175632e+72*cos(theta)**7 + 8.30812319229425e+69*cos(theta)**5 - 2.7018286804209e+67*cos(theta)**3 + 2.5764418440123e+64*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl86_m34(theta, phi):
    return 1.82205041674886e-65*(1.0 - cos(theta)**2)**17*(1.41181302305957e+87*cos(theta)**52 - 1.09477430910935e+88*cos(theta)**50 + 3.96774712620992e+88*cos(theta)**48 - 8.93337077517921e+88*cos(theta)**46 + 1.40091496247129e+89*cos(theta)**44 - 1.62609270490532e+89*cos(theta)**42 + 1.44934349785039e+89*cos(theta)**40 - 1.01571242436955e+89*cos(theta)**38 + 5.68507829882e+88*cos(theta)**36 - 2.56745471559613e+88*cos(theta)**34 + 9.41400062385248e+87*cos(theta)**32 - 2.81116454511188e+87*cos(theta)**30 + 6.83924260136279e+86*cos(theta)**28 - 1.35281721785198e+86*cos(theta)**26 + 2.16584037340834e+85*cos(theta)**24 - 2.78681558536458e+84*cos(theta)**22 + 2.85352127756746e+83*cos(theta)**20 - 2.29440982961412e+82*cos(theta)**18 + 1.42353894538102e+81*cos(theta)**16 - 6.65983132342e+79*cos(theta)**14 + 2.27836334748579e+78*cos(theta)**12 - 5.46608436692337e+76*cos(theta)**10 + 8.66715280167554e+74*cos(theta)**8 - 8.30812319229425e+72*cos(theta)**6 + 4.15406159614713e+70*cos(theta)**4 - 8.10548604126269e+67*cos(theta)**2 + 2.5764418440123e+64)*cos(34*phi)

#@torch.jit.script
def Yl86_m35(theta, phi):
    return 2.29702664477922e-67*(1.0 - cos(theta)**2)**17.5*(7.34142771990975e+88*cos(theta)**51 - 5.47387154554674e+89*cos(theta)**49 + 1.90451862058076e+90*cos(theta)**47 - 4.10935055658244e+90*cos(theta)**45 + 6.16402583487365e+90*cos(theta)**43 - 6.82958936060234e+90*cos(theta)**41 + 5.79737399140158e+90*cos(theta)**39 - 3.85970721260428e+90*cos(theta)**37 + 2.0466281875752e+90*cos(theta)**35 - 8.72934603302685e+89*cos(theta)**33 + 3.01248019963279e+89*cos(theta)**31 - 8.43349363533563e+88*cos(theta)**29 + 1.91498792838158e+88*cos(theta)**27 - 3.51732476641515e+87*cos(theta)**25 + 5.19801689618002e+86*cos(theta)**23 - 6.13099428780208e+85*cos(theta)**21 + 5.70704255513491e+84*cos(theta)**19 - 4.12993769330542e+83*cos(theta)**17 + 2.27766231260964e+82*cos(theta)**15 - 9.323763852788e+80*cos(theta)**13 + 2.73403601698295e+79*cos(theta)**11 - 5.46608436692337e+77*cos(theta)**9 + 6.93372224134043e+75*cos(theta)**7 - 4.98487391537655e+73*cos(theta)**5 + 1.66162463845885e+71*cos(theta)**3 - 1.62109720825254e+68*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl86_m36(theta, phi):
    return 2.9120647647107e-69*(1.0 - cos(theta)**2)**18*(3.74412813715397e+90*cos(theta)**50 - 2.6821970573179e+91*cos(theta)**48 + 8.95123751672957e+91*cos(theta)**46 - 1.8492077504621e+92*cos(theta)**44 + 2.65053110899567e+92*cos(theta)**42 - 2.80013163784696e+92*cos(theta)**40 + 2.26097585664661e+92*cos(theta)**38 - 1.42809166866359e+92*cos(theta)**36 + 7.1631986565132e+91*cos(theta)**34 - 2.88068419089886e+91*cos(theta)**32 + 9.33868861886166e+90*cos(theta)**30 - 2.44571315424733e+90*cos(theta)**28 + 5.17046740663027e+89*cos(theta)**26 - 8.79331191603787e+88*cos(theta)**24 + 1.19554388612141e+88*cos(theta)**22 - 1.28750880043844e+87*cos(theta)**20 + 1.08433808547563e+86*cos(theta)**18 - 7.02089407861921e+84*cos(theta)**16 + 3.41649346891446e+83*cos(theta)**14 - 1.21208930086244e+82*cos(theta)**12 + 3.00743961868124e+80*cos(theta)**10 - 4.91947593023104e+78*cos(theta)**8 + 4.8536055689383e+76*cos(theta)**6 - 2.49243695768828e+74*cos(theta)**4 + 4.98487391537655e+71*cos(theta)**2 - 1.62109720825254e+68)*cos(36*phi)

#@torch.jit.script
def Yl86_m37(theta, phi):
    return 3.71332936182363e-71*(1.0 - cos(theta)**2)**18.5*(1.87206406857699e+92*cos(theta)**49 - 1.28745458751259e+93*cos(theta)**47 + 4.1175692576956e+93*cos(theta)**45 - 8.13651410203322e+93*cos(theta)**43 + 1.11322306577818e+94*cos(theta)**41 - 1.12005265513878e+94*cos(theta)**39 + 8.59170825525714e+93*cos(theta)**37 - 5.14113000718891e+93*cos(theta)**35 + 2.43548754321449e+93*cos(theta)**33 - 9.21818941087635e+92*cos(theta)**31 + 2.8016065856585e+92*cos(theta)**29 - 6.84799683189254e+91*cos(theta)**27 + 1.34432152572387e+91*cos(theta)**25 - 2.11039485984909e+90*cos(theta)**23 + 2.63019654946709e+89*cos(theta)**21 - 2.57501760087687e+88*cos(theta)**19 + 1.95180855385614e+87*cos(theta)**17 - 1.12334305257907e+86*cos(theta)**15 + 4.78309085648024e+84*cos(theta)**13 - 1.45450716103493e+83*cos(theta)**11 + 3.00743961868124e+81*cos(theta)**9 - 3.93558074418483e+79*cos(theta)**7 + 2.91216334136298e+77*cos(theta)**5 - 9.9697478307531e+74*cos(theta)**3 + 9.9697478307531e+71*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl86_m38(theta, phi):
    return 4.76381172539445e-73*(1.0 - cos(theta)**2)**19*(9.17311393602723e+93*cos(theta)**48 - 6.05103656130919e+94*cos(theta)**46 + 1.85290616596302e+95*cos(theta)**44 - 3.49870106387429e+95*cos(theta)**42 + 4.56421456969055e+95*cos(theta)**40 - 4.36820535504126e+95*cos(theta)**38 + 3.17893205444514e+95*cos(theta)**36 - 1.79939550251612e+95*cos(theta)**34 + 8.03710889260782e+94*cos(theta)**32 - 2.85763871737167e+94*cos(theta)**30 + 8.12465909840964e+93*cos(theta)**28 - 1.84895914461098e+93*cos(theta)**26 + 3.36080381430968e+92*cos(theta)**24 - 4.85390817765291e+91*cos(theta)**22 + 5.52341275388089e+90*cos(theta)**20 - 4.89253344166606e+89*cos(theta)**18 + 3.31807454155544e+88*cos(theta)**16 - 1.68501457886861e+87*cos(theta)**14 + 6.21801811342431e+85*cos(theta)**12 - 1.59995787713842e+84*cos(theta)**10 + 2.70669565681312e+82*cos(theta)**8 - 2.75490652092938e+80*cos(theta)**6 + 1.45608167068149e+78*cos(theta)**4 - 2.99092434922593e+75*cos(theta)**2 + 9.9697478307531e+71)*cos(38*phi)

#@torch.jit.script
def Yl86_m39(theta, phi):
    return 6.15005449230678e-75*(1.0 - cos(theta)**2)**19.5*(4.40309468929307e+95*cos(theta)**47 - 2.78347681820223e+96*cos(theta)**45 + 8.15278713023729e+96*cos(theta)**43 - 1.4694544468272e+97*cos(theta)**41 + 1.82568582787622e+97*cos(theta)**39 - 1.65991803491568e+97*cos(theta)**37 + 1.14441553960025e+97*cos(theta)**35 - 6.1179447085548e+96*cos(theta)**33 + 2.5718748456345e+96*cos(theta)**31 - 8.572916152115e+95*cos(theta)**29 + 2.2749045475547e+95*cos(theta)**27 - 4.80729377598856e+94*cos(theta)**25 + 8.06592915434322e+93*cos(theta)**23 - 1.06785979908364e+93*cos(theta)**21 + 1.10468255077618e+92*cos(theta)**19 - 8.80656019499891e+90*cos(theta)**17 + 5.3089192664887e+89*cos(theta)**15 - 2.35902041041606e+88*cos(theta)**13 + 7.46162173610918e+86*cos(theta)**11 - 1.59995787713842e+85*cos(theta)**9 + 2.16535652545049e+83*cos(theta)**7 - 1.65294391255763e+81*cos(theta)**5 + 5.82432668272596e+78*cos(theta)**3 - 5.98184869845186e+75*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl86_m40(theta, phi):
    return 7.99180286079389e-77*(1.0 - cos(theta)**2)**20*(2.06945450396774e+97*cos(theta)**46 - 1.252564568191e+98*cos(theta)**44 + 3.50569846600204e+98*cos(theta)**42 - 6.02476323199152e+98*cos(theta)**40 + 7.12017472871725e+98*cos(theta)**38 - 6.14169672918801e+98*cos(theta)**36 + 4.00545438860088e+98*cos(theta)**34 - 2.01892175382308e+98*cos(theta)**32 + 7.97281202146695e+97*cos(theta)**30 - 2.48614568411335e+97*cos(theta)**28 + 6.14224227839769e+96*cos(theta)**26 - 1.20182344399714e+96*cos(theta)**24 + 1.85516370549894e+95*cos(theta)**22 - 2.24250557807564e+94*cos(theta)**20 + 2.09889684647474e+93*cos(theta)**18 - 1.49711523314981e+92*cos(theta)**16 + 7.96337889973305e+90*cos(theta)**14 - 3.06672653354087e+89*cos(theta)**12 + 8.2077839097201e+87*cos(theta)**10 - 1.43996208942458e+86*cos(theta)**8 + 1.51574956781535e+84*cos(theta)**6 - 8.26471956278814e+81*cos(theta)**4 + 1.74729800481779e+79*cos(theta)**2 - 5.98184869845186e+75)*cos(40*phi)

#@torch.jit.script
def Yl86_m41(theta, phi):
    return 1.0455961753763e-78*(1.0 - cos(theta)**2)**20.5*(9.51949071825162e+98*cos(theta)**45 - 5.51128410004041e+99*cos(theta)**43 + 1.47239335572085e+100*cos(theta)**41 - 2.40990529279661e+100*cos(theta)**39 + 2.70566639691256e+100*cos(theta)**37 - 2.21101082250768e+100*cos(theta)**35 + 1.3618544921243e+100*cos(theta)**33 - 6.46054961223387e+99*cos(theta)**31 + 2.39184360644009e+99*cos(theta)**29 - 6.96120791551738e+98*cos(theta)**27 + 1.5969829923834e+98*cos(theta)**25 - 2.88437626559314e+97*cos(theta)**23 + 4.08136015209767e+96*cos(theta)**21 - 4.48501115615129e+95*cos(theta)**19 + 3.77801432365453e+94*cos(theta)**17 - 2.3953843730397e+93*cos(theta)**15 + 1.11487304596263e+92*cos(theta)**13 - 3.68007184024905e+90*cos(theta)**11 + 8.2077839097201e+88*cos(theta)**9 - 1.15196967153966e+87*cos(theta)**7 + 9.09449740689207e+84*cos(theta)**5 - 3.30588782511526e+82*cos(theta)**3 + 3.49459600963558e+79*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl86_m42(theta, phi):
    return 1.37769392789582e-80*(1.0 - cos(theta)**2)**21*(4.28377082321323e+100*cos(theta)**44 - 2.36985216301738e+101*cos(theta)**42 + 6.03681275845551e+101*cos(theta)**40 - 9.39863064190677e+101*cos(theta)**38 + 1.00109656685765e+102*cos(theta)**36 - 7.73853787877689e+101*cos(theta)**34 + 4.49411982401018e+101*cos(theta)**32 - 2.0027703797925e+101*cos(theta)**30 + 6.93634645867625e+100*cos(theta)**28 - 1.87952613718969e+100*cos(theta)**26 + 3.9924574809585e+99*cos(theta)**24 - 6.63406541086421e+98*cos(theta)**22 + 8.57085631940511e+97*cos(theta)**20 - 8.52152119668744e+96*cos(theta)**18 + 6.4226243502127e+95*cos(theta)**16 - 3.59307655955955e+94*cos(theta)**14 + 1.44933495975142e+93*cos(theta)**12 - 4.04807902427395e+91*cos(theta)**10 + 7.38700551874809e+89*cos(theta)**8 - 8.06378770077764e+87*cos(theta)**6 + 4.54724870344604e+85*cos(theta)**4 - 9.91766347534577e+82*cos(theta)**2 + 3.49459600963558e+79)*cos(42*phi)

#@torch.jit.script
def Yl86_m43(theta, phi):
    return 1.82865404459152e-82*(1.0 - cos(theta)**2)**21.5*(1.88485916221382e+102*cos(theta)**43 - 9.95337908467298e+102*cos(theta)**41 + 2.4147251033822e+103*cos(theta)**39 - 3.57147964392457e+103*cos(theta)**37 + 3.60394764068752e+103*cos(theta)**35 - 2.63110287878414e+103*cos(theta)**33 + 1.43811834368326e+103*cos(theta)**31 - 6.0083111393775e+102*cos(theta)**29 + 1.94217700842935e+102*cos(theta)**27 - 4.8867679566932e+101*cos(theta)**25 + 9.5818979543004e+100*cos(theta)**23 - 1.45949439039013e+100*cos(theta)**21 + 1.71417126388102e+99*cos(theta)**19 - 1.53387381540374e+98*cos(theta)**17 + 1.02761989603403e+97*cos(theta)**15 - 5.03030718338338e+95*cos(theta)**13 + 1.7392019517017e+94*cos(theta)**11 - 4.04807902427395e+92*cos(theta)**9 + 5.90960441499847e+90*cos(theta)**7 - 4.83827262046658e+88*cos(theta)**5 + 1.81889948137841e+86*cos(theta)**3 - 1.98353269506915e+83*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl86_m44(theta, phi):
    return 2.44582650436353e-84*(1.0 - cos(theta)**2)**22*(8.10489439751943e+103*cos(theta)**42 - 4.08088542471592e+104*cos(theta)**40 + 9.41742790319059e+104*cos(theta)**38 - 1.32144746825209e+105*cos(theta)**36 + 1.26138167424063e+105*cos(theta)**34 - 8.68263949998767e+104*cos(theta)**32 + 4.4581668654181e+104*cos(theta)**30 - 1.74241023041947e+104*cos(theta)**28 + 5.24387792275924e+103*cos(theta)**26 - 1.2216919891733e+103*cos(theta)**24 + 2.20383652948909e+102*cos(theta)**22 - 3.06493821981927e+101*cos(theta)**20 + 3.25692540137394e+100*cos(theta)**18 - 2.60758548618636e+99*cos(theta)**16 + 1.54142984405105e+98*cos(theta)**14 - 6.53939933839839e+96*cos(theta)**12 + 1.91312214687187e+95*cos(theta)**10 - 3.64327112184656e+93*cos(theta)**8 + 4.13672309049893e+91*cos(theta)**6 - 2.41913631023329e+89*cos(theta)**4 + 5.45669844413524e+86*cos(theta)**2 - 1.98353269506915e+83)*cos(44*phi)

#@torch.jit.script
def Yl86_m45(theta, phi):
    return 3.29735232158954e-86*(1.0 - cos(theta)**2)**22.5*(3.40405564695816e+105*cos(theta)**41 - 1.63235416988637e+106*cos(theta)**39 + 3.57862260321242e+106*cos(theta)**37 - 4.75721088570753e+106*cos(theta)**35 + 4.28869769241815e+106*cos(theta)**33 - 2.77844463999606e+106*cos(theta)**31 + 1.33745005962543e+106*cos(theta)**29 - 4.87874864517453e+105*cos(theta)**27 + 1.3634082599174e+105*cos(theta)**25 - 2.93206077401592e+104*cos(theta)**23 + 4.848440364876e+103*cos(theta)**21 - 6.12987643963853e+102*cos(theta)**19 + 5.86246572247309e+101*cos(theta)**17 - 4.17213677789817e+100*cos(theta)**15 + 2.15800178167147e+99*cos(theta)**13 - 7.84727920607807e+97*cos(theta)**11 + 1.91312214687187e+96*cos(theta)**9 - 2.91461689747724e+94*cos(theta)**7 + 2.48203385429936e+92*cos(theta)**5 - 9.67654524093316e+89*cos(theta)**3 + 1.09133968882705e+87*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl86_m46(theta, phi):
    return 4.48215075733493e-88*(1.0 - cos(theta)**2)**23*(1.39566281525285e+107*cos(theta)**40 - 6.36618126255684e+107*cos(theta)**38 + 1.3240903631886e+108*cos(theta)**36 - 1.66502380999764e+108*cos(theta)**34 + 1.41527023849799e+108*cos(theta)**32 - 8.61317838398777e+107*cos(theta)**30 + 3.87860517291375e+107*cos(theta)**28 - 1.31726213419712e+107*cos(theta)**26 + 3.40852064979351e+106*cos(theta)**24 - 6.74373978023662e+105*cos(theta)**22 + 1.01817247662396e+105*cos(theta)**20 - 1.16467652353132e+104*cos(theta)**18 + 9.96619172820426e+102*cos(theta)**16 - 6.25820516684726e+101*cos(theta)**14 + 2.80540231617291e+100*cos(theta)**12 - 8.63200712668587e+98*cos(theta)**10 + 1.72180993218468e+97*cos(theta)**8 - 2.04023182823407e+95*cos(theta)**6 + 1.24101692714968e+93*cos(theta)**4 - 2.90296357227995e+90*cos(theta)**2 + 1.09133968882705e+87)*cos(46*phi)

#@torch.jit.script
def Yl86_m47(theta, phi):
    return 6.14512390159355e-90*(1.0 - cos(theta)**2)**23.5*(5.58265126101138e+108*cos(theta)**39 - 2.4191488797716e+109*cos(theta)**37 + 4.76672530747895e+109*cos(theta)**35 - 5.66108095399196e+109*cos(theta)**33 + 4.52886476319357e+109*cos(theta)**31 - 2.58395351519633e+109*cos(theta)**29 + 1.08600944841585e+109*cos(theta)**27 - 3.42488154891252e+108*cos(theta)**25 + 8.18044955950442e+107*cos(theta)**23 - 1.48362275165206e+107*cos(theta)**21 + 2.03634495324792e+106*cos(theta)**19 - 2.09641774235638e+105*cos(theta)**17 + 1.59459067651268e+104*cos(theta)**15 - 8.76148723358616e+102*cos(theta)**13 + 3.36648277940749e+101*cos(theta)**11 - 8.63200712668587e+99*cos(theta)**9 + 1.37744794574775e+98*cos(theta)**7 - 1.22413909694044e+96*cos(theta)**5 + 4.96406770859871e+93*cos(theta)**3 - 5.8059271445599e+90*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl86_m48(theta, phi):
    return 8.50052876115164e-92*(1.0 - cos(theta)**2)**24*(2.17723399179444e+110*cos(theta)**38 - 8.95085085515491e+110*cos(theta)**36 + 1.66835385761763e+111*cos(theta)**34 - 1.86815671481735e+111*cos(theta)**32 + 1.40394807659001e+111*cos(theta)**30 - 7.49346519406936e+110*cos(theta)**28 + 2.93222551072279e+110*cos(theta)**26 - 8.5622038722813e+109*cos(theta)**24 + 1.88150339868602e+109*cos(theta)**22 - 3.11560777846932e+108*cos(theta)**20 + 3.86905541117105e+107*cos(theta)**18 - 3.56391016200584e+106*cos(theta)**16 + 2.39188601476902e+105*cos(theta)**14 - 1.1389933403662e+104*cos(theta)**12 + 3.70313105734824e+102*cos(theta)**10 - 7.76880641401729e+100*cos(theta)**8 + 9.64213562023422e+98*cos(theta)**6 - 6.12069548470221e+96*cos(theta)**4 + 1.48922031257961e+94*cos(theta)**2 - 5.8059271445599e+90)*cos(48*phi)

#@torch.jit.script
def Yl86_m49(theta, phi):
    return 1.18682656471811e-93*(1.0 - cos(theta)**2)**24.5*(8.27348916881887e+111*cos(theta)**37 - 3.22230630785577e+112*cos(theta)**35 + 5.67240311589995e+112*cos(theta)**33 - 5.97810148741551e+112*cos(theta)**31 + 4.21184422977002e+112*cos(theta)**29 - 2.09817025433942e+112*cos(theta)**27 + 7.62378632787926e+111*cos(theta)**25 - 2.05492892934751e+111*cos(theta)**23 + 4.13930747710924e+110*cos(theta)**21 - 6.23121555693864e+109*cos(theta)**19 + 6.96429974010789e+108*cos(theta)**17 - 5.70225625920935e+107*cos(theta)**15 + 3.34864042067663e+106*cos(theta)**13 - 1.36679200843944e+105*cos(theta)**11 + 3.70313105734824e+103*cos(theta)**9 - 6.21504513121383e+101*cos(theta)**7 + 5.78528137214053e+99*cos(theta)**5 - 2.44827819388089e+97*cos(theta)**3 + 2.97844062515923e+94*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl86_m50(theta, phi):
    return 1.67308090398789e-95*(1.0 - cos(theta)**2)**25*(3.06119099246298e+113*cos(theta)**36 - 1.12780720774952e+114*cos(theta)**34 + 1.87189302824698e+114*cos(theta)**32 - 1.85321146109881e+114*cos(theta)**30 + 1.22143482663331e+114*cos(theta)**28 - 5.66505968671644e+113*cos(theta)**26 + 1.90594658196982e+113*cos(theta)**24 - 4.72633653749927e+112*cos(theta)**22 + 8.6925457019294e+111*cos(theta)**20 - 1.18393095581834e+111*cos(theta)**18 + 1.18393095581834e+110*cos(theta)**16 - 8.55338438881402e+108*cos(theta)**14 + 4.35323254687962e+107*cos(theta)**12 - 1.50347120928339e+106*cos(theta)**10 + 3.33281795161342e+104*cos(theta)**8 - 4.35053159184968e+102*cos(theta)**6 + 2.89264068607027e+100*cos(theta)**4 - 7.34483458164266e+97*cos(theta)**2 + 2.97844062515923e+94)*cos(50*phi)

#@torch.jit.script
def Yl86_m51(theta, phi):
    return 2.38234913716956e-97*(1.0 - cos(theta)**2)**25.5*(1.10202875728667e+115*cos(theta)**35 - 3.83454450634836e+115*cos(theta)**33 + 5.99005769039035e+115*cos(theta)**31 - 5.55963438329643e+115*cos(theta)**29 + 3.42001751457326e+115*cos(theta)**27 - 1.47291551854627e+115*cos(theta)**25 + 4.57427179672756e+114*cos(theta)**23 - 1.03979403824984e+114*cos(theta)**21 + 1.73850914038588e+113*cos(theta)**19 - 2.13107572047301e+112*cos(theta)**17 + 1.89428952930935e+111*cos(theta)**15 - 1.19747381443396e+110*cos(theta)**13 + 5.22387905625554e+108*cos(theta)**11 - 1.50347120928339e+107*cos(theta)**9 + 2.66625436129073e+105*cos(theta)**7 - 2.61031895510981e+103*cos(theta)**5 + 1.15705627442811e+101*cos(theta)**3 - 1.46896691632853e+98*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl86_m52(theta, phi):
    return 3.42792919621603e-99*(1.0 - cos(theta)**2)**26*(3.85710065050336e+116*cos(theta)**34 - 1.26539968709496e+117*cos(theta)**32 + 1.85691788402101e+117*cos(theta)**30 - 1.61229397115596e+117*cos(theta)**28 + 9.23404728934779e+116*cos(theta)**26 - 3.68228879636568e+116*cos(theta)**24 + 1.05208251324734e+116*cos(theta)**22 - 2.18356748032466e+115*cos(theta)**20 + 3.30316736673317e+114*cos(theta)**18 - 3.62282872480412e+113*cos(theta)**16 + 2.84143429396402e+112*cos(theta)**14 - 1.55671595876415e+111*cos(theta)**12 + 5.7462669618811e+109*cos(theta)**10 - 1.35312408835505e+108*cos(theta)**8 + 1.86637805290351e+106*cos(theta)**6 - 1.3051594775549e+104*cos(theta)**4 + 3.47116882328432e+101*cos(theta)**2 - 1.46896691632853e+98)*cos(52*phi)

#@torch.jit.script
def Yl86_m53(theta, phi):
    return 4.98637554963799e-101*(1.0 - cos(theta)**2)**26.5*(1.31141422117114e+118*cos(theta)**33 - 4.04927899870387e+118*cos(theta)**31 + 5.57075365206302e+118*cos(theta)**29 - 4.5144231192367e+118*cos(theta)**27 + 2.40085229523043e+118*cos(theta)**25 - 8.83749311127764e+117*cos(theta)**23 + 2.31458152914414e+117*cos(theta)**21 - 4.36713496064933e+116*cos(theta)**19 + 5.94570126011971e+115*cos(theta)**17 - 5.7965259596866e+114*cos(theta)**15 + 3.97800801154963e+113*cos(theta)**13 - 1.86805915051698e+112*cos(theta)**11 + 5.7462669618811e+110*cos(theta)**9 - 1.08249927068404e+109*cos(theta)**7 + 1.11982683174211e+107*cos(theta)**5 - 5.22063791021962e+104*cos(theta)**3 + 6.94233764656864e+101*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl86_m54(theta, phi):
    return 7.33607895109391e-103*(1.0 - cos(theta)**2)**27*(4.32766692986476e+119*cos(theta)**32 - 1.2552764895982e+120*cos(theta)**30 + 1.61551855909828e+120*cos(theta)**28 - 1.21889424219391e+120*cos(theta)**26 + 6.00213073807607e+119*cos(theta)**24 - 2.03262341559386e+119*cos(theta)**22 + 4.8606212112027e+118*cos(theta)**20 - 8.29755642523373e+117*cos(theta)**18 + 1.01076921422035e+117*cos(theta)**16 - 8.6947889395299e+115*cos(theta)**14 + 5.17141041501451e+114*cos(theta)**12 - 2.05486506556868e+113*cos(theta)**10 + 5.17164026569299e+111*cos(theta)**8 - 7.57749489478826e+109*cos(theta)**6 + 5.59913415871054e+107*cos(theta)**4 - 1.56619137306588e+105*cos(theta)**2 + 6.94233764656864e+101)*cos(54*phi)

#@torch.jit.script
def Yl86_m55(theta, phi):
    return 1.09214286055077e-104*(1.0 - cos(theta)**2)**27.5*(1.38485341755672e+121*cos(theta)**31 - 3.7658294687946e+121*cos(theta)**29 + 4.52345196547517e+121*cos(theta)**27 - 3.16912502970416e+121*cos(theta)**25 + 1.44051137713826e+121*cos(theta)**23 - 4.47177151430649e+120*cos(theta)**21 + 9.72124242240541e+119*cos(theta)**19 - 1.49356015654207e+119*cos(theta)**17 + 1.61723074275256e+118*cos(theta)**15 - 1.21727045153419e+117*cos(theta)**13 + 6.20569249801742e+115*cos(theta)**11 - 2.05486506556868e+114*cos(theta)**9 + 4.13731221255439e+112*cos(theta)**7 - 4.54649693687296e+110*cos(theta)**5 + 2.23965366348422e+108*cos(theta)**3 - 3.13238274613177e+105*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl86_m56(theta, phi):
    return 1.64609324218092e-106*(1.0 - cos(theta)**2)**28*(4.29304559442585e+122*cos(theta)**30 - 1.09209054595043e+123*cos(theta)**28 + 1.2213320306783e+123*cos(theta)**26 - 7.92281257426041e+122*cos(theta)**24 + 3.31317616741799e+122*cos(theta)**22 - 9.39072018004362e+121*cos(theta)**20 + 1.84703606025703e+121*cos(theta)**18 - 2.53905226612152e+120*cos(theta)**16 + 2.42584611412884e+119*cos(theta)**14 - 1.58245158699444e+118*cos(theta)**12 + 6.82626174781916e+116*cos(theta)**10 - 1.84937855901181e+115*cos(theta)**8 + 2.89611854878807e+113*cos(theta)**6 - 2.27324846843648e+111*cos(theta)**4 + 6.71896099045265e+108*cos(theta)**2 - 3.13238274613177e+105)*cos(56*phi)

#@torch.jit.script
def Yl86_m57(theta, phi):
    return 2.51319267873586e-108*(1.0 - cos(theta)**2)**28.5*(1.28791367832775e+124*cos(theta)**29 - 3.05785352866122e+124*cos(theta)**27 + 3.17546327976357e+124*cos(theta)**25 - 1.9014750178225e+124*cos(theta)**23 + 7.28898756831957e+123*cos(theta)**21 - 1.87814403600872e+123*cos(theta)**19 + 3.32466490846265e+122*cos(theta)**17 - 4.06248362579443e+121*cos(theta)**15 + 3.39618455978038e+120*cos(theta)**13 - 1.89894190439333e+119*cos(theta)**11 + 6.82626174781916e+117*cos(theta)**9 - 1.47950284720945e+116*cos(theta)**7 + 1.73767112927284e+114*cos(theta)**5 - 9.09299387374591e+111*cos(theta)**3 + 1.34379219809053e+109*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl86_m58(theta, phi):
    return 3.88906803651622e-110*(1.0 - cos(theta)**2)**29*(3.73494966715049e+125*cos(theta)**28 - 8.25620452738529e+125*cos(theta)**26 + 7.93865819940893e+125*cos(theta)**24 - 4.37339254099175e+125*cos(theta)**22 + 1.53068738934711e+125*cos(theta)**20 - 3.56847366841658e+124*cos(theta)**18 + 5.6519303443865e+123*cos(theta)**16 - 6.09372543869165e+122*cos(theta)**14 + 4.41503992771449e+121*cos(theta)**12 - 2.08883609483266e+120*cos(theta)**10 + 6.14363557303724e+118*cos(theta)**8 - 1.03565199304662e+117*cos(theta)**6 + 8.68835564636422e+114*cos(theta)**4 - 2.72789816212377e+112*cos(theta)**2 + 1.34379219809053e+109)*cos(58*phi)

#@torch.jit.script
def Yl86_m59(theta, phi):
    return 6.10355024536255e-112*(1.0 - cos(theta)**2)**29.5*(1.04578590680214e+127*cos(theta)**27 - 2.14661317712017e+127*cos(theta)**25 + 1.90527796785814e+127*cos(theta)**23 - 9.62146359018184e+126*cos(theta)**21 + 3.06137477869422e+126*cos(theta)**19 - 6.42325260314984e+125*cos(theta)**17 + 9.04308855101841e+124*cos(theta)**15 - 8.53121561416831e+123*cos(theta)**13 + 5.29804791325739e+122*cos(theta)**11 - 2.08883609483266e+121*cos(theta)**9 + 4.91490845842979e+119*cos(theta)**7 - 6.21391195827969e+117*cos(theta)**5 + 3.47534225854569e+115*cos(theta)**3 - 5.45579632424755e+112*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl86_m60(theta, phi):
    return 9.72129705504536e-114*(1.0 - cos(theta)**2)**30*(2.82362194836577e+128*cos(theta)**26 - 5.36653294280044e+128*cos(theta)**24 + 4.38213932607373e+128*cos(theta)**22 - 2.02050735393819e+128*cos(theta)**20 + 5.81661207951902e+127*cos(theta)**18 - 1.09195294253547e+127*cos(theta)**16 + 1.35646328265276e+126*cos(theta)**14 - 1.10905802984188e+125*cos(theta)**12 + 5.82785270458313e+123*cos(theta)**10 - 1.8799524853494e+122*cos(theta)**8 + 3.44043592090086e+120*cos(theta)**6 - 3.10695597913985e+118*cos(theta)**4 + 1.04260267756371e+116*cos(theta)**2 - 5.45579632424755e+112)*cos(60*phi)

#@torch.jit.script
def Yl86_m61(theta, phi):
    return 1.57245734250362e-115*(1.0 - cos(theta)**2)**30.5*(7.341417065751e+129*cos(theta)**25 - 1.2879679062721e+130*cos(theta)**23 + 9.6407065173622e+129*cos(theta)**21 - 4.04101470787637e+129*cos(theta)**19 + 1.04699017431342e+129*cos(theta)**17 - 1.74712470805676e+128*cos(theta)**15 + 1.89904859571387e+127*cos(theta)**13 - 1.33086963581026e+126*cos(theta)**11 + 5.82785270458313e+124*cos(theta)**9 - 1.50396198827952e+123*cos(theta)**7 + 2.06426155254051e+121*cos(theta)**5 - 1.24278239165594e+119*cos(theta)**3 + 2.08520535512741e+116*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl86_m62(theta, phi):
    return 2.58510394688469e-117*(1.0 - cos(theta)**2)**31*(1.83535426643775e+131*cos(theta)**24 - 2.96232618442584e+131*cos(theta)**22 + 2.02454836864606e+131*cos(theta)**20 - 7.67792794496511e+130*cos(theta)**18 + 1.77988329633282e+130*cos(theta)**16 - 2.62068706208513e+129*cos(theta)**14 + 2.46876317442802e+128*cos(theta)**12 - 1.46395659939128e+127*cos(theta)**10 + 5.24506743412481e+125*cos(theta)**8 - 1.05277339179566e+124*cos(theta)**6 + 1.03213077627026e+122*cos(theta)**4 - 3.72834717496781e+119*cos(theta)**2 + 2.08520535512741e+116)*cos(62*phi)

#@torch.jit.script
def Yl86_m63(theta, phi):
    return 4.32294047645489e-119*(1.0 - cos(theta)**2)**31.5*(4.4048502394506e+132*cos(theta)**23 - 6.51711760573685e+132*cos(theta)**21 + 4.04909673729212e+132*cos(theta)**19 - 1.38202703009372e+132*cos(theta)**17 + 2.84781327413251e+131*cos(theta)**15 - 3.66896188691919e+130*cos(theta)**13 + 2.96251580931363e+129*cos(theta)**11 - 1.46395659939128e+128*cos(theta)**9 + 4.19605394729985e+126*cos(theta)**7 - 6.31664035077397e+124*cos(theta)**5 + 4.12852310508103e+122*cos(theta)**3 - 7.45669434993563e+119*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl86_m64(theta, phi):
    return 7.35986262532712e-121*(1.0 - cos(theta)**2)**32*(1.01311555507364e+134*cos(theta)**22 - 1.36859469720474e+134*cos(theta)**20 + 7.69328380085504e+133*cos(theta)**18 - 2.34944595115932e+133*cos(theta)**16 + 4.27171991119877e+132*cos(theta)**14 - 4.76965045299494e+131*cos(theta)**12 + 3.25876739024499e+130*cos(theta)**10 - 1.31756093945215e+129*cos(theta)**8 + 2.9372377631099e+127*cos(theta)**6 - 3.15832017538699e+125*cos(theta)**4 + 1.23855693152431e+123*cos(theta)**2 - 7.45669434993563e+119)*cos(64*phi)

#@torch.jit.script
def Yl86_m65(theta, phi):
    return 1.27693824371294e-122*(1.0 - cos(theta)**2)**32.5*(2.228854221162e+135*cos(theta)**21 - 2.73718939440948e+135*cos(theta)**19 + 1.38479108415391e+135*cos(theta)**17 - 3.75911352185492e+134*cos(theta)**15 + 5.98040787567828e+133*cos(theta)**13 - 5.72358054359393e+132*cos(theta)**11 + 3.25876739024499e+131*cos(theta)**9 - 1.05404875156172e+130*cos(theta)**7 + 1.76234265786594e+128*cos(theta)**5 - 1.26332807015479e+126*cos(theta)**3 + 2.47711386304862e+123*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl86_m66(theta, phi):
    return 2.26015619141157e-124*(1.0 - cos(theta)**2)**33*(4.68059386444021e+136*cos(theta)**20 - 5.20065984937801e+136*cos(theta)**18 + 2.35414484306164e+136*cos(theta)**16 - 5.63867028278238e+135*cos(theta)**14 + 7.77453023838176e+134*cos(theta)**12 - 6.29593859795333e+133*cos(theta)**10 + 2.93289065122049e+132*cos(theta)**8 - 7.37834126093206e+130*cos(theta)**6 + 8.81171328932969e+128*cos(theta)**4 - 3.78998421046438e+126*cos(theta)**2 + 2.47711386304862e+123)*cos(66*phi)

#@torch.jit.script
def Yl86_m67(theta, phi):
    return 4.08580597787152e-126*(1.0 - cos(theta)**2)**33.5*(9.36118772888041e+137*cos(theta)**19 - 9.36118772888041e+137*cos(theta)**17 + 3.76663174889863e+137*cos(theta)**15 - 7.89413839589533e+136*cos(theta)**13 + 9.32943628605811e+135*cos(theta)**11 - 6.29593859795333e+134*cos(theta)**9 + 2.34631252097639e+133*cos(theta)**7 - 4.42700475655924e+131*cos(theta)**5 + 3.52468531573188e+129*cos(theta)**3 - 7.57996842092876e+126*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl86_m68(theta, phi):
    return 7.55336686206047e-128*(1.0 - cos(theta)**2)**34*(1.77862566848728e+139*cos(theta)**18 - 1.59140191390967e+139*cos(theta)**16 + 5.64994762334794e+138*cos(theta)**14 - 1.02623799146639e+138*cos(theta)**12 + 1.02623799146639e+137*cos(theta)**10 - 5.66634473815799e+135*cos(theta)**8 + 1.64241876468348e+134*cos(theta)**6 - 2.21350237827962e+132*cos(theta)**4 + 1.05740559471956e+130*cos(theta)**2 - 7.57996842092876e+126)*cos(68*phi)

#@torch.jit.script
def Yl86_m69(theta, phi):
    return 1.43000803257229e-129*(1.0 - cos(theta)**2)**34.5*(3.2015262032771e+140*cos(theta)**17 - 2.54624306225547e+140*cos(theta)**15 + 7.90992667268712e+139*cos(theta)**13 - 1.23148558975967e+139*cos(theta)**11 + 1.02623799146639e+138*cos(theta)**9 - 4.5330757905264e+136*cos(theta)**7 + 9.85451258810086e+134*cos(theta)**5 - 8.85400951311847e+132*cos(theta)**3 + 2.11481118943913e+130*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl86_m70(theta, phi):
    return 2.77684550159859e-131*(1.0 - cos(theta)**2)**35*(5.44259454557107e+141*cos(theta)**16 - 3.81936459338321e+141*cos(theta)**14 + 1.02829046744933e+141*cos(theta)**12 - 1.35463414873564e+140*cos(theta)**10 + 9.23614192319753e+138*cos(theta)**8 - 3.17315305336848e+137*cos(theta)**6 + 4.92725629405043e+135*cos(theta)**4 - 2.65620285393554e+133*cos(theta)**2 + 2.11481118943913e+130)*cos(70*phi)

#@torch.jit.script
def Yl86_m71(theta, phi):
    return 5.54040993754688e-133*(1.0 - cos(theta)**2)**35.5*(8.70815127291371e+142*cos(theta)**15 - 5.34711043073649e+142*cos(theta)**13 + 1.23394856093919e+142*cos(theta)**11 - 1.35463414873564e+141*cos(theta)**9 + 7.38891353855802e+139*cos(theta)**7 - 1.90389183202109e+138*cos(theta)**5 + 1.97090251762017e+136*cos(theta)**3 - 5.31240570787108e+133*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl86_m72(theta, phi):
    return 1.13806672766906e-134*(1.0 - cos(theta)**2)**36*(1.30622269093706e+144*cos(theta)**14 - 6.95124355995744e+143*cos(theta)**12 + 1.35734341703311e+143*cos(theta)**10 - 1.21917073386207e+142*cos(theta)**8 + 5.17223947699062e+140*cos(theta)**6 - 9.51945916010543e+138*cos(theta)**4 + 5.91270755286052e+136*cos(theta)**2 - 5.31240570787108e+133)*cos(72*phi)

#@torch.jit.script
def Yl86_m73(theta, phi):
    return 2.41215464093889e-136*(1.0 - cos(theta)**2)**36.5*(1.82871176731188e+145*cos(theta)**13 - 8.34149227194893e+144*cos(theta)**11 + 1.35734341703311e+144*cos(theta)**9 - 9.75336587089659e+142*cos(theta)**7 + 3.10334368619437e+141*cos(theta)**5 - 3.80778366404217e+139*cos(theta)**3 + 1.1825415105721e+137*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl86_m74(theta, phi):
    return 5.2889989291103e-138*(1.0 - cos(theta)**2)**37*(2.37732529750544e+146*cos(theta)**12 - 9.17564149914382e+145*cos(theta)**10 + 1.2216090753298e+145*cos(theta)**8 - 6.82735610962761e+143*cos(theta)**6 + 1.55167184309719e+142*cos(theta)**4 - 1.14233509921265e+140*cos(theta)**2 + 1.1825415105721e+137)*cos(74*phi)

#@torch.jit.script
def Yl86_m75(theta, phi):
    return 1.20328892097281e-139*(1.0 - cos(theta)**2)**37.5*(2.85279035700653e+147*cos(theta)**11 - 9.17564149914382e+146*cos(theta)**9 + 9.77287260263839e+145*cos(theta)**7 - 4.09641366577657e+144*cos(theta)**5 + 6.20668737238874e+142*cos(theta)**3 - 2.2846701984253e+140*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl86_m76(theta, phi):
    return 2.85046733260192e-141*(1.0 - cos(theta)**2)**38*(3.13806939270719e+148*cos(theta)**10 - 8.25807734922944e+147*cos(theta)**8 + 6.84101082184687e+146*cos(theta)**6 - 2.04820683288828e+145*cos(theta)**4 + 1.86200621171662e+143*cos(theta)**2 - 2.2846701984253e+140)*cos(76*phi)

#@torch.jit.script
def Yl86_m77(theta, phi):
    return 7.06028554586467e-143*(1.0 - cos(theta)**2)**38.5*(3.13806939270719e+149*cos(theta)**9 - 6.60646187938355e+148*cos(theta)**7 + 4.10460649310812e+147*cos(theta)**5 - 8.19282733155314e+145*cos(theta)**3 + 3.72401242343324e+143*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl86_m78(theta, phi):
    return 1.83771892284239e-144*(1.0 - cos(theta)**2)**39*(2.82426245343647e+150*cos(theta)**8 - 4.62452331556848e+149*cos(theta)**6 + 2.05230324655406e+148*cos(theta)**4 - 2.45784819946594e+146*cos(theta)**2 + 3.72401242343324e+143)*cos(78*phi)

#@torch.jit.script
def Yl86_m79(theta, phi):
    return 5.0581548613413e-146*(1.0 - cos(theta)**2)**39.5*(2.25940996274917e+151*cos(theta)**7 - 2.77471398934109e+150*cos(theta)**5 + 8.20921298621624e+148*cos(theta)**3 - 4.91569639893188e+146*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl86_m80(theta, phi):
    return 1.4838467766475e-147*(1.0 - cos(theta)**2)**40*(1.58158697392442e+152*cos(theta)**6 - 1.38735699467055e+151*cos(theta)**4 + 2.46276389586487e+149*cos(theta)**2 - 4.91569639893188e+146)*cos(80*phi)

#@torch.jit.script
def Yl86_m81(theta, phi):
    return 4.68765020418527e-149*(1.0 - cos(theta)**2)**40.5*(9.48952184354653e+152*cos(theta)**5 - 5.54942797868218e+151*cos(theta)**3 + 4.92552779172975e+149*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl86_m82(theta, phi):
    return 1.61739298007621e-150*(1.0 - cos(theta)**2)**41*(4.74476092177326e+153*cos(theta)**4 - 1.66482839360465e+152*cos(theta)**2 + 4.92552779172975e+149)*cos(82*phi)

#@torch.jit.script
def Yl86_m83(theta, phi):
    return 6.22074223106233e-152*(1.0 - cos(theta)**2)**41.5*(1.89790436870931e+154*cos(theta)**3 - 3.32965678720931e+152*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl86_m84(theta, phi):
    return 2.75459095946835e-153*(1.0 - cos(theta)**2)**42*(5.69371310612792e+154*cos(theta)**2 - 3.32965678720931e+152)*cos(84*phi)

#@torch.jit.script
def Yl86_m85(theta, phi):
    return 16.96171027275*(1.0 - cos(theta)**2)**42.5*cos(85*phi)*cos(theta)

#@torch.jit.script
def Yl86_m86(theta, phi):
    return 1.29331828349511*(1.0 - cos(theta)**2)**43*cos(86*phi)

#@torch.jit.script
def Yl87_m_minus_87(theta, phi):
    return 1.29702939093238*(1.0 - cos(theta)**2)**43.5*sin(87*phi)

#@torch.jit.script
def Yl87_m_minus_86(theta, phi):
    return 17.108992720905*(1.0 - cos(theta)**2)**43*sin(86*phi)*cos(theta)

#@torch.jit.script
def Yl87_m_minus_85(theta, phi):
    return 1.61543992435537e-155*(1.0 - cos(theta)**2)**42.5*(9.8501236736013e+156*cos(theta)**2 - 5.69371310612792e+154)*sin(85*phi)

#@torch.jit.script
def Yl87_m_minus_84(theta, phi):
    return 3.66957410742427e-154*(1.0 - cos(theta)**2)**42*(3.2833745578671e+156*cos(theta)**3 - 5.69371310612792e+154*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl87_m_minus_83(theta, phi):
    return 9.59718162005753e-153*(1.0 - cos(theta)**2)**41.5*(8.20843639466775e+155*cos(theta)**4 - 2.84685655306396e+154*cos(theta)**2 + 8.32414196802327e+151)*sin(83*phi)

#@torch.jit.script
def Yl87_m_minus_82(theta, phi):
    return 2.79803521763245e-151*(1.0 - cos(theta)**2)**41*(1.64168727893355e+155*cos(theta)**5 - 9.48952184354653e+153*cos(theta)**3 + 8.32414196802327e+151*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl87_m_minus_81(theta, phi):
    return 8.90988613519781e-150*(1.0 - cos(theta)**2)**40.5*(2.73614546488925e+154*cos(theta)**6 - 2.37238046088663e+153*cos(theta)**4 + 4.16207098401164e+151*cos(theta)**2 - 8.20921298621624e+148)*sin(81*phi)

#@torch.jit.script
def Yl87_m_minus_80(theta, phi):
    return 3.05545445765463e-148*(1.0 - cos(theta)**2)**40*(3.90877923555607e+153*cos(theta)**7 - 4.74476092177326e+152*cos(theta)**5 + 1.38735699467055e+151*cos(theta)**3 - 8.20921298621624e+148*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl87_m_minus_79(theta, phi):
    return 1.11680935685474e-146*(1.0 - cos(theta)**2)**39.5*(4.88597404444509e+152*cos(theta)**8 - 7.90793486962211e+151*cos(theta)**6 + 3.46839248667636e+150*cos(theta)**4 - 4.10460649310812e+148*cos(theta)**2 + 6.14462049866485e+145)*sin(79*phi)

#@torch.jit.script
def Yl87_m_minus_78(theta, phi):
    return 4.31672460379404e-145*(1.0 - cos(theta)**2)**39*(5.42886004938343e+151*cos(theta)**9 - 1.12970498137459e+151*cos(theta)**7 + 6.93678497335273e+149*cos(theta)**5 - 1.36820216436937e+148*cos(theta)**3 + 6.14462049866485e+145*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl87_m_minus_77(theta, phi):
    return 1.75346182317299e-143*(1.0 - cos(theta)**2)**38.5*(5.42886004938343e+150*cos(theta)**10 - 1.41213122671823e+150*cos(theta)**8 + 1.15613082889212e+149*cos(theta)**6 - 3.42050541092343e+147*cos(theta)**4 + 3.07231024933243e+145*cos(theta)**2 - 3.72401242343324e+142)*sin(77*phi)

#@torch.jit.script
def Yl87_m_minus_76(theta, phi):
    return 7.44756978553847e-142*(1.0 - cos(theta)**2)**38*(4.9353273176213e+149*cos(theta)**11 - 1.56903469635359e+149*cos(theta)**9 + 1.65161546984589e+148*cos(theta)**7 - 6.84101082184687e+146*cos(theta)**5 + 1.02410341644414e+145*cos(theta)**3 - 3.72401242343324e+142*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl87_m_minus_75(theta, phi):
    return 3.29381351035043e-140*(1.0 - cos(theta)**2)**37.5*(4.11277276468442e+148*cos(theta)**12 - 1.56903469635359e+148*cos(theta)**10 + 2.06451933730736e+147*cos(theta)**8 - 1.14016847030781e+146*cos(theta)**6 + 2.56025854111036e+144*cos(theta)**4 - 1.86200621171662e+142*cos(theta)**2 + 1.90389183202109e+139)*sin(75*phi)

#@torch.jit.script
def Yl87_m_minus_74(theta, phi):
    return 1.51156974270712e-138*(1.0 - cos(theta)**2)**37*(3.16367135744955e+147*cos(theta)**13 - 1.42639517850327e+147*cos(theta)**11 + 2.29391037478595e+146*cos(theta)**9 - 1.62881210043973e+145*cos(theta)**7 + 5.12051708222071e+143*cos(theta)**5 - 6.20668737238874e+141*cos(theta)**3 + 1.90389183202109e+139*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl87_m_minus_73(theta, phi):
    return 7.1763753512832e-137*(1.0 - cos(theta)**2)**36.5*(2.25976525532111e+146*cos(theta)**14 - 1.18866264875272e+146*cos(theta)**12 + 2.29391037478595e+145*cos(theta)**10 - 2.03601512554966e+144*cos(theta)**8 + 8.53419513703452e+142*cos(theta)**6 - 1.55167184309719e+141*cos(theta)**4 + 9.51945916010543e+138*cos(theta)**2 - 8.44672507551502e+135)*sin(73*phi)

#@torch.jit.script
def Yl87_m_minus_72(theta, phi):
    return 3.51569156266604e-135*(1.0 - cos(theta)**2)**36*(1.50651017021407e+145*cos(theta)**15 - 9.1435588365594e+144*cos(theta)**13 + 2.08537306798723e+144*cos(theta)**11 - 2.26223902838851e+143*cos(theta)**9 + 1.21917073386207e+142*cos(theta)**7 - 3.10334368619437e+140*cos(theta)**5 + 3.17315305336848e+138*cos(theta)**3 - 8.44672507551502e+135*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl87_m_minus_71(theta, phi):
    return 1.77324735287298e-133*(1.0 - cos(theta)**2)**35.5*(9.41568856383795e+143*cos(theta)**16 - 6.53111345468528e+143*cos(theta)**14 + 1.73781088998936e+143*cos(theta)**12 - 2.26223902838852e+142*cos(theta)**10 + 1.52396341732759e+141*cos(theta)**8 - 5.17223947699062e+139*cos(theta)**6 + 7.93288263342119e+137*cos(theta)**4 - 4.22336253775751e+135*cos(theta)**2 + 3.32025356741943e+132)*sin(71*phi)

#@torch.jit.script
def Yl87_m_minus_70(theta, phi):
    return 9.19014416896121e-132*(1.0 - cos(theta)**2)**35*(5.53864033166938e+142*cos(theta)**17 - 4.35407563645686e+142*cos(theta)**15 + 1.33677760768412e+142*cos(theta)**13 - 2.05658093489865e+141*cos(theta)**11 + 1.69329268591955e+140*cos(theta)**9 - 7.38891353855802e+138*cos(theta)**7 + 1.58657652668424e+137*cos(theta)**5 - 1.40778751258584e+135*cos(theta)**3 + 3.32025356741943e+132*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl87_m_minus_69(theta, phi):
    return 4.88549308735178e-130*(1.0 - cos(theta)**2)**34.5*(3.07702240648299e+141*cos(theta)**18 - 2.72129727278554e+141*cos(theta)**16 + 9.54841148345802e+140*cos(theta)**14 - 1.71381744574888e+140*cos(theta)**12 + 1.69329268591955e+139*cos(theta)**10 - 9.23614192319753e+137*cos(theta)**8 + 2.6442942111404e+136*cos(theta)**6 - 3.51946878146459e+134*cos(theta)**4 + 1.66012678370971e+132*cos(theta)**2 - 1.17489510524396e+129)*sin(69*phi)

#@torch.jit.script
def Yl87_m_minus_68(theta, phi):
    return 2.65979094257895e-128*(1.0 - cos(theta)**2)**34*(1.61948547709631e+140*cos(theta)**19 - 1.60076310163855e+140*cos(theta)**17 + 6.36560765563868e+139*cos(theta)**15 - 1.31832111211452e+139*cos(theta)**13 + 1.53935698719959e+138*cos(theta)**11 - 1.02623799146639e+137*cos(theta)**9 + 3.777563158772e+135*cos(theta)**7 - 7.03893756292919e+133*cos(theta)**5 + 5.53375594569904e+131*cos(theta)**3 - 1.17489510524396e+129*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl87_m_minus_67(theta, phi):
    return 1.48090892226691e-126*(1.0 - cos(theta)**2)**33.5*(8.09742738548156e+138*cos(theta)**20 - 8.89312834243639e+138*cos(theta)**18 + 3.97850478477417e+138*cos(theta)**16 - 9.41657937224657e+137*cos(theta)**14 + 1.28279748933299e+137*cos(theta)**12 - 1.02623799146639e+136*cos(theta)**10 + 4.72195394846499e+134*cos(theta)**8 - 1.1731562604882e+133*cos(theta)**6 + 1.38343898642476e+131*cos(theta)**4 - 5.87447552621979e+128*cos(theta)**2 + 3.78998421046438e+125)*sin(67*phi)

#@torch.jit.script
def Yl87_m_minus_66(theta, phi):
    return 8.42167267078511e-125*(1.0 - cos(theta)**2)**33*(3.85591780261026e+137*cos(theta)**21 - 4.68059386444021e+137*cos(theta)**19 + 2.3402969322201e+137*cos(theta)**17 - 6.27771958149771e+136*cos(theta)**15 + 9.86767299486916e+135*cos(theta)**13 - 9.32943628605811e+134*cos(theta)**11 + 5.24661549829444e+133*cos(theta)**9 - 1.67593751498314e+132*cos(theta)**7 + 2.76687797284952e+130*cos(theta)**5 - 1.95815850873993e+128*cos(theta)**3 + 3.78998421046438e+125*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl87_m_minus_65(theta, phi):
    return 4.88602194583257e-123*(1.0 - cos(theta)**2)**32.5*(1.75268991027739e+136*cos(theta)**22 - 2.3402969322201e+136*cos(theta)**20 + 1.3001649623445e+136*cos(theta)**18 - 3.92357473843607e+135*cos(theta)**16 + 7.04833785347797e+134*cos(theta)**14 - 7.77453023838176e+133*cos(theta)**12 + 5.24661549829444e+132*cos(theta)**10 - 2.09492189372892e+131*cos(theta)**8 + 4.61146328808254e+129*cos(theta)**6 - 4.89539627184983e+127*cos(theta)**4 + 1.89499210523219e+125*cos(theta)**2 - 1.12596084684028e+122)*sin(65*phi)

#@torch.jit.script
def Yl87_m_minus_64(theta, phi):
    return 2.8889573162515e-121*(1.0 - cos(theta)**2)**32*(7.62039091424953e+134*cos(theta)**23 - 1.114427110581e+135*cos(theta)**21 + 6.84297348602369e+134*cos(theta)**19 - 2.30798514025651e+134*cos(theta)**17 + 4.69889190231865e+133*cos(theta)**15 - 5.98040787567828e+132*cos(theta)**13 + 4.76965045299494e+131*cos(theta)**11 - 2.32769099303214e+130*cos(theta)**9 + 6.58780469726077e+128*cos(theta)**7 - 9.79079254369965e+126*cos(theta)**5 + 6.31664035077397e+124*cos(theta)**3 - 1.12596084684028e+122*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl87_m_minus_63(theta, phi):
    return 1.73914270649208e-119*(1.0 - cos(theta)**2)**31.5*(3.17516288093731e+133*cos(theta)**24 - 5.06557777536819e+133*cos(theta)**22 + 3.42148674301185e+133*cos(theta)**20 - 1.28221396680917e+133*cos(theta)**18 + 2.93680743894915e+132*cos(theta)**16 - 4.27171991119877e+131*cos(theta)**14 + 3.97470871082912e+130*cos(theta)**12 - 2.32769099303214e+129*cos(theta)**10 + 8.23475587157596e+127*cos(theta)**8 - 1.63179875728328e+126*cos(theta)**6 + 1.57916008769349e+124*cos(theta)**4 - 5.6298042342014e+121*cos(theta)**2 + 3.10695597913985e+118)*sin(63*phi)

#@torch.jit.script
def Yl87_m_minus_62(theta, phi):
    return 1.06500305519713e-117*(1.0 - cos(theta)**2)**31*(1.27006515237492e+132*cos(theta)**25 - 2.2024251197253e+132*cos(theta)**23 + 1.62927940143421e+132*cos(theta)**21 - 6.74849456215354e+131*cos(theta)**19 + 1.72753378761715e+131*cos(theta)**17 - 2.84781327413251e+130*cos(theta)**15 + 3.05746823909932e+129*cos(theta)**13 - 2.11608272093831e+128*cos(theta)**11 + 9.14972874619551e+126*cos(theta)**9 - 2.33114108183325e+125*cos(theta)**7 + 3.15832017538699e+123*cos(theta)**5 - 1.87660141140047e+121*cos(theta)**3 + 3.10695597913985e+118*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl87_m_minus_61(theta, phi):
    return 6.62873506814228e-116*(1.0 - cos(theta)**2)**30.5*(4.88486597067278e+130*cos(theta)**26 - 9.17677133218874e+130*cos(theta)**24 + 7.4058154610646e+130*cos(theta)**22 - 3.37424728107677e+130*cos(theta)**20 + 9.59740993120638e+129*cos(theta)**18 - 1.77988329633282e+129*cos(theta)**16 + 2.18390588507095e+128*cos(theta)**14 - 1.76340226744859e+127*cos(theta)**12 + 9.14972874619551e+125*cos(theta)**10 - 2.91392635229156e+124*cos(theta)**8 + 5.26386695897831e+122*cos(theta)**6 - 4.69150352850117e+120*cos(theta)**4 + 1.55347798956992e+118*cos(theta)**2 - 8.0200205966439e+114)*sin(61*phi)

#@torch.jit.script
def Yl87_m_minus_60(theta, phi):
    return 4.19028344984038e-114*(1.0 - cos(theta)**2)**30*(1.8092096187677e+129*cos(theta)**27 - 3.6707085328755e+129*cos(theta)**25 + 3.21991976568026e+129*cos(theta)**23 - 1.60678441956037e+129*cos(theta)**21 + 5.05126838484547e+128*cos(theta)**19 - 1.04699017431342e+128*cos(theta)**17 + 1.45593725671396e+127*cos(theta)**15 - 1.35646328265276e+126*cos(theta)**13 + 8.3179352238141e+124*cos(theta)**11 - 3.23769594699063e+123*cos(theta)**9 + 7.51980994139758e+121*cos(theta)**7 - 9.38300705700233e+119*cos(theta)**5 + 5.17825996523308e+117*cos(theta)**3 - 8.0200205966439e+114*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl87_m_minus_59(theta, phi):
    return 2.68832075291e-112*(1.0 - cos(theta)**2)**29.5*(6.46146292417034e+127*cos(theta)**28 - 1.41181097418288e+128*cos(theta)**26 + 1.34163323570011e+128*cos(theta)**24 - 7.30356554345621e+127*cos(theta)**22 + 2.52563419242273e+127*cos(theta)**20 - 5.81661207951902e+126*cos(theta)**18 + 9.09960785446227e+125*cos(theta)**16 - 9.68902344751972e+124*cos(theta)**14 + 6.93161268651175e+123*cos(theta)**12 - 3.23769594699063e+122*cos(theta)**10 + 9.39976242674698e+120*cos(theta)**8 - 1.56383450950039e+119*cos(theta)**6 + 1.29456499130827e+117*cos(theta)**4 - 4.01001029832195e+114*cos(theta)**2 + 1.94849868723127e+111)*sin(59*phi)

#@torch.jit.script
def Yl87_m_minus_58(theta, phi):
    return 1.74926864444e-110*(1.0 - cos(theta)**2)**29*(2.22809066350701e+126*cos(theta)**29 - 5.22892953401068e+126*cos(theta)**27 + 5.36653294280044e+126*cos(theta)**25 - 3.17546327976357e+126*cos(theta)**23 + 1.20268294877273e+126*cos(theta)**21 - 3.06137477869422e+125*cos(theta)**19 + 5.35271050262487e+124*cos(theta)**17 - 6.45934896501315e+123*cos(theta)**15 + 5.33200975885519e+122*cos(theta)**13 - 2.94335995180966e+121*cos(theta)**11 + 1.04441804741633e+120*cos(theta)**9 - 2.23404929928627e+118*cos(theta)**7 + 2.58912998261654e+116*cos(theta)**5 - 1.33667009944065e+114*cos(theta)**3 + 1.94849868723127e+111*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl87_m_minus_57(theta, phi):
    return 1.15372190922818e-108*(1.0 - cos(theta)**2)**28.5*(7.42696887835671e+124*cos(theta)**30 - 1.86747483357524e+125*cos(theta)**28 + 2.06405113184632e+125*cos(theta)**26 - 1.32310969990149e+125*cos(theta)**24 + 5.46674067623968e+124*cos(theta)**22 - 1.53068738934711e+124*cos(theta)**20 + 2.97372805701381e+123*cos(theta)**18 - 4.03709310313322e+122*cos(theta)**16 + 3.80857839918228e+121*cos(theta)**14 - 2.45279995984138e+120*cos(theta)**12 + 1.04441804741633e+119*cos(theta)**10 - 2.79256162410784e+117*cos(theta)**8 + 4.31521663769423e+115*cos(theta)**6 - 3.34167524860162e+113*cos(theta)**4 + 9.74249343615634e+110*cos(theta)**2 - 4.47930732696843e+107)*sin(57*phi)

#@torch.jit.script
def Yl87_m_minus_56(theta, phi):
    return 7.70838207698024e-107*(1.0 - cos(theta)**2)**28*(2.39579641237313e+123*cos(theta)**31 - 6.43956839163877e+123*cos(theta)**29 + 7.64463382165304e+123*cos(theta)**27 - 5.29243879960595e+123*cos(theta)**25 + 2.37684377227812e+123*cos(theta)**23 - 7.28898756831958e+122*cos(theta)**21 + 1.56512003000727e+122*cos(theta)**19 - 2.37476064890189e+121*cos(theta)**17 + 2.53905226612152e+120*cos(theta)**15 - 1.88676919987799e+119*cos(theta)**13 + 9.49470952196665e+117*cos(theta)**11 - 3.10284624900871e+116*cos(theta)**9 + 6.16459519670604e+114*cos(theta)**7 - 6.68335049720325e+112*cos(theta)**5 + 3.24749781205211e+110*cos(theta)**3 - 4.47930732696843e+107*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl87_m_minus_55(theta, phi):
    return 5.21442278515843e-105*(1.0 - cos(theta)**2)**27.5*(7.48686378866604e+121*cos(theta)**32 - 2.14652279721292e+122*cos(theta)**30 + 2.73022636487609e+122*cos(theta)**28 - 2.03555338446383e+122*cos(theta)**26 + 9.90351571782551e+121*cos(theta)**24 - 3.31317616741799e+121*cos(theta)**22 + 7.82560015003635e+120*cos(theta)**20 - 1.31931147161216e+120*cos(theta)**18 + 1.58690766632595e+119*cos(theta)**16 - 1.34769228562713e+118*cos(theta)**14 + 7.91225793497221e+116*cos(theta)**12 - 3.10284624900871e+115*cos(theta)**10 + 7.70574399588255e+113*cos(theta)**8 - 1.11389174953387e+112*cos(theta)**6 + 8.11874453013028e+109*cos(theta)**4 - 2.23965366348422e+107*cos(theta)**2 + 9.78869608166178e+103)*sin(55*phi)

#@torch.jit.script
def Yl87_m_minus_54(theta, phi):
    return 3.56949997264925e-103*(1.0 - cos(theta)**2)**27*(2.26874660262607e+120*cos(theta)**33 - 6.92426708778362e+120*cos(theta)**31 + 9.4145736719865e+120*cos(theta)**29 - 7.53908660912529e+120*cos(theta)**27 + 3.9614062871302e+120*cos(theta)**25 - 1.44051137713826e+120*cos(theta)**23 + 3.72647626192207e+119*cos(theta)**21 - 6.94374458743243e+118*cos(theta)**19 + 9.33475097838794e+117*cos(theta)**17 - 8.98461523751423e+116*cos(theta)**15 + 6.08635225767093e+115*cos(theta)**13 - 2.82076931728064e+114*cos(theta)**11 + 8.56193777320284e+112*cos(theta)**9 - 1.59127392790554e+111*cos(theta)**7 + 1.62374890602606e+109*cos(theta)**5 - 7.46551221161405e+106*cos(theta)**3 + 9.78869608166178e+103*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl87_m_minus_53(theta, phi):
    return 2.47147600195587e-101*(1.0 - cos(theta)**2)**26.5*(6.6727841253708e+118*cos(theta)**34 - 2.16383346493238e+119*cos(theta)**32 + 3.1381912239955e+119*cos(theta)**30 - 2.69253093183046e+119*cos(theta)**28 + 1.52361780274239e+119*cos(theta)**26 - 6.00213073807607e+118*cos(theta)**24 + 1.69385284632821e+118*cos(theta)**22 - 3.47187229371622e+117*cos(theta)**20 + 5.18597276577108e+116*cos(theta)**18 - 5.61538452344639e+115*cos(theta)**16 + 4.34739446976495e+114*cos(theta)**14 - 2.35064109773387e+113*cos(theta)**12 + 8.56193777320284e+111*cos(theta)**10 - 1.98909240988192e+110*cos(theta)**8 + 2.70624817671009e+108*cos(theta)**6 - 1.86637805290351e+106*cos(theta)**4 + 4.89434804083089e+103*cos(theta)**2 - 2.04186401369666e+100)*sin(53*phi)

#@torch.jit.script
def Yl87_m_minus_52(theta, phi):
    return 1.73003320136911e-99*(1.0 - cos(theta)**2)**26*(1.90650975010594e+117*cos(theta)**35 - 6.5570711058557e+117*cos(theta)**33 + 1.01231974967597e+118*cos(theta)**31 - 9.28458942010503e+117*cos(theta)**29 + 5.64302889904587e+117*cos(theta)**27 - 2.40085229523043e+117*cos(theta)**25 + 7.36457759273137e+116*cos(theta)**23 - 1.65327252081725e+116*cos(theta)**21 + 2.72945935040583e+115*cos(theta)**19 - 3.30316736673317e+114*cos(theta)**17 + 2.8982629798433e+113*cos(theta)**15 - 1.80818545979528e+112*cos(theta)**13 + 7.78357979382076e+110*cos(theta)**11 - 2.21010267764658e+109*cos(theta)**9 + 3.86606882387156e+107*cos(theta)**7 - 3.73275610580703e+105*cos(theta)**5 + 1.63144934694363e+103*cos(theta)**3 - 2.04186401369666e+100*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl87_m_minus_51(theta, phi):
    return 1.22380743782299e-97*(1.0 - cos(theta)**2)**25.5*(5.29586041696096e+115*cos(theta)**36 - 1.92855032525168e+116*cos(theta)**34 + 3.1634992177374e+116*cos(theta)**32 - 3.09486314003501e+116*cos(theta)**30 + 2.01536746394496e+116*cos(theta)**28 - 9.23404728934779e+115*cos(theta)**26 + 3.0685739969714e+115*cos(theta)**24 - 7.51487509462385e+114*cos(theta)**22 + 1.36472967520292e+114*cos(theta)**20 - 1.83509298151843e+113*cos(theta)**18 + 1.81141436240206e+112*cos(theta)**16 - 1.29156104271092e+111*cos(theta)**14 + 6.48631649485063e+109*cos(theta)**12 - 2.21010267764658e+108*cos(theta)**10 + 4.83258602983945e+106*cos(theta)**8 - 6.22126017634504e+104*cos(theta)**6 + 4.07862336735908e+102*cos(theta)**4 - 1.02093200684833e+100*cos(theta)**2 + 4.08046365646814e+96)*sin(51*phi)

#@torch.jit.script
def Yl87_m_minus_50(theta, phi):
    return 8.74487273590109e-96*(1.0 - cos(theta)**2)**25*(1.43131362620566e+114*cos(theta)**37 - 5.51014378643336e+114*cos(theta)**35 + 9.58636126587091e+114*cos(theta)**33 - 9.98342948398391e+114*cos(theta)**31 + 6.94954297912054e+114*cos(theta)**29 - 3.42001751457326e+114*cos(theta)**27 + 1.22742959878856e+114*cos(theta)**25 - 3.26733699766254e+113*cos(theta)**23 + 6.4987127390615e+112*cos(theta)**21 - 9.65838411325489e+111*cos(theta)**19 + 1.06553786023651e+111*cos(theta)**17 - 8.61040695140612e+109*cos(theta)**15 + 4.98947422680818e+108*cos(theta)**13 - 2.00918425240598e+107*cos(theta)**11 + 5.36954003315495e+105*cos(theta)**9 - 8.88751453763577e+103*cos(theta)**7 + 8.15724673471815e+101*cos(theta)**5 - 3.40310668949443e+99*cos(theta)**3 + 4.08046365646814e+96*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl87_m_minus_49(theta, phi):
    return 6.30965444746346e-94*(1.0 - cos(theta)**2)**24.5*(3.76661480580438e+112*cos(theta)**38 - 1.53059549623149e+113*cos(theta)**36 + 2.8195180193738e+113*cos(theta)**34 - 3.11982171374497e+113*cos(theta)**32 + 2.31651432637351e+113*cos(theta)**30 - 1.22143482663331e+113*cos(theta)**28 + 4.7208830722637e+112*cos(theta)**26 - 1.36139041569273e+112*cos(theta)**24 + 2.95396033593705e+111*cos(theta)**22 - 4.82919205662744e+110*cos(theta)**20 + 5.91965477909171e+109*cos(theta)**18 - 5.38150434462882e+108*cos(theta)**16 + 3.56391016200584e+107*cos(theta)**14 - 1.67432021033832e+106*cos(theta)**12 + 5.36954003315495e+104*cos(theta)**10 - 1.11093931720447e+103*cos(theta)**8 + 1.35954112245303e+101*cos(theta)**6 - 8.50776672373608e+98*cos(theta)**4 + 2.04023182823407e+96*cos(theta)**2 - 7.83800164515586e+92)*sin(49*phi)

#@torch.jit.script
def Yl87_m_minus_48(theta, phi):
    return 4.59523084254623e-92*(1.0 - cos(theta)**2)**24*(9.65798668154969e+110*cos(theta)**39 - 4.13674458440943e+111*cos(theta)**37 + 8.05576576963942e+111*cos(theta)**35 - 9.45400519316658e+111*cos(theta)**33 + 7.47262685926939e+111*cos(theta)**31 - 4.21184422977002e+111*cos(theta)**29 + 1.74847521194952e+111*cos(theta)**27 - 5.4455616627709e+110*cos(theta)**25 + 1.28433058084219e+110*cos(theta)**23 - 2.29961526506069e+109*cos(theta)**21 + 3.11560777846932e+108*cos(theta)**19 - 3.16559079095813e+107*cos(theta)**17 + 2.3759401080039e+106*cos(theta)**15 - 1.28793862333717e+105*cos(theta)**13 + 4.88140003014086e+103*cos(theta)**11 - 1.23437701911608e+102*cos(theta)**9 + 1.94220160350432e+100*cos(theta)**7 - 1.70155334474722e+98*cos(theta)**5 + 6.80077276078024e+95*cos(theta)**3 - 7.83800164515586e+92*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl87_m_minus_47(theta, phi):
    return 3.37679124436137e-90*(1.0 - cos(theta)**2)**23.5*(2.41449667038742e+109*cos(theta)**40 - 1.08861699589722e+110*cos(theta)**38 + 2.23771271378873e+110*cos(theta)**36 - 2.78058976269605e+110*cos(theta)**34 + 2.33519589352169e+110*cos(theta)**32 - 1.40394807659001e+110*cos(theta)**30 + 6.24455432839114e+109*cos(theta)**28 - 2.09444679337342e+109*cos(theta)**26 + 5.35137742017581e+108*cos(theta)**24 - 1.04527966593668e+108*cos(theta)**22 + 1.55780388923466e+107*cos(theta)**20 - 1.7586615505323e+106*cos(theta)**18 + 1.48496256750243e+105*cos(theta)**16 - 9.19956159526547e+103*cos(theta)**14 + 4.06783335845072e+102*cos(theta)**12 - 1.23437701911608e+101*cos(theta)**10 + 2.4277520043804e+99*cos(theta)**8 - 2.83592224124536e+97*cos(theta)**6 + 1.70019319019506e+95*cos(theta)**4 - 3.91900082257793e+92*cos(theta)**2 + 1.45148178613997e+89)*sin(47*phi)

#@torch.jit.script
def Yl87_m_minus_46(theta, phi):
    return 2.5029290597084e-88*(1.0 - cos(theta)**2)**23*(5.88901626923761e+107*cos(theta)**41 - 2.79132563050569e+108*cos(theta)**39 + 6.047872199429e+108*cos(theta)**37 - 7.94454217913158e+108*cos(theta)**35 + 7.07635119248996e+108*cos(theta)**33 - 4.52886476319357e+108*cos(theta)**31 + 2.15329459599694e+108*cos(theta)**29 - 7.7572103458275e+107*cos(theta)**27 + 2.14055096807032e+107*cos(theta)**25 - 4.54469419972468e+106*cos(theta)**23 + 7.41811375826028e+105*cos(theta)**21 - 9.25611342385418e+104*cos(theta)**19 + 8.73507392648491e+103*cos(theta)**17 - 6.13304106351031e+102*cos(theta)**15 + 3.12910258342363e+101*cos(theta)**13 - 1.12216092646916e+100*cos(theta)**11 + 2.69750222708934e+98*cos(theta)**9 - 4.05131748749337e+96*cos(theta)**7 + 3.40038638039012e+94*cos(theta)**5 - 1.30633360752598e+92*cos(theta)**3 + 1.45148178613997e+89*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl87_m_minus_45(theta, phi):
    return 1.87067786008528e-86*(1.0 - cos(theta)**2)**22.5*(1.40214673077086e+106*cos(theta)**42 - 6.97831407626423e+106*cos(theta)**40 + 1.59154531563921e+107*cos(theta)**38 - 2.20681727198099e+107*cos(theta)**36 + 2.08127976249705e+107*cos(theta)**34 - 1.41527023849799e+107*cos(theta)**32 + 7.17764865332314e+106*cos(theta)**30 - 2.77043226636696e+106*cos(theta)**28 + 8.23288833873201e+105*cos(theta)**26 - 1.89362258321862e+105*cos(theta)**24 + 3.37186989011831e+104*cos(theta)**22 - 4.62805671192709e+103*cos(theta)**20 + 4.85281884804717e+102*cos(theta)**18 - 3.83315066469395e+101*cos(theta)**16 + 2.23507327387402e+100*cos(theta)**14 - 9.3513410539097e+98*cos(theta)**12 + 2.69750222708934e+97*cos(theta)**10 - 5.06414685936671e+95*cos(theta)**8 + 5.66731063398353e+93*cos(theta)**6 - 3.26583401881494e+91*cos(theta)**4 + 7.25740893069987e+88*cos(theta)**2 - 2.59842783054059e+85)*sin(45*phi)

#@torch.jit.script
def Yl87_m_minus_44(theta, phi):
    return 1.40935434808519e-84*(1.0 - cos(theta)**2)**22*(3.26080635062991e+104*cos(theta)**43 - 1.70202782347908e+105*cos(theta)**41 + 4.08088542471592e+105*cos(theta)**39 - 5.96437100535404e+105*cos(theta)**37 + 5.94651360713442e+105*cos(theta)**35 - 4.28869769241815e+105*cos(theta)**33 + 2.31537053333005e+105*cos(theta)**31 - 9.55321471161022e+104*cos(theta)**29 + 3.04921790323408e+104*cos(theta)**27 - 7.57449033287446e+103*cos(theta)**25 + 1.46603038700796e+103*cos(theta)**23 - 2.20383652948909e+102*cos(theta)**21 + 2.55411518318272e+101*cos(theta)**19 - 2.2547945086435e+100*cos(theta)**17 + 1.49004884924935e+99*cos(theta)**15 - 7.19333927223823e+97*cos(theta)**13 + 2.4522747518994e+96*cos(theta)**11 - 5.62682984374079e+94*cos(theta)**9 + 8.0961580485479e+92*cos(theta)**7 - 6.53166803762989e+90*cos(theta)**5 + 2.41913631023329e+88*cos(theta)**3 - 2.59842783054059e+85*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl87_m_minus_43(theta, phi):
    return 1.06999607787514e-82*(1.0 - cos(theta)**2)**21.5*(7.41092352415888e+102*cos(theta)**44 - 4.05244719875971e+103*cos(theta)**42 + 1.02022135617898e+104*cos(theta)**40 - 1.56957131719843e+104*cos(theta)**38 + 1.65180933531512e+104*cos(theta)**36 - 1.26138167424063e+104*cos(theta)**34 + 7.23553291665639e+103*cos(theta)**32 - 3.18440490387007e+103*cos(theta)**30 + 1.08900639401217e+103*cos(theta)**28 - 2.91326551264402e+102*cos(theta)**26 + 6.1084599458665e+101*cos(theta)**24 - 1.0017438770405e+101*cos(theta)**22 + 1.27705759159136e+100*cos(theta)**20 - 1.25266361591305e+99*cos(theta)**18 + 9.31280530780842e+97*cos(theta)**16 - 5.13809948017016e+96*cos(theta)**14 + 2.0435622932495e+95*cos(theta)**12 - 5.62682984374079e+93*cos(theta)**10 + 1.01201975606849e+92*cos(theta)**8 - 1.08861133960498e+90*cos(theta)**6 + 6.04784077558323e+87*cos(theta)**4 - 1.2992139152703e+85*cos(theta)**2 + 4.5080288524299e+81)*sin(43*phi)

#@torch.jit.script
def Yl87_m_minus_42(theta, phi):
    return 8.18389632082959e-81*(1.0 - cos(theta)**2)**21*(1.64687189425753e+101*cos(theta)**45 - 9.4242958110691e+101*cos(theta)**43 + 2.48834477116824e+102*cos(theta)**41 - 4.02454183897034e+102*cos(theta)**39 + 4.46434955490572e+102*cos(theta)**37 - 3.60394764068752e+102*cos(theta)**35 + 2.19258573232012e+102*cos(theta)**33 - 1.02722738834518e+102*cos(theta)**31 + 3.75519446211093e+101*cos(theta)**29 - 1.07898722690519e+101*cos(theta)**27 + 2.4433839783466e+100*cos(theta)**25 - 4.35540816104564e+99*cos(theta)**23 + 6.08122662662553e+98*cos(theta)**21 - 6.59296639954239e+97*cos(theta)**19 + 5.47812076929907e+96*cos(theta)**17 - 3.42539965344677e+95*cos(theta)**15 + 1.57197099480731e+94*cos(theta)**13 - 5.11529985794617e+92*cos(theta)**11 + 1.12446639563165e+91*cos(theta)**9 - 1.55515905657854e+89*cos(theta)**7 + 1.20956815511665e+87*cos(theta)**5 - 4.33071305090099e+84*cos(theta)**3 + 4.5080288524299e+81*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl87_m_minus_41(theta, phi):
    return 6.30425671627657e-79*(1.0 - cos(theta)**2)**20.5*(3.58015629186419e+99*cos(theta)**46 - 2.14188541160661e+100*cos(theta)**44 + 5.92463040754344e+100*cos(theta)**42 - 1.00613545974258e+101*cos(theta)**40 + 1.17482883023835e+101*cos(theta)**38 - 1.00109656685765e+101*cos(theta)**36 + 6.44878156564741e+100*cos(theta)**34 - 3.2100855885787e+100*cos(theta)**32 + 1.25173148737031e+100*cos(theta)**30 - 3.85352581037569e+99*cos(theta)**28 + 9.39763068594847e+98*cos(theta)**26 - 1.81475340043568e+98*cos(theta)**24 + 2.76419392119342e+97*cos(theta)**22 - 3.29648319977119e+96*cos(theta)**20 + 3.04340042738837e+95*cos(theta)**18 - 2.14087478340423e+94*cos(theta)**16 + 1.12283642486236e+93*cos(theta)**14 - 4.26274988162181e+91*cos(theta)**12 + 1.12446639563165e+90*cos(theta)**10 - 1.94394882072318e+88*cos(theta)**8 + 2.01594692519441e+86*cos(theta)**6 - 1.08267826272525e+84*cos(theta)**4 + 2.25401442621495e+81*cos(theta)**2 - 7.59694784703387e+77)*sin(41*phi)

#@torch.jit.script
def Yl87_m_minus_40(theta, phi):
    return 4.88976292791609e-77*(1.0 - cos(theta)**2)**20*(7.61735381247701e+97*cos(theta)**47 - 4.75974535912581e+98*cos(theta)**45 + 1.3778210250101e+99*cos(theta)**43 - 2.45398892620142e+99*cos(theta)**41 + 3.01238161599576e+99*cos(theta)**39 - 2.70566639691256e+99*cos(theta)**37 + 1.8425090187564e+99*cos(theta)**35 - 9.72753208660213e+98*cos(theta)**33 + 4.03784350764617e+98*cos(theta)**31 - 1.32880200357783e+98*cos(theta)**29 + 3.48060395775869e+97*cos(theta)**27 - 7.25901360174273e+96*cos(theta)**25 + 1.20182344399714e+96*cos(theta)**23 - 1.56975390465295e+95*cos(theta)**21 + 1.60178969862546e+94*cos(theta)**19 - 1.25933810788484e+93*cos(theta)**17 + 7.48557616574907e+91*cos(theta)**15 - 3.27903837047832e+90*cos(theta)**13 + 1.02224217784696e+89*cos(theta)**11 - 2.15994313413687e+87*cos(theta)**9 + 2.87992417884916e+85*cos(theta)**7 - 2.16535652545049e+83*cos(theta)**5 + 7.51338142071649e+80*cos(theta)**3 - 7.59694784703387e+77*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl87_m_minus_39(theta, phi):
    return 3.81777458698772e-75*(1.0 - cos(theta)**2)**19.5*(1.58694871093271e+96*cos(theta)**48 - 1.03472725198387e+97*cos(theta)**46 + 3.1314114204775e+97*cos(theta)**44 - 5.84283077667006e+97*cos(theta)**42 + 7.5309540399894e+97*cos(theta)**40 - 7.12017472871725e+97*cos(theta)**38 + 5.11808060765668e+97*cos(theta)**36 - 2.86103884900063e+97*cos(theta)**34 + 1.26182609613943e+97*cos(theta)**32 - 4.42934001192609e+96*cos(theta)**30 + 1.24307284205668e+96*cos(theta)**28 - 2.79192830836259e+95*cos(theta)**26 + 5.00759768332142e+94*cos(theta)**24 - 7.13524502114977e+93*cos(theta)**22 + 8.0089484931273e+92*cos(theta)**20 - 6.99632282158247e+91*cos(theta)**18 + 4.67848510359317e+90*cos(theta)**16 - 2.34217026462737e+89*cos(theta)**14 + 8.51868481539131e+87*cos(theta)**12 - 2.15994313413687e+86*cos(theta)**10 + 3.59990522356144e+84*cos(theta)**8 - 3.60892754241749e+82*cos(theta)**6 + 1.87834535517912e+80*cos(theta)**4 - 3.79847392351693e+77*cos(theta)**2 + 1.24621847884414e+74)*sin(39*phi)

#@torch.jit.script
def Yl87_m_minus_38(theta, phi):
    return 2.99980894173249e-73*(1.0 - cos(theta)**2)**19*(3.23867083863818e+94*cos(theta)**49 - 2.20154734464653e+95*cos(theta)**47 + 6.95869204550557e+95*cos(theta)**45 - 1.35879785503955e+96*cos(theta)**43 + 1.836818058534e+96*cos(theta)**41 - 1.82568582787622e+96*cos(theta)**39 + 1.3832650290964e+96*cos(theta)**37 - 8.17439671143036e+95*cos(theta)**35 + 3.82371544284675e+95*cos(theta)**33 - 1.42881935868583e+95*cos(theta)**31 + 4.2864580760575e+94*cos(theta)**29 - 1.03404752161577e+94*cos(theta)**27 + 2.00303907332857e+93*cos(theta)**25 - 3.10228044397816e+92*cos(theta)**23 + 3.81378499672728e+91*cos(theta)**21 - 3.68227516925393e+90*cos(theta)**19 + 2.75205006093716e+89*cos(theta)**17 - 1.56144684308491e+88*cos(theta)**15 + 6.55283447337793e+86*cos(theta)**13 - 1.96358466739715e+85*cos(theta)**11 + 3.99989469284605e+83*cos(theta)**9 - 5.15561077488213e+81*cos(theta)**7 + 3.75669071035825e+79*cos(theta)**5 - 1.26615797450564e+77*cos(theta)**3 + 1.24621847884414e+74*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl87_m_minus_37(theta, phi):
    return 2.3715572003035e-71*(1.0 - cos(theta)**2)**18.5*(6.47734167727637e+92*cos(theta)**50 - 4.58655696801361e+93*cos(theta)**48 + 1.5127591403273e+94*cos(theta)**46 - 3.0881769432717e+94*cos(theta)**44 + 4.37337632984286e+94*cos(theta)**42 - 4.56421456969055e+94*cos(theta)**40 + 3.64017112920105e+94*cos(theta)**38 - 2.2706657531751e+94*cos(theta)**36 + 1.12462218907257e+94*cos(theta)**34 - 4.46506049589323e+93*cos(theta)**32 + 1.42881935868583e+93*cos(theta)**30 - 3.69302686291347e+92*cos(theta)**28 + 7.7039964358791e+91*cos(theta)**26 - 1.29261685165757e+91*cos(theta)**24 + 1.73353863487604e+90*cos(theta)**22 - 1.84113758462696e+89*cos(theta)**20 + 1.52891670052064e+88*cos(theta)**18 - 9.7590427692807e+86*cos(theta)**16 + 4.68059605241281e+85*cos(theta)**14 - 1.63632055616429e+84*cos(theta)**12 + 3.99989469284605e+82*cos(theta)**10 - 6.44451346860266e+80*cos(theta)**8 + 6.26115118393041e+78*cos(theta)**6 - 3.16539493626411e+76*cos(theta)**4 + 6.23109239422069e+73*cos(theta)**2 - 1.99394956615062e+70)*sin(37*phi)

#@torch.jit.script
def Yl87_m_minus_36(theta, phi):
    return 1.88594722082738e-69*(1.0 - cos(theta)**2)**18*(1.27006699554439e+91*cos(theta)**51 - 9.36032034288493e+91*cos(theta)**49 + 3.21863646878148e+92*cos(theta)**47 - 6.86261542949267e+92*cos(theta)**45 + 1.01706426275415e+93*cos(theta)**43 - 1.11322306577818e+93*cos(theta)**41 + 9.33377212615654e+92*cos(theta)**39 - 6.13693446804081e+92*cos(theta)**37 + 3.21320625449307e+92*cos(theta)**35 - 1.35304863511916e+92*cos(theta)**33 + 4.60909470543817e+91*cos(theta)**31 - 1.27345753893568e+91*cos(theta)**29 + 2.85333201328856e+90*cos(theta)**27 - 5.17046740663027e+89*cos(theta)**25 + 7.53712449946103e+88*cos(theta)**23 - 8.76732183155697e+87*cos(theta)**21 + 8.04693000274023e+86*cos(theta)**19 - 5.74061339369453e+85*cos(theta)**17 + 3.12039736827521e+84*cos(theta)**15 - 1.25870812012638e+83*cos(theta)**13 + 3.63626790258732e+81*cos(theta)**11 - 7.16057052066962e+79*cos(theta)**9 + 8.94450169132916e+77*cos(theta)**7 - 6.33078987252822e+75*cos(theta)**5 + 2.07703079807356e+73*cos(theta)**3 - 1.99394956615062e+70*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl87_m_minus_35(theta, phi):
    return 1.50828621616385e-67*(1.0 - cos(theta)**2)**17.5*(2.44243652989305e+89*cos(theta)**52 - 1.87206406857699e+90*cos(theta)**50 + 6.70549264329476e+90*cos(theta)**48 - 1.49187291945493e+91*cos(theta)**46 + 2.31150968807762e+91*cos(theta)**44 - 2.65053110899567e+91*cos(theta)**42 + 2.33344303153913e+91*cos(theta)**40 - 1.61498275474758e+91*cos(theta)**38 + 8.92557292914741e+90*cos(theta)**36 - 3.979554809174e+90*cos(theta)**34 + 1.44034209544943e+90*cos(theta)**32 - 4.24485846311894e+89*cos(theta)**30 + 1.01904714760306e+89*cos(theta)**28 - 1.98864131024241e+88*cos(theta)**26 + 3.1404685414421e+87*cos(theta)**24 - 3.98514628707135e+86*cos(theta)**22 + 4.02346500137011e+85*cos(theta)**20 - 3.18922966316363e+84*cos(theta)**18 + 1.950248355172e+83*cos(theta)**16 - 8.99077228661699e+81*cos(theta)**14 + 3.0302232521561e+80*cos(theta)**12 - 7.16057052066962e+78*cos(theta)**10 + 1.11806271141614e+77*cos(theta)**8 - 1.05513164542137e+75*cos(theta)**6 + 5.19257699518391e+72*cos(theta)**4 - 9.9697478307531e+69*cos(theta)**2 + 3.11749463125488e+66)*sin(35*phi)

#@torch.jit.script
def Yl87_m_minus_34(theta, phi):
    return 1.21283469548074e-65*(1.0 - cos(theta)**2)**17*(4.60837081111896e+87*cos(theta)**53 - 3.67071385995487e+88*cos(theta)**51 + 1.36846788638668e+89*cos(theta)**49 - 3.17419770096793e+89*cos(theta)**47 + 5.13668819572805e+89*cos(theta)**45 - 6.16402583487366e+89*cos(theta)**43 + 5.69132446716862e+89*cos(theta)**41 - 4.1409814224297e+89*cos(theta)**39 + 2.41231700787768e+89*cos(theta)**37 - 1.137015659764e+89*cos(theta)**35 + 4.36467301651342e+88*cos(theta)**33 - 1.36930918165127e+88*cos(theta)**31 + 3.51395568138985e+87*cos(theta)**29 - 7.36533818608301e+86*cos(theta)**27 + 1.25618741657684e+86*cos(theta)**25 - 1.73267229872667e+85*cos(theta)**23 + 1.91593571493815e+84*cos(theta)**21 - 1.67854192798086e+83*cos(theta)**19 + 1.14720491480706e+82*cos(theta)**17 - 5.993848191078e+80*cos(theta)**15 + 2.330940963197e+79*cos(theta)**13 - 6.50960956424511e+77*cos(theta)**11 + 1.24229190157349e+76*cos(theta)**9 - 1.50733092203053e+74*cos(theta)**7 + 1.03851539903678e+72*cos(theta)**5 - 3.3232492769177e+69*cos(theta)**3 + 3.11749463125488e+66*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl87_m_minus_33(theta, phi):
    return 9.80372628269639e-64*(1.0 - cos(theta)**2)**16.5*(8.53402002059067e+85*cos(theta)**54 - 7.05906511529783e+86*cos(theta)**52 + 2.73693577277337e+87*cos(theta)**50 - 6.61291187701653e+87*cos(theta)**48 + 1.1166713468974e+88*cos(theta)**46 - 1.40091496247129e+88*cos(theta)**44 + 1.35507725408777e+88*cos(theta)**42 - 1.03524535560742e+88*cos(theta)**40 + 6.34820265230968e+87*cos(theta)**38 - 3.15837683267778e+87*cos(theta)**36 + 1.28372735779807e+87*cos(theta)**34 - 4.27909119266022e+86*cos(theta)**32 + 1.17131856046328e+86*cos(theta)**30 - 2.63047792360107e+85*cos(theta)**28 + 4.83149006375707e+84*cos(theta)**26 - 7.21946791136115e+83*cos(theta)**24 + 8.70879870426432e+82*cos(theta)**22 - 8.39270963990429e+81*cos(theta)**20 + 6.373360637817e+80*cos(theta)**18 - 3.74615511942375e+79*cos(theta)**16 + 1.664957830855e+78*cos(theta)**14 - 5.42467463687092e+76*cos(theta)**12 + 1.24229190157349e+75*cos(theta)**10 - 1.88416365253816e+73*cos(theta)**8 + 1.73085899839464e+71*cos(theta)**6 - 8.30812319229425e+68*cos(theta)**4 + 1.55874731562744e+66*cos(theta)**2 - 4.77118860002277e+62)*sin(33*phi)

#@torch.jit.script
def Yl87_m_minus_32(theta, phi):
    return 7.96458488291644e-62*(1.0 - cos(theta)**2)**16*(1.55164000374376e+84*cos(theta)**55 - 1.33189907835808e+85*cos(theta)**53 + 5.36654073092818e+85*cos(theta)**51 - 1.34957385245235e+86*cos(theta)**49 + 2.37589648276043e+86*cos(theta)**47 - 3.1131443610473e+86*cos(theta)**45 + 3.1513424513669e+86*cos(theta)**43 - 2.52498867221323e+86*cos(theta)**41 + 1.62774426982299e+86*cos(theta)**39 - 8.53615360183184e+85*cos(theta)**37 + 3.66779245085162e+85*cos(theta)**35 - 1.29669430080613e+85*cos(theta)**33 + 3.7784469692364e+84*cos(theta)**31 - 9.07061352965887e+83*cos(theta)**29 + 1.78944076435447e+83*cos(theta)**27 - 2.88778716454446e+82*cos(theta)**25 + 3.78643421924536e+81*cos(theta)**23 - 3.99652839995442e+80*cos(theta)**21 + 3.35440033569316e+79*cos(theta)**19 - 2.20362065848456e+78*cos(theta)**17 + 1.10997188723667e+77*cos(theta)**15 - 4.17282664374687e+75*cos(theta)**13 + 1.12935627415772e+74*cos(theta)**11 - 2.09351516948685e+72*cos(theta)**9 + 2.47265571199234e+70*cos(theta)**7 - 1.66162463845885e+68*cos(theta)**5 + 5.1958243854248e+65*cos(theta)**3 - 4.77118860002277e+62*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl87_m_minus_31(theta, phi):
    return 6.5017555840577e-60*(1.0 - cos(theta)**2)**15.5*(2.770785720971e+82*cos(theta)**56 - 2.46647977473719e+83*cos(theta)**54 + 1.03202706364003e+84*cos(theta)**52 - 2.6991477049047e+84*cos(theta)**50 + 4.94978433908423e+84*cos(theta)**48 - 6.76770513271152e+84*cos(theta)**46 + 7.16214193492477e+84*cos(theta)**44 - 6.01187779098388e+84*cos(theta)**42 + 4.06936067455749e+84*cos(theta)**40 - 2.24635621100838e+84*cos(theta)**38 + 1.01883123634767e+84*cos(theta)**36 - 3.81380676707684e+83*cos(theta)**34 + 1.18076467788637e+83*cos(theta)**32 - 3.02353784321962e+82*cos(theta)**30 + 6.39085987269454e+81*cos(theta)**28 - 1.11068737097864e+81*cos(theta)**26 + 1.57768092468556e+80*cos(theta)**24 - 1.8166038181611e+79*cos(theta)**22 + 1.67720016784658e+78*cos(theta)**20 - 1.22423369915809e+77*cos(theta)**18 + 6.93732429522916e+75*cos(theta)**16 - 2.98059045981919e+74*cos(theta)**14 + 9.41130228464768e+72*cos(theta)**12 - 2.09351516948685e+71*cos(theta)**10 + 3.09081963999042e+69*cos(theta)**8 - 2.76937439743142e+67*cos(theta)**6 + 1.2989560963562e+65*cos(theta)**4 - 2.38559430001139e+62*cos(theta)**2 + 7.15964675873765e+58)*sin(31*phi)

#@torch.jit.script
def Yl87_m_minus_30(theta, phi):
    return 5.33223241699831e-58*(1.0 - cos(theta)**2)**15*(4.86102758065087e+80*cos(theta)**57 - 4.48450868134034e+81*cos(theta)**55 + 1.94722087479252e+82*cos(theta)**53 - 5.2924464802053e+82*cos(theta)**51 + 1.01016006920086e+83*cos(theta)**49 - 1.43993726227905e+83*cos(theta)**47 + 1.59158709664995e+83*cos(theta)**45 - 1.3981111141823e+83*cos(theta)**43 + 9.92526993794509e+82*cos(theta)**41 - 5.7598877205343e+82*cos(theta)**39 + 2.75359793607479e+82*cos(theta)**37 - 1.08965907630767e+82*cos(theta)**35 + 3.57807478147386e+81*cos(theta)**33 - 9.75334788135363e+80*cos(theta)**31 + 2.20374478368777e+80*cos(theta)**29 - 4.11365692955051e+79*cos(theta)**27 + 6.31072369874226e+78*cos(theta)**25 - 7.89827747026566e+77*cos(theta)**23 + 7.98666746593609e+76*cos(theta)**21 - 6.44333525872678e+75*cos(theta)**19 + 4.08077899719363e+74*cos(theta)**17 - 1.98706030654613e+73*cos(theta)**15 + 7.23946329588283e+71*cos(theta)**13 - 1.90319560862441e+70*cos(theta)**11 + 3.4342440444338e+68*cos(theta)**9 - 3.95624913918774e+66*cos(theta)**7 + 2.5979121927124e+64*cos(theta)**5 - 7.95198100003795e+61*cos(theta)**3 + 7.15964675873765e+58*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl87_m_minus_29(theta, phi):
    return 4.39254276583338e-56*(1.0 - cos(theta)**2)**14.5*(8.38108203560495e+78*cos(theta)**58 - 8.00805121667918e+79*cos(theta)**56 + 3.60596458294911e+80*cos(theta)**54 - 1.01777816927025e+81*cos(theta)**52 + 2.02032013840172e+81*cos(theta)**50 - 2.99986929641468e+81*cos(theta)**48 + 3.45997194923902e+81*cos(theta)**46 - 3.17752525950522e+81*cos(theta)**44 + 2.36315950903454e+81*cos(theta)**42 - 1.43997193013358e+81*cos(theta)**40 + 7.24631035809154e+80*cos(theta)**38 - 3.0268307675213e+80*cos(theta)**36 + 1.05237493572761e+80*cos(theta)**34 - 3.04792121292301e+79*cos(theta)**32 + 7.34581594562591e+78*cos(theta)**30 - 1.46916318912518e+78*cos(theta)**28 + 2.42720142259318e+77*cos(theta)**26 - 3.29094894594402e+76*cos(theta)**24 + 3.63030339360732e+75*cos(theta)**22 - 3.22166762936339e+74*cos(theta)**20 + 2.26709944288535e+73*cos(theta)**18 - 1.24191269159133e+72*cos(theta)**16 + 5.17104521134488e+70*cos(theta)**14 - 1.58599634052034e+69*cos(theta)**12 + 3.4342440444338e+67*cos(theta)**10 - 4.94531142398467e+65*cos(theta)**8 + 4.32985365452067e+63*cos(theta)**6 - 1.98799525000949e+61*cos(theta)**4 + 3.57982337936883e+58*cos(theta)**2 - 1.05506141449125e+55)*sin(29*phi)

#@torch.jit.script
def Yl87_m_minus_28(theta, phi):
    return 3.63388349102687e-54*(1.0 - cos(theta)**2)**14*(1.42052237891609e+77*cos(theta)**59 - 1.40492126608407e+78*cos(theta)**57 + 6.55629924172565e+78*cos(theta)**55 - 1.92033616843443e+79*cos(theta)**53 + 3.96141203608181e+79*cos(theta)**51 - 6.12218223758098e+79*cos(theta)**49 + 7.3616424451894e+79*cos(theta)**47 - 7.06116724334494e+79*cos(theta)**45 + 5.49571978845243e+79*cos(theta)**43 - 3.51212665886238e+79*cos(theta)**41 + 1.85802829694655e+79*cos(theta)**39 - 8.18062369600352e+78*cos(theta)**37 + 3.0067855306503e+78*cos(theta)**35 - 9.23612488764548e+77*cos(theta)**33 + 2.3696180469761e+77*cos(theta)**31 - 5.06607996250063e+76*cos(theta)**29 + 8.98963489849325e+75*cos(theta)**27 - 1.31637957837761e+75*cos(theta)**25 + 1.57839277982927e+74*cos(theta)**23 - 1.53412744255399e+73*cos(theta)**21 + 1.19321023309755e+72*cos(theta)**19 - 7.30536877406664e+70*cos(theta)**17 + 3.44736347422992e+69*cos(theta)**15 - 1.21999718501564e+68*cos(theta)**13 + 3.12204004039437e+66*cos(theta)**11 - 5.49479047109408e+64*cos(theta)**9 + 6.18550522074381e+62*cos(theta)**7 - 3.97599050001898e+60*cos(theta)**5 + 1.19327445978961e+58*cos(theta)**3 - 1.05506141449125e+55*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl87_m_minus_27(theta, phi):
    return 3.01853033216279e-52*(1.0 - cos(theta)**2)**13.5*(2.36753729819349e+75*cos(theta)**60 - 2.42227804497253e+76*cos(theta)**58 + 1.17076772173672e+77*cos(theta)**56 - 3.5561780896934e+77*cos(theta)**54 + 7.6181000693881e+77*cos(theta)**52 - 1.2244364475162e+78*cos(theta)**50 + 1.53367550941446e+78*cos(theta)**48 - 1.5350363572489e+78*cos(theta)**46 + 1.24902722464828e+78*cos(theta)**44 - 8.36220633062471e+77*cos(theta)**42 + 4.64507074236637e+77*cos(theta)**40 - 2.15279570947461e+77*cos(theta)**38 + 8.35218202958417e+76*cos(theta)**36 - 2.71650731989573e+76*cos(theta)**34 + 7.40505639680031e+75*cos(theta)**32 - 1.68869332083354e+75*cos(theta)**30 + 3.21058389231902e+74*cos(theta)**28 - 5.06299837837542e+73*cos(theta)**26 + 6.57663658262195e+72*cos(theta)**24 - 6.97330655706361e+71*cos(theta)**22 + 5.96605116548776e+70*cos(theta)**20 - 4.0585382078148e+69*cos(theta)**18 + 2.1546021713937e+68*cos(theta)**16 - 8.7142656072546e+66*cos(theta)**14 + 2.60170003366197e+65*cos(theta)**12 - 5.49479047109408e+63*cos(theta)**10 + 7.73188152592976e+61*cos(theta)**8 - 6.62665083336496e+59*cos(theta)**6 + 2.98318614947402e+57*cos(theta)**4 - 5.27530707245627e+54*cos(theta)**2 + 1.52907451375544e+51)*sin(27*phi)

#@torch.jit.script
def Yl87_m_minus_26(theta, phi):
    return 2.51717197260066e-50*(1.0 - cos(theta)**2)**13*(3.8812086855631e+73*cos(theta)**61 - 4.10555600842802e+74*cos(theta)**59 + 2.05397845918723e+75*cos(theta)**57 - 6.46577834489709e+75*cos(theta)**55 + 1.43737737158266e+76*cos(theta)**53 - 2.40085577944352e+76*cos(theta)**51 + 3.12995001921318e+76*cos(theta)**49 - 3.26603480265723e+76*cos(theta)**47 + 2.77561605477395e+76*cos(theta)**45 - 1.94469914665691e+76*cos(theta)**43 + 1.13294408350399e+76*cos(theta)**41 - 5.51998899865285e+75*cos(theta)**39 + 2.25734649448221e+75*cos(theta)**37 - 7.76144948541637e+74*cos(theta)**35 + 2.24395648387888e+74*cos(theta)**33 - 5.44739780914046e+73*cos(theta)**31 + 1.10709789390311e+73*cos(theta)**29 - 1.87518458458349e+72*cos(theta)**27 + 2.63065463304878e+71*cos(theta)**25 - 3.03187241611461e+70*cos(theta)**23 + 2.84097674547036e+69*cos(theta)**21 - 2.13607274095516e+68*cos(theta)**19 + 1.26741304199629e+67*cos(theta)**17 - 5.8095104048364e+65*cos(theta)**15 + 2.00130771820152e+64*cos(theta)**13 - 4.99526406463098e+62*cos(theta)**11 + 8.59097947325529e+60*cos(theta)**9 - 9.46664404766423e+58*cos(theta)**7 + 5.96637229894804e+56*cos(theta)**5 - 1.75843569081876e+54*cos(theta)**3 + 1.52907451375544e+51*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl87_m_minus_25(theta, phi):
    return 2.10691955484688e-48*(1.0 - cos(theta)**2)**12.5*(6.26001400897274e+71*cos(theta)**62 - 6.84259334738003e+72*cos(theta)**60 + 3.54134217101247e+73*cos(theta)**58 - 1.15460327587448e+74*cos(theta)**56 + 2.6618099473753e+74*cos(theta)**54 - 4.6170303450837e+74*cos(theta)**52 + 6.25990003842636e+74*cos(theta)**50 - 6.80423917220257e+74*cos(theta)**48 + 6.03394794516077e+74*cos(theta)**46 - 4.41977078785661e+74*cos(theta)**44 + 2.69748591310475e+74*cos(theta)**42 - 1.37999724966321e+74*cos(theta)**40 + 5.94038551179529e+73*cos(theta)**38 - 2.15595819039344e+73*cos(theta)**36 + 6.59987201140848e+72*cos(theta)**34 - 1.70231181535639e+72*cos(theta)**32 + 3.69032631301036e+71*cos(theta)**30 - 6.69708780208389e+70*cos(theta)**28 + 1.0117902434803e+70*cos(theta)**26 - 1.26328017338109e+69*cos(theta)**24 + 1.29135306612289e+68*cos(theta)**22 - 1.06803637047758e+67*cos(theta)**20 + 7.04118356664608e+65*cos(theta)**18 - 3.63094400302275e+64*cos(theta)**16 + 1.42950551300108e+63*cos(theta)**14 - 4.16272005385915e+61*cos(theta)**12 + 8.59097947325529e+59*cos(theta)**10 - 1.18333050595803e+58*cos(theta)**8 + 9.94395383158007e+55*cos(theta)**6 - 4.39608922704689e+53*cos(theta)**4 + 7.64537256877721e+50*cos(theta)**2 - 2.18252142985361e+47)*sin(25*phi)

#@torch.jit.script
def Yl87_m_minus_24(theta, phi):
    return 1.76981242607138e-46*(1.0 - cos(theta)**2)**12*(9.9365301729726e+69*cos(theta)**63 - 1.12173661432459e+71*cos(theta)**61 + 6.00227486612283e+71*cos(theta)**59 - 2.02561978223593e+72*cos(theta)**57 + 4.83965444977327e+72*cos(theta)**55 - 8.71137800959188e+72*cos(theta)**53 + 1.2274313800836e+73*cos(theta)**51 - 1.38862023922501e+73*cos(theta)**49 + 1.28381871173633e+73*cos(theta)**47 - 9.82171286190359e+72*cos(theta)**45 + 6.27322305373197e+72*cos(theta)**43 - 3.36584695039808e+72*cos(theta)**41 + 1.5231757722552e+72*cos(theta)**39 - 5.82691402809037e+71*cos(theta)**37 + 1.88567771754528e+71*cos(theta)**35 - 5.15852065259513e+70*cos(theta)**33 + 1.19042784290657e+70*cos(theta)**31 - 2.30934062140824e+69*cos(theta)**29 + 3.74737127214926e+68*cos(theta)**27 - 5.05312069352436e+67*cos(theta)**25 + 5.6145785483604e+66*cos(theta)**23 - 5.08588747846466e+65*cos(theta)**21 + 3.70588608770846e+64*cos(theta)**19 - 2.13584941354279e+63*cos(theta)**17 + 9.53003675334055e+61*cos(theta)**15 - 3.20209234912243e+60*cos(theta)**13 + 7.80998133932299e+58*cos(theta)**11 - 1.3148116732867e+57*cos(theta)**9 + 1.42056483308287e+55*cos(theta)**7 - 8.79217845409379e+52*cos(theta)**5 + 2.54845752292574e+50*cos(theta)**3 - 2.18252142985361e+47*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl87_m_minus_23(theta, phi):
    return 1.49169047428675e-44*(1.0 - cos(theta)**2)**11.5*(1.55258283952697e+68*cos(theta)**64 - 1.80925260374935e+69*cos(theta)**62 + 1.00037914435381e+70*cos(theta)**60 - 3.49244790040678e+70*cos(theta)**58 + 8.64224008888084e+70*cos(theta)**56 - 1.61321814992442e+71*cos(theta)**54 + 2.36044496169923e+71*cos(theta)**52 - 2.77724047845003e+71*cos(theta)**50 + 2.67462231611736e+71*cos(theta)**48 - 2.13515496997904e+71*cos(theta)**46 + 1.42573251221181e+71*cos(theta)**44 - 8.01392131047162e+70*cos(theta)**42 + 3.807939430638e+70*cos(theta)**40 - 1.53339842844483e+70*cos(theta)**38 + 5.237993659848e+69*cos(theta)**36 - 1.51721195664563e+69*cos(theta)**34 + 3.72008700908303e+68*cos(theta)**32 - 7.69780207136079e+67*cos(theta)**30 + 1.33834688291045e+67*cos(theta)**28 - 1.94350795904783e+66*cos(theta)**26 + 2.3394077284835e+65*cos(theta)**24 - 2.31176703566576e+64*cos(theta)**22 + 1.85294304385423e+63*cos(theta)**20 - 1.18658300752377e+62*cos(theta)**18 + 5.95627297083785e+60*cos(theta)**16 - 2.28720882080173e+59*cos(theta)**14 + 6.50831778276916e+57*cos(theta)**12 - 1.3148116732867e+56*cos(theta)**10 + 1.77570604135358e+54*cos(theta)**8 - 1.4653630756823e+52*cos(theta)**6 + 6.37114380731434e+49*cos(theta)**4 - 1.09126071492681e+47*cos(theta)**2 + 3.07224300373538e+43)*sin(23*phi)

#@torch.jit.script
def Yl87_m_minus_22(theta, phi):
    return 1.26133874784716e-42*(1.0 - cos(theta)**2)**11*(2.38858898388764e+66*cos(theta)**65 - 2.87182952976087e+67*cos(theta)**63 + 1.63996581041607e+68*cos(theta)**61 - 5.91940322102843e+68*cos(theta)**59 + 1.51618247173348e+69*cos(theta)**57 - 2.9331239089535e+69*cos(theta)**55 + 4.45366973905516e+69*cos(theta)**53 - 5.44556956558829e+69*cos(theta)**51 + 5.45841289003543e+69*cos(theta)**49 - 4.54288291484902e+69*cos(theta)**47 + 3.1682944715818e+69*cos(theta)**45 - 1.86370263034224e+69*cos(theta)**43 + 9.28765714789757e+68*cos(theta)**41 - 3.93179084216624e+68*cos(theta)**39 + 1.41567396212108e+68*cos(theta)**37 - 4.33489130470179e+67*cos(theta)**35 + 1.12729909366152e+67*cos(theta)**33 - 2.48316195850348e+66*cos(theta)**31 + 4.61498925141534e+65*cos(theta)**29 - 7.19817762610307e+64*cos(theta)**27 + 9.35763091393399e+63*cos(theta)**25 - 1.00511610246337e+63*cos(theta)**23 + 8.82353830406777e+61*cos(theta)**21 - 6.24517372380934e+60*cos(theta)**19 + 3.50368998284579e+59*cos(theta)**17 - 1.52480588053449e+58*cos(theta)**15 + 5.00639829443781e+56*cos(theta)**13 - 1.19528333935154e+55*cos(theta)**11 + 1.97300671261509e+53*cos(theta)**9 - 2.09337582240328e+51*cos(theta)**7 + 1.27422876146287e+49*cos(theta)**5 - 3.63753571642269e+46*cos(theta)**3 + 3.07224300373538e+43*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl87_m_minus_21(theta, phi):
    return 1.0698353748352e-40*(1.0 - cos(theta)**2)**10.5*(3.61907421801158e+64*cos(theta)**66 - 4.48723364025135e+65*cos(theta)**64 + 2.64510614583238e+66*cos(theta)**62 - 9.86567203504739e+66*cos(theta)**60 + 2.61410770988531e+67*cos(theta)**58 - 5.23772126598839e+67*cos(theta)**56 + 8.24753655380584e+67*cos(theta)**54 - 1.04722491645929e+68*cos(theta)**52 + 1.09168257800709e+68*cos(theta)**50 - 9.46433940593546e+67*cos(theta)**48 + 6.88759667735174e+67*cos(theta)**46 - 4.23568779623236e+67*cos(theta)**44 + 2.21134693997561e+67*cos(theta)**42 - 9.8294771054156e+66*cos(theta)**40 + 3.72545779505548e+66*cos(theta)**38 - 1.20413647352828e+66*cos(theta)**36 + 3.31558556959272e+65*cos(theta)**34 - 7.75988112032338e+64*cos(theta)**32 + 1.53832975047178e+64*cos(theta)**30 - 2.57077772360824e+63*cos(theta)**28 + 3.59908881305154e+62*cos(theta)**26 - 4.18798376026405e+61*cos(theta)**24 + 4.01069922912171e+60*cos(theta)**22 - 3.12258686190467e+59*cos(theta)**20 + 1.94649443491433e+58*cos(theta)**18 - 9.53003675334055e+56*cos(theta)**16 + 3.5759987817413e+55*cos(theta)**14 - 9.9606944945962e+53*cos(theta)**12 + 1.97300671261509e+52*cos(theta)**10 - 2.6167197780041e+50*cos(theta)**8 + 2.12371460243811e+48*cos(theta)**6 - 9.09383929105672e+45*cos(theta)**4 + 1.53612150186769e+43*cos(theta)**2 - 4.2705629743333e+39)*sin(21*phi)

#@torch.jit.script
def Yl87_m_minus_20(theta, phi):
    return 9.10052051744521e-39*(1.0 - cos(theta)**2)**10*(5.40160331046505e+62*cos(theta)**67 - 6.90343636961747e+63*cos(theta)**65 + 4.19858118386092e+64*cos(theta)**63 - 1.617323284434e+65*cos(theta)**61 + 4.43069103370392e+65*cos(theta)**59 - 9.18898467717261e+65*cos(theta)**57 + 1.49955210069197e+66*cos(theta)**55 - 1.97589606879111e+66*cos(theta)**53 + 2.1405540745237e+66*cos(theta)**51 - 1.93149783794601e+66*cos(theta)**49 + 1.4654461015642e+66*cos(theta)**47 - 9.41263954718301e+65*cos(theta)**45 + 5.14266730226887e+65*cos(theta)**43 - 2.39743344034527e+65*cos(theta)**41 + 9.55245588475763e+64*cos(theta)**39 - 3.25442290142777e+64*cos(theta)**37 + 9.47310162740776e+63*cos(theta)**35 - 2.35147912737072e+63*cos(theta)**33 + 4.96235403377994e+62*cos(theta)**31 - 8.8647507710629e+61*cos(theta)**29 + 1.33299585668575e+61*cos(theta)**27 - 1.67519350410562e+60*cos(theta)**25 + 1.74378227353118e+59*cos(theta)**23 - 1.48694612471651e+58*cos(theta)**21 + 1.02447075521807e+57*cos(theta)**19 - 5.60590397255327e+55*cos(theta)**17 + 2.38399918782753e+54*cos(theta)**15 - 7.66207268815093e+52*cos(theta)**13 + 1.79364246601372e+51*cos(theta)**11 - 2.90746642000456e+49*cos(theta)**9 + 3.03387800348302e+47*cos(theta)**7 - 1.81876785821134e+45*cos(theta)**5 + 5.12040500622563e+42*cos(theta)**3 - 4.2705629743333e+39*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl87_m_minus_19(theta, phi):
    return 7.76269599145231e-37*(1.0 - cos(theta)**2)**9.5*(7.94353428009566e+60*cos(theta)**68 - 1.0459752075178e+62*cos(theta)**66 + 6.56028309978268e+62*cos(theta)**64 - 2.60858594263548e+63*cos(theta)**62 + 7.38448505617319e+63*cos(theta)**60 - 1.58430770296079e+64*cos(theta)**58 + 2.67777160837852e+64*cos(theta)**56 - 3.65906679405761e+64*cos(theta)**54 + 4.11645014331481e+64*cos(theta)**52 - 3.86299567589203e+64*cos(theta)**50 + 3.05301271159209e+64*cos(theta)**48 - 2.04622598851805e+64*cos(theta)**46 + 1.16878802324292e+64*cos(theta)**44 - 5.70817485796493e+63*cos(theta)**42 + 2.38811397118941e+63*cos(theta)**40 - 8.56427079323098e+62*cos(theta)**38 + 2.63141711872438e+62*cos(theta)**36 - 6.91611508050212e+61*cos(theta)**34 + 1.55073563555623e+61*cos(theta)**32 - 2.95491692368763e+60*cos(theta)**30 + 4.76069948816341e+59*cos(theta)**28 - 6.44305193886777e+58*cos(theta)**26 + 7.26575947304658e+57*cos(theta)**24 - 6.75884602143868e+56*cos(theta)**22 + 5.12235377609034e+55*cos(theta)**20 - 3.11439109586293e+54*cos(theta)**18 + 1.48999949239221e+53*cos(theta)**16 - 5.47290906296495e+51*cos(theta)**14 + 1.49470205501143e+50*cos(theta)**12 - 2.90746642000456e+48*cos(theta)**10 + 3.79234750435377e+46*cos(theta)**8 - 3.03127976368557e+44*cos(theta)**6 + 1.28010125155641e+42*cos(theta)**4 - 2.13528148716665e+39*cos(theta)**2 + 5.86938286741796e+35)*sin(19*phi)

#@torch.jit.script
def Yl87_m_minus_18(theta, phi):
    return 6.63880720004326e-35*(1.0 - cos(theta)**2)**9*(1.15123685218778e+59*cos(theta)**69 - 1.56115702614597e+60*cos(theta)**67 + 1.00927432304349e+61*cos(theta)**65 - 4.14061260735791e+61*cos(theta)**63 + 1.21057132068413e+62*cos(theta)**61 - 2.68526729315389e+62*cos(theta)**59 + 4.69784492697986e+62*cos(theta)**57 - 6.65284871646837e+62*cos(theta)**55 + 7.76688706285813e+62*cos(theta)**53 - 7.57450132527848e+62*cos(theta)**51 + 6.23063818692262e+62*cos(theta)**49 - 4.35367231599584e+62*cos(theta)**47 + 2.59730671831761e+62*cos(theta)**45 - 1.32748252510812e+62*cos(theta)**43 + 5.82466822241319e+61*cos(theta)**41 - 2.19596687005923e+61*cos(theta)**39 + 7.11193815871454e+60*cos(theta)**37 - 1.97603288014346e+60*cos(theta)**35 + 4.69919889562494e+59*cos(theta)**33 - 9.53199007641172e+58*cos(theta)**31 + 1.6416205131598e+58*cos(theta)**29 - 2.38631553291399e+57*cos(theta)**27 + 2.90630378921863e+56*cos(theta)**25 - 2.93862870497334e+55*cos(theta)**23 + 2.43921608385254e+54*cos(theta)**21 - 1.63915320834891e+53*cos(theta)**19 + 8.76470289642474e+51*cos(theta)**17 - 3.64860604197663e+50*cos(theta)**15 + 1.14977081154726e+49*cos(theta)**13 - 2.64315129091324e+47*cos(theta)**11 + 4.21371944928197e+45*cos(theta)**9 - 4.33039966240796e+43*cos(theta)**7 + 2.56020250311282e+41*cos(theta)**5 - 7.11760495722217e+38*cos(theta)**3 + 5.86938286741796e+35*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl87_m_minus_17(theta, phi):
    return 5.69159154928737e-33*(1.0 - cos(theta)**2)**8.5*(1.64462407455397e+57*cos(theta)**70 - 2.29581915609701e+58*cos(theta)**68 + 1.52920351976286e+59*cos(theta)**66 - 6.46970719899673e+59*cos(theta)**64 + 1.95253438820021e+60*cos(theta)**62 - 4.47544548858981e+60*cos(theta)**60 + 8.0997326327239e+60*cos(theta)**58 - 1.18800869936935e+61*cos(theta)**56 + 1.4383124190478e+61*cos(theta)**54 - 1.45663487024586e+61*cos(theta)**52 + 1.24612763738452e+61*cos(theta)**50 - 9.07015065832467e+60*cos(theta)**48 + 5.64631895286437e+60*cos(theta)**46 - 3.0170057388821e+60*cos(theta)**44 + 1.38682576724124e+60*cos(theta)**42 - 5.48991717514806e+59*cos(theta)**40 + 1.87156267334593e+59*cos(theta)**38 - 5.48898022262073e+58*cos(theta)**36 + 1.38211732224263e+58*cos(theta)**34 - 2.97874689887866e+57*cos(theta)**32 + 5.47206837719932e+56*cos(theta)**30 - 8.52255547469282e+55*cos(theta)**28 + 1.11780914969947e+55*cos(theta)**26 - 1.22442862707222e+54*cos(theta)**24 + 1.10873458356934e+53*cos(theta)**22 - 8.19576604174454e+51*cos(theta)**20 + 4.86927938690264e+50*cos(theta)**18 - 2.28037877623539e+49*cos(theta)**16 + 8.21264865390898e+47*cos(theta)**14 - 2.20262607576103e+46*cos(theta)**12 + 4.21371944928197e+44*cos(theta)**10 - 5.41299957800995e+42*cos(theta)**8 + 4.26700417185469e+40*cos(theta)**6 - 1.77940123930554e+38*cos(theta)**4 + 2.93469143370898e+35*cos(theta)**2 - 7.98555492165708e+31)*sin(17*phi)

#@torch.jit.script
def Yl87_m_minus_16(theta, phi):
    return 4.89079624256809e-31*(1.0 - cos(theta)**2)**8*(2.3163719359915e+55*cos(theta)**71 - 3.32727413927103e+56*cos(theta)**69 + 2.2823933130789e+57*cos(theta)**67 - 9.9533956907642e+57*cos(theta)**65 + 3.09926093365113e+58*cos(theta)**63 - 7.33679588293412e+58*cos(theta)**61 + 1.37283603944473e+59*cos(theta)**59 - 2.08422578836728e+59*cos(theta)**57 + 2.61511348917782e+59*cos(theta)**55 - 2.74836767970917e+59*cos(theta)**53 + 2.44338752428338e+59*cos(theta)**51 - 1.85105115476014e+59*cos(theta)**49 + 1.20134445805625e+59*cos(theta)**47 - 6.70445719751577e+58*cos(theta)**45 + 3.22517620288659e+58*cos(theta)**43 - 1.3390041890605e+58*cos(theta)**41 + 4.79887864960495e+57*cos(theta)**39 - 1.48350816827587e+57*cos(theta)**37 + 3.94890663497894e+56*cos(theta)**35 - 9.02650575417776e+55*cos(theta)**33 + 1.76518334748365e+55*cos(theta)**31 - 2.9388122326527e+54*cos(theta)**29 + 4.14003388777583e+53*cos(theta)**27 - 4.8977145082889e+52*cos(theta)**25 + 4.82058514595364e+51*cos(theta)**23 - 3.90274573416407e+50*cos(theta)**21 + 2.5627786246856e+49*cos(theta)**19 - 1.34139928013847e+48*cos(theta)**17 + 5.47509910260599e+46*cos(theta)**15 - 1.69432775058541e+45*cos(theta)**13 + 3.83065404480179e+43*cos(theta)**11 - 6.01444397556661e+41*cos(theta)**9 + 6.0957202455067e+39*cos(theta)**7 - 3.55880247861109e+37*cos(theta)**5 + 9.78230477902992e+34*cos(theta)**3 - 7.98555492165708e+31*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl87_m_minus_15(theta, phi):
    return 4.21176790154604e-29*(1.0 - cos(theta)**2)**7.5*(3.21718324443264e+53*cos(theta)**72 - 4.75324877038719e+54*cos(theta)**70 + 3.35646075452779e+55*cos(theta)**68 - 1.50809025617639e+56*cos(theta)**66 + 4.84259520882989e+56*cos(theta)**64 - 1.18335417466679e+57*cos(theta)**62 + 2.28806006574121e+57*cos(theta)**60 - 3.59349273856428e+57*cos(theta)**58 + 4.66984551638896e+57*cos(theta)**56 - 5.08956977723921e+57*cos(theta)**54 + 4.69882216208343e+57*cos(theta)**52 - 3.70210230952028e+57*cos(theta)**50 + 2.50280095428385e+57*cos(theta)**48 - 1.45749069511212e+57*cos(theta)**46 + 7.32994591565135e+56*cos(theta)**44 - 3.18810521204882e+56*cos(theta)**42 + 1.19971966240124e+56*cos(theta)**40 - 3.90396886388388e+55*cos(theta)**38 + 1.09691850971637e+55*cos(theta)**36 - 2.65485463358169e+54*cos(theta)**34 + 5.51619796088641e+53*cos(theta)**32 - 9.79604077550898e+52*cos(theta)**30 + 1.47858353134851e+52*cos(theta)**28 - 1.88373634934188e+51*cos(theta)**26 + 2.00857714414735e+50*cos(theta)**24 - 1.77397533371094e+49*cos(theta)**22 + 1.2813893123428e+48*cos(theta)**20 - 7.45221822299148e+46*cos(theta)**18 + 3.42193693912874e+45*cos(theta)**16 - 1.21023410756101e+44*cos(theta)**14 + 3.19221170400149e+42*cos(theta)**12 - 6.01444397556661e+40*cos(theta)**10 + 7.61965030688338e+38*cos(theta)**8 - 5.93133746435181e+36*cos(theta)**6 + 2.44557619475748e+34*cos(theta)**4 - 3.99277746082854e+31*cos(theta)**2 + 1.07680082546617e+28)*sin(15*phi)

#@torch.jit.script
def Yl87_m_minus_14(theta, phi):
    return 3.63434328353075e-27*(1.0 - cos(theta)**2)**7*(4.40710033483924e+51*cos(theta)**73 - 6.69471657801012e+52*cos(theta)**71 + 4.86443587612724e+53*cos(theta)**69 - 2.25088097936775e+54*cos(theta)**67 + 7.4501464751229e+54*cos(theta)**65 - 1.87833995978856e+55*cos(theta)**63 + 3.75091814055937e+55*cos(theta)**61 - 6.09066565858353e+55*cos(theta)**59 + 8.19271143226134e+55*cos(theta)**57 - 9.25376323134402e+55*cos(theta)**55 + 8.86570219261024e+55*cos(theta)**53 - 7.25902413631427e+55*cos(theta)**51 + 5.10775704955888e+55*cos(theta)**49 - 3.10104403215345e+55*cos(theta)**47 + 1.62887687014474e+55*cos(theta)**45 - 7.41419816755539e+54*cos(theta)**43 + 2.9261455180518e+54*cos(theta)**41 - 1.00101765740612e+54*cos(theta)**39 + 2.96464462085506e+53*cos(theta)**37 - 7.58529895309056e+52*cos(theta)**35 + 1.67157513966255e+52*cos(theta)**33 - 3.16001315338999e+51*cos(theta)**31 + 5.09856390120176e+50*cos(theta)**29 - 6.97680129385883e+49*cos(theta)**27 + 8.0343085765894e+48*cos(theta)**25 - 7.71293623352583e+47*cos(theta)**23 + 6.10185386829904e+46*cos(theta)**21 - 3.92222011736394e+45*cos(theta)**19 + 2.01290408184044e+44*cos(theta)**17 - 8.06822738374004e+42*cos(theta)**15 + 2.45554746461653e+41*cos(theta)**13 - 5.4676763414242e+39*cos(theta)**11 + 8.46627811875931e+37*cos(theta)**9 - 8.4733392347883e+35*cos(theta)**7 + 4.89115238951496e+33*cos(theta)**5 - 1.33092582027618e+31*cos(theta)**3 + 1.07680082546617e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl87_m_minus_13(theta, phi):
    return 3.14197332166303e-25*(1.0 - cos(theta)**2)**6.5*(5.95554099302599e+49*cos(theta)**74 - 9.2982174694585e+50*cos(theta)**72 + 6.9491941087532e+51*cos(theta)**70 - 3.31011908730552e+52*cos(theta)**68 + 1.12881007198832e+53*cos(theta)**66 - 2.93490618716963e+53*cos(theta)**64 + 6.04986796864414e+53*cos(theta)**62 - 1.01511094309726e+54*cos(theta)**60 + 1.41253645383816e+54*cos(theta)**58 - 1.65245771988286e+54*cos(theta)**56 + 1.64179670233523e+54*cos(theta)**54 - 1.39596618006044e+54*cos(theta)**52 + 1.02155140991178e+54*cos(theta)**50 - 6.4605084003197e+53*cos(theta)**48 + 3.54103667422771e+53*cos(theta)**46 - 1.68504503808077e+53*cos(theta)**44 + 6.96701313821857e+52*cos(theta)**42 - 2.50254414351531e+52*cos(theta)**40 + 7.80169637067122e+51*cos(theta)**38 - 2.1070274869696e+51*cos(theta)**36 + 4.91639746959573e+50*cos(theta)**34 - 9.87504110434373e+49*cos(theta)**32 + 1.69952130040059e+49*cos(theta)**30 - 2.49171474780673e+48*cos(theta)**28 + 3.09011868330362e+47*cos(theta)**26 - 3.21372343063576e+46*cos(theta)**24 + 2.77356994013593e+45*cos(theta)**22 - 1.96111005868197e+44*cos(theta)**20 + 1.11828004546691e+43*cos(theta)**18 - 5.04264211483752e+41*cos(theta)**16 + 1.75396247472609e+40*cos(theta)**14 - 4.55639695118683e+38*cos(theta)**12 + 8.46627811875931e+36*cos(theta)**10 - 1.05916740434854e+35*cos(theta)**8 + 8.1519206491916e+32*cos(theta)**6 - 3.32731455069045e+30*cos(theta)**4 + 5.38400412733083e+27*cos(theta)**2 - 1.44072896101976e+24)*sin(13*phi)

#@torch.jit.script
def Yl87_m_minus_12(theta, phi):
    return 2.72102871457316e-23*(1.0 - cos(theta)**2)**6*(7.94072132403466e+47*cos(theta)**75 - 1.27372842047377e+49*cos(theta)**73 + 9.78759733627211e+49*cos(theta)**71 - 4.79727403957321e+50*cos(theta)**69 + 1.68479115222137e+51*cos(theta)**67 - 4.51524028795327e+51*cos(theta)**65 + 9.60296502959387e+51*cos(theta)**63 - 1.66411630015944e+52*cos(theta)**61 + 2.39412958277655e+52*cos(theta)**59 - 2.89904863137344e+52*cos(theta)**57 + 2.98508491333678e+52*cos(theta)**55 - 2.63389845294422e+52*cos(theta)**53 + 2.00304198021917e+52*cos(theta)**51 - 1.31847110210606e+52*cos(theta)**49 + 7.5341205834632e+51*cos(theta)**47 - 3.74454452906838e+51*cos(theta)**45 + 1.6202356135392e+51*cos(theta)**43 - 6.10376620369587e+50*cos(theta)**41 + 2.00043496683877e+50*cos(theta)**39 - 5.69466888370162e+49*cos(theta)**37 + 1.40468499131307e+49*cos(theta)**35 - 2.99243669828598e+48*cos(theta)**33 + 5.48232677548576e+47*cos(theta)**31 - 8.59211982002319e+46*cos(theta)**29 + 1.14448840122356e+46*cos(theta)**27 - 1.2854893722543e+45*cos(theta)**25 + 1.20589997397214e+44*cos(theta)**23 - 9.338619327057e+42*cos(theta)**21 + 5.88568444982584e+41*cos(theta)**19 - 2.96626006755148e+40*cos(theta)**17 + 1.16930831648406e+39*cos(theta)**15 - 3.50492073168218e+37*cos(theta)**13 + 7.69661647159937e+35*cos(theta)**11 - 1.17685267149838e+34*cos(theta)**9 + 1.16456009274166e+32*cos(theta)**7 - 6.6546291013809e+29*cos(theta)**5 + 1.79466804244361e+27*cos(theta)**3 - 1.44072896101976e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl87_m_minus_11(theta, phi):
    return 2.36024734775532e-21*(1.0 - cos(theta)**2)**5.5*(1.04483175316245e+46*cos(theta)**76 - 1.72125462226185e+47*cos(theta)**74 + 1.35938851892668e+48*cos(theta)**72 - 6.85324862796173e+48*cos(theta)**70 + 2.47763404738437e+49*cos(theta)**68 - 6.84127316356557e+49*cos(theta)**66 + 1.50046328587404e+50*cos(theta)**64 - 2.68405854864425e+50*cos(theta)**62 + 3.99021597129424e+50*cos(theta)**60 - 4.99835970926455e+50*cos(theta)**58 + 5.33050877381568e+50*cos(theta)**56 - 4.87758972767448e+50*cos(theta)**54 + 3.85200380811378e+50*cos(theta)**52 - 2.63694220421212e+50*cos(theta)**50 + 1.56960845488817e+50*cos(theta)**48 - 8.14031419362691e+49*cos(theta)**46 + 3.68235366713455e+49*cos(theta)**44 - 1.45327766754664e+49*cos(theta)**42 + 5.00108741709693e+48*cos(theta)**40 - 1.49859707465832e+48*cos(theta)**38 + 3.90190275364741e+47*cos(theta)**36 - 8.80128440672347e+46*cos(theta)**34 + 1.7132271173393e+46*cos(theta)**32 - 2.86403994000773e+45*cos(theta)**30 + 4.08745857579843e+44*cos(theta)**28 - 4.94418989328579e+43*cos(theta)**26 + 5.02458322488393e+42*cos(theta)**24 - 4.24482696684409e+41*cos(theta)**22 + 2.94284222491292e+40*cos(theta)**20 - 1.64792225975082e+39*cos(theta)**18 + 7.3081769780254e+37*cos(theta)**16 - 2.50351480834441e+36*cos(theta)**14 + 6.41384705966614e+34*cos(theta)**12 - 1.17685267149838e+33*cos(theta)**10 + 1.45570011592707e+31*cos(theta)**8 - 1.10910485023015e+29*cos(theta)**6 + 4.48667010610902e+26*cos(theta)**4 - 7.20364480509878e+23*cos(theta)**2 + 1.91484444579978e+20)*sin(11*phi)

#@torch.jit.script
def Yl87_m_minus_10(theta, phi):
    return 2.05029295166213e-19*(1.0 - cos(theta)**2)**5*(1.35692435475644e+44*cos(theta)**77 - 2.2950061630158e+45*cos(theta)**75 + 1.86217605332422e+46*cos(theta)**73 - 9.65246285628413e+46*cos(theta)**71 + 3.59077398171648e+47*cos(theta)**69 - 1.02108554680083e+48*cos(theta)**67 + 2.30840505519084e+48*cos(theta)**65 - 4.26041039467341e+48*cos(theta)**63 + 6.54133765785942e+48*cos(theta)**61 - 8.47179611739755e+48*cos(theta)**59 + 9.351769778624e+48*cos(theta)**57 - 8.86834495940814e+48*cos(theta)**55 + 7.26793171342224e+48*cos(theta)**53 - 5.17047491021985e+48*cos(theta)**51 + 3.20328256099626e+48*cos(theta)**49 - 1.73198174332487e+48*cos(theta)**47 + 8.18300814918789e+47*cos(theta)**45 - 3.37971550592241e+47*cos(theta)**43 + 1.21977741880413e+47*cos(theta)**41 - 3.842556601688e+46*cos(theta)**39 + 1.0545683117966e+46*cos(theta)**37 - 2.51465268763528e+45*cos(theta)**35 + 5.19159732527061e+44*cos(theta)**33 - 9.23883851615397e+43*cos(theta)**31 + 1.40946847441325e+43*cos(theta)**29 - 1.8311814419577e+42*cos(theta)**27 + 2.00983328995357e+41*cos(theta)**25 - 1.84557694210613e+40*cos(theta)**23 + 1.40135344043472e+39*cos(theta)**21 - 8.67327505132013e+37*cos(theta)**19 + 4.29892763413259e+36*cos(theta)**17 - 1.66900987222961e+35*cos(theta)**15 + 4.9337285074355e+33*cos(theta)**13 - 1.06986606499852e+32*cos(theta)**11 + 1.6174445732523e+30*cos(theta)**9 - 1.58443550032879e+28*cos(theta)**7 + 8.97334021221804e+25*cos(theta)**5 - 2.40121493503293e+23*cos(theta)**3 + 1.91484444579978e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl87_m_minus_9(theta, phi):
    return 1.78340133412671e-17*(1.0 - cos(theta)**2)**4.5*(1.7396466086621e+42*cos(theta)**78 - 3.01974495133657e+43*cos(theta)**76 + 2.51645412611381e+44*cos(theta)**74 - 1.34061984115057e+45*cos(theta)**72 + 5.12967711673782e+45*cos(theta)**70 - 1.50159639235416e+46*cos(theta)**68 + 3.49758341695581e+46*cos(theta)**66 - 6.65689124167721e+46*cos(theta)**64 + 1.05505446094507e+47*cos(theta)**62 - 1.41196601956626e+47*cos(theta)**60 + 1.61237409976276e+47*cos(theta)**58 - 1.58363302846574e+47*cos(theta)**56 + 1.34591328026338e+47*cos(theta)**54 - 9.94322098119201e+46*cos(theta)**52 + 6.40656512199252e+46*cos(theta)**50 - 3.60829529859349e+46*cos(theta)**48 + 1.77891481504085e+46*cos(theta)**46 - 7.68117160436911e+45*cos(theta)**44 + 2.90423194953364e+45*cos(theta)**42 - 9.60639150422e+44*cos(theta)**40 + 2.77517976788578e+44*cos(theta)**38 - 6.98514635454244e+43*cos(theta)**36 + 1.52694038978547e+43*cos(theta)**34 - 2.88713703629812e+42*cos(theta)**32 + 4.69822824804418e+41*cos(theta)**30 - 6.53993372127749e+40*cos(theta)**28 + 7.73012803828297e+39*cos(theta)**26 - 7.68990392544219e+38*cos(theta)**24 + 6.36978836561238e+37*cos(theta)**22 - 4.33663752566006e+36*cos(theta)**20 + 2.38829313007366e+35*cos(theta)**18 - 1.0431311701435e+34*cos(theta)**16 + 3.52409179102535e+32*cos(theta)**14 - 8.91555054165436e+30*cos(theta)**12 + 1.6174445732523e+29*cos(theta)**10 - 1.98054437541098e+27*cos(theta)**8 + 1.49555670203634e+25*cos(theta)**6 - 6.00303733758231e+22*cos(theta)**4 + 9.57422222899891e+19*cos(theta)**2 - 2.53085440893442e+16)*sin(9*phi)

#@torch.jit.script
def Yl87_m_minus_8(theta, phi):
    return 1.55309581468744e-15*(1.0 - cos(theta)**2)**4*(2.20208431476215e+40*cos(theta)**79 - 3.9217466900475e+41*cos(theta)**77 + 3.35527216815175e+42*cos(theta)**75 - 1.8364655358227e+43*cos(theta)**73 + 7.22489734751806e+43*cos(theta)**71 - 2.17622665558574e+44*cos(theta)**69 + 5.22027375665046e+44*cos(theta)**67 - 1.02413711410419e+45*cos(theta)**65 + 1.67468962054773e+45*cos(theta)**63 - 2.31469839273157e+45*cos(theta)**61 + 2.73283745722501e+45*cos(theta)**59 - 2.77830355871182e+45*cos(theta)**57 + 2.44711505502432e+45*cos(theta)**55 - 1.87607943041359e+45*cos(theta)**53 + 1.25618923960638e+45*cos(theta)**51 - 7.36386795631324e+44*cos(theta)**49 + 3.78492513838478e+44*cos(theta)**47 - 1.70692702319314e+44*cos(theta)**45 + 6.75402778961312e+43*cos(theta)**43 - 2.34302231810244e+43*cos(theta)**41 + 7.11584555868148e+42*cos(theta)**39 - 1.88787739311958e+42*cos(theta)**37 + 4.3626868279585e+41*cos(theta)**35 - 8.74890010999429e+40*cos(theta)**33 + 1.51555749936909e+40*cos(theta)**31 - 2.2551495590612e+39*cos(theta)**29 + 2.86301038454925e+38*cos(theta)**27 - 3.07596157017688e+37*cos(theta)**25 + 2.76947320244016e+36*cos(theta)**23 - 2.06506548840955e+35*cos(theta)**21 + 1.25699638424929e+34*cos(theta)**19 - 6.1360657067265e+32*cos(theta)**17 + 2.34939452735024e+31*cos(theta)**15 - 6.85811580127258e+29*cos(theta)**13 + 1.47040415750209e+28*cos(theta)**11 - 2.20060486156776e+26*cos(theta)**9 + 2.13650957433763e+24*cos(theta)**7 - 1.20060746751646e+22*cos(theta)**5 + 3.1914074096663e+19*cos(theta)**3 - 2.53085440893442e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl87_m_minus_7(theta, phi):
    return 1.35395754117171e-13*(1.0 - cos(theta)**2)**3.5*(2.75260539345268e+38*cos(theta)**80 - 5.02788037185577e+39*cos(theta)**78 + 4.41483180019967e+40*cos(theta)**76 - 2.48171018354419e+41*cos(theta)**74 + 1.00345796493306e+42*cos(theta)**72 - 3.10889522226535e+42*cos(theta)**70 + 7.6768731715448e+42*cos(theta)**68 - 1.55172290015786e+43*cos(theta)**66 + 2.61670253210582e+43*cos(theta)**64 - 3.73338450440576e+43*cos(theta)**62 + 4.55472909537502e+43*cos(theta)**60 - 4.79017854950314e+43*cos(theta)**58 + 4.36984831254343e+43*cos(theta)**56 - 3.47422116743257e+43*cos(theta)**54 + 2.41574853770457e+43*cos(theta)**52 - 1.47277359126265e+43*cos(theta)**50 + 7.88526070496829e+42*cos(theta)**48 - 3.71071091998508e+42*cos(theta)**46 + 1.53500631582116e+42*cos(theta)**44 - 5.57862456691057e+41*cos(theta)**42 + 1.77896138967037e+41*cos(theta)**40 - 4.96809840294626e+40*cos(theta)**38 + 1.21185745221069e+40*cos(theta)**36 - 2.5732059147042e+39*cos(theta)**34 + 4.7361171855284e+38*cos(theta)**32 - 7.51716519687068e+37*cos(theta)**30 + 1.02250370876759e+37*cos(theta)**28 - 1.18306214237572e+36*cos(theta)**26 + 1.1539471676834e+35*cos(theta)**24 - 9.38666131095252e+33*cos(theta)**22 + 6.28498192124647e+32*cos(theta)**20 - 3.40892539262583e+31*cos(theta)**18 + 1.4683715795939e+30*cos(theta)**16 - 4.89865414376613e+28*cos(theta)**14 + 1.22533679791841e+27*cos(theta)**12 - 2.20060486156776e+25*cos(theta)**10 + 2.67063696792204e+23*cos(theta)**8 - 2.00101244586077e+21*cos(theta)**6 + 7.97851852416576e+18*cos(theta)**4 - 1.26542720446721e+16*cos(theta)**2 + 3330071590703.18)*sin(7*phi)

#@torch.jit.script
def Yl87_m_minus_6(theta, phi):
    return 1.1814394860243e-11*(1.0 - cos(theta)**2)**3*(3.39827826352183e+36*cos(theta)**81 - 6.36440553399464e+37*cos(theta)**79 + 5.73354779246711e+38*cos(theta)**77 - 3.30894691139226e+39*cos(theta)**75 + 1.3745999519631e+40*cos(theta)**73 - 4.37872566516246e+40*cos(theta)**71 + 1.11259031471664e+41*cos(theta)**69 - 2.31600432859382e+41*cos(theta)**67 + 4.02569620323972e+41*cos(theta)**65 - 5.92600714985041e+41*cos(theta)**63 + 7.46676900881151e+41*cos(theta)**61 - 8.11894669407313e+41*cos(theta)**59 + 7.66640054832181e+41*cos(theta)**57 - 6.31676575896831e+41*cos(theta)**55 + 4.55801610887655e+41*cos(theta)**53 - 2.88779135541696e+41*cos(theta)**51 + 1.60923687856496e+41*cos(theta)**49 - 7.89512961698952e+40*cos(theta)**47 + 3.41112514626925e+40*cos(theta)**45 - 1.29735455044432e+40*cos(theta)**43 + 4.33893021870822e+39*cos(theta)**41 - 1.27387138537083e+39*cos(theta)**39 + 3.27529041138025e+38*cos(theta)**37 - 7.35201689915486e+37*cos(theta)**35 + 1.4351870259177e+37*cos(theta)**33 - 2.42489199899054e+36*cos(theta)**31 + 3.52587485781927e+35*cos(theta)**29 - 4.3817116384286e+34*cos(theta)**27 + 4.61578867073361e+33*cos(theta)**25 - 4.08115709171849e+32*cos(theta)**23 + 2.99284853392689e+31*cos(theta)**21 - 1.79417125927675e+30*cos(theta)**19 + 8.6374798799641e+28*cos(theta)**17 - 3.26576942917742e+27*cos(theta)**15 + 9.42566767629547e+25*cos(theta)**13 - 2.00054987415251e+24*cos(theta)**11 + 2.96737440880226e+22*cos(theta)**9 - 2.85858920837253e+20*cos(theta)**7 + 1.59570370483315e+18*cos(theta)**5 - 4.21809068155737e+15*cos(theta)**3 + 3330071590703.18*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl87_m_minus_5(theta, phi):
    return 1.0317153265403e-9*(1.0 - cos(theta)**2)**2.5*(4.14424178478272e+34*cos(theta)**82 - 7.95550691749331e+35*cos(theta)**80 + 7.35070229803475e+36*cos(theta)**78 - 4.35387751498981e+37*cos(theta)**76 + 1.85756750265284e+38*cos(theta)**74 - 6.08156342383675e+38*cos(theta)**72 + 1.58941473530948e+39*cos(theta)**70 - 3.40588871852032e+39*cos(theta)**68 + 6.09953970187837e+39*cos(theta)**66 - 9.25938617164126e+39*cos(theta)**64 + 1.20431758206637e+40*cos(theta)**62 - 1.35315778234552e+40*cos(theta)**60 + 1.32179319798652e+40*cos(theta)**58 - 1.12799388553005e+40*cos(theta)**56 + 8.44077057199361e+39*cos(theta)**54 - 5.55344491426338e+39*cos(theta)**52 + 3.21847375712991e+39*cos(theta)**50 - 1.64481867020615e+39*cos(theta)**48 + 7.41548944841142e+38*cos(theta)**46 - 2.94853306919163e+38*cos(theta)**44 + 1.03307862350196e+38*cos(theta)**42 - 3.18467846342709e+37*cos(theta)**40 + 8.61918529310593e+36*cos(theta)**38 - 2.04222691643191e+36*cos(theta)**36 + 4.22113831152264e+35*cos(theta)**34 - 7.57778749684545e+34*cos(theta)**32 + 1.17529161927309e+34*cos(theta)**30 - 1.5648970137245e+33*cos(theta)**28 + 1.77530333489754e+32*cos(theta)**26 - 1.70048212154937e+31*cos(theta)**24 + 1.3603856972395e+30*cos(theta)**22 - 8.97085629638377e+28*cos(theta)**20 + 4.79859993331339e+27*cos(theta)**18 - 2.04110589323589e+26*cos(theta)**16 + 6.73261976878248e+24*cos(theta)**14 - 1.66712489512709e+23*cos(theta)**12 + 2.96737440880226e+21*cos(theta)**10 - 3.57323651046566e+19*cos(theta)**8 + 2.65950617472192e+17*cos(theta)**6 - 1.05452267038934e+15*cos(theta)**4 + 1665035795351.59*cos(theta)**2 - 436673431.7733)*sin(5*phi)

#@torch.jit.script
def Yl87_m_minus_4(theta, phi):
    return 9.01556278258805e-8*(1.0 - cos(theta)**2)**2*(4.99306239130448e+32*cos(theta)**83 - 9.8216134783868e+33*cos(theta)**81 + 9.30468645320855e+34*cos(theta)**79 - 5.65438638310365e+35*cos(theta)**77 + 2.47675667020379e+36*cos(theta)**75 - 8.33090879977637e+36*cos(theta)**73 + 2.23861230325279e+37*cos(theta)**71 - 4.93607060655119e+37*cos(theta)**69 + 9.10379059981846e+37*cos(theta)**67 - 1.42452094948327e+38*cos(theta)**65 + 1.91161520962916e+38*cos(theta)**63 - 2.21829144646807e+38*cos(theta)**61 + 2.24032745421444e+38*cos(theta)**59 - 1.9789366412808e+38*cos(theta)**57 + 1.53468555854429e+38*cos(theta)**55 - 1.04781979514403e+38*cos(theta)**53 + 6.31073285711748e+37*cos(theta)**51 - 3.35677279633908e+37*cos(theta)**49 + 1.57776371242796e+37*cos(theta)**47 - 6.55229570931474e+36*cos(theta)**45 + 2.40250842674874e+36*cos(theta)**43 - 7.76750844738314e+35*cos(theta)**41 + 2.2100475110528e+35*cos(theta)**39 - 5.51953220657272e+34*cos(theta)**37 + 1.2060395175779e+34*cos(theta)**35 - 2.29629924146832e+33*cos(theta)**33 + 3.79126328797771e+32*cos(theta)**31 - 5.39619659905e+31*cos(theta)**29 + 6.57519753665756e+30*cos(theta)**27 - 6.80192848619748e+29*cos(theta)**25 + 5.91472042278042e+28*cos(theta)**23 - 4.27183633161132e+27*cos(theta)**21 + 2.52557891227021e+26*cos(theta)**19 - 1.20065052543288e+25*cos(theta)**17 + 4.48841317918832e+23*cos(theta)**15 - 1.28240376548238e+22*cos(theta)**13 + 2.69761309891115e+20*cos(theta)**11 - 3.97026278940629e+18*cos(theta)**9 + 3.79929453531703e+16*cos(theta)**7 - 210904534077868.0*cos(theta)**5 + 555011931783.864*cos(theta)**3 - 436673431.7733*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl87_m_minus_3(theta, phi):
    return 7.88230401443765e-6*(1.0 - cos(theta)**2)**1.5*(5.9441218944101e+30*cos(theta)**84 - 1.19775774126668e+32*cos(theta)**82 + 1.16308580665107e+33*cos(theta)**80 - 7.24921331167135e+33*cos(theta)**78 + 3.2588903555313e+34*cos(theta)**76 - 1.12579848645627e+35*cos(theta)**74 + 3.10918375451777e+35*cos(theta)**72 - 7.05152943793027e+35*cos(theta)**70 + 1.33879273526742e+36*cos(theta)**68 - 2.15836507497465e+36*cos(theta)**66 + 2.98689876504557e+36*cos(theta)**64 - 3.57788942978721e+36*cos(theta)**62 + 3.7338790903574e+36*cos(theta)**60 - 3.4119597263462e+36*cos(theta)**58 + 2.74050992597195e+36*cos(theta)**56 - 1.94040702804451e+36*cos(theta)**54 + 1.21360247252259e+36*cos(theta)**52 - 6.71354559267817e+35*cos(theta)**50 + 3.28700773422492e+35*cos(theta)**48 - 1.4244121107206e+35*cos(theta)**46 + 5.46024642442895e+34*cos(theta)**44 - 1.84940677318646e+34*cos(theta)**42 + 5.525118777632e+33*cos(theta)**40 - 1.45250847541387e+33*cos(theta)**38 + 3.35010977104972e+32*cos(theta)**36 - 6.75382129843623e+31*cos(theta)**34 + 1.18476977749303e+31*cos(theta)**32 - 1.79873219968333e+30*cos(theta)**30 + 2.34828483452056e+29*cos(theta)**28 - 2.61612634084518e+28*cos(theta)**26 + 2.46446684282517e+27*cos(theta)**24 - 1.94174378709605e+26*cos(theta)**22 + 1.2627894561351e+25*cos(theta)**20 - 6.67028069684931e+23*cos(theta)**18 + 2.8052582369927e+22*cos(theta)**16 - 9.16002689630269e+20*cos(theta)**14 + 2.24801091575929e+19*cos(theta)**12 - 3.97026278940629e+17*cos(theta)**10 + 4.74911816914628e+15*cos(theta)**8 - 35150755679644.7*cos(theta)**6 + 138752982945.966*cos(theta)**4 - 218336715.88665*cos(theta)**2 + 57126.2992900706)*sin(3*phi)

#@torch.jit.script
def Yl87_m_minus_2(theta, phi):
    return 0.000689420032930979*(1.0 - cos(theta)**2)*(6.99308458165894e+28*cos(theta)**85 - 1.44308161598396e+30*cos(theta)**83 + 1.43590840327292e+31*cos(theta)**81 - 9.17621938186247e+31*cos(theta)**79 + 4.23232513705363e+32*cos(theta)**77 - 1.50106464860836e+33*cos(theta)**75 + 4.25915582810653e+33*cos(theta)**73 - 9.93173160271869e+33*cos(theta)**71 + 1.94027932647452e+34*cos(theta)**69 - 3.22144041040993e+34*cos(theta)**67 + 4.59522886930088e+34*cos(theta)**65 - 5.6791895710908e+34*cos(theta)**63 + 6.12111326288098e+34*cos(theta)**61 - 5.78298258702746e+34*cos(theta)**59 + 4.80791215082798e+34*cos(theta)**57 - 3.52801277826274e+34*cos(theta)**55 + 2.28981598589168e+34*cos(theta)**53 - 1.31638148876042e+34*cos(theta)**51 + 6.70817904943862e+33*cos(theta)**49 - 3.03066406536297e+33*cos(theta)**47 + 1.21338809431754e+33*cos(theta)**45 - 4.30094598415456e+32*cos(theta)**43 + 1.3475899457639e+32*cos(theta)**41 - 3.72438070618942e+31*cos(theta)**39 + 9.0543507325668e+30*cos(theta)**37 - 1.92966322812464e+30*cos(theta)**35 + 3.59021144694859e+29*cos(theta)**33 - 5.80236193446237e+28*cos(theta)**31 + 8.09753391213985e+27*cos(theta)**29 - 9.68935681794513e+26*cos(theta)**27 + 9.85786737130069e+25*cos(theta)**25 - 8.44236429172198e+24*cos(theta)**23 + 6.01328312445287e+23*cos(theta)**21 - 3.51067405097332e+22*cos(theta)**19 + 1.65015190411335e+21*cos(theta)**17 - 6.10668459753513e+19*cos(theta)**15 + 1.72923916596868e+18*cos(theta)**13 - 3.60932980855118e+16*cos(theta)**11 + 527679796571809.0*cos(theta)**9 - 5021536525663.53*cos(theta)**7 + 27750596589.1932*cos(theta)**5 - 72778905.2955499*cos(theta)**3 + 57126.2992900706*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl87_m_minus_1(theta, phi):
    return 0.0603153882582824*(1.0 - cos(theta)**2)**0.5*(8.13149369960342e+26*cos(theta)**86 - 1.7179543047428e+28*cos(theta)**84 + 1.75110780886942e+29*cos(theta)**82 - 1.14702742273281e+30*cos(theta)**80 + 5.42605786801748e+30*cos(theta)**78 - 1.97508506395836e+31*cos(theta)**76 + 5.75561598392774e+31*cos(theta)**74 - 1.37940716704426e+32*cos(theta)**72 + 2.77182760924932e+32*cos(theta)**70 - 4.7374123682499e+32*cos(theta)**68 + 6.9624679837892e+32*cos(theta)**66 - 8.87373370482938e+32*cos(theta)**64 + 9.87276332722739e+32*cos(theta)**62 - 9.63830431171244e+32*cos(theta)**60 + 8.28950370832411e+32*cos(theta)**58 - 6.30002281832632e+32*cos(theta)**56 + 4.24039997387349e+32*cos(theta)**54 - 2.53150286300082e+32*cos(theta)**52 + 1.34163580988772e+32*cos(theta)**50 - 6.31388346950619e+31*cos(theta)**48 + 2.63780020503814e+31*cos(theta)**46 - 9.77487723671492e+30*cos(theta)**44 + 3.20854748991406e+30*cos(theta)**42 - 9.31095176547355e+29*cos(theta)**40 + 2.38272387699126e+29*cos(theta)**38 - 5.36017563367954e+28*cos(theta)**36 + 1.05594454322017e+28*cos(theta)**34 - 1.81323810451949e+27*cos(theta)**32 + 2.69917797071329e+26*cos(theta)**30 - 3.46048457783754e+25*cos(theta)**28 + 3.79148745050027e+24*cos(theta)**26 - 3.51765178821749e+23*cos(theta)**24 + 2.73331051111494e+22*cos(theta)**22 - 1.75533702548666e+21*cos(theta)**20 + 9.16751057840751e+19*cos(theta)**18 - 3.81667787345945e+18*cos(theta)**16 + 1.23517083283477e+17*cos(theta)**14 - 3.00777484045931e+15*cos(theta)**12 + 52767979657180.9*cos(theta)**10 - 627692065707.941*cos(theta)**8 + 4625099431.5322*cos(theta)**6 - 18194726.3238875*cos(theta)**4 + 28563.1496450353*cos(theta)**2 - 7.46358757382683)*sin(phi)

#@torch.jit.script
def Yl87_m0(theta, phi):
    return 1.09575898949058e+26*cos(theta)**87 - 2.369499641436e+27*cos(theta)**85 + 2.473425064306e+28*cos(theta)**83 - 1.66017070884286e+29*cos(theta)**81 + 8.05232499498633e+29*cos(theta)**79 - 3.00717737085489e+30*cos(theta)**77 + 8.99693352466403e+30*cos(theta)**75 - 2.21530528224869e+31*cos(theta)**73 + 4.57690430955153e+31*cos(theta)**71 - 8.04926200228984e+31*cos(theta)**69 + 1.21829475208851e+32*cos(theta)**67 - 1.60050487039079e+32*cos(theta)**65 + 1.83722413378193e+32*cos(theta)**63 - 1.85239996555297e+32*cos(theta)**61 + 1.64717781193486e+32*cos(theta)**59 - 1.29577987872209e+32*cos(theta)**57 + 9.03874425891805e+31*cos(theta)**55 - 5.59972266353496e+31*cos(theta)**53 + 3.08409985225867e+31*cos(theta)**51 - 1.51065205978863e+31*cos(theta)**49 + 6.5797289715238e+30*cos(theta)**47 - 2.54661189338247e+30*cos(theta)**45 + 8.74790345055046e+29*cos(theta)**43 - 2.66240539799362e+29*cos(theta)**41 + 7.16263919407732e+28*cos(theta)**39 - 1.69840500569961e+28*cos(theta)**37 + 3.53701605314554e+27*cos(theta)**35 - 6.44176477386469e+26*cos(theta)**33 + 1.02078385372166e+26*cos(theta)**31 - 1.39895223100669e+25*cos(theta)**29 + 1.64630320518468e+24*cos(theta)**27 - 1.64959299177797e+23*cos(theta)**25 + 1.3932373241368e+22*cos(theta)**23 - 9.79952857955549e+20*cos(theta)**21 + 5.65668224768184e+19*cos(theta)**19 - 2.63208888259481e+18*cos(theta)**17 + 9.65383193184722e+16*cos(theta)**15 - 2.71247619171517e+15*cos(theta)**13 + 56239538265226.7*cos(theta)**11 - 817651230395.842*cos(theta)**9 + 7746169551.1185*cos(theta)**7 - 42661830.7299996*cos(theta)**5 + 111621.744453165*cos(theta)**3 - 87.5007142303357*cos(theta)

#@torch.jit.script
def Yl87_m1(theta, phi):
    return 0.0603153882582824*(1.0 - cos(theta)**2)**0.5*(8.13149369960342e+26*cos(theta)**86 - 1.7179543047428e+28*cos(theta)**84 + 1.75110780886942e+29*cos(theta)**82 - 1.14702742273281e+30*cos(theta)**80 + 5.42605786801748e+30*cos(theta)**78 - 1.97508506395836e+31*cos(theta)**76 + 5.75561598392774e+31*cos(theta)**74 - 1.37940716704426e+32*cos(theta)**72 + 2.77182760924932e+32*cos(theta)**70 - 4.7374123682499e+32*cos(theta)**68 + 6.9624679837892e+32*cos(theta)**66 - 8.87373370482938e+32*cos(theta)**64 + 9.87276332722739e+32*cos(theta)**62 - 9.63830431171244e+32*cos(theta)**60 + 8.28950370832411e+32*cos(theta)**58 - 6.30002281832632e+32*cos(theta)**56 + 4.24039997387349e+32*cos(theta)**54 - 2.53150286300082e+32*cos(theta)**52 + 1.34163580988772e+32*cos(theta)**50 - 6.31388346950619e+31*cos(theta)**48 + 2.63780020503814e+31*cos(theta)**46 - 9.77487723671492e+30*cos(theta)**44 + 3.20854748991406e+30*cos(theta)**42 - 9.31095176547355e+29*cos(theta)**40 + 2.38272387699126e+29*cos(theta)**38 - 5.36017563367954e+28*cos(theta)**36 + 1.05594454322017e+28*cos(theta)**34 - 1.81323810451949e+27*cos(theta)**32 + 2.69917797071329e+26*cos(theta)**30 - 3.46048457783754e+25*cos(theta)**28 + 3.79148745050027e+24*cos(theta)**26 - 3.51765178821749e+23*cos(theta)**24 + 2.73331051111494e+22*cos(theta)**22 - 1.75533702548666e+21*cos(theta)**20 + 9.16751057840751e+19*cos(theta)**18 - 3.81667787345945e+18*cos(theta)**16 + 1.23517083283477e+17*cos(theta)**14 - 3.00777484045931e+15*cos(theta)**12 + 52767979657180.9*cos(theta)**10 - 627692065707.941*cos(theta)**8 + 4625099431.5322*cos(theta)**6 - 18194726.3238875*cos(theta)**4 + 28563.1496450353*cos(theta)**2 - 7.46358757382683)*cos(phi)

#@torch.jit.script
def Yl87_m2(theta, phi):
    return 0.000689420032930979*(1.0 - cos(theta)**2)*(6.99308458165894e+28*cos(theta)**85 - 1.44308161598396e+30*cos(theta)**83 + 1.43590840327292e+31*cos(theta)**81 - 9.17621938186247e+31*cos(theta)**79 + 4.23232513705363e+32*cos(theta)**77 - 1.50106464860836e+33*cos(theta)**75 + 4.25915582810653e+33*cos(theta)**73 - 9.93173160271869e+33*cos(theta)**71 + 1.94027932647452e+34*cos(theta)**69 - 3.22144041040993e+34*cos(theta)**67 + 4.59522886930088e+34*cos(theta)**65 - 5.6791895710908e+34*cos(theta)**63 + 6.12111326288098e+34*cos(theta)**61 - 5.78298258702746e+34*cos(theta)**59 + 4.80791215082798e+34*cos(theta)**57 - 3.52801277826274e+34*cos(theta)**55 + 2.28981598589168e+34*cos(theta)**53 - 1.31638148876042e+34*cos(theta)**51 + 6.70817904943862e+33*cos(theta)**49 - 3.03066406536297e+33*cos(theta)**47 + 1.21338809431754e+33*cos(theta)**45 - 4.30094598415456e+32*cos(theta)**43 + 1.3475899457639e+32*cos(theta)**41 - 3.72438070618942e+31*cos(theta)**39 + 9.0543507325668e+30*cos(theta)**37 - 1.92966322812464e+30*cos(theta)**35 + 3.59021144694859e+29*cos(theta)**33 - 5.80236193446237e+28*cos(theta)**31 + 8.09753391213985e+27*cos(theta)**29 - 9.68935681794513e+26*cos(theta)**27 + 9.85786737130069e+25*cos(theta)**25 - 8.44236429172198e+24*cos(theta)**23 + 6.01328312445287e+23*cos(theta)**21 - 3.51067405097332e+22*cos(theta)**19 + 1.65015190411335e+21*cos(theta)**17 - 6.10668459753513e+19*cos(theta)**15 + 1.72923916596868e+18*cos(theta)**13 - 3.60932980855118e+16*cos(theta)**11 + 527679796571809.0*cos(theta)**9 - 5021536525663.53*cos(theta)**7 + 27750596589.1932*cos(theta)**5 - 72778905.2955499*cos(theta)**3 + 57126.2992900706*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl87_m3(theta, phi):
    return 7.88230401443765e-6*(1.0 - cos(theta)**2)**1.5*(5.9441218944101e+30*cos(theta)**84 - 1.19775774126668e+32*cos(theta)**82 + 1.16308580665107e+33*cos(theta)**80 - 7.24921331167135e+33*cos(theta)**78 + 3.2588903555313e+34*cos(theta)**76 - 1.12579848645627e+35*cos(theta)**74 + 3.10918375451777e+35*cos(theta)**72 - 7.05152943793027e+35*cos(theta)**70 + 1.33879273526742e+36*cos(theta)**68 - 2.15836507497465e+36*cos(theta)**66 + 2.98689876504557e+36*cos(theta)**64 - 3.57788942978721e+36*cos(theta)**62 + 3.7338790903574e+36*cos(theta)**60 - 3.4119597263462e+36*cos(theta)**58 + 2.74050992597195e+36*cos(theta)**56 - 1.94040702804451e+36*cos(theta)**54 + 1.21360247252259e+36*cos(theta)**52 - 6.71354559267817e+35*cos(theta)**50 + 3.28700773422492e+35*cos(theta)**48 - 1.4244121107206e+35*cos(theta)**46 + 5.46024642442895e+34*cos(theta)**44 - 1.84940677318646e+34*cos(theta)**42 + 5.525118777632e+33*cos(theta)**40 - 1.45250847541387e+33*cos(theta)**38 + 3.35010977104972e+32*cos(theta)**36 - 6.75382129843623e+31*cos(theta)**34 + 1.18476977749303e+31*cos(theta)**32 - 1.79873219968333e+30*cos(theta)**30 + 2.34828483452056e+29*cos(theta)**28 - 2.61612634084518e+28*cos(theta)**26 + 2.46446684282517e+27*cos(theta)**24 - 1.94174378709605e+26*cos(theta)**22 + 1.2627894561351e+25*cos(theta)**20 - 6.67028069684931e+23*cos(theta)**18 + 2.8052582369927e+22*cos(theta)**16 - 9.16002689630269e+20*cos(theta)**14 + 2.24801091575929e+19*cos(theta)**12 - 3.97026278940629e+17*cos(theta)**10 + 4.74911816914628e+15*cos(theta)**8 - 35150755679644.7*cos(theta)**6 + 138752982945.966*cos(theta)**4 - 218336715.88665*cos(theta)**2 + 57126.2992900706)*cos(3*phi)

#@torch.jit.script
def Yl87_m4(theta, phi):
    return 9.01556278258805e-8*(1.0 - cos(theta)**2)**2*(4.99306239130448e+32*cos(theta)**83 - 9.8216134783868e+33*cos(theta)**81 + 9.30468645320855e+34*cos(theta)**79 - 5.65438638310365e+35*cos(theta)**77 + 2.47675667020379e+36*cos(theta)**75 - 8.33090879977637e+36*cos(theta)**73 + 2.23861230325279e+37*cos(theta)**71 - 4.93607060655119e+37*cos(theta)**69 + 9.10379059981846e+37*cos(theta)**67 - 1.42452094948327e+38*cos(theta)**65 + 1.91161520962916e+38*cos(theta)**63 - 2.21829144646807e+38*cos(theta)**61 + 2.24032745421444e+38*cos(theta)**59 - 1.9789366412808e+38*cos(theta)**57 + 1.53468555854429e+38*cos(theta)**55 - 1.04781979514403e+38*cos(theta)**53 + 6.31073285711748e+37*cos(theta)**51 - 3.35677279633908e+37*cos(theta)**49 + 1.57776371242796e+37*cos(theta)**47 - 6.55229570931474e+36*cos(theta)**45 + 2.40250842674874e+36*cos(theta)**43 - 7.76750844738314e+35*cos(theta)**41 + 2.2100475110528e+35*cos(theta)**39 - 5.51953220657272e+34*cos(theta)**37 + 1.2060395175779e+34*cos(theta)**35 - 2.29629924146832e+33*cos(theta)**33 + 3.79126328797771e+32*cos(theta)**31 - 5.39619659905e+31*cos(theta)**29 + 6.57519753665756e+30*cos(theta)**27 - 6.80192848619748e+29*cos(theta)**25 + 5.91472042278042e+28*cos(theta)**23 - 4.27183633161132e+27*cos(theta)**21 + 2.52557891227021e+26*cos(theta)**19 - 1.20065052543288e+25*cos(theta)**17 + 4.48841317918832e+23*cos(theta)**15 - 1.28240376548238e+22*cos(theta)**13 + 2.69761309891115e+20*cos(theta)**11 - 3.97026278940629e+18*cos(theta)**9 + 3.79929453531703e+16*cos(theta)**7 - 210904534077868.0*cos(theta)**5 + 555011931783.864*cos(theta)**3 - 436673431.7733*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl87_m5(theta, phi):
    return 1.0317153265403e-9*(1.0 - cos(theta)**2)**2.5*(4.14424178478272e+34*cos(theta)**82 - 7.95550691749331e+35*cos(theta)**80 + 7.35070229803475e+36*cos(theta)**78 - 4.35387751498981e+37*cos(theta)**76 + 1.85756750265284e+38*cos(theta)**74 - 6.08156342383675e+38*cos(theta)**72 + 1.58941473530948e+39*cos(theta)**70 - 3.40588871852032e+39*cos(theta)**68 + 6.09953970187837e+39*cos(theta)**66 - 9.25938617164126e+39*cos(theta)**64 + 1.20431758206637e+40*cos(theta)**62 - 1.35315778234552e+40*cos(theta)**60 + 1.32179319798652e+40*cos(theta)**58 - 1.12799388553005e+40*cos(theta)**56 + 8.44077057199361e+39*cos(theta)**54 - 5.55344491426338e+39*cos(theta)**52 + 3.21847375712991e+39*cos(theta)**50 - 1.64481867020615e+39*cos(theta)**48 + 7.41548944841142e+38*cos(theta)**46 - 2.94853306919163e+38*cos(theta)**44 + 1.03307862350196e+38*cos(theta)**42 - 3.18467846342709e+37*cos(theta)**40 + 8.61918529310593e+36*cos(theta)**38 - 2.04222691643191e+36*cos(theta)**36 + 4.22113831152264e+35*cos(theta)**34 - 7.57778749684545e+34*cos(theta)**32 + 1.17529161927309e+34*cos(theta)**30 - 1.5648970137245e+33*cos(theta)**28 + 1.77530333489754e+32*cos(theta)**26 - 1.70048212154937e+31*cos(theta)**24 + 1.3603856972395e+30*cos(theta)**22 - 8.97085629638377e+28*cos(theta)**20 + 4.79859993331339e+27*cos(theta)**18 - 2.04110589323589e+26*cos(theta)**16 + 6.73261976878248e+24*cos(theta)**14 - 1.66712489512709e+23*cos(theta)**12 + 2.96737440880226e+21*cos(theta)**10 - 3.57323651046566e+19*cos(theta)**8 + 2.65950617472192e+17*cos(theta)**6 - 1.05452267038934e+15*cos(theta)**4 + 1665035795351.59*cos(theta)**2 - 436673431.7733)*cos(5*phi)

#@torch.jit.script
def Yl87_m6(theta, phi):
    return 1.1814394860243e-11*(1.0 - cos(theta)**2)**3*(3.39827826352183e+36*cos(theta)**81 - 6.36440553399464e+37*cos(theta)**79 + 5.73354779246711e+38*cos(theta)**77 - 3.30894691139226e+39*cos(theta)**75 + 1.3745999519631e+40*cos(theta)**73 - 4.37872566516246e+40*cos(theta)**71 + 1.11259031471664e+41*cos(theta)**69 - 2.31600432859382e+41*cos(theta)**67 + 4.02569620323972e+41*cos(theta)**65 - 5.92600714985041e+41*cos(theta)**63 + 7.46676900881151e+41*cos(theta)**61 - 8.11894669407313e+41*cos(theta)**59 + 7.66640054832181e+41*cos(theta)**57 - 6.31676575896831e+41*cos(theta)**55 + 4.55801610887655e+41*cos(theta)**53 - 2.88779135541696e+41*cos(theta)**51 + 1.60923687856496e+41*cos(theta)**49 - 7.89512961698952e+40*cos(theta)**47 + 3.41112514626925e+40*cos(theta)**45 - 1.29735455044432e+40*cos(theta)**43 + 4.33893021870822e+39*cos(theta)**41 - 1.27387138537083e+39*cos(theta)**39 + 3.27529041138025e+38*cos(theta)**37 - 7.35201689915486e+37*cos(theta)**35 + 1.4351870259177e+37*cos(theta)**33 - 2.42489199899054e+36*cos(theta)**31 + 3.52587485781927e+35*cos(theta)**29 - 4.3817116384286e+34*cos(theta)**27 + 4.61578867073361e+33*cos(theta)**25 - 4.08115709171849e+32*cos(theta)**23 + 2.99284853392689e+31*cos(theta)**21 - 1.79417125927675e+30*cos(theta)**19 + 8.6374798799641e+28*cos(theta)**17 - 3.26576942917742e+27*cos(theta)**15 + 9.42566767629547e+25*cos(theta)**13 - 2.00054987415251e+24*cos(theta)**11 + 2.96737440880226e+22*cos(theta)**9 - 2.85858920837253e+20*cos(theta)**7 + 1.59570370483315e+18*cos(theta)**5 - 4.21809068155737e+15*cos(theta)**3 + 3330071590703.18*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl87_m7(theta, phi):
    return 1.35395754117171e-13*(1.0 - cos(theta)**2)**3.5*(2.75260539345268e+38*cos(theta)**80 - 5.02788037185577e+39*cos(theta)**78 + 4.41483180019967e+40*cos(theta)**76 - 2.48171018354419e+41*cos(theta)**74 + 1.00345796493306e+42*cos(theta)**72 - 3.10889522226535e+42*cos(theta)**70 + 7.6768731715448e+42*cos(theta)**68 - 1.55172290015786e+43*cos(theta)**66 + 2.61670253210582e+43*cos(theta)**64 - 3.73338450440576e+43*cos(theta)**62 + 4.55472909537502e+43*cos(theta)**60 - 4.79017854950314e+43*cos(theta)**58 + 4.36984831254343e+43*cos(theta)**56 - 3.47422116743257e+43*cos(theta)**54 + 2.41574853770457e+43*cos(theta)**52 - 1.47277359126265e+43*cos(theta)**50 + 7.88526070496829e+42*cos(theta)**48 - 3.71071091998508e+42*cos(theta)**46 + 1.53500631582116e+42*cos(theta)**44 - 5.57862456691057e+41*cos(theta)**42 + 1.77896138967037e+41*cos(theta)**40 - 4.96809840294626e+40*cos(theta)**38 + 1.21185745221069e+40*cos(theta)**36 - 2.5732059147042e+39*cos(theta)**34 + 4.7361171855284e+38*cos(theta)**32 - 7.51716519687068e+37*cos(theta)**30 + 1.02250370876759e+37*cos(theta)**28 - 1.18306214237572e+36*cos(theta)**26 + 1.1539471676834e+35*cos(theta)**24 - 9.38666131095252e+33*cos(theta)**22 + 6.28498192124647e+32*cos(theta)**20 - 3.40892539262583e+31*cos(theta)**18 + 1.4683715795939e+30*cos(theta)**16 - 4.89865414376613e+28*cos(theta)**14 + 1.22533679791841e+27*cos(theta)**12 - 2.20060486156776e+25*cos(theta)**10 + 2.67063696792204e+23*cos(theta)**8 - 2.00101244586077e+21*cos(theta)**6 + 7.97851852416576e+18*cos(theta)**4 - 1.26542720446721e+16*cos(theta)**2 + 3330071590703.18)*cos(7*phi)

#@torch.jit.script
def Yl87_m8(theta, phi):
    return 1.55309581468744e-15*(1.0 - cos(theta)**2)**4*(2.20208431476215e+40*cos(theta)**79 - 3.9217466900475e+41*cos(theta)**77 + 3.35527216815175e+42*cos(theta)**75 - 1.8364655358227e+43*cos(theta)**73 + 7.22489734751806e+43*cos(theta)**71 - 2.17622665558574e+44*cos(theta)**69 + 5.22027375665046e+44*cos(theta)**67 - 1.02413711410419e+45*cos(theta)**65 + 1.67468962054773e+45*cos(theta)**63 - 2.31469839273157e+45*cos(theta)**61 + 2.73283745722501e+45*cos(theta)**59 - 2.77830355871182e+45*cos(theta)**57 + 2.44711505502432e+45*cos(theta)**55 - 1.87607943041359e+45*cos(theta)**53 + 1.25618923960638e+45*cos(theta)**51 - 7.36386795631324e+44*cos(theta)**49 + 3.78492513838478e+44*cos(theta)**47 - 1.70692702319314e+44*cos(theta)**45 + 6.75402778961312e+43*cos(theta)**43 - 2.34302231810244e+43*cos(theta)**41 + 7.11584555868148e+42*cos(theta)**39 - 1.88787739311958e+42*cos(theta)**37 + 4.3626868279585e+41*cos(theta)**35 - 8.74890010999429e+40*cos(theta)**33 + 1.51555749936909e+40*cos(theta)**31 - 2.2551495590612e+39*cos(theta)**29 + 2.86301038454925e+38*cos(theta)**27 - 3.07596157017688e+37*cos(theta)**25 + 2.76947320244016e+36*cos(theta)**23 - 2.06506548840955e+35*cos(theta)**21 + 1.25699638424929e+34*cos(theta)**19 - 6.1360657067265e+32*cos(theta)**17 + 2.34939452735024e+31*cos(theta)**15 - 6.85811580127258e+29*cos(theta)**13 + 1.47040415750209e+28*cos(theta)**11 - 2.20060486156776e+26*cos(theta)**9 + 2.13650957433763e+24*cos(theta)**7 - 1.20060746751646e+22*cos(theta)**5 + 3.1914074096663e+19*cos(theta)**3 - 2.53085440893442e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl87_m9(theta, phi):
    return 1.78340133412671e-17*(1.0 - cos(theta)**2)**4.5*(1.7396466086621e+42*cos(theta)**78 - 3.01974495133657e+43*cos(theta)**76 + 2.51645412611381e+44*cos(theta)**74 - 1.34061984115057e+45*cos(theta)**72 + 5.12967711673782e+45*cos(theta)**70 - 1.50159639235416e+46*cos(theta)**68 + 3.49758341695581e+46*cos(theta)**66 - 6.65689124167721e+46*cos(theta)**64 + 1.05505446094507e+47*cos(theta)**62 - 1.41196601956626e+47*cos(theta)**60 + 1.61237409976276e+47*cos(theta)**58 - 1.58363302846574e+47*cos(theta)**56 + 1.34591328026338e+47*cos(theta)**54 - 9.94322098119201e+46*cos(theta)**52 + 6.40656512199252e+46*cos(theta)**50 - 3.60829529859349e+46*cos(theta)**48 + 1.77891481504085e+46*cos(theta)**46 - 7.68117160436911e+45*cos(theta)**44 + 2.90423194953364e+45*cos(theta)**42 - 9.60639150422e+44*cos(theta)**40 + 2.77517976788578e+44*cos(theta)**38 - 6.98514635454244e+43*cos(theta)**36 + 1.52694038978547e+43*cos(theta)**34 - 2.88713703629812e+42*cos(theta)**32 + 4.69822824804418e+41*cos(theta)**30 - 6.53993372127749e+40*cos(theta)**28 + 7.73012803828297e+39*cos(theta)**26 - 7.68990392544219e+38*cos(theta)**24 + 6.36978836561238e+37*cos(theta)**22 - 4.33663752566006e+36*cos(theta)**20 + 2.38829313007366e+35*cos(theta)**18 - 1.0431311701435e+34*cos(theta)**16 + 3.52409179102535e+32*cos(theta)**14 - 8.91555054165436e+30*cos(theta)**12 + 1.6174445732523e+29*cos(theta)**10 - 1.98054437541098e+27*cos(theta)**8 + 1.49555670203634e+25*cos(theta)**6 - 6.00303733758231e+22*cos(theta)**4 + 9.57422222899891e+19*cos(theta)**2 - 2.53085440893442e+16)*cos(9*phi)

#@torch.jit.script
def Yl87_m10(theta, phi):
    return 2.05029295166213e-19*(1.0 - cos(theta)**2)**5*(1.35692435475644e+44*cos(theta)**77 - 2.2950061630158e+45*cos(theta)**75 + 1.86217605332422e+46*cos(theta)**73 - 9.65246285628413e+46*cos(theta)**71 + 3.59077398171648e+47*cos(theta)**69 - 1.02108554680083e+48*cos(theta)**67 + 2.30840505519084e+48*cos(theta)**65 - 4.26041039467341e+48*cos(theta)**63 + 6.54133765785942e+48*cos(theta)**61 - 8.47179611739755e+48*cos(theta)**59 + 9.351769778624e+48*cos(theta)**57 - 8.86834495940814e+48*cos(theta)**55 + 7.26793171342224e+48*cos(theta)**53 - 5.17047491021985e+48*cos(theta)**51 + 3.20328256099626e+48*cos(theta)**49 - 1.73198174332487e+48*cos(theta)**47 + 8.18300814918789e+47*cos(theta)**45 - 3.37971550592241e+47*cos(theta)**43 + 1.21977741880413e+47*cos(theta)**41 - 3.842556601688e+46*cos(theta)**39 + 1.0545683117966e+46*cos(theta)**37 - 2.51465268763528e+45*cos(theta)**35 + 5.19159732527061e+44*cos(theta)**33 - 9.23883851615397e+43*cos(theta)**31 + 1.40946847441325e+43*cos(theta)**29 - 1.8311814419577e+42*cos(theta)**27 + 2.00983328995357e+41*cos(theta)**25 - 1.84557694210613e+40*cos(theta)**23 + 1.40135344043472e+39*cos(theta)**21 - 8.67327505132013e+37*cos(theta)**19 + 4.29892763413259e+36*cos(theta)**17 - 1.66900987222961e+35*cos(theta)**15 + 4.9337285074355e+33*cos(theta)**13 - 1.06986606499852e+32*cos(theta)**11 + 1.6174445732523e+30*cos(theta)**9 - 1.58443550032879e+28*cos(theta)**7 + 8.97334021221804e+25*cos(theta)**5 - 2.40121493503293e+23*cos(theta)**3 + 1.91484444579978e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl87_m11(theta, phi):
    return 2.36024734775532e-21*(1.0 - cos(theta)**2)**5.5*(1.04483175316245e+46*cos(theta)**76 - 1.72125462226185e+47*cos(theta)**74 + 1.35938851892668e+48*cos(theta)**72 - 6.85324862796173e+48*cos(theta)**70 + 2.47763404738437e+49*cos(theta)**68 - 6.84127316356557e+49*cos(theta)**66 + 1.50046328587404e+50*cos(theta)**64 - 2.68405854864425e+50*cos(theta)**62 + 3.99021597129424e+50*cos(theta)**60 - 4.99835970926455e+50*cos(theta)**58 + 5.33050877381568e+50*cos(theta)**56 - 4.87758972767448e+50*cos(theta)**54 + 3.85200380811378e+50*cos(theta)**52 - 2.63694220421212e+50*cos(theta)**50 + 1.56960845488817e+50*cos(theta)**48 - 8.14031419362691e+49*cos(theta)**46 + 3.68235366713455e+49*cos(theta)**44 - 1.45327766754664e+49*cos(theta)**42 + 5.00108741709693e+48*cos(theta)**40 - 1.49859707465832e+48*cos(theta)**38 + 3.90190275364741e+47*cos(theta)**36 - 8.80128440672347e+46*cos(theta)**34 + 1.7132271173393e+46*cos(theta)**32 - 2.86403994000773e+45*cos(theta)**30 + 4.08745857579843e+44*cos(theta)**28 - 4.94418989328579e+43*cos(theta)**26 + 5.02458322488393e+42*cos(theta)**24 - 4.24482696684409e+41*cos(theta)**22 + 2.94284222491292e+40*cos(theta)**20 - 1.64792225975082e+39*cos(theta)**18 + 7.3081769780254e+37*cos(theta)**16 - 2.50351480834441e+36*cos(theta)**14 + 6.41384705966614e+34*cos(theta)**12 - 1.17685267149838e+33*cos(theta)**10 + 1.45570011592707e+31*cos(theta)**8 - 1.10910485023015e+29*cos(theta)**6 + 4.48667010610902e+26*cos(theta)**4 - 7.20364480509878e+23*cos(theta)**2 + 1.91484444579978e+20)*cos(11*phi)

#@torch.jit.script
def Yl87_m12(theta, phi):
    return 2.72102871457316e-23*(1.0 - cos(theta)**2)**6*(7.94072132403466e+47*cos(theta)**75 - 1.27372842047377e+49*cos(theta)**73 + 9.78759733627211e+49*cos(theta)**71 - 4.79727403957321e+50*cos(theta)**69 + 1.68479115222137e+51*cos(theta)**67 - 4.51524028795327e+51*cos(theta)**65 + 9.60296502959387e+51*cos(theta)**63 - 1.66411630015944e+52*cos(theta)**61 + 2.39412958277655e+52*cos(theta)**59 - 2.89904863137344e+52*cos(theta)**57 + 2.98508491333678e+52*cos(theta)**55 - 2.63389845294422e+52*cos(theta)**53 + 2.00304198021917e+52*cos(theta)**51 - 1.31847110210606e+52*cos(theta)**49 + 7.5341205834632e+51*cos(theta)**47 - 3.74454452906838e+51*cos(theta)**45 + 1.6202356135392e+51*cos(theta)**43 - 6.10376620369587e+50*cos(theta)**41 + 2.00043496683877e+50*cos(theta)**39 - 5.69466888370162e+49*cos(theta)**37 + 1.40468499131307e+49*cos(theta)**35 - 2.99243669828598e+48*cos(theta)**33 + 5.48232677548576e+47*cos(theta)**31 - 8.59211982002319e+46*cos(theta)**29 + 1.14448840122356e+46*cos(theta)**27 - 1.2854893722543e+45*cos(theta)**25 + 1.20589997397214e+44*cos(theta)**23 - 9.338619327057e+42*cos(theta)**21 + 5.88568444982584e+41*cos(theta)**19 - 2.96626006755148e+40*cos(theta)**17 + 1.16930831648406e+39*cos(theta)**15 - 3.50492073168218e+37*cos(theta)**13 + 7.69661647159937e+35*cos(theta)**11 - 1.17685267149838e+34*cos(theta)**9 + 1.16456009274166e+32*cos(theta)**7 - 6.6546291013809e+29*cos(theta)**5 + 1.79466804244361e+27*cos(theta)**3 - 1.44072896101976e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl87_m13(theta, phi):
    return 3.14197332166303e-25*(1.0 - cos(theta)**2)**6.5*(5.95554099302599e+49*cos(theta)**74 - 9.2982174694585e+50*cos(theta)**72 + 6.9491941087532e+51*cos(theta)**70 - 3.31011908730552e+52*cos(theta)**68 + 1.12881007198832e+53*cos(theta)**66 - 2.93490618716963e+53*cos(theta)**64 + 6.04986796864414e+53*cos(theta)**62 - 1.01511094309726e+54*cos(theta)**60 + 1.41253645383816e+54*cos(theta)**58 - 1.65245771988286e+54*cos(theta)**56 + 1.64179670233523e+54*cos(theta)**54 - 1.39596618006044e+54*cos(theta)**52 + 1.02155140991178e+54*cos(theta)**50 - 6.4605084003197e+53*cos(theta)**48 + 3.54103667422771e+53*cos(theta)**46 - 1.68504503808077e+53*cos(theta)**44 + 6.96701313821857e+52*cos(theta)**42 - 2.50254414351531e+52*cos(theta)**40 + 7.80169637067122e+51*cos(theta)**38 - 2.1070274869696e+51*cos(theta)**36 + 4.91639746959573e+50*cos(theta)**34 - 9.87504110434373e+49*cos(theta)**32 + 1.69952130040059e+49*cos(theta)**30 - 2.49171474780673e+48*cos(theta)**28 + 3.09011868330362e+47*cos(theta)**26 - 3.21372343063576e+46*cos(theta)**24 + 2.77356994013593e+45*cos(theta)**22 - 1.96111005868197e+44*cos(theta)**20 + 1.11828004546691e+43*cos(theta)**18 - 5.04264211483752e+41*cos(theta)**16 + 1.75396247472609e+40*cos(theta)**14 - 4.55639695118683e+38*cos(theta)**12 + 8.46627811875931e+36*cos(theta)**10 - 1.05916740434854e+35*cos(theta)**8 + 8.1519206491916e+32*cos(theta)**6 - 3.32731455069045e+30*cos(theta)**4 + 5.38400412733083e+27*cos(theta)**2 - 1.44072896101976e+24)*cos(13*phi)

#@torch.jit.script
def Yl87_m14(theta, phi):
    return 3.63434328353075e-27*(1.0 - cos(theta)**2)**7*(4.40710033483924e+51*cos(theta)**73 - 6.69471657801012e+52*cos(theta)**71 + 4.86443587612724e+53*cos(theta)**69 - 2.25088097936775e+54*cos(theta)**67 + 7.4501464751229e+54*cos(theta)**65 - 1.87833995978856e+55*cos(theta)**63 + 3.75091814055937e+55*cos(theta)**61 - 6.09066565858353e+55*cos(theta)**59 + 8.19271143226134e+55*cos(theta)**57 - 9.25376323134402e+55*cos(theta)**55 + 8.86570219261024e+55*cos(theta)**53 - 7.25902413631427e+55*cos(theta)**51 + 5.10775704955888e+55*cos(theta)**49 - 3.10104403215345e+55*cos(theta)**47 + 1.62887687014474e+55*cos(theta)**45 - 7.41419816755539e+54*cos(theta)**43 + 2.9261455180518e+54*cos(theta)**41 - 1.00101765740612e+54*cos(theta)**39 + 2.96464462085506e+53*cos(theta)**37 - 7.58529895309056e+52*cos(theta)**35 + 1.67157513966255e+52*cos(theta)**33 - 3.16001315338999e+51*cos(theta)**31 + 5.09856390120176e+50*cos(theta)**29 - 6.97680129385883e+49*cos(theta)**27 + 8.0343085765894e+48*cos(theta)**25 - 7.71293623352583e+47*cos(theta)**23 + 6.10185386829904e+46*cos(theta)**21 - 3.92222011736394e+45*cos(theta)**19 + 2.01290408184044e+44*cos(theta)**17 - 8.06822738374004e+42*cos(theta)**15 + 2.45554746461653e+41*cos(theta)**13 - 5.4676763414242e+39*cos(theta)**11 + 8.46627811875931e+37*cos(theta)**9 - 8.4733392347883e+35*cos(theta)**7 + 4.89115238951496e+33*cos(theta)**5 - 1.33092582027618e+31*cos(theta)**3 + 1.07680082546617e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl87_m15(theta, phi):
    return 4.21176790154604e-29*(1.0 - cos(theta)**2)**7.5*(3.21718324443264e+53*cos(theta)**72 - 4.75324877038719e+54*cos(theta)**70 + 3.35646075452779e+55*cos(theta)**68 - 1.50809025617639e+56*cos(theta)**66 + 4.84259520882989e+56*cos(theta)**64 - 1.18335417466679e+57*cos(theta)**62 + 2.28806006574121e+57*cos(theta)**60 - 3.59349273856428e+57*cos(theta)**58 + 4.66984551638896e+57*cos(theta)**56 - 5.08956977723921e+57*cos(theta)**54 + 4.69882216208343e+57*cos(theta)**52 - 3.70210230952028e+57*cos(theta)**50 + 2.50280095428385e+57*cos(theta)**48 - 1.45749069511212e+57*cos(theta)**46 + 7.32994591565135e+56*cos(theta)**44 - 3.18810521204882e+56*cos(theta)**42 + 1.19971966240124e+56*cos(theta)**40 - 3.90396886388388e+55*cos(theta)**38 + 1.09691850971637e+55*cos(theta)**36 - 2.65485463358169e+54*cos(theta)**34 + 5.51619796088641e+53*cos(theta)**32 - 9.79604077550898e+52*cos(theta)**30 + 1.47858353134851e+52*cos(theta)**28 - 1.88373634934188e+51*cos(theta)**26 + 2.00857714414735e+50*cos(theta)**24 - 1.77397533371094e+49*cos(theta)**22 + 1.2813893123428e+48*cos(theta)**20 - 7.45221822299148e+46*cos(theta)**18 + 3.42193693912874e+45*cos(theta)**16 - 1.21023410756101e+44*cos(theta)**14 + 3.19221170400149e+42*cos(theta)**12 - 6.01444397556661e+40*cos(theta)**10 + 7.61965030688338e+38*cos(theta)**8 - 5.93133746435181e+36*cos(theta)**6 + 2.44557619475748e+34*cos(theta)**4 - 3.99277746082854e+31*cos(theta)**2 + 1.07680082546617e+28)*cos(15*phi)

#@torch.jit.script
def Yl87_m16(theta, phi):
    return 4.89079624256809e-31*(1.0 - cos(theta)**2)**8*(2.3163719359915e+55*cos(theta)**71 - 3.32727413927103e+56*cos(theta)**69 + 2.2823933130789e+57*cos(theta)**67 - 9.9533956907642e+57*cos(theta)**65 + 3.09926093365113e+58*cos(theta)**63 - 7.33679588293412e+58*cos(theta)**61 + 1.37283603944473e+59*cos(theta)**59 - 2.08422578836728e+59*cos(theta)**57 + 2.61511348917782e+59*cos(theta)**55 - 2.74836767970917e+59*cos(theta)**53 + 2.44338752428338e+59*cos(theta)**51 - 1.85105115476014e+59*cos(theta)**49 + 1.20134445805625e+59*cos(theta)**47 - 6.70445719751577e+58*cos(theta)**45 + 3.22517620288659e+58*cos(theta)**43 - 1.3390041890605e+58*cos(theta)**41 + 4.79887864960495e+57*cos(theta)**39 - 1.48350816827587e+57*cos(theta)**37 + 3.94890663497894e+56*cos(theta)**35 - 9.02650575417776e+55*cos(theta)**33 + 1.76518334748365e+55*cos(theta)**31 - 2.9388122326527e+54*cos(theta)**29 + 4.14003388777583e+53*cos(theta)**27 - 4.8977145082889e+52*cos(theta)**25 + 4.82058514595364e+51*cos(theta)**23 - 3.90274573416407e+50*cos(theta)**21 + 2.5627786246856e+49*cos(theta)**19 - 1.34139928013847e+48*cos(theta)**17 + 5.47509910260599e+46*cos(theta)**15 - 1.69432775058541e+45*cos(theta)**13 + 3.83065404480179e+43*cos(theta)**11 - 6.01444397556661e+41*cos(theta)**9 + 6.0957202455067e+39*cos(theta)**7 - 3.55880247861109e+37*cos(theta)**5 + 9.78230477902992e+34*cos(theta)**3 - 7.98555492165708e+31*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl87_m17(theta, phi):
    return 5.69159154928737e-33*(1.0 - cos(theta)**2)**8.5*(1.64462407455397e+57*cos(theta)**70 - 2.29581915609701e+58*cos(theta)**68 + 1.52920351976286e+59*cos(theta)**66 - 6.46970719899673e+59*cos(theta)**64 + 1.95253438820021e+60*cos(theta)**62 - 4.47544548858981e+60*cos(theta)**60 + 8.0997326327239e+60*cos(theta)**58 - 1.18800869936935e+61*cos(theta)**56 + 1.4383124190478e+61*cos(theta)**54 - 1.45663487024586e+61*cos(theta)**52 + 1.24612763738452e+61*cos(theta)**50 - 9.07015065832467e+60*cos(theta)**48 + 5.64631895286437e+60*cos(theta)**46 - 3.0170057388821e+60*cos(theta)**44 + 1.38682576724124e+60*cos(theta)**42 - 5.48991717514806e+59*cos(theta)**40 + 1.87156267334593e+59*cos(theta)**38 - 5.48898022262073e+58*cos(theta)**36 + 1.38211732224263e+58*cos(theta)**34 - 2.97874689887866e+57*cos(theta)**32 + 5.47206837719932e+56*cos(theta)**30 - 8.52255547469282e+55*cos(theta)**28 + 1.11780914969947e+55*cos(theta)**26 - 1.22442862707222e+54*cos(theta)**24 + 1.10873458356934e+53*cos(theta)**22 - 8.19576604174454e+51*cos(theta)**20 + 4.86927938690264e+50*cos(theta)**18 - 2.28037877623539e+49*cos(theta)**16 + 8.21264865390898e+47*cos(theta)**14 - 2.20262607576103e+46*cos(theta)**12 + 4.21371944928197e+44*cos(theta)**10 - 5.41299957800995e+42*cos(theta)**8 + 4.26700417185469e+40*cos(theta)**6 - 1.77940123930554e+38*cos(theta)**4 + 2.93469143370898e+35*cos(theta)**2 - 7.98555492165708e+31)*cos(17*phi)

#@torch.jit.script
def Yl87_m18(theta, phi):
    return 6.63880720004326e-35*(1.0 - cos(theta)**2)**9*(1.15123685218778e+59*cos(theta)**69 - 1.56115702614597e+60*cos(theta)**67 + 1.00927432304349e+61*cos(theta)**65 - 4.14061260735791e+61*cos(theta)**63 + 1.21057132068413e+62*cos(theta)**61 - 2.68526729315389e+62*cos(theta)**59 + 4.69784492697986e+62*cos(theta)**57 - 6.65284871646837e+62*cos(theta)**55 + 7.76688706285813e+62*cos(theta)**53 - 7.57450132527848e+62*cos(theta)**51 + 6.23063818692262e+62*cos(theta)**49 - 4.35367231599584e+62*cos(theta)**47 + 2.59730671831761e+62*cos(theta)**45 - 1.32748252510812e+62*cos(theta)**43 + 5.82466822241319e+61*cos(theta)**41 - 2.19596687005923e+61*cos(theta)**39 + 7.11193815871454e+60*cos(theta)**37 - 1.97603288014346e+60*cos(theta)**35 + 4.69919889562494e+59*cos(theta)**33 - 9.53199007641172e+58*cos(theta)**31 + 1.6416205131598e+58*cos(theta)**29 - 2.38631553291399e+57*cos(theta)**27 + 2.90630378921863e+56*cos(theta)**25 - 2.93862870497334e+55*cos(theta)**23 + 2.43921608385254e+54*cos(theta)**21 - 1.63915320834891e+53*cos(theta)**19 + 8.76470289642474e+51*cos(theta)**17 - 3.64860604197663e+50*cos(theta)**15 + 1.14977081154726e+49*cos(theta)**13 - 2.64315129091324e+47*cos(theta)**11 + 4.21371944928197e+45*cos(theta)**9 - 4.33039966240796e+43*cos(theta)**7 + 2.56020250311282e+41*cos(theta)**5 - 7.11760495722217e+38*cos(theta)**3 + 5.86938286741796e+35*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl87_m19(theta, phi):
    return 7.76269599145231e-37*(1.0 - cos(theta)**2)**9.5*(7.94353428009566e+60*cos(theta)**68 - 1.0459752075178e+62*cos(theta)**66 + 6.56028309978268e+62*cos(theta)**64 - 2.60858594263548e+63*cos(theta)**62 + 7.38448505617319e+63*cos(theta)**60 - 1.58430770296079e+64*cos(theta)**58 + 2.67777160837852e+64*cos(theta)**56 - 3.65906679405761e+64*cos(theta)**54 + 4.11645014331481e+64*cos(theta)**52 - 3.86299567589203e+64*cos(theta)**50 + 3.05301271159209e+64*cos(theta)**48 - 2.04622598851805e+64*cos(theta)**46 + 1.16878802324292e+64*cos(theta)**44 - 5.70817485796493e+63*cos(theta)**42 + 2.38811397118941e+63*cos(theta)**40 - 8.56427079323098e+62*cos(theta)**38 + 2.63141711872438e+62*cos(theta)**36 - 6.91611508050212e+61*cos(theta)**34 + 1.55073563555623e+61*cos(theta)**32 - 2.95491692368763e+60*cos(theta)**30 + 4.76069948816341e+59*cos(theta)**28 - 6.44305193886777e+58*cos(theta)**26 + 7.26575947304658e+57*cos(theta)**24 - 6.75884602143868e+56*cos(theta)**22 + 5.12235377609034e+55*cos(theta)**20 - 3.11439109586293e+54*cos(theta)**18 + 1.48999949239221e+53*cos(theta)**16 - 5.47290906296495e+51*cos(theta)**14 + 1.49470205501143e+50*cos(theta)**12 - 2.90746642000456e+48*cos(theta)**10 + 3.79234750435377e+46*cos(theta)**8 - 3.03127976368557e+44*cos(theta)**6 + 1.28010125155641e+42*cos(theta)**4 - 2.13528148716665e+39*cos(theta)**2 + 5.86938286741796e+35)*cos(19*phi)

#@torch.jit.script
def Yl87_m20(theta, phi):
    return 9.10052051744521e-39*(1.0 - cos(theta)**2)**10*(5.40160331046505e+62*cos(theta)**67 - 6.90343636961747e+63*cos(theta)**65 + 4.19858118386092e+64*cos(theta)**63 - 1.617323284434e+65*cos(theta)**61 + 4.43069103370392e+65*cos(theta)**59 - 9.18898467717261e+65*cos(theta)**57 + 1.49955210069197e+66*cos(theta)**55 - 1.97589606879111e+66*cos(theta)**53 + 2.1405540745237e+66*cos(theta)**51 - 1.93149783794601e+66*cos(theta)**49 + 1.4654461015642e+66*cos(theta)**47 - 9.41263954718301e+65*cos(theta)**45 + 5.14266730226887e+65*cos(theta)**43 - 2.39743344034527e+65*cos(theta)**41 + 9.55245588475763e+64*cos(theta)**39 - 3.25442290142777e+64*cos(theta)**37 + 9.47310162740776e+63*cos(theta)**35 - 2.35147912737072e+63*cos(theta)**33 + 4.96235403377994e+62*cos(theta)**31 - 8.8647507710629e+61*cos(theta)**29 + 1.33299585668575e+61*cos(theta)**27 - 1.67519350410562e+60*cos(theta)**25 + 1.74378227353118e+59*cos(theta)**23 - 1.48694612471651e+58*cos(theta)**21 + 1.02447075521807e+57*cos(theta)**19 - 5.60590397255327e+55*cos(theta)**17 + 2.38399918782753e+54*cos(theta)**15 - 7.66207268815093e+52*cos(theta)**13 + 1.79364246601372e+51*cos(theta)**11 - 2.90746642000456e+49*cos(theta)**9 + 3.03387800348302e+47*cos(theta)**7 - 1.81876785821134e+45*cos(theta)**5 + 5.12040500622563e+42*cos(theta)**3 - 4.2705629743333e+39*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl87_m21(theta, phi):
    return 1.0698353748352e-40*(1.0 - cos(theta)**2)**10.5*(3.61907421801158e+64*cos(theta)**66 - 4.48723364025135e+65*cos(theta)**64 + 2.64510614583238e+66*cos(theta)**62 - 9.86567203504739e+66*cos(theta)**60 + 2.61410770988531e+67*cos(theta)**58 - 5.23772126598839e+67*cos(theta)**56 + 8.24753655380584e+67*cos(theta)**54 - 1.04722491645929e+68*cos(theta)**52 + 1.09168257800709e+68*cos(theta)**50 - 9.46433940593546e+67*cos(theta)**48 + 6.88759667735174e+67*cos(theta)**46 - 4.23568779623236e+67*cos(theta)**44 + 2.21134693997561e+67*cos(theta)**42 - 9.8294771054156e+66*cos(theta)**40 + 3.72545779505548e+66*cos(theta)**38 - 1.20413647352828e+66*cos(theta)**36 + 3.31558556959272e+65*cos(theta)**34 - 7.75988112032338e+64*cos(theta)**32 + 1.53832975047178e+64*cos(theta)**30 - 2.57077772360824e+63*cos(theta)**28 + 3.59908881305154e+62*cos(theta)**26 - 4.18798376026405e+61*cos(theta)**24 + 4.01069922912171e+60*cos(theta)**22 - 3.12258686190467e+59*cos(theta)**20 + 1.94649443491433e+58*cos(theta)**18 - 9.53003675334055e+56*cos(theta)**16 + 3.5759987817413e+55*cos(theta)**14 - 9.9606944945962e+53*cos(theta)**12 + 1.97300671261509e+52*cos(theta)**10 - 2.6167197780041e+50*cos(theta)**8 + 2.12371460243811e+48*cos(theta)**6 - 9.09383929105672e+45*cos(theta)**4 + 1.53612150186769e+43*cos(theta)**2 - 4.2705629743333e+39)*cos(21*phi)

#@torch.jit.script
def Yl87_m22(theta, phi):
    return 1.26133874784716e-42*(1.0 - cos(theta)**2)**11*(2.38858898388764e+66*cos(theta)**65 - 2.87182952976087e+67*cos(theta)**63 + 1.63996581041607e+68*cos(theta)**61 - 5.91940322102843e+68*cos(theta)**59 + 1.51618247173348e+69*cos(theta)**57 - 2.9331239089535e+69*cos(theta)**55 + 4.45366973905516e+69*cos(theta)**53 - 5.44556956558829e+69*cos(theta)**51 + 5.45841289003543e+69*cos(theta)**49 - 4.54288291484902e+69*cos(theta)**47 + 3.1682944715818e+69*cos(theta)**45 - 1.86370263034224e+69*cos(theta)**43 + 9.28765714789757e+68*cos(theta)**41 - 3.93179084216624e+68*cos(theta)**39 + 1.41567396212108e+68*cos(theta)**37 - 4.33489130470179e+67*cos(theta)**35 + 1.12729909366152e+67*cos(theta)**33 - 2.48316195850348e+66*cos(theta)**31 + 4.61498925141534e+65*cos(theta)**29 - 7.19817762610307e+64*cos(theta)**27 + 9.35763091393399e+63*cos(theta)**25 - 1.00511610246337e+63*cos(theta)**23 + 8.82353830406777e+61*cos(theta)**21 - 6.24517372380934e+60*cos(theta)**19 + 3.50368998284579e+59*cos(theta)**17 - 1.52480588053449e+58*cos(theta)**15 + 5.00639829443781e+56*cos(theta)**13 - 1.19528333935154e+55*cos(theta)**11 + 1.97300671261509e+53*cos(theta)**9 - 2.09337582240328e+51*cos(theta)**7 + 1.27422876146287e+49*cos(theta)**5 - 3.63753571642269e+46*cos(theta)**3 + 3.07224300373538e+43*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl87_m23(theta, phi):
    return 1.49169047428675e-44*(1.0 - cos(theta)**2)**11.5*(1.55258283952697e+68*cos(theta)**64 - 1.80925260374935e+69*cos(theta)**62 + 1.00037914435381e+70*cos(theta)**60 - 3.49244790040678e+70*cos(theta)**58 + 8.64224008888084e+70*cos(theta)**56 - 1.61321814992442e+71*cos(theta)**54 + 2.36044496169923e+71*cos(theta)**52 - 2.77724047845003e+71*cos(theta)**50 + 2.67462231611736e+71*cos(theta)**48 - 2.13515496997904e+71*cos(theta)**46 + 1.42573251221181e+71*cos(theta)**44 - 8.01392131047162e+70*cos(theta)**42 + 3.807939430638e+70*cos(theta)**40 - 1.53339842844483e+70*cos(theta)**38 + 5.237993659848e+69*cos(theta)**36 - 1.51721195664563e+69*cos(theta)**34 + 3.72008700908303e+68*cos(theta)**32 - 7.69780207136079e+67*cos(theta)**30 + 1.33834688291045e+67*cos(theta)**28 - 1.94350795904783e+66*cos(theta)**26 + 2.3394077284835e+65*cos(theta)**24 - 2.31176703566576e+64*cos(theta)**22 + 1.85294304385423e+63*cos(theta)**20 - 1.18658300752377e+62*cos(theta)**18 + 5.95627297083785e+60*cos(theta)**16 - 2.28720882080173e+59*cos(theta)**14 + 6.50831778276916e+57*cos(theta)**12 - 1.3148116732867e+56*cos(theta)**10 + 1.77570604135358e+54*cos(theta)**8 - 1.4653630756823e+52*cos(theta)**6 + 6.37114380731434e+49*cos(theta)**4 - 1.09126071492681e+47*cos(theta)**2 + 3.07224300373538e+43)*cos(23*phi)

#@torch.jit.script
def Yl87_m24(theta, phi):
    return 1.76981242607138e-46*(1.0 - cos(theta)**2)**12*(9.9365301729726e+69*cos(theta)**63 - 1.12173661432459e+71*cos(theta)**61 + 6.00227486612283e+71*cos(theta)**59 - 2.02561978223593e+72*cos(theta)**57 + 4.83965444977327e+72*cos(theta)**55 - 8.71137800959188e+72*cos(theta)**53 + 1.2274313800836e+73*cos(theta)**51 - 1.38862023922501e+73*cos(theta)**49 + 1.28381871173633e+73*cos(theta)**47 - 9.82171286190359e+72*cos(theta)**45 + 6.27322305373197e+72*cos(theta)**43 - 3.36584695039808e+72*cos(theta)**41 + 1.5231757722552e+72*cos(theta)**39 - 5.82691402809037e+71*cos(theta)**37 + 1.88567771754528e+71*cos(theta)**35 - 5.15852065259513e+70*cos(theta)**33 + 1.19042784290657e+70*cos(theta)**31 - 2.30934062140824e+69*cos(theta)**29 + 3.74737127214926e+68*cos(theta)**27 - 5.05312069352436e+67*cos(theta)**25 + 5.6145785483604e+66*cos(theta)**23 - 5.08588747846466e+65*cos(theta)**21 + 3.70588608770846e+64*cos(theta)**19 - 2.13584941354279e+63*cos(theta)**17 + 9.53003675334055e+61*cos(theta)**15 - 3.20209234912243e+60*cos(theta)**13 + 7.80998133932299e+58*cos(theta)**11 - 1.3148116732867e+57*cos(theta)**9 + 1.42056483308287e+55*cos(theta)**7 - 8.79217845409379e+52*cos(theta)**5 + 2.54845752292574e+50*cos(theta)**3 - 2.18252142985361e+47*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl87_m25(theta, phi):
    return 2.10691955484688e-48*(1.0 - cos(theta)**2)**12.5*(6.26001400897274e+71*cos(theta)**62 - 6.84259334738003e+72*cos(theta)**60 + 3.54134217101247e+73*cos(theta)**58 - 1.15460327587448e+74*cos(theta)**56 + 2.6618099473753e+74*cos(theta)**54 - 4.6170303450837e+74*cos(theta)**52 + 6.25990003842636e+74*cos(theta)**50 - 6.80423917220257e+74*cos(theta)**48 + 6.03394794516077e+74*cos(theta)**46 - 4.41977078785661e+74*cos(theta)**44 + 2.69748591310475e+74*cos(theta)**42 - 1.37999724966321e+74*cos(theta)**40 + 5.94038551179529e+73*cos(theta)**38 - 2.15595819039344e+73*cos(theta)**36 + 6.59987201140848e+72*cos(theta)**34 - 1.70231181535639e+72*cos(theta)**32 + 3.69032631301036e+71*cos(theta)**30 - 6.69708780208389e+70*cos(theta)**28 + 1.0117902434803e+70*cos(theta)**26 - 1.26328017338109e+69*cos(theta)**24 + 1.29135306612289e+68*cos(theta)**22 - 1.06803637047758e+67*cos(theta)**20 + 7.04118356664608e+65*cos(theta)**18 - 3.63094400302275e+64*cos(theta)**16 + 1.42950551300108e+63*cos(theta)**14 - 4.16272005385915e+61*cos(theta)**12 + 8.59097947325529e+59*cos(theta)**10 - 1.18333050595803e+58*cos(theta)**8 + 9.94395383158007e+55*cos(theta)**6 - 4.39608922704689e+53*cos(theta)**4 + 7.64537256877721e+50*cos(theta)**2 - 2.18252142985361e+47)*cos(25*phi)

#@torch.jit.script
def Yl87_m26(theta, phi):
    return 2.51717197260066e-50*(1.0 - cos(theta)**2)**13*(3.8812086855631e+73*cos(theta)**61 - 4.10555600842802e+74*cos(theta)**59 + 2.05397845918723e+75*cos(theta)**57 - 6.46577834489709e+75*cos(theta)**55 + 1.43737737158266e+76*cos(theta)**53 - 2.40085577944352e+76*cos(theta)**51 + 3.12995001921318e+76*cos(theta)**49 - 3.26603480265723e+76*cos(theta)**47 + 2.77561605477395e+76*cos(theta)**45 - 1.94469914665691e+76*cos(theta)**43 + 1.13294408350399e+76*cos(theta)**41 - 5.51998899865285e+75*cos(theta)**39 + 2.25734649448221e+75*cos(theta)**37 - 7.76144948541637e+74*cos(theta)**35 + 2.24395648387888e+74*cos(theta)**33 - 5.44739780914046e+73*cos(theta)**31 + 1.10709789390311e+73*cos(theta)**29 - 1.87518458458349e+72*cos(theta)**27 + 2.63065463304878e+71*cos(theta)**25 - 3.03187241611461e+70*cos(theta)**23 + 2.84097674547036e+69*cos(theta)**21 - 2.13607274095516e+68*cos(theta)**19 + 1.26741304199629e+67*cos(theta)**17 - 5.8095104048364e+65*cos(theta)**15 + 2.00130771820152e+64*cos(theta)**13 - 4.99526406463098e+62*cos(theta)**11 + 8.59097947325529e+60*cos(theta)**9 - 9.46664404766423e+58*cos(theta)**7 + 5.96637229894804e+56*cos(theta)**5 - 1.75843569081876e+54*cos(theta)**3 + 1.52907451375544e+51*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl87_m27(theta, phi):
    return 3.01853033216279e-52*(1.0 - cos(theta)**2)**13.5*(2.36753729819349e+75*cos(theta)**60 - 2.42227804497253e+76*cos(theta)**58 + 1.17076772173672e+77*cos(theta)**56 - 3.5561780896934e+77*cos(theta)**54 + 7.6181000693881e+77*cos(theta)**52 - 1.2244364475162e+78*cos(theta)**50 + 1.53367550941446e+78*cos(theta)**48 - 1.5350363572489e+78*cos(theta)**46 + 1.24902722464828e+78*cos(theta)**44 - 8.36220633062471e+77*cos(theta)**42 + 4.64507074236637e+77*cos(theta)**40 - 2.15279570947461e+77*cos(theta)**38 + 8.35218202958417e+76*cos(theta)**36 - 2.71650731989573e+76*cos(theta)**34 + 7.40505639680031e+75*cos(theta)**32 - 1.68869332083354e+75*cos(theta)**30 + 3.21058389231902e+74*cos(theta)**28 - 5.06299837837542e+73*cos(theta)**26 + 6.57663658262195e+72*cos(theta)**24 - 6.97330655706361e+71*cos(theta)**22 + 5.96605116548776e+70*cos(theta)**20 - 4.0585382078148e+69*cos(theta)**18 + 2.1546021713937e+68*cos(theta)**16 - 8.7142656072546e+66*cos(theta)**14 + 2.60170003366197e+65*cos(theta)**12 - 5.49479047109408e+63*cos(theta)**10 + 7.73188152592976e+61*cos(theta)**8 - 6.62665083336496e+59*cos(theta)**6 + 2.98318614947402e+57*cos(theta)**4 - 5.27530707245627e+54*cos(theta)**2 + 1.52907451375544e+51)*cos(27*phi)

#@torch.jit.script
def Yl87_m28(theta, phi):
    return 3.63388349102687e-54*(1.0 - cos(theta)**2)**14*(1.42052237891609e+77*cos(theta)**59 - 1.40492126608407e+78*cos(theta)**57 + 6.55629924172565e+78*cos(theta)**55 - 1.92033616843443e+79*cos(theta)**53 + 3.96141203608181e+79*cos(theta)**51 - 6.12218223758098e+79*cos(theta)**49 + 7.3616424451894e+79*cos(theta)**47 - 7.06116724334494e+79*cos(theta)**45 + 5.49571978845243e+79*cos(theta)**43 - 3.51212665886238e+79*cos(theta)**41 + 1.85802829694655e+79*cos(theta)**39 - 8.18062369600352e+78*cos(theta)**37 + 3.0067855306503e+78*cos(theta)**35 - 9.23612488764548e+77*cos(theta)**33 + 2.3696180469761e+77*cos(theta)**31 - 5.06607996250063e+76*cos(theta)**29 + 8.98963489849325e+75*cos(theta)**27 - 1.31637957837761e+75*cos(theta)**25 + 1.57839277982927e+74*cos(theta)**23 - 1.53412744255399e+73*cos(theta)**21 + 1.19321023309755e+72*cos(theta)**19 - 7.30536877406664e+70*cos(theta)**17 + 3.44736347422992e+69*cos(theta)**15 - 1.21999718501564e+68*cos(theta)**13 + 3.12204004039437e+66*cos(theta)**11 - 5.49479047109408e+64*cos(theta)**9 + 6.18550522074381e+62*cos(theta)**7 - 3.97599050001898e+60*cos(theta)**5 + 1.19327445978961e+58*cos(theta)**3 - 1.05506141449125e+55*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl87_m29(theta, phi):
    return 4.39254276583338e-56*(1.0 - cos(theta)**2)**14.5*(8.38108203560495e+78*cos(theta)**58 - 8.00805121667918e+79*cos(theta)**56 + 3.60596458294911e+80*cos(theta)**54 - 1.01777816927025e+81*cos(theta)**52 + 2.02032013840172e+81*cos(theta)**50 - 2.99986929641468e+81*cos(theta)**48 + 3.45997194923902e+81*cos(theta)**46 - 3.17752525950522e+81*cos(theta)**44 + 2.36315950903454e+81*cos(theta)**42 - 1.43997193013358e+81*cos(theta)**40 + 7.24631035809154e+80*cos(theta)**38 - 3.0268307675213e+80*cos(theta)**36 + 1.05237493572761e+80*cos(theta)**34 - 3.04792121292301e+79*cos(theta)**32 + 7.34581594562591e+78*cos(theta)**30 - 1.46916318912518e+78*cos(theta)**28 + 2.42720142259318e+77*cos(theta)**26 - 3.29094894594402e+76*cos(theta)**24 + 3.63030339360732e+75*cos(theta)**22 - 3.22166762936339e+74*cos(theta)**20 + 2.26709944288535e+73*cos(theta)**18 - 1.24191269159133e+72*cos(theta)**16 + 5.17104521134488e+70*cos(theta)**14 - 1.58599634052034e+69*cos(theta)**12 + 3.4342440444338e+67*cos(theta)**10 - 4.94531142398467e+65*cos(theta)**8 + 4.32985365452067e+63*cos(theta)**6 - 1.98799525000949e+61*cos(theta)**4 + 3.57982337936883e+58*cos(theta)**2 - 1.05506141449125e+55)*cos(29*phi)

#@torch.jit.script
def Yl87_m30(theta, phi):
    return 5.33223241699831e-58*(1.0 - cos(theta)**2)**15*(4.86102758065087e+80*cos(theta)**57 - 4.48450868134034e+81*cos(theta)**55 + 1.94722087479252e+82*cos(theta)**53 - 5.2924464802053e+82*cos(theta)**51 + 1.01016006920086e+83*cos(theta)**49 - 1.43993726227905e+83*cos(theta)**47 + 1.59158709664995e+83*cos(theta)**45 - 1.3981111141823e+83*cos(theta)**43 + 9.92526993794509e+82*cos(theta)**41 - 5.7598877205343e+82*cos(theta)**39 + 2.75359793607479e+82*cos(theta)**37 - 1.08965907630767e+82*cos(theta)**35 + 3.57807478147386e+81*cos(theta)**33 - 9.75334788135363e+80*cos(theta)**31 + 2.20374478368777e+80*cos(theta)**29 - 4.11365692955051e+79*cos(theta)**27 + 6.31072369874226e+78*cos(theta)**25 - 7.89827747026566e+77*cos(theta)**23 + 7.98666746593609e+76*cos(theta)**21 - 6.44333525872678e+75*cos(theta)**19 + 4.08077899719363e+74*cos(theta)**17 - 1.98706030654613e+73*cos(theta)**15 + 7.23946329588283e+71*cos(theta)**13 - 1.90319560862441e+70*cos(theta)**11 + 3.4342440444338e+68*cos(theta)**9 - 3.95624913918774e+66*cos(theta)**7 + 2.5979121927124e+64*cos(theta)**5 - 7.95198100003795e+61*cos(theta)**3 + 7.15964675873765e+58*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl87_m31(theta, phi):
    return 6.5017555840577e-60*(1.0 - cos(theta)**2)**15.5*(2.770785720971e+82*cos(theta)**56 - 2.46647977473719e+83*cos(theta)**54 + 1.03202706364003e+84*cos(theta)**52 - 2.6991477049047e+84*cos(theta)**50 + 4.94978433908423e+84*cos(theta)**48 - 6.76770513271152e+84*cos(theta)**46 + 7.16214193492477e+84*cos(theta)**44 - 6.01187779098388e+84*cos(theta)**42 + 4.06936067455749e+84*cos(theta)**40 - 2.24635621100838e+84*cos(theta)**38 + 1.01883123634767e+84*cos(theta)**36 - 3.81380676707684e+83*cos(theta)**34 + 1.18076467788637e+83*cos(theta)**32 - 3.02353784321962e+82*cos(theta)**30 + 6.39085987269454e+81*cos(theta)**28 - 1.11068737097864e+81*cos(theta)**26 + 1.57768092468556e+80*cos(theta)**24 - 1.8166038181611e+79*cos(theta)**22 + 1.67720016784658e+78*cos(theta)**20 - 1.22423369915809e+77*cos(theta)**18 + 6.93732429522916e+75*cos(theta)**16 - 2.98059045981919e+74*cos(theta)**14 + 9.41130228464768e+72*cos(theta)**12 - 2.09351516948685e+71*cos(theta)**10 + 3.09081963999042e+69*cos(theta)**8 - 2.76937439743142e+67*cos(theta)**6 + 1.2989560963562e+65*cos(theta)**4 - 2.38559430001139e+62*cos(theta)**2 + 7.15964675873765e+58)*cos(31*phi)

#@torch.jit.script
def Yl87_m32(theta, phi):
    return 7.96458488291644e-62*(1.0 - cos(theta)**2)**16*(1.55164000374376e+84*cos(theta)**55 - 1.33189907835808e+85*cos(theta)**53 + 5.36654073092818e+85*cos(theta)**51 - 1.34957385245235e+86*cos(theta)**49 + 2.37589648276043e+86*cos(theta)**47 - 3.1131443610473e+86*cos(theta)**45 + 3.1513424513669e+86*cos(theta)**43 - 2.52498867221323e+86*cos(theta)**41 + 1.62774426982299e+86*cos(theta)**39 - 8.53615360183184e+85*cos(theta)**37 + 3.66779245085162e+85*cos(theta)**35 - 1.29669430080613e+85*cos(theta)**33 + 3.7784469692364e+84*cos(theta)**31 - 9.07061352965887e+83*cos(theta)**29 + 1.78944076435447e+83*cos(theta)**27 - 2.88778716454446e+82*cos(theta)**25 + 3.78643421924536e+81*cos(theta)**23 - 3.99652839995442e+80*cos(theta)**21 + 3.35440033569316e+79*cos(theta)**19 - 2.20362065848456e+78*cos(theta)**17 + 1.10997188723667e+77*cos(theta)**15 - 4.17282664374687e+75*cos(theta)**13 + 1.12935627415772e+74*cos(theta)**11 - 2.09351516948685e+72*cos(theta)**9 + 2.47265571199234e+70*cos(theta)**7 - 1.66162463845885e+68*cos(theta)**5 + 5.1958243854248e+65*cos(theta)**3 - 4.77118860002277e+62*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl87_m33(theta, phi):
    return 9.80372628269639e-64*(1.0 - cos(theta)**2)**16.5*(8.53402002059067e+85*cos(theta)**54 - 7.05906511529783e+86*cos(theta)**52 + 2.73693577277337e+87*cos(theta)**50 - 6.61291187701653e+87*cos(theta)**48 + 1.1166713468974e+88*cos(theta)**46 - 1.40091496247129e+88*cos(theta)**44 + 1.35507725408777e+88*cos(theta)**42 - 1.03524535560742e+88*cos(theta)**40 + 6.34820265230968e+87*cos(theta)**38 - 3.15837683267778e+87*cos(theta)**36 + 1.28372735779807e+87*cos(theta)**34 - 4.27909119266022e+86*cos(theta)**32 + 1.17131856046328e+86*cos(theta)**30 - 2.63047792360107e+85*cos(theta)**28 + 4.83149006375707e+84*cos(theta)**26 - 7.21946791136115e+83*cos(theta)**24 + 8.70879870426432e+82*cos(theta)**22 - 8.39270963990429e+81*cos(theta)**20 + 6.373360637817e+80*cos(theta)**18 - 3.74615511942375e+79*cos(theta)**16 + 1.664957830855e+78*cos(theta)**14 - 5.42467463687092e+76*cos(theta)**12 + 1.24229190157349e+75*cos(theta)**10 - 1.88416365253816e+73*cos(theta)**8 + 1.73085899839464e+71*cos(theta)**6 - 8.30812319229425e+68*cos(theta)**4 + 1.55874731562744e+66*cos(theta)**2 - 4.77118860002277e+62)*cos(33*phi)

#@torch.jit.script
def Yl87_m34(theta, phi):
    return 1.21283469548074e-65*(1.0 - cos(theta)**2)**17*(4.60837081111896e+87*cos(theta)**53 - 3.67071385995487e+88*cos(theta)**51 + 1.36846788638668e+89*cos(theta)**49 - 3.17419770096793e+89*cos(theta)**47 + 5.13668819572805e+89*cos(theta)**45 - 6.16402583487366e+89*cos(theta)**43 + 5.69132446716862e+89*cos(theta)**41 - 4.1409814224297e+89*cos(theta)**39 + 2.41231700787768e+89*cos(theta)**37 - 1.137015659764e+89*cos(theta)**35 + 4.36467301651342e+88*cos(theta)**33 - 1.36930918165127e+88*cos(theta)**31 + 3.51395568138985e+87*cos(theta)**29 - 7.36533818608301e+86*cos(theta)**27 + 1.25618741657684e+86*cos(theta)**25 - 1.73267229872667e+85*cos(theta)**23 + 1.91593571493815e+84*cos(theta)**21 - 1.67854192798086e+83*cos(theta)**19 + 1.14720491480706e+82*cos(theta)**17 - 5.993848191078e+80*cos(theta)**15 + 2.330940963197e+79*cos(theta)**13 - 6.50960956424511e+77*cos(theta)**11 + 1.24229190157349e+76*cos(theta)**9 - 1.50733092203053e+74*cos(theta)**7 + 1.03851539903678e+72*cos(theta)**5 - 3.3232492769177e+69*cos(theta)**3 + 3.11749463125488e+66*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl87_m35(theta, phi):
    return 1.50828621616385e-67*(1.0 - cos(theta)**2)**17.5*(2.44243652989305e+89*cos(theta)**52 - 1.87206406857699e+90*cos(theta)**50 + 6.70549264329476e+90*cos(theta)**48 - 1.49187291945493e+91*cos(theta)**46 + 2.31150968807762e+91*cos(theta)**44 - 2.65053110899567e+91*cos(theta)**42 + 2.33344303153913e+91*cos(theta)**40 - 1.61498275474758e+91*cos(theta)**38 + 8.92557292914741e+90*cos(theta)**36 - 3.979554809174e+90*cos(theta)**34 + 1.44034209544943e+90*cos(theta)**32 - 4.24485846311894e+89*cos(theta)**30 + 1.01904714760306e+89*cos(theta)**28 - 1.98864131024241e+88*cos(theta)**26 + 3.1404685414421e+87*cos(theta)**24 - 3.98514628707135e+86*cos(theta)**22 + 4.02346500137011e+85*cos(theta)**20 - 3.18922966316363e+84*cos(theta)**18 + 1.950248355172e+83*cos(theta)**16 - 8.99077228661699e+81*cos(theta)**14 + 3.0302232521561e+80*cos(theta)**12 - 7.16057052066962e+78*cos(theta)**10 + 1.11806271141614e+77*cos(theta)**8 - 1.05513164542137e+75*cos(theta)**6 + 5.19257699518391e+72*cos(theta)**4 - 9.9697478307531e+69*cos(theta)**2 + 3.11749463125488e+66)*cos(35*phi)

#@torch.jit.script
def Yl87_m36(theta, phi):
    return 1.88594722082738e-69*(1.0 - cos(theta)**2)**18*(1.27006699554439e+91*cos(theta)**51 - 9.36032034288493e+91*cos(theta)**49 + 3.21863646878148e+92*cos(theta)**47 - 6.86261542949267e+92*cos(theta)**45 + 1.01706426275415e+93*cos(theta)**43 - 1.11322306577818e+93*cos(theta)**41 + 9.33377212615654e+92*cos(theta)**39 - 6.13693446804081e+92*cos(theta)**37 + 3.21320625449307e+92*cos(theta)**35 - 1.35304863511916e+92*cos(theta)**33 + 4.60909470543817e+91*cos(theta)**31 - 1.27345753893568e+91*cos(theta)**29 + 2.85333201328856e+90*cos(theta)**27 - 5.17046740663027e+89*cos(theta)**25 + 7.53712449946103e+88*cos(theta)**23 - 8.76732183155697e+87*cos(theta)**21 + 8.04693000274023e+86*cos(theta)**19 - 5.74061339369453e+85*cos(theta)**17 + 3.12039736827521e+84*cos(theta)**15 - 1.25870812012638e+83*cos(theta)**13 + 3.63626790258732e+81*cos(theta)**11 - 7.16057052066962e+79*cos(theta)**9 + 8.94450169132916e+77*cos(theta)**7 - 6.33078987252822e+75*cos(theta)**5 + 2.07703079807356e+73*cos(theta)**3 - 1.99394956615062e+70*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl87_m37(theta, phi):
    return 2.3715572003035e-71*(1.0 - cos(theta)**2)**18.5*(6.47734167727637e+92*cos(theta)**50 - 4.58655696801361e+93*cos(theta)**48 + 1.5127591403273e+94*cos(theta)**46 - 3.0881769432717e+94*cos(theta)**44 + 4.37337632984286e+94*cos(theta)**42 - 4.56421456969055e+94*cos(theta)**40 + 3.64017112920105e+94*cos(theta)**38 - 2.2706657531751e+94*cos(theta)**36 + 1.12462218907257e+94*cos(theta)**34 - 4.46506049589323e+93*cos(theta)**32 + 1.42881935868583e+93*cos(theta)**30 - 3.69302686291347e+92*cos(theta)**28 + 7.7039964358791e+91*cos(theta)**26 - 1.29261685165757e+91*cos(theta)**24 + 1.73353863487604e+90*cos(theta)**22 - 1.84113758462696e+89*cos(theta)**20 + 1.52891670052064e+88*cos(theta)**18 - 9.7590427692807e+86*cos(theta)**16 + 4.68059605241281e+85*cos(theta)**14 - 1.63632055616429e+84*cos(theta)**12 + 3.99989469284605e+82*cos(theta)**10 - 6.44451346860266e+80*cos(theta)**8 + 6.26115118393041e+78*cos(theta)**6 - 3.16539493626411e+76*cos(theta)**4 + 6.23109239422069e+73*cos(theta)**2 - 1.99394956615062e+70)*cos(37*phi)

#@torch.jit.script
def Yl87_m38(theta, phi):
    return 2.99980894173249e-73*(1.0 - cos(theta)**2)**19*(3.23867083863818e+94*cos(theta)**49 - 2.20154734464653e+95*cos(theta)**47 + 6.95869204550557e+95*cos(theta)**45 - 1.35879785503955e+96*cos(theta)**43 + 1.836818058534e+96*cos(theta)**41 - 1.82568582787622e+96*cos(theta)**39 + 1.3832650290964e+96*cos(theta)**37 - 8.17439671143036e+95*cos(theta)**35 + 3.82371544284675e+95*cos(theta)**33 - 1.42881935868583e+95*cos(theta)**31 + 4.2864580760575e+94*cos(theta)**29 - 1.03404752161577e+94*cos(theta)**27 + 2.00303907332857e+93*cos(theta)**25 - 3.10228044397816e+92*cos(theta)**23 + 3.81378499672728e+91*cos(theta)**21 - 3.68227516925393e+90*cos(theta)**19 + 2.75205006093716e+89*cos(theta)**17 - 1.56144684308491e+88*cos(theta)**15 + 6.55283447337793e+86*cos(theta)**13 - 1.96358466739715e+85*cos(theta)**11 + 3.99989469284605e+83*cos(theta)**9 - 5.15561077488213e+81*cos(theta)**7 + 3.75669071035825e+79*cos(theta)**5 - 1.26615797450564e+77*cos(theta)**3 + 1.24621847884414e+74*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl87_m39(theta, phi):
    return 3.81777458698772e-75*(1.0 - cos(theta)**2)**19.5*(1.58694871093271e+96*cos(theta)**48 - 1.03472725198387e+97*cos(theta)**46 + 3.1314114204775e+97*cos(theta)**44 - 5.84283077667006e+97*cos(theta)**42 + 7.5309540399894e+97*cos(theta)**40 - 7.12017472871725e+97*cos(theta)**38 + 5.11808060765668e+97*cos(theta)**36 - 2.86103884900063e+97*cos(theta)**34 + 1.26182609613943e+97*cos(theta)**32 - 4.42934001192609e+96*cos(theta)**30 + 1.24307284205668e+96*cos(theta)**28 - 2.79192830836259e+95*cos(theta)**26 + 5.00759768332142e+94*cos(theta)**24 - 7.13524502114977e+93*cos(theta)**22 + 8.0089484931273e+92*cos(theta)**20 - 6.99632282158247e+91*cos(theta)**18 + 4.67848510359317e+90*cos(theta)**16 - 2.34217026462737e+89*cos(theta)**14 + 8.51868481539131e+87*cos(theta)**12 - 2.15994313413687e+86*cos(theta)**10 + 3.59990522356144e+84*cos(theta)**8 - 3.60892754241749e+82*cos(theta)**6 + 1.87834535517912e+80*cos(theta)**4 - 3.79847392351693e+77*cos(theta)**2 + 1.24621847884414e+74)*cos(39*phi)

#@torch.jit.script
def Yl87_m40(theta, phi):
    return 4.88976292791609e-77*(1.0 - cos(theta)**2)**20*(7.61735381247701e+97*cos(theta)**47 - 4.75974535912581e+98*cos(theta)**45 + 1.3778210250101e+99*cos(theta)**43 - 2.45398892620142e+99*cos(theta)**41 + 3.01238161599576e+99*cos(theta)**39 - 2.70566639691256e+99*cos(theta)**37 + 1.8425090187564e+99*cos(theta)**35 - 9.72753208660213e+98*cos(theta)**33 + 4.03784350764617e+98*cos(theta)**31 - 1.32880200357783e+98*cos(theta)**29 + 3.48060395775869e+97*cos(theta)**27 - 7.25901360174273e+96*cos(theta)**25 + 1.20182344399714e+96*cos(theta)**23 - 1.56975390465295e+95*cos(theta)**21 + 1.60178969862546e+94*cos(theta)**19 - 1.25933810788484e+93*cos(theta)**17 + 7.48557616574907e+91*cos(theta)**15 - 3.27903837047832e+90*cos(theta)**13 + 1.02224217784696e+89*cos(theta)**11 - 2.15994313413687e+87*cos(theta)**9 + 2.87992417884916e+85*cos(theta)**7 - 2.16535652545049e+83*cos(theta)**5 + 7.51338142071649e+80*cos(theta)**3 - 7.59694784703387e+77*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl87_m41(theta, phi):
    return 6.30425671627657e-79*(1.0 - cos(theta)**2)**20.5*(3.58015629186419e+99*cos(theta)**46 - 2.14188541160661e+100*cos(theta)**44 + 5.92463040754344e+100*cos(theta)**42 - 1.00613545974258e+101*cos(theta)**40 + 1.17482883023835e+101*cos(theta)**38 - 1.00109656685765e+101*cos(theta)**36 + 6.44878156564741e+100*cos(theta)**34 - 3.2100855885787e+100*cos(theta)**32 + 1.25173148737031e+100*cos(theta)**30 - 3.85352581037569e+99*cos(theta)**28 + 9.39763068594847e+98*cos(theta)**26 - 1.81475340043568e+98*cos(theta)**24 + 2.76419392119342e+97*cos(theta)**22 - 3.29648319977119e+96*cos(theta)**20 + 3.04340042738837e+95*cos(theta)**18 - 2.14087478340423e+94*cos(theta)**16 + 1.12283642486236e+93*cos(theta)**14 - 4.26274988162181e+91*cos(theta)**12 + 1.12446639563165e+90*cos(theta)**10 - 1.94394882072318e+88*cos(theta)**8 + 2.01594692519441e+86*cos(theta)**6 - 1.08267826272525e+84*cos(theta)**4 + 2.25401442621495e+81*cos(theta)**2 - 7.59694784703387e+77)*cos(41*phi)

#@torch.jit.script
def Yl87_m42(theta, phi):
    return 8.18389632082959e-81*(1.0 - cos(theta)**2)**21*(1.64687189425753e+101*cos(theta)**45 - 9.4242958110691e+101*cos(theta)**43 + 2.48834477116824e+102*cos(theta)**41 - 4.02454183897034e+102*cos(theta)**39 + 4.46434955490572e+102*cos(theta)**37 - 3.60394764068752e+102*cos(theta)**35 + 2.19258573232012e+102*cos(theta)**33 - 1.02722738834518e+102*cos(theta)**31 + 3.75519446211093e+101*cos(theta)**29 - 1.07898722690519e+101*cos(theta)**27 + 2.4433839783466e+100*cos(theta)**25 - 4.35540816104564e+99*cos(theta)**23 + 6.08122662662553e+98*cos(theta)**21 - 6.59296639954239e+97*cos(theta)**19 + 5.47812076929907e+96*cos(theta)**17 - 3.42539965344677e+95*cos(theta)**15 + 1.57197099480731e+94*cos(theta)**13 - 5.11529985794617e+92*cos(theta)**11 + 1.12446639563165e+91*cos(theta)**9 - 1.55515905657854e+89*cos(theta)**7 + 1.20956815511665e+87*cos(theta)**5 - 4.33071305090099e+84*cos(theta)**3 + 4.5080288524299e+81*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl87_m43(theta, phi):
    return 1.06999607787514e-82*(1.0 - cos(theta)**2)**21.5*(7.41092352415888e+102*cos(theta)**44 - 4.05244719875971e+103*cos(theta)**42 + 1.02022135617898e+104*cos(theta)**40 - 1.56957131719843e+104*cos(theta)**38 + 1.65180933531512e+104*cos(theta)**36 - 1.26138167424063e+104*cos(theta)**34 + 7.23553291665639e+103*cos(theta)**32 - 3.18440490387007e+103*cos(theta)**30 + 1.08900639401217e+103*cos(theta)**28 - 2.91326551264402e+102*cos(theta)**26 + 6.1084599458665e+101*cos(theta)**24 - 1.0017438770405e+101*cos(theta)**22 + 1.27705759159136e+100*cos(theta)**20 - 1.25266361591305e+99*cos(theta)**18 + 9.31280530780842e+97*cos(theta)**16 - 5.13809948017016e+96*cos(theta)**14 + 2.0435622932495e+95*cos(theta)**12 - 5.62682984374079e+93*cos(theta)**10 + 1.01201975606849e+92*cos(theta)**8 - 1.08861133960498e+90*cos(theta)**6 + 6.04784077558323e+87*cos(theta)**4 - 1.2992139152703e+85*cos(theta)**2 + 4.5080288524299e+81)*cos(43*phi)

#@torch.jit.script
def Yl87_m44(theta, phi):
    return 1.40935434808519e-84*(1.0 - cos(theta)**2)**22*(3.26080635062991e+104*cos(theta)**43 - 1.70202782347908e+105*cos(theta)**41 + 4.08088542471592e+105*cos(theta)**39 - 5.96437100535404e+105*cos(theta)**37 + 5.94651360713442e+105*cos(theta)**35 - 4.28869769241815e+105*cos(theta)**33 + 2.31537053333005e+105*cos(theta)**31 - 9.55321471161022e+104*cos(theta)**29 + 3.04921790323408e+104*cos(theta)**27 - 7.57449033287446e+103*cos(theta)**25 + 1.46603038700796e+103*cos(theta)**23 - 2.20383652948909e+102*cos(theta)**21 + 2.55411518318272e+101*cos(theta)**19 - 2.2547945086435e+100*cos(theta)**17 + 1.49004884924935e+99*cos(theta)**15 - 7.19333927223823e+97*cos(theta)**13 + 2.4522747518994e+96*cos(theta)**11 - 5.62682984374079e+94*cos(theta)**9 + 8.0961580485479e+92*cos(theta)**7 - 6.53166803762989e+90*cos(theta)**5 + 2.41913631023329e+88*cos(theta)**3 - 2.59842783054059e+85*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl87_m45(theta, phi):
    return 1.87067786008528e-86*(1.0 - cos(theta)**2)**22.5*(1.40214673077086e+106*cos(theta)**42 - 6.97831407626423e+106*cos(theta)**40 + 1.59154531563921e+107*cos(theta)**38 - 2.20681727198099e+107*cos(theta)**36 + 2.08127976249705e+107*cos(theta)**34 - 1.41527023849799e+107*cos(theta)**32 + 7.17764865332314e+106*cos(theta)**30 - 2.77043226636696e+106*cos(theta)**28 + 8.23288833873201e+105*cos(theta)**26 - 1.89362258321862e+105*cos(theta)**24 + 3.37186989011831e+104*cos(theta)**22 - 4.62805671192709e+103*cos(theta)**20 + 4.85281884804717e+102*cos(theta)**18 - 3.83315066469395e+101*cos(theta)**16 + 2.23507327387402e+100*cos(theta)**14 - 9.3513410539097e+98*cos(theta)**12 + 2.69750222708934e+97*cos(theta)**10 - 5.06414685936671e+95*cos(theta)**8 + 5.66731063398353e+93*cos(theta)**6 - 3.26583401881494e+91*cos(theta)**4 + 7.25740893069987e+88*cos(theta)**2 - 2.59842783054059e+85)*cos(45*phi)

#@torch.jit.script
def Yl87_m46(theta, phi):
    return 2.5029290597084e-88*(1.0 - cos(theta)**2)**23*(5.88901626923761e+107*cos(theta)**41 - 2.79132563050569e+108*cos(theta)**39 + 6.047872199429e+108*cos(theta)**37 - 7.94454217913158e+108*cos(theta)**35 + 7.07635119248996e+108*cos(theta)**33 - 4.52886476319357e+108*cos(theta)**31 + 2.15329459599694e+108*cos(theta)**29 - 7.7572103458275e+107*cos(theta)**27 + 2.14055096807032e+107*cos(theta)**25 - 4.54469419972468e+106*cos(theta)**23 + 7.41811375826028e+105*cos(theta)**21 - 9.25611342385418e+104*cos(theta)**19 + 8.73507392648491e+103*cos(theta)**17 - 6.13304106351031e+102*cos(theta)**15 + 3.12910258342363e+101*cos(theta)**13 - 1.12216092646916e+100*cos(theta)**11 + 2.69750222708934e+98*cos(theta)**9 - 4.05131748749337e+96*cos(theta)**7 + 3.40038638039012e+94*cos(theta)**5 - 1.30633360752598e+92*cos(theta)**3 + 1.45148178613997e+89*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl87_m47(theta, phi):
    return 3.37679124436137e-90*(1.0 - cos(theta)**2)**23.5*(2.41449667038742e+109*cos(theta)**40 - 1.08861699589722e+110*cos(theta)**38 + 2.23771271378873e+110*cos(theta)**36 - 2.78058976269605e+110*cos(theta)**34 + 2.33519589352169e+110*cos(theta)**32 - 1.40394807659001e+110*cos(theta)**30 + 6.24455432839114e+109*cos(theta)**28 - 2.09444679337342e+109*cos(theta)**26 + 5.35137742017581e+108*cos(theta)**24 - 1.04527966593668e+108*cos(theta)**22 + 1.55780388923466e+107*cos(theta)**20 - 1.7586615505323e+106*cos(theta)**18 + 1.48496256750243e+105*cos(theta)**16 - 9.19956159526547e+103*cos(theta)**14 + 4.06783335845072e+102*cos(theta)**12 - 1.23437701911608e+101*cos(theta)**10 + 2.4277520043804e+99*cos(theta)**8 - 2.83592224124536e+97*cos(theta)**6 + 1.70019319019506e+95*cos(theta)**4 - 3.91900082257793e+92*cos(theta)**2 + 1.45148178613997e+89)*cos(47*phi)

#@torch.jit.script
def Yl87_m48(theta, phi):
    return 4.59523084254623e-92*(1.0 - cos(theta)**2)**24*(9.65798668154969e+110*cos(theta)**39 - 4.13674458440943e+111*cos(theta)**37 + 8.05576576963942e+111*cos(theta)**35 - 9.45400519316658e+111*cos(theta)**33 + 7.47262685926939e+111*cos(theta)**31 - 4.21184422977002e+111*cos(theta)**29 + 1.74847521194952e+111*cos(theta)**27 - 5.4455616627709e+110*cos(theta)**25 + 1.28433058084219e+110*cos(theta)**23 - 2.29961526506069e+109*cos(theta)**21 + 3.11560777846932e+108*cos(theta)**19 - 3.16559079095813e+107*cos(theta)**17 + 2.3759401080039e+106*cos(theta)**15 - 1.28793862333717e+105*cos(theta)**13 + 4.88140003014086e+103*cos(theta)**11 - 1.23437701911608e+102*cos(theta)**9 + 1.94220160350432e+100*cos(theta)**7 - 1.70155334474722e+98*cos(theta)**5 + 6.80077276078024e+95*cos(theta)**3 - 7.83800164515586e+92*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl87_m49(theta, phi):
    return 6.30965444746346e-94*(1.0 - cos(theta)**2)**24.5*(3.76661480580438e+112*cos(theta)**38 - 1.53059549623149e+113*cos(theta)**36 + 2.8195180193738e+113*cos(theta)**34 - 3.11982171374497e+113*cos(theta)**32 + 2.31651432637351e+113*cos(theta)**30 - 1.22143482663331e+113*cos(theta)**28 + 4.7208830722637e+112*cos(theta)**26 - 1.36139041569273e+112*cos(theta)**24 + 2.95396033593705e+111*cos(theta)**22 - 4.82919205662744e+110*cos(theta)**20 + 5.91965477909171e+109*cos(theta)**18 - 5.38150434462882e+108*cos(theta)**16 + 3.56391016200584e+107*cos(theta)**14 - 1.67432021033832e+106*cos(theta)**12 + 5.36954003315495e+104*cos(theta)**10 - 1.11093931720447e+103*cos(theta)**8 + 1.35954112245303e+101*cos(theta)**6 - 8.50776672373608e+98*cos(theta)**4 + 2.04023182823407e+96*cos(theta)**2 - 7.83800164515586e+92)*cos(49*phi)

#@torch.jit.script
def Yl87_m50(theta, phi):
    return 8.74487273590109e-96*(1.0 - cos(theta)**2)**25*(1.43131362620566e+114*cos(theta)**37 - 5.51014378643336e+114*cos(theta)**35 + 9.58636126587091e+114*cos(theta)**33 - 9.98342948398391e+114*cos(theta)**31 + 6.94954297912054e+114*cos(theta)**29 - 3.42001751457326e+114*cos(theta)**27 + 1.22742959878856e+114*cos(theta)**25 - 3.26733699766254e+113*cos(theta)**23 + 6.4987127390615e+112*cos(theta)**21 - 9.65838411325489e+111*cos(theta)**19 + 1.06553786023651e+111*cos(theta)**17 - 8.61040695140612e+109*cos(theta)**15 + 4.98947422680818e+108*cos(theta)**13 - 2.00918425240598e+107*cos(theta)**11 + 5.36954003315495e+105*cos(theta)**9 - 8.88751453763577e+103*cos(theta)**7 + 8.15724673471815e+101*cos(theta)**5 - 3.40310668949443e+99*cos(theta)**3 + 4.08046365646814e+96*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl87_m51(theta, phi):
    return 1.22380743782299e-97*(1.0 - cos(theta)**2)**25.5*(5.29586041696096e+115*cos(theta)**36 - 1.92855032525168e+116*cos(theta)**34 + 3.1634992177374e+116*cos(theta)**32 - 3.09486314003501e+116*cos(theta)**30 + 2.01536746394496e+116*cos(theta)**28 - 9.23404728934779e+115*cos(theta)**26 + 3.0685739969714e+115*cos(theta)**24 - 7.51487509462385e+114*cos(theta)**22 + 1.36472967520292e+114*cos(theta)**20 - 1.83509298151843e+113*cos(theta)**18 + 1.81141436240206e+112*cos(theta)**16 - 1.29156104271092e+111*cos(theta)**14 + 6.48631649485063e+109*cos(theta)**12 - 2.21010267764658e+108*cos(theta)**10 + 4.83258602983945e+106*cos(theta)**8 - 6.22126017634504e+104*cos(theta)**6 + 4.07862336735908e+102*cos(theta)**4 - 1.02093200684833e+100*cos(theta)**2 + 4.08046365646814e+96)*cos(51*phi)

#@torch.jit.script
def Yl87_m52(theta, phi):
    return 1.73003320136911e-99*(1.0 - cos(theta)**2)**26*(1.90650975010594e+117*cos(theta)**35 - 6.5570711058557e+117*cos(theta)**33 + 1.01231974967597e+118*cos(theta)**31 - 9.28458942010503e+117*cos(theta)**29 + 5.64302889904587e+117*cos(theta)**27 - 2.40085229523043e+117*cos(theta)**25 + 7.36457759273137e+116*cos(theta)**23 - 1.65327252081725e+116*cos(theta)**21 + 2.72945935040583e+115*cos(theta)**19 - 3.30316736673317e+114*cos(theta)**17 + 2.8982629798433e+113*cos(theta)**15 - 1.80818545979528e+112*cos(theta)**13 + 7.78357979382076e+110*cos(theta)**11 - 2.21010267764658e+109*cos(theta)**9 + 3.86606882387156e+107*cos(theta)**7 - 3.73275610580703e+105*cos(theta)**5 + 1.63144934694363e+103*cos(theta)**3 - 2.04186401369666e+100*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl87_m53(theta, phi):
    return 2.47147600195587e-101*(1.0 - cos(theta)**2)**26.5*(6.6727841253708e+118*cos(theta)**34 - 2.16383346493238e+119*cos(theta)**32 + 3.1381912239955e+119*cos(theta)**30 - 2.69253093183046e+119*cos(theta)**28 + 1.52361780274239e+119*cos(theta)**26 - 6.00213073807607e+118*cos(theta)**24 + 1.69385284632821e+118*cos(theta)**22 - 3.47187229371622e+117*cos(theta)**20 + 5.18597276577108e+116*cos(theta)**18 - 5.61538452344639e+115*cos(theta)**16 + 4.34739446976495e+114*cos(theta)**14 - 2.35064109773387e+113*cos(theta)**12 + 8.56193777320284e+111*cos(theta)**10 - 1.98909240988192e+110*cos(theta)**8 + 2.70624817671009e+108*cos(theta)**6 - 1.86637805290351e+106*cos(theta)**4 + 4.89434804083089e+103*cos(theta)**2 - 2.04186401369666e+100)*cos(53*phi)

#@torch.jit.script
def Yl87_m54(theta, phi):
    return 3.56949997264925e-103*(1.0 - cos(theta)**2)**27*(2.26874660262607e+120*cos(theta)**33 - 6.92426708778362e+120*cos(theta)**31 + 9.4145736719865e+120*cos(theta)**29 - 7.53908660912529e+120*cos(theta)**27 + 3.9614062871302e+120*cos(theta)**25 - 1.44051137713826e+120*cos(theta)**23 + 3.72647626192207e+119*cos(theta)**21 - 6.94374458743243e+118*cos(theta)**19 + 9.33475097838794e+117*cos(theta)**17 - 8.98461523751423e+116*cos(theta)**15 + 6.08635225767093e+115*cos(theta)**13 - 2.82076931728064e+114*cos(theta)**11 + 8.56193777320284e+112*cos(theta)**9 - 1.59127392790554e+111*cos(theta)**7 + 1.62374890602606e+109*cos(theta)**5 - 7.46551221161405e+106*cos(theta)**3 + 9.78869608166178e+103*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl87_m55(theta, phi):
    return 5.21442278515843e-105*(1.0 - cos(theta)**2)**27.5*(7.48686378866604e+121*cos(theta)**32 - 2.14652279721292e+122*cos(theta)**30 + 2.73022636487609e+122*cos(theta)**28 - 2.03555338446383e+122*cos(theta)**26 + 9.90351571782551e+121*cos(theta)**24 - 3.31317616741799e+121*cos(theta)**22 + 7.82560015003635e+120*cos(theta)**20 - 1.31931147161216e+120*cos(theta)**18 + 1.58690766632595e+119*cos(theta)**16 - 1.34769228562713e+118*cos(theta)**14 + 7.91225793497221e+116*cos(theta)**12 - 3.10284624900871e+115*cos(theta)**10 + 7.70574399588255e+113*cos(theta)**8 - 1.11389174953387e+112*cos(theta)**6 + 8.11874453013028e+109*cos(theta)**4 - 2.23965366348422e+107*cos(theta)**2 + 9.78869608166178e+103)*cos(55*phi)

#@torch.jit.script
def Yl87_m56(theta, phi):
    return 7.70838207698024e-107*(1.0 - cos(theta)**2)**28*(2.39579641237313e+123*cos(theta)**31 - 6.43956839163877e+123*cos(theta)**29 + 7.64463382165304e+123*cos(theta)**27 - 5.29243879960595e+123*cos(theta)**25 + 2.37684377227812e+123*cos(theta)**23 - 7.28898756831958e+122*cos(theta)**21 + 1.56512003000727e+122*cos(theta)**19 - 2.37476064890189e+121*cos(theta)**17 + 2.53905226612152e+120*cos(theta)**15 - 1.88676919987799e+119*cos(theta)**13 + 9.49470952196665e+117*cos(theta)**11 - 3.10284624900871e+116*cos(theta)**9 + 6.16459519670604e+114*cos(theta)**7 - 6.68335049720325e+112*cos(theta)**5 + 3.24749781205211e+110*cos(theta)**3 - 4.47930732696843e+107*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl87_m57(theta, phi):
    return 1.15372190922818e-108*(1.0 - cos(theta)**2)**28.5*(7.42696887835671e+124*cos(theta)**30 - 1.86747483357524e+125*cos(theta)**28 + 2.06405113184632e+125*cos(theta)**26 - 1.32310969990149e+125*cos(theta)**24 + 5.46674067623968e+124*cos(theta)**22 - 1.53068738934711e+124*cos(theta)**20 + 2.97372805701381e+123*cos(theta)**18 - 4.03709310313322e+122*cos(theta)**16 + 3.80857839918228e+121*cos(theta)**14 - 2.45279995984138e+120*cos(theta)**12 + 1.04441804741633e+119*cos(theta)**10 - 2.79256162410784e+117*cos(theta)**8 + 4.31521663769423e+115*cos(theta)**6 - 3.34167524860162e+113*cos(theta)**4 + 9.74249343615634e+110*cos(theta)**2 - 4.47930732696843e+107)*cos(57*phi)

#@torch.jit.script
def Yl87_m58(theta, phi):
    return 1.74926864444e-110*(1.0 - cos(theta)**2)**29*(2.22809066350701e+126*cos(theta)**29 - 5.22892953401068e+126*cos(theta)**27 + 5.36653294280044e+126*cos(theta)**25 - 3.17546327976357e+126*cos(theta)**23 + 1.20268294877273e+126*cos(theta)**21 - 3.06137477869422e+125*cos(theta)**19 + 5.35271050262487e+124*cos(theta)**17 - 6.45934896501315e+123*cos(theta)**15 + 5.33200975885519e+122*cos(theta)**13 - 2.94335995180966e+121*cos(theta)**11 + 1.04441804741633e+120*cos(theta)**9 - 2.23404929928627e+118*cos(theta)**7 + 2.58912998261654e+116*cos(theta)**5 - 1.33667009944065e+114*cos(theta)**3 + 1.94849868723127e+111*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl87_m59(theta, phi):
    return 2.68832075291e-112*(1.0 - cos(theta)**2)**29.5*(6.46146292417034e+127*cos(theta)**28 - 1.41181097418288e+128*cos(theta)**26 + 1.34163323570011e+128*cos(theta)**24 - 7.30356554345621e+127*cos(theta)**22 + 2.52563419242273e+127*cos(theta)**20 - 5.81661207951902e+126*cos(theta)**18 + 9.09960785446227e+125*cos(theta)**16 - 9.68902344751972e+124*cos(theta)**14 + 6.93161268651175e+123*cos(theta)**12 - 3.23769594699063e+122*cos(theta)**10 + 9.39976242674698e+120*cos(theta)**8 - 1.56383450950039e+119*cos(theta)**6 + 1.29456499130827e+117*cos(theta)**4 - 4.01001029832195e+114*cos(theta)**2 + 1.94849868723127e+111)*cos(59*phi)

#@torch.jit.script
def Yl87_m60(theta, phi):
    return 4.19028344984038e-114*(1.0 - cos(theta)**2)**30*(1.8092096187677e+129*cos(theta)**27 - 3.6707085328755e+129*cos(theta)**25 + 3.21991976568026e+129*cos(theta)**23 - 1.60678441956037e+129*cos(theta)**21 + 5.05126838484547e+128*cos(theta)**19 - 1.04699017431342e+128*cos(theta)**17 + 1.45593725671396e+127*cos(theta)**15 - 1.35646328265276e+126*cos(theta)**13 + 8.3179352238141e+124*cos(theta)**11 - 3.23769594699063e+123*cos(theta)**9 + 7.51980994139758e+121*cos(theta)**7 - 9.38300705700233e+119*cos(theta)**5 + 5.17825996523308e+117*cos(theta)**3 - 8.0200205966439e+114*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl87_m61(theta, phi):
    return 6.62873506814228e-116*(1.0 - cos(theta)**2)**30.5*(4.88486597067278e+130*cos(theta)**26 - 9.17677133218874e+130*cos(theta)**24 + 7.4058154610646e+130*cos(theta)**22 - 3.37424728107677e+130*cos(theta)**20 + 9.59740993120638e+129*cos(theta)**18 - 1.77988329633282e+129*cos(theta)**16 + 2.18390588507095e+128*cos(theta)**14 - 1.76340226744859e+127*cos(theta)**12 + 9.14972874619551e+125*cos(theta)**10 - 2.91392635229156e+124*cos(theta)**8 + 5.26386695897831e+122*cos(theta)**6 - 4.69150352850117e+120*cos(theta)**4 + 1.55347798956992e+118*cos(theta)**2 - 8.0200205966439e+114)*cos(61*phi)

#@torch.jit.script
def Yl87_m62(theta, phi):
    return 1.06500305519713e-117*(1.0 - cos(theta)**2)**31*(1.27006515237492e+132*cos(theta)**25 - 2.2024251197253e+132*cos(theta)**23 + 1.62927940143421e+132*cos(theta)**21 - 6.74849456215354e+131*cos(theta)**19 + 1.72753378761715e+131*cos(theta)**17 - 2.84781327413251e+130*cos(theta)**15 + 3.05746823909932e+129*cos(theta)**13 - 2.11608272093831e+128*cos(theta)**11 + 9.14972874619551e+126*cos(theta)**9 - 2.33114108183325e+125*cos(theta)**7 + 3.15832017538699e+123*cos(theta)**5 - 1.87660141140047e+121*cos(theta)**3 + 3.10695597913985e+118*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl87_m63(theta, phi):
    return 1.73914270649208e-119*(1.0 - cos(theta)**2)**31.5*(3.17516288093731e+133*cos(theta)**24 - 5.06557777536819e+133*cos(theta)**22 + 3.42148674301185e+133*cos(theta)**20 - 1.28221396680917e+133*cos(theta)**18 + 2.93680743894915e+132*cos(theta)**16 - 4.27171991119877e+131*cos(theta)**14 + 3.97470871082912e+130*cos(theta)**12 - 2.32769099303214e+129*cos(theta)**10 + 8.23475587157596e+127*cos(theta)**8 - 1.63179875728328e+126*cos(theta)**6 + 1.57916008769349e+124*cos(theta)**4 - 5.6298042342014e+121*cos(theta)**2 + 3.10695597913985e+118)*cos(63*phi)

#@torch.jit.script
def Yl87_m64(theta, phi):
    return 2.8889573162515e-121*(1.0 - cos(theta)**2)**32*(7.62039091424953e+134*cos(theta)**23 - 1.114427110581e+135*cos(theta)**21 + 6.84297348602369e+134*cos(theta)**19 - 2.30798514025651e+134*cos(theta)**17 + 4.69889190231865e+133*cos(theta)**15 - 5.98040787567828e+132*cos(theta)**13 + 4.76965045299494e+131*cos(theta)**11 - 2.32769099303214e+130*cos(theta)**9 + 6.58780469726077e+128*cos(theta)**7 - 9.79079254369965e+126*cos(theta)**5 + 6.31664035077397e+124*cos(theta)**3 - 1.12596084684028e+122*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl87_m65(theta, phi):
    return 4.88602194583257e-123*(1.0 - cos(theta)**2)**32.5*(1.75268991027739e+136*cos(theta)**22 - 2.3402969322201e+136*cos(theta)**20 + 1.3001649623445e+136*cos(theta)**18 - 3.92357473843607e+135*cos(theta)**16 + 7.04833785347797e+134*cos(theta)**14 - 7.77453023838176e+133*cos(theta)**12 + 5.24661549829444e+132*cos(theta)**10 - 2.09492189372892e+131*cos(theta)**8 + 4.61146328808254e+129*cos(theta)**6 - 4.89539627184983e+127*cos(theta)**4 + 1.89499210523219e+125*cos(theta)**2 - 1.12596084684028e+122)*cos(65*phi)

#@torch.jit.script
def Yl87_m66(theta, phi):
    return 8.42167267078511e-125*(1.0 - cos(theta)**2)**33*(3.85591780261026e+137*cos(theta)**21 - 4.68059386444021e+137*cos(theta)**19 + 2.3402969322201e+137*cos(theta)**17 - 6.27771958149771e+136*cos(theta)**15 + 9.86767299486916e+135*cos(theta)**13 - 9.32943628605811e+134*cos(theta)**11 + 5.24661549829444e+133*cos(theta)**9 - 1.67593751498314e+132*cos(theta)**7 + 2.76687797284952e+130*cos(theta)**5 - 1.95815850873993e+128*cos(theta)**3 + 3.78998421046438e+125*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl87_m67(theta, phi):
    return 1.48090892226691e-126*(1.0 - cos(theta)**2)**33.5*(8.09742738548156e+138*cos(theta)**20 - 8.89312834243639e+138*cos(theta)**18 + 3.97850478477417e+138*cos(theta)**16 - 9.41657937224657e+137*cos(theta)**14 + 1.28279748933299e+137*cos(theta)**12 - 1.02623799146639e+136*cos(theta)**10 + 4.72195394846499e+134*cos(theta)**8 - 1.1731562604882e+133*cos(theta)**6 + 1.38343898642476e+131*cos(theta)**4 - 5.87447552621979e+128*cos(theta)**2 + 3.78998421046438e+125)*cos(67*phi)

#@torch.jit.script
def Yl87_m68(theta, phi):
    return 2.65979094257895e-128*(1.0 - cos(theta)**2)**34*(1.61948547709631e+140*cos(theta)**19 - 1.60076310163855e+140*cos(theta)**17 + 6.36560765563868e+139*cos(theta)**15 - 1.31832111211452e+139*cos(theta)**13 + 1.53935698719959e+138*cos(theta)**11 - 1.02623799146639e+137*cos(theta)**9 + 3.777563158772e+135*cos(theta)**7 - 7.03893756292919e+133*cos(theta)**5 + 5.53375594569904e+131*cos(theta)**3 - 1.17489510524396e+129*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl87_m69(theta, phi):
    return 4.88549308735178e-130*(1.0 - cos(theta)**2)**34.5*(3.07702240648299e+141*cos(theta)**18 - 2.72129727278554e+141*cos(theta)**16 + 9.54841148345802e+140*cos(theta)**14 - 1.71381744574888e+140*cos(theta)**12 + 1.69329268591955e+139*cos(theta)**10 - 9.23614192319753e+137*cos(theta)**8 + 2.6442942111404e+136*cos(theta)**6 - 3.51946878146459e+134*cos(theta)**4 + 1.66012678370971e+132*cos(theta)**2 - 1.17489510524396e+129)*cos(69*phi)

#@torch.jit.script
def Yl87_m70(theta, phi):
    return 9.19014416896121e-132*(1.0 - cos(theta)**2)**35*(5.53864033166938e+142*cos(theta)**17 - 4.35407563645686e+142*cos(theta)**15 + 1.33677760768412e+142*cos(theta)**13 - 2.05658093489865e+141*cos(theta)**11 + 1.69329268591955e+140*cos(theta)**9 - 7.38891353855802e+138*cos(theta)**7 + 1.58657652668424e+137*cos(theta)**5 - 1.40778751258584e+135*cos(theta)**3 + 3.32025356741943e+132*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl87_m71(theta, phi):
    return 1.77324735287298e-133*(1.0 - cos(theta)**2)**35.5*(9.41568856383795e+143*cos(theta)**16 - 6.53111345468528e+143*cos(theta)**14 + 1.73781088998936e+143*cos(theta)**12 - 2.26223902838852e+142*cos(theta)**10 + 1.52396341732759e+141*cos(theta)**8 - 5.17223947699062e+139*cos(theta)**6 + 7.93288263342119e+137*cos(theta)**4 - 4.22336253775751e+135*cos(theta)**2 + 3.32025356741943e+132)*cos(71*phi)

#@torch.jit.script
def Yl87_m72(theta, phi):
    return 3.51569156266604e-135*(1.0 - cos(theta)**2)**36*(1.50651017021407e+145*cos(theta)**15 - 9.1435588365594e+144*cos(theta)**13 + 2.08537306798723e+144*cos(theta)**11 - 2.26223902838851e+143*cos(theta)**9 + 1.21917073386207e+142*cos(theta)**7 - 3.10334368619437e+140*cos(theta)**5 + 3.17315305336848e+138*cos(theta)**3 - 8.44672507551502e+135*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl87_m73(theta, phi):
    return 7.1763753512832e-137*(1.0 - cos(theta)**2)**36.5*(2.25976525532111e+146*cos(theta)**14 - 1.18866264875272e+146*cos(theta)**12 + 2.29391037478595e+145*cos(theta)**10 - 2.03601512554966e+144*cos(theta)**8 + 8.53419513703452e+142*cos(theta)**6 - 1.55167184309719e+141*cos(theta)**4 + 9.51945916010543e+138*cos(theta)**2 - 8.44672507551502e+135)*cos(73*phi)

#@torch.jit.script
def Yl87_m74(theta, phi):
    return 1.51156974270712e-138*(1.0 - cos(theta)**2)**37*(3.16367135744955e+147*cos(theta)**13 - 1.42639517850327e+147*cos(theta)**11 + 2.29391037478595e+146*cos(theta)**9 - 1.62881210043973e+145*cos(theta)**7 + 5.12051708222071e+143*cos(theta)**5 - 6.20668737238874e+141*cos(theta)**3 + 1.90389183202109e+139*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl87_m75(theta, phi):
    return 3.29381351035043e-140*(1.0 - cos(theta)**2)**37.5*(4.11277276468442e+148*cos(theta)**12 - 1.56903469635359e+148*cos(theta)**10 + 2.06451933730736e+147*cos(theta)**8 - 1.14016847030781e+146*cos(theta)**6 + 2.56025854111036e+144*cos(theta)**4 - 1.86200621171662e+142*cos(theta)**2 + 1.90389183202109e+139)*cos(75*phi)

#@torch.jit.script
def Yl87_m76(theta, phi):
    return 7.44756978553847e-142*(1.0 - cos(theta)**2)**38*(4.9353273176213e+149*cos(theta)**11 - 1.56903469635359e+149*cos(theta)**9 + 1.65161546984589e+148*cos(theta)**7 - 6.84101082184687e+146*cos(theta)**5 + 1.02410341644414e+145*cos(theta)**3 - 3.72401242343324e+142*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl87_m77(theta, phi):
    return 1.75346182317299e-143*(1.0 - cos(theta)**2)**38.5*(5.42886004938343e+150*cos(theta)**10 - 1.41213122671823e+150*cos(theta)**8 + 1.15613082889212e+149*cos(theta)**6 - 3.42050541092343e+147*cos(theta)**4 + 3.07231024933243e+145*cos(theta)**2 - 3.72401242343324e+142)*cos(77*phi)

#@torch.jit.script
def Yl87_m78(theta, phi):
    return 4.31672460379404e-145*(1.0 - cos(theta)**2)**39*(5.42886004938343e+151*cos(theta)**9 - 1.12970498137459e+151*cos(theta)**7 + 6.93678497335273e+149*cos(theta)**5 - 1.36820216436937e+148*cos(theta)**3 + 6.14462049866485e+145*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl87_m79(theta, phi):
    return 1.11680935685474e-146*(1.0 - cos(theta)**2)**39.5*(4.88597404444509e+152*cos(theta)**8 - 7.90793486962211e+151*cos(theta)**6 + 3.46839248667636e+150*cos(theta)**4 - 4.10460649310812e+148*cos(theta)**2 + 6.14462049866485e+145)*cos(79*phi)

#@torch.jit.script
def Yl87_m80(theta, phi):
    return 3.05545445765463e-148*(1.0 - cos(theta)**2)**40*(3.90877923555607e+153*cos(theta)**7 - 4.74476092177326e+152*cos(theta)**5 + 1.38735699467055e+151*cos(theta)**3 - 8.20921298621624e+148*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl87_m81(theta, phi):
    return 8.90988613519781e-150*(1.0 - cos(theta)**2)**40.5*(2.73614546488925e+154*cos(theta)**6 - 2.37238046088663e+153*cos(theta)**4 + 4.16207098401164e+151*cos(theta)**2 - 8.20921298621624e+148)*cos(81*phi)

#@torch.jit.script
def Yl87_m82(theta, phi):
    return 2.79803521763245e-151*(1.0 - cos(theta)**2)**41*(1.64168727893355e+155*cos(theta)**5 - 9.48952184354653e+153*cos(theta)**3 + 8.32414196802327e+151*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl87_m83(theta, phi):
    return 9.59718162005753e-153*(1.0 - cos(theta)**2)**41.5*(8.20843639466775e+155*cos(theta)**4 - 2.84685655306396e+154*cos(theta)**2 + 8.32414196802327e+151)*cos(83*phi)

#@torch.jit.script
def Yl87_m84(theta, phi):
    return 3.66957410742427e-154*(1.0 - cos(theta)**2)**42*(3.2833745578671e+156*cos(theta)**3 - 5.69371310612792e+154*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl87_m85(theta, phi):
    return 1.61543992435537e-155*(1.0 - cos(theta)**2)**42.5*(9.8501236736013e+156*cos(theta)**2 - 5.69371310612792e+154)*cos(85*phi)

#@torch.jit.script
def Yl87_m86(theta, phi):
    return 17.108992720905*(1.0 - cos(theta)**2)**43*cos(86*phi)*cos(theta)

#@torch.jit.script
def Yl87_m87(theta, phi):
    return 1.29702939093238*(1.0 - cos(theta)**2)**43.5*cos(87*phi)

#@torch.jit.script
def Yl88_m_minus_88(theta, phi):
    return 1.30070891432765*(1.0 - cos(theta)**2)**44*sin(88*phi)

#@torch.jit.script
def Yl88_m_minus_87(theta, phi):
    return 17.2558537211813*(1.0 - cos(theta)**2)**43.5*sin(87*phi)*cos(theta)

#@torch.jit.script
def Yl88_m_minus_86(theta, phi):
    return 9.36398577033487e-158*(1.0 - cos(theta)**2)**43*(1.72377164288023e+159*cos(theta)**2 - 9.8501236736013e+156)*sin(86*phi)

#@torch.jit.script
def Yl88_m_minus_85(theta, phi):
    return 2.13941972980226e-156*(1.0 - cos(theta)**2)**42.5*(5.74590547626742e+158*cos(theta)**3 - 9.8501236736013e+156*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl88_m_minus_84(theta, phi):
    return 5.62793462288332e-155*(1.0 - cos(theta)**2)**42*(1.43647636906686e+158*cos(theta)**4 - 4.92506183680065e+156*cos(theta)**2 + 1.42342827653198e+154)*sin(84*phi)

#@torch.jit.script
def Yl88_m_minus_83(theta, phi):
    return 1.65043440895802e-153*(1.0 - cos(theta)**2)**41.5*(2.87295273813371e+157*cos(theta)**5 - 1.64168727893355e+156*cos(theta)**3 + 1.42342827653198e+154*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl88_m_minus_82(theta, phi):
    return 5.28654520028694e-152*(1.0 - cos(theta)**2)**41*(4.78825456355619e+156*cos(theta)**6 - 4.10421819733387e+155*cos(theta)**4 + 7.1171413826599e+153*cos(theta)**2 - 1.38735699467055e+151)*sin(82*phi)

#@torch.jit.script
def Yl88_m_minus_81(theta, phi):
    return 1.82366654254733e-150*(1.0 - cos(theta)**2)**40.5*(6.84036366222312e+155*cos(theta)**7 - 8.20843639466775e+154*cos(theta)**5 + 2.37238046088663e+153*cos(theta)**3 - 1.38735699467055e+151*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl88_m_minus_80(theta, phi):
    return 6.70554029006287e-149*(1.0 - cos(theta)**2)**40*(8.5504545777789e+154*cos(theta)**8 - 1.36807273244462e+154*cos(theta)**6 + 5.93095115221658e+152*cos(theta)**4 - 6.93678497335273e+150*cos(theta)**2 + 1.02615162327703e+148)*sin(80*phi)

#@torch.jit.script
def Yl88_m_minus_79(theta, phi):
    return 2.60741207175745e-147*(1.0 - cos(theta)**2)**39.5*(9.500505086421e+153*cos(theta)**9 - 1.95438961777804e+153*cos(theta)**7 + 1.18619023044332e+152*cos(theta)**5 - 2.31226165778424e+150*cos(theta)**3 + 1.02615162327703e+148*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl88_m_minus_78(theta, phi):
    return 1.06553546064646e-145*(1.0 - cos(theta)**2)**39*(9.500505086421e+152*cos(theta)**10 - 2.44298702222254e+152*cos(theta)**8 + 1.97698371740553e+151*cos(theta)**6 - 5.7806541444606e+149*cos(theta)**4 + 5.13075811638515e+147*cos(theta)**2 - 6.14462049866485e+144)*sin(78*phi)

#@torch.jit.script
def Yl88_m_minus_77(theta, phi):
    return 4.55321642740204e-144*(1.0 - cos(theta)**2)**38.5*(8.63682280583728e+151*cos(theta)**11 - 2.71443002469172e+151*cos(theta)**9 + 2.82426245343647e+150*cos(theta)**7 - 1.15613082889212e+149*cos(theta)**5 + 1.71025270546172e+147*cos(theta)**3 - 6.14462049866485e+144*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl88_m_minus_76(theta, phi):
    return 2.02605340681909e-142*(1.0 - cos(theta)**2)**38*(7.19735233819773e+150*cos(theta)**12 - 2.71443002469172e+150*cos(theta)**10 + 3.53032806679558e+149*cos(theta)**8 - 1.9268847148202e+148*cos(theta)**6 + 4.27563176365429e+146*cos(theta)**4 - 3.07231024933243e+144*cos(theta)**2 + 3.10334368619437e+141)*sin(76*phi)

#@torch.jit.script
def Yl88_m_minus_75(theta, phi):
    return 9.35501502528341e-141*(1.0 - cos(theta)**2)**37.5*(5.53642487553672e+149*cos(theta)**13 - 2.46766365881065e+149*cos(theta)**11 + 3.92258674088398e+148*cos(theta)**9 - 2.75269244974315e+147*cos(theta)**7 + 8.55126352730859e+145*cos(theta)**5 - 1.02410341644414e+144*cos(theta)**3 + 3.10334368619437e+141*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl88_m_minus_74(theta, phi):
    return 4.46891721307658e-139*(1.0 - cos(theta)**2)**37*(3.95458919681194e+148*cos(theta)**14 - 2.05638638234221e+148*cos(theta)**12 + 3.92258674088398e+147*cos(theta)**10 - 3.44086556217893e+146*cos(theta)**8 + 1.42521058788476e+145*cos(theta)**6 - 2.56025854111036e+143*cos(theta)**4 + 1.55167184309719e+141*cos(theta)**2 - 1.35992273715792e+138)*sin(74*phi)

#@torch.jit.script
def Yl88_m_minus_73(theta, phi):
    return 2.20295408870265e-137*(1.0 - cos(theta)**2)**36.5*(2.63639279787463e+147*cos(theta)**15 - 1.58183567872478e+147*cos(theta)**13 + 3.56598794625817e+146*cos(theta)**11 - 3.82318395797659e+145*cos(theta)**9 + 2.03601512554966e+144*cos(theta)**7 - 5.12051708222071e+142*cos(theta)**5 + 5.17223947699062e+140*cos(theta)**3 - 1.35992273715792e+138*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl88_m_minus_72(theta, phi):
    return 1.11809415090215e-135*(1.0 - cos(theta)**2)**36*(1.64774549867164e+146*cos(theta)**16 - 1.12988262766055e+146*cos(theta)**14 + 2.9716566218818e+145*cos(theta)**12 - 3.82318395797659e+144*cos(theta)**10 + 2.54501890693708e+143*cos(theta)**8 - 8.53419513703452e+141*cos(theta)**6 + 1.29305986924765e+140*cos(theta)**4 - 6.79961368578959e+137*cos(theta)**2 + 5.27920317219689e+134)*sin(72*phi)

#@torch.jit.script
def Yl88_m_minus_71(theta, phi):
    return 5.83126566224347e-134*(1.0 - cos(theta)**2)**35.5*(9.69262058042142e+144*cos(theta)**17 - 7.53255085107036e+144*cos(theta)**15 + 2.28588970913985e+144*cos(theta)**13 - 3.47562177997872e+143*cos(theta)**11 + 2.82779878548564e+142*cos(theta)**9 - 1.21917073386207e+141*cos(theta)**7 + 2.58611973849531e+139*cos(theta)**5 - 2.2665378952632e+137*cos(theta)**3 + 5.27920317219689e+134*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl88_m_minus_70(theta, phi):
    return 3.11959088180028e-132*(1.0 - cos(theta)**2)**35*(5.38478921134523e+143*cos(theta)**18 - 4.70784428191898e+143*cos(theta)**16 + 1.63277836367132e+143*cos(theta)**14 - 2.8963514833156e+142*cos(theta)**12 + 2.82779878548564e+141*cos(theta)**10 - 1.52396341732759e+140*cos(theta)**8 + 4.31019956415885e+138*cos(theta)**6 - 5.66634473815799e+136*cos(theta)**4 + 2.63960158609844e+134*cos(theta)**2 - 1.84458531523301e+131)*sin(70*phi)

#@torch.jit.script
def Yl88_m_minus_69(theta, phi):
    return 1.70923975802033e-130*(1.0 - cos(theta)**2)**34.5*(2.83409958491854e+142*cos(theta)**19 - 2.76932016583469e+142*cos(theta)**17 + 1.08851890911421e+142*cos(theta)**15 - 2.22796267947354e+141*cos(theta)**13 + 2.57072616862331e+140*cos(theta)**11 - 1.69329268591955e+139*cos(theta)**9 + 6.15742794879835e+137*cos(theta)**7 - 1.1332689476316e+136*cos(theta)**5 + 8.79867195366148e+133*cos(theta)**3 - 1.84458531523301e+131*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl88_m_minus_68(theta, phi):
    return 9.57784512729653e-129*(1.0 - cos(theta)**2)**34*(1.41704979245927e+141*cos(theta)**20 - 1.5385112032415e+141*cos(theta)**18 + 6.80324318196384e+140*cos(theta)**16 - 1.59140191390967e+140*cos(theta)**14 + 2.14227180718609e+139*cos(theta)**12 - 1.69329268591955e+138*cos(theta)**10 + 7.69678493599794e+136*cos(theta)**8 - 1.888781579386e+135*cos(theta)**6 + 2.19966798841537e+133*cos(theta)**4 - 9.22292657616507e+130*cos(theta)**2 + 5.87447552621979e+127)*sin(68*phi)

#@torch.jit.script
def Yl88_m_minus_67(theta, phi):
    return 5.48200915921706e-127*(1.0 - cos(theta)**2)**33.5*(6.74785615456796e+139*cos(theta)**21 - 8.09742738548155e+139*cos(theta)**19 + 4.00190775409638e+139*cos(theta)**17 - 1.06093460927311e+139*cos(theta)**15 + 1.64790139014315e+138*cos(theta)**13 - 1.53935698719959e+137*cos(theta)**11 + 8.55198326221994e+135*cos(theta)**9 - 2.69825939912285e+134*cos(theta)**7 + 4.39933597683074e+132*cos(theta)**5 - 3.07430885872169e+130*cos(theta)**3 + 5.87447552621979e+127*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl88_m_minus_66(theta, phi):
    return 3.20123050213715e-125*(1.0 - cos(theta)**2)**33*(3.06720734298544e+138*cos(theta)**22 - 4.04871369274078e+138*cos(theta)**20 + 2.2232820856091e+138*cos(theta)**18 - 6.63084130795696e+137*cos(theta)**16 + 1.17707242153082e+137*cos(theta)**14 - 1.28279748933299e+136*cos(theta)**12 + 8.55198326221994e+134*cos(theta)**10 - 3.37282424890357e+133*cos(theta)**8 + 7.33222662805123e+131*cos(theta)**6 - 7.68577214680423e+129*cos(theta)**4 + 2.9372377631099e+127*cos(theta)**2 - 1.72272009566563e+124)*sin(66*phi)

#@torch.jit.script
def Yl88_m_minus_65(theta, phi):
    return 1.90520285980036e-123*(1.0 - cos(theta)**2)**32.5*(1.33356840999367e+137*cos(theta)**23 - 1.92795890130513e+137*cos(theta)**21 + 1.17014846611005e+137*cos(theta)**19 - 3.9004948870335e+136*cos(theta)**17 + 7.84714947687214e+135*cos(theta)**15 - 9.86767299486916e+134*cos(theta)**13 + 7.77453023838176e+133*cos(theta)**11 - 3.74758249878174e+132*cos(theta)**9 + 1.04746094686446e+131*cos(theta)**7 - 1.53715442936085e+129*cos(theta)**5 + 9.79079254369965e+126*cos(theta)**3 - 1.72272009566563e+124*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl88_m_minus_64(theta, phi):
    return 1.15449634146812e-121*(1.0 - cos(theta)**2)**32*(5.55653504164028e+135*cos(theta)**24 - 8.76344955138696e+135*cos(theta)**22 + 5.85074233055026e+135*cos(theta)**20 - 2.1669416039075e+135*cos(theta)**18 + 4.90446842304509e+134*cos(theta)**16 - 7.04833785347797e+133*cos(theta)**14 + 6.47877519865147e+132*cos(theta)**12 - 3.74758249878174e+131*cos(theta)**10 + 1.30932618358058e+130*cos(theta)**8 - 2.56192404893474e+128*cos(theta)**6 + 2.44769813592491e+126*cos(theta)**4 - 8.61360047832814e+123*cos(theta)**2 + 4.69150352850117e+120)*sin(64*phi)

#@torch.jit.script
def Yl88_m_minus_63(theta, phi):
    return 7.11679341372251e-120*(1.0 - cos(theta)**2)**31.5*(2.22261401665611e+134*cos(theta)**25 - 3.81019545712477e+134*cos(theta)**23 + 2.7860677764525e+134*cos(theta)**21 - 1.14049558100395e+134*cos(theta)**19 + 2.88498142532064e+133*cos(theta)**17 - 4.69889190231865e+132*cos(theta)**15 + 4.9836732297319e+131*cos(theta)**13 - 3.40689318071067e+130*cos(theta)**11 + 1.45480687064509e+129*cos(theta)**9 - 3.6598914984782e+127*cos(theta)**7 + 4.89539627184983e+125*cos(theta)**5 - 2.87120015944271e+123*cos(theta)**3 + 4.69150352850117e+120*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl88_m_minus_62(theta, phi):
    return 4.45922623989734e-118*(1.0 - cos(theta)**2)**31*(8.54851544867736e+132*cos(theta)**26 - 1.58758144046865e+133*cos(theta)**24 + 1.26639444384205e+133*cos(theta)**22 - 5.70247790501974e+132*cos(theta)**20 + 1.60276745851147e+132*cos(theta)**18 - 2.93680743894915e+131*cos(theta)**16 + 3.55976659266564e+130*cos(theta)**14 - 2.83907765059223e+129*cos(theta)**12 + 1.45480687064509e+128*cos(theta)**10 - 4.57486437309776e+126*cos(theta)**8 + 8.15899378641638e+124*cos(theta)**6 - 7.17800039860678e+122*cos(theta)**4 + 2.34575176425058e+120*cos(theta)**2 - 1.19498306889994e+117)*sin(62*phi)

#@torch.jit.script
def Yl88_m_minus_61(theta, phi):
    return 2.83783420176876e-116*(1.0 - cos(theta)**2)**30.5*(3.16611683284347e+131*cos(theta)**27 - 6.35032576187461e+131*cos(theta)**25 + 5.50606279931325e+131*cos(theta)**23 - 2.71546566905702e+131*cos(theta)**21 + 8.43561820269193e+130*cos(theta)**19 - 1.72753378761715e+130*cos(theta)**17 + 2.37317772844376e+129*cos(theta)**15 - 2.18390588507095e+128*cos(theta)**13 + 1.32255170058644e+127*cos(theta)**11 - 5.08318263677528e+125*cos(theta)**9 + 1.16557054091663e+124*cos(theta)**7 - 1.43560007972136e+122*cos(theta)**5 + 7.81917254750194e+119*cos(theta)**3 - 1.19498306889994e+117*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl88_m_minus_60(theta, phi):
    return 1.83298608656671e-114*(1.0 - cos(theta)**2)**30*(1.13075601172981e+130*cos(theta)**28 - 2.44243298533639e+130*cos(theta)**26 + 2.29419283304719e+130*cos(theta)**24 - 1.2343025768441e+130*cos(theta)**22 + 4.21780910134596e+129*cos(theta)**20 - 9.59740993120638e+128*cos(theta)**18 + 1.48323608027735e+128*cos(theta)**16 - 1.55993277505068e+127*cos(theta)**14 + 1.10212641715537e+126*cos(theta)**12 - 5.08318263677528e+124*cos(theta)**10 + 1.45696317614578e+123*cos(theta)**8 - 2.3926667995356e+121*cos(theta)**6 + 1.95479313687549e+119*cos(theta)**4 - 5.9749153444997e+116*cos(theta)**2 + 2.86429307022996e+113)*sin(60*phi)

#@torch.jit.script
def Yl88_m_minus_59(theta, phi):
    return 1.20085072628967e-112*(1.0 - cos(theta)**2)**29.5*(3.89915866113728e+128*cos(theta)**29 - 9.04604809383848e+128*cos(theta)**27 + 9.17677133218874e+128*cos(theta)**25 - 5.36653294280044e+128*cos(theta)**23 + 2.00848052445046e+128*cos(theta)**21 - 5.05126838484547e+127*cos(theta)**19 + 8.72491811927853e+126*cos(theta)**17 - 1.03995518336712e+126*cos(theta)**15 + 8.47789551657976e+124*cos(theta)**13 - 4.62107512434117e+123*cos(theta)**11 + 1.61884797349531e+122*cos(theta)**9 - 3.41809542790799e+120*cos(theta)**7 + 3.90958627375097e+118*cos(theta)**5 - 1.99163844816657e+116*cos(theta)**3 + 2.86429307022996e+113*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl88_m_minus_58(theta, phi):
    return 7.97458919237988e-111*(1.0 - cos(theta)**2)**29*(1.29971955371242e+127*cos(theta)**30 - 3.23073146208517e+127*cos(theta)**28 + 3.52952743545721e+127*cos(theta)**26 - 2.23605539283351e+127*cos(theta)**24 + 9.12945692932027e+126*cos(theta)**22 - 2.52563419242273e+126*cos(theta)**20 + 4.84717673293252e+125*cos(theta)**18 - 6.49971989604448e+124*cos(theta)**16 + 6.05563965469983e+123*cos(theta)**14 - 3.85089593695097e+122*cos(theta)**12 + 1.61884797349531e+121*cos(theta)**10 - 4.27261928488499e+119*cos(theta)**8 + 6.51597712291829e+117*cos(theta)**6 - 4.97909612041642e+115*cos(theta)**4 + 1.43214653511498e+113*cos(theta)**2 - 6.49499562410422e+109)*sin(58*phi)

#@torch.jit.script
def Yl88_m_minus_57(theta, phi):
    return 5.36494896000854e-109*(1.0 - cos(theta)**2)**28.5*(4.19264372165298e+125*cos(theta)**31 - 1.11404533175351e+126*cos(theta)**29 + 1.30723238350267e+126*cos(theta)**27 - 8.94422157133406e+125*cos(theta)**25 + 3.96932909970446e+125*cos(theta)**23 - 1.20268294877273e+125*cos(theta)**21 + 2.55114564891185e+124*cos(theta)**19 - 3.82336464473205e+123*cos(theta)**17 + 4.03709310313322e+122*cos(theta)**15 - 2.96222764380844e+121*cos(theta)**13 + 1.47167997590483e+120*cos(theta)**11 - 4.74735476098332e+118*cos(theta)**9 + 9.30853874702612e+116*cos(theta)**7 - 9.95819224083284e+114*cos(theta)**5 + 4.77382178371661e+112*cos(theta)**3 - 6.49499562410422e+109*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl88_m_minus_56(theta, phi):
    return 3.65447154693842e-107*(1.0 - cos(theta)**2)**28*(1.31020116301656e+124*cos(theta)**32 - 3.71348443917836e+124*cos(theta)**30 + 4.66868708393811e+124*cos(theta)**28 - 3.44008521974387e+124*cos(theta)**26 + 1.65388712487686e+124*cos(theta)**24 - 5.46674067623968e+123*cos(theta)**22 + 1.27557282445593e+123*cos(theta)**20 - 2.12409146929558e+122*cos(theta)**18 + 2.52318318945826e+121*cos(theta)**16 - 2.1158768884346e+120*cos(theta)**14 + 1.22639997992069e+119*cos(theta)**12 - 4.74735476098332e+117*cos(theta)**10 + 1.16356734337827e+116*cos(theta)**8 - 1.65969870680547e+114*cos(theta)**6 + 1.19345544592915e+112*cos(theta)**4 - 3.24749781205211e+109*cos(theta)**2 + 1.39978353967763e+106)*sin(56*phi)

#@torch.jit.script
def Yl88_m_minus_55(theta, phi):
    return 2.51920088896542e-105*(1.0 - cos(theta)**2)**27.5*(3.97030655459563e+122*cos(theta)**33 - 1.19789820618657e+123*cos(theta)**31 + 1.60989209790969e+123*cos(theta)**29 - 1.27410563694217e+123*cos(theta)**27 + 6.61554849950744e+122*cos(theta)**25 - 2.37684377227812e+122*cos(theta)**23 + 6.07415630693298e+121*cos(theta)**21 - 1.11794287857662e+121*cos(theta)**19 + 1.48422540556368e+120*cos(theta)**17 - 1.41058459228973e+119*cos(theta)**15 + 9.43384599938994e+117*cos(theta)**13 - 4.31577705543938e+116*cos(theta)**11 + 1.29285260375363e+115*cos(theta)**9 - 2.37099815257925e+113*cos(theta)**7 + 2.3869108918583e+111*cos(theta)**5 - 1.08249927068404e+109*cos(theta)**3 + 1.39978353967763e+106*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl88_m_minus_54(theta, phi):
    return 1.75658948261692e-103*(1.0 - cos(theta)**2)**27*(1.16773722193989e+121*cos(theta)**34 - 3.74343189433302e+121*cos(theta)**32 + 5.36630699303231e+121*cos(theta)**30 - 4.55037727479348e+121*cos(theta)**28 + 2.54444173057978e+121*cos(theta)**26 - 9.90351571782551e+120*cos(theta)**24 + 2.76098013951499e+120*cos(theta)**22 - 5.58971439288311e+119*cos(theta)**20 + 8.24569669757602e+118*cos(theta)**18 - 8.81615370181084e+117*cos(theta)**16 + 6.73846142813567e+116*cos(theta)**14 - 3.59648087953282e+115*cos(theta)**12 + 1.29285260375363e+114*cos(theta)**10 - 2.96374769072406e+112*cos(theta)**8 + 3.97818481976384e+110*cos(theta)**6 - 2.70624817671009e+108*cos(theta)**4 + 6.99891769838817e+105*cos(theta)**2 - 2.87902825931229e+102)*sin(54*phi)

#@torch.jit.script
def Yl88_m_minus_53(theta, phi):
    return 1.23836443964968e-101*(1.0 - cos(theta)**2)**26.5*(3.3363920626854e+119*cos(theta)**35 - 1.13437330131304e+120*cos(theta)**33 + 1.73106677194591e+120*cos(theta)**31 - 1.56909561199775e+120*cos(theta)**29 + 9.42385826140661e+119*cos(theta)**27 - 3.9614062871302e+119*cos(theta)**25 + 1.20042614761521e+119*cos(theta)**23 - 2.66176875851577e+118*cos(theta)**21 + 4.33984036714527e+117*cos(theta)**19 - 5.18597276577108e+116*cos(theta)**17 + 4.49230761875711e+115*cos(theta)**15 - 2.76652375348679e+114*cos(theta)**13 + 1.17532054886693e+113*cos(theta)**11 - 3.2930529896934e+111*cos(theta)**9 + 5.6831211710912e+109*cos(theta)**7 - 5.41249635342019e+107*cos(theta)**5 + 2.33297256612939e+105*cos(theta)**3 - 2.87902825931229e+102*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl88_m_minus_52(theta, phi):
    return 8.82285779089399e-100*(1.0 - cos(theta)**2)**26*(9.26775572968167e+117*cos(theta)**36 - 3.3363920626854e+118*cos(theta)**34 + 5.40958366233096e+118*cos(theta)**32 - 5.23031870665917e+118*cos(theta)**30 + 3.36566366478808e+118*cos(theta)**28 - 1.52361780274239e+118*cos(theta)**26 + 5.00177561506339e+117*cos(theta)**24 - 1.20989489023444e+117*cos(theta)**22 + 2.16992018357264e+116*cos(theta)**20 - 2.88109598098393e+115*cos(theta)**18 + 2.8076922617232e+114*cos(theta)**16 - 1.9760883953477e+113*cos(theta)**14 + 9.79433790722446e+111*cos(theta)**12 - 3.2930529896934e+110*cos(theta)**10 + 7.103901463864e+108*cos(theta)**8 - 9.02082725570031e+106*cos(theta)**6 + 5.83243141532348e+104*cos(theta)**4 - 1.43951412965614e+102*cos(theta)**2 + 5.67184448249072e+98)*sin(52*phi)

#@torch.jit.script
def Yl88_m_minus_51(theta, phi):
    return 6.35000634266923e-98*(1.0 - cos(theta)**2)**25.5*(2.50479884585991e+116*cos(theta)**37 - 9.53254875052972e+116*cos(theta)**35 + 1.63926777646393e+117*cos(theta)**33 - 1.68719958279328e+117*cos(theta)**31 + 1.16057367751313e+117*cos(theta)**29 - 5.64302889904587e+116*cos(theta)**27 + 2.00071024602536e+116*cos(theta)**25 - 5.26041256623669e+115*cos(theta)**23 + 1.03329532551078e+115*cos(theta)**21 - 1.51636630578102e+114*cos(theta)**19 + 1.65158368336659e+113*cos(theta)**17 - 1.31739226356514e+112*cos(theta)**15 + 7.53410608248035e+110*cos(theta)**13 - 2.99368453608491e+109*cos(theta)**11 + 7.89322384873777e+107*cos(theta)**9 - 1.28868960795719e+106*cos(theta)**7 + 1.1664862830647e+104*cos(theta)**5 - 4.79838043218715e+101*cos(theta)**3 + 5.67184448249072e+98*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl88_m_minus_50(theta, phi):
    return 4.61501755657922e-96*(1.0 - cos(theta)**2)**25*(6.59157591015766e+114*cos(theta)**38 - 2.64793020848048e+115*cos(theta)**36 + 4.82137581312919e+115*cos(theta)**34 - 5.272498696229e+115*cos(theta)**32 + 3.86857892504376e+115*cos(theta)**30 - 2.01536746394496e+115*cos(theta)**28 + 7.69503940778983e+114*cos(theta)**26 - 2.19183856926529e+114*cos(theta)**24 + 4.6967969341399e+113*cos(theta)**22 - 7.58183152890509e+112*cos(theta)**20 + 9.17546490759214e+111*cos(theta)**18 - 8.2337016472821e+110*cos(theta)**16 + 5.38150434462882e+109*cos(theta)**14 - 2.49473711340409e+108*cos(theta)**12 + 7.89322384873777e+106*cos(theta)**10 - 1.61086200994648e+105*cos(theta)**8 + 1.94414380510783e+103*cos(theta)**6 - 1.19959510804679e+101*cos(theta)**4 + 2.83592224124536e+98*cos(theta)**2 - 1.07380622538635e+95)*sin(50*phi)

#@torch.jit.script
def Yl88_m_minus_49(theta, phi):
    return 3.38567451314845e-94*(1.0 - cos(theta)**2)**24.5*(1.6901476692712e+113*cos(theta)**39 - 7.15656813102832e+113*cos(theta)**37 + 1.37753594660834e+114*cos(theta)**35 - 1.59772687764515e+114*cos(theta)**33 + 1.24792868549799e+114*cos(theta)**31 - 6.94954297912053e+113*cos(theta)**29 + 2.85001459547771e+113*cos(theta)**27 - 8.76735427706115e+112*cos(theta)**25 + 2.04208562353909e+112*cos(theta)**23 - 3.61039596614528e+111*cos(theta)**21 + 4.82919205662744e+110*cos(theta)**19 - 4.84335391016594e+109*cos(theta)**17 + 3.58766956308588e+108*cos(theta)**15 - 1.91902854877238e+107*cos(theta)**13 + 7.17565804430707e+105*cos(theta)**11 - 1.78984667771832e+104*cos(theta)**9 + 2.77734829301118e+102*cos(theta)**7 - 2.39919021609357e+100*cos(theta)**5 + 9.45307413748453e+97*cos(theta)**3 - 1.07380622538635e+95*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl88_m_minus_48(theta, phi):
    return 2.50631401985519e-92*(1.0 - cos(theta)**2)**24*(4.22536917317799e+111*cos(theta)**40 - 1.88330740290219e+112*cos(theta)**38 + 3.82648874057873e+112*cos(theta)**36 - 4.69919669895633e+112*cos(theta)**34 + 3.89977714218121e+112*cos(theta)**32 - 2.31651432637351e+112*cos(theta)**30 + 1.01786235552776e+112*cos(theta)**28 - 3.37205933733121e+111*cos(theta)**26 + 8.50869009807954e+110*cos(theta)**24 - 1.64108907552058e+110*cos(theta)**22 + 2.41459602831372e+109*cos(theta)**20 - 2.69075217231441e+108*cos(theta)**18 + 2.24229347692868e+107*cos(theta)**16 - 1.37073467769455e+106*cos(theta)**14 + 5.97971503692256e+104*cos(theta)**12 - 1.78984667771832e+103*cos(theta)**10 + 3.47168536626397e+101*cos(theta)**8 - 3.99865036015596e+99*cos(theta)**6 + 2.36326853437113e+97*cos(theta)**4 - 5.36903112693177e+94*cos(theta)**2 + 1.95950041128897e+91)*sin(48*phi)

#@torch.jit.script
def Yl88_m_minus_47(theta, phi):
    return 1.87153031423753e-90*(1.0 - cos(theta)**2)**23.5*(1.03057784711658e+110*cos(theta)**41 - 4.82899334077484e+110*cos(theta)**39 + 1.03418614610236e+111*cos(theta)**37 - 1.34262762827324e+111*cos(theta)**35 + 1.18175064914582e+111*cos(theta)**33 - 7.47262685926939e+110*cos(theta)**31 + 3.50987019147502e+110*cos(theta)**29 - 1.24891086567823e+110*cos(theta)**27 + 3.40347603923181e+109*cos(theta)**25 - 7.13516989356775e+108*cos(theta)**23 + 1.14980763253034e+108*cos(theta)**21 - 1.41618535384969e+107*cos(theta)**19 + 1.31899616289922e+106*cos(theta)**17 - 9.13823118463037e+104*cos(theta)**15 + 4.59978079763274e+103*cos(theta)**13 - 1.62713334338029e+102*cos(theta)**11 + 3.85742818473775e+100*cos(theta)**9 - 5.71235765736565e+98*cos(theta)**7 + 4.72653706874226e+96*cos(theta)**5 - 1.78967704231059e+94*cos(theta)**3 + 1.95950041128897e+91*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl88_m_minus_46(theta, phi):
    return 1.40925114213237e-88*(1.0 - cos(theta)**2)**23*(2.45375677884901e+108*cos(theta)**42 - 1.20724833519371e+109*cos(theta)**40 + 2.72154248974305e+109*cos(theta)**38 - 3.72952118964788e+109*cos(theta)**36 + 3.47573720337007e+109*cos(theta)**34 - 2.33519589352168e+109*cos(theta)**32 + 1.16995673049167e+109*cos(theta)**30 - 4.46039594885081e+108*cos(theta)**28 + 1.30902924585839e+108*cos(theta)**26 - 2.97298745565323e+107*cos(theta)**24 + 5.22639832968338e+106*cos(theta)**22 - 7.08092676924845e+105*cos(theta)**20 + 7.32775646055123e+104*cos(theta)**18 - 5.71139449039398e+103*cos(theta)**16 + 3.28555771259481e+102*cos(theta)**14 - 1.35594445281691e+101*cos(theta)**12 + 3.85742818473775e+99*cos(theta)**10 - 7.14044707170706e+97*cos(theta)**8 + 7.87756178123711e+95*cos(theta)**6 - 4.47419260577647e+93*cos(theta)**4 + 9.79750205644483e+90*cos(theta)**2 - 3.45590901461899e+87)*sin(46*phi)

#@torch.jit.script
def Yl88_m_minus_45(theta, phi):
    return 1.06973208606581e-86*(1.0 - cos(theta)**2)**22.5*(5.70641111360234e+106*cos(theta)**43 - 2.94450813461881e+107*cos(theta)**41 + 6.97831407626423e+107*cos(theta)**39 - 1.00797869990483e+108*cos(theta)**37 + 9.93067772391447e+107*cos(theta)**35 - 7.07635119248995e+107*cos(theta)**33 + 3.77405396932798e+107*cos(theta)**31 - 1.53806756856925e+107*cos(theta)**29 + 4.84825646614219e+106*cos(theta)**27 - 1.18919498226129e+106*cos(theta)**25 + 2.27234709986234e+105*cos(theta)**23 - 3.37186989011831e+104*cos(theta)**21 + 3.85671392660591e+103*cos(theta)**19 - 3.35964381787881e+102*cos(theta)**17 + 2.19037180839654e+101*cos(theta)**15 - 1.04303419447454e+100*cos(theta)**13 + 3.50675289521614e+98*cos(theta)**11 - 7.93383007967452e+96*cos(theta)**9 + 1.12536596874816e+95*cos(theta)**7 - 8.94838521155294e+92*cos(theta)**5 + 3.26583401881494e+90*cos(theta)**3 - 3.45590901461899e+87*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl88_m_minus_44(theta, phi):
    return 8.18327566371218e-85*(1.0 - cos(theta)**2)**22*(1.2969116167278e+105*cos(theta)**44 - 7.0107336538543e+105*cos(theta)**42 + 1.74457851906606e+106*cos(theta)**40 - 2.65257552606535e+106*cos(theta)**38 + 2.75852158997624e+106*cos(theta)**36 - 2.08127976249705e+106*cos(theta)**34 + 1.17939186541499e+106*cos(theta)**32 - 5.12689189523082e+105*cos(theta)**30 + 1.73152016647935e+105*cos(theta)**28 - 4.57382685485112e+104*cos(theta)**26 + 9.46811291609308e+103*cos(theta)**24 - 1.53266813187196e+103*cos(theta)**22 + 1.92835696330296e+102*cos(theta)**20 - 1.86646878771045e+101*cos(theta)**18 + 1.36898238024784e+100*cos(theta)**16 - 7.45024424624674e+98*cos(theta)**14 + 2.92229407934678e+97*cos(theta)**12 - 7.93383007967452e+95*cos(theta)**10 + 1.4067074609352e+94*cos(theta)**8 - 1.49139753525882e+92*cos(theta)**6 + 8.16458504703736e+89*cos(theta)**4 - 1.72795450730949e+87*cos(theta)**2 + 5.90551779668316e+83)*sin(44*phi)

#@torch.jit.script
def Yl88_m_minus_43(theta, phi):
    return 6.30696474934279e-83*(1.0 - cos(theta)**2)**21.5*(2.88202581495068e+103*cos(theta)**45 - 1.63040317531495e+104*cos(theta)**43 + 4.2550695586977e+104*cos(theta)**41 - 6.80147570785987e+104*cos(theta)**39 + 7.45546375669255e+104*cos(theta)**37 - 5.94651360713442e+104*cos(theta)**35 + 3.5739147436818e+104*cos(theta)**33 - 1.65383609523575e+104*cos(theta)**31 + 5.97075919475639e+103*cos(theta)**29 - 1.69400994624116e+103*cos(theta)**27 + 3.78724516643723e+102*cos(theta)**25 - 6.66377448639982e+101*cos(theta)**23 + 9.18265220620455e+100*cos(theta)**21 - 9.82351993531816e+99*cos(theta)**19 + 8.05283753086963e+98*cos(theta)**17 - 4.96682949749782e+97*cos(theta)**15 + 2.24791852257445e+96*cos(theta)**13 - 7.2125727997041e+94*cos(theta)**11 + 1.563008289928e+93*cos(theta)**9 - 2.13056790751261e+91*cos(theta)**7 + 1.63291700940747e+89*cos(theta)**5 - 5.75984835769831e+86*cos(theta)**3 + 5.90551779668316e+83*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl88_m_minus_42(theta, phi):
    return 4.89592737905498e-81*(1.0 - cos(theta)**2)**21*(6.26527351076234e+101*cos(theta)**46 - 3.70546176207944e+102*cos(theta)**44 + 1.01311179968993e+103*cos(theta)**42 - 1.70036892696497e+103*cos(theta)**40 + 1.96196414649804e+103*cos(theta)**38 - 1.65180933531512e+103*cos(theta)**36 + 1.05115139520053e+103*cos(theta)**34 - 5.16823779761171e+102*cos(theta)**32 + 1.9902530649188e+102*cos(theta)**30 - 6.05003552228984e+101*cos(theta)**28 + 1.45663275632201e+101*cos(theta)**26 - 2.77657270266659e+100*cos(theta)**24 + 4.17393282100207e+99*cos(theta)**22 - 4.91175996765908e+98*cos(theta)**20 + 4.47379862826091e+97*cos(theta)**18 - 3.10426843593614e+96*cos(theta)**16 + 1.60565608755318e+95*cos(theta)**14 - 6.01047733308675e+93*cos(theta)**12 + 1.563008289928e+92*cos(theta)**10 - 2.66320988439076e+90*cos(theta)**8 + 2.72152834901245e+88*cos(theta)**6 - 1.43996208942458e+86*cos(theta)**4 + 2.95275889834158e+83*cos(theta)**2 - 9.80006272267369e+79)*sin(42*phi)

#@torch.jit.script
def Yl88_m_minus_41(theta, phi):
    return 3.82697453538678e-79*(1.0 - cos(theta)**2)**20.5*(1.33303691718348e+100*cos(theta)**47 - 8.23435947128765e+100*cos(theta)**45 + 2.35607395276727e+101*cos(theta)**43 - 4.14724128528041e+101*cos(theta)**41 + 5.03067729871292e+101*cos(theta)**39 - 4.46434955490572e+101*cos(theta)**37 + 3.00328970057294e+101*cos(theta)**35 - 1.56613266594294e+101*cos(theta)**33 + 6.42017117715741e+100*cos(theta)**31 - 2.08621914561719e+100*cos(theta)**29 + 5.39493613452597e+99*cos(theta)**27 - 1.11062908106664e+99*cos(theta)**25 + 1.81475340043568e+98*cos(theta)**23 - 2.3389333179329e+97*cos(theta)**21 + 2.35463085697943e+96*cos(theta)**19 - 1.82604025643302e+95*cos(theta)**17 + 1.07043739170212e+94*cos(theta)**15 - 4.62344410237443e+92*cos(theta)**13 + 1.42091662720727e+91*cos(theta)**11 - 2.95912209376751e+89*cos(theta)**9 + 3.88789764144636e+87*cos(theta)**7 - 2.87992417884916e+85*cos(theta)**5 + 9.84252966113861e+82*cos(theta)**3 - 9.80006272267369e+79*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl88_m_minus_40(theta, phi):
    return 3.01141802998416e-77*(1.0 - cos(theta)**2)**20*(2.77716024413224e+98*cos(theta)**48 - 1.7900781459321e+99*cos(theta)**46 + 5.35471352901653e+99*cos(theta)**44 - 9.8743840125724e+99*cos(theta)**42 + 1.25766932467823e+100*cos(theta)**40 - 1.17482883023835e+100*cos(theta)**38 + 8.34247139048038e+99*cos(theta)**36 - 4.60627254689101e+99*cos(theta)**34 + 2.00630349286169e+99*cos(theta)**32 - 6.95406381872395e+98*cos(theta)**30 + 1.92676290518785e+98*cos(theta)**28 - 4.27165031179476e+97*cos(theta)**26 + 7.56147250181534e+96*cos(theta)**24 - 1.06315150815132e+96*cos(theta)**22 + 1.17731542848971e+95*cos(theta)**20 - 1.01446680912946e+94*cos(theta)**18 + 6.69023369813823e+92*cos(theta)**16 - 3.30246007312459e+91*cos(theta)**14 + 1.18409718933939e+90*cos(theta)**12 - 2.95912209376751e+88*cos(theta)**10 + 4.85987205180795e+86*cos(theta)**8 - 4.79987363141526e+84*cos(theta)**6 + 2.46063241528465e+82*cos(theta)**4 - 4.90003136133684e+79*cos(theta)**2 + 1.58269746813206e+76)*sin(40*phi)

#@torch.jit.script
def Yl88_m_minus_39(theta, phi):
    return 2.38492140318794e-75*(1.0 - cos(theta)**2)**19.5*(5.66767396761682e+96*cos(theta)**49 - 3.80867690623851e+97*cos(theta)**47 + 1.18993633978145e+98*cos(theta)**45 - 2.29636837501684e+98*cos(theta)**43 + 3.06748615775178e+98*cos(theta)**41 - 3.01238161599576e+98*cos(theta)**39 + 2.25472199742713e+98*cos(theta)**37 - 1.31607787054029e+98*cos(theta)**35 + 6.07970755412633e+97*cos(theta)**33 - 2.24324639313676e+97*cos(theta)**31 + 6.64401001788913e+96*cos(theta)**29 - 1.58209270807213e+96*cos(theta)**27 + 3.02458900072614e+95*cos(theta)**25 - 4.62239786152746e+94*cos(theta)**23 + 5.60626394518911e+93*cos(theta)**21 - 5.3392989954182e+92*cos(theta)**19 + 3.93543158714014e+91*cos(theta)**17 - 2.20164004874973e+90*cos(theta)**15 + 9.10843991799532e+88*cos(theta)**13 - 2.6901109943341e+87*cos(theta)**11 + 5.39985783534217e+85*cos(theta)**9 - 6.85696233059323e+83*cos(theta)**7 + 4.9212648305693e+81*cos(theta)**5 - 1.63334378711228e+79*cos(theta)**3 + 1.58269746813206e+76*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl88_m_minus_38(theta, phi):
    return 1.90046962962022e-73*(1.0 - cos(theta)**2)**19*(1.13353479352336e+95*cos(theta)**50 - 7.93474355466355e+95*cos(theta)**48 + 2.58681812995968e+96*cos(theta)**46 - 5.21901903412917e+96*cos(theta)**44 + 7.30353847083757e+96*cos(theta)**42 - 7.5309540399894e+96*cos(theta)**40 + 5.93347894059771e+96*cos(theta)**38 - 3.65577186261191e+96*cos(theta)**36 + 1.78814928062539e+96*cos(theta)**34 - 7.01014497855237e+95*cos(theta)**32 + 2.21467000596304e+95*cos(theta)**30 - 5.65033110025762e+94*cos(theta)**28 + 1.16330346181774e+94*cos(theta)**26 - 1.92599910896978e+93*cos(theta)**24 + 2.54830179326778e+92*cos(theta)**22 - 2.6696494977091e+91*cos(theta)**20 + 2.18635088174452e+90*cos(theta)**18 - 1.37602503046858e+89*cos(theta)**16 + 6.5060285128538e+87*cos(theta)**14 - 2.24175916194508e+86*cos(theta)**12 + 5.39985783534217e+84*cos(theta)**10 - 8.57120291324154e+82*cos(theta)**8 + 8.20210805094884e+80*cos(theta)**6 - 4.0833594677807e+78*cos(theta)**4 + 7.91348734066028e+75*cos(theta)**2 - 2.49243695768828e+72)*sin(38*phi)

#@torch.jit.script
def Yl88_m_minus_37(theta, phi):
    return 1.52346083668197e-71*(1.0 - cos(theta)**2)**18.5*(2.22261724220268e+93*cos(theta)**51 - 1.61933541931909e+94*cos(theta)**49 + 5.50386836161634e+94*cos(theta)**47 - 1.15978200758426e+95*cos(theta)**45 + 1.69849731879944e+95*cos(theta)**43 - 1.836818058534e+95*cos(theta)**41 + 1.52140485656352e+95*cos(theta)**39 - 9.88046449354571e+94*cos(theta)**37 + 5.10899794464398e+94*cos(theta)**35 - 2.12428635713708e+94*cos(theta)**33 + 7.14409679342917e+93*cos(theta)**31 - 1.94839003457159e+93*cos(theta)**29 + 4.30853134006572e+92*cos(theta)**27 - 7.7039964358791e+91*cos(theta)**25 + 1.10795730142077e+91*cos(theta)**23 - 1.27126166557576e+90*cos(theta)**21 + 1.15071099039185e+89*cos(theta)**19 - 8.09426488510929e+87*cos(theta)**17 + 4.33735234190254e+86*cos(theta)**15 - 1.72443012457314e+85*cos(theta)**13 + 4.90896166849288e+83*cos(theta)**11 - 9.5235587924906e+81*cos(theta)**9 + 1.17172972156412e+80*cos(theta)**7 - 8.16671893556141e+77*cos(theta)**5 + 2.63782911355343e+75*cos(theta)**3 - 2.49243695768828e+72*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl88_m_minus_36(theta, phi):
    return 1.22825339347686e-69*(1.0 - cos(theta)**2)**18*(4.27426392731284e+91*cos(theta)**52 - 3.23867083863818e+92*cos(theta)**50 + 1.1466392420034e+93*cos(theta)**48 - 2.52126523387883e+93*cos(theta)**46 + 3.86022117908963e+93*cos(theta)**44 - 4.37337632984286e+93*cos(theta)**42 + 3.80351214140879e+93*cos(theta)**40 - 2.60012223514361e+93*cos(theta)**38 + 1.41916609573444e+93*cos(theta)**36 - 6.24790105040318e+92*cos(theta)**34 + 2.23253024794662e+92*cos(theta)**32 - 6.49463344857197e+91*cos(theta)**30 + 1.53876119288061e+91*cos(theta)**28 - 2.96307555226119e+90*cos(theta)**26 + 4.61648875591988e+89*cos(theta)**24 - 5.77846211625346e+88*cos(theta)**22 + 5.75355495195926e+87*cos(theta)**20 - 4.49681382506072e+86*cos(theta)**18 + 2.71084521368908e+85*cos(theta)**16 - 1.23173580326653e+84*cos(theta)**14 + 4.09080139041073e+82*cos(theta)**12 - 9.5235587924906e+80*cos(theta)**10 + 1.46466215195515e+79*cos(theta)**8 - 1.36111982259357e+77*cos(theta)**6 + 6.59457278388356e+74*cos(theta)**4 - 1.24621847884414e+72*cos(theta)**2 + 3.8345183964435e+68)*sin(36*phi)

#@torch.jit.script
def Yl88_m_minus_35(theta, phi):
    return 9.9571889866149e-68*(1.0 - cos(theta)**2)**17.5*(8.06464891945818e+89*cos(theta)**53 - 6.35033497772193e+90*cos(theta)**51 + 2.34008008572123e+91*cos(theta)**49 - 5.36439411463581e+91*cos(theta)**47 + 8.57826928686584e+91*cos(theta)**45 - 1.01706426275415e+92*cos(theta)**43 + 9.27685888148485e+91*cos(theta)**41 - 6.66698009011181e+91*cos(theta)**39 + 3.83558404252551e+91*cos(theta)**37 - 1.78511458582948e+91*cos(theta)**35 + 6.7652431755958e+90*cos(theta)**33 - 2.09504304792644e+90*cos(theta)**31 + 5.30607307889867e+89*cos(theta)**29 - 1.09743538972637e+89*cos(theta)**27 + 1.84659550236795e+88*cos(theta)**25 - 2.51237483315368e+87*cos(theta)**23 + 2.73978807236155e+86*cos(theta)**21 - 2.36674411845301e+85*cos(theta)**19 + 1.59461483158181e+84*cos(theta)**17 - 8.21157202177686e+82*cos(theta)**15 + 3.14677030031595e+81*cos(theta)**13 - 8.657780720446e+79*cos(theta)**11 + 1.62740239106128e+78*cos(theta)**9 - 1.94445688941938e+76*cos(theta)**7 + 1.31891455677671e+74*cos(theta)**5 - 4.15406159614713e+71*cos(theta)**3 + 3.8345183964435e+68*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl88_m_minus_34(theta, phi):
    return 8.11495630503163e-66*(1.0 - cos(theta)**2)**17*(1.49345350360337e+88*cos(theta)**54 - 1.22121826494653e+89*cos(theta)**52 + 4.68016017144246e+89*cos(theta)**50 - 1.11758210721579e+90*cos(theta)**48 + 1.86484114931866e+90*cos(theta)**46 - 2.31150968807762e+90*cos(theta)**44 + 2.20877592416306e+90*cos(theta)**42 - 1.66674502252795e+90*cos(theta)**40 + 1.00936422171724e+90*cos(theta)**38 - 4.95865162730411e+89*cos(theta)**36 + 1.989777404587e+89*cos(theta)**34 - 6.54700952477013e+88*cos(theta)**32 + 1.76869102629956e+88*cos(theta)**30 - 3.9194121061656e+87*cos(theta)**28 + 7.1022903937229e+86*cos(theta)**26 - 1.04682284714737e+86*cos(theta)**24 + 1.2453582147098e+85*cos(theta)**22 - 1.1833720592265e+84*cos(theta)**20 + 8.85897128656564e+82*cos(theta)**18 - 5.13223251361054e+81*cos(theta)**16 + 2.24769307165425e+80*cos(theta)**14 - 7.21481726703833e+78*cos(theta)**12 + 1.62740239106128e+77*cos(theta)**10 - 2.43057111177423e+75*cos(theta)**8 + 2.19819092796119e+73*cos(theta)**6 - 1.03851539903678e+71*cos(theta)**4 + 1.91725919822175e+68*cos(theta)**2 - 5.77313820602755e+64)*sin(34*phi)

#@torch.jit.script
def Yl88_m_minus_33(theta, phi):
    return 6.64733315876798e-64*(1.0 - cos(theta)**2)**16.5*(2.71537000655158e+86*cos(theta)**55 - 2.30418540555948e+87*cos(theta)**53 + 9.17678464988718e+87*cos(theta)**51 - 2.28077981064448e+88*cos(theta)**49 + 3.96774712620992e+88*cos(theta)**47 - 5.13668819572805e+88*cos(theta)**45 + 5.13668819572805e+88*cos(theta)**43 - 4.0652317622633e+88*cos(theta)**41 + 2.58811338901856e+88*cos(theta)**39 - 1.3401761154876e+88*cos(theta)**37 + 5.68507829882e+87*cos(theta)**35 - 1.98394228023337e+87*cos(theta)**33 + 5.70545492354696e+86*cos(theta)**31 - 1.35152141591917e+86*cos(theta)**29 + 2.63047792360107e+85*cos(theta)**27 - 4.18729138858946e+84*cos(theta)**25 + 5.41460093352086e+83*cos(theta)**23 - 5.63510504393574e+82*cos(theta)**21 + 4.66261646661349e+81*cos(theta)**19 - 3.01896030212384e+80*cos(theta)**17 + 1.4984620477695e+79*cos(theta)**15 - 5.54985943618333e+77*cos(theta)**13 + 1.47945671914662e+76*cos(theta)**11 - 2.70063456863803e+74*cos(theta)**9 + 3.14027275423027e+72*cos(theta)**7 - 2.07703079807356e+70*cos(theta)**5 + 6.3908639940725e+67*cos(theta)**3 - 5.77313820602755e+64*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl88_m_minus_32(theta, phi):
    return 5.47184950748734e-62*(1.0 - cos(theta)**2)**16*(4.84887501169925e+84*cos(theta)**56 - 4.26701001029534e+85*cos(theta)**54 + 1.76476627882446e+86*cos(theta)**52 - 4.56155962128895e+86*cos(theta)**50 + 8.26613984627066e+86*cos(theta)**48 - 1.1166713468974e+87*cos(theta)**46 + 1.16742913539274e+87*cos(theta)**44 - 9.67912324348405e+86*cos(theta)**42 + 6.4702834725464e+86*cos(theta)**40 - 3.52677925128315e+86*cos(theta)**38 + 1.57918841633889e+86*cos(theta)**36 - 5.83512435362757e+85*cos(theta)**34 + 1.78295466360842e+85*cos(theta)**32 - 4.50507138639724e+84*cos(theta)**30 + 9.39456401286098e+83*cos(theta)**28 - 1.61049668791902e+83*cos(theta)**26 + 2.25608372230036e+82*cos(theta)**24 - 2.56141138360715e+81*cos(theta)**22 + 2.33130823330675e+80*cos(theta)**20 - 1.67720016784658e+79*cos(theta)**18 + 9.36538779855937e+77*cos(theta)**16 - 3.96418531155952e+76*cos(theta)**14 + 1.23288059928885e+75*cos(theta)**12 - 2.70063456863803e+73*cos(theta)**10 + 3.92534094278784e+71*cos(theta)**8 - 3.46171799678927e+69*cos(theta)**6 + 1.59771599851813e+67*cos(theta)**4 - 2.88656910301378e+64*cos(theta)**2 + 8.51997964289781e+60)*sin(32*phi)

#@torch.jit.script
def Yl88_m_minus_31(theta, phi):
    return 4.52545442251838e-60*(1.0 - cos(theta)**2)**15.5*(8.50679826613903e+82*cos(theta)**57 - 7.75820001871879e+83*cos(theta)**55 + 3.3297476958952e+84*cos(theta)**53 - 8.94423455154696e+84*cos(theta)**51 + 1.68696731556544e+85*cos(theta)**49 - 2.37589648276043e+85*cos(theta)**47 + 2.59428696753942e+85*cos(theta)**45 - 2.2509588938335e+85*cos(theta)**43 + 1.57811792013327e+85*cos(theta)**41 - 9.04302372123886e+84*cos(theta)**39 + 4.26807680091592e+84*cos(theta)**37 - 1.66717838675073e+84*cos(theta)**35 + 5.40289292002553e+83*cos(theta)**33 - 1.45324883432169e+83*cos(theta)**31 + 3.23950483202103e+82*cos(theta)**29 - 5.96480254784824e+81*cos(theta)**27 + 9.02433488920143e+80*cos(theta)**25 - 1.11365712330746e+80*cos(theta)**23 + 1.11014677776512e+79*cos(theta)**21 - 8.82736930445568e+77*cos(theta)**19 + 5.50905164621139e+76*cos(theta)**17 - 2.64279020770635e+75*cos(theta)**15 + 9.48369691760651e+73*cos(theta)**13 - 2.45512233512548e+72*cos(theta)**11 + 4.36148993643093e+70*cos(theta)**9 - 4.94531142398467e+68*cos(theta)**7 + 3.19543199703625e+66*cos(theta)**5 - 9.62189701004592e+63*cos(theta)**3 + 8.51997964289781e+60*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl88_m_minus_30(theta, phi):
    return 3.7596695308826e-58*(1.0 - cos(theta)**2)**15*(1.46668935623087e+81*cos(theta)**58 - 1.3853928604855e+82*cos(theta)**56 + 6.16619943684297e+82*cos(theta)**54 - 1.72004510606672e+83*cos(theta)**52 + 3.37393463113088e+83*cos(theta)**50 - 4.94978433908423e+83*cos(theta)**48 + 5.6397542772596e+83*cos(theta)**46 - 5.11581566780341e+83*cos(theta)**44 + 3.75742361936493e+83*cos(theta)**42 - 2.26075593030971e+83*cos(theta)**40 + 1.12317810550419e+83*cos(theta)**38 - 4.6310510743076e+82*cos(theta)**36 + 1.58908615294868e+82*cos(theta)**34 - 4.54140260725528e+81*cos(theta)**32 + 1.07983494400701e+81*cos(theta)**30 - 2.13028662423151e+80*cos(theta)**28 + 3.47089803430824e+79*cos(theta)**26 - 4.64023801378107e+78*cos(theta)**24 + 5.04612171711417e+77*cos(theta)**22 - 4.41368465222784e+76*cos(theta)**20 + 3.06058424789522e+75*cos(theta)**18 - 1.65174387981647e+74*cos(theta)**16 + 6.77406922686179e+72*cos(theta)**14 - 2.04593527927124e+71*cos(theta)**12 + 4.36148993643093e+69*cos(theta)**10 - 6.18163927998084e+67*cos(theta)**8 + 5.32571999506042e+65*cos(theta)**6 - 2.40547425251148e+63*cos(theta)**4 + 4.2599898214489e+60*cos(theta)**2 - 1.23442185495477e+57)*sin(30*phi)

#@torch.jit.script
def Yl88_m_minus_29(theta, phi):
    return 3.13701562796289e-56*(1.0 - cos(theta)**2)**14.5*(2.48591416310316e+79*cos(theta)**59 - 2.43051379032544e+80*cos(theta)**57 + 1.12112717033509e+81*cos(theta)**55 - 3.2453681246542e+81*cos(theta)**53 + 6.61555810025663e+81*cos(theta)**51 - 1.01016006920086e+82*cos(theta)**49 + 1.19994771856587e+82*cos(theta)**47 - 1.13684792617854e+82*cos(theta)**45 + 8.73819446363936e+81*cos(theta)**43 - 5.51403885441394e+81*cos(theta)**41 + 2.87994386026715e+81*cos(theta)**39 - 1.25163542548854e+81*cos(theta)**37 + 4.54024615128196e+80*cos(theta)**35 - 1.37618260825918e+80*cos(theta)**33 + 3.48333852905487e+79*cos(theta)**31 - 7.34581594562591e+78*cos(theta)**29 + 1.28551779048453e+78*cos(theta)**27 - 1.85609520551243e+77*cos(theta)**25 + 2.19396596396268e+76*cos(theta)**23 - 2.10175459629897e+75*cos(theta)**21 + 1.61083381468169e+74*cos(theta)**19 - 9.71614046950863e+72*cos(theta)**17 + 4.5160461512412e+71*cos(theta)**15 - 1.57379636867018e+70*cos(theta)**13 + 3.96499085130084e+68*cos(theta)**11 - 6.8684880888676e+66*cos(theta)**9 + 7.60817142151488e+64*cos(theta)**7 - 4.81094850502296e+62*cos(theta)**5 + 1.41999660714963e+60*cos(theta)**3 - 1.23442185495477e+57*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl88_m_minus_28(theta, phi):
    return 2.6283623549957e-54*(1.0 - cos(theta)**2)**14*(4.14319027183861e+77*cos(theta)**60 - 4.19054101780248e+78*cos(theta)**58 + 2.0020128041698e+79*cos(theta)**56 - 6.00994097158184e+79*cos(theta)**54 + 1.27222271158781e+80*cos(theta)**52 - 2.02032013840172e+80*cos(theta)**50 + 2.49989108034557e+80*cos(theta)**48 - 2.47140853517073e+80*cos(theta)**46 + 1.98595328719076e+80*cos(theta)**44 - 1.31286639390808e+80*cos(theta)**42 + 7.19985965066788e+79*cos(theta)**40 - 3.29377743549616e+79*cos(theta)**38 + 1.26117948646721e+79*cos(theta)**36 - 4.04759590664464e+78*cos(theta)**34 + 1.08854329032965e+78*cos(theta)**32 - 2.44860531520864e+77*cos(theta)**30 + 4.59113496601619e+76*cos(theta)**28 - 7.13882771350934e+75*cos(theta)**26 + 9.14152484984451e+74*cos(theta)**24 - 9.55342998317715e+73*cos(theta)**22 + 8.05416907340847e+72*cos(theta)**20 - 5.39785581639368e+71*cos(theta)**18 + 2.82252884452575e+70*cos(theta)**16 - 1.12414026333584e+69*cos(theta)**14 + 3.3041590427507e+67*cos(theta)**12 - 6.8684880888676e+65*cos(theta)**10 + 9.5102142768936e+63*cos(theta)**8 - 8.0182475083716e+61*cos(theta)**6 + 3.54999151787409e+59*cos(theta)**4 - 6.17210927477384e+56*cos(theta)**2 + 1.75843569081876e+53)*sin(28*phi)

#@torch.jit.script
def Yl88_m_minus_27(theta, phi):
    return 2.21095116687289e-52*(1.0 - cos(theta)**2)**13.5*(6.79211519973542e+75*cos(theta)**61 - 7.10261189458047e+76*cos(theta)**59 + 3.51230316521017e+77*cos(theta)**57 - 1.09271654028761e+78*cos(theta)**55 + 2.40042021054304e+78*cos(theta)**53 - 3.96141203608181e+78*cos(theta)**51 + 5.10181853131749e+78*cos(theta)**49 - 5.25831603227815e+78*cos(theta)**47 + 4.41322952709059e+78*cos(theta)**45 - 3.05317766025135e+78*cos(theta)**43 + 1.75606332943119e+78*cos(theta)**41 - 8.44558316793886e+77*cos(theta)**39 + 3.40859320666814e+77*cos(theta)**37 - 1.15645597332704e+77*cos(theta)**35 + 3.29861603130196e+76*cos(theta)**33 - 7.89872682325367e+75*cos(theta)**31 + 1.58314998828145e+75*cos(theta)**29 - 2.64401026426272e+74*cos(theta)**27 + 3.6566099399378e+73*cos(theta)**25 - 4.15366521007702e+72*cos(theta)**23 + 3.83531860638499e+71*cos(theta)**21 - 2.84097674547036e+70*cos(theta)**19 + 1.66031108501515e+69*cos(theta)**17 - 7.49426842223896e+67*cos(theta)**15 + 2.54166080211593e+66*cos(theta)**13 - 6.24408008078873e+64*cos(theta)**11 + 1.0566904752104e+63*cos(theta)**9 - 1.14546392976737e+61*cos(theta)**7 + 7.09998303574817e+58*cos(theta)**5 - 2.05736975825795e+56*cos(theta)**3 + 1.75843569081876e+53*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl88_m_minus_26(theta, phi):
    return 1.86691229290973e-50*(1.0 - cos(theta)**2)**13*(1.09550245157023e+74*cos(theta)**62 - 1.18376864909674e+75*cos(theta)**60 + 6.05569511243132e+75*cos(theta)**58 - 1.95127953622787e+76*cos(theta)**56 + 4.44522261211675e+76*cos(theta)**54 - 7.6181000693881e+76*cos(theta)**52 + 1.0203637062635e+77*cos(theta)**50 - 1.09548250672461e+77*cos(theta)**48 + 9.59397723280562e+76*cos(theta)**46 - 6.93904013693488e+76*cos(theta)**44 + 4.18110316531236e+76*cos(theta)**42 - 2.11139579198472e+76*cos(theta)**40 + 8.96998212281088e+75*cos(theta)**38 - 3.21237770368622e+75*cos(theta)**36 + 9.70181185677046e+74*cos(theta)**34 - 2.46835213226677e+74*cos(theta)**32 + 5.27716662760482e+73*cos(theta)**30 - 9.44289380093828e+72*cos(theta)**28 + 1.40638843843762e+72*cos(theta)**26 - 1.73069383753209e+71*cos(theta)**24 + 1.7433266392659e+70*cos(theta)**22 - 1.42048837273518e+69*cos(theta)**20 + 9.22395047230636e+67*cos(theta)**18 - 4.68391776389935e+66*cos(theta)**16 + 1.81547200151138e+65*cos(theta)**14 - 5.20340006732394e+63*cos(theta)**12 + 1.0566904752104e+62*cos(theta)**10 - 1.43182991220921e+60*cos(theta)**8 + 1.18333050595803e+58*cos(theta)**6 - 5.14342439564487e+55*cos(theta)**4 + 8.79217845409379e+52*cos(theta)**2 - 2.46624921573458e+49)*sin(26*phi)

#@torch.jit.script
def Yl88_m_minus_25(theta, phi):
    return 1.58214621197398e-48*(1.0 - cos(theta)**2)**12.5*(1.7388927802702e+72*cos(theta)**63 - 1.94060434278155e+73*cos(theta)**61 + 1.026389002107e+74*cos(theta)**59 - 3.42329743197872e+74*cos(theta)**57 + 8.08222293112136e+74*cos(theta)**55 - 1.43737737158266e+75*cos(theta)**53 + 2.00071314953627e+75*cos(theta)**51 - 2.23567858515227e+75*cos(theta)**49 + 2.04127175166077e+75*cos(theta)**47 - 1.54200891931886e+75*cos(theta)**45 + 9.72349573328455e+74*cos(theta)**43 - 5.14974583410906e+74*cos(theta)**41 + 2.29999541610535e+74*cos(theta)**39 - 8.68210190185465e+73*cos(theta)**37 + 2.77194624479156e+73*cos(theta)**35 - 7.47985494626294e+72*cos(theta)**33 + 1.70231181535639e+72*cos(theta)**31 - 3.25617027618562e+71*cos(theta)**29 + 5.20884606828747e+70*cos(theta)**27 - 6.92277535012837e+69*cos(theta)**25 + 7.57968104028653e+68*cos(theta)**23 - 6.764230346358e+67*cos(theta)**21 + 4.85471077489809e+66*cos(theta)**19 - 2.75524574347021e+65*cos(theta)**17 + 1.21031466767425e+64*cos(theta)**15 - 4.00261543640303e+62*cos(theta)**13 + 9.60627704736728e+60*cos(theta)**11 - 1.59092212467691e+59*cos(theta)**9 + 1.69047215136861e+57*cos(theta)**7 - 1.02868487912897e+55*cos(theta)**5 + 2.9307261513646e+52*cos(theta)**3 - 2.46624921573458e+49*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl88_m_minus_24(theta, phi):
    return 1.34547559442794e-46*(1.0 - cos(theta)**2)**12*(2.7170199691722e+70*cos(theta)**64 - 3.13000700448637e+71*cos(theta)**62 + 1.71064833684501e+72*cos(theta)**60 - 5.90223695168745e+72*cos(theta)**58 + 1.4432540948431e+73*cos(theta)**56 - 2.6618099473753e+73*cos(theta)**54 + 3.84752528756975e+73*cos(theta)**52 - 4.47135717030455e+73*cos(theta)**50 + 4.25264948262661e+73*cos(theta)**48 - 3.35219330286709e+73*cos(theta)**46 + 2.20988539392831e+73*cos(theta)**44 - 1.22612996050216e+73*cos(theta)**42 + 5.74998854026339e+72*cos(theta)**40 - 2.2847636583828e+72*cos(theta)**38 + 7.69985067997656e+71*cos(theta)**36 - 2.19995733713616e+71*cos(theta)**34 + 5.31972442298873e+70*cos(theta)**32 - 1.08539009206187e+70*cos(theta)**30 + 1.86030216724552e+69*cos(theta)**28 - 2.66260590389553e+68*cos(theta)**26 + 3.15820043345272e+67*cos(theta)**24 - 3.07465015743545e+66*cos(theta)**22 + 2.42735538744904e+65*cos(theta)**20 - 1.53069207970567e+64*cos(theta)**18 + 7.56446667296406e+62*cos(theta)**16 - 2.85901102600217e+61*cos(theta)**14 + 8.00523087280606e+59*cos(theta)**12 - 1.59092212467691e+58*cos(theta)**10 + 2.11309018921077e+56*cos(theta)**8 - 1.71447479854829e+54*cos(theta)**6 + 7.32681537841149e+51*cos(theta)**4 - 1.23312460786729e+49*cos(theta)**2 + 3.41018973414627e+45)*sin(24*phi)

#@torch.jit.script
def Yl88_m_minus_23(theta, phi):
    return 1.14799901164874e-44*(1.0 - cos(theta)**2)**11.5*(4.18003072180338e+68*cos(theta)**65 - 4.9682650864863e+69*cos(theta)**63 + 2.80434153581149e+70*cos(theta)**61 - 1.00037914435381e+71*cos(theta)**59 + 2.53202472779491e+71*cos(theta)**57 - 4.83965444977327e+71*cos(theta)**55 + 7.2594816746599e+71*cos(theta)**53 - 8.76736700059715e+71*cos(theta)**51 + 8.67887649515634e+71*cos(theta)**49 - 7.13232617631297e+71*cos(theta)**47 + 4.91085643095179e+71*cos(theta)**45 - 2.85146502442362e+71*cos(theta)**43 + 1.40243622933253e+71*cos(theta)**41 - 5.8583683548277e+70*cos(theta)**39 + 2.08104072431799e+70*cos(theta)**37 - 6.2855923918176e+69*cos(theta)**35 + 1.61203770393598e+69*cos(theta)**33 - 3.50125836148991e+68*cos(theta)**31 + 6.41483505946733e+67*cos(theta)**29 - 9.86150334776121e+66*cos(theta)**27 + 1.26328017338109e+66*cos(theta)**25 - 1.33680441627628e+65*cos(theta)**23 + 1.15588351783288e+64*cos(theta)**21 - 8.05627410371405e+62*cos(theta)**19 + 4.44968627821416e+61*cos(theta)**17 - 1.90600735066811e+60*cos(theta)**15 + 6.15786990215851e+58*cos(theta)**13 - 1.44629284061537e+57*cos(theta)**11 + 2.34787798801196e+55*cos(theta)**9 - 2.44924971221184e+53*cos(theta)**7 + 1.4653630756823e+51*cos(theta)**5 - 4.11041535955764e+48*cos(theta)**3 + 3.41018973414627e+45*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl88_m_minus_22(theta, phi):
    return 9.82595953556126e-43*(1.0 - cos(theta)**2)**11*(6.33337988152027e+66*cos(theta)**66 - 7.76291419763484e+67*cos(theta)**64 + 4.52313150937337e+68*cos(theta)**62 - 1.66729857392301e+69*cos(theta)**60 + 4.36555987550847e+69*cos(theta)**58 - 8.64224008888084e+69*cos(theta)**56 + 1.34434845827035e+70*cos(theta)**54 - 1.68603211549945e+70*cos(theta)**52 + 1.73577529903127e+70*cos(theta)**50 - 1.48590128673187e+70*cos(theta)**48 + 1.06757748498952e+70*cos(theta)**46 - 6.48060232823551e+69*cos(theta)**44 + 3.33913387936317e+69*cos(theta)**42 - 1.46459208870692e+69*cos(theta)**40 + 5.47642295873155e+68*cos(theta)**38 - 1.745997886616e+68*cos(theta)**36 + 4.74128736451759e+67*cos(theta)**34 - 1.0941432379656e+67*cos(theta)**32 + 2.13827835315578e+66*cos(theta)**30 - 3.52196548134329e+65*cos(theta)**28 + 4.85876989761957e+64*cos(theta)**26 - 5.57001840115119e+63*cos(theta)**24 + 5.25401599014944e+62*cos(theta)**22 - 4.02813705185702e+61*cos(theta)**20 + 2.4720479323412e+60*cos(theta)**18 - 1.19125459416757e+59*cos(theta)**16 + 4.39847850154179e+57*cos(theta)**14 - 1.20524403384614e+56*cos(theta)**12 + 2.34787798801196e+54*cos(theta)**10 - 3.0615621402648e+52*cos(theta)**8 + 2.44227179280383e+50*cos(theta)**6 - 1.02760383988941e+48*cos(theta)**4 + 1.70509486707314e+45*cos(theta)**2 - 4.6549136420233e+41)*sin(22*phi)

#@torch.jit.script
def Yl88_m_minus_21(theta, phi):
    return 8.43545892915952e-41*(1.0 - cos(theta)**2)**10.5*(9.45280579331383e+64*cos(theta)**67 - 1.19429449194382e+66*cos(theta)**65 + 7.17957382440217e+66*cos(theta)**63 - 2.73327635069346e+67*cos(theta)**61 + 7.39925402628554e+67*cos(theta)**59 - 1.51618247173348e+68*cos(theta)**57 + 2.44426992412791e+68*cos(theta)**55 - 3.18119267075368e+68*cos(theta)**53 + 3.40348097849268e+68*cos(theta)**51 - 3.03245160557524e+68*cos(theta)**49 + 2.27144145742451e+68*cos(theta)**47 - 1.440133850719e+68*cos(theta)**45 + 7.76542762642599e+67*cos(theta)**43 - 3.57217582611445e+67*cos(theta)**41 + 1.40421101505937e+67*cos(theta)**39 - 4.71891320707027e+66*cos(theta)**37 + 1.35465353271931e+66*cos(theta)**35 - 3.31558556959272e+65*cos(theta)**33 + 6.89767210695412e+64*cos(theta)**31 - 1.21447085563562e+64*cos(theta)**29 + 1.79954440652577e+63*cos(theta)**27 - 2.22800736046047e+62*cos(theta)**25 + 2.28435477832585e+61*cos(theta)**23 - 1.9181605008843e+60*cos(theta)**21 + 1.30107785912695e+59*cos(theta)**19 - 7.00737996569158e+57*cos(theta)**17 + 2.93231900102786e+56*cos(theta)**15 - 9.27110795266262e+54*cos(theta)**13 + 2.13443453455633e+53*cos(theta)**11 - 3.40173571140533e+51*cos(theta)**9 + 3.48895970400547e+49*cos(theta)**7 - 2.05520767977882e+47*cos(theta)**5 + 5.68364955691045e+44*cos(theta)**3 - 4.6549136420233e+41*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl88_m_minus_20(theta, phi):
    return 7.26233737831782e-39*(1.0 - cos(theta)**2)**10*(1.39011849901674e+63*cos(theta)**68 - 1.80953710900579e+64*cos(theta)**66 + 1.12180841006284e+65*cos(theta)**64 - 4.40851024305396e+65*cos(theta)**62 + 1.23320900438092e+66*cos(theta)**60 - 2.61410770988531e+66*cos(theta)**58 + 4.36476772165699e+66*cos(theta)**56 - 5.89109753843275e+66*cos(theta)**54 + 6.54515572787054e+66*cos(theta)**52 - 6.06490321115048e+66*cos(theta)**50 + 4.73216970296773e+66*cos(theta)**48 - 3.13072576243261e+66*cos(theta)**46 + 1.76486991509682e+66*cos(theta)**44 - 8.50518053836774e+65*cos(theta)**42 + 3.51052753764843e+65*cos(theta)**40 - 1.24181926501849e+65*cos(theta)**38 + 3.76292647977586e+64*cos(theta)**36 - 9.75172226350799e+63*cos(theta)**34 + 2.15552253342316e+63*cos(theta)**32 - 4.04823618545206e+62*cos(theta)**30 + 6.4269443090206e+61*cos(theta)**28 - 8.56925907869413e+60*cos(theta)**26 + 9.51814490969102e+59*cos(theta)**24 - 8.7189113676559e+58*cos(theta)**22 + 6.50538929563473e+57*cos(theta)**20 - 3.89298886982866e+56*cos(theta)**18 + 1.83269937564241e+55*cos(theta)**16 - 6.62221996618759e+53*cos(theta)**14 + 1.77869544546361e+52*cos(theta)**12 - 3.40173571140533e+50*cos(theta)**10 + 4.36119963000684e+48*cos(theta)**8 - 3.4253461329647e+46*cos(theta)**6 + 1.42091238922761e+44*cos(theta)**4 - 2.32745682101165e+41*cos(theta)**2 + 6.28023966813721e+37)*sin(20*phi)

#@torch.jit.script
def Yl88_m_minus_19(theta, phi):
    return 6.26921037573639e-37*(1.0 - cos(theta)**2)**9.5*(2.01466449132861e+61*cos(theta)**69 - 2.70080165523252e+62*cos(theta)**67 + 1.72585909240437e+63*cos(theta)**65 - 6.99763530643486e+63*cos(theta)**63 + 2.0216541055425e+64*cos(theta)**61 - 4.43069103370392e+64*cos(theta)**59 + 7.65748723097717e+64*cos(theta)**57 - 1.07110864335141e+65*cos(theta)**55 + 1.23493504299444e+65*cos(theta)**53 - 1.18919670806872e+65*cos(theta)**51 + 9.65748918973007e+64*cos(theta)**49 - 6.66111864347364e+64*cos(theta)**47 + 3.92193314465959e+64*cos(theta)**45 - 1.9779489624111e+64*cos(theta)**43 + 8.56226228694739e+63*cos(theta)**41 - 3.18415196158588e+63*cos(theta)**39 + 1.01700715669618e+63*cos(theta)**37 - 2.78620636100228e+62*cos(theta)**35 + 6.53188646491867e+61*cos(theta)**33 - 1.30588264046841e+61*cos(theta)**31 + 2.21618769276572e+60*cos(theta)**29 - 3.1737996587756e+59*cos(theta)**27 + 3.80725796387641e+58*cos(theta)**25 - 3.79083102941561e+57*cos(theta)**23 + 3.09780442649273e+56*cos(theta)**21 - 2.04894151043614e+55*cos(theta)**19 + 1.07805845626024e+54*cos(theta)**17 - 4.41481331079172e+52*cos(theta)**15 + 1.36822726574124e+51*cos(theta)**13 - 3.09248701036849e+49*cos(theta)**11 + 4.84577736667427e+47*cos(theta)**9 - 4.893351618521e+45*cos(theta)**7 + 2.84182477845523e+43*cos(theta)**5 - 7.75818940337217e+40*cos(theta)**3 + 6.28023966813721e+37*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl88_m_minus_18(theta, phi):
    return 5.42567470944355e-35*(1.0 - cos(theta)**2)**9*(2.87809213046944e+59*cos(theta)**70 - 3.97176714004783e+60*cos(theta)**68 + 2.6149380187945e+61*cos(theta)**66 - 1.09338051663045e+62*cos(theta)**64 + 3.26073242829435e+62*cos(theta)**62 - 7.38448505617319e+62*cos(theta)**60 + 1.320256419134e+63*cos(theta)**58 - 1.91269400598466e+63*cos(theta)**56 + 2.286916746286e+63*cos(theta)**54 - 2.286916746286e+63*cos(theta)**52 + 1.93149783794601e+63*cos(theta)**50 - 1.38773305072368e+63*cos(theta)**48 + 8.52594161882519e+62*cos(theta)**46 - 4.49533855093432e+62*cos(theta)**44 + 2.03863387784462e+62*cos(theta)**42 - 7.96037990396469e+61*cos(theta)**40 + 2.67633462288468e+61*cos(theta)**38 - 7.73946211389523e+60*cos(theta)**36 + 1.92114307791726e+60*cos(theta)**34 - 4.08088325146377e+59*cos(theta)**32 + 7.38729230921908e+58*cos(theta)**30 - 1.13349987813414e+58*cos(theta)**28 + 1.46432998610631e+57*cos(theta)**26 - 1.57951292892317e+56*cos(theta)**24 + 1.40809292113306e+55*cos(theta)**22 - 1.02447075521807e+54*cos(theta)**20 + 5.98921364589024e+52*cos(theta)**18 - 2.75925831924483e+51*cos(theta)**16 + 9.77305189815169e+49*cos(theta)**14 - 2.5770725086404e+48*cos(theta)**12 + 4.84577736667427e+46*cos(theta)**10 - 6.11668952315125e+44*cos(theta)**8 + 4.73637463075871e+42*cos(theta)**6 - 1.93954735084304e+40*cos(theta)**4 + 3.14011983406861e+37*cos(theta)**2 - 8.38483266773994e+33)*sin(18*phi)

#@torch.jit.script
def Yl88_m_minus_17(theta, phi):
    return 4.7069096230179e-33*(1.0 - cos(theta)**2)**8.5*(4.05365088798513e+57*cos(theta)**71 - 5.75618426093888e+58*cos(theta)**69 + 3.90289256536492e+59*cos(theta)**67 - 1.68212387173915e+60*cos(theta)**65 + 5.17576575919738e+60*cos(theta)**63 - 1.21057132068413e+61*cos(theta)**61 + 2.23772274429491e+61*cos(theta)**59 - 3.35560351927133e+61*cos(theta)**57 + 4.15803044779273e+61*cos(theta)**55 - 4.3149372571434e+61*cos(theta)**53 + 3.78725066263924e+61*cos(theta)**51 - 2.83210826678301e+61*cos(theta)**49 + 1.81403013166493e+61*cos(theta)**47 - 9.98964122429849e+60*cos(theta)**45 + 4.74100901824329e+60*cos(theta)**43 - 1.94155607413773e+60*cos(theta)**41 + 6.86239646893508e+59*cos(theta)**39 - 2.09174651726898e+59*cos(theta)**37 + 5.48898022262073e+58*cos(theta)**35 - 1.23663128832235e+58*cos(theta)**33 + 2.38299751910293e+57*cos(theta)**31 - 3.90862026942808e+56*cos(theta)**29 + 5.42344439298634e+55*cos(theta)**27 - 6.31805171569268e+54*cos(theta)**25 + 6.12214313536112e+53*cos(theta)**23 - 4.87843216770509e+52*cos(theta)**21 + 3.15221770836329e+51*cos(theta)**19 - 1.62309312896755e+50*cos(theta)**17 + 6.51536793210113e+48*cos(theta)**15 - 1.98236346818493e+47*cos(theta)**13 + 4.40525215152206e+45*cos(theta)**11 - 6.79632169239027e+43*cos(theta)**9 + 6.76624947251244e+41*cos(theta)**7 - 3.87909470168608e+39*cos(theta)**5 + 1.0467066113562e+37*cos(theta)**3 - 8.38483266773994e+33*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl88_m_minus_16(theta, phi):
    return 4.09257603944502e-31*(1.0 - cos(theta)**2)**8*(5.63007067775712e+55*cos(theta)**72 - 8.22312037276983e+56*cos(theta)**70 + 5.73954789024253e+57*cos(theta)**68 - 2.5486725329381e+58*cos(theta)**66 + 8.08713399874591e+58*cos(theta)**64 - 1.95253438820021e+59*cos(theta)**62 + 3.72953790715818e+59*cos(theta)**60 - 5.7855233090885e+59*cos(theta)**58 + 7.42505437105845e+59*cos(theta)**56 - 7.99062455026556e+59*cos(theta)**54 + 7.28317435122931e+59*cos(theta)**52 - 5.66421653356602e+59*cos(theta)**50 + 3.77922944096861e+59*cos(theta)**48 - 2.17166113571706e+59*cos(theta)**46 + 1.07750204960075e+59*cos(theta)**44 - 4.62275255747079e+58*cos(theta)**42 + 1.71559911723377e+58*cos(theta)**40 - 5.50459609807627e+57*cos(theta)**38 + 1.52471672850576e+57*cos(theta)**36 - 3.63715084800692e+56*cos(theta)**34 + 7.44686724719665e+55*cos(theta)**32 - 1.30287342314269e+55*cos(theta)**30 + 1.93694442606655e+54*cos(theta)**28 - 2.43001989065103e+53*cos(theta)**26 + 2.55089297306714e+52*cos(theta)**24 - 2.21746916713867e+51*cos(theta)**22 + 1.57610885418164e+50*cos(theta)**20 - 9.0171840498197e+48*cos(theta)**18 + 4.0721049575632e+47*cos(theta)**16 - 1.41597390584638e+46*cos(theta)**14 + 3.67104345960172e+44*cos(theta)**12 - 6.79632169239028e+42*cos(theta)**10 + 8.45781184064055e+40*cos(theta)**8 - 6.46515783614347e+38*cos(theta)**6 + 2.61676652839051e+36*cos(theta)**4 - 4.19241633386997e+33*cos(theta)**2 + 1.10910485023015e+30)*sin(16*phi)

#@torch.jit.script
def Yl88_m_minus_15(theta, phi):
    return 3.56594677784948e-29*(1.0 - cos(theta)**2)**7.5*(7.71242558596866e+53*cos(theta)**73 - 1.15818596799575e+55*cos(theta)**71 + 8.31818534817758e+55*cos(theta)**69 - 3.8039888551315e+56*cos(theta)**67 + 1.24417446134552e+57*cos(theta)**65 - 3.09926093365113e+57*cos(theta)**63 + 6.11399656911177e+57*cos(theta)**61 - 9.80597171031949e+57*cos(theta)**59 + 1.30264111772955e+58*cos(theta)**57 - 1.45284082732101e+58*cos(theta)**55 + 1.37418383985459e+58*cos(theta)**53 - 1.11063069285608e+58*cos(theta)**51 + 7.71271314483391e+57*cos(theta)**49 - 4.62055560790865e+57*cos(theta)**47 + 2.39444899911277e+57*cos(theta)**45 - 1.07505873429553e+57*cos(theta)**43 + 4.18438809081407e+56*cos(theta)**41 - 1.41143489694263e+56*cos(theta)**39 + 4.12085602298854e+55*cos(theta)**37 - 1.03918595657341e+55*cos(theta)**35 + 2.25662643854444e+54*cos(theta)**33 - 4.20281749400869e+53*cos(theta)**31 + 6.67911871057431e+52*cos(theta)**29 - 9.00007366907789e+51*cos(theta)**27 + 1.02035718922685e+51*cos(theta)**25 - 9.64117029190728e+49*cos(theta)**23 + 7.50528025800782e+48*cos(theta)**21 - 4.74588634201037e+47*cos(theta)**19 + 2.39535585739012e+46*cos(theta)**17 - 9.43982603897584e+44*cos(theta)**15 + 2.82387958430901e+43*cos(theta)**13 - 6.17847426580934e+41*cos(theta)**11 + 9.39756871182284e+39*cos(theta)**9 - 9.23593976591925e+37*cos(theta)**7 + 5.23353305678101e+35*cos(theta)**5 - 1.39747211128999e+33*cos(theta)**3 + 1.10910485023015e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl88_m_minus_14(theta, phi):
    return 3.11321654068509e-27*(1.0 - cos(theta)**2)**7*(1.04221967377955e+52*cos(theta)**74 - 1.60859162221632e+53*cos(theta)**72 + 1.1883121925968e+54*cos(theta)**70 - 5.59410125754632e+54*cos(theta)**68 + 1.88511282022049e+55*cos(theta)**66 - 4.84259520882989e+55*cos(theta)**64 + 9.86128478888995e+55*cos(theta)**62 - 1.63432861838658e+56*cos(theta)**60 + 2.24593296160268e+56*cos(theta)**58 - 2.59435862021609e+56*cos(theta)**56 + 2.54478488861961e+56*cos(theta)**54 - 2.13582825549247e+56*cos(theta)**52 + 1.54254262896678e+56*cos(theta)**50 - 9.62615751647635e+55*cos(theta)**48 + 5.20532391111473e+55*cos(theta)**46 - 2.44331530521712e+55*cos(theta)**44 + 9.96282878765255e+54*cos(theta)**42 - 3.52858724235658e+54*cos(theta)**40 + 1.0844357955233e+54*cos(theta)**38 - 2.88662765714835e+53*cos(theta)**36 + 6.63713658395424e+52*cos(theta)**34 - 1.31338046687772e+52*cos(theta)**32 + 2.22637290352477e+51*cos(theta)**30 - 3.21431202467068e+50*cos(theta)**28 + 3.92445072779559e+49*cos(theta)**26 - 4.0171542882947e+48*cos(theta)**24 + 3.41149102636719e+47*cos(theta)**22 - 2.37294317100518e+46*cos(theta)**20 + 1.33075325410562e+45*cos(theta)**18 - 5.8998912743599e+43*cos(theta)**16 + 2.01705684593501e+42*cos(theta)**14 - 5.14872855484112e+40*cos(theta)**12 + 9.39756871182284e+38*cos(theta)**10 - 1.15449247073991e+37*cos(theta)**8 + 8.72255509463502e+34*cos(theta)**6 - 3.49368027822497e+32*cos(theta)**4 + 5.54552425115075e+29*cos(theta)**2 - 1.45513625062995e+26)*sin(14*phi)

#@torch.jit.script
def Yl88_m_minus_13(theta, phi):
    return 2.72295238304572e-25*(1.0 - cos(theta)**2)**6.5*(1.38962623170607e+50*cos(theta)**75 - 2.20355016741962e+51*cos(theta)**73 + 1.67367914450253e+52*cos(theta)**71 - 8.10739312687873e+52*cos(theta)**69 + 2.81360122420969e+53*cos(theta)**67 - 7.4501464751229e+53*cos(theta)**65 + 1.5652832998238e+54*cos(theta)**63 - 2.67922724325669e+54*cos(theta)**61 + 3.80666603661471e+54*cos(theta)**59 - 4.5515063512563e+54*cos(theta)**57 + 4.62688161567201e+54*cos(theta)**55 - 4.02986463300465e+54*cos(theta)**53 + 3.02459339013094e+54*cos(theta)**51 - 1.96452194213803e+54*cos(theta)**49 + 1.10751572576909e+54*cos(theta)**47 - 5.42958956714915e+53*cos(theta)**45 + 2.31693692736106e+53*cos(theta)**43 - 8.60631034721117e+52*cos(theta)**41 + 2.7806046039059e+52*cos(theta)**39 - 7.80169637067122e+51*cos(theta)**37 + 1.89632473827264e+51*cos(theta)**35 - 3.97994080872035e+50*cos(theta)**33 + 7.18184807588635e+49*cos(theta)**31 - 1.10838345678299e+49*cos(theta)**29 + 1.45350026955392e+48*cos(theta)**27 - 1.60686171531788e+47*cos(theta)**25 + 1.48325696798574e+46*cos(theta)**23 - 1.1299729385739e+45*cos(theta)**21 + 7.00396449529275e+43*cos(theta)**19 - 3.47052427903524e+42*cos(theta)**17 + 1.34470456395667e+41*cos(theta)**15 - 3.96056042680086e+39*cos(theta)**13 + 8.5432442834753e+37*cos(theta)**11 - 1.28276941193323e+36*cos(theta)**9 + 1.24607929923357e+34*cos(theta)**7 - 6.98736055644995e+31*cos(theta)**5 + 1.84850808371692e+29*cos(theta)**3 - 1.45513625062995e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl88_m_minus_12(theta, phi):
    return 2.38565440217662e-23*(1.0 - cos(theta)**2)**6*(1.8284555680343e+48*cos(theta)**76 - 2.977770496513e+49*cos(theta)**74 + 2.32455436736463e+50*cos(theta)**72 - 1.15819901812553e+51*cos(theta)**70 + 4.1376488591319e+51*cos(theta)**68 - 1.12881007198832e+52*cos(theta)**66 + 2.44575515597469e+52*cos(theta)**64 - 4.32133426331724e+52*cos(theta)**62 + 6.34444339435785e+52*cos(theta)**60 - 7.84742474354535e+52*cos(theta)**58 + 8.2622885994143e+52*cos(theta)**56 - 7.46271228334195e+52*cos(theta)**54 + 5.81652575025182e+52*cos(theta)**52 - 3.92904388427606e+52*cos(theta)**50 + 2.30732442868561e+52*cos(theta)**48 - 1.1803455580759e+52*cos(theta)**46 + 5.26576574400241e+51*cos(theta)**44 - 2.04912151124076e+51*cos(theta)**42 + 6.95151150976474e+50*cos(theta)**40 - 2.0530779922819e+50*cos(theta)**38 + 5.267568717424e+49*cos(theta)**36 - 1.17057082609422e+49*cos(theta)**34 + 2.24432752371448e+48*cos(theta)**32 - 3.69461152260997e+47*cos(theta)**30 + 5.19107239126401e+46*cos(theta)**28 - 6.18023736660723e+45*cos(theta)**26 + 6.18023736660723e+44*cos(theta)**24 - 5.13624062988135e+43*cos(theta)**22 + 3.50198224764637e+42*cos(theta)**20 - 1.92806904390846e+41*cos(theta)**18 + 8.4044035247292e+39*cos(theta)**16 - 2.82897173342919e+38*cos(theta)**14 + 7.11937023622942e+36*cos(theta)**12 - 1.28276941193323e+35*cos(theta)**10 + 1.55759912404197e+33*cos(theta)**8 - 1.16456009274166e+31*cos(theta)**6 + 4.62127020929229e+28*cos(theta)**4 - 7.27568125314977e+25*cos(theta)**2 + 1.89569600134178e+22)*sin(12*phi)

#@torch.jit.script
def Yl88_m_minus_11(theta, phi):
    return 2.0934032419725e-21*(1.0 - cos(theta)**2)**5.5*(2.37461762082376e+46*cos(theta)**77 - 3.97036066201733e+47*cos(theta)**75 + 3.18432105118442e+48*cos(theta)**73 - 1.63126622271202e+49*cos(theta)**71 + 5.99659254946652e+49*cos(theta)**69 - 1.68479115222137e+50*cos(theta)**67 + 3.76270023996106e+50*cos(theta)**65 - 6.8592607354242e+50*cos(theta)**63 + 1.04007268759965e+51*cos(theta)**61 - 1.33007199043141e+51*cos(theta)**59 + 1.44952431568672e+51*cos(theta)**57 - 1.35685677878945e+51*cos(theta)**55 + 1.09745768872676e+51*cos(theta)**53 - 7.70400761622757e+50*cos(theta)**51 + 4.7088253646645e+50*cos(theta)**49 - 2.51137352782107e+50*cos(theta)**47 + 1.17017016533387e+50*cos(theta)**45 - 4.76539886335059e+49*cos(theta)**43 + 1.69549061213774e+49*cos(theta)**41 - 5.26430254431256e+48*cos(theta)**39 + 1.4236672209254e+48*cos(theta)**37 - 3.34448807455492e+47*cos(theta)**35 + 6.8009924961045e+46*cos(theta)**33 - 1.19181016858386e+46*cos(theta)**31 + 1.79002496250483e+45*cos(theta)**29 - 2.28897680244712e+44*cos(theta)**27 + 2.47209494664289e+43*cos(theta)**25 - 2.23314809994841e+42*cos(theta)**23 + 1.66761059411732e+41*cos(theta)**21 - 1.01477318100445e+40*cos(theta)**19 + 4.94376677925247e+38*cos(theta)**17 - 1.88598115561946e+37*cos(theta)**15 + 5.4764386432534e+35*cos(theta)**13 - 1.16615401084839e+34*cos(theta)**11 + 1.73066569337996e+32*cos(theta)**9 - 1.66365727534523e+30*cos(theta)**7 + 9.24254041858458e+27*cos(theta)**5 - 2.42522708438326e+25*cos(theta)**3 + 1.89569600134178e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl88_m_minus_10(theta, phi):
    return 1.83957623774865e-19*(1.0 - cos(theta)**2)**5*(3.04438156515867e+44*cos(theta)**78 - 5.22415876581227e+45*cos(theta)**76 + 4.30313655565462e+46*cos(theta)**74 - 2.26564753154447e+47*cos(theta)**72 + 8.56656078495217e+47*cos(theta)**70 - 2.47763404738437e+48*cos(theta)**68 + 5.70106096963797e+48*cos(theta)**66 - 1.07175948991003e+49*cos(theta)**64 + 1.67753659290266e+49*cos(theta)**62 - 2.21678665071902e+49*cos(theta)**60 + 2.49917985463228e+49*cos(theta)**58 - 2.42295853355258e+49*cos(theta)**56 + 2.0323290531977e+49*cos(theta)**54 - 1.48153992619761e+49*cos(theta)**52 + 9.417650729329e+48*cos(theta)**50 - 5.23202818296056e+48*cos(theta)**48 + 2.54384818550841e+48*cos(theta)**46 - 1.08304519621604e+48*cos(theta)**44 + 4.03688240985176e+47*cos(theta)**42 - 1.31607563607814e+47*cos(theta)**40 + 3.7464926866458e+46*cos(theta)**38 - 9.29024465154144e+45*cos(theta)**36 + 2.00029191061897e+45*cos(theta)**34 - 3.72440677682457e+44*cos(theta)**32 + 5.9667498750161e+43*cos(theta)**30 - 8.17491715159687e+42*cos(theta)**28 + 9.50805748708805e+41*cos(theta)**26 - 9.30478374978505e+40*cos(theta)**24 + 7.58004815507873e+39*cos(theta)**22 - 5.07386590502227e+38*cos(theta)**20 + 2.74653709958471e+37*cos(theta)**18 - 1.17873822226216e+36*cos(theta)**16 + 3.91174188803814e+34*cos(theta)**14 - 9.71795009040325e+32*cos(theta)**12 + 1.73066569337996e+31*cos(theta)**10 - 2.07957159418153e+29*cos(theta)**8 + 1.54042340309743e+27*cos(theta)**6 - 6.06306771095814e+24*cos(theta)**4 + 9.47848000670892e+21*cos(theta)**2 - 2.45492877666639e+18)*sin(10*phi)

#@torch.jit.script
def Yl88_m_minus_9(theta, phi):
    return 1.6186180329657e-17*(1.0 - cos(theta)**2)**4.5*(3.85364755083376e+42*cos(theta)**79 - 6.78462177378218e+43*cos(theta)**77 + 5.73751540753949e+44*cos(theta)**75 - 3.10362675554037e+45*cos(theta)**73 + 1.20655785703552e+46*cos(theta)**71 - 3.59077398171648e+46*cos(theta)**69 + 8.50904622334026e+46*cos(theta)**67 - 1.64886075370774e+47*cos(theta)**65 + 2.66275649667088e+47*cos(theta)**63 - 3.63407647658856e+47*cos(theta)**61 + 4.23589805869877e+47*cos(theta)**59 - 4.25080444482909e+47*cos(theta)**57 + 3.69514373308673e+47*cos(theta)**55 - 2.79535835131624e+47*cos(theta)**53 + 1.84659818222137e+47*cos(theta)**51 - 1.06776085366542e+47*cos(theta)**49 + 5.41244294789023e+46*cos(theta)**47 - 2.40676710270232e+46*cos(theta)**45 + 9.38809862756224e+45*cos(theta)**43 - 3.20994057580034e+45*cos(theta)**41 + 9.60639150422e+44*cos(theta)**39 - 2.51087693284904e+44*cos(theta)**37 + 5.71511974462563e+43*cos(theta)**35 - 1.12860811418926e+43*cos(theta)**33 + 1.92475802419874e+42*cos(theta)**31 - 2.81893694882651e+41*cos(theta)**29 + 3.52150277299557e+40*cos(theta)**27 - 3.72191349991402e+39*cos(theta)**25 + 3.2956731109038e+38*cos(theta)**23 - 2.41612662143918e+37*cos(theta)**21 + 1.44554584188669e+36*cos(theta)**19 - 6.93375424860094e+34*cos(theta)**17 + 2.60782792535876e+33*cos(theta)**15 - 7.47534622338712e+31*cos(theta)**13 + 1.57333244852724e+30*cos(theta)**11 - 2.31063510464615e+28*cos(theta)**9 + 2.20060486156776e+26*cos(theta)**7 - 1.21261354219163e+24*cos(theta)**5 + 3.15949333556964e+21*cos(theta)**3 - 2.45492877666639e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl88_m_minus_8(theta, phi):
    return 1.42585458067574e-15*(1.0 - cos(theta)**2)**4*(4.8170594385422e+40*cos(theta)**80 - 8.69823304331048e+41*cos(theta)**78 + 7.54936237834144e+42*cos(theta)**76 - 4.19409021018969e+43*cos(theta)**74 + 1.67577480143822e+44*cos(theta)**72 - 5.12967711673782e+44*cos(theta)**70 + 1.2513303269618e+45*cos(theta)**68 - 2.49827386925415e+45*cos(theta)**66 + 4.16055702604826e+45*cos(theta)**64 - 5.86141367191704e+45*cos(theta)**62 + 7.05983009783129e+45*cos(theta)**60 - 7.32897318073981e+45*cos(theta)**58 + 6.59847095194058e+45*cos(theta)**56 - 5.17658953947453e+45*cos(theta)**54 + 3.55115035042572e+45*cos(theta)**52 - 2.13552170733084e+45*cos(theta)**50 + 1.12759228081046e+45*cos(theta)**48 - 5.23210239717896e+44*cos(theta)**46 + 2.13365877899142e+44*cos(theta)**44 - 7.64271565666748e+43*cos(theta)**42 + 2.401597876055e+43*cos(theta)**40 - 6.60757087591852e+42*cos(theta)**38 + 1.58753326239601e+42*cos(theta)**36 - 3.31943562996842e+41*cos(theta)**34 + 6.01486882562107e+40*cos(theta)**32 - 9.39645649608835e+39*cos(theta)**30 + 1.25767956178413e+39*cos(theta)**28 - 1.43150519227462e+38*cos(theta)**26 + 1.37319712954325e+37*cos(theta)**24 - 1.09823937338144e+36*cos(theta)**22 + 7.22772920943344e+34*cos(theta)**20 - 3.85208569366719e+33*cos(theta)**18 + 1.62989245334923e+32*cos(theta)**16 - 5.33953301670508e+30*cos(theta)**14 + 1.3111103737727e+29*cos(theta)**12 - 2.31063510464615e+27*cos(theta)**10 + 2.7507560769597e+25*cos(theta)**8 - 2.02102257031938e+23*cos(theta)**6 + 7.8987333389241e+20*cos(theta)**4 - 1.22746438833319e+18*cos(theta)**2 + 316356801116802.0)*sin(8*phi)

#@torch.jit.script
def Yl88_m_minus_7(theta, phi):
    return 1.25734182122363e-13*(1.0 - cos(theta)**2)**3.5*(5.94698696116321e+38*cos(theta)**81 - 1.10104215738107e+40*cos(theta)**79 + 9.80436672511875e+40*cos(theta)**77 - 5.59212028025292e+41*cos(theta)**75 + 2.29558191977838e+42*cos(theta)**73 - 7.22489734751806e+42*cos(theta)**71 + 1.81352221298812e+43*cos(theta)**69 - 3.72876696903605e+43*cos(theta)**67 + 6.40085696315116e+43*cos(theta)**65 - 9.30383122526514e+43*cos(theta)**63 + 1.15734919636578e+44*cos(theta)**61 - 1.24219884419319e+44*cos(theta)**59 + 1.15762648279659e+44*cos(theta)**57 - 9.41198098086278e+43*cos(theta)**55 + 6.70028368004852e+43*cos(theta)**53 - 4.18729746535459e+43*cos(theta)**51 + 2.30120873634789e+43*cos(theta)**49 - 1.11321327599552e+43*cos(theta)**47 + 4.74146395331426e+42*cos(theta)**45 - 1.77737573410872e+42*cos(theta)**43 + 5.8575557952561e+41*cos(theta)**41 - 1.69424894254321e+41*cos(theta)**39 + 4.29063043890813e+40*cos(theta)**37 - 9.48410179990978e+39*cos(theta)**35 + 1.82268752291548e+39*cos(theta)**33 - 3.03111499873818e+38*cos(theta)**31 + 4.3368260751177e+37*cos(theta)**29 - 5.30187108249861e+36*cos(theta)**27 + 5.49278851817299e+35*cos(theta)**25 - 4.77495379731063e+34*cos(theta)**23 + 3.44177581401592e+33*cos(theta)**21 - 2.02741352298273e+32*cos(theta)**19 + 9.58760266676016e+30*cos(theta)**17 - 3.55968867780339e+29*cos(theta)**15 + 1.00854644136362e+28*cos(theta)**13 - 2.10057736786013e+26*cos(theta)**11 + 3.05639564106633e+24*cos(theta)**9 - 2.88717510045626e+22*cos(theta)**7 + 1.57974666778482e+20*cos(theta)**5 - 4.09154796111064e+17*cos(theta)**3 + 316356801116802.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl88_m_minus_6(theta, phi):
    return 1.10974217129701e-11*(1.0 - cos(theta)**2)**3*(7.25242312336976e+36*cos(theta)**82 - 1.37630269672634e+38*cos(theta)**80 + 1.25697009296394e+39*cos(theta)**78 - 7.35805300033279e+39*cos(theta)**76 + 3.10213772943024e+40*cos(theta)**74 - 1.00345796493306e+41*cos(theta)**72 + 2.59074601855446e+41*cos(theta)**70 - 5.48348083681771e+41*cos(theta)**68 + 9.69826812598661e+41*cos(theta)**66 - 1.45372362894768e+42*cos(theta)**64 + 1.86669225220288e+42*cos(theta)**62 - 2.07033140698865e+42*cos(theta)**60 + 1.99590772895964e+42*cos(theta)**58 - 1.68071088943978e+42*cos(theta)**56 + 1.24079327408306e+42*cos(theta)**54 - 8.0524951256819e+41*cos(theta)**52 + 4.60241747269578e+41*cos(theta)**50 - 2.31919432499067e+41*cos(theta)**48 + 1.03075303332919e+41*cos(theta)**46 - 4.03949030479254e+40*cos(theta)**44 + 1.39465614172764e+40*cos(theta)**42 - 4.23562235635803e+39*cos(theta)**40 + 1.12911327339688e+39*cos(theta)**38 - 2.63447272219716e+38*cos(theta)**36 + 5.36084565563375e+37*cos(theta)**34 - 9.47223437105681e+36*cos(theta)**32 + 1.4456086917059e+36*cos(theta)**30 - 1.89352538660664e+35*cos(theta)**28 + 2.11261096852807e+34*cos(theta)**26 - 1.98956408221276e+33*cos(theta)**24 + 1.56444355182542e+32*cos(theta)**22 - 1.01370676149137e+31*cos(theta)**20 + 5.32644592597786e+29*cos(theta)**18 - 2.22480542362712e+28*cos(theta)**16 + 7.20390315259725e+26*cos(theta)**14 - 1.75048113988344e+25*cos(theta)**12 + 3.05639564106633e+23*cos(theta)**10 - 3.60896887557032e+21*cos(theta)**8 + 2.6329111129747e+19*cos(theta)**6 - 1.02288699027766e+17*cos(theta)**4 + 158178400558401.0*cos(theta)**2 - 40610629154.9169)*sin(6*phi)

#@torch.jit.script
def Yl88_m_minus_5(theta, phi):
    return 9.8022339352122e-10*(1.0 - cos(theta)**2)**2.5*(8.73785918478285e+34*cos(theta)**83 - 1.69913913176092e+36*cos(theta)**81 + 1.59110138349866e+37*cos(theta)**79 - 9.55591298744518e+37*cos(theta)**77 + 4.13618363924032e+38*cos(theta)**75 - 1.3745999519631e+39*cos(theta)**73 + 3.64893805430205e+39*cos(theta)**71 - 7.94707367654741e+39*cos(theta)**69 + 1.44750270537114e+40*cos(theta)**67 - 2.23649789068874e+40*cos(theta)**65 + 2.9630035749252e+40*cos(theta)**63 - 3.39398591309614e+40*cos(theta)**61 + 3.3828944558638e+40*cos(theta)**59 - 2.94861559550839e+40*cos(theta)**57 + 2.25598777106011e+40*cos(theta)**55 - 1.51933870295885e+40*cos(theta)**53 + 9.02434798567799e+39*cos(theta)**51 - 4.73304964283811e+39*cos(theta)**49 + 2.19309156027487e+39*cos(theta)**47 - 8.9766451217612e+38*cos(theta)**45 + 3.2433863761108e+38*cos(theta)**43 - 1.03307862350196e+38*cos(theta)**41 + 2.89516223947917e+37*cos(theta)**39 - 7.12019654647881e+36*cos(theta)**37 + 1.53167018732393e+36*cos(theta)**35 - 2.8703740518354e+35*cos(theta)**33 + 4.66325384421258e+34*cos(theta)**31 - 6.5293978848505e+33*cos(theta)**29 + 7.8244850686225e+32*cos(theta)**27 - 7.95825632885105e+31*cos(theta)**25 + 6.80192848619748e+30*cos(theta)**23 - 4.82717505472079e+29*cos(theta)**21 + 2.80339259261993e+28*cos(theta)**19 - 1.30870907272183e+27*cos(theta)**17 + 4.8026021017315e+25*cos(theta)**15 - 1.3465239537565e+24*cos(theta)**13 + 2.77854149187848e+22*cos(theta)**11 - 4.00996541730036e+20*cos(theta)**9 + 3.76130158996386e+18*cos(theta)**7 - 2.04577398055532e+16*cos(theta)**5 + 52726133519467.1*cos(theta)**3 - 40610629154.9169*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl88_m_minus_4(theta, phi):
    return 8.66375535447722e-8*(1.0 - cos(theta)**2)**2*(1.04022133152177e+33*cos(theta)**84 - 2.07212089239136e+34*cos(theta)**82 + 1.98887672937333e+35*cos(theta)**80 - 1.22511704967246e+36*cos(theta)**78 + 5.44234689373727e+36*cos(theta)**76 - 1.85756750265284e+37*cos(theta)**74 + 5.06796951986396e+37*cos(theta)**72 - 1.13529623950677e+38*cos(theta)**70 + 2.1286804490752e+38*cos(theta)**68 - 3.38863316771021e+38*cos(theta)**66 + 4.62969308582063e+38*cos(theta)**64 - 5.47417082757442e+38*cos(theta)**62 + 5.63815742643967e+38*cos(theta)**60 - 5.08381999225584e+38*cos(theta)**58 + 4.02854959117877e+38*cos(theta)**56 - 2.81359019066454e+38*cos(theta)**54 + 1.73545153570731e+38*cos(theta)**52 - 9.46609928567622e+37*cos(theta)**50 + 4.56894075057264e+37*cos(theta)**48 - 1.95144459168722e+37*cos(theta)**46 + 7.37133267297908e+36*cos(theta)**44 - 2.45971100833799e+36*cos(theta)**42 + 7.23790559869793e+35*cos(theta)**40 - 1.8737359332839e+35*cos(theta)**38 + 4.25463940923314e+34*cos(theta)**36 - 8.44227662304528e+33*cos(theta)**34 + 1.45726682631643e+33*cos(theta)**32 - 2.17646596161683e+32*cos(theta)**30 + 2.79445895307946e+31*cos(theta)**28 - 3.06086781878887e+30*cos(theta)**26 + 2.83413686924895e+29*cos(theta)**24 - 2.19417047941854e+28*cos(theta)**22 + 1.40169629630996e+27*cos(theta)**20 - 7.27060595956574e+25*cos(theta)**18 + 3.00162631358219e+24*cos(theta)**16 - 9.61802824111782e+22*cos(theta)**14 + 2.31545124323207e+21*cos(theta)**12 - 4.00996541730036e+19*cos(theta)**10 + 4.70162698745482e+17*cos(theta)**8 - 3.40962330092554e+15*cos(theta)**6 + 13181533379866.8*cos(theta)**4 - 20305314577.4584*cos(theta)**2 + 5198493.23539642)*sin(4*phi)

#@torch.jit.script
def Yl88_m_minus_3(theta, phi):
    return 7.66142504046251e-6*(1.0 - cos(theta)**2)**1.5*(1.22378980179031e+31*cos(theta)**85 - 2.49653119565224e+32*cos(theta)**83 + 2.4554033695967e+33*cos(theta)**81 - 1.55078107553476e+34*cos(theta)**79 + 7.06798297887957e+34*cos(theta)**77 - 2.47675667020379e+35*cos(theta)**75 + 6.94242399981364e+35*cos(theta)**73 - 1.59900878803771e+36*cos(theta)**71 + 3.08504412909449e+36*cos(theta)**69 - 5.05766144434359e+36*cos(theta)**67 + 7.12260474741636e+36*cos(theta)**65 - 8.68916004376893e+36*cos(theta)**63 + 9.24288102695028e+36*cos(theta)**61 - 8.61664405467092e+36*cos(theta)**59 + 7.06763086171713e+36*cos(theta)**57 - 5.11561852848097e+36*cos(theta)**55 + 3.27443685982511e+36*cos(theta)**53 - 1.8560978991522e+36*cos(theta)**51 + 9.32436887871968e+35*cos(theta)**49 - 4.15200976954727e+35*cos(theta)**47 + 1.63807392732869e+35*cos(theta)**45 - 5.72025815892557e+34*cos(theta)**43 + 1.76534282895071e+34*cos(theta)**41 - 4.80445111098435e+33*cos(theta)**39 + 1.14990254303598e+33*cos(theta)**37 - 2.4120790351558e+32*cos(theta)**35 + 4.41596007974676e+31*cos(theta)**33 - 7.02085794069946e+30*cos(theta)**31 + 9.63606535544643e+29*cos(theta)**29 - 1.13365474769958e+29*cos(theta)**27 + 1.13365474769958e+28*cos(theta)**25 - 9.53987164964583e+26*cos(theta)**23 + 6.67474426814269e+25*cos(theta)**21 - 3.82663471556092e+24*cos(theta)**19 + 1.76566253740129e+23*cos(theta)**17 - 6.41201882741188e+21*cos(theta)**15 + 1.78111634094775e+20*cos(theta)**13 - 3.64542310663669e+18*cos(theta)**11 + 5.22402998606091e+16*cos(theta)**9 - 487089042989362.0*cos(theta)**7 + 2636306675973.35*cos(theta)**5 - 6768438192.48614*cos(theta)**3 + 5198493.23539642*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl88_m_minus_2(theta, phi):
    return 0.0006777655315445*(1.0 - cos(theta)**2)*(1.4230113974306e+29*cos(theta)**86 - 2.97206094720505e+30*cos(theta)**84 + 2.99439435316671e+31*cos(theta)**82 - 1.93847634441845e+32*cos(theta)**80 + 9.06151663958919e+32*cos(theta)**78 - 3.2588903555313e+33*cos(theta)**76 + 9.38165405380222e+33*cos(theta)**74 - 2.22084553894126e+34*cos(theta)**72 + 4.40720589870642e+34*cos(theta)**70 - 7.43773741815234e+34*cos(theta)**68 + 1.07918253748733e+35*cos(theta)**66 - 1.35768125683889e+35*cos(theta)**64 + 1.49078726241134e+35*cos(theta)**62 - 1.43610734244515e+35*cos(theta)**60 + 1.21855704512364e+35*cos(theta)**58 - 9.13503308657317e+34*cos(theta)**56 + 6.06377196263909e+34*cos(theta)**54 - 3.56941903683115e+34*cos(theta)**52 + 1.86487377574394e+34*cos(theta)**50 - 8.65002035322348e+33*cos(theta)**48 + 3.56103027680149e+33*cos(theta)**46 - 1.30005867248308e+33*cos(theta)**44 + 4.20319721178741e+32*cos(theta)**42 - 1.20111277774609e+32*cos(theta)**40 + 3.0260593237789e+31*cos(theta)**38 - 6.70021954209943e+30*cos(theta)**36 + 1.29881178816081e+30*cos(theta)**34 - 2.19401810646858e+29*cos(theta)**32 + 3.21202178514881e+28*cos(theta)**30 - 4.04876695606993e+27*cos(theta)**28 + 4.36021056807531e+26*cos(theta)**26 - 3.97494652068576e+25*cos(theta)**24 + 3.03397466733758e+24*cos(theta)**22 - 1.91331735778046e+23*cos(theta)**20 + 9.80923631889604e+21*cos(theta)**18 - 4.00751176713243e+20*cos(theta)**16 + 1.27222595781982e+19*cos(theta)**14 - 3.03785258886391e+17*cos(theta)**12 + 5.22402998606091e+15*cos(theta)**10 - 60886130373670.3*cos(theta)**8 + 439384445995.559*cos(theta)**6 - 1692109548.12154*cos(theta)**4 + 2599246.61769821*cos(theta)**2 - 664.259294070588)*sin(2*phi)

#@torch.jit.script
def Yl88_m_minus_1(theta, phi):
    return 0.0599736332592992*(1.0 - cos(theta)**2)**0.5*(1.63564528440299e+27*cos(theta)**87 - 3.49654229082947e+28*cos(theta)**85 + 3.60770403995989e+29*cos(theta)**83 - 2.39318067212154e+30*cos(theta)**81 + 1.14702742273281e+31*cos(theta)**79 - 4.23232513705363e+31*cos(theta)**77 + 1.25088720717363e+32*cos(theta)**75 - 3.04225416293324e+32*cos(theta)**73 + 6.20733225169918e+32*cos(theta)**71 - 1.07793295915251e+33*cos(theta)**69 + 1.61072020520497e+33*cos(theta)**67 - 2.08874039513676e+33*cos(theta)**65 + 2.3663289879545e+33*cos(theta)**63 - 2.3542743318773e+33*cos(theta)**61 + 2.06535092393838e+33*cos(theta)**59 - 1.60263738360933e+33*cos(theta)**57 + 1.10250399320711e+33*cos(theta)**55 - 6.73475289968142e+32*cos(theta)**53 + 3.65661524655674e+32*cos(theta)**51 - 1.76531027616806e+32*cos(theta)**49 + 7.57666016340743e+31*cos(theta)**47 - 2.88901927218463e+31*cos(theta)**45 + 9.77487723671492e+30*cos(theta)**43 - 2.92954336035631e+30*cos(theta)**41 + 7.75912647122796e+29*cos(theta)**39 - 1.81087014651336e+29*cos(theta)**37 + 3.71089082331661e+28*cos(theta)**35 - 6.64853971657146e+27*cos(theta)**33 + 1.03613605972542e+27*cos(theta)**31 - 1.39612653657584e+26*cos(theta)**29 + 1.61489280299085e+25*cos(theta)**27 - 1.58997860827431e+24*cos(theta)**25 + 1.31911942058156e+23*cos(theta)**23 - 9.1110350370498e+21*cos(theta)**21 + 5.1627559573137e+20*cos(theta)**19 - 2.35735986301907e+19*cos(theta)**17 + 8.48150638546545e+17*cos(theta)**15 - 2.33680968374147e+16*cos(theta)**13 + 474911816914628.0*cos(theta)**11 - 6765125597074.48*cos(theta)**9 + 62769206570.7941*cos(theta)**7 - 338421909.624307*cos(theta)**5 + 866415.539232737*cos(theta)**3 - 664.259294070588*cos(theta))*sin(phi)

#@torch.jit.script
def Yl88_m0(theta, phi):
    return 2.19148260424481e+26*cos(theta)**88 - 4.7937116623138e+27*cos(theta)**86 + 5.06387749299334e+28*cos(theta)**84 - 3.44106762974167e+29*cos(theta)**82 + 1.69050082816155e+30*cos(theta)**80 - 6.39758397244371e+30*cos(theta)**78 + 1.94060047164126e+31*cos(theta)**76 - 4.84724920611533e+31*cos(theta)**74 + 1.01649224423273e+32*cos(theta)**72 - 1.8156213670572e+32*cos(theta)**70 + 2.79281885442237e+32*cos(theta)**68 - 3.7314025515391e+32*cos(theta)**66 + 4.35940003978833e+32*cos(theta)**64 - 4.47710162007808e+32*cos(theta)**62 + 4.05858061532486e+32*cos(theta)**60 - 3.25790824903628e+32*cos(theta)**58 + 2.32125962743835e+32*cos(theta)**56 - 1.4704812119519e+32*cos(theta)**54 + 8.29101108866494e+31*cos(theta)**52 - 4.16277194379769e+31*cos(theta)**50 + 1.86109329604094e+31*cos(theta)**48 - 7.40498496625813e+30*cos(theta)**46 + 2.61932995217948e+30*cos(theta)**44 - 8.22398318872151e+29*cos(theta)**42 + 2.28709609996422e+29*cos(theta)**40 - 5.61869278101446e+28*cos(theta)**38 + 1.21536646924713e+28*cos(theta)**36 - 2.30557324789428e+27*cos(theta)**34 + 3.81766998839637e+26*cos(theta)**32 - 5.48700177990322e+25*cos(theta)**30 + 6.80013041099117e+24*cos(theta)**28 - 7.21023645260774e+23*cos(theta)**26 + 6.48043928953959e+22*cos(theta)**24 - 4.88288627876857e+21*cos(theta)**22 + 3.04356915918926e+20*cos(theta)**20 - 1.54413388583701e+19*cos(theta)**18 + 6.25006572838789e+17*cos(theta)**16 - 1.96800810130293e+16*cos(theta)**14 + 466619951064530.0*cos(theta)**12 - 7976409419906.5*cos(theta)**10 + 92509903065.9259*cos(theta)**8 - 665026260.807683*cos(theta)**6 + 2553864.28881599*cos(theta)**4 - 3915.96875361511*cos(theta)**2 + 0.999992020841447

#@torch.jit.script
def Yl88_m1(theta, phi):
    return 0.0599736332592992*(1.0 - cos(theta)**2)**0.5*(1.63564528440299e+27*cos(theta)**87 - 3.49654229082947e+28*cos(theta)**85 + 3.60770403995989e+29*cos(theta)**83 - 2.39318067212154e+30*cos(theta)**81 + 1.14702742273281e+31*cos(theta)**79 - 4.23232513705363e+31*cos(theta)**77 + 1.25088720717363e+32*cos(theta)**75 - 3.04225416293324e+32*cos(theta)**73 + 6.20733225169918e+32*cos(theta)**71 - 1.07793295915251e+33*cos(theta)**69 + 1.61072020520497e+33*cos(theta)**67 - 2.08874039513676e+33*cos(theta)**65 + 2.3663289879545e+33*cos(theta)**63 - 2.3542743318773e+33*cos(theta)**61 + 2.06535092393838e+33*cos(theta)**59 - 1.60263738360933e+33*cos(theta)**57 + 1.10250399320711e+33*cos(theta)**55 - 6.73475289968142e+32*cos(theta)**53 + 3.65661524655674e+32*cos(theta)**51 - 1.76531027616806e+32*cos(theta)**49 + 7.57666016340743e+31*cos(theta)**47 - 2.88901927218463e+31*cos(theta)**45 + 9.77487723671492e+30*cos(theta)**43 - 2.92954336035631e+30*cos(theta)**41 + 7.75912647122796e+29*cos(theta)**39 - 1.81087014651336e+29*cos(theta)**37 + 3.71089082331661e+28*cos(theta)**35 - 6.64853971657146e+27*cos(theta)**33 + 1.03613605972542e+27*cos(theta)**31 - 1.39612653657584e+26*cos(theta)**29 + 1.61489280299085e+25*cos(theta)**27 - 1.58997860827431e+24*cos(theta)**25 + 1.31911942058156e+23*cos(theta)**23 - 9.1110350370498e+21*cos(theta)**21 + 5.1627559573137e+20*cos(theta)**19 - 2.35735986301907e+19*cos(theta)**17 + 8.48150638546545e+17*cos(theta)**15 - 2.33680968374147e+16*cos(theta)**13 + 474911816914628.0*cos(theta)**11 - 6765125597074.48*cos(theta)**9 + 62769206570.7941*cos(theta)**7 - 338421909.624307*cos(theta)**5 + 866415.539232737*cos(theta)**3 - 664.259294070588*cos(theta))*cos(phi)

#@torch.jit.script
def Yl88_m2(theta, phi):
    return 0.0006777655315445*(1.0 - cos(theta)**2)*(1.4230113974306e+29*cos(theta)**86 - 2.97206094720505e+30*cos(theta)**84 + 2.99439435316671e+31*cos(theta)**82 - 1.93847634441845e+32*cos(theta)**80 + 9.06151663958919e+32*cos(theta)**78 - 3.2588903555313e+33*cos(theta)**76 + 9.38165405380222e+33*cos(theta)**74 - 2.22084553894126e+34*cos(theta)**72 + 4.40720589870642e+34*cos(theta)**70 - 7.43773741815234e+34*cos(theta)**68 + 1.07918253748733e+35*cos(theta)**66 - 1.35768125683889e+35*cos(theta)**64 + 1.49078726241134e+35*cos(theta)**62 - 1.43610734244515e+35*cos(theta)**60 + 1.21855704512364e+35*cos(theta)**58 - 9.13503308657317e+34*cos(theta)**56 + 6.06377196263909e+34*cos(theta)**54 - 3.56941903683115e+34*cos(theta)**52 + 1.86487377574394e+34*cos(theta)**50 - 8.65002035322348e+33*cos(theta)**48 + 3.56103027680149e+33*cos(theta)**46 - 1.30005867248308e+33*cos(theta)**44 + 4.20319721178741e+32*cos(theta)**42 - 1.20111277774609e+32*cos(theta)**40 + 3.0260593237789e+31*cos(theta)**38 - 6.70021954209943e+30*cos(theta)**36 + 1.29881178816081e+30*cos(theta)**34 - 2.19401810646858e+29*cos(theta)**32 + 3.21202178514881e+28*cos(theta)**30 - 4.04876695606993e+27*cos(theta)**28 + 4.36021056807531e+26*cos(theta)**26 - 3.97494652068576e+25*cos(theta)**24 + 3.03397466733758e+24*cos(theta)**22 - 1.91331735778046e+23*cos(theta)**20 + 9.80923631889604e+21*cos(theta)**18 - 4.00751176713243e+20*cos(theta)**16 + 1.27222595781982e+19*cos(theta)**14 - 3.03785258886391e+17*cos(theta)**12 + 5.22402998606091e+15*cos(theta)**10 - 60886130373670.3*cos(theta)**8 + 439384445995.559*cos(theta)**6 - 1692109548.12154*cos(theta)**4 + 2599246.61769821*cos(theta)**2 - 664.259294070588)*cos(2*phi)

#@torch.jit.script
def Yl88_m3(theta, phi):
    return 7.66142504046251e-6*(1.0 - cos(theta)**2)**1.5*(1.22378980179031e+31*cos(theta)**85 - 2.49653119565224e+32*cos(theta)**83 + 2.4554033695967e+33*cos(theta)**81 - 1.55078107553476e+34*cos(theta)**79 + 7.06798297887957e+34*cos(theta)**77 - 2.47675667020379e+35*cos(theta)**75 + 6.94242399981364e+35*cos(theta)**73 - 1.59900878803771e+36*cos(theta)**71 + 3.08504412909449e+36*cos(theta)**69 - 5.05766144434359e+36*cos(theta)**67 + 7.12260474741636e+36*cos(theta)**65 - 8.68916004376893e+36*cos(theta)**63 + 9.24288102695028e+36*cos(theta)**61 - 8.61664405467092e+36*cos(theta)**59 + 7.06763086171713e+36*cos(theta)**57 - 5.11561852848097e+36*cos(theta)**55 + 3.27443685982511e+36*cos(theta)**53 - 1.8560978991522e+36*cos(theta)**51 + 9.32436887871968e+35*cos(theta)**49 - 4.15200976954727e+35*cos(theta)**47 + 1.63807392732869e+35*cos(theta)**45 - 5.72025815892557e+34*cos(theta)**43 + 1.76534282895071e+34*cos(theta)**41 - 4.80445111098435e+33*cos(theta)**39 + 1.14990254303598e+33*cos(theta)**37 - 2.4120790351558e+32*cos(theta)**35 + 4.41596007974676e+31*cos(theta)**33 - 7.02085794069946e+30*cos(theta)**31 + 9.63606535544643e+29*cos(theta)**29 - 1.13365474769958e+29*cos(theta)**27 + 1.13365474769958e+28*cos(theta)**25 - 9.53987164964583e+26*cos(theta)**23 + 6.67474426814269e+25*cos(theta)**21 - 3.82663471556092e+24*cos(theta)**19 + 1.76566253740129e+23*cos(theta)**17 - 6.41201882741188e+21*cos(theta)**15 + 1.78111634094775e+20*cos(theta)**13 - 3.64542310663669e+18*cos(theta)**11 + 5.22402998606091e+16*cos(theta)**9 - 487089042989362.0*cos(theta)**7 + 2636306675973.35*cos(theta)**5 - 6768438192.48614*cos(theta)**3 + 5198493.23539642*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl88_m4(theta, phi):
    return 8.66375535447722e-8*(1.0 - cos(theta)**2)**2*(1.04022133152177e+33*cos(theta)**84 - 2.07212089239136e+34*cos(theta)**82 + 1.98887672937333e+35*cos(theta)**80 - 1.22511704967246e+36*cos(theta)**78 + 5.44234689373727e+36*cos(theta)**76 - 1.85756750265284e+37*cos(theta)**74 + 5.06796951986396e+37*cos(theta)**72 - 1.13529623950677e+38*cos(theta)**70 + 2.1286804490752e+38*cos(theta)**68 - 3.38863316771021e+38*cos(theta)**66 + 4.62969308582063e+38*cos(theta)**64 - 5.47417082757442e+38*cos(theta)**62 + 5.63815742643967e+38*cos(theta)**60 - 5.08381999225584e+38*cos(theta)**58 + 4.02854959117877e+38*cos(theta)**56 - 2.81359019066454e+38*cos(theta)**54 + 1.73545153570731e+38*cos(theta)**52 - 9.46609928567622e+37*cos(theta)**50 + 4.56894075057264e+37*cos(theta)**48 - 1.95144459168722e+37*cos(theta)**46 + 7.37133267297908e+36*cos(theta)**44 - 2.45971100833799e+36*cos(theta)**42 + 7.23790559869793e+35*cos(theta)**40 - 1.8737359332839e+35*cos(theta)**38 + 4.25463940923314e+34*cos(theta)**36 - 8.44227662304528e+33*cos(theta)**34 + 1.45726682631643e+33*cos(theta)**32 - 2.17646596161683e+32*cos(theta)**30 + 2.79445895307946e+31*cos(theta)**28 - 3.06086781878887e+30*cos(theta)**26 + 2.83413686924895e+29*cos(theta)**24 - 2.19417047941854e+28*cos(theta)**22 + 1.40169629630996e+27*cos(theta)**20 - 7.27060595956574e+25*cos(theta)**18 + 3.00162631358219e+24*cos(theta)**16 - 9.61802824111782e+22*cos(theta)**14 + 2.31545124323207e+21*cos(theta)**12 - 4.00996541730036e+19*cos(theta)**10 + 4.70162698745482e+17*cos(theta)**8 - 3.40962330092554e+15*cos(theta)**6 + 13181533379866.8*cos(theta)**4 - 20305314577.4584*cos(theta)**2 + 5198493.23539642)*cos(4*phi)

#@torch.jit.script
def Yl88_m5(theta, phi):
    return 9.8022339352122e-10*(1.0 - cos(theta)**2)**2.5*(8.73785918478285e+34*cos(theta)**83 - 1.69913913176092e+36*cos(theta)**81 + 1.59110138349866e+37*cos(theta)**79 - 9.55591298744518e+37*cos(theta)**77 + 4.13618363924032e+38*cos(theta)**75 - 1.3745999519631e+39*cos(theta)**73 + 3.64893805430205e+39*cos(theta)**71 - 7.94707367654741e+39*cos(theta)**69 + 1.44750270537114e+40*cos(theta)**67 - 2.23649789068874e+40*cos(theta)**65 + 2.9630035749252e+40*cos(theta)**63 - 3.39398591309614e+40*cos(theta)**61 + 3.3828944558638e+40*cos(theta)**59 - 2.94861559550839e+40*cos(theta)**57 + 2.25598777106011e+40*cos(theta)**55 - 1.51933870295885e+40*cos(theta)**53 + 9.02434798567799e+39*cos(theta)**51 - 4.73304964283811e+39*cos(theta)**49 + 2.19309156027487e+39*cos(theta)**47 - 8.9766451217612e+38*cos(theta)**45 + 3.2433863761108e+38*cos(theta)**43 - 1.03307862350196e+38*cos(theta)**41 + 2.89516223947917e+37*cos(theta)**39 - 7.12019654647881e+36*cos(theta)**37 + 1.53167018732393e+36*cos(theta)**35 - 2.8703740518354e+35*cos(theta)**33 + 4.66325384421258e+34*cos(theta)**31 - 6.5293978848505e+33*cos(theta)**29 + 7.8244850686225e+32*cos(theta)**27 - 7.95825632885105e+31*cos(theta)**25 + 6.80192848619748e+30*cos(theta)**23 - 4.82717505472079e+29*cos(theta)**21 + 2.80339259261993e+28*cos(theta)**19 - 1.30870907272183e+27*cos(theta)**17 + 4.8026021017315e+25*cos(theta)**15 - 1.3465239537565e+24*cos(theta)**13 + 2.77854149187848e+22*cos(theta)**11 - 4.00996541730036e+20*cos(theta)**9 + 3.76130158996386e+18*cos(theta)**7 - 2.04577398055532e+16*cos(theta)**5 + 52726133519467.1*cos(theta)**3 - 40610629154.9169*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl88_m6(theta, phi):
    return 1.10974217129701e-11*(1.0 - cos(theta)**2)**3*(7.25242312336976e+36*cos(theta)**82 - 1.37630269672634e+38*cos(theta)**80 + 1.25697009296394e+39*cos(theta)**78 - 7.35805300033279e+39*cos(theta)**76 + 3.10213772943024e+40*cos(theta)**74 - 1.00345796493306e+41*cos(theta)**72 + 2.59074601855446e+41*cos(theta)**70 - 5.48348083681771e+41*cos(theta)**68 + 9.69826812598661e+41*cos(theta)**66 - 1.45372362894768e+42*cos(theta)**64 + 1.86669225220288e+42*cos(theta)**62 - 2.07033140698865e+42*cos(theta)**60 + 1.99590772895964e+42*cos(theta)**58 - 1.68071088943978e+42*cos(theta)**56 + 1.24079327408306e+42*cos(theta)**54 - 8.0524951256819e+41*cos(theta)**52 + 4.60241747269578e+41*cos(theta)**50 - 2.31919432499067e+41*cos(theta)**48 + 1.03075303332919e+41*cos(theta)**46 - 4.03949030479254e+40*cos(theta)**44 + 1.39465614172764e+40*cos(theta)**42 - 4.23562235635803e+39*cos(theta)**40 + 1.12911327339688e+39*cos(theta)**38 - 2.63447272219716e+38*cos(theta)**36 + 5.36084565563375e+37*cos(theta)**34 - 9.47223437105681e+36*cos(theta)**32 + 1.4456086917059e+36*cos(theta)**30 - 1.89352538660664e+35*cos(theta)**28 + 2.11261096852807e+34*cos(theta)**26 - 1.98956408221276e+33*cos(theta)**24 + 1.56444355182542e+32*cos(theta)**22 - 1.01370676149137e+31*cos(theta)**20 + 5.32644592597786e+29*cos(theta)**18 - 2.22480542362712e+28*cos(theta)**16 + 7.20390315259725e+26*cos(theta)**14 - 1.75048113988344e+25*cos(theta)**12 + 3.05639564106633e+23*cos(theta)**10 - 3.60896887557032e+21*cos(theta)**8 + 2.6329111129747e+19*cos(theta)**6 - 1.02288699027766e+17*cos(theta)**4 + 158178400558401.0*cos(theta)**2 - 40610629154.9169)*cos(6*phi)

#@torch.jit.script
def Yl88_m7(theta, phi):
    return 1.25734182122363e-13*(1.0 - cos(theta)**2)**3.5*(5.94698696116321e+38*cos(theta)**81 - 1.10104215738107e+40*cos(theta)**79 + 9.80436672511875e+40*cos(theta)**77 - 5.59212028025292e+41*cos(theta)**75 + 2.29558191977838e+42*cos(theta)**73 - 7.22489734751806e+42*cos(theta)**71 + 1.81352221298812e+43*cos(theta)**69 - 3.72876696903605e+43*cos(theta)**67 + 6.40085696315116e+43*cos(theta)**65 - 9.30383122526514e+43*cos(theta)**63 + 1.15734919636578e+44*cos(theta)**61 - 1.24219884419319e+44*cos(theta)**59 + 1.15762648279659e+44*cos(theta)**57 - 9.41198098086278e+43*cos(theta)**55 + 6.70028368004852e+43*cos(theta)**53 - 4.18729746535459e+43*cos(theta)**51 + 2.30120873634789e+43*cos(theta)**49 - 1.11321327599552e+43*cos(theta)**47 + 4.74146395331426e+42*cos(theta)**45 - 1.77737573410872e+42*cos(theta)**43 + 5.8575557952561e+41*cos(theta)**41 - 1.69424894254321e+41*cos(theta)**39 + 4.29063043890813e+40*cos(theta)**37 - 9.48410179990978e+39*cos(theta)**35 + 1.82268752291548e+39*cos(theta)**33 - 3.03111499873818e+38*cos(theta)**31 + 4.3368260751177e+37*cos(theta)**29 - 5.30187108249861e+36*cos(theta)**27 + 5.49278851817299e+35*cos(theta)**25 - 4.77495379731063e+34*cos(theta)**23 + 3.44177581401592e+33*cos(theta)**21 - 2.02741352298273e+32*cos(theta)**19 + 9.58760266676016e+30*cos(theta)**17 - 3.55968867780339e+29*cos(theta)**15 + 1.00854644136362e+28*cos(theta)**13 - 2.10057736786013e+26*cos(theta)**11 + 3.05639564106633e+24*cos(theta)**9 - 2.88717510045626e+22*cos(theta)**7 + 1.57974666778482e+20*cos(theta)**5 - 4.09154796111064e+17*cos(theta)**3 + 316356801116802.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl88_m8(theta, phi):
    return 1.42585458067574e-15*(1.0 - cos(theta)**2)**4*(4.8170594385422e+40*cos(theta)**80 - 8.69823304331048e+41*cos(theta)**78 + 7.54936237834144e+42*cos(theta)**76 - 4.19409021018969e+43*cos(theta)**74 + 1.67577480143822e+44*cos(theta)**72 - 5.12967711673782e+44*cos(theta)**70 + 1.2513303269618e+45*cos(theta)**68 - 2.49827386925415e+45*cos(theta)**66 + 4.16055702604826e+45*cos(theta)**64 - 5.86141367191704e+45*cos(theta)**62 + 7.05983009783129e+45*cos(theta)**60 - 7.32897318073981e+45*cos(theta)**58 + 6.59847095194058e+45*cos(theta)**56 - 5.17658953947453e+45*cos(theta)**54 + 3.55115035042572e+45*cos(theta)**52 - 2.13552170733084e+45*cos(theta)**50 + 1.12759228081046e+45*cos(theta)**48 - 5.23210239717896e+44*cos(theta)**46 + 2.13365877899142e+44*cos(theta)**44 - 7.64271565666748e+43*cos(theta)**42 + 2.401597876055e+43*cos(theta)**40 - 6.60757087591852e+42*cos(theta)**38 + 1.58753326239601e+42*cos(theta)**36 - 3.31943562996842e+41*cos(theta)**34 + 6.01486882562107e+40*cos(theta)**32 - 9.39645649608835e+39*cos(theta)**30 + 1.25767956178413e+39*cos(theta)**28 - 1.43150519227462e+38*cos(theta)**26 + 1.37319712954325e+37*cos(theta)**24 - 1.09823937338144e+36*cos(theta)**22 + 7.22772920943344e+34*cos(theta)**20 - 3.85208569366719e+33*cos(theta)**18 + 1.62989245334923e+32*cos(theta)**16 - 5.33953301670508e+30*cos(theta)**14 + 1.3111103737727e+29*cos(theta)**12 - 2.31063510464615e+27*cos(theta)**10 + 2.7507560769597e+25*cos(theta)**8 - 2.02102257031938e+23*cos(theta)**6 + 7.8987333389241e+20*cos(theta)**4 - 1.22746438833319e+18*cos(theta)**2 + 316356801116802.0)*cos(8*phi)

#@torch.jit.script
def Yl88_m9(theta, phi):
    return 1.6186180329657e-17*(1.0 - cos(theta)**2)**4.5*(3.85364755083376e+42*cos(theta)**79 - 6.78462177378218e+43*cos(theta)**77 + 5.73751540753949e+44*cos(theta)**75 - 3.10362675554037e+45*cos(theta)**73 + 1.20655785703552e+46*cos(theta)**71 - 3.59077398171648e+46*cos(theta)**69 + 8.50904622334026e+46*cos(theta)**67 - 1.64886075370774e+47*cos(theta)**65 + 2.66275649667088e+47*cos(theta)**63 - 3.63407647658856e+47*cos(theta)**61 + 4.23589805869877e+47*cos(theta)**59 - 4.25080444482909e+47*cos(theta)**57 + 3.69514373308673e+47*cos(theta)**55 - 2.79535835131624e+47*cos(theta)**53 + 1.84659818222137e+47*cos(theta)**51 - 1.06776085366542e+47*cos(theta)**49 + 5.41244294789023e+46*cos(theta)**47 - 2.40676710270232e+46*cos(theta)**45 + 9.38809862756224e+45*cos(theta)**43 - 3.20994057580034e+45*cos(theta)**41 + 9.60639150422e+44*cos(theta)**39 - 2.51087693284904e+44*cos(theta)**37 + 5.71511974462563e+43*cos(theta)**35 - 1.12860811418926e+43*cos(theta)**33 + 1.92475802419874e+42*cos(theta)**31 - 2.81893694882651e+41*cos(theta)**29 + 3.52150277299557e+40*cos(theta)**27 - 3.72191349991402e+39*cos(theta)**25 + 3.2956731109038e+38*cos(theta)**23 - 2.41612662143918e+37*cos(theta)**21 + 1.44554584188669e+36*cos(theta)**19 - 6.93375424860094e+34*cos(theta)**17 + 2.60782792535876e+33*cos(theta)**15 - 7.47534622338712e+31*cos(theta)**13 + 1.57333244852724e+30*cos(theta)**11 - 2.31063510464615e+28*cos(theta)**9 + 2.20060486156776e+26*cos(theta)**7 - 1.21261354219163e+24*cos(theta)**5 + 3.15949333556964e+21*cos(theta)**3 - 2.45492877666639e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl88_m10(theta, phi):
    return 1.83957623774865e-19*(1.0 - cos(theta)**2)**5*(3.04438156515867e+44*cos(theta)**78 - 5.22415876581227e+45*cos(theta)**76 + 4.30313655565462e+46*cos(theta)**74 - 2.26564753154447e+47*cos(theta)**72 + 8.56656078495217e+47*cos(theta)**70 - 2.47763404738437e+48*cos(theta)**68 + 5.70106096963797e+48*cos(theta)**66 - 1.07175948991003e+49*cos(theta)**64 + 1.67753659290266e+49*cos(theta)**62 - 2.21678665071902e+49*cos(theta)**60 + 2.49917985463228e+49*cos(theta)**58 - 2.42295853355258e+49*cos(theta)**56 + 2.0323290531977e+49*cos(theta)**54 - 1.48153992619761e+49*cos(theta)**52 + 9.417650729329e+48*cos(theta)**50 - 5.23202818296056e+48*cos(theta)**48 + 2.54384818550841e+48*cos(theta)**46 - 1.08304519621604e+48*cos(theta)**44 + 4.03688240985176e+47*cos(theta)**42 - 1.31607563607814e+47*cos(theta)**40 + 3.7464926866458e+46*cos(theta)**38 - 9.29024465154144e+45*cos(theta)**36 + 2.00029191061897e+45*cos(theta)**34 - 3.72440677682457e+44*cos(theta)**32 + 5.9667498750161e+43*cos(theta)**30 - 8.17491715159687e+42*cos(theta)**28 + 9.50805748708805e+41*cos(theta)**26 - 9.30478374978505e+40*cos(theta)**24 + 7.58004815507873e+39*cos(theta)**22 - 5.07386590502227e+38*cos(theta)**20 + 2.74653709958471e+37*cos(theta)**18 - 1.17873822226216e+36*cos(theta)**16 + 3.91174188803814e+34*cos(theta)**14 - 9.71795009040325e+32*cos(theta)**12 + 1.73066569337996e+31*cos(theta)**10 - 2.07957159418153e+29*cos(theta)**8 + 1.54042340309743e+27*cos(theta)**6 - 6.06306771095814e+24*cos(theta)**4 + 9.47848000670892e+21*cos(theta)**2 - 2.45492877666639e+18)*cos(10*phi)

#@torch.jit.script
def Yl88_m11(theta, phi):
    return 2.0934032419725e-21*(1.0 - cos(theta)**2)**5.5*(2.37461762082376e+46*cos(theta)**77 - 3.97036066201733e+47*cos(theta)**75 + 3.18432105118442e+48*cos(theta)**73 - 1.63126622271202e+49*cos(theta)**71 + 5.99659254946652e+49*cos(theta)**69 - 1.68479115222137e+50*cos(theta)**67 + 3.76270023996106e+50*cos(theta)**65 - 6.8592607354242e+50*cos(theta)**63 + 1.04007268759965e+51*cos(theta)**61 - 1.33007199043141e+51*cos(theta)**59 + 1.44952431568672e+51*cos(theta)**57 - 1.35685677878945e+51*cos(theta)**55 + 1.09745768872676e+51*cos(theta)**53 - 7.70400761622757e+50*cos(theta)**51 + 4.7088253646645e+50*cos(theta)**49 - 2.51137352782107e+50*cos(theta)**47 + 1.17017016533387e+50*cos(theta)**45 - 4.76539886335059e+49*cos(theta)**43 + 1.69549061213774e+49*cos(theta)**41 - 5.26430254431256e+48*cos(theta)**39 + 1.4236672209254e+48*cos(theta)**37 - 3.34448807455492e+47*cos(theta)**35 + 6.8009924961045e+46*cos(theta)**33 - 1.19181016858386e+46*cos(theta)**31 + 1.79002496250483e+45*cos(theta)**29 - 2.28897680244712e+44*cos(theta)**27 + 2.47209494664289e+43*cos(theta)**25 - 2.23314809994841e+42*cos(theta)**23 + 1.66761059411732e+41*cos(theta)**21 - 1.01477318100445e+40*cos(theta)**19 + 4.94376677925247e+38*cos(theta)**17 - 1.88598115561946e+37*cos(theta)**15 + 5.4764386432534e+35*cos(theta)**13 - 1.16615401084839e+34*cos(theta)**11 + 1.73066569337996e+32*cos(theta)**9 - 1.66365727534523e+30*cos(theta)**7 + 9.24254041858458e+27*cos(theta)**5 - 2.42522708438326e+25*cos(theta)**3 + 1.89569600134178e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl88_m12(theta, phi):
    return 2.38565440217662e-23*(1.0 - cos(theta)**2)**6*(1.8284555680343e+48*cos(theta)**76 - 2.977770496513e+49*cos(theta)**74 + 2.32455436736463e+50*cos(theta)**72 - 1.15819901812553e+51*cos(theta)**70 + 4.1376488591319e+51*cos(theta)**68 - 1.12881007198832e+52*cos(theta)**66 + 2.44575515597469e+52*cos(theta)**64 - 4.32133426331724e+52*cos(theta)**62 + 6.34444339435785e+52*cos(theta)**60 - 7.84742474354535e+52*cos(theta)**58 + 8.2622885994143e+52*cos(theta)**56 - 7.46271228334195e+52*cos(theta)**54 + 5.81652575025182e+52*cos(theta)**52 - 3.92904388427606e+52*cos(theta)**50 + 2.30732442868561e+52*cos(theta)**48 - 1.1803455580759e+52*cos(theta)**46 + 5.26576574400241e+51*cos(theta)**44 - 2.04912151124076e+51*cos(theta)**42 + 6.95151150976474e+50*cos(theta)**40 - 2.0530779922819e+50*cos(theta)**38 + 5.267568717424e+49*cos(theta)**36 - 1.17057082609422e+49*cos(theta)**34 + 2.24432752371448e+48*cos(theta)**32 - 3.69461152260997e+47*cos(theta)**30 + 5.19107239126401e+46*cos(theta)**28 - 6.18023736660723e+45*cos(theta)**26 + 6.18023736660723e+44*cos(theta)**24 - 5.13624062988135e+43*cos(theta)**22 + 3.50198224764637e+42*cos(theta)**20 - 1.92806904390846e+41*cos(theta)**18 + 8.4044035247292e+39*cos(theta)**16 - 2.82897173342919e+38*cos(theta)**14 + 7.11937023622942e+36*cos(theta)**12 - 1.28276941193323e+35*cos(theta)**10 + 1.55759912404197e+33*cos(theta)**8 - 1.16456009274166e+31*cos(theta)**6 + 4.62127020929229e+28*cos(theta)**4 - 7.27568125314977e+25*cos(theta)**2 + 1.89569600134178e+22)*cos(12*phi)

#@torch.jit.script
def Yl88_m13(theta, phi):
    return 2.72295238304572e-25*(1.0 - cos(theta)**2)**6.5*(1.38962623170607e+50*cos(theta)**75 - 2.20355016741962e+51*cos(theta)**73 + 1.67367914450253e+52*cos(theta)**71 - 8.10739312687873e+52*cos(theta)**69 + 2.81360122420969e+53*cos(theta)**67 - 7.4501464751229e+53*cos(theta)**65 + 1.5652832998238e+54*cos(theta)**63 - 2.67922724325669e+54*cos(theta)**61 + 3.80666603661471e+54*cos(theta)**59 - 4.5515063512563e+54*cos(theta)**57 + 4.62688161567201e+54*cos(theta)**55 - 4.02986463300465e+54*cos(theta)**53 + 3.02459339013094e+54*cos(theta)**51 - 1.96452194213803e+54*cos(theta)**49 + 1.10751572576909e+54*cos(theta)**47 - 5.42958956714915e+53*cos(theta)**45 + 2.31693692736106e+53*cos(theta)**43 - 8.60631034721117e+52*cos(theta)**41 + 2.7806046039059e+52*cos(theta)**39 - 7.80169637067122e+51*cos(theta)**37 + 1.89632473827264e+51*cos(theta)**35 - 3.97994080872035e+50*cos(theta)**33 + 7.18184807588635e+49*cos(theta)**31 - 1.10838345678299e+49*cos(theta)**29 + 1.45350026955392e+48*cos(theta)**27 - 1.60686171531788e+47*cos(theta)**25 + 1.48325696798574e+46*cos(theta)**23 - 1.1299729385739e+45*cos(theta)**21 + 7.00396449529275e+43*cos(theta)**19 - 3.47052427903524e+42*cos(theta)**17 + 1.34470456395667e+41*cos(theta)**15 - 3.96056042680086e+39*cos(theta)**13 + 8.5432442834753e+37*cos(theta)**11 - 1.28276941193323e+36*cos(theta)**9 + 1.24607929923357e+34*cos(theta)**7 - 6.98736055644995e+31*cos(theta)**5 + 1.84850808371692e+29*cos(theta)**3 - 1.45513625062995e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl88_m14(theta, phi):
    return 3.11321654068509e-27*(1.0 - cos(theta)**2)**7*(1.04221967377955e+52*cos(theta)**74 - 1.60859162221632e+53*cos(theta)**72 + 1.1883121925968e+54*cos(theta)**70 - 5.59410125754632e+54*cos(theta)**68 + 1.88511282022049e+55*cos(theta)**66 - 4.84259520882989e+55*cos(theta)**64 + 9.86128478888995e+55*cos(theta)**62 - 1.63432861838658e+56*cos(theta)**60 + 2.24593296160268e+56*cos(theta)**58 - 2.59435862021609e+56*cos(theta)**56 + 2.54478488861961e+56*cos(theta)**54 - 2.13582825549247e+56*cos(theta)**52 + 1.54254262896678e+56*cos(theta)**50 - 9.62615751647635e+55*cos(theta)**48 + 5.20532391111473e+55*cos(theta)**46 - 2.44331530521712e+55*cos(theta)**44 + 9.96282878765255e+54*cos(theta)**42 - 3.52858724235658e+54*cos(theta)**40 + 1.0844357955233e+54*cos(theta)**38 - 2.88662765714835e+53*cos(theta)**36 + 6.63713658395424e+52*cos(theta)**34 - 1.31338046687772e+52*cos(theta)**32 + 2.22637290352477e+51*cos(theta)**30 - 3.21431202467068e+50*cos(theta)**28 + 3.92445072779559e+49*cos(theta)**26 - 4.0171542882947e+48*cos(theta)**24 + 3.41149102636719e+47*cos(theta)**22 - 2.37294317100518e+46*cos(theta)**20 + 1.33075325410562e+45*cos(theta)**18 - 5.8998912743599e+43*cos(theta)**16 + 2.01705684593501e+42*cos(theta)**14 - 5.14872855484112e+40*cos(theta)**12 + 9.39756871182284e+38*cos(theta)**10 - 1.15449247073991e+37*cos(theta)**8 + 8.72255509463502e+34*cos(theta)**6 - 3.49368027822497e+32*cos(theta)**4 + 5.54552425115075e+29*cos(theta)**2 - 1.45513625062995e+26)*cos(14*phi)

#@torch.jit.script
def Yl88_m15(theta, phi):
    return 3.56594677784948e-29*(1.0 - cos(theta)**2)**7.5*(7.71242558596866e+53*cos(theta)**73 - 1.15818596799575e+55*cos(theta)**71 + 8.31818534817758e+55*cos(theta)**69 - 3.8039888551315e+56*cos(theta)**67 + 1.24417446134552e+57*cos(theta)**65 - 3.09926093365113e+57*cos(theta)**63 + 6.11399656911177e+57*cos(theta)**61 - 9.80597171031949e+57*cos(theta)**59 + 1.30264111772955e+58*cos(theta)**57 - 1.45284082732101e+58*cos(theta)**55 + 1.37418383985459e+58*cos(theta)**53 - 1.11063069285608e+58*cos(theta)**51 + 7.71271314483391e+57*cos(theta)**49 - 4.62055560790865e+57*cos(theta)**47 + 2.39444899911277e+57*cos(theta)**45 - 1.07505873429553e+57*cos(theta)**43 + 4.18438809081407e+56*cos(theta)**41 - 1.41143489694263e+56*cos(theta)**39 + 4.12085602298854e+55*cos(theta)**37 - 1.03918595657341e+55*cos(theta)**35 + 2.25662643854444e+54*cos(theta)**33 - 4.20281749400869e+53*cos(theta)**31 + 6.67911871057431e+52*cos(theta)**29 - 9.00007366907789e+51*cos(theta)**27 + 1.02035718922685e+51*cos(theta)**25 - 9.64117029190728e+49*cos(theta)**23 + 7.50528025800782e+48*cos(theta)**21 - 4.74588634201037e+47*cos(theta)**19 + 2.39535585739012e+46*cos(theta)**17 - 9.43982603897584e+44*cos(theta)**15 + 2.82387958430901e+43*cos(theta)**13 - 6.17847426580934e+41*cos(theta)**11 + 9.39756871182284e+39*cos(theta)**9 - 9.23593976591925e+37*cos(theta)**7 + 5.23353305678101e+35*cos(theta)**5 - 1.39747211128999e+33*cos(theta)**3 + 1.10910485023015e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl88_m16(theta, phi):
    return 4.09257603944502e-31*(1.0 - cos(theta)**2)**8*(5.63007067775712e+55*cos(theta)**72 - 8.22312037276983e+56*cos(theta)**70 + 5.73954789024253e+57*cos(theta)**68 - 2.5486725329381e+58*cos(theta)**66 + 8.08713399874591e+58*cos(theta)**64 - 1.95253438820021e+59*cos(theta)**62 + 3.72953790715818e+59*cos(theta)**60 - 5.7855233090885e+59*cos(theta)**58 + 7.42505437105845e+59*cos(theta)**56 - 7.99062455026556e+59*cos(theta)**54 + 7.28317435122931e+59*cos(theta)**52 - 5.66421653356602e+59*cos(theta)**50 + 3.77922944096861e+59*cos(theta)**48 - 2.17166113571706e+59*cos(theta)**46 + 1.07750204960075e+59*cos(theta)**44 - 4.62275255747079e+58*cos(theta)**42 + 1.71559911723377e+58*cos(theta)**40 - 5.50459609807627e+57*cos(theta)**38 + 1.52471672850576e+57*cos(theta)**36 - 3.63715084800692e+56*cos(theta)**34 + 7.44686724719665e+55*cos(theta)**32 - 1.30287342314269e+55*cos(theta)**30 + 1.93694442606655e+54*cos(theta)**28 - 2.43001989065103e+53*cos(theta)**26 + 2.55089297306714e+52*cos(theta)**24 - 2.21746916713867e+51*cos(theta)**22 + 1.57610885418164e+50*cos(theta)**20 - 9.0171840498197e+48*cos(theta)**18 + 4.0721049575632e+47*cos(theta)**16 - 1.41597390584638e+46*cos(theta)**14 + 3.67104345960172e+44*cos(theta)**12 - 6.79632169239028e+42*cos(theta)**10 + 8.45781184064055e+40*cos(theta)**8 - 6.46515783614347e+38*cos(theta)**6 + 2.61676652839051e+36*cos(theta)**4 - 4.19241633386997e+33*cos(theta)**2 + 1.10910485023015e+30)*cos(16*phi)

#@torch.jit.script
def Yl88_m17(theta, phi):
    return 4.7069096230179e-33*(1.0 - cos(theta)**2)**8.5*(4.05365088798513e+57*cos(theta)**71 - 5.75618426093888e+58*cos(theta)**69 + 3.90289256536492e+59*cos(theta)**67 - 1.68212387173915e+60*cos(theta)**65 + 5.17576575919738e+60*cos(theta)**63 - 1.21057132068413e+61*cos(theta)**61 + 2.23772274429491e+61*cos(theta)**59 - 3.35560351927133e+61*cos(theta)**57 + 4.15803044779273e+61*cos(theta)**55 - 4.3149372571434e+61*cos(theta)**53 + 3.78725066263924e+61*cos(theta)**51 - 2.83210826678301e+61*cos(theta)**49 + 1.81403013166493e+61*cos(theta)**47 - 9.98964122429849e+60*cos(theta)**45 + 4.74100901824329e+60*cos(theta)**43 - 1.94155607413773e+60*cos(theta)**41 + 6.86239646893508e+59*cos(theta)**39 - 2.09174651726898e+59*cos(theta)**37 + 5.48898022262073e+58*cos(theta)**35 - 1.23663128832235e+58*cos(theta)**33 + 2.38299751910293e+57*cos(theta)**31 - 3.90862026942808e+56*cos(theta)**29 + 5.42344439298634e+55*cos(theta)**27 - 6.31805171569268e+54*cos(theta)**25 + 6.12214313536112e+53*cos(theta)**23 - 4.87843216770509e+52*cos(theta)**21 + 3.15221770836329e+51*cos(theta)**19 - 1.62309312896755e+50*cos(theta)**17 + 6.51536793210113e+48*cos(theta)**15 - 1.98236346818493e+47*cos(theta)**13 + 4.40525215152206e+45*cos(theta)**11 - 6.79632169239027e+43*cos(theta)**9 + 6.76624947251244e+41*cos(theta)**7 - 3.87909470168608e+39*cos(theta)**5 + 1.0467066113562e+37*cos(theta)**3 - 8.38483266773994e+33*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl88_m18(theta, phi):
    return 5.42567470944355e-35*(1.0 - cos(theta)**2)**9*(2.87809213046944e+59*cos(theta)**70 - 3.97176714004783e+60*cos(theta)**68 + 2.6149380187945e+61*cos(theta)**66 - 1.09338051663045e+62*cos(theta)**64 + 3.26073242829435e+62*cos(theta)**62 - 7.38448505617319e+62*cos(theta)**60 + 1.320256419134e+63*cos(theta)**58 - 1.91269400598466e+63*cos(theta)**56 + 2.286916746286e+63*cos(theta)**54 - 2.286916746286e+63*cos(theta)**52 + 1.93149783794601e+63*cos(theta)**50 - 1.38773305072368e+63*cos(theta)**48 + 8.52594161882519e+62*cos(theta)**46 - 4.49533855093432e+62*cos(theta)**44 + 2.03863387784462e+62*cos(theta)**42 - 7.96037990396469e+61*cos(theta)**40 + 2.67633462288468e+61*cos(theta)**38 - 7.73946211389523e+60*cos(theta)**36 + 1.92114307791726e+60*cos(theta)**34 - 4.08088325146377e+59*cos(theta)**32 + 7.38729230921908e+58*cos(theta)**30 - 1.13349987813414e+58*cos(theta)**28 + 1.46432998610631e+57*cos(theta)**26 - 1.57951292892317e+56*cos(theta)**24 + 1.40809292113306e+55*cos(theta)**22 - 1.02447075521807e+54*cos(theta)**20 + 5.98921364589024e+52*cos(theta)**18 - 2.75925831924483e+51*cos(theta)**16 + 9.77305189815169e+49*cos(theta)**14 - 2.5770725086404e+48*cos(theta)**12 + 4.84577736667427e+46*cos(theta)**10 - 6.11668952315125e+44*cos(theta)**8 + 4.73637463075871e+42*cos(theta)**6 - 1.93954735084304e+40*cos(theta)**4 + 3.14011983406861e+37*cos(theta)**2 - 8.38483266773994e+33)*cos(18*phi)

#@torch.jit.script
def Yl88_m19(theta, phi):
    return 6.26921037573639e-37*(1.0 - cos(theta)**2)**9.5*(2.01466449132861e+61*cos(theta)**69 - 2.70080165523252e+62*cos(theta)**67 + 1.72585909240437e+63*cos(theta)**65 - 6.99763530643486e+63*cos(theta)**63 + 2.0216541055425e+64*cos(theta)**61 - 4.43069103370392e+64*cos(theta)**59 + 7.65748723097717e+64*cos(theta)**57 - 1.07110864335141e+65*cos(theta)**55 + 1.23493504299444e+65*cos(theta)**53 - 1.18919670806872e+65*cos(theta)**51 + 9.65748918973007e+64*cos(theta)**49 - 6.66111864347364e+64*cos(theta)**47 + 3.92193314465959e+64*cos(theta)**45 - 1.9779489624111e+64*cos(theta)**43 + 8.56226228694739e+63*cos(theta)**41 - 3.18415196158588e+63*cos(theta)**39 + 1.01700715669618e+63*cos(theta)**37 - 2.78620636100228e+62*cos(theta)**35 + 6.53188646491867e+61*cos(theta)**33 - 1.30588264046841e+61*cos(theta)**31 + 2.21618769276572e+60*cos(theta)**29 - 3.1737996587756e+59*cos(theta)**27 + 3.80725796387641e+58*cos(theta)**25 - 3.79083102941561e+57*cos(theta)**23 + 3.09780442649273e+56*cos(theta)**21 - 2.04894151043614e+55*cos(theta)**19 + 1.07805845626024e+54*cos(theta)**17 - 4.41481331079172e+52*cos(theta)**15 + 1.36822726574124e+51*cos(theta)**13 - 3.09248701036849e+49*cos(theta)**11 + 4.84577736667427e+47*cos(theta)**9 - 4.893351618521e+45*cos(theta)**7 + 2.84182477845523e+43*cos(theta)**5 - 7.75818940337217e+40*cos(theta)**3 + 6.28023966813721e+37*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl88_m20(theta, phi):
    return 7.26233737831782e-39*(1.0 - cos(theta)**2)**10*(1.39011849901674e+63*cos(theta)**68 - 1.80953710900579e+64*cos(theta)**66 + 1.12180841006284e+65*cos(theta)**64 - 4.40851024305396e+65*cos(theta)**62 + 1.23320900438092e+66*cos(theta)**60 - 2.61410770988531e+66*cos(theta)**58 + 4.36476772165699e+66*cos(theta)**56 - 5.89109753843275e+66*cos(theta)**54 + 6.54515572787054e+66*cos(theta)**52 - 6.06490321115048e+66*cos(theta)**50 + 4.73216970296773e+66*cos(theta)**48 - 3.13072576243261e+66*cos(theta)**46 + 1.76486991509682e+66*cos(theta)**44 - 8.50518053836774e+65*cos(theta)**42 + 3.51052753764843e+65*cos(theta)**40 - 1.24181926501849e+65*cos(theta)**38 + 3.76292647977586e+64*cos(theta)**36 - 9.75172226350799e+63*cos(theta)**34 + 2.15552253342316e+63*cos(theta)**32 - 4.04823618545206e+62*cos(theta)**30 + 6.4269443090206e+61*cos(theta)**28 - 8.56925907869413e+60*cos(theta)**26 + 9.51814490969102e+59*cos(theta)**24 - 8.7189113676559e+58*cos(theta)**22 + 6.50538929563473e+57*cos(theta)**20 - 3.89298886982866e+56*cos(theta)**18 + 1.83269937564241e+55*cos(theta)**16 - 6.62221996618759e+53*cos(theta)**14 + 1.77869544546361e+52*cos(theta)**12 - 3.40173571140533e+50*cos(theta)**10 + 4.36119963000684e+48*cos(theta)**8 - 3.4253461329647e+46*cos(theta)**6 + 1.42091238922761e+44*cos(theta)**4 - 2.32745682101165e+41*cos(theta)**2 + 6.28023966813721e+37)*cos(20*phi)

#@torch.jit.script
def Yl88_m21(theta, phi):
    return 8.43545892915952e-41*(1.0 - cos(theta)**2)**10.5*(9.45280579331383e+64*cos(theta)**67 - 1.19429449194382e+66*cos(theta)**65 + 7.17957382440217e+66*cos(theta)**63 - 2.73327635069346e+67*cos(theta)**61 + 7.39925402628554e+67*cos(theta)**59 - 1.51618247173348e+68*cos(theta)**57 + 2.44426992412791e+68*cos(theta)**55 - 3.18119267075368e+68*cos(theta)**53 + 3.40348097849268e+68*cos(theta)**51 - 3.03245160557524e+68*cos(theta)**49 + 2.27144145742451e+68*cos(theta)**47 - 1.440133850719e+68*cos(theta)**45 + 7.76542762642599e+67*cos(theta)**43 - 3.57217582611445e+67*cos(theta)**41 + 1.40421101505937e+67*cos(theta)**39 - 4.71891320707027e+66*cos(theta)**37 + 1.35465353271931e+66*cos(theta)**35 - 3.31558556959272e+65*cos(theta)**33 + 6.89767210695412e+64*cos(theta)**31 - 1.21447085563562e+64*cos(theta)**29 + 1.79954440652577e+63*cos(theta)**27 - 2.22800736046047e+62*cos(theta)**25 + 2.28435477832585e+61*cos(theta)**23 - 1.9181605008843e+60*cos(theta)**21 + 1.30107785912695e+59*cos(theta)**19 - 7.00737996569158e+57*cos(theta)**17 + 2.93231900102786e+56*cos(theta)**15 - 9.27110795266262e+54*cos(theta)**13 + 2.13443453455633e+53*cos(theta)**11 - 3.40173571140533e+51*cos(theta)**9 + 3.48895970400547e+49*cos(theta)**7 - 2.05520767977882e+47*cos(theta)**5 + 5.68364955691045e+44*cos(theta)**3 - 4.6549136420233e+41*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl88_m22(theta, phi):
    return 9.82595953556126e-43*(1.0 - cos(theta)**2)**11*(6.33337988152027e+66*cos(theta)**66 - 7.76291419763484e+67*cos(theta)**64 + 4.52313150937337e+68*cos(theta)**62 - 1.66729857392301e+69*cos(theta)**60 + 4.36555987550847e+69*cos(theta)**58 - 8.64224008888084e+69*cos(theta)**56 + 1.34434845827035e+70*cos(theta)**54 - 1.68603211549945e+70*cos(theta)**52 + 1.73577529903127e+70*cos(theta)**50 - 1.48590128673187e+70*cos(theta)**48 + 1.06757748498952e+70*cos(theta)**46 - 6.48060232823551e+69*cos(theta)**44 + 3.33913387936317e+69*cos(theta)**42 - 1.46459208870692e+69*cos(theta)**40 + 5.47642295873155e+68*cos(theta)**38 - 1.745997886616e+68*cos(theta)**36 + 4.74128736451759e+67*cos(theta)**34 - 1.0941432379656e+67*cos(theta)**32 + 2.13827835315578e+66*cos(theta)**30 - 3.52196548134329e+65*cos(theta)**28 + 4.85876989761957e+64*cos(theta)**26 - 5.57001840115119e+63*cos(theta)**24 + 5.25401599014944e+62*cos(theta)**22 - 4.02813705185702e+61*cos(theta)**20 + 2.4720479323412e+60*cos(theta)**18 - 1.19125459416757e+59*cos(theta)**16 + 4.39847850154179e+57*cos(theta)**14 - 1.20524403384614e+56*cos(theta)**12 + 2.34787798801196e+54*cos(theta)**10 - 3.0615621402648e+52*cos(theta)**8 + 2.44227179280383e+50*cos(theta)**6 - 1.02760383988941e+48*cos(theta)**4 + 1.70509486707314e+45*cos(theta)**2 - 4.6549136420233e+41)*cos(22*phi)

#@torch.jit.script
def Yl88_m23(theta, phi):
    return 1.14799901164874e-44*(1.0 - cos(theta)**2)**11.5*(4.18003072180338e+68*cos(theta)**65 - 4.9682650864863e+69*cos(theta)**63 + 2.80434153581149e+70*cos(theta)**61 - 1.00037914435381e+71*cos(theta)**59 + 2.53202472779491e+71*cos(theta)**57 - 4.83965444977327e+71*cos(theta)**55 + 7.2594816746599e+71*cos(theta)**53 - 8.76736700059715e+71*cos(theta)**51 + 8.67887649515634e+71*cos(theta)**49 - 7.13232617631297e+71*cos(theta)**47 + 4.91085643095179e+71*cos(theta)**45 - 2.85146502442362e+71*cos(theta)**43 + 1.40243622933253e+71*cos(theta)**41 - 5.8583683548277e+70*cos(theta)**39 + 2.08104072431799e+70*cos(theta)**37 - 6.2855923918176e+69*cos(theta)**35 + 1.61203770393598e+69*cos(theta)**33 - 3.50125836148991e+68*cos(theta)**31 + 6.41483505946733e+67*cos(theta)**29 - 9.86150334776121e+66*cos(theta)**27 + 1.26328017338109e+66*cos(theta)**25 - 1.33680441627628e+65*cos(theta)**23 + 1.15588351783288e+64*cos(theta)**21 - 8.05627410371405e+62*cos(theta)**19 + 4.44968627821416e+61*cos(theta)**17 - 1.90600735066811e+60*cos(theta)**15 + 6.15786990215851e+58*cos(theta)**13 - 1.44629284061537e+57*cos(theta)**11 + 2.34787798801196e+55*cos(theta)**9 - 2.44924971221184e+53*cos(theta)**7 + 1.4653630756823e+51*cos(theta)**5 - 4.11041535955764e+48*cos(theta)**3 + 3.41018973414627e+45*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl88_m24(theta, phi):
    return 1.34547559442794e-46*(1.0 - cos(theta)**2)**12*(2.7170199691722e+70*cos(theta)**64 - 3.13000700448637e+71*cos(theta)**62 + 1.71064833684501e+72*cos(theta)**60 - 5.90223695168745e+72*cos(theta)**58 + 1.4432540948431e+73*cos(theta)**56 - 2.6618099473753e+73*cos(theta)**54 + 3.84752528756975e+73*cos(theta)**52 - 4.47135717030455e+73*cos(theta)**50 + 4.25264948262661e+73*cos(theta)**48 - 3.35219330286709e+73*cos(theta)**46 + 2.20988539392831e+73*cos(theta)**44 - 1.22612996050216e+73*cos(theta)**42 + 5.74998854026339e+72*cos(theta)**40 - 2.2847636583828e+72*cos(theta)**38 + 7.69985067997656e+71*cos(theta)**36 - 2.19995733713616e+71*cos(theta)**34 + 5.31972442298873e+70*cos(theta)**32 - 1.08539009206187e+70*cos(theta)**30 + 1.86030216724552e+69*cos(theta)**28 - 2.66260590389553e+68*cos(theta)**26 + 3.15820043345272e+67*cos(theta)**24 - 3.07465015743545e+66*cos(theta)**22 + 2.42735538744904e+65*cos(theta)**20 - 1.53069207970567e+64*cos(theta)**18 + 7.56446667296406e+62*cos(theta)**16 - 2.85901102600217e+61*cos(theta)**14 + 8.00523087280606e+59*cos(theta)**12 - 1.59092212467691e+58*cos(theta)**10 + 2.11309018921077e+56*cos(theta)**8 - 1.71447479854829e+54*cos(theta)**6 + 7.32681537841149e+51*cos(theta)**4 - 1.23312460786729e+49*cos(theta)**2 + 3.41018973414627e+45)*cos(24*phi)

#@torch.jit.script
def Yl88_m25(theta, phi):
    return 1.58214621197398e-48*(1.0 - cos(theta)**2)**12.5*(1.7388927802702e+72*cos(theta)**63 - 1.94060434278155e+73*cos(theta)**61 + 1.026389002107e+74*cos(theta)**59 - 3.42329743197872e+74*cos(theta)**57 + 8.08222293112136e+74*cos(theta)**55 - 1.43737737158266e+75*cos(theta)**53 + 2.00071314953627e+75*cos(theta)**51 - 2.23567858515227e+75*cos(theta)**49 + 2.04127175166077e+75*cos(theta)**47 - 1.54200891931886e+75*cos(theta)**45 + 9.72349573328455e+74*cos(theta)**43 - 5.14974583410906e+74*cos(theta)**41 + 2.29999541610535e+74*cos(theta)**39 - 8.68210190185465e+73*cos(theta)**37 + 2.77194624479156e+73*cos(theta)**35 - 7.47985494626294e+72*cos(theta)**33 + 1.70231181535639e+72*cos(theta)**31 - 3.25617027618562e+71*cos(theta)**29 + 5.20884606828747e+70*cos(theta)**27 - 6.92277535012837e+69*cos(theta)**25 + 7.57968104028653e+68*cos(theta)**23 - 6.764230346358e+67*cos(theta)**21 + 4.85471077489809e+66*cos(theta)**19 - 2.75524574347021e+65*cos(theta)**17 + 1.21031466767425e+64*cos(theta)**15 - 4.00261543640303e+62*cos(theta)**13 + 9.60627704736728e+60*cos(theta)**11 - 1.59092212467691e+59*cos(theta)**9 + 1.69047215136861e+57*cos(theta)**7 - 1.02868487912897e+55*cos(theta)**5 + 2.9307261513646e+52*cos(theta)**3 - 2.46624921573458e+49*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl88_m26(theta, phi):
    return 1.86691229290973e-50*(1.0 - cos(theta)**2)**13*(1.09550245157023e+74*cos(theta)**62 - 1.18376864909674e+75*cos(theta)**60 + 6.05569511243132e+75*cos(theta)**58 - 1.95127953622787e+76*cos(theta)**56 + 4.44522261211675e+76*cos(theta)**54 - 7.6181000693881e+76*cos(theta)**52 + 1.0203637062635e+77*cos(theta)**50 - 1.09548250672461e+77*cos(theta)**48 + 9.59397723280562e+76*cos(theta)**46 - 6.93904013693488e+76*cos(theta)**44 + 4.18110316531236e+76*cos(theta)**42 - 2.11139579198472e+76*cos(theta)**40 + 8.96998212281088e+75*cos(theta)**38 - 3.21237770368622e+75*cos(theta)**36 + 9.70181185677046e+74*cos(theta)**34 - 2.46835213226677e+74*cos(theta)**32 + 5.27716662760482e+73*cos(theta)**30 - 9.44289380093828e+72*cos(theta)**28 + 1.40638843843762e+72*cos(theta)**26 - 1.73069383753209e+71*cos(theta)**24 + 1.7433266392659e+70*cos(theta)**22 - 1.42048837273518e+69*cos(theta)**20 + 9.22395047230636e+67*cos(theta)**18 - 4.68391776389935e+66*cos(theta)**16 + 1.81547200151138e+65*cos(theta)**14 - 5.20340006732394e+63*cos(theta)**12 + 1.0566904752104e+62*cos(theta)**10 - 1.43182991220921e+60*cos(theta)**8 + 1.18333050595803e+58*cos(theta)**6 - 5.14342439564487e+55*cos(theta)**4 + 8.79217845409379e+52*cos(theta)**2 - 2.46624921573458e+49)*cos(26*phi)

#@torch.jit.script
def Yl88_m27(theta, phi):
    return 2.21095116687289e-52*(1.0 - cos(theta)**2)**13.5*(6.79211519973542e+75*cos(theta)**61 - 7.10261189458047e+76*cos(theta)**59 + 3.51230316521017e+77*cos(theta)**57 - 1.09271654028761e+78*cos(theta)**55 + 2.40042021054304e+78*cos(theta)**53 - 3.96141203608181e+78*cos(theta)**51 + 5.10181853131749e+78*cos(theta)**49 - 5.25831603227815e+78*cos(theta)**47 + 4.41322952709059e+78*cos(theta)**45 - 3.05317766025135e+78*cos(theta)**43 + 1.75606332943119e+78*cos(theta)**41 - 8.44558316793886e+77*cos(theta)**39 + 3.40859320666814e+77*cos(theta)**37 - 1.15645597332704e+77*cos(theta)**35 + 3.29861603130196e+76*cos(theta)**33 - 7.89872682325367e+75*cos(theta)**31 + 1.58314998828145e+75*cos(theta)**29 - 2.64401026426272e+74*cos(theta)**27 + 3.6566099399378e+73*cos(theta)**25 - 4.15366521007702e+72*cos(theta)**23 + 3.83531860638499e+71*cos(theta)**21 - 2.84097674547036e+70*cos(theta)**19 + 1.66031108501515e+69*cos(theta)**17 - 7.49426842223896e+67*cos(theta)**15 + 2.54166080211593e+66*cos(theta)**13 - 6.24408008078873e+64*cos(theta)**11 + 1.0566904752104e+63*cos(theta)**9 - 1.14546392976737e+61*cos(theta)**7 + 7.09998303574817e+58*cos(theta)**5 - 2.05736975825795e+56*cos(theta)**3 + 1.75843569081876e+53*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl88_m28(theta, phi):
    return 2.6283623549957e-54*(1.0 - cos(theta)**2)**14*(4.14319027183861e+77*cos(theta)**60 - 4.19054101780248e+78*cos(theta)**58 + 2.0020128041698e+79*cos(theta)**56 - 6.00994097158184e+79*cos(theta)**54 + 1.27222271158781e+80*cos(theta)**52 - 2.02032013840172e+80*cos(theta)**50 + 2.49989108034557e+80*cos(theta)**48 - 2.47140853517073e+80*cos(theta)**46 + 1.98595328719076e+80*cos(theta)**44 - 1.31286639390808e+80*cos(theta)**42 + 7.19985965066788e+79*cos(theta)**40 - 3.29377743549616e+79*cos(theta)**38 + 1.26117948646721e+79*cos(theta)**36 - 4.04759590664464e+78*cos(theta)**34 + 1.08854329032965e+78*cos(theta)**32 - 2.44860531520864e+77*cos(theta)**30 + 4.59113496601619e+76*cos(theta)**28 - 7.13882771350934e+75*cos(theta)**26 + 9.14152484984451e+74*cos(theta)**24 - 9.55342998317715e+73*cos(theta)**22 + 8.05416907340847e+72*cos(theta)**20 - 5.39785581639368e+71*cos(theta)**18 + 2.82252884452575e+70*cos(theta)**16 - 1.12414026333584e+69*cos(theta)**14 + 3.3041590427507e+67*cos(theta)**12 - 6.8684880888676e+65*cos(theta)**10 + 9.5102142768936e+63*cos(theta)**8 - 8.0182475083716e+61*cos(theta)**6 + 3.54999151787409e+59*cos(theta)**4 - 6.17210927477384e+56*cos(theta)**2 + 1.75843569081876e+53)*cos(28*phi)

#@torch.jit.script
def Yl88_m29(theta, phi):
    return 3.13701562796289e-56*(1.0 - cos(theta)**2)**14.5*(2.48591416310316e+79*cos(theta)**59 - 2.43051379032544e+80*cos(theta)**57 + 1.12112717033509e+81*cos(theta)**55 - 3.2453681246542e+81*cos(theta)**53 + 6.61555810025663e+81*cos(theta)**51 - 1.01016006920086e+82*cos(theta)**49 + 1.19994771856587e+82*cos(theta)**47 - 1.13684792617854e+82*cos(theta)**45 + 8.73819446363936e+81*cos(theta)**43 - 5.51403885441394e+81*cos(theta)**41 + 2.87994386026715e+81*cos(theta)**39 - 1.25163542548854e+81*cos(theta)**37 + 4.54024615128196e+80*cos(theta)**35 - 1.37618260825918e+80*cos(theta)**33 + 3.48333852905487e+79*cos(theta)**31 - 7.34581594562591e+78*cos(theta)**29 + 1.28551779048453e+78*cos(theta)**27 - 1.85609520551243e+77*cos(theta)**25 + 2.19396596396268e+76*cos(theta)**23 - 2.10175459629897e+75*cos(theta)**21 + 1.61083381468169e+74*cos(theta)**19 - 9.71614046950863e+72*cos(theta)**17 + 4.5160461512412e+71*cos(theta)**15 - 1.57379636867018e+70*cos(theta)**13 + 3.96499085130084e+68*cos(theta)**11 - 6.8684880888676e+66*cos(theta)**9 + 7.60817142151488e+64*cos(theta)**7 - 4.81094850502296e+62*cos(theta)**5 + 1.41999660714963e+60*cos(theta)**3 - 1.23442185495477e+57*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl88_m30(theta, phi):
    return 3.7596695308826e-58*(1.0 - cos(theta)**2)**15*(1.46668935623087e+81*cos(theta)**58 - 1.3853928604855e+82*cos(theta)**56 + 6.16619943684297e+82*cos(theta)**54 - 1.72004510606672e+83*cos(theta)**52 + 3.37393463113088e+83*cos(theta)**50 - 4.94978433908423e+83*cos(theta)**48 + 5.6397542772596e+83*cos(theta)**46 - 5.11581566780341e+83*cos(theta)**44 + 3.75742361936493e+83*cos(theta)**42 - 2.26075593030971e+83*cos(theta)**40 + 1.12317810550419e+83*cos(theta)**38 - 4.6310510743076e+82*cos(theta)**36 + 1.58908615294868e+82*cos(theta)**34 - 4.54140260725528e+81*cos(theta)**32 + 1.07983494400701e+81*cos(theta)**30 - 2.13028662423151e+80*cos(theta)**28 + 3.47089803430824e+79*cos(theta)**26 - 4.64023801378107e+78*cos(theta)**24 + 5.04612171711417e+77*cos(theta)**22 - 4.41368465222784e+76*cos(theta)**20 + 3.06058424789522e+75*cos(theta)**18 - 1.65174387981647e+74*cos(theta)**16 + 6.77406922686179e+72*cos(theta)**14 - 2.04593527927124e+71*cos(theta)**12 + 4.36148993643093e+69*cos(theta)**10 - 6.18163927998084e+67*cos(theta)**8 + 5.32571999506042e+65*cos(theta)**6 - 2.40547425251148e+63*cos(theta)**4 + 4.2599898214489e+60*cos(theta)**2 - 1.23442185495477e+57)*cos(30*phi)

#@torch.jit.script
def Yl88_m31(theta, phi):
    return 4.52545442251838e-60*(1.0 - cos(theta)**2)**15.5*(8.50679826613903e+82*cos(theta)**57 - 7.75820001871879e+83*cos(theta)**55 + 3.3297476958952e+84*cos(theta)**53 - 8.94423455154696e+84*cos(theta)**51 + 1.68696731556544e+85*cos(theta)**49 - 2.37589648276043e+85*cos(theta)**47 + 2.59428696753942e+85*cos(theta)**45 - 2.2509588938335e+85*cos(theta)**43 + 1.57811792013327e+85*cos(theta)**41 - 9.04302372123886e+84*cos(theta)**39 + 4.26807680091592e+84*cos(theta)**37 - 1.66717838675073e+84*cos(theta)**35 + 5.40289292002553e+83*cos(theta)**33 - 1.45324883432169e+83*cos(theta)**31 + 3.23950483202103e+82*cos(theta)**29 - 5.96480254784824e+81*cos(theta)**27 + 9.02433488920143e+80*cos(theta)**25 - 1.11365712330746e+80*cos(theta)**23 + 1.11014677776512e+79*cos(theta)**21 - 8.82736930445568e+77*cos(theta)**19 + 5.50905164621139e+76*cos(theta)**17 - 2.64279020770635e+75*cos(theta)**15 + 9.48369691760651e+73*cos(theta)**13 - 2.45512233512548e+72*cos(theta)**11 + 4.36148993643093e+70*cos(theta)**9 - 4.94531142398467e+68*cos(theta)**7 + 3.19543199703625e+66*cos(theta)**5 - 9.62189701004592e+63*cos(theta)**3 + 8.51997964289781e+60*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl88_m32(theta, phi):
    return 5.47184950748734e-62*(1.0 - cos(theta)**2)**16*(4.84887501169925e+84*cos(theta)**56 - 4.26701001029534e+85*cos(theta)**54 + 1.76476627882446e+86*cos(theta)**52 - 4.56155962128895e+86*cos(theta)**50 + 8.26613984627066e+86*cos(theta)**48 - 1.1166713468974e+87*cos(theta)**46 + 1.16742913539274e+87*cos(theta)**44 - 9.67912324348405e+86*cos(theta)**42 + 6.4702834725464e+86*cos(theta)**40 - 3.52677925128315e+86*cos(theta)**38 + 1.57918841633889e+86*cos(theta)**36 - 5.83512435362757e+85*cos(theta)**34 + 1.78295466360842e+85*cos(theta)**32 - 4.50507138639724e+84*cos(theta)**30 + 9.39456401286098e+83*cos(theta)**28 - 1.61049668791902e+83*cos(theta)**26 + 2.25608372230036e+82*cos(theta)**24 - 2.56141138360715e+81*cos(theta)**22 + 2.33130823330675e+80*cos(theta)**20 - 1.67720016784658e+79*cos(theta)**18 + 9.36538779855937e+77*cos(theta)**16 - 3.96418531155952e+76*cos(theta)**14 + 1.23288059928885e+75*cos(theta)**12 - 2.70063456863803e+73*cos(theta)**10 + 3.92534094278784e+71*cos(theta)**8 - 3.46171799678927e+69*cos(theta)**6 + 1.59771599851813e+67*cos(theta)**4 - 2.88656910301378e+64*cos(theta)**2 + 8.51997964289781e+60)*cos(32*phi)

#@torch.jit.script
def Yl88_m33(theta, phi):
    return 6.64733315876798e-64*(1.0 - cos(theta)**2)**16.5*(2.71537000655158e+86*cos(theta)**55 - 2.30418540555948e+87*cos(theta)**53 + 9.17678464988718e+87*cos(theta)**51 - 2.28077981064448e+88*cos(theta)**49 + 3.96774712620992e+88*cos(theta)**47 - 5.13668819572805e+88*cos(theta)**45 + 5.13668819572805e+88*cos(theta)**43 - 4.0652317622633e+88*cos(theta)**41 + 2.58811338901856e+88*cos(theta)**39 - 1.3401761154876e+88*cos(theta)**37 + 5.68507829882e+87*cos(theta)**35 - 1.98394228023337e+87*cos(theta)**33 + 5.70545492354696e+86*cos(theta)**31 - 1.35152141591917e+86*cos(theta)**29 + 2.63047792360107e+85*cos(theta)**27 - 4.18729138858946e+84*cos(theta)**25 + 5.41460093352086e+83*cos(theta)**23 - 5.63510504393574e+82*cos(theta)**21 + 4.66261646661349e+81*cos(theta)**19 - 3.01896030212384e+80*cos(theta)**17 + 1.4984620477695e+79*cos(theta)**15 - 5.54985943618333e+77*cos(theta)**13 + 1.47945671914662e+76*cos(theta)**11 - 2.70063456863803e+74*cos(theta)**9 + 3.14027275423027e+72*cos(theta)**7 - 2.07703079807356e+70*cos(theta)**5 + 6.3908639940725e+67*cos(theta)**3 - 5.77313820602755e+64*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl88_m34(theta, phi):
    return 8.11495630503163e-66*(1.0 - cos(theta)**2)**17*(1.49345350360337e+88*cos(theta)**54 - 1.22121826494653e+89*cos(theta)**52 + 4.68016017144246e+89*cos(theta)**50 - 1.11758210721579e+90*cos(theta)**48 + 1.86484114931866e+90*cos(theta)**46 - 2.31150968807762e+90*cos(theta)**44 + 2.20877592416306e+90*cos(theta)**42 - 1.66674502252795e+90*cos(theta)**40 + 1.00936422171724e+90*cos(theta)**38 - 4.95865162730411e+89*cos(theta)**36 + 1.989777404587e+89*cos(theta)**34 - 6.54700952477013e+88*cos(theta)**32 + 1.76869102629956e+88*cos(theta)**30 - 3.9194121061656e+87*cos(theta)**28 + 7.1022903937229e+86*cos(theta)**26 - 1.04682284714737e+86*cos(theta)**24 + 1.2453582147098e+85*cos(theta)**22 - 1.1833720592265e+84*cos(theta)**20 + 8.85897128656564e+82*cos(theta)**18 - 5.13223251361054e+81*cos(theta)**16 + 2.24769307165425e+80*cos(theta)**14 - 7.21481726703833e+78*cos(theta)**12 + 1.62740239106128e+77*cos(theta)**10 - 2.43057111177423e+75*cos(theta)**8 + 2.19819092796119e+73*cos(theta)**6 - 1.03851539903678e+71*cos(theta)**4 + 1.91725919822175e+68*cos(theta)**2 - 5.77313820602755e+64)*cos(34*phi)

#@torch.jit.script
def Yl88_m35(theta, phi):
    return 9.9571889866149e-68*(1.0 - cos(theta)**2)**17.5*(8.06464891945818e+89*cos(theta)**53 - 6.35033497772193e+90*cos(theta)**51 + 2.34008008572123e+91*cos(theta)**49 - 5.36439411463581e+91*cos(theta)**47 + 8.57826928686584e+91*cos(theta)**45 - 1.01706426275415e+92*cos(theta)**43 + 9.27685888148485e+91*cos(theta)**41 - 6.66698009011181e+91*cos(theta)**39 + 3.83558404252551e+91*cos(theta)**37 - 1.78511458582948e+91*cos(theta)**35 + 6.7652431755958e+90*cos(theta)**33 - 2.09504304792644e+90*cos(theta)**31 + 5.30607307889867e+89*cos(theta)**29 - 1.09743538972637e+89*cos(theta)**27 + 1.84659550236795e+88*cos(theta)**25 - 2.51237483315368e+87*cos(theta)**23 + 2.73978807236155e+86*cos(theta)**21 - 2.36674411845301e+85*cos(theta)**19 + 1.59461483158181e+84*cos(theta)**17 - 8.21157202177686e+82*cos(theta)**15 + 3.14677030031595e+81*cos(theta)**13 - 8.657780720446e+79*cos(theta)**11 + 1.62740239106128e+78*cos(theta)**9 - 1.94445688941938e+76*cos(theta)**7 + 1.31891455677671e+74*cos(theta)**5 - 4.15406159614713e+71*cos(theta)**3 + 3.8345183964435e+68*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl88_m36(theta, phi):
    return 1.22825339347686e-69*(1.0 - cos(theta)**2)**18*(4.27426392731284e+91*cos(theta)**52 - 3.23867083863818e+92*cos(theta)**50 + 1.1466392420034e+93*cos(theta)**48 - 2.52126523387883e+93*cos(theta)**46 + 3.86022117908963e+93*cos(theta)**44 - 4.37337632984286e+93*cos(theta)**42 + 3.80351214140879e+93*cos(theta)**40 - 2.60012223514361e+93*cos(theta)**38 + 1.41916609573444e+93*cos(theta)**36 - 6.24790105040318e+92*cos(theta)**34 + 2.23253024794662e+92*cos(theta)**32 - 6.49463344857197e+91*cos(theta)**30 + 1.53876119288061e+91*cos(theta)**28 - 2.96307555226119e+90*cos(theta)**26 + 4.61648875591988e+89*cos(theta)**24 - 5.77846211625346e+88*cos(theta)**22 + 5.75355495195926e+87*cos(theta)**20 - 4.49681382506072e+86*cos(theta)**18 + 2.71084521368908e+85*cos(theta)**16 - 1.23173580326653e+84*cos(theta)**14 + 4.09080139041073e+82*cos(theta)**12 - 9.5235587924906e+80*cos(theta)**10 + 1.46466215195515e+79*cos(theta)**8 - 1.36111982259357e+77*cos(theta)**6 + 6.59457278388356e+74*cos(theta)**4 - 1.24621847884414e+72*cos(theta)**2 + 3.8345183964435e+68)*cos(36*phi)

#@torch.jit.script
def Yl88_m37(theta, phi):
    return 1.52346083668197e-71*(1.0 - cos(theta)**2)**18.5*(2.22261724220268e+93*cos(theta)**51 - 1.61933541931909e+94*cos(theta)**49 + 5.50386836161634e+94*cos(theta)**47 - 1.15978200758426e+95*cos(theta)**45 + 1.69849731879944e+95*cos(theta)**43 - 1.836818058534e+95*cos(theta)**41 + 1.52140485656352e+95*cos(theta)**39 - 9.88046449354571e+94*cos(theta)**37 + 5.10899794464398e+94*cos(theta)**35 - 2.12428635713708e+94*cos(theta)**33 + 7.14409679342917e+93*cos(theta)**31 - 1.94839003457159e+93*cos(theta)**29 + 4.30853134006572e+92*cos(theta)**27 - 7.7039964358791e+91*cos(theta)**25 + 1.10795730142077e+91*cos(theta)**23 - 1.27126166557576e+90*cos(theta)**21 + 1.15071099039185e+89*cos(theta)**19 - 8.09426488510929e+87*cos(theta)**17 + 4.33735234190254e+86*cos(theta)**15 - 1.72443012457314e+85*cos(theta)**13 + 4.90896166849288e+83*cos(theta)**11 - 9.5235587924906e+81*cos(theta)**9 + 1.17172972156412e+80*cos(theta)**7 - 8.16671893556141e+77*cos(theta)**5 + 2.63782911355343e+75*cos(theta)**3 - 2.49243695768828e+72*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl88_m38(theta, phi):
    return 1.90046962962022e-73*(1.0 - cos(theta)**2)**19*(1.13353479352336e+95*cos(theta)**50 - 7.93474355466355e+95*cos(theta)**48 + 2.58681812995968e+96*cos(theta)**46 - 5.21901903412917e+96*cos(theta)**44 + 7.30353847083757e+96*cos(theta)**42 - 7.5309540399894e+96*cos(theta)**40 + 5.93347894059771e+96*cos(theta)**38 - 3.65577186261191e+96*cos(theta)**36 + 1.78814928062539e+96*cos(theta)**34 - 7.01014497855237e+95*cos(theta)**32 + 2.21467000596304e+95*cos(theta)**30 - 5.65033110025762e+94*cos(theta)**28 + 1.16330346181774e+94*cos(theta)**26 - 1.92599910896978e+93*cos(theta)**24 + 2.54830179326778e+92*cos(theta)**22 - 2.6696494977091e+91*cos(theta)**20 + 2.18635088174452e+90*cos(theta)**18 - 1.37602503046858e+89*cos(theta)**16 + 6.5060285128538e+87*cos(theta)**14 - 2.24175916194508e+86*cos(theta)**12 + 5.39985783534217e+84*cos(theta)**10 - 8.57120291324154e+82*cos(theta)**8 + 8.20210805094884e+80*cos(theta)**6 - 4.0833594677807e+78*cos(theta)**4 + 7.91348734066028e+75*cos(theta)**2 - 2.49243695768828e+72)*cos(38*phi)

#@torch.jit.script
def Yl88_m39(theta, phi):
    return 2.38492140318794e-75*(1.0 - cos(theta)**2)**19.5*(5.66767396761682e+96*cos(theta)**49 - 3.80867690623851e+97*cos(theta)**47 + 1.18993633978145e+98*cos(theta)**45 - 2.29636837501684e+98*cos(theta)**43 + 3.06748615775178e+98*cos(theta)**41 - 3.01238161599576e+98*cos(theta)**39 + 2.25472199742713e+98*cos(theta)**37 - 1.31607787054029e+98*cos(theta)**35 + 6.07970755412633e+97*cos(theta)**33 - 2.24324639313676e+97*cos(theta)**31 + 6.64401001788913e+96*cos(theta)**29 - 1.58209270807213e+96*cos(theta)**27 + 3.02458900072614e+95*cos(theta)**25 - 4.62239786152746e+94*cos(theta)**23 + 5.60626394518911e+93*cos(theta)**21 - 5.3392989954182e+92*cos(theta)**19 + 3.93543158714014e+91*cos(theta)**17 - 2.20164004874973e+90*cos(theta)**15 + 9.10843991799532e+88*cos(theta)**13 - 2.6901109943341e+87*cos(theta)**11 + 5.39985783534217e+85*cos(theta)**9 - 6.85696233059323e+83*cos(theta)**7 + 4.9212648305693e+81*cos(theta)**5 - 1.63334378711228e+79*cos(theta)**3 + 1.58269746813206e+76*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl88_m40(theta, phi):
    return 3.01141802998416e-77*(1.0 - cos(theta)**2)**20*(2.77716024413224e+98*cos(theta)**48 - 1.7900781459321e+99*cos(theta)**46 + 5.35471352901653e+99*cos(theta)**44 - 9.8743840125724e+99*cos(theta)**42 + 1.25766932467823e+100*cos(theta)**40 - 1.17482883023835e+100*cos(theta)**38 + 8.34247139048038e+99*cos(theta)**36 - 4.60627254689101e+99*cos(theta)**34 + 2.00630349286169e+99*cos(theta)**32 - 6.95406381872395e+98*cos(theta)**30 + 1.92676290518785e+98*cos(theta)**28 - 4.27165031179476e+97*cos(theta)**26 + 7.56147250181534e+96*cos(theta)**24 - 1.06315150815132e+96*cos(theta)**22 + 1.17731542848971e+95*cos(theta)**20 - 1.01446680912946e+94*cos(theta)**18 + 6.69023369813823e+92*cos(theta)**16 - 3.30246007312459e+91*cos(theta)**14 + 1.18409718933939e+90*cos(theta)**12 - 2.95912209376751e+88*cos(theta)**10 + 4.85987205180795e+86*cos(theta)**8 - 4.79987363141526e+84*cos(theta)**6 + 2.46063241528465e+82*cos(theta)**4 - 4.90003136133684e+79*cos(theta)**2 + 1.58269746813206e+76)*cos(40*phi)

#@torch.jit.script
def Yl88_m41(theta, phi):
    return 3.82697453538678e-79*(1.0 - cos(theta)**2)**20.5*(1.33303691718348e+100*cos(theta)**47 - 8.23435947128765e+100*cos(theta)**45 + 2.35607395276727e+101*cos(theta)**43 - 4.14724128528041e+101*cos(theta)**41 + 5.03067729871292e+101*cos(theta)**39 - 4.46434955490572e+101*cos(theta)**37 + 3.00328970057294e+101*cos(theta)**35 - 1.56613266594294e+101*cos(theta)**33 + 6.42017117715741e+100*cos(theta)**31 - 2.08621914561719e+100*cos(theta)**29 + 5.39493613452597e+99*cos(theta)**27 - 1.11062908106664e+99*cos(theta)**25 + 1.81475340043568e+98*cos(theta)**23 - 2.3389333179329e+97*cos(theta)**21 + 2.35463085697943e+96*cos(theta)**19 - 1.82604025643302e+95*cos(theta)**17 + 1.07043739170212e+94*cos(theta)**15 - 4.62344410237443e+92*cos(theta)**13 + 1.42091662720727e+91*cos(theta)**11 - 2.95912209376751e+89*cos(theta)**9 + 3.88789764144636e+87*cos(theta)**7 - 2.87992417884916e+85*cos(theta)**5 + 9.84252966113861e+82*cos(theta)**3 - 9.80006272267369e+79*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl88_m42(theta, phi):
    return 4.89592737905498e-81*(1.0 - cos(theta)**2)**21*(6.26527351076234e+101*cos(theta)**46 - 3.70546176207944e+102*cos(theta)**44 + 1.01311179968993e+103*cos(theta)**42 - 1.70036892696497e+103*cos(theta)**40 + 1.96196414649804e+103*cos(theta)**38 - 1.65180933531512e+103*cos(theta)**36 + 1.05115139520053e+103*cos(theta)**34 - 5.16823779761171e+102*cos(theta)**32 + 1.9902530649188e+102*cos(theta)**30 - 6.05003552228984e+101*cos(theta)**28 + 1.45663275632201e+101*cos(theta)**26 - 2.77657270266659e+100*cos(theta)**24 + 4.17393282100207e+99*cos(theta)**22 - 4.91175996765908e+98*cos(theta)**20 + 4.47379862826091e+97*cos(theta)**18 - 3.10426843593614e+96*cos(theta)**16 + 1.60565608755318e+95*cos(theta)**14 - 6.01047733308675e+93*cos(theta)**12 + 1.563008289928e+92*cos(theta)**10 - 2.66320988439076e+90*cos(theta)**8 + 2.72152834901245e+88*cos(theta)**6 - 1.43996208942458e+86*cos(theta)**4 + 2.95275889834158e+83*cos(theta)**2 - 9.80006272267369e+79)*cos(42*phi)

#@torch.jit.script
def Yl88_m43(theta, phi):
    return 6.30696474934279e-83*(1.0 - cos(theta)**2)**21.5*(2.88202581495068e+103*cos(theta)**45 - 1.63040317531495e+104*cos(theta)**43 + 4.2550695586977e+104*cos(theta)**41 - 6.80147570785987e+104*cos(theta)**39 + 7.45546375669255e+104*cos(theta)**37 - 5.94651360713442e+104*cos(theta)**35 + 3.5739147436818e+104*cos(theta)**33 - 1.65383609523575e+104*cos(theta)**31 + 5.97075919475639e+103*cos(theta)**29 - 1.69400994624116e+103*cos(theta)**27 + 3.78724516643723e+102*cos(theta)**25 - 6.66377448639982e+101*cos(theta)**23 + 9.18265220620455e+100*cos(theta)**21 - 9.82351993531816e+99*cos(theta)**19 + 8.05283753086963e+98*cos(theta)**17 - 4.96682949749782e+97*cos(theta)**15 + 2.24791852257445e+96*cos(theta)**13 - 7.2125727997041e+94*cos(theta)**11 + 1.563008289928e+93*cos(theta)**9 - 2.13056790751261e+91*cos(theta)**7 + 1.63291700940747e+89*cos(theta)**5 - 5.75984835769831e+86*cos(theta)**3 + 5.90551779668316e+83*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl88_m44(theta, phi):
    return 8.18327566371218e-85*(1.0 - cos(theta)**2)**22*(1.2969116167278e+105*cos(theta)**44 - 7.0107336538543e+105*cos(theta)**42 + 1.74457851906606e+106*cos(theta)**40 - 2.65257552606535e+106*cos(theta)**38 + 2.75852158997624e+106*cos(theta)**36 - 2.08127976249705e+106*cos(theta)**34 + 1.17939186541499e+106*cos(theta)**32 - 5.12689189523082e+105*cos(theta)**30 + 1.73152016647935e+105*cos(theta)**28 - 4.57382685485112e+104*cos(theta)**26 + 9.46811291609308e+103*cos(theta)**24 - 1.53266813187196e+103*cos(theta)**22 + 1.92835696330296e+102*cos(theta)**20 - 1.86646878771045e+101*cos(theta)**18 + 1.36898238024784e+100*cos(theta)**16 - 7.45024424624674e+98*cos(theta)**14 + 2.92229407934678e+97*cos(theta)**12 - 7.93383007967452e+95*cos(theta)**10 + 1.4067074609352e+94*cos(theta)**8 - 1.49139753525882e+92*cos(theta)**6 + 8.16458504703736e+89*cos(theta)**4 - 1.72795450730949e+87*cos(theta)**2 + 5.90551779668316e+83)*cos(44*phi)

#@torch.jit.script
def Yl88_m45(theta, phi):
    return 1.06973208606581e-86*(1.0 - cos(theta)**2)**22.5*(5.70641111360234e+106*cos(theta)**43 - 2.94450813461881e+107*cos(theta)**41 + 6.97831407626423e+107*cos(theta)**39 - 1.00797869990483e+108*cos(theta)**37 + 9.93067772391447e+107*cos(theta)**35 - 7.07635119248995e+107*cos(theta)**33 + 3.77405396932798e+107*cos(theta)**31 - 1.53806756856925e+107*cos(theta)**29 + 4.84825646614219e+106*cos(theta)**27 - 1.18919498226129e+106*cos(theta)**25 + 2.27234709986234e+105*cos(theta)**23 - 3.37186989011831e+104*cos(theta)**21 + 3.85671392660591e+103*cos(theta)**19 - 3.35964381787881e+102*cos(theta)**17 + 2.19037180839654e+101*cos(theta)**15 - 1.04303419447454e+100*cos(theta)**13 + 3.50675289521614e+98*cos(theta)**11 - 7.93383007967452e+96*cos(theta)**9 + 1.12536596874816e+95*cos(theta)**7 - 8.94838521155294e+92*cos(theta)**5 + 3.26583401881494e+90*cos(theta)**3 - 3.45590901461899e+87*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl88_m46(theta, phi):
    return 1.40925114213237e-88*(1.0 - cos(theta)**2)**23*(2.45375677884901e+108*cos(theta)**42 - 1.20724833519371e+109*cos(theta)**40 + 2.72154248974305e+109*cos(theta)**38 - 3.72952118964788e+109*cos(theta)**36 + 3.47573720337007e+109*cos(theta)**34 - 2.33519589352168e+109*cos(theta)**32 + 1.16995673049167e+109*cos(theta)**30 - 4.46039594885081e+108*cos(theta)**28 + 1.30902924585839e+108*cos(theta)**26 - 2.97298745565323e+107*cos(theta)**24 + 5.22639832968338e+106*cos(theta)**22 - 7.08092676924845e+105*cos(theta)**20 + 7.32775646055123e+104*cos(theta)**18 - 5.71139449039398e+103*cos(theta)**16 + 3.28555771259481e+102*cos(theta)**14 - 1.35594445281691e+101*cos(theta)**12 + 3.85742818473775e+99*cos(theta)**10 - 7.14044707170706e+97*cos(theta)**8 + 7.87756178123711e+95*cos(theta)**6 - 4.47419260577647e+93*cos(theta)**4 + 9.79750205644483e+90*cos(theta)**2 - 3.45590901461899e+87)*cos(46*phi)

#@torch.jit.script
def Yl88_m47(theta, phi):
    return 1.87153031423753e-90*(1.0 - cos(theta)**2)**23.5*(1.03057784711658e+110*cos(theta)**41 - 4.82899334077484e+110*cos(theta)**39 + 1.03418614610236e+111*cos(theta)**37 - 1.34262762827324e+111*cos(theta)**35 + 1.18175064914582e+111*cos(theta)**33 - 7.47262685926939e+110*cos(theta)**31 + 3.50987019147502e+110*cos(theta)**29 - 1.24891086567823e+110*cos(theta)**27 + 3.40347603923181e+109*cos(theta)**25 - 7.13516989356775e+108*cos(theta)**23 + 1.14980763253034e+108*cos(theta)**21 - 1.41618535384969e+107*cos(theta)**19 + 1.31899616289922e+106*cos(theta)**17 - 9.13823118463037e+104*cos(theta)**15 + 4.59978079763274e+103*cos(theta)**13 - 1.62713334338029e+102*cos(theta)**11 + 3.85742818473775e+100*cos(theta)**9 - 5.71235765736565e+98*cos(theta)**7 + 4.72653706874226e+96*cos(theta)**5 - 1.78967704231059e+94*cos(theta)**3 + 1.95950041128897e+91*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl88_m48(theta, phi):
    return 2.50631401985519e-92*(1.0 - cos(theta)**2)**24*(4.22536917317799e+111*cos(theta)**40 - 1.88330740290219e+112*cos(theta)**38 + 3.82648874057873e+112*cos(theta)**36 - 4.69919669895633e+112*cos(theta)**34 + 3.89977714218121e+112*cos(theta)**32 - 2.31651432637351e+112*cos(theta)**30 + 1.01786235552776e+112*cos(theta)**28 - 3.37205933733121e+111*cos(theta)**26 + 8.50869009807954e+110*cos(theta)**24 - 1.64108907552058e+110*cos(theta)**22 + 2.41459602831372e+109*cos(theta)**20 - 2.69075217231441e+108*cos(theta)**18 + 2.24229347692868e+107*cos(theta)**16 - 1.37073467769455e+106*cos(theta)**14 + 5.97971503692256e+104*cos(theta)**12 - 1.78984667771832e+103*cos(theta)**10 + 3.47168536626397e+101*cos(theta)**8 - 3.99865036015596e+99*cos(theta)**6 + 2.36326853437113e+97*cos(theta)**4 - 5.36903112693177e+94*cos(theta)**2 + 1.95950041128897e+91)*cos(48*phi)

#@torch.jit.script
def Yl88_m49(theta, phi):
    return 3.38567451314845e-94*(1.0 - cos(theta)**2)**24.5*(1.6901476692712e+113*cos(theta)**39 - 7.15656813102832e+113*cos(theta)**37 + 1.37753594660834e+114*cos(theta)**35 - 1.59772687764515e+114*cos(theta)**33 + 1.24792868549799e+114*cos(theta)**31 - 6.94954297912053e+113*cos(theta)**29 + 2.85001459547771e+113*cos(theta)**27 - 8.76735427706115e+112*cos(theta)**25 + 2.04208562353909e+112*cos(theta)**23 - 3.61039596614528e+111*cos(theta)**21 + 4.82919205662744e+110*cos(theta)**19 - 4.84335391016594e+109*cos(theta)**17 + 3.58766956308588e+108*cos(theta)**15 - 1.91902854877238e+107*cos(theta)**13 + 7.17565804430707e+105*cos(theta)**11 - 1.78984667771832e+104*cos(theta)**9 + 2.77734829301118e+102*cos(theta)**7 - 2.39919021609357e+100*cos(theta)**5 + 9.45307413748453e+97*cos(theta)**3 - 1.07380622538635e+95*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl88_m50(theta, phi):
    return 4.61501755657922e-96*(1.0 - cos(theta)**2)**25*(6.59157591015766e+114*cos(theta)**38 - 2.64793020848048e+115*cos(theta)**36 + 4.82137581312919e+115*cos(theta)**34 - 5.272498696229e+115*cos(theta)**32 + 3.86857892504376e+115*cos(theta)**30 - 2.01536746394496e+115*cos(theta)**28 + 7.69503940778983e+114*cos(theta)**26 - 2.19183856926529e+114*cos(theta)**24 + 4.6967969341399e+113*cos(theta)**22 - 7.58183152890509e+112*cos(theta)**20 + 9.17546490759214e+111*cos(theta)**18 - 8.2337016472821e+110*cos(theta)**16 + 5.38150434462882e+109*cos(theta)**14 - 2.49473711340409e+108*cos(theta)**12 + 7.89322384873777e+106*cos(theta)**10 - 1.61086200994648e+105*cos(theta)**8 + 1.94414380510783e+103*cos(theta)**6 - 1.19959510804679e+101*cos(theta)**4 + 2.83592224124536e+98*cos(theta)**2 - 1.07380622538635e+95)*cos(50*phi)

#@torch.jit.script
def Yl88_m51(theta, phi):
    return 6.35000634266923e-98*(1.0 - cos(theta)**2)**25.5*(2.50479884585991e+116*cos(theta)**37 - 9.53254875052972e+116*cos(theta)**35 + 1.63926777646393e+117*cos(theta)**33 - 1.68719958279328e+117*cos(theta)**31 + 1.16057367751313e+117*cos(theta)**29 - 5.64302889904587e+116*cos(theta)**27 + 2.00071024602536e+116*cos(theta)**25 - 5.26041256623669e+115*cos(theta)**23 + 1.03329532551078e+115*cos(theta)**21 - 1.51636630578102e+114*cos(theta)**19 + 1.65158368336659e+113*cos(theta)**17 - 1.31739226356514e+112*cos(theta)**15 + 7.53410608248035e+110*cos(theta)**13 - 2.99368453608491e+109*cos(theta)**11 + 7.89322384873777e+107*cos(theta)**9 - 1.28868960795719e+106*cos(theta)**7 + 1.1664862830647e+104*cos(theta)**5 - 4.79838043218715e+101*cos(theta)**3 + 5.67184448249072e+98*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl88_m52(theta, phi):
    return 8.82285779089399e-100*(1.0 - cos(theta)**2)**26*(9.26775572968167e+117*cos(theta)**36 - 3.3363920626854e+118*cos(theta)**34 + 5.40958366233096e+118*cos(theta)**32 - 5.23031870665917e+118*cos(theta)**30 + 3.36566366478808e+118*cos(theta)**28 - 1.52361780274239e+118*cos(theta)**26 + 5.00177561506339e+117*cos(theta)**24 - 1.20989489023444e+117*cos(theta)**22 + 2.16992018357264e+116*cos(theta)**20 - 2.88109598098393e+115*cos(theta)**18 + 2.8076922617232e+114*cos(theta)**16 - 1.9760883953477e+113*cos(theta)**14 + 9.79433790722446e+111*cos(theta)**12 - 3.2930529896934e+110*cos(theta)**10 + 7.103901463864e+108*cos(theta)**8 - 9.02082725570031e+106*cos(theta)**6 + 5.83243141532348e+104*cos(theta)**4 - 1.43951412965614e+102*cos(theta)**2 + 5.67184448249072e+98)*cos(52*phi)

#@torch.jit.script
def Yl88_m53(theta, phi):
    return 1.23836443964968e-101*(1.0 - cos(theta)**2)**26.5*(3.3363920626854e+119*cos(theta)**35 - 1.13437330131304e+120*cos(theta)**33 + 1.73106677194591e+120*cos(theta)**31 - 1.56909561199775e+120*cos(theta)**29 + 9.42385826140661e+119*cos(theta)**27 - 3.9614062871302e+119*cos(theta)**25 + 1.20042614761521e+119*cos(theta)**23 - 2.66176875851577e+118*cos(theta)**21 + 4.33984036714527e+117*cos(theta)**19 - 5.18597276577108e+116*cos(theta)**17 + 4.49230761875711e+115*cos(theta)**15 - 2.76652375348679e+114*cos(theta)**13 + 1.17532054886693e+113*cos(theta)**11 - 3.2930529896934e+111*cos(theta)**9 + 5.6831211710912e+109*cos(theta)**7 - 5.41249635342019e+107*cos(theta)**5 + 2.33297256612939e+105*cos(theta)**3 - 2.87902825931229e+102*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl88_m54(theta, phi):
    return 1.75658948261692e-103*(1.0 - cos(theta)**2)**27*(1.16773722193989e+121*cos(theta)**34 - 3.74343189433302e+121*cos(theta)**32 + 5.36630699303231e+121*cos(theta)**30 - 4.55037727479348e+121*cos(theta)**28 + 2.54444173057978e+121*cos(theta)**26 - 9.90351571782551e+120*cos(theta)**24 + 2.76098013951499e+120*cos(theta)**22 - 5.58971439288311e+119*cos(theta)**20 + 8.24569669757602e+118*cos(theta)**18 - 8.81615370181084e+117*cos(theta)**16 + 6.73846142813567e+116*cos(theta)**14 - 3.59648087953282e+115*cos(theta)**12 + 1.29285260375363e+114*cos(theta)**10 - 2.96374769072406e+112*cos(theta)**8 + 3.97818481976384e+110*cos(theta)**6 - 2.70624817671009e+108*cos(theta)**4 + 6.99891769838817e+105*cos(theta)**2 - 2.87902825931229e+102)*cos(54*phi)

#@torch.jit.script
def Yl88_m55(theta, phi):
    return 2.51920088896542e-105*(1.0 - cos(theta)**2)**27.5*(3.97030655459563e+122*cos(theta)**33 - 1.19789820618657e+123*cos(theta)**31 + 1.60989209790969e+123*cos(theta)**29 - 1.27410563694217e+123*cos(theta)**27 + 6.61554849950744e+122*cos(theta)**25 - 2.37684377227812e+122*cos(theta)**23 + 6.07415630693298e+121*cos(theta)**21 - 1.11794287857662e+121*cos(theta)**19 + 1.48422540556368e+120*cos(theta)**17 - 1.41058459228973e+119*cos(theta)**15 + 9.43384599938994e+117*cos(theta)**13 - 4.31577705543938e+116*cos(theta)**11 + 1.29285260375363e+115*cos(theta)**9 - 2.37099815257925e+113*cos(theta)**7 + 2.3869108918583e+111*cos(theta)**5 - 1.08249927068404e+109*cos(theta)**3 + 1.39978353967763e+106*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl88_m56(theta, phi):
    return 3.65447154693842e-107*(1.0 - cos(theta)**2)**28*(1.31020116301656e+124*cos(theta)**32 - 3.71348443917836e+124*cos(theta)**30 + 4.66868708393811e+124*cos(theta)**28 - 3.44008521974387e+124*cos(theta)**26 + 1.65388712487686e+124*cos(theta)**24 - 5.46674067623968e+123*cos(theta)**22 + 1.27557282445593e+123*cos(theta)**20 - 2.12409146929558e+122*cos(theta)**18 + 2.52318318945826e+121*cos(theta)**16 - 2.1158768884346e+120*cos(theta)**14 + 1.22639997992069e+119*cos(theta)**12 - 4.74735476098332e+117*cos(theta)**10 + 1.16356734337827e+116*cos(theta)**8 - 1.65969870680547e+114*cos(theta)**6 + 1.19345544592915e+112*cos(theta)**4 - 3.24749781205211e+109*cos(theta)**2 + 1.39978353967763e+106)*cos(56*phi)

#@torch.jit.script
def Yl88_m57(theta, phi):
    return 5.36494896000854e-109*(1.0 - cos(theta)**2)**28.5*(4.19264372165298e+125*cos(theta)**31 - 1.11404533175351e+126*cos(theta)**29 + 1.30723238350267e+126*cos(theta)**27 - 8.94422157133406e+125*cos(theta)**25 + 3.96932909970446e+125*cos(theta)**23 - 1.20268294877273e+125*cos(theta)**21 + 2.55114564891185e+124*cos(theta)**19 - 3.82336464473205e+123*cos(theta)**17 + 4.03709310313322e+122*cos(theta)**15 - 2.96222764380844e+121*cos(theta)**13 + 1.47167997590483e+120*cos(theta)**11 - 4.74735476098332e+118*cos(theta)**9 + 9.30853874702612e+116*cos(theta)**7 - 9.95819224083284e+114*cos(theta)**5 + 4.77382178371661e+112*cos(theta)**3 - 6.49499562410422e+109*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl88_m58(theta, phi):
    return 7.97458919237988e-111*(1.0 - cos(theta)**2)**29*(1.29971955371242e+127*cos(theta)**30 - 3.23073146208517e+127*cos(theta)**28 + 3.52952743545721e+127*cos(theta)**26 - 2.23605539283351e+127*cos(theta)**24 + 9.12945692932027e+126*cos(theta)**22 - 2.52563419242273e+126*cos(theta)**20 + 4.84717673293252e+125*cos(theta)**18 - 6.49971989604448e+124*cos(theta)**16 + 6.05563965469983e+123*cos(theta)**14 - 3.85089593695097e+122*cos(theta)**12 + 1.61884797349531e+121*cos(theta)**10 - 4.27261928488499e+119*cos(theta)**8 + 6.51597712291829e+117*cos(theta)**6 - 4.97909612041642e+115*cos(theta)**4 + 1.43214653511498e+113*cos(theta)**2 - 6.49499562410422e+109)*cos(58*phi)

#@torch.jit.script
def Yl88_m59(theta, phi):
    return 1.20085072628967e-112*(1.0 - cos(theta)**2)**29.5*(3.89915866113728e+128*cos(theta)**29 - 9.04604809383848e+128*cos(theta)**27 + 9.17677133218874e+128*cos(theta)**25 - 5.36653294280044e+128*cos(theta)**23 + 2.00848052445046e+128*cos(theta)**21 - 5.05126838484547e+127*cos(theta)**19 + 8.72491811927853e+126*cos(theta)**17 - 1.03995518336712e+126*cos(theta)**15 + 8.47789551657976e+124*cos(theta)**13 - 4.62107512434117e+123*cos(theta)**11 + 1.61884797349531e+122*cos(theta)**9 - 3.41809542790799e+120*cos(theta)**7 + 3.90958627375097e+118*cos(theta)**5 - 1.99163844816657e+116*cos(theta)**3 + 2.86429307022996e+113*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl88_m60(theta, phi):
    return 1.83298608656671e-114*(1.0 - cos(theta)**2)**30*(1.13075601172981e+130*cos(theta)**28 - 2.44243298533639e+130*cos(theta)**26 + 2.29419283304719e+130*cos(theta)**24 - 1.2343025768441e+130*cos(theta)**22 + 4.21780910134596e+129*cos(theta)**20 - 9.59740993120638e+128*cos(theta)**18 + 1.48323608027735e+128*cos(theta)**16 - 1.55993277505068e+127*cos(theta)**14 + 1.10212641715537e+126*cos(theta)**12 - 5.08318263677528e+124*cos(theta)**10 + 1.45696317614578e+123*cos(theta)**8 - 2.3926667995356e+121*cos(theta)**6 + 1.95479313687549e+119*cos(theta)**4 - 5.9749153444997e+116*cos(theta)**2 + 2.86429307022996e+113)*cos(60*phi)

#@torch.jit.script
def Yl88_m61(theta, phi):
    return 2.83783420176876e-116*(1.0 - cos(theta)**2)**30.5*(3.16611683284347e+131*cos(theta)**27 - 6.35032576187461e+131*cos(theta)**25 + 5.50606279931325e+131*cos(theta)**23 - 2.71546566905702e+131*cos(theta)**21 + 8.43561820269193e+130*cos(theta)**19 - 1.72753378761715e+130*cos(theta)**17 + 2.37317772844376e+129*cos(theta)**15 - 2.18390588507095e+128*cos(theta)**13 + 1.32255170058644e+127*cos(theta)**11 - 5.08318263677528e+125*cos(theta)**9 + 1.16557054091663e+124*cos(theta)**7 - 1.43560007972136e+122*cos(theta)**5 + 7.81917254750194e+119*cos(theta)**3 - 1.19498306889994e+117*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl88_m62(theta, phi):
    return 4.45922623989734e-118*(1.0 - cos(theta)**2)**31*(8.54851544867736e+132*cos(theta)**26 - 1.58758144046865e+133*cos(theta)**24 + 1.26639444384205e+133*cos(theta)**22 - 5.70247790501974e+132*cos(theta)**20 + 1.60276745851147e+132*cos(theta)**18 - 2.93680743894915e+131*cos(theta)**16 + 3.55976659266564e+130*cos(theta)**14 - 2.83907765059223e+129*cos(theta)**12 + 1.45480687064509e+128*cos(theta)**10 - 4.57486437309776e+126*cos(theta)**8 + 8.15899378641638e+124*cos(theta)**6 - 7.17800039860678e+122*cos(theta)**4 + 2.34575176425058e+120*cos(theta)**2 - 1.19498306889994e+117)*cos(62*phi)

#@torch.jit.script
def Yl88_m63(theta, phi):
    return 7.11679341372251e-120*(1.0 - cos(theta)**2)**31.5*(2.22261401665611e+134*cos(theta)**25 - 3.81019545712477e+134*cos(theta)**23 + 2.7860677764525e+134*cos(theta)**21 - 1.14049558100395e+134*cos(theta)**19 + 2.88498142532064e+133*cos(theta)**17 - 4.69889190231865e+132*cos(theta)**15 + 4.9836732297319e+131*cos(theta)**13 - 3.40689318071067e+130*cos(theta)**11 + 1.45480687064509e+129*cos(theta)**9 - 3.6598914984782e+127*cos(theta)**7 + 4.89539627184983e+125*cos(theta)**5 - 2.87120015944271e+123*cos(theta)**3 + 4.69150352850117e+120*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl88_m64(theta, phi):
    return 1.15449634146812e-121*(1.0 - cos(theta)**2)**32*(5.55653504164028e+135*cos(theta)**24 - 8.76344955138696e+135*cos(theta)**22 + 5.85074233055026e+135*cos(theta)**20 - 2.1669416039075e+135*cos(theta)**18 + 4.90446842304509e+134*cos(theta)**16 - 7.04833785347797e+133*cos(theta)**14 + 6.47877519865147e+132*cos(theta)**12 - 3.74758249878174e+131*cos(theta)**10 + 1.30932618358058e+130*cos(theta)**8 - 2.56192404893474e+128*cos(theta)**6 + 2.44769813592491e+126*cos(theta)**4 - 8.61360047832814e+123*cos(theta)**2 + 4.69150352850117e+120)*cos(64*phi)

#@torch.jit.script
def Yl88_m65(theta, phi):
    return 1.90520285980036e-123*(1.0 - cos(theta)**2)**32.5*(1.33356840999367e+137*cos(theta)**23 - 1.92795890130513e+137*cos(theta)**21 + 1.17014846611005e+137*cos(theta)**19 - 3.9004948870335e+136*cos(theta)**17 + 7.84714947687214e+135*cos(theta)**15 - 9.86767299486916e+134*cos(theta)**13 + 7.77453023838176e+133*cos(theta)**11 - 3.74758249878174e+132*cos(theta)**9 + 1.04746094686446e+131*cos(theta)**7 - 1.53715442936085e+129*cos(theta)**5 + 9.79079254369965e+126*cos(theta)**3 - 1.72272009566563e+124*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl88_m66(theta, phi):
    return 3.20123050213715e-125*(1.0 - cos(theta)**2)**33*(3.06720734298544e+138*cos(theta)**22 - 4.04871369274078e+138*cos(theta)**20 + 2.2232820856091e+138*cos(theta)**18 - 6.63084130795696e+137*cos(theta)**16 + 1.17707242153082e+137*cos(theta)**14 - 1.28279748933299e+136*cos(theta)**12 + 8.55198326221994e+134*cos(theta)**10 - 3.37282424890357e+133*cos(theta)**8 + 7.33222662805123e+131*cos(theta)**6 - 7.68577214680423e+129*cos(theta)**4 + 2.9372377631099e+127*cos(theta)**2 - 1.72272009566563e+124)*cos(66*phi)

#@torch.jit.script
def Yl88_m67(theta, phi):
    return 5.48200915921706e-127*(1.0 - cos(theta)**2)**33.5*(6.74785615456796e+139*cos(theta)**21 - 8.09742738548155e+139*cos(theta)**19 + 4.00190775409638e+139*cos(theta)**17 - 1.06093460927311e+139*cos(theta)**15 + 1.64790139014315e+138*cos(theta)**13 - 1.53935698719959e+137*cos(theta)**11 + 8.55198326221994e+135*cos(theta)**9 - 2.69825939912285e+134*cos(theta)**7 + 4.39933597683074e+132*cos(theta)**5 - 3.07430885872169e+130*cos(theta)**3 + 5.87447552621979e+127*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl88_m68(theta, phi):
    return 9.57784512729653e-129*(1.0 - cos(theta)**2)**34*(1.41704979245927e+141*cos(theta)**20 - 1.5385112032415e+141*cos(theta)**18 + 6.80324318196384e+140*cos(theta)**16 - 1.59140191390967e+140*cos(theta)**14 + 2.14227180718609e+139*cos(theta)**12 - 1.69329268591955e+138*cos(theta)**10 + 7.69678493599794e+136*cos(theta)**8 - 1.888781579386e+135*cos(theta)**6 + 2.19966798841537e+133*cos(theta)**4 - 9.22292657616507e+130*cos(theta)**2 + 5.87447552621979e+127)*cos(68*phi)

#@torch.jit.script
def Yl88_m69(theta, phi):
    return 1.70923975802033e-130*(1.0 - cos(theta)**2)**34.5*(2.83409958491854e+142*cos(theta)**19 - 2.76932016583469e+142*cos(theta)**17 + 1.08851890911421e+142*cos(theta)**15 - 2.22796267947354e+141*cos(theta)**13 + 2.57072616862331e+140*cos(theta)**11 - 1.69329268591955e+139*cos(theta)**9 + 6.15742794879835e+137*cos(theta)**7 - 1.1332689476316e+136*cos(theta)**5 + 8.79867195366148e+133*cos(theta)**3 - 1.84458531523301e+131*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl88_m70(theta, phi):
    return 3.11959088180028e-132*(1.0 - cos(theta)**2)**35*(5.38478921134523e+143*cos(theta)**18 - 4.70784428191898e+143*cos(theta)**16 + 1.63277836367132e+143*cos(theta)**14 - 2.8963514833156e+142*cos(theta)**12 + 2.82779878548564e+141*cos(theta)**10 - 1.52396341732759e+140*cos(theta)**8 + 4.31019956415885e+138*cos(theta)**6 - 5.66634473815799e+136*cos(theta)**4 + 2.63960158609844e+134*cos(theta)**2 - 1.84458531523301e+131)*cos(70*phi)

#@torch.jit.script
def Yl88_m71(theta, phi):
    return 5.83126566224347e-134*(1.0 - cos(theta)**2)**35.5*(9.69262058042142e+144*cos(theta)**17 - 7.53255085107036e+144*cos(theta)**15 + 2.28588970913985e+144*cos(theta)**13 - 3.47562177997872e+143*cos(theta)**11 + 2.82779878548564e+142*cos(theta)**9 - 1.21917073386207e+141*cos(theta)**7 + 2.58611973849531e+139*cos(theta)**5 - 2.2665378952632e+137*cos(theta)**3 + 5.27920317219689e+134*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl88_m72(theta, phi):
    return 1.11809415090215e-135*(1.0 - cos(theta)**2)**36*(1.64774549867164e+146*cos(theta)**16 - 1.12988262766055e+146*cos(theta)**14 + 2.9716566218818e+145*cos(theta)**12 - 3.82318395797659e+144*cos(theta)**10 + 2.54501890693708e+143*cos(theta)**8 - 8.53419513703452e+141*cos(theta)**6 + 1.29305986924765e+140*cos(theta)**4 - 6.79961368578959e+137*cos(theta)**2 + 5.27920317219689e+134)*cos(72*phi)

#@torch.jit.script
def Yl88_m73(theta, phi):
    return 2.20295408870265e-137*(1.0 - cos(theta)**2)**36.5*(2.63639279787463e+147*cos(theta)**15 - 1.58183567872478e+147*cos(theta)**13 + 3.56598794625817e+146*cos(theta)**11 - 3.82318395797659e+145*cos(theta)**9 + 2.03601512554966e+144*cos(theta)**7 - 5.12051708222071e+142*cos(theta)**5 + 5.17223947699062e+140*cos(theta)**3 - 1.35992273715792e+138*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl88_m74(theta, phi):
    return 4.46891721307658e-139*(1.0 - cos(theta)**2)**37*(3.95458919681194e+148*cos(theta)**14 - 2.05638638234221e+148*cos(theta)**12 + 3.92258674088398e+147*cos(theta)**10 - 3.44086556217893e+146*cos(theta)**8 + 1.42521058788476e+145*cos(theta)**6 - 2.56025854111036e+143*cos(theta)**4 + 1.55167184309719e+141*cos(theta)**2 - 1.35992273715792e+138)*cos(74*phi)

#@torch.jit.script
def Yl88_m75(theta, phi):
    return 9.35501502528341e-141*(1.0 - cos(theta)**2)**37.5*(5.53642487553672e+149*cos(theta)**13 - 2.46766365881065e+149*cos(theta)**11 + 3.92258674088398e+148*cos(theta)**9 - 2.75269244974315e+147*cos(theta)**7 + 8.55126352730859e+145*cos(theta)**5 - 1.02410341644414e+144*cos(theta)**3 + 3.10334368619437e+141*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl88_m76(theta, phi):
    return 2.02605340681909e-142*(1.0 - cos(theta)**2)**38*(7.19735233819773e+150*cos(theta)**12 - 2.71443002469172e+150*cos(theta)**10 + 3.53032806679558e+149*cos(theta)**8 - 1.9268847148202e+148*cos(theta)**6 + 4.27563176365429e+146*cos(theta)**4 - 3.07231024933243e+144*cos(theta)**2 + 3.10334368619437e+141)*cos(76*phi)

#@torch.jit.script
def Yl88_m77(theta, phi):
    return 4.55321642740204e-144*(1.0 - cos(theta)**2)**38.5*(8.63682280583728e+151*cos(theta)**11 - 2.71443002469172e+151*cos(theta)**9 + 2.82426245343647e+150*cos(theta)**7 - 1.15613082889212e+149*cos(theta)**5 + 1.71025270546172e+147*cos(theta)**3 - 6.14462049866485e+144*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl88_m78(theta, phi):
    return 1.06553546064646e-145*(1.0 - cos(theta)**2)**39*(9.500505086421e+152*cos(theta)**10 - 2.44298702222254e+152*cos(theta)**8 + 1.97698371740553e+151*cos(theta)**6 - 5.7806541444606e+149*cos(theta)**4 + 5.13075811638515e+147*cos(theta)**2 - 6.14462049866485e+144)*cos(78*phi)

#@torch.jit.script
def Yl88_m79(theta, phi):
    return 2.60741207175745e-147*(1.0 - cos(theta)**2)**39.5*(9.500505086421e+153*cos(theta)**9 - 1.95438961777804e+153*cos(theta)**7 + 1.18619023044332e+152*cos(theta)**5 - 2.31226165778424e+150*cos(theta)**3 + 1.02615162327703e+148*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl88_m80(theta, phi):
    return 6.70554029006287e-149*(1.0 - cos(theta)**2)**40*(8.5504545777789e+154*cos(theta)**8 - 1.36807273244462e+154*cos(theta)**6 + 5.93095115221658e+152*cos(theta)**4 - 6.93678497335273e+150*cos(theta)**2 + 1.02615162327703e+148)*cos(80*phi)

#@torch.jit.script
def Yl88_m81(theta, phi):
    return 1.82366654254733e-150*(1.0 - cos(theta)**2)**40.5*(6.84036366222312e+155*cos(theta)**7 - 8.20843639466775e+154*cos(theta)**5 + 2.37238046088663e+153*cos(theta)**3 - 1.38735699467055e+151*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl88_m82(theta, phi):
    return 5.28654520028694e-152*(1.0 - cos(theta)**2)**41*(4.78825456355619e+156*cos(theta)**6 - 4.10421819733387e+155*cos(theta)**4 + 7.1171413826599e+153*cos(theta)**2 - 1.38735699467055e+151)*cos(82*phi)

#@torch.jit.script
def Yl88_m83(theta, phi):
    return 1.65043440895802e-153*(1.0 - cos(theta)**2)**41.5*(2.87295273813371e+157*cos(theta)**5 - 1.64168727893355e+156*cos(theta)**3 + 1.42342827653198e+154*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl88_m84(theta, phi):
    return 5.62793462288332e-155*(1.0 - cos(theta)**2)**42*(1.43647636906686e+158*cos(theta)**4 - 4.92506183680065e+156*cos(theta)**2 + 1.42342827653198e+154)*cos(84*phi)

#@torch.jit.script
def Yl88_m85(theta, phi):
    return 2.13941972980226e-156*(1.0 - cos(theta)**2)**42.5*(5.74590547626742e+158*cos(theta)**3 - 9.8501236736013e+156*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl88_m86(theta, phi):
    return 9.36398577033487e-158*(1.0 - cos(theta)**2)**43*(1.72377164288023e+159*cos(theta)**2 - 9.8501236736013e+156)*cos(86*phi)

#@torch.jit.script
def Yl88_m87(theta, phi):
    return 17.2558537211813*(1.0 - cos(theta)**2)**43.5*cos(87*phi)*cos(theta)

#@torch.jit.script
def Yl88_m88(theta, phi):
    return 1.30070891432765*(1.0 - cos(theta)**2)**44*cos(88*phi)

#@torch.jit.script
def Yl89_m_minus_89(theta, phi):
    return 1.30435747384896*(1.0 - cos(theta)**2)**44.5*sin(89*phi)

#@torch.jit.script
def Yl89_m_minus_88(theta, phi):
    return 17.4022992356252*(1.0 - cos(theta)**2)**44*sin(88*phi)*cos(theta)

#@torch.jit.script
def Yl89_m_minus_87(theta, phi):
    return 5.36568618484204e-160*(1.0 - cos(theta)**2)**43.5*(3.051075807898e+161*cos(theta)**2 - 1.72377164288023e+159)*sin(87*phi)

#@torch.jit.script
def Yl89_m_minus_86(theta, phi):
    return 1.23294081721955e-158*(1.0 - cos(theta)**2)**43*(1.01702526929933e+161*cos(theta)**3 - 1.72377164288023e+159*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl89_m_minus_85(theta, phi):
    return 3.26205478362367e-157*(1.0 - cos(theta)**2)**42.5*(2.54256317324833e+160*cos(theta)**4 - 8.61885821440113e+158*cos(theta)**2 + 2.46253091840032e+156)*sin(85*phi)

#@torch.jit.script
def Yl89_m_minus_84(theta, phi):
    return 9.62167928580298e-156*(1.0 - cos(theta)**2)**42*(5.08512634649667e+159*cos(theta)**5 - 2.87295273813371e+158*cos(theta)**3 + 2.46253091840032e+156*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl89_m_minus_83(theta, phi):
    return 3.0999133430702e-154*(1.0 - cos(theta)**2)**41.5*(8.47521057749445e+158*cos(theta)**6 - 7.18238184533428e+157*cos(theta)**4 + 1.23126545920016e+156*cos(theta)**2 - 2.37238046088663e+153)*sin(83*phi)

#@torch.jit.script
def Yl89_m_minus_82(theta, phi):
    return 1.07562972868882e-152*(1.0 - cos(theta)**2)**41*(1.21074436821349e+158*cos(theta)**7 - 1.43647636906686e+157*cos(theta)**5 + 4.10421819733387e+155*cos(theta)**3 - 2.37238046088663e+153*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl89_m_minus_81(theta, phi):
    return 3.97837617692343e-151*(1.0 - cos(theta)**2)**40.5*(1.51343046026687e+157*cos(theta)**8 - 2.39412728177809e+156*cos(theta)**6 + 1.02605454933347e+155*cos(theta)**4 - 1.18619023044332e+153*cos(theta)**2 + 1.73419624333818e+150)*sin(81*phi)

#@torch.jit.script
def Yl89_m_minus_80(theta, phi):
    return 1.55615037248401e-149*(1.0 - cos(theta)**2)**40*(1.68158940029652e+156*cos(theta)**9 - 3.42018183111156e+155*cos(theta)**7 + 2.05210909866694e+154*cos(theta)**5 - 3.95396743481105e+152*cos(theta)**3 + 1.73419624333818e+150*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl89_m_minus_79(theta, phi):
    return 6.39727342639955e-148*(1.0 - cos(theta)**2)**39.5*(1.68158940029652e+155*cos(theta)**10 - 4.27522728888945e+154*cos(theta)**8 + 3.42018183111156e+153*cos(theta)**6 - 9.88491858702763e+151*cos(theta)**4 + 8.67098121669091e+149*cos(theta)**2 - 1.02615162327703e+147)*sin(79*phi)

#@torch.jit.script
def Yl89_m_minus_78(theta, phi):
    return 2.75008360374433e-146*(1.0 - cos(theta)**2)**39*(1.5287176366332e+154*cos(theta)**11 - 4.7502525432105e+153*cos(theta)**9 + 4.88597404444509e+152*cos(theta)**7 - 1.97698371740553e+151*cos(theta)**5 + 2.8903270722303e+149*cos(theta)**3 - 1.02615162327703e+147*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl89_m_minus_77(theta, phi):
    return 1.23110403680912e-144*(1.0 - cos(theta)**2)**38.5*(1.273931363861e+153*cos(theta)**12 - 4.7502525432105e+152*cos(theta)**10 + 6.10746755555636e+151*cos(theta)**8 - 3.29497286234254e+150*cos(theta)**6 + 7.22581768057576e+148*cos(theta)**4 - 5.13075811638515e+146*cos(theta)**2 + 5.12051708222071e+143)*sin(77*phi)

#@torch.jit.script
def Yl89_m_minus_76(theta, phi):
    return 5.71900499082503e-143*(1.0 - cos(theta)**2)**38*(9.79947202969999e+151*cos(theta)**13 - 4.31841140291864e+151*cos(theta)**11 + 6.78607506172929e+150*cos(theta)**9 - 4.70710408906078e+149*cos(theta)**7 + 1.44516353611515e+148*cos(theta)**5 - 1.71025270546172e+146*cos(theta)**3 + 5.12051708222071e+143*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl89_m_minus_75(theta, phi):
    return 2.74869444967131e-141*(1.0 - cos(theta)**2)**37.5*(6.99962287835713e+150*cos(theta)**14 - 3.59867616909887e+150*cos(theta)**12 + 6.78607506172929e+149*cos(theta)**10 - 5.88388011132597e+148*cos(theta)**8 + 2.40860589352525e+147*cos(theta)**6 - 4.27563176365429e+145*cos(theta)**4 + 2.56025854111036e+143*cos(theta)**2 - 2.21667406156741e+140)*sin(75*phi)

#@torch.jit.script
def Yl89_m_minus_74(theta, phi):
    return 1.36330811253467e-139*(1.0 - cos(theta)**2)**37*(4.66641525223809e+149*cos(theta)**15 - 2.76821243776836e+149*cos(theta)**13 + 6.16915914702663e+148*cos(theta)**11 - 6.53764456813997e+147*cos(theta)**9 + 3.44086556217893e+146*cos(theta)**7 - 8.55126352730859e+144*cos(theta)**5 + 8.53419513703452e+142*cos(theta)**3 - 2.21667406156741e+140*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl89_m_minus_73(theta, phi):
    return 6.96222112353882e-138*(1.0 - cos(theta)**2)**36.5*(2.91650953264881e+148*cos(theta)**16 - 1.97729459840597e+148*cos(theta)**14 + 5.14096595585552e+147*cos(theta)**12 - 6.53764456813997e+146*cos(theta)**10 + 4.30108195272366e+145*cos(theta)**8 - 1.42521058788476e+144*cos(theta)**6 + 2.13354878425863e+142*cos(theta)**4 - 1.1083370307837e+140*cos(theta)**2 + 8.49951710723699e+136)*sin(73*phi)

#@torch.jit.script
def Yl89_m_minus_72(theta, phi):
    return 3.65367388073676e-136*(1.0 - cos(theta)**2)**36*(1.71559384273459e+147*cos(theta)**17 - 1.31819639893731e+147*cos(theta)**15 + 3.95458919681194e+146*cos(theta)**13 - 5.94331324376361e+145*cos(theta)**11 + 4.77897994747074e+144*cos(theta)**9 - 2.03601512554966e+143*cos(theta)**7 + 4.26709756851726e+141*cos(theta)**5 - 3.69445676927901e+139*cos(theta)**3 + 8.49951710723699e+136*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl89_m_minus_71(theta, phi):
    return 1.96688501270417e-134*(1.0 - cos(theta)**2)**35.5*(9.53107690408106e+145*cos(theta)**18 - 8.23872749335821e+145*cos(theta)**16 + 2.82470656915139e+145*cos(theta)**14 - 4.95276103646967e+144*cos(theta)**12 + 4.77897994747074e+143*cos(theta)**10 - 2.54501890693708e+142*cos(theta)**8 + 7.1118292808621e+140*cos(theta)**6 - 9.23614192319753e+138*cos(theta)**4 + 4.2497585536185e+136*cos(theta)**2 - 2.93289065122049e+133)*sin(71*phi)

#@torch.jit.script
def Yl89_m_minus_70(theta, phi):
    return 1.08446555619479e-132*(1.0 - cos(theta)**2)**35*(5.01635626530582e+144*cos(theta)**19 - 4.84631029021071e+144*cos(theta)**17 + 1.88313771276759e+144*cos(theta)**15 - 3.80981618189975e+143*cos(theta)**13 + 4.3445272249734e+142*cos(theta)**11 - 2.82779878548564e+141*cos(theta)**9 + 1.01597561155173e+140*cos(theta)**7 - 1.84722838463951e+138*cos(theta)**5 + 1.4165861845395e+136*cos(theta)**3 - 2.93289065122049e+133*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl89_m_minus_69(theta, phi):
    return 6.11546271788306e-131*(1.0 - cos(theta)**2)**34.5*(2.50817813265291e+143*cos(theta)**20 - 2.69239460567262e+143*cos(theta)**18 + 1.17696107047974e+143*cos(theta)**16 - 2.72129727278554e+142*cos(theta)**14 + 3.6204393541445e+141*cos(theta)**12 - 2.82779878548564e+140*cos(theta)**10 + 1.26996951443966e+139*cos(theta)**8 - 3.07871397439918e+137*cos(theta)**6 + 3.54146546134875e+135*cos(theta)**4 - 1.46644532561025e+133*cos(theta)**2 + 9.22292657616507e+129)*sin(69*phi)

#@torch.jit.script
def Yl89_m_minus_68(theta, phi):
    return 3.52263392866995e-129*(1.0 - cos(theta)**2)**34*(1.19437053935853e+142*cos(theta)**21 - 1.41704979245927e+142*cos(theta)**19 + 6.92330041458673e+141*cos(theta)**17 - 1.81419818185702e+141*cos(theta)**15 + 2.78495334934192e+140*cos(theta)**13 - 2.57072616862331e+139*cos(theta)**11 + 1.41107723826629e+138*cos(theta)**9 - 4.39816282057025e+136*cos(theta)**7 + 7.08293092269749e+134*cos(theta)**5 - 4.88815108536749e+132*cos(theta)**3 + 9.22292657616507e+129*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl89_m_minus_67(theta, phi):
    return 2.07027806328931e-127*(1.0 - cos(theta)**2)**33.5*(5.42895699708422e+140*cos(theta)**22 - 7.08524896229636e+140*cos(theta)**20 + 3.84627800810374e+140*cos(theta)**18 - 1.13387386366064e+140*cos(theta)**16 + 1.98925239238709e+139*cos(theta)**14 - 2.14227180718609e+138*cos(theta)**12 + 1.41107723826629e+137*cos(theta)**10 - 5.49770352571282e+135*cos(theta)**8 + 1.18048848711625e+134*cos(theta)**6 - 1.22203777134187e+132*cos(theta)**4 + 4.61146328808254e+129*cos(theta)**2 - 2.67021614828172e+126)*sin(67*phi)

#@torch.jit.script
def Yl89_m_minus_66(theta, phi):
    return 1.24009483179719e-125*(1.0 - cos(theta)**2)**33*(2.36041608568879e+139*cos(theta)**23 - 3.37392807728398e+139*cos(theta)**21 + 2.02435684637039e+139*cos(theta)**19 - 6.66984625682729e+138*cos(theta)**17 + 1.32616826159139e+138*cos(theta)**15 - 1.64790139014315e+137*cos(theta)**13 + 1.28279748933299e+136*cos(theta)**11 - 6.10855947301424e+134*cos(theta)**9 + 1.68641212445178e+133*cos(theta)**7 - 2.44407554268374e+131*cos(theta)**5 + 1.53715442936085e+129*cos(theta)**3 - 2.67021614828172e+126*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl89_m_minus_65(theta, phi):
    return 7.56356193448717e-124*(1.0 - cos(theta)**2)**32.5*(9.8350670237033e+137*cos(theta)**24 - 1.53360367149272e+138*cos(theta)**22 + 1.01217842318519e+138*cos(theta)**20 - 3.70547014268183e+137*cos(theta)**18 + 8.2885516349462e+136*cos(theta)**16 - 1.17707242153082e+136*cos(theta)**14 + 1.06899790777749e+135*cos(theta)**12 - 6.10855947301424e+133*cos(theta)**10 + 2.10801515556473e+132*cos(theta)**8 - 4.07345923780624e+130*cos(theta)**6 + 3.84288607340211e+128*cos(theta)**4 - 1.33510807414086e+126*cos(theta)**2 + 7.17800039860678e+122)*sin(65*phi)

#@torch.jit.script
def Yl89_m_minus_64(theta, phi):
    return 4.69306676041125e-122*(1.0 - cos(theta)**2)**32*(3.93402680948132e+136*cos(theta)**25 - 6.66784204996834e+136*cos(theta)**23 + 4.81989725326283e+136*cos(theta)**21 - 1.95024744351675e+136*cos(theta)**19 + 4.87561860879188e+135*cos(theta)**17 - 7.84714947687214e+134*cos(theta)**15 + 8.22306082905763e+133*cos(theta)**13 - 5.5532358845584e+132*cos(theta)**11 + 2.34223906173859e+131*cos(theta)**9 - 5.81922748258035e+129*cos(theta)**7 + 7.68577214680423e+127*cos(theta)**5 - 4.45036024713621e+125*cos(theta)**3 + 7.17800039860678e+122*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl89_m_minus_63(theta, phi):
    return 2.95998235141899e-120*(1.0 - cos(theta)**2)**31.5*(1.51308723441589e+135*cos(theta)**26 - 2.77826752082014e+135*cos(theta)**24 + 2.19086238784674e+135*cos(theta)**22 - 9.75123721758376e+134*cos(theta)**20 + 2.70867700488438e+134*cos(theta)**18 - 4.90446842304509e+133*cos(theta)**16 + 5.87361487789831e+132*cos(theta)**14 - 4.62769657046533e+131*cos(theta)**12 + 2.34223906173859e+130*cos(theta)**10 - 7.27403435322543e+128*cos(theta)**8 + 1.28096202446737e+127*cos(theta)**6 - 1.11259006178405e+125*cos(theta)**4 + 3.58900019930339e+122*cos(theta)**2 - 1.80442443403891e+119)*sin(63*phi)

#@torch.jit.script
def Yl89_m_minus_62(theta, phi):
    return 1.89623779144393e-118*(1.0 - cos(theta)**2)**31*(5.60402679413294e+133*cos(theta)**27 - 1.11130700832806e+134*cos(theta)**25 + 9.52548864281192e+133*cos(theta)**23 - 4.6434462940875e+133*cos(theta)**21 + 1.42561947625494e+133*cos(theta)**19 - 2.88498142532064e+132*cos(theta)**17 + 3.91574325193221e+131*cos(theta)**15 - 3.55976659266564e+130*cos(theta)**13 + 2.12930823794417e+129*cos(theta)**11 - 8.0822603924727e+127*cos(theta)**9 + 1.8299457492391e+126*cos(theta)**7 - 2.2251801235681e+124*cos(theta)**5 + 1.1963333997678e+122*cos(theta)**3 - 1.80442443403891e+119*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl89_m_minus_61(theta, phi):
    return 1.23299208012332e-116*(1.0 - cos(theta)**2)**30.5*(2.00143814076176e+132*cos(theta)**28 - 4.27425772433868e+132*cos(theta)**26 + 3.96895360117163e+132*cos(theta)**24 - 2.11065740640341e+132*cos(theta)**22 + 7.12809738127468e+131*cos(theta)**20 - 1.60276745851147e+131*cos(theta)**18 + 2.44733953245763e+130*cos(theta)**16 - 2.5426904233326e+129*cos(theta)**14 + 1.77442353162014e+128*cos(theta)**12 - 8.0822603924727e+126*cos(theta)**10 + 2.28743218654888e+125*cos(theta)**8 - 3.70863353928017e+123*cos(theta)**6 + 2.99083349941949e+121*cos(theta)**4 - 9.02212217019455e+118*cos(theta)**2 + 4.26779667464265e+115)*sin(61*phi)

#@torch.jit.script
def Yl89_m_minus_60(theta, phi):
    return 8.13214128810101e-115*(1.0 - cos(theta)**2)**30*(6.90151083021298e+130*cos(theta)**29 - 1.58305841642173e+131*cos(theta)**27 + 1.58758144046865e+131*cos(theta)**25 - 9.17677133218874e+130*cos(theta)**23 + 3.39433208632128e+130*cos(theta)**21 - 8.43561820269193e+129*cos(theta)**19 + 1.43961148968096e+129*cos(theta)**17 - 1.6951269488884e+128*cos(theta)**15 + 1.36494117816934e+127*cos(theta)**13 - 7.34750944770246e+125*cos(theta)**11 + 2.54159131838764e+124*cos(theta)**9 - 5.29804791325739e+122*cos(theta)**7 + 5.98166699883899e+120*cos(theta)**5 - 3.00737405673152e+118*cos(theta)**3 + 4.26779667464265e+115*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl89_m_minus_59(theta, phi):
    return 5.4369917879787e-113*(1.0 - cos(theta)**2)**29.5*(2.30050361007099e+129*cos(theta)**30 - 5.65378005864905e+129*cos(theta)**28 + 6.10608246334097e+129*cos(theta)**26 - 3.82365472174531e+129*cos(theta)**24 + 1.54287822105513e+129*cos(theta)**22 - 4.21780910134596e+128*cos(theta)**20 + 7.99784160933865e+127*cos(theta)**18 - 1.05945434305525e+127*cos(theta)**16 + 9.74957984406672e+125*cos(theta)**14 - 6.12292453975205e+124*cos(theta)**12 + 2.54159131838764e+123*cos(theta)**10 - 6.62255989157174e+121*cos(theta)**8 + 9.96944499806498e+119*cos(theta)**6 - 7.51843514182879e+117*cos(theta)**4 + 2.13389833732132e+115*cos(theta)**2 - 9.54764356743321e+111)*sin(59*phi)

#@torch.jit.script
def Yl89_m_minus_58(theta, phi):
    return 3.68273425697931e-111*(1.0 - cos(theta)**2)**29*(7.42097938732578e+127*cos(theta)**31 - 1.94957933056864e+128*cos(theta)**29 + 2.26151202345962e+128*cos(theta)**27 - 1.52946188869812e+128*cos(theta)**25 + 6.70816617850054e+127*cos(theta)**23 - 2.00848052445046e+127*cos(theta)**21 + 4.20939032070455e+126*cos(theta)**19 - 6.23208437091324e+125*cos(theta)**17 + 6.49971989604448e+124*cos(theta)**15 - 4.70994195365542e+123*cos(theta)**13 + 2.31053756217058e+122*cos(theta)**11 - 7.35839987952415e+120*cos(theta)**9 + 1.424206428295e+119*cos(theta)**7 - 1.50368702836576e+117*cos(theta)**5 + 7.11299445773774e+114*cos(theta)**3 - 9.54764356743321e+111*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl89_m_minus_57(theta, phi):
    return 2.52582954060277e-109*(1.0 - cos(theta)**2)**28.5*(2.31905605853931e+126*cos(theta)**32 - 6.49859776856212e+126*cos(theta)**30 + 8.07682865521293e+126*cos(theta)**28 - 5.88254572576202e+126*cos(theta)**26 + 2.79506924104189e+126*cos(theta)**24 - 9.12945692932027e+125*cos(theta)**22 + 2.10469516035228e+125*cos(theta)**20 - 3.4622690949518e+124*cos(theta)**18 + 4.0623249350278e+123*cos(theta)**16 - 3.36424425261101e+122*cos(theta)**14 + 1.92544796847549e+121*cos(theta)**12 - 7.35839987952415e+119*cos(theta)**10 + 1.78025803536875e+118*cos(theta)**8 - 2.50614504727626e+116*cos(theta)**6 + 1.77824861443444e+114*cos(theta)**4 - 4.7738217837166e+111*cos(theta)**2 + 2.02968613253257e+108)*sin(57*phi)

#@torch.jit.script
def Yl89_m_minus_56(theta, phi):
    return 1.75322411673177e-107*(1.0 - cos(theta)**2)**28*(7.02744260163426e+124*cos(theta)**33 - 2.09632186082649e+125*cos(theta)**31 + 2.78511332938377e+125*cos(theta)**29 - 2.17872063917112e+125*cos(theta)**27 + 1.11802769641676e+125*cos(theta)**25 - 3.96932909970446e+124*cos(theta)**23 + 1.00223579064394e+124*cos(theta)**21 - 1.82224689207989e+123*cos(theta)**19 + 2.38960290295753e+122*cos(theta)**17 - 2.24282950174068e+121*cos(theta)**15 + 1.48111382190422e+120*cos(theta)**13 - 6.68945443593105e+118*cos(theta)**11 + 1.97806448374305e+117*cos(theta)**9 - 3.58020721039466e+115*cos(theta)**7 + 3.55649722886887e+113*cos(theta)**5 - 1.59127392790554e+111*cos(theta)**3 + 2.02968613253257e+108*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl89_m_minus_55(theta, phi):
    return 1.23100805769927e-105*(1.0 - cos(theta)**2)**27.5*(2.06689488283361e+123*cos(theta)**34 - 6.55100581508279e+123*cos(theta)**32 + 9.28371109794589e+123*cos(theta)**30 - 7.78114513989685e+123*cos(theta)**28 + 4.30010652467984e+123*cos(theta)**26 - 1.65388712487686e+123*cos(theta)**24 + 4.55561723019973e+122*cos(theta)**22 - 9.11123446039947e+121*cos(theta)**20 + 1.32755716830974e+121*cos(theta)**18 - 1.40176843858792e+120*cos(theta)**16 + 1.0579384442173e+119*cos(theta)**14 - 5.57454536327587e+117*cos(theta)**12 + 1.97806448374305e+116*cos(theta)**10 - 4.47525901299333e+114*cos(theta)**8 + 5.92749538144812e+112*cos(theta)**6 - 3.97818481976384e+110*cos(theta)**4 + 1.01484306626629e+108*cos(theta)**2 - 4.11701041081657e+104)*sin(55*phi)

#@torch.jit.script
def Yl89_m_minus_54(theta, phi):
    return 8.73929025958482e-104*(1.0 - cos(theta)**2)**27*(5.90541395095316e+121*cos(theta)**35 - 1.98515327729781e+122*cos(theta)**33 + 2.99474551546642e+122*cos(theta)**31 - 2.68315349651615e+122*cos(theta)**29 + 1.59263204617772e+122*cos(theta)**27 - 6.61554849950744e+121*cos(theta)**25 + 1.9807031435651e+121*cos(theta)**23 - 4.3386830763807e+120*cos(theta)**21 + 6.98714299110389e+119*cos(theta)**19 - 8.24569669757602e+118*cos(theta)**17 + 7.05292296144867e+117*cos(theta)**15 - 4.28811181790452e+116*cos(theta)**13 + 1.79824043976641e+115*cos(theta)**11 - 4.97251001443703e+113*cos(theta)**9 + 8.46785054492588e+111*cos(theta)**7 - 7.95636963952768e+109*cos(theta)**5 + 3.38281022088762e+107*cos(theta)**3 - 4.11701041081657e+104*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl89_m_minus_53(theta, phi):
    return 6.2704026980257e-102*(1.0 - cos(theta)**2)**26.5*(1.64039276415366e+120*cos(theta)**36 - 5.83868610969945e+120*cos(theta)**34 + 9.35857973583255e+120*cos(theta)**32 - 8.94384498838718e+120*cos(theta)**30 + 5.68797159349185e+120*cos(theta)**28 - 2.54444173057978e+120*cos(theta)**26 + 8.25292976485459e+119*cos(theta)**24 - 1.97212867108214e+119*cos(theta)**22 + 3.49357149555194e+118*cos(theta)**20 - 4.58094260976445e+117*cos(theta)**18 + 4.40807685090542e+116*cos(theta)**16 - 3.06293701278894e+115*cos(theta)**14 + 1.49853369980534e+114*cos(theta)**12 - 4.97251001443703e+112*cos(theta)**10 + 1.05848131811574e+111*cos(theta)**8 - 1.32606160658795e+109*cos(theta)**6 + 8.45702555221904e+106*cos(theta)**4 - 2.05850520540829e+104*cos(theta)**2 + 7.99730072031191e+100)*sin(53*phi)

#@torch.jit.script
def Yl89_m_minus_52(theta, phi):
    return 4.54506885839889e-100*(1.0 - cos(theta)**2)**26*(4.43349395717204e+118*cos(theta)**37 - 1.6681960313427e+119*cos(theta)**35 + 2.83593325328259e+119*cos(theta)**33 - 2.88511128657651e+119*cos(theta)**31 + 1.96136951499719e+119*cos(theta)**29 - 9.42385826140661e+118*cos(theta)**27 + 3.30117190594184e+118*cos(theta)**25 - 8.57447248296581e+117*cos(theta)**23 + 1.66360547407235e+117*cos(theta)**21 - 2.41102242619182e+116*cos(theta)**19 + 2.59298638288554e+115*cos(theta)**17 - 2.04195800852596e+114*cos(theta)**15 + 1.15271823061949e+113*cos(theta)**13 - 4.52046364948821e+111*cos(theta)**11 + 1.17609035346193e+110*cos(theta)**9 - 1.89437372369707e+108*cos(theta)**7 + 1.69140511044381e+106*cos(theta)**5 - 6.86168401802762e+103*cos(theta)**3 + 7.99730072031191e+100*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl89_m_minus_51(theta, phi):
    return 3.32691589418808e-98*(1.0 - cos(theta)**2)**25.5*(1.16670893609791e+117*cos(theta)**38 - 4.63387786484084e+117*cos(theta)**36 + 8.34098015671351e+117*cos(theta)**34 - 9.01597277055159e+117*cos(theta)**32 + 6.53789838332396e+117*cos(theta)**30 - 3.36566366478808e+117*cos(theta)**28 + 1.26968150228532e+117*cos(theta)**26 - 3.57269686790242e+116*cos(theta)**24 + 7.56184306396525e+115*cos(theta)**22 - 1.20551121309591e+115*cos(theta)**20 + 1.44054799049197e+114*cos(theta)**18 - 1.27622375532873e+113*cos(theta)**16 + 8.2337016472821e+111*cos(theta)**14 - 3.76705304124018e+110*cos(theta)**12 + 1.17609035346193e+109*cos(theta)**10 - 2.36796715462133e+107*cos(theta)**8 + 2.81900851740635e+105*cos(theta)**6 - 1.71542100450691e+103*cos(theta)**4 + 3.99865036015596e+100*cos(theta)**2 - 1.49259065328703e+97)*sin(51*phi)

#@torch.jit.script
def Yl89_m_minus_50(theta, phi):
    return 2.45831846480124e-96*(1.0 - cos(theta)**2)**25*(2.99156137461002e+115*cos(theta)**39 - 1.25239942292996e+116*cos(theta)**37 + 2.38313718763243e+116*cos(theta)**35 - 2.73211296077321e+116*cos(theta)**33 + 2.1089994784916e+116*cos(theta)**31 - 1.16057367751313e+116*cos(theta)**29 + 4.70252408253823e+115*cos(theta)**27 - 1.42907874716097e+115*cos(theta)**25 + 3.28775785389793e+114*cos(theta)**23 - 5.74052958617099e+113*cos(theta)**21 + 7.58183152890509e+112*cos(theta)**19 - 7.50719856075721e+111*cos(theta)**17 + 5.4891344315214e+110*cos(theta)**15 - 2.89773310864629e+109*cos(theta)**13 + 1.06917304860175e+108*cos(theta)**11 - 2.63107461624592e+106*cos(theta)**9 + 4.02715502486621e+104*cos(theta)**7 - 3.43084200901381e+102*cos(theta)**5 + 1.33288345338532e+100*cos(theta)**3 - 1.49259065328703e+97*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl89_m_minus_49(theta, phi):
    return 1.83305518164533e-94*(1.0 - cos(theta)**2)**24.5*(7.47890343652504e+113*cos(theta)**40 - 3.29578795507883e+114*cos(theta)**38 + 6.61982552120119e+114*cos(theta)**36 - 8.03562635521532e+114*cos(theta)**34 + 6.59062337028625e+114*cos(theta)**32 - 3.86857892504376e+114*cos(theta)**30 + 1.6794728866208e+114*cos(theta)**28 - 5.49645671984988e+113*cos(theta)**26 + 1.36989910579081e+113*cos(theta)**24 - 2.60933163007772e+112*cos(theta)**22 + 3.79091576445254e+111*cos(theta)**20 - 4.17066586708734e+110*cos(theta)**18 + 3.43070901970087e+109*cos(theta)**16 - 2.06980936331878e+108*cos(theta)**14 + 8.90977540501461e+106*cos(theta)**12 - 2.63107461624592e+105*cos(theta)**10 + 5.03394378108276e+103*cos(theta)**8 - 5.71807001502302e+101*cos(theta)**6 + 3.3322086334633e+99*cos(theta)**4 - 7.46295326643516e+96*cos(theta)**2 + 2.68451556346588e+93)*sin(49*phi)

#@torch.jit.script
def Yl89_m_minus_48(theta, phi):
    return 1.37881821026187e-92*(1.0 - cos(theta)**2)**24*(1.82412278939635e+112*cos(theta)**41 - 8.45073834635598e+112*cos(theta)**39 + 1.78914203275708e+113*cos(theta)**37 - 2.29589324434724e+113*cos(theta)**35 + 1.99715859705644e+113*cos(theta)**33 - 1.24792868549799e+113*cos(theta)**31 + 5.79128581593378e+112*cos(theta)**29 - 2.03572471105551e+112*cos(theta)**27 + 5.47959642316322e+111*cos(theta)**25 - 1.13449201307727e+111*cos(theta)**23 + 1.80519798307264e+110*cos(theta)**21 - 2.19508729846702e+109*cos(theta)**19 + 2.01806412923581e+108*cos(theta)**17 - 1.37987290887919e+107*cos(theta)**15 + 6.85367338847277e+105*cos(theta)**13 - 2.39188601476902e+104*cos(theta)**11 + 5.59327086786974e+102*cos(theta)**9 - 8.16867145003288e+100*cos(theta)**7 + 6.66441726692659e+98*cos(theta)**5 - 2.48765108881172e+96*cos(theta)**3 + 2.68451556346588e+93*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl89_m_minus_47(theta, phi):
    return 1.04590427793794e-90*(1.0 - cos(theta)**2)**23.5*(4.34314949856274e+110*cos(theta)**42 - 2.11268458658899e+111*cos(theta)**40 + 4.70826850725547e+111*cos(theta)**38 - 6.37748123429788e+111*cos(theta)**36 + 5.87399587369541e+111*cos(theta)**34 - 3.89977714218121e+111*cos(theta)**32 + 1.93042860531126e+111*cos(theta)**30 - 7.27044539662682e+110*cos(theta)**28 + 2.10753708583201e+110*cos(theta)**26 - 4.72705005448863e+109*cos(theta)**24 + 8.20544537760291e+108*cos(theta)**22 - 1.09754364923351e+108*cos(theta)**20 + 1.12114673846434e+107*cos(theta)**18 - 8.62420568049491e+105*cos(theta)**16 + 4.89548099176627e+104*cos(theta)**14 - 1.99323834564085e+103*cos(theta)**12 + 5.59327086786974e+101*cos(theta)**10 - 1.02108393125411e+100*cos(theta)**8 + 1.11073621115443e+98*cos(theta)**6 - 6.2191277220293e+95*cos(theta)**4 + 1.34225778173294e+93*cos(theta)**2 - 4.66547716973563e+89)*sin(47*phi)

#@torch.jit.script
def Yl89_m_minus_46(theta, phi):
    return 7.99826190890544e-89*(1.0 - cos(theta)**2)**23*(1.01003476710761e+109*cos(theta)**43 - 5.15288923558291e+109*cos(theta)**41 + 1.20724833519371e+110*cos(theta)**39 - 1.72364357683726e+110*cos(theta)**37 + 1.67828453534155e+110*cos(theta)**35 - 1.18175064914582e+110*cos(theta)**33 + 6.22718904939116e+109*cos(theta)**31 - 2.50705013676787e+109*cos(theta)**29 + 7.80569291048892e+108*cos(theta)**27 - 1.89082002179545e+108*cos(theta)**25 + 3.56758494678387e+107*cos(theta)**23 - 5.22639832968338e+106*cos(theta)**21 + 5.90077230770704e+105*cos(theta)**19 - 5.07306216499701e+104*cos(theta)**17 + 3.26365399451085e+103*cos(theta)**15 - 1.53326026587758e+102*cos(theta)**13 + 5.0847916980634e+100*cos(theta)**11 - 1.13453770139346e+99*cos(theta)**9 + 1.5867660159349e+97*cos(theta)**7 - 1.24382554440586e+95*cos(theta)**5 + 4.47419260577647e+92*cos(theta)**3 - 4.66547716973563e+89*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl89_m_minus_45(theta, phi):
    return 6.16437206669811e-87*(1.0 - cos(theta)**2)**22.5*(2.29553356160821e+107*cos(theta)**44 - 1.2268783894245e+108*cos(theta)**42 + 3.01812083798428e+108*cos(theta)**40 - 4.53590414957175e+108*cos(theta)**38 + 4.66190148705985e+108*cos(theta)**36 - 3.47573720337007e+108*cos(theta)**34 + 1.94599657793474e+108*cos(theta)**32 - 8.35683378922623e+107*cos(theta)**30 + 2.78774746803176e+107*cos(theta)**28 - 7.27238469921328e+106*cos(theta)**26 + 1.48649372782661e+106*cos(theta)**24 - 2.37563560440154e+105*cos(theta)**22 + 2.95038615385352e+104*cos(theta)**20 - 2.81836786944278e+103*cos(theta)**18 + 2.03978374656928e+102*cos(theta)**16 - 1.09518590419827e+101*cos(theta)**14 + 4.23732641505283e+99*cos(theta)**12 - 1.13453770139346e+98*cos(theta)**10 + 1.98345751991863e+96*cos(theta)**8 - 2.07304257400977e+94*cos(theta)**6 + 1.11854815144412e+92*cos(theta)**4 - 2.33273858486782e+89*cos(theta)**2 + 7.85433866958861e+85)*sin(45*phi)

#@torch.jit.script
def Yl89_m_minus_44(theta, phi):
    return 4.78682444162545e-85*(1.0 - cos(theta)**2)**22*(5.1011856924627e+105*cos(theta)**45 - 2.85320555680117e+106*cos(theta)**43 + 7.36127033654702e+106*cos(theta)**41 - 1.16305234604404e+107*cos(theta)**39 + 1.25997337488104e+107*cos(theta)**37 - 9.93067772391447e+106*cos(theta)**35 + 5.89695932707496e+106*cos(theta)**33 - 2.69575283523427e+106*cos(theta)**31 + 9.61292230355778e+105*cos(theta)**29 - 2.69347581452344e+105*cos(theta)**27 + 5.94597491130645e+104*cos(theta)**25 - 1.03288504539197e+104*cos(theta)**23 + 1.4049457875493e+103*cos(theta)**21 - 1.48335151023304e+102*cos(theta)**19 + 1.19987279209958e+101*cos(theta)**17 - 7.3012393613218e+99*cos(theta)**15 + 3.25948185773295e+98*cos(theta)**13 - 1.03139791035769e+97*cos(theta)**11 + 2.20384168879848e+95*cos(theta)**9 - 2.96148939144252e+93*cos(theta)**7 + 2.23709630288824e+91*cos(theta)**5 - 7.77579528289272e+88*cos(theta)**3 + 7.85433866958861e+85*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl89_m_minus_43(theta, phi):
    return 3.74414135178388e-83*(1.0 - cos(theta)**2)**21.5*(1.10895341140493e+104*cos(theta)**46 - 6.48455808363902e+104*cos(theta)**44 + 1.75268341346358e+105*cos(theta)**42 - 2.90763086511009e+105*cos(theta)**40 + 3.31571940758169e+105*cos(theta)**38 - 2.75852158997624e+105*cos(theta)**36 + 1.73439980208087e+105*cos(theta)**34 - 8.42422761010709e+104*cos(theta)**32 + 3.20430743451926e+104*cos(theta)**30 - 9.61955648044085e+103*cos(theta)**28 + 2.28691342742556e+103*cos(theta)**26 - 4.30368768913322e+102*cos(theta)**24 + 6.38611721613316e+101*cos(theta)**22 - 7.41675755116521e+100*cos(theta)**20 + 6.66595995610875e+99*cos(theta)**18 - 4.56327460082613e+98*cos(theta)**16 + 2.3282013269521e+97*cos(theta)**14 - 8.59498258631406e+95*cos(theta)**12 + 2.20384168879848e+94*cos(theta)**10 - 3.70186173930315e+92*cos(theta)**8 + 3.72849383814706e+90*cos(theta)**6 - 1.94394882072318e+88*cos(theta)**4 + 3.9271693347943e+85*cos(theta)**2 - 1.28380821667025e+82)*sin(43*phi)

#@torch.jit.script
def Yl89_m_minus_42(theta, phi):
    return 2.94909070805061e-81*(1.0 - cos(theta)**2)**21*(2.35947534341475e+102*cos(theta)**47 - 1.44101290747534e+103*cos(theta)**45 + 4.07600793828739e+103*cos(theta)**43 - 7.0917825978295e+103*cos(theta)**41 + 8.50184463482484e+103*cos(theta)**39 - 7.45546375669255e+103*cos(theta)**37 + 4.95542800594535e+103*cos(theta)**35 - 2.552796245487e+103*cos(theta)**33 + 1.03364755952234e+103*cos(theta)**31 - 3.31708844153133e+102*cos(theta)**29 + 8.47004973120578e+101*cos(theta)**27 - 1.72147507565329e+101*cos(theta)**25 + 2.77657270266659e+100*cos(theta)**23 - 3.53178931007867e+99*cos(theta)**21 + 3.50839997689934e+98*cos(theta)**19 - 2.68427917695654e+97*cos(theta)**17 + 1.55213421796807e+96*cos(theta)**15 - 6.61152506639543e+94*cos(theta)**13 + 2.00349244436225e+93*cos(theta)**11 - 4.11317971033684e+91*cos(theta)**9 + 5.32641976878151e+89*cos(theta)**7 - 3.88789764144636e+87*cos(theta)**5 + 1.30905644493143e+85*cos(theta)**3 - 1.28380821667025e+82*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl89_m_minus_41(theta, phi):
    return 2.33853781656624e-79*(1.0 - cos(theta)**2)**20.5*(4.91557363211407e+100*cos(theta)**48 - 3.13263675538117e+101*cos(theta)**46 + 9.2636544051986e+101*cos(theta)**44 - 1.68851966614988e+102*cos(theta)**42 + 2.12546115870621e+102*cos(theta)**40 - 1.96196414649804e+102*cos(theta)**38 + 1.37650777942926e+102*cos(theta)**36 - 7.50822425143234e+101*cos(theta)**34 + 3.23014862350732e+101*cos(theta)**32 - 1.10569614717711e+101*cos(theta)**30 + 3.02501776114492e+100*cos(theta)**28 - 6.62105798328187e+99*cos(theta)**26 + 1.15690529277775e+99*cos(theta)**24 - 1.60535877730849e+98*cos(theta)**22 + 1.75419998844967e+97*cos(theta)**20 - 1.4912662094203e+96*cos(theta)**18 + 9.70083886230044e+94*cos(theta)**16 - 4.72251790456816e+93*cos(theta)**14 + 1.66957703696854e+92*cos(theta)**12 - 4.11317971033684e+90*cos(theta)**10 + 6.65802471097689e+88*cos(theta)**8 - 6.4798294024106e+86*cos(theta)**6 + 3.27264111232859e+84*cos(theta)**4 - 6.41904108335126e+81*cos(theta)**2 + 2.04167973389035e+78)*sin(41*phi)

#@torch.jit.script
def Yl89_m_minus_40(theta, phi):
    return 1.86644034437968e-77*(1.0 - cos(theta)**2)**20*(1.00317829226818e+99*cos(theta)**49 - 6.66518458591738e+99*cos(theta)**47 + 2.05858986782191e+100*cos(theta)**45 - 3.92678992127879e+100*cos(theta)**43 + 5.18405160660051e+100*cos(theta)**41 - 5.03067729871292e+100*cos(theta)**39 + 3.72029129575477e+100*cos(theta)**37 - 2.14520692898067e+100*cos(theta)**35 + 9.78832916214339e+99*cos(theta)**33 - 3.56676176508745e+99*cos(theta)**31 + 1.04310957280859e+99*cos(theta)**29 - 2.45224369751181e+98*cos(theta)**27 + 4.62762117111099e+97*cos(theta)**25 - 6.97982077090647e+96*cos(theta)**23 + 8.35333327833177e+95*cos(theta)**21 - 7.84876952326475e+94*cos(theta)**19 + 5.7063758013532e+93*cos(theta)**17 - 3.14834526971211e+92*cos(theta)**15 + 1.28429002843734e+91*cos(theta)**13 - 3.7392542821244e+89*cos(theta)**11 + 7.39780523441877e+87*cos(theta)**9 - 9.25689914630086e+85*cos(theta)**7 + 6.54528222465717e+83*cos(theta)**5 - 2.13968036111709e+81*cos(theta)**3 + 2.04167973389035e+78*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl89_m_minus_39(theta, phi):
    return 1.49897355401543e-75*(1.0 - cos(theta)**2)**19.5*(2.00635658453636e+97*cos(theta)**50 - 1.38858012206612e+98*cos(theta)**48 + 4.47519536483024e+98*cos(theta)**46 - 8.92452254836089e+98*cos(theta)**44 + 1.23429800157155e+99*cos(theta)**42 - 1.25766932467823e+99*cos(theta)**40 + 9.79024025198622e+98*cos(theta)**38 - 5.95890813605741e+98*cos(theta)**36 + 2.87892034180688e+98*cos(theta)**34 - 1.11461305158983e+98*cos(theta)**32 + 3.47703190936198e+97*cos(theta)**30 - 8.75801320539931e+96*cos(theta)**28 + 1.77985429658115e+96*cos(theta)**26 - 2.90825865454436e+95*cos(theta)**24 + 3.79696967196899e+94*cos(theta)**22 - 3.92438476163237e+93*cos(theta)**20 + 3.17020877852955e+92*cos(theta)**18 - 1.96771579357007e+91*cos(theta)**16 + 9.17350020312386e+89*cos(theta)**14 - 3.11604523510366e+88*cos(theta)**12 + 7.39780523441877e+86*cos(theta)**10 - 1.15711239328761e+85*cos(theta)**8 + 1.0908803707762e+83*cos(theta)**6 - 5.34920090279272e+80*cos(theta)**4 + 1.02083986694518e+78*cos(theta)**2 - 3.16539493626411e+74)*sin(39*phi)

#@torch.jit.script
def Yl89_m_minus_38(theta, phi):
    return 1.21111126490024e-73*(1.0 - cos(theta)**2)**19*(3.93403251869874e+95*cos(theta)**51 - 2.83383698380841e+96*cos(theta)**49 + 9.52169226559626e+96*cos(theta)**47 - 1.98322723296909e+97*cos(theta)**45 + 2.87046046877105e+97*cos(theta)**43 - 3.06748615775178e+97*cos(theta)**41 + 2.5103180133298e+97*cos(theta)**39 - 1.61051571244795e+97*cos(theta)**37 + 8.2254866908768e+96*cos(theta)**35 - 3.37761530784796e+96*cos(theta)**33 + 1.12162319656838e+96*cos(theta)**31 - 3.02000455358597e+95*cos(theta)**29 + 6.59205295030055e+94*cos(theta)**27 - 1.16330346181774e+94*cos(theta)**25 + 1.65085637911695e+93*cos(theta)**23 - 1.86875464839637e+92*cos(theta)**21 + 1.66853093606819e+91*cos(theta)**19 - 1.15747987857063e+90*cos(theta)**17 + 6.11566680208257e+88*cos(theta)**15 - 2.39695787315666e+87*cos(theta)**13 + 6.72527748583524e+85*cos(theta)**11 - 1.28568043698623e+84*cos(theta)**9 + 1.55840052968028e+82*cos(theta)**7 - 1.06984018055854e+80*cos(theta)**5 + 3.40279955648392e+77*cos(theta)**3 - 3.16539493626411e+74*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl89_m_minus_37(theta, phi):
    return 9.84209552655039e-72*(1.0 - cos(theta)**2)**18.5*(7.56544715134372e+93*cos(theta)**52 - 5.66767396761682e+94*cos(theta)**50 + 1.98368588866589e+95*cos(theta)**48 - 4.3113635499328e+95*cos(theta)**46 + 6.52377379266147e+95*cos(theta)**44 - 7.30353847083757e+95*cos(theta)**42 + 6.2757950333245e+95*cos(theta)**40 - 4.23819924328408e+95*cos(theta)**38 + 2.28485741413244e+95*cos(theta)**36 - 9.93416267014106e+94*cos(theta)**34 + 3.50507248927619e+94*cos(theta)**32 - 1.00666818452866e+94*cos(theta)**30 + 2.35430462510734e+93*cos(theta)**28 - 4.4742440839144e+92*cos(theta)**26 + 6.87856824632063e+91*cos(theta)**24 - 8.49433931089259e+90*cos(theta)**22 + 8.34265468034093e+89*cos(theta)**20 - 6.43044376983682e+88*cos(theta)**18 + 3.82229175130161e+87*cos(theta)**16 - 1.71211276654047e+86*cos(theta)**14 + 5.6043979048627e+84*cos(theta)**12 - 1.28568043698623e+83*cos(theta)**10 + 1.94800066210035e+81*cos(theta)**8 - 1.78306696759757e+79*cos(theta)**6 + 8.5069988912098e+76*cos(theta)**4 - 1.58269746813206e+74*cos(theta)**2 + 4.79314799555438e+70)*sin(37*phi)

#@torch.jit.script
def Yl89_m_minus_36(theta, phi):
    return 8.04286507778352e-70*(1.0 - cos(theta)**2)**18*(1.4274428587441e+92*cos(theta)**53 - 1.11130862110134e+93*cos(theta)**51 + 4.04833854829773e+93*cos(theta)**49 - 9.17311393602723e+93*cos(theta)**47 + 1.44972750948033e+94*cos(theta)**45 - 1.69849731879944e+94*cos(theta)**43 + 1.530681715445e+94*cos(theta)**41 - 1.08671775468823e+94*cos(theta)**39 + 6.17529030846607e+93*cos(theta)**37 - 2.83833219146888e+93*cos(theta)**35 + 1.06214317856854e+93*cos(theta)**33 - 3.24731672428599e+92*cos(theta)**31 + 8.11829181071497e+91*cos(theta)**29 - 1.65712743848682e+91*cos(theta)**27 + 2.75142729852825e+90*cos(theta)**25 - 3.69319100473591e+89*cos(theta)**23 + 3.97269270492425e+88*cos(theta)**21 - 3.3844440893878e+87*cos(theta)**19 + 2.24840691253036e+86*cos(theta)**17 - 1.14140851102698e+85*cos(theta)**15 + 4.31107531143285e+83*cos(theta)**13 - 1.16880039726021e+82*cos(theta)**11 + 2.1644451801115e+80*cos(theta)**9 - 2.54723852513939e+78*cos(theta)**7 + 1.70139977824196e+76*cos(theta)**5 - 5.27565822710685e+73*cos(theta)**3 + 4.79314799555438e+70*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl89_m_minus_35(theta, phi):
    return 6.60788794510886e-68*(1.0 - cos(theta)**2)**17.5*(2.64341270137796e+90*cos(theta)**54 - 2.13713196365642e+91*cos(theta)**52 + 8.09667709659546e+91*cos(theta)**50 - 1.91106540333901e+92*cos(theta)**48 + 3.15158154234854e+92*cos(theta)**46 - 3.86022117908963e+92*cos(theta)**44 + 3.64448027486905e+92*cos(theta)**42 - 2.71679438672056e+92*cos(theta)**40 + 1.62507639696475e+92*cos(theta)**38 - 7.88425608741354e+91*cos(theta)**36 + 3.12395052520159e+91*cos(theta)**34 - 1.01478647633937e+91*cos(theta)**32 + 2.70609727023832e+90*cos(theta)**30 - 5.91831228031006e+89*cos(theta)**28 + 1.05824126866471e+89*cos(theta)**26 - 1.53882958530663e+88*cos(theta)**24 + 1.80576941132921e+87*cos(theta)**22 - 1.6922220446939e+86*cos(theta)**20 + 1.24911495140575e+85*cos(theta)**18 - 7.13380319391864e+83*cos(theta)**16 + 3.07933950816632e+82*cos(theta)**14 - 9.74000331050175e+80*cos(theta)**12 + 2.1644451801115e+79*cos(theta)**10 - 3.18404815642424e+77*cos(theta)**8 + 2.83566629706993e+75*cos(theta)**6 - 1.31891455677671e+73*cos(theta)**4 + 2.39657399777719e+70*cos(theta)**2 - 7.10095999341389e+66)*sin(35*phi)

#@torch.jit.script
def Yl89_m_minus_34(theta, phi):
    return 5.45701134971043e-66*(1.0 - cos(theta)**2)**17*(4.80620491159629e+88*cos(theta)**55 - 4.03232445972909e+89*cos(theta)**53 + 1.58758374443048e+90*cos(theta)**51 - 3.90013347620205e+90*cos(theta)**49 + 6.70549264329476e+90*cos(theta)**47 - 8.57826928686584e+90*cos(theta)**45 + 8.47553552295128e+90*cos(theta)**43 - 6.62632777248918e+90*cos(theta)**41 + 4.16686255631988e+90*cos(theta)**39 - 2.13088002362528e+90*cos(theta)**37 + 8.92557292914741e+89*cos(theta)**35 - 3.07511053436173e+89*cos(theta)**33 + 8.72934603302684e+88*cos(theta)**31 - 2.04079733803795e+88*cos(theta)**29 + 3.9194121061656e+87*cos(theta)**27 - 6.15531834122651e+86*cos(theta)**25 + 7.85117135360524e+85*cos(theta)**23 - 8.0582002128281e+84*cos(theta)**21 + 6.57428921792503e+83*cos(theta)**19 - 4.19635481995214e+82*cos(theta)**17 + 2.05289300544421e+81*cos(theta)**15 - 7.4923102388475e+79*cos(theta)**13 + 1.967677436465e+78*cos(theta)**11 - 3.53783128491582e+76*cos(theta)**9 + 4.05095185295705e+74*cos(theta)**7 - 2.63782911355343e+72*cos(theta)**5 + 7.98857999259063e+69*cos(theta)**3 - 7.10095999341389e+66*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl89_m_minus_33(theta, phi):
    return 4.52899067270559e-64*(1.0 - cos(theta)**2)**16.5*(8.58250877070766e+86*cos(theta)**56 - 7.46726751801684e+87*cos(theta)**54 + 3.05304566236631e+88*cos(theta)**52 - 7.8002669524041e+88*cos(theta)**50 + 1.39697763401974e+89*cos(theta)**48 - 1.86484114931866e+89*cos(theta)**46 + 1.92625807339802e+89*cos(theta)**44 - 1.5776970886879e+89*cos(theta)**42 + 1.04171563907997e+89*cos(theta)**40 - 5.60757900954021e+88*cos(theta)**38 + 2.47932581365206e+88*cos(theta)**36 - 9.04444274812273e+87*cos(theta)**34 + 2.72792063532089e+87*cos(theta)**32 - 6.80265779345983e+86*cos(theta)**30 + 1.39979003791629e+86*cos(theta)**28 - 2.36743013124097e+85*cos(theta)**26 + 3.27132139733552e+84*cos(theta)**24 - 3.66281827855823e+83*cos(theta)**22 + 3.28714460896251e+82*cos(theta)**20 - 2.33130823330675e+81*cos(theta)**18 + 1.28305812840263e+80*cos(theta)**16 - 5.35165017060535e+78*cos(theta)**14 + 1.63973119705417e+77*cos(theta)**12 - 3.53783128491582e+75*cos(theta)**10 + 5.06368981619631e+73*cos(theta)**8 - 4.39638185592238e+71*cos(theta)**6 + 1.99714499814766e+69*cos(theta)**4 - 3.55047999670695e+66*cos(theta)**2 + 1.03091753679063e+63)*sin(33*phi)

#@torch.jit.script
def Yl89_m_minus_32(theta, phi):
    return 3.77675462261663e-62*(1.0 - cos(theta)**2)**16*(1.50570329310661e+85*cos(theta)**57 - 1.35768500327579e+86*cos(theta)**55 + 5.7604635138987e+86*cos(theta)**53 - 1.52946410831453e+87*cos(theta)**51 + 2.85097476330559e+87*cos(theta)**49 - 3.96774712620992e+87*cos(theta)**47 + 4.28057349644004e+87*cos(theta)**45 - 3.6690629969486e+87*cos(theta)**43 + 2.54076985141456e+87*cos(theta)**41 - 1.43784077167698e+87*cos(theta)**39 + 6.70088057743799e+86*cos(theta)**37 - 2.58412649946364e+86*cos(theta)**35 + 8.26642616763906e+85*cos(theta)**33 - 2.19440573982575e+85*cos(theta)**31 + 4.82686219971133e+84*cos(theta)**29 - 8.76825974533691e+83*cos(theta)**27 + 1.30852855893421e+83*cos(theta)**25 - 1.59252968632966e+82*cos(theta)**23 + 1.56530695664882e+81*cos(theta)**21 - 1.22700433331934e+80*cos(theta)**19 + 7.54740075530961e+78*cos(theta)**17 - 3.56776678040357e+77*cos(theta)**15 + 1.26133169004167e+76*cos(theta)**13 - 3.21621025901438e+74*cos(theta)**11 + 5.6263220179959e+72*cos(theta)**9 - 6.28054550846054e+70*cos(theta)**7 + 3.99428999629531e+68*cos(theta)**5 - 1.18349333223565e+66*cos(theta)**3 + 1.03091753679063e+63*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl89_m_minus_31(theta, phi):
    return 3.1639196910608e-60*(1.0 - cos(theta)**2)**15.5*(2.59604016052863e+83*cos(theta)**58 - 2.42443750584962e+84*cos(theta)**56 + 1.06675250257383e+85*cos(theta)**54 - 2.9412771313741e+85*cos(theta)**52 + 5.70194952661119e+85*cos(theta)**50 - 8.26613984627066e+85*cos(theta)**48 + 9.30559455747834e+85*cos(theta)**46 - 8.33877953851955e+85*cos(theta)**44 + 6.04945202717753e+85*cos(theta)**42 - 3.59460192919245e+85*cos(theta)**40 + 1.76338962564158e+85*cos(theta)**38 - 7.17812916517677e+84*cos(theta)**36 + 2.43130181401149e+84*cos(theta)**34 - 6.85751793695548e+83*cos(theta)**32 + 1.60895406657044e+83*cos(theta)**30 - 3.13152133762033e+82*cos(theta)**28 + 5.03280214974695e+81*cos(theta)**26 - 6.63554035970693e+80*cos(theta)**24 + 7.11503162113098e+79*cos(theta)**22 - 6.1350216665967e+78*cos(theta)**20 + 4.19300041961645e+77*cos(theta)**18 - 2.22985423775223e+76*cos(theta)**16 + 9.00951207172619e+74*cos(theta)**14 - 2.68017521584532e+73*cos(theta)**12 + 5.6263220179959e+71*cos(theta)**10 - 7.85068188557567e+69*cos(theta)**8 + 6.65714999382552e+67*cos(theta)**6 - 2.95873333058912e+65*cos(theta)**4 + 5.15458768395317e+62*cos(theta)**2 - 1.46896200739617e+59)*sin(31*phi)

#@torch.jit.script
def Yl89_m_minus_30(theta, phi):
    return 2.66220858884676e-58*(1.0 - cos(theta)**2)**15*(4.4000680686926e+81*cos(theta)**59 - 4.25339913306951e+82*cos(theta)**57 + 1.9395500046797e+83*cos(theta)**55 - 5.54957949315867e+83*cos(theta)**53 + 1.11802931894337e+84*cos(theta)**51 - 1.68696731556544e+84*cos(theta)**49 + 1.97991373563369e+84*cos(theta)**47 - 1.85306211967101e+84*cos(theta)**45 + 1.40684930864594e+84*cos(theta)**43 - 8.76732177851816e+83*cos(theta)**41 + 4.52151186061943e+83*cos(theta)**39 - 1.94003490950724e+83*cos(theta)**37 + 6.94657661146139e+82*cos(theta)**35 - 2.07803573847136e+82*cos(theta)**33 + 5.19017440829175e+81*cos(theta)**31 - 1.07983494400701e+81*cos(theta)**29 + 1.86400079620257e+80*cos(theta)**27 - 2.65421614388277e+79*cos(theta)**25 + 3.09349200918738e+78*cos(theta)**23 - 2.92143888885557e+77*cos(theta)**21 + 2.20684232611392e+76*cos(theta)**19 - 1.31167896338367e+75*cos(theta)**17 + 6.00634138115079e+73*cos(theta)**15 - 2.06167324295794e+72*cos(theta)**13 + 5.11483819817809e+70*cos(theta)**11 - 8.72297987286186e+68*cos(theta)**9 + 9.5102142768936e+66*cos(theta)**7 - 5.91746666117824e+64*cos(theta)**5 + 1.71819589465106e+62*cos(theta)**3 - 1.46896200739617e+59*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl89_m_minus_29(theta, phi):
    return 2.24952687544693e-56*(1.0 - cos(theta)**2)**14.5*(7.33344678115433e+79*cos(theta)**60 - 7.33344678115433e+80*cos(theta)**58 + 3.46348215121375e+81*cos(theta)**56 - 1.0276999061405e+82*cos(theta)**54 + 2.1500563825834e+82*cos(theta)**52 - 3.37393463113088e+82*cos(theta)**50 + 4.12482028257019e+82*cos(theta)**48 - 4.02839591232829e+82*cos(theta)**46 + 3.19738479237713e+82*cos(theta)**44 - 2.08745756631385e+82*cos(theta)**42 + 1.13037796515486e+82*cos(theta)**40 - 5.10535502501904e+81*cos(theta)**38 + 1.92960461429483e+81*cos(theta)**36 - 6.1118698190334e+80*cos(theta)**34 + 1.62192950259117e+80*cos(theta)**32 - 3.5994498133567e+79*cos(theta)**30 + 6.65714570072348e+78*cos(theta)**28 - 1.02085236303184e+78*cos(theta)**26 + 1.28895500382808e+77*cos(theta)**24 - 1.32792676766162e+76*cos(theta)**22 + 1.10342116305696e+75*cos(theta)**20 - 7.28710535213147e+73*cos(theta)**18 + 3.75396336321924e+72*cos(theta)**16 - 1.47262374496996e+71*cos(theta)**14 + 4.26236516514841e+69*cos(theta)**12 - 8.72297987286186e+67*cos(theta)**10 + 1.1887767846117e+66*cos(theta)**8 - 9.86244443529707e+63*cos(theta)**6 + 4.29548973662764e+61*cos(theta)**4 - 7.34481003698087e+58*cos(theta)**2 + 2.05736975825795e+55)*sin(29*phi)

#@torch.jit.script
def Yl89_m_minus_28(theta, phi):
    return 1.90852172201028e-54*(1.0 - cos(theta)**2)**14*(1.20220439035317e+78*cos(theta)**61 - 1.24295708155158e+79*cos(theta)**59 + 6.07628447581359e+79*cos(theta)**57 - 1.86854528389181e+80*cos(theta)**55 + 4.05671015581774e+80*cos(theta)**53 - 6.61555810025663e+80*cos(theta)**51 + 8.41800057667385e+80*cos(theta)**49 - 8.57105513261338e+80*cos(theta)**47 + 7.10529953861584e+80*cos(theta)**45 - 4.85455247979965e+80*cos(theta)**43 + 2.75701942720697e+80*cos(theta)**41 - 1.30906539103052e+80*cos(theta)**39 + 5.21514760620225e+79*cos(theta)**37 - 1.74624851972383e+79*cos(theta)**35 + 4.91493788663992e+78*cos(theta)**33 - 1.16111284301829e+78*cos(theta)**31 + 2.2955674830081e+77*cos(theta)**29 - 3.78093467789569e+76*cos(theta)**27 + 5.1558200153123e+75*cos(theta)**25 - 5.77359464200706e+74*cos(theta)**23 + 5.25438649074743e+73*cos(theta)**21 - 3.83531860638499e+72*cos(theta)**19 + 2.20821374307014e+71*cos(theta)**17 - 9.81749163313303e+69*cos(theta)**15 + 3.27874243472954e+68*cos(theta)**13 - 7.92998170260169e+66*cos(theta)**11 + 1.320863094013e+65*cos(theta)**9 - 1.40892063361387e+63*cos(theta)**7 + 8.59097947325529e+60*cos(theta)**5 - 2.44827001232696e+58*cos(theta)**3 + 2.05736975825795e+55*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl89_m_minus_27(theta, phi):
    return 1.62549591679572e-52*(1.0 - cos(theta)**2)**13.5*(1.93903933927931e+76*cos(theta)**62 - 2.0715951359193e+77*cos(theta)**60 + 1.04763525445062e+78*cos(theta)**58 - 3.33668800694966e+78*cos(theta)**56 + 7.5124262144773e+78*cos(theta)**54 - 1.27222271158781e+79*cos(theta)**52 + 1.68360011533477e+79*cos(theta)**50 - 1.78563648596112e+79*cos(theta)**48 + 1.54463033448171e+79*cos(theta)**46 - 1.10330738177265e+79*cos(theta)**44 + 6.5643319695404e+78*cos(theta)**42 - 3.27266347757631e+78*cos(theta)**40 + 1.37240726479007e+78*cos(theta)**38 - 4.85069033256619e+77*cos(theta)**36 + 1.4455699666588e+77*cos(theta)**34 - 3.62847763443215e+76*cos(theta)**32 + 7.65189161002699e+75*cos(theta)**30 - 1.35033381353417e+75*cos(theta)**28 + 1.98300769819704e+74*cos(theta)**26 - 2.40566443416961e+73*cos(theta)**24 + 2.38835749579429e+72*cos(theta)**22 - 1.91765930319249e+71*cos(theta)**20 + 1.22678541281675e+70*cos(theta)**18 - 6.13593227070815e+68*cos(theta)**16 + 2.34195888194967e+67*cos(theta)**14 - 6.60831808550141e+65*cos(theta)**12 + 1.320863094013e+64*cos(theta)**10 - 1.76115079201733e+62*cos(theta)**8 + 1.43182991220921e+60*cos(theta)**6 - 6.12067503081739e+57*cos(theta)**4 + 1.02868487912897e+55*cos(theta)**2 - 2.83618659809477e+51)*sin(27*phi)

#@torch.jit.script
def Yl89_m_minus_26(theta, phi):
    return 1.38958511135867e-50*(1.0 - cos(theta)**2)**13*(3.07784022107826e+74*cos(theta)**63 - 3.39605759986771e+75*cos(theta)**61 + 1.77565297364512e+76*cos(theta)**59 - 5.85383860868361e+76*cos(theta)**57 + 1.36589567535951e+77*cos(theta)**55 - 2.40042021054304e+77*cos(theta)**53 + 3.30117669673484e+77*cos(theta)**51 - 3.6441560937982e+77*cos(theta)**49 + 3.28644752017384e+77*cos(theta)**47 - 2.45179418171699e+77*cos(theta)**45 + 1.52658883012567e+77*cos(theta)**43 - 7.98210604286905e+76*cos(theta)**41 + 3.51899298664119e+76*cos(theta)**39 - 1.31099738718005e+76*cos(theta)**37 + 4.13019990473943e+75*cos(theta)**35 - 1.09953867710065e+75*cos(theta)**33 + 2.46835213226677e+74*cos(theta)**31 - 4.65632349494543e+73*cos(theta)**29 + 7.34447295628533e+72*cos(theta)**27 - 9.62265773667843e+71*cos(theta)**25 + 1.03841630251926e+71*cos(theta)**23 - 9.1317109675833e+69*cos(theta)**21 + 6.45676533061446e+68*cos(theta)**19 - 3.60937192394597e+67*cos(theta)**17 + 1.56130592129978e+66*cos(theta)**15 - 5.08332160423185e+64*cos(theta)**13 + 1.20078463092091e+63*cos(theta)**11 - 1.95683421335259e+61*cos(theta)**9 + 2.04547130315602e+59*cos(theta)**7 - 1.22413500616348e+57*cos(theta)**5 + 3.42894959709658e+54*cos(theta)**3 - 2.83618659809477e+51*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl89_m_minus_25(theta, phi):
    return 1.19213121397702e-48*(1.0 - cos(theta)**2)**12.5*(4.80912534543478e+72*cos(theta)**64 - 5.47751225785115e+73*cos(theta)**62 + 2.95942162274186e+74*cos(theta)**60 - 1.00928251873855e+75*cos(theta)**58 + 2.43909942028484e+75*cos(theta)**56 - 4.44522261211675e+75*cos(theta)**54 + 6.34841672449009e+75*cos(theta)**52 - 7.28831218759641e+75*cos(theta)**50 + 6.84676566702884e+75*cos(theta)**48 - 5.32998735155868e+75*cos(theta)**46 + 3.46952006846744e+75*cos(theta)**44 - 1.90050143877834e+75*cos(theta)**42 + 8.79748246660298e+74*cos(theta)**40 - 3.44999312415803e+74*cos(theta)**38 + 1.14727775131651e+74*cos(theta)**36 - 3.23393728559015e+73*cos(theta)**34 + 7.71360041333366e+72*cos(theta)**32 - 1.55210783164848e+72*cos(theta)**30 + 2.62302605581619e+71*cos(theta)**28 - 3.70102220641478e+70*cos(theta)**26 + 4.32673459383023e+69*cos(theta)**24 - 4.15077771253786e+68*cos(theta)**22 + 3.22838266530723e+67*cos(theta)**20 - 2.00520662441443e+66*cos(theta)**18 + 9.75816200812364e+64*cos(theta)**16 - 3.63094400302275e+63*cos(theta)**14 + 1.00065385910076e+62*cos(theta)**12 - 1.95683421335259e+60*cos(theta)**10 + 2.55683912894503e+58*cos(theta)**8 - 2.04022501027246e+56*cos(theta)**6 + 8.57237399274144e+53*cos(theta)**4 - 1.41809329904739e+51*cos(theta)**2 + 3.85351439958529e+47)*sin(25*phi)

#@torch.jit.script
def Yl89_m_minus_24(theta, phi):
    return 1.02620272462204e-46*(1.0 - cos(theta)**2)**12*(7.39865437759198e+70*cos(theta)**65 - 8.69446390135102e+71*cos(theta)**63 + 4.85151085695387e+72*cos(theta)**61 - 1.71064833684501e+73*cos(theta)**59 + 4.2791217899734e+73*cos(theta)**57 - 8.08222293112136e+73*cos(theta)**55 + 1.19781447631888e+74*cos(theta)**53 - 1.42908082109734e+74*cos(theta)**51 + 1.39729911572017e+74*cos(theta)**49 - 1.13403986203376e+74*cos(theta)**47 + 7.71004459659432e+73*cos(theta)**45 - 4.41977078785661e+73*cos(theta)**43 + 2.14572743087878e+73*cos(theta)**41 - 8.84613621578982e+72*cos(theta)**39 + 3.1007506792338e+72*cos(theta)**37 - 9.23982081597187e+71*cos(theta)**35 + 2.33745467070717e+71*cos(theta)**33 - 5.00679945693057e+70*cos(theta)**31 + 9.04491743384893e+69*cos(theta)**29 - 1.37074896533881e+69*cos(theta)**27 + 1.73069383753209e+68*cos(theta)**25 - 1.80468596197298e+67*cos(theta)**23 + 1.53732507871773e+66*cos(theta)**21 - 1.05537190758654e+65*cos(theta)**19 + 5.74009529889626e+63*cos(theta)**17 - 2.4206293353485e+62*cos(theta)**15 + 7.69733737769814e+60*cos(theta)**13 - 1.7789401939569e+59*cos(theta)**11 + 2.84093236549447e+57*cos(theta)**9 - 2.91460715753209e+55*cos(theta)**7 + 1.71447479854829e+53*cos(theta)**5 - 4.72697766349128e+50*cos(theta)**3 + 3.85351439958529e+47*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl89_m_minus_23(theta, phi):
    return 8.86225726032474e-45*(1.0 - cos(theta)**2)**11.5*(1.12100823902909e+69*cos(theta)**66 - 1.3585099845861e+70*cos(theta)**64 + 7.82501751121592e+70*cos(theta)**62 - 2.85108056140834e+71*cos(theta)**60 + 7.37779618960931e+71*cos(theta)**58 - 1.4432540948431e+72*cos(theta)**56 + 2.21817495614608e+72*cos(theta)**54 - 2.74823234826411e+72*cos(theta)**52 + 2.79459823144034e+72*cos(theta)**50 - 2.36258304590367e+72*cos(theta)**48 + 1.67609665143355e+72*cos(theta)**46 - 1.0044933608765e+72*cos(theta)**44 + 5.10887483542566e+71*cos(theta)**42 - 2.21153405394746e+71*cos(theta)**40 + 8.15987020851001e+70*cos(theta)**38 - 2.56661689332552e+70*cos(theta)**36 + 6.8748666785505e+69*cos(theta)**34 - 1.5646248302908e+69*cos(theta)**32 + 3.01497247794964e+68*cos(theta)**30 - 4.89553201906717e+67*cos(theta)**28 + 6.65651475973882e+66*cos(theta)**26 - 7.5195248415541e+65*cos(theta)**24 + 6.98784126689876e+64*cos(theta)**22 - 5.2768595379327e+63*cos(theta)**20 + 3.18894183272014e+62*cos(theta)**18 - 1.51289333459281e+61*cos(theta)**16 + 5.49809812692724e+59*cos(theta)**14 - 1.48245016163075e+58*cos(theta)**12 + 2.84093236549447e+56*cos(theta)**10 - 3.64325894691511e+54*cos(theta)**8 + 2.85745799758048e+52*cos(theta)**6 - 1.18174441587282e+50*cos(theta)**4 + 1.92675719979264e+47*cos(theta)**2 - 5.16695414264586e+43)*sin(23*phi)

#@torch.jit.script
def Yl89_m_minus_22(theta, phi):
    return 7.67698630014625e-43*(1.0 - cos(theta)**2)**11*(1.67314662541655e+67*cos(theta)**67 - 2.09001536090169e+68*cos(theta)**65 + 1.24206627162157e+69*cos(theta)**63 - 4.67390255968581e+69*cos(theta)**61 + 1.25047393044226e+70*cos(theta)**59 - 2.53202472779491e+70*cos(theta)**57 + 4.03304537481106e+70*cos(theta)**55 - 5.1853440533285e+70*cos(theta)**53 + 5.47960437537322e+70*cos(theta)**51 - 4.82159805286463e+70*cos(theta)**49 + 3.56616308815648e+70*cos(theta)**47 - 2.23220746861445e+70*cos(theta)**45 + 1.18811042684318e+70*cos(theta)**43 - 5.39398549743282e+69*cos(theta)**41 + 2.09227441243846e+69*cos(theta)**39 - 6.9368024143933e+68*cos(theta)**37 + 1.964247622443e+68*cos(theta)**35 - 4.74128736451759e+67*cos(theta)**33 + 9.7257176708053e+66*cos(theta)**31 - 1.68811448933351e+66*cos(theta)**29 + 2.4653758369403e+65*cos(theta)**27 - 3.00780993662164e+64*cos(theta)**25 + 3.03819185517337e+63*cos(theta)**23 - 2.51279025615843e+62*cos(theta)**21 + 1.67839043827376e+61*cos(theta)**19 - 8.89937255642831e+59*cos(theta)**17 + 3.66539875128483e+58*cos(theta)**15 - 1.1403462781775e+57*cos(theta)**13 + 2.58266578681316e+55*cos(theta)**11 - 4.04806549657235e+53*cos(theta)**9 + 4.0820828536864e+51*cos(theta)**7 - 2.36348883174564e+49*cos(theta)**5 + 6.42252399930881e+46*cos(theta)**3 - 5.16695414264586e+43*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl89_m_minus_21(theta, phi):
    return 6.66970631729821e-41*(1.0 - cos(theta)**2)**10.5*(2.46050974325963e+65*cos(theta)**68 - 3.16668994076013e+66*cos(theta)**66 + 1.94072854940871e+67*cos(theta)**64 - 7.53855251562227e+67*cos(theta)**62 + 2.08412321740376e+68*cos(theta)**60 - 4.36555987550847e+68*cos(theta)**58 + 7.20186674073403e+68*cos(theta)**56 - 9.60248898764537e+68*cos(theta)**54 + 1.05377007218716e+69*cos(theta)**52 - 9.64319610572927e+68*cos(theta)**50 + 7.42950643365934e+68*cos(theta)**48 - 4.85262493177055e+68*cos(theta)**46 + 2.70025097009813e+68*cos(theta)**44 - 1.28428226129353e+68*cos(theta)**42 + 5.23068603109616e+67*cos(theta)**40 - 1.82547431957718e+67*cos(theta)**38 + 5.456243395675e+66*cos(theta)**36 - 1.39449628368164e+66*cos(theta)**34 + 3.03928677212666e+65*cos(theta)**32 - 5.62704829777836e+64*cos(theta)**30 + 8.80491370335822e+63*cos(theta)**28 - 1.15684997562371e+63*cos(theta)**26 + 1.26591327298891e+62*cos(theta)**24 - 1.14217738916292e+61*cos(theta)**22 + 8.3919521913688e+59*cos(theta)**20 - 4.9440958646824e+58*cos(theta)**18 + 2.29087421955302e+57*cos(theta)**16 - 8.14533055841073e+55*cos(theta)**14 + 2.15222148901097e+54*cos(theta)**12 - 4.04806549657235e+52*cos(theta)**10 + 5.102603567108e+50*cos(theta)**8 - 3.9391480529094e+48*cos(theta)**6 + 1.6056309998272e+46*cos(theta)**4 - 2.58347707132293e+43*cos(theta)**2 + 6.84546123826956e+39)*sin(21*phi)

#@torch.jit.script
def Yl89_m_minus_20(theta, phi):
    return 5.81068856595213e-39*(1.0 - cos(theta)**2)**10*(3.56595614965164e+63*cos(theta)**69 - 4.72640289665692e+64*cos(theta)**67 + 2.98573622985956e+65*cos(theta)**65 - 1.19659563740036e+66*cos(theta)**63 + 3.41659543836682e+66*cos(theta)**61 - 7.39925402628554e+66*cos(theta)**59 + 1.26348539311123e+67*cos(theta)**57 - 1.7459070886628e+67*cos(theta)**55 + 1.98824541922105e+67*cos(theta)**53 - 1.89082276582927e+67*cos(theta)**51 + 1.51622580278762e+67*cos(theta)**49 - 1.03247338973841e+67*cos(theta)**47 + 6.00055771132917e+66*cos(theta)**45 - 2.98670293324076e+66*cos(theta)**43 + 1.27577708075516e+66*cos(theta)**41 - 4.68070338353124e+65*cos(theta)**39 + 1.47466037720946e+65*cos(theta)**37 - 3.98427509623327e+64*cos(theta)**35 + 9.20995991553533e+63*cos(theta)**33 - 1.81517687025108e+63*cos(theta)**31 + 3.03617713908904e+62*cos(theta)**29 - 4.28462953934707e+61*cos(theta)**27 + 5.06365309195562e+60*cos(theta)**25 - 4.96598864853445e+59*cos(theta)**23 + 3.99616771017562e+58*cos(theta)**21 - 2.60215571825389e+57*cos(theta)**19 + 1.3475730703253e+56*cos(theta)**17 - 5.43022037227382e+54*cos(theta)**15 + 1.6555549915469e+53*cos(theta)**13 - 3.6800595423385e+51*cos(theta)**11 + 5.66955951900889e+49*cos(theta)**9 - 5.62735436129915e+47*cos(theta)**7 + 3.2112619996544e+45*cos(theta)**5 - 8.61159023774311e+42*cos(theta)**3 + 6.84546123826956e+39*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl89_m_minus_19(theta, phi):
    return 5.07562897863914e-37*(1.0 - cos(theta)**2)**9.5*(5.09422307093091e+61*cos(theta)**70 - 6.9505924950837e+62*cos(theta)**68 + 4.52384277251448e+63*cos(theta)**66 - 1.86968068343806e+64*cos(theta)**64 + 5.51063780381745e+64*cos(theta)**62 - 1.23320900438092e+65*cos(theta)**60 + 2.17842309157109e+65*cos(theta)**58 - 3.11769122975499e+65*cos(theta)**56 + 3.68193596152047e+65*cos(theta)**54 - 3.63619762659475e+65*cos(theta)**52 + 3.03245160557524e+65*cos(theta)**50 - 2.1509862286217e+65*cos(theta)**48 + 1.30446906768025e+65*cos(theta)**46 - 6.78796121191083e+64*cos(theta)**44 + 3.03756447798848e+64*cos(theta)**42 - 1.17017584588281e+64*cos(theta)**40 + 3.88068520318279e+63*cos(theta)**38 - 1.10674308228702e+63*cos(theta)**36 + 2.70881173986333e+62*cos(theta)**34 - 5.67242771953463e+61*cos(theta)**32 + 1.01205904636301e+61*cos(theta)**30 - 1.5302248354811e+60*cos(theta)**28 + 1.94755888152139e+59*cos(theta)**26 - 2.06916193688935e+58*cos(theta)**24 + 1.81643986826165e+57*cos(theta)**22 - 1.30107785912695e+56*cos(theta)**20 + 7.4865170573628e+54*cos(theta)**18 - 3.39388773267114e+53*cos(theta)**16 + 1.18253927967635e+52*cos(theta)**14 - 3.06671628528208e+50*cos(theta)**12 + 5.66955951900889e+48*cos(theta)**10 - 7.03419295162393e+46*cos(theta)**8 + 5.35210333275734e+44*cos(theta)**6 - 2.15289755943578e+42*cos(theta)**4 + 3.42273061913478e+39*cos(theta)**2 - 8.97177095448173e+35)*sin(19*phi)

#@torch.jit.script
def Yl89_m_minus_18(theta, phi):
    return 4.44458197209647e-35*(1.0 - cos(theta)**2)**9*(7.17496207173368e+59*cos(theta)**71 - 1.0073322456643e+61*cos(theta)**69 + 6.75200413808131e+61*cos(theta)**67 - 2.87643182067395e+62*cos(theta)**65 + 8.74704413304358e+62*cos(theta)**63 - 2.0216541055425e+63*cos(theta)**61 + 3.6922425280866e+63*cos(theta)**59 - 5.46963373641227e+63*cos(theta)**57 + 6.6944290209463e+63*cos(theta)**55 - 6.86075023885801e+63*cos(theta)**53 + 5.94598354034361e+63*cos(theta)**51 - 4.38976781351367e+63*cos(theta)**49 + 2.77546610144735e+63*cos(theta)**47 - 1.50843582486907e+63*cos(theta)**45 + 7.06410343718251e+62*cos(theta)**43 - 2.85408742898246e+62*cos(theta)**41 + 9.95047487995587e+61*cos(theta)**39 - 2.99119751969464e+61*cos(theta)**37 + 7.73946211389523e+60*cos(theta)**35 - 1.71891749076807e+60*cos(theta)**33 + 3.26470660117101e+59*cos(theta)**31 - 5.27663736372791e+58*cos(theta)**29 + 7.21318104267183e+57*cos(theta)**27 - 8.27664774755741e+56*cos(theta)**25 + 7.89756464461585e+55*cos(theta)**23 - 6.19560885298546e+54*cos(theta)**21 + 3.94027213545411e+53*cos(theta)**19 - 1.99640454863008e+52*cos(theta)**17 + 7.88359519784236e+50*cos(theta)**15 - 2.35901252714006e+49*cos(theta)**13 + 5.15414501728081e+47*cos(theta)**11 - 7.81576994624882e+45*cos(theta)**9 + 7.64586190393906e+43*cos(theta)**7 - 4.30579511887155e+41*cos(theta)**5 + 1.14091020637826e+39*cos(theta)**3 - 8.97177095448173e+35*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl89_m_minus_17(theta, phi):
    return 3.90111773492035e-33*(1.0 - cos(theta)**2)**8.5*(9.96522509963011e+57*cos(theta)**72 - 1.43904606523472e+59*cos(theta)**70 + 9.92941785011957e+59*cos(theta)**68 - 4.35823003132416e+60*cos(theta)**66 + 1.36672564578806e+61*cos(theta)**64 - 3.26073242829435e+61*cos(theta)**62 + 6.153737546811e+61*cos(theta)**60 - 9.43040299381425e+61*cos(theta)**58 + 1.19543375374041e+62*cos(theta)**56 - 1.27050930349222e+62*cos(theta)**54 + 1.143458373143e+62*cos(theta)**52 - 8.77953562702733e+61*cos(theta)**50 + 5.78222104468198e+61*cos(theta)**48 - 3.27920831493277e+61*cos(theta)**46 + 1.60547805390512e+61*cos(theta)**44 - 6.79544625948205e+60*cos(theta)**42 + 2.48761871998897e+60*cos(theta)**40 - 7.87157242024906e+59*cos(theta)**38 + 2.14985058719312e+59*cos(theta)**36 - 5.05563967872962e+58*cos(theta)**34 + 1.02022081286594e+58*cos(theta)**32 - 1.75887912124264e+57*cos(theta)**30 + 2.57613608666851e+56*cos(theta)**28 - 3.18332605675285e+55*cos(theta)**26 + 3.2906519352566e+54*cos(theta)**24 - 2.81618584226612e+53*cos(theta)**22 + 1.97013606772705e+52*cos(theta)**20 - 1.10911363812782e+51*cos(theta)**18 + 4.92724699865148e+49*cos(theta)**16 - 1.68500894795719e+48*cos(theta)**14 + 4.29512084773401e+46*cos(theta)**12 - 7.81576994624882e+44*cos(theta)**10 + 9.55732737992382e+42*cos(theta)**8 - 7.17632519811926e+40*cos(theta)**6 + 2.85227551594565e+38*cos(theta)**4 - 4.48588547724087e+35*cos(theta)**2 + 1.16456009274166e+32)*sin(17*phi)

#@torch.jit.script
def Yl89_m_minus_16(theta, phi):
    return 3.43165342252496e-31*(1.0 - cos(theta)**2)**8*(1.36509932871645e+56*cos(theta)**73 - 2.02682544399256e+57*cos(theta)**71 + 1.43904606523472e+58*cos(theta)**69 - 6.50482094227486e+58*cos(theta)**67 + 2.10265483967394e+59*cos(theta)**65 - 5.17576575919738e+59*cos(theta)**63 + 1.00880943390344e+60*cos(theta)**61 - 1.59837338878208e+60*cos(theta)**59 + 2.09725219954458e+60*cos(theta)**57 - 2.31001691544041e+60*cos(theta)**55 + 2.1574686285717e+60*cos(theta)**53 - 1.72147757392693e+60*cos(theta)**51 + 1.18004511115959e+60*cos(theta)**49 - 6.97703896794206e+59*cos(theta)**47 + 3.56772900867803e+59*cos(theta)**45 - 1.58033633941443e+59*cos(theta)**43 + 6.06736273168041e+58*cos(theta)**41 - 2.01835190262796e+58*cos(theta)**39 + 5.81040699241384e+57*cos(theta)**37 - 1.44446847963703e+57*cos(theta)**35 + 3.09157822080588e+56*cos(theta)**33 - 5.67380361691174e+55*cos(theta)**31 + 8.88322788506383e+54*cos(theta)**29 - 1.1790096506492e+54*cos(theta)**27 + 1.31626077410264e+53*cos(theta)**25 - 1.22442862707222e+52*cos(theta)**23 + 9.38160032250978e+50*cos(theta)**21 - 5.83744020067275e+49*cos(theta)**19 + 2.89838058744205e+48*cos(theta)**17 - 1.12333929863813e+47*cos(theta)**15 + 3.30393911364154e+45*cos(theta)**13 - 7.10524540568074e+43*cos(theta)**11 + 1.06192526443598e+42*cos(theta)**9 - 1.02518931401704e+40*cos(theta)**7 + 5.7045510318913e+37*cos(theta)**5 - 1.49529515908029e+35*cos(theta)**3 + 1.16456009274166e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl89_m_minus_15(theta, phi):
    return 3.02492025183777e-29*(1.0 - cos(theta)**2)**7.5*(1.8447288225898e+54*cos(theta)**74 - 2.81503533887856e+55*cos(theta)**72 + 2.05578009319246e+56*cos(theta)**70 - 9.56591315040421e+56*cos(theta)**68 + 3.18584066617263e+57*cos(theta)**66 - 8.08713399874591e+57*cos(theta)**64 + 1.62711199016684e+58*cos(theta)**62 - 2.66395564797013e+58*cos(theta)**60 + 3.61595206818031e+58*cos(theta)**58 - 4.12503020614358e+58*cos(theta)**56 + 3.99531227513278e+58*cos(theta)**54 - 3.31053379601332e+58*cos(theta)**52 + 2.36009022231918e+58*cos(theta)**50 - 1.45354978498793e+58*cos(theta)**48 + 7.75593262756094e+57*cos(theta)**46 - 3.59167349866916e+57*cos(theta)**44 + 1.44461017420962e+57*cos(theta)**42 - 5.04587975656991e+56*cos(theta)**40 + 1.52905447168785e+56*cos(theta)**38 - 4.01241244343621e+55*cos(theta)**36 + 9.0928771200173e+54*cos(theta)**34 - 1.77306363028492e+54*cos(theta)**32 + 2.96107596168794e+53*cos(theta)**30 - 4.21074875231858e+52*cos(theta)**28 + 5.06254143885631e+51*cos(theta)**26 - 5.10178594613427e+50*cos(theta)**24 + 4.26436378295899e+49*cos(theta)**22 - 2.91872010033638e+48*cos(theta)**20 + 1.6102114374678e+47*cos(theta)**18 - 7.02087061648828e+45*cos(theta)**16 + 2.35995650974396e+44*cos(theta)**14 - 5.92103783806728e+42*cos(theta)**12 + 1.06192526443598e+41*cos(theta)**10 - 1.2814866425213e+39*cos(theta)**8 + 9.50758505315217e+36*cos(theta)**6 - 3.73823789770072e+34*cos(theta)**4 + 5.82280046370829e+31*cos(theta)**2 - 1.49879033814885e+28)*sin(15*phi)

#@torch.jit.script
def Yl89_m_minus_14(theta, phi):
    return 2.67153723039434e-27*(1.0 - cos(theta)**2)**7*(2.45963843011974e+52*cos(theta)**75 - 3.85621279298433e+53*cos(theta)**73 + 2.89546491998938e+54*cos(theta)**71 - 1.38636422469626e+55*cos(theta)**69 + 4.75498606891437e+55*cos(theta)**67 - 1.24417446134552e+56*cos(theta)**65 + 2.58271744470927e+56*cos(theta)**63 - 4.36714040650841e+56*cos(theta)**61 + 6.12873231894968e+56*cos(theta)**59 - 7.23689509849752e+56*cos(theta)**57 + 7.26420413660506e+56*cos(theta)**55 - 6.24629018115721e+56*cos(theta)**53 + 4.62762788690034e+56*cos(theta)**51 - 2.96642813262843e+56*cos(theta)**49 + 1.65019843139595e+56*cos(theta)**47 - 7.98149666370925e+55*cos(theta)**45 + 3.35955854467354e+55*cos(theta)**43 - 1.2307023796512e+55*cos(theta)**41 + 3.92065249150731e+54*cos(theta)**39 - 1.0844357955233e+54*cos(theta)**37 + 2.59796489143352e+53*cos(theta)**35 - 5.37292009177248e+52*cos(theta)**33 + 9.55185794092885e+51*cos(theta)**31 - 1.45198232838572e+51*cos(theta)**29 + 1.87501534772456e+50*cos(theta)**27 - 2.04071437845371e+49*cos(theta)**25 + 1.85407120998217e+48*cos(theta)**23 - 1.38986671444589e+47*cos(theta)**21 + 8.47479703930423e+45*cos(theta)**19 - 4.12992389205193e+44*cos(theta)**17 + 1.57330433982931e+43*cos(theta)**15 - 4.55464449082099e+41*cos(theta)**13 + 9.65386604032709e+39*cos(theta)**11 - 1.42387404724588e+38*cos(theta)**9 + 1.3582264361646e+36*cos(theta)**7 - 7.47647579540144e+33*cos(theta)**5 + 1.94093348790276e+31*cos(theta)**3 - 1.49879033814885e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl89_m_minus_13(theta, phi):
    return 2.36366889105142e-25*(1.0 - cos(theta)**2)**6.5*(3.2363663554207e+50*cos(theta)**76 - 5.21109836889774e+51*cos(theta)**74 + 4.0214790555408e+52*cos(theta)**72 - 1.98052032099466e+53*cos(theta)**70 + 6.9926265719329e+53*cos(theta)**68 - 1.88511282022049e+54*cos(theta)**66 + 4.03549600735824e+54*cos(theta)**64 - 7.04377484920711e+54*cos(theta)**62 + 1.02145538649161e+55*cos(theta)**60 - 1.24774053422371e+55*cos(theta)**58 + 1.29717931010805e+55*cos(theta)**56 - 1.156720403918e+55*cos(theta)**54 + 8.89928439788528e+54*cos(theta)**52 - 5.93285626525685e+54*cos(theta)**50 + 3.43791339874155e+54*cos(theta)**48 - 1.73510797037158e+54*cos(theta)**46 + 7.63536032880349e+53*cos(theta)**44 - 2.93024376107428e+53*cos(theta)**42 + 9.80163122876828e+52*cos(theta)**40 - 2.85377840927184e+52*cos(theta)**38 + 7.21656914287088e+51*cos(theta)**36 - 1.5802706152272e+51*cos(theta)**34 + 2.98495560654027e+50*cos(theta)**32 - 4.83994109461906e+49*cos(theta)**30 + 6.69648338473057e+48*cos(theta)**28 - 7.84890145559118e+47*cos(theta)**26 + 7.72529670825904e+46*cos(theta)**24 - 6.31757597475406e+45*cos(theta)**22 + 4.23739851965211e+44*cos(theta)**20 - 2.29440216225107e+43*cos(theta)**18 + 9.83315212393317e+41*cos(theta)**16 - 3.25331749344356e+40*cos(theta)**14 + 8.04488836693925e+38*cos(theta)**12 - 1.42387404724588e+37*cos(theta)**10 + 1.69778304520574e+35*cos(theta)**8 - 1.24607929923357e+33*cos(theta)**6 + 4.85233371975691e+30*cos(theta)**4 - 7.49395169074426e+27*cos(theta)**2 + 1.9146529613552e+24)*sin(13*phi)

#@torch.jit.script
def Yl89_m_minus_12(theta, phi):
    return 2.09474946331826e-23*(1.0 - cos(theta)**2)**6*(4.20307318885806e+48*cos(theta)**77 - 6.94813115853033e+49*cos(theta)**75 + 5.50887541854904e+50*cos(theta)**73 - 2.78946524083755e+51*cos(theta)**71 + 1.01342414085984e+52*cos(theta)**69 - 2.81360122420969e+52*cos(theta)**67 + 6.20845539593575e+52*cos(theta)**65 - 1.11805949987414e+53*cos(theta)**63 + 1.67451702703543e+53*cos(theta)**61 - 2.11481446478595e+53*cos(theta)**59 + 2.27575317562815e+53*cos(theta)**57 - 2.10312800712364e+53*cos(theta)**55 + 1.67911026375194e+53*cos(theta)**53 - 1.16330515005036e+53*cos(theta)**51 + 7.01614979335011e+52*cos(theta)**49 - 3.69171908589697e+52*cos(theta)**47 + 1.69674673973411e+52*cos(theta)**45 - 6.81452037459135e+51*cos(theta)**43 + 2.39064176311421e+51*cos(theta)**41 - 7.31738053659446e+50*cos(theta)**39 + 1.9504240926678e+50*cos(theta)**37 - 4.51505890064914e+49*cos(theta)**35 + 9.04532001981898e+48*cos(theta)**33 - 1.56127132084486e+48*cos(theta)**31 + 2.30913220163123e+47*cos(theta)**29 - 2.90700053910785e+46*cos(theta)**27 + 3.09011868330362e+45*cos(theta)**25 - 2.74677216293655e+44*cos(theta)**23 + 2.01780881888196e+43*cos(theta)**21 - 1.2075800853953e+42*cos(theta)**19 + 5.78420713172539e+40*cos(theta)**17 - 2.16887832896238e+39*cos(theta)**15 + 6.18837566687634e+37*cos(theta)**13 - 1.29443095204171e+36*cos(theta)**11 + 1.88642560578416e+34*cos(theta)**9 - 1.78011328461939e+32*cos(theta)**7 + 9.70466743951381e+29*cos(theta)**5 - 2.49798389691475e+27*cos(theta)**3 + 1.9146529613552e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl89_m_minus_11(theta, phi):
    return 1.85925978615847e-21*(1.0 - cos(theta)**2)**5.5*(5.38855537033084e+46*cos(theta)**78 - 9.14227784017148e+47*cos(theta)**76 + 7.44442624128249e+48*cos(theta)**74 - 3.87425727894104e+49*cos(theta)**72 + 1.44774877265692e+50*cos(theta)**70 - 4.1376488591319e+50*cos(theta)**68 + 9.40675059990265e+50*cos(theta)**66 - 1.74696796855335e+51*cos(theta)**64 + 2.70083391457328e+51*cos(theta)**62 - 3.52469077464325e+51*cos(theta)**60 + 3.92371237177267e+51*cos(theta)**58 - 3.7555857270065e+51*cos(theta)**56 + 3.10946345139248e+51*cos(theta)**54 - 2.23712528855839e+51*cos(theta)**52 + 1.40322995867002e+51*cos(theta)**50 - 7.69108142895202e+50*cos(theta)**48 + 3.68857986898719e+50*cos(theta)**46 - 1.54875463058894e+50*cos(theta)**44 + 5.69200419789099e+49*cos(theta)**42 - 1.82934513414862e+49*cos(theta)**40 + 5.13269498070475e+48*cos(theta)**38 - 1.25418302795809e+48*cos(theta)**36 + 2.66038824112323e+47*cos(theta)**34 - 4.87897287764018e+46*cos(theta)**32 + 7.69710733877078e+45*cos(theta)**30 - 1.0382144782528e+45*cos(theta)**28 + 1.18850718588601e+44*cos(theta)**26 - 1.14448840122356e+43*cos(theta)**24 + 9.17185826764527e+41*cos(theta)**22 - 6.03790042697651e+40*cos(theta)**20 + 3.21344840651411e+39*cos(theta)**18 - 1.35554895560148e+38*cos(theta)**16 + 4.4202683334831e+36*cos(theta)**14 - 1.07869246003476e+35*cos(theta)**12 + 1.88642560578416e+33*cos(theta)**10 - 2.22514160577424e+31*cos(theta)**8 + 1.6174445732523e+29*cos(theta)**6 - 6.24495974228688e+26*cos(theta)**4 + 9.57326480677601e+23*cos(theta)**2 - 2.43037948889972e+20)*sin(11*phi)

#@torch.jit.script
def Yl89_m_minus_10(theta, phi):
    return 1.65254624516731e-19*(1.0 - cos(theta)**2)**5*(6.82095616497575e+44*cos(theta)**79 - 1.18730881041188e+46*cos(theta)**77 + 9.92590165504332e+46*cos(theta)**75 - 5.30720175197403e+47*cos(theta)**73 + 2.03908277839002e+48*cos(theta)**71 - 5.99659254946652e+48*cos(theta)**69 + 1.40399262685114e+49*cos(theta)**67 - 2.68764302854362e+49*cos(theta)**65 + 4.28703795964012e+49*cos(theta)**63 - 5.77818159777582e+49*cos(theta)**61 + 6.65035995215707e+49*cos(theta)**59 - 6.58874688948509e+49*cos(theta)**57 + 5.65356991162269e+49*cos(theta)**55 - 4.22099111048753e+49*cos(theta)**53 + 2.75143129150985e+49*cos(theta)**51 - 1.56960845488817e+49*cos(theta)**49 + 7.84804227444084e+48*cos(theta)**47 - 3.44167695686432e+48*cos(theta)**45 + 1.32372190648628e+48*cos(theta)**43 - 4.46181740036248e+47*cos(theta)**41 + 1.31607563607814e+47*cos(theta)**39 - 3.3896838593462e+46*cos(theta)**37 + 7.60110926035209e+45*cos(theta)**35 - 1.47847662958793e+45*cos(theta)**33 + 2.48293785121638e+44*cos(theta)**31 - 3.58004992500966e+43*cos(theta)**29 + 4.40187846624447e+42*cos(theta)**27 - 4.57795360489425e+41*cos(theta)**25 + 3.98776446419359e+40*cos(theta)**23 - 2.87519067951262e+39*cos(theta)**21 + 1.69128863500743e+38*cos(theta)**19 - 7.97381738589109e+36*cos(theta)**17 + 2.9468455556554e+35*cos(theta)**15 - 8.2976343079597e+33*cos(theta)**13 + 1.71493236889469e+32*cos(theta)**11 - 2.47237956197138e+30*cos(theta)**9 + 2.31063510464615e+28*cos(theta)**7 - 1.24899194845738e+26*cos(theta)**5 + 3.19108826892534e+23*cos(theta)**3 - 2.43037948889972e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl89_m_minus_9(theta, phi):
    return 1.47067331559185e-17*(1.0 - cos(theta)**2)**4.5*(8.52619520621969e+42*cos(theta)**80 - 1.52219078257933e+44*cos(theta)**78 + 1.30603969145307e+45*cos(theta)**76 - 7.17189425942437e+45*cos(theta)**74 + 2.83205941443059e+46*cos(theta)**72 - 8.56656078495217e+46*cos(theta)**70 + 2.06469503948697e+47*cos(theta)**68 - 4.07218640688427e+47*cos(theta)**66 + 6.69849681193769e+47*cos(theta)**64 - 9.31964773834809e+47*cos(theta)**62 + 1.10839332535951e+48*cos(theta)**60 - 1.13599084301467e+48*cos(theta)**58 + 1.00956605564691e+48*cos(theta)**56 - 7.81665020460654e+47*cos(theta)**54 + 5.29121402213432e+47*cos(theta)**52 - 3.13921690977633e+47*cos(theta)**50 + 1.63500880717517e+47*cos(theta)**48 - 7.48190642796591e+46*cos(theta)**46 + 3.0084588783779e+46*cos(theta)**44 - 1.06233747627678e+46*cos(theta)**42 + 3.29018909019535e+45*cos(theta)**40 - 8.92022068249e+44*cos(theta)**38 + 2.11141923898669e+44*cos(theta)**36 - 4.34846067525863e+43*cos(theta)**34 + 7.75918078505118e+42*cos(theta)**32 - 1.19334997500322e+42*cos(theta)**30 + 1.57209945223017e+41*cos(theta)**28 - 1.76075138649779e+40*cos(theta)**26 + 1.66156852674733e+39*cos(theta)**24 - 1.30690485432392e+38*cos(theta)**22 + 8.45644317503712e+36*cos(theta)**20 - 4.42989854771727e+35*cos(theta)**18 + 1.84177847228463e+34*cos(theta)**16 - 5.92688164854264e+32*cos(theta)**14 + 1.42911030741224e+31*cos(theta)**12 - 2.47237956197138e+29*cos(theta)**10 + 2.88829388080768e+27*cos(theta)**8 - 2.08165324742896e+25*cos(theta)**6 + 7.97772067231334e+22*cos(theta)**4 - 1.21518974444986e+20*cos(theta)**2 + 3.06866097083298e+16)*sin(9*phi)

#@torch.jit.script
def Yl89_m_minus_8(theta, phi):
    return 1.31030307370003e-15*(1.0 - cos(theta)**2)**4*(1.05261669212589e+41*cos(theta)**81 - 1.92682377541688e+42*cos(theta)**79 + 1.69615544344554e+43*cos(theta)**77 - 9.56252567923249e+43*cos(theta)**75 + 3.87953344442546e+44*cos(theta)**73 - 1.20655785703552e+45*cos(theta)**71 + 2.9923116514304e+45*cos(theta)**69 - 6.07789015952875e+45*cos(theta)**67 + 1.03053797106734e+46*cos(theta)**65 - 1.47930916481716e+46*cos(theta)**63 + 1.81703823829428e+46*cos(theta)**61 - 1.92540820849944e+46*cos(theta)**59 + 1.77116851867879e+46*cos(theta)**57 - 1.42120912811028e+46*cos(theta)**55 + 9.9834226832723e+45*cos(theta)**53 - 6.15532727407124e+45*cos(theta)**51 + 3.33675266770444e+45*cos(theta)**49 - 1.5918949846736e+45*cos(theta)**47 + 6.68546417417311e+44*cos(theta)**45 - 2.47055227041112e+44*cos(theta)**43 + 8.02485143950086e+43*cos(theta)**41 - 2.28723607243333e+43*cos(theta)**39 + 5.70653848374781e+42*cos(theta)**37 - 1.24241733578818e+42*cos(theta)**35 + 2.35126690456097e+41*cos(theta)**33 - 3.84951604839749e+40*cos(theta)**31 + 5.42103259389713e+39*cos(theta)**29 - 6.52130143147329e+38*cos(theta)**27 + 6.64627410698932e+37*cos(theta)**25 - 5.68219501879965e+36*cos(theta)**23 + 4.02687770239863e+35*cos(theta)**21 - 2.33152555143014e+34*cos(theta)**19 + 1.0833991013439e+33*cos(theta)**17 - 3.95125443236176e+31*cos(theta)**15 + 1.09931562108634e+30*cos(theta)**13 - 2.24761778361034e+28*cos(theta)**11 + 3.20921542311965e+26*cos(theta)**9 - 2.97379035346994e+24*cos(theta)**7 + 1.59554413446267e+22*cos(theta)**5 - 4.05063248149954e+19*cos(theta)**3 + 3.06866097083298e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl89_m_minus_7(theta, phi):
    return 1.168596424302e-13*(1.0 - cos(theta)**2)**3.5*(1.28367889283645e+39*cos(theta)**82 - 2.4085297192711e+40*cos(theta)**80 + 2.17455826082762e+41*cos(theta)**78 - 1.25822706305691e+42*cos(theta)**76 + 5.24261276273711e+42*cos(theta)**74 - 1.67577480143822e+43*cos(theta)**72 + 4.27473093061485e+43*cos(theta)**70 - 8.93807376401287e+43*cos(theta)**68 + 1.56142116828384e+44*cos(theta)**66 - 2.31142057002681e+44*cos(theta)**64 + 2.93070683595852e+44*cos(theta)**62 - 3.2090136808324e+44*cos(theta)**60 + 3.05373882530825e+44*cos(theta)**58 - 2.53787344305407e+44*cos(theta)**56 + 1.84878197838376e+44*cos(theta)**54 - 1.18371678347524e+44*cos(theta)**52 + 6.67350533540887e+43*cos(theta)**50 - 3.31644788473666e+43*cos(theta)**48 + 1.45336177699415e+43*cos(theta)**46 - 5.61489152366163e+42*cos(theta)**44 + 1.91067891416687e+42*cos(theta)**42 - 5.71809018108334e+41*cos(theta)**40 + 1.50172065361785e+41*cos(theta)**38 - 3.45115926607828e+40*cos(theta)**36 + 6.91549089576754e+39*cos(theta)**34 - 1.20297376512421e+39*cos(theta)**32 + 1.80701086463238e+38*cos(theta)**30 - 2.32903622552617e+37*cos(theta)**28 + 2.55625927191897e+36*cos(theta)**26 - 2.36758125783319e+35*cos(theta)**24 + 1.83039895563574e+34*cos(theta)**22 - 1.16576277571507e+33*cos(theta)**20 + 6.01888389635499e+31*cos(theta)**18 - 2.4695340202261e+30*cos(theta)**16 + 7.852254436331e+28*cos(theta)**14 - 1.87301481967529e+27*cos(theta)**12 + 3.20921542311965e+25*cos(theta)**10 - 3.71723794183743e+23*cos(theta)**8 + 2.65924022410445e+21*cos(theta)**6 - 1.01265812037488e+19*cos(theta)**4 + 1.53433048541649e+16*cos(theta)**2 - 3858009769717.1)*sin(7*phi)

#@torch.jit.script
def Yl89_m_minus_6(theta, phi):
    return 1.04313187372637e-11*(1.0 - cos(theta)**2)**3*(1.54660107570656e+37*cos(theta)**83 - 2.9734934805816e+38*cos(theta)**81 + 2.75260539345268e+39*cos(theta)**79 - 1.63406112085313e+40*cos(theta)**77 + 6.99015035031615e+40*cos(theta)**75 - 2.29558191977838e+41*cos(theta)**73 + 6.02074778959838e+41*cos(theta)**71 - 1.29537300927723e+42*cos(theta)**69 + 2.33047935564753e+42*cos(theta)**67 - 3.55603164619509e+42*cos(theta)**65 + 4.65191561263257e+42*cos(theta)**63 - 5.26067816529902e+42*cos(theta)**61 + 5.17582851747162e+42*cos(theta)**59 - 4.45240954921767e+42*cos(theta)**57 + 3.36142177887956e+42*cos(theta)**55 - 2.23342789334951e+42*cos(theta)**53 + 1.30853045792331e+42*cos(theta)**51 - 6.76826098925849e+41*cos(theta)**49 + 3.09225909998756e+41*cos(theta)**47 - 1.24775367192481e+41*cos(theta)**45 + 4.44343933527179e+40*cos(theta)**43 - 1.39465614172764e+40*cos(theta)**41 + 3.8505657785073e+39*cos(theta)**39 - 9.32745747588724e+38*cos(theta)**37 + 1.97585454164787e+38*cos(theta)**35 - 3.64537504583095e+37*cos(theta)**33 + 5.82906730526573e+36*cos(theta)**31 - 8.03115939836611e+35*cos(theta)**29 + 9.46762693303322e+34*cos(theta)**27 - 9.47032503133275e+33*cos(theta)**25 + 7.95825632885105e+32*cos(theta)**23 - 5.55125131292891e+31*cos(theta)**21 + 3.16783362966052e+30*cos(theta)**19 - 1.45266707072124e+29*cos(theta)**17 + 5.23483629088734e+27*cos(theta)**15 - 1.44078063051945e+26*cos(theta)**13 + 2.91746856647241e+24*cos(theta)**11 - 4.13026437981937e+22*cos(theta)**9 + 3.79891460586349e+20*cos(theta)**7 - 2.02531624074977e+18*cos(theta)**5 + 5.11443495138831e+15*cos(theta)**3 - 3858009769717.1*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl89_m_minus_5(theta, phi):
    return 9.31838524946863e-10*(1.0 - cos(theta)**2)**2.5*(1.84119175679353e+35*cos(theta)**84 - 3.62621156168488e+36*cos(theta)**82 + 3.44075674181585e+37*cos(theta)**80 - 2.0949501549399e+38*cos(theta)**78 + 9.19756625041598e+38*cos(theta)**76 - 3.10213772943024e+39*cos(theta)**74 + 8.36214970777553e+39*cos(theta)**72 - 1.85053287039604e+40*cos(theta)**70 + 3.42717552301107e+40*cos(theta)**68 - 5.38792673665923e+40*cos(theta)**66 + 7.26861814473839e+40*cos(theta)**64 - 8.48496478274036e+40*cos(theta)**62 + 8.6263808624527e+40*cos(theta)**60 - 7.67656818830632e+40*cos(theta)**58 + 6.00253889085636e+40*cos(theta)**56 - 4.13597758027687e+40*cos(theta)**54 + 2.51640472677559e+40*cos(theta)**52 - 1.3536521978517e+40*cos(theta)**50 + 6.44220645830742e+39*cos(theta)**48 - 2.71250798244523e+39*cos(theta)**46 + 1.00987257619813e+39*cos(theta)**44 - 3.32060986125629e+38*cos(theta)**42 + 9.62641444626824e+37*cos(theta)**40 - 2.45459407260191e+37*cos(theta)**38 + 5.48848483791075e+36*cos(theta)**36 - 1.07216913112675e+36*cos(theta)**34 + 1.82158353289554e+35*cos(theta)**32 - 2.6770531327887e+34*cos(theta)**30 + 3.38129533322615e+33*cos(theta)**28 - 3.64243270435875e+32*cos(theta)**26 + 3.31594013702127e+31*cos(theta)**24 - 2.52329605133132e+30*cos(theta)**22 + 1.58391681483026e+29*cos(theta)**20 - 8.07037261511798e+27*cos(theta)**18 + 3.27177268180458e+26*cos(theta)**16 - 1.02912902179961e+25*cos(theta)**14 + 2.43122380539367e+23*cos(theta)**12 - 4.13026437981937e+21*cos(theta)**10 + 4.74864325732937e+19*cos(theta)**8 - 3.37552706791628e+17*cos(theta)**6 + 1.27860873784708e+15*cos(theta)**4 - 1929004884858.55*cos(theta)**2 + 483459870.891867)*sin(5*phi)

#@torch.jit.script
def Yl89_m_minus_4(theta, phi):
    return 8.32940637874957e-8*(1.0 - cos(theta)**2)**2*(2.16610794916886e+33*cos(theta)**85 - 4.36892959239142e+34*cos(theta)**83 + 4.24784782940229e+35*cos(theta)**81 - 2.65183563916444e+36*cos(theta)**79 + 1.19448912343065e+37*cos(theta)**77 - 4.13618363924032e+37*cos(theta)**75 + 1.14549995996925e+38*cos(theta)**73 - 2.60638432450147e+38*cos(theta)**71 + 4.96692104784213e+38*cos(theta)**69 - 8.04168169650631e+38*cos(theta)**67 + 1.11824894534437e+39*cos(theta)**65 - 1.34681980678418e+39*cos(theta)**63 + 1.41416079712339e+39*cos(theta)**61 - 1.30111325225531e+39*cos(theta)**59 + 1.05307699839585e+39*cos(theta)**57 - 7.51995923686703e+38*cos(theta)**55 + 4.7479334467464e+38*cos(theta)**53 - 2.65421999578764e+38*cos(theta)**51 + 1.31473601189947e+38*cos(theta)**49 - 5.7712935796707e+37*cos(theta)**47 + 2.2441612804403e+37*cos(theta)**45 - 7.72234851454952e+36*cos(theta)**43 + 2.34790596250445e+36*cos(theta)**41 - 6.2938309553895e+35*cos(theta)**39 + 1.48337428051642e+35*cos(theta)**37 - 3.06334037464786e+34*cos(theta)**35 + 5.51995009968346e+33*cos(theta)**33 - 8.63565526706034e+32*cos(theta)**31 + 1.16596390800902e+32*cos(theta)**29 - 1.3490491497625e+31*cos(theta)**27 + 1.32637605480851e+30*cos(theta)**25 - 1.09708523970927e+29*cos(theta)**23 + 7.54246102300124e+27*cos(theta)**21 - 4.24756453427262e+26*cos(theta)**19 + 1.9245721657674e+25*cos(theta)**17 - 6.86086014533071e+23*cos(theta)**15 + 1.87017215799513e+22*cos(theta)**13 - 3.75478579983579e+20*cos(theta)**11 + 5.27627028592152e+18*cos(theta)**9 - 4.82218152559469e+16*cos(theta)**7 + 255721747569415.0*cos(theta)**5 - 643001628286.184*cos(theta)**3 + 483459870.891867*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl89_m_minus_3(theta, phi):
    return 7.44911623588723e-6*(1.0 - cos(theta)**2)**1.5*(2.51873017345216e+31*cos(theta)**86 - 5.20110665760884e+32*cos(theta)**84 + 5.1803022309784e+33*cos(theta)**82 - 3.31479454895554e+34*cos(theta)**80 + 1.53139631209057e+35*cos(theta)**78 - 5.44234689373727e+35*cos(theta)**76 + 1.54797291887737e+36*cos(theta)**74 - 3.61997822847426e+36*cos(theta)**72 + 7.09560149691733e+36*cos(theta)**70 - 1.18260024948622e+37*cos(theta)**68 + 1.6943165838551e+37*cos(theta)**66 - 2.10440594810029e+37*cos(theta)**64 + 2.28090451148934e+37*cos(theta)**62 - 2.16852208709218e+37*cos(theta)**60 + 1.81564999723423e+37*cos(theta)**58 - 1.34284986372626e+37*cos(theta)**56 + 8.79246934582667e+36*cos(theta)**54 - 5.10426922266855e+36*cos(theta)**52 + 2.62947202379895e+36*cos(theta)**50 - 1.20235282909806e+36*cos(theta)**48 + 4.87861147921804e+35*cos(theta)**46 - 1.75507920785216e+35*cos(theta)**44 + 5.59025229167726e+34*cos(theta)**42 - 1.57345773884738e+34*cos(theta)**40 + 3.90361652767479e+33*cos(theta)**38 - 8.50927881846628e+32*cos(theta)**36 + 1.62351473520102e+32*cos(theta)**34 - 2.69864227095636e+31*cos(theta)**32 + 3.88654636003006e+30*cos(theta)**30 - 4.81803267772321e+29*cos(theta)**28 + 5.10144636464811e+28*cos(theta)**26 - 4.57118849878863e+27*cos(theta)**24 + 3.42839137409147e+26*cos(theta)**22 - 2.12378226713631e+25*cos(theta)**20 + 1.06920675875967e+24*cos(theta)**18 - 4.2880375908317e+22*cos(theta)**16 + 1.33583725571081e+21*cos(theta)**14 - 3.12898816652982e+19*cos(theta)**12 + 5.27627028592152e+17*cos(theta)**10 - 6.02772690699336e+15*cos(theta)**8 + 42620291261569.2*cos(theta)**6 - 160750407071.546*cos(theta)**4 + 241729935.445934*cos(theta)**2 - 60447.5957604235)*sin(3*phi)

#@torch.jit.script
def Yl89_m_minus_2(theta, phi):
    return 0.000666435757516697*(1.0 - cos(theta)**2)*(2.89509215339329e+29*cos(theta)**87 - 6.11894900895157e+30*cos(theta)**85 + 6.24132798913061e+31*cos(theta)**83 - 4.09233894932783e+32*cos(theta)**81 + 1.93847634441845e+33*cos(theta)**79 - 7.06798297887957e+33*cos(theta)**77 + 2.06396389183649e+34*cos(theta)**75 - 4.95887428558117e+34*cos(theta)**73 + 9.99380492523568e+34*cos(theta)**71 - 1.7139134050525e+35*cos(theta)**69 + 2.5288307221718e+35*cos(theta)**67 - 3.23754761246198e+35*cos(theta)**65 + 3.62048335157039e+35*cos(theta)**63 - 3.55495424113472e+35*cos(theta)**61 + 3.07737287666819e+35*cos(theta)**59 - 2.35587695390571e+35*cos(theta)**57 + 1.5986307901503e+35*cos(theta)**55 - 9.63069664654443e+34*cos(theta)**53 + 5.155827497645e+34*cos(theta)**51 - 2.4537812838736e+34*cos(theta)**49 + 1.03800244238682e+34*cos(theta)**47 - 3.90017601744925e+33*cos(theta)**45 + 1.30005867248308e+33*cos(theta)**43 - 3.83770180206677e+32*cos(theta)**41 + 1.00092731478841e+32*cos(theta)**39 - 2.29980508607197e+31*cos(theta)**37 + 4.63861352914576e+30*cos(theta)**35 - 8.1777038513829e+29*cos(theta)**33 + 1.25372463226776e+29*cos(theta)**31 - 1.66139057852525e+28*cos(theta)**29 + 1.8894245794993e+27*cos(theta)**27 - 1.82847539951545e+26*cos(theta)**25 + 1.49060494525716e+25*cos(theta)**23 - 1.01132488911253e+24*cos(theta)**21 + 5.62740399347194e+22*cos(theta)**19 - 2.52237505343041e+21*cos(theta)**17 + 8.90558170473873e+19*cos(theta)**15 - 2.40691397425371e+18*cos(theta)**13 + 4.79660935083775e+16*cos(theta)**11 - 669747434110373.0*cos(theta)**9 + 6088613037367.03*cos(theta)**7 - 32150081414.3092*cos(theta)**5 + 80576645.1486446*cos(theta)**3 - 60447.5957604235*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl89_m_minus_1(theta, phi):
    return 0.0596376227236298*(1.0 - cos(theta)**2)**0.5*(3.28987744703783e+27*cos(theta)**88 - 7.11505698715299e+28*cos(theta)**86 + 7.43015236801263e+29*cos(theta)**84 - 4.99065725527784e+30*cos(theta)**82 + 2.42309543052306e+31*cos(theta)**80 - 9.06151663958919e+31*cos(theta)**78 + 2.71574196294275e+32*cos(theta)**76 - 6.70118146700159e+32*cos(theta)**74 + 1.38802846183829e+33*cos(theta)**72 - 2.44844772150357e+33*cos(theta)**70 + 3.71886870907617e+33*cos(theta)**68 - 4.90537517039694e+33*cos(theta)**66 + 5.65700523682873e+33*cos(theta)**64 - 5.73379716312052e+33*cos(theta)**62 + 5.12895479444698e+33*cos(theta)**60 - 4.06185681707881e+33*cos(theta)**58 + 2.85469783955411e+33*cos(theta)**56 - 1.78346234195267e+33*cos(theta)**54 + 9.91505288008653e+32*cos(theta)**52 - 4.9075625677472e+32*cos(theta)**50 + 2.16250508830587e+32*cos(theta)**48 - 8.47864351619402e+31*cos(theta)**46 + 2.95467880109792e+31*cos(theta)**44 - 9.13738524301612e+30*cos(theta)**42 + 2.50231828697102e+30*cos(theta)**40 - 6.05211864755781e+29*cos(theta)**38 + 1.28850375809604e+29*cos(theta)**36 - 2.40520701511262e+28*cos(theta)**34 + 3.91788947583675e+27*cos(theta)**32 - 5.53796859508415e+26*cos(theta)**30 + 6.74794492678321e+25*cos(theta)**28 - 7.03259769044404e+24*cos(theta)**26 + 6.2108539385715e+23*cos(theta)**24 - 4.59693131414786e+22*cos(theta)**22 + 2.81370199673597e+21*cos(theta)**20 - 1.40131947412801e+20*cos(theta)**18 + 5.5659885654617e+18*cos(theta)**16 - 1.71922426732408e+17*cos(theta)**14 + 3.99717445903146e+15*cos(theta)**12 - 66974743411037.3*cos(theta)**10 + 761076629670.879*cos(theta)**8 - 5358346902.38486*cos(theta)**6 + 20144161.2871611*cos(theta)**4 - 30223.7978802118*cos(theta)**2 + 7.54840106898396)*sin(phi)

#@torch.jit.script
def Yl89_m0(theta, phi):
    return 4.3828960410898e+26*cos(theta)**89 - 9.6968479643546e+27*cos(theta)**87 + 1.03645452099002e+29*cos(theta)**85 - 7.12936924842844e+29*cos(theta)**83 + 3.54696543163772e+30*cos(theta)**81 - 1.36001988148002e+31*cos(theta)**79 + 4.18185753976043e+31*cos(theta)**77 - 1.05940391007264e+32*cos(theta)**75 + 2.25448301414999e+32*cos(theta)**73 - 4.08887602566333e+32*cos(theta)**71 + 6.39047605268766e+32*cos(theta)**69 - 8.68098252438057e+32*cos(theta)**67 + 1.03191679362395e+33*cos(theta)**65 - 1.0791286730708e+33*cos(theta)**63 + 9.96943376777325e+32*cos(theta)**61 - 8.16289207831098e+32*cos(theta)**59 + 5.93822633758082e+32*cos(theta)**57 - 3.84479076461622e+32*cos(theta)**55 + 2.21814851804782e+32*cos(theta)**53 - 1.14095134672262e+32*cos(theta)**51 + 5.23278045709115e+31*cos(theta)**49 - 2.13894675618324e+31*cos(theta)**47 + 7.78519004523261e+30*cos(theta)**45 - 2.51956134186999e+30*cos(theta)**43 + 7.23652637311895e+29*cos(theta)**41 - 1.83998500029691e+29*cos(theta)**39 + 4.12910019751669e+28*cos(theta)**37 - 8.14809105643293e+27*cos(theta)**35 + 1.40769865812358e+27*cos(theta)**33 - 2.11816725987247e+26*cos(theta)**31 + 2.75895735529607e+25*cos(theta)**29 - 3.08832833264462e+24*cos(theta)**27 + 2.94566099119093e+23*cos(theta)**25 - 2.36979967111096e+22*cos(theta)**23 + 1.58865743717826e+21*cos(theta)**21 - 8.74490332391701e+19*cos(theta)**19 + 3.88208325127157e+18*cos(theta)**17 - 1.35897895025208e+17*cos(theta)**15 + 3.64570234482546e+15*cos(theta)**13 - 72192125640108.1*cos(theta)**11 + 1002668411668.17*cos(theta)**9 - 9076203877.30803*cos(theta)**7 + 47769494.0910949*cos(theta)**5 - 119453.598627394*cos(theta)**3 + 89.5006982722733*cos(theta)

#@torch.jit.script
def Yl89_m1(theta, phi):
    return 0.0596376227236298*(1.0 - cos(theta)**2)**0.5*(3.28987744703783e+27*cos(theta)**88 - 7.11505698715299e+28*cos(theta)**86 + 7.43015236801263e+29*cos(theta)**84 - 4.99065725527784e+30*cos(theta)**82 + 2.42309543052306e+31*cos(theta)**80 - 9.06151663958919e+31*cos(theta)**78 + 2.71574196294275e+32*cos(theta)**76 - 6.70118146700159e+32*cos(theta)**74 + 1.38802846183829e+33*cos(theta)**72 - 2.44844772150357e+33*cos(theta)**70 + 3.71886870907617e+33*cos(theta)**68 - 4.90537517039694e+33*cos(theta)**66 + 5.65700523682873e+33*cos(theta)**64 - 5.73379716312052e+33*cos(theta)**62 + 5.12895479444698e+33*cos(theta)**60 - 4.06185681707881e+33*cos(theta)**58 + 2.85469783955411e+33*cos(theta)**56 - 1.78346234195267e+33*cos(theta)**54 + 9.91505288008653e+32*cos(theta)**52 - 4.9075625677472e+32*cos(theta)**50 + 2.16250508830587e+32*cos(theta)**48 - 8.47864351619402e+31*cos(theta)**46 + 2.95467880109792e+31*cos(theta)**44 - 9.13738524301612e+30*cos(theta)**42 + 2.50231828697102e+30*cos(theta)**40 - 6.05211864755781e+29*cos(theta)**38 + 1.28850375809604e+29*cos(theta)**36 - 2.40520701511262e+28*cos(theta)**34 + 3.91788947583675e+27*cos(theta)**32 - 5.53796859508415e+26*cos(theta)**30 + 6.74794492678321e+25*cos(theta)**28 - 7.03259769044404e+24*cos(theta)**26 + 6.2108539385715e+23*cos(theta)**24 - 4.59693131414786e+22*cos(theta)**22 + 2.81370199673597e+21*cos(theta)**20 - 1.40131947412801e+20*cos(theta)**18 + 5.5659885654617e+18*cos(theta)**16 - 1.71922426732408e+17*cos(theta)**14 + 3.99717445903146e+15*cos(theta)**12 - 66974743411037.3*cos(theta)**10 + 761076629670.879*cos(theta)**8 - 5358346902.38486*cos(theta)**6 + 20144161.2871611*cos(theta)**4 - 30223.7978802118*cos(theta)**2 + 7.54840106898396)*cos(phi)

#@torch.jit.script
def Yl89_m2(theta, phi):
    return 0.000666435757516697*(1.0 - cos(theta)**2)*(2.89509215339329e+29*cos(theta)**87 - 6.11894900895157e+30*cos(theta)**85 + 6.24132798913061e+31*cos(theta)**83 - 4.09233894932783e+32*cos(theta)**81 + 1.93847634441845e+33*cos(theta)**79 - 7.06798297887957e+33*cos(theta)**77 + 2.06396389183649e+34*cos(theta)**75 - 4.95887428558117e+34*cos(theta)**73 + 9.99380492523568e+34*cos(theta)**71 - 1.7139134050525e+35*cos(theta)**69 + 2.5288307221718e+35*cos(theta)**67 - 3.23754761246198e+35*cos(theta)**65 + 3.62048335157039e+35*cos(theta)**63 - 3.55495424113472e+35*cos(theta)**61 + 3.07737287666819e+35*cos(theta)**59 - 2.35587695390571e+35*cos(theta)**57 + 1.5986307901503e+35*cos(theta)**55 - 9.63069664654443e+34*cos(theta)**53 + 5.155827497645e+34*cos(theta)**51 - 2.4537812838736e+34*cos(theta)**49 + 1.03800244238682e+34*cos(theta)**47 - 3.90017601744925e+33*cos(theta)**45 + 1.30005867248308e+33*cos(theta)**43 - 3.83770180206677e+32*cos(theta)**41 + 1.00092731478841e+32*cos(theta)**39 - 2.29980508607197e+31*cos(theta)**37 + 4.63861352914576e+30*cos(theta)**35 - 8.1777038513829e+29*cos(theta)**33 + 1.25372463226776e+29*cos(theta)**31 - 1.66139057852525e+28*cos(theta)**29 + 1.8894245794993e+27*cos(theta)**27 - 1.82847539951545e+26*cos(theta)**25 + 1.49060494525716e+25*cos(theta)**23 - 1.01132488911253e+24*cos(theta)**21 + 5.62740399347194e+22*cos(theta)**19 - 2.52237505343041e+21*cos(theta)**17 + 8.90558170473873e+19*cos(theta)**15 - 2.40691397425371e+18*cos(theta)**13 + 4.79660935083775e+16*cos(theta)**11 - 669747434110373.0*cos(theta)**9 + 6088613037367.03*cos(theta)**7 - 32150081414.3092*cos(theta)**5 + 80576645.1486446*cos(theta)**3 - 60447.5957604235*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl89_m3(theta, phi):
    return 7.44911623588723e-6*(1.0 - cos(theta)**2)**1.5*(2.51873017345216e+31*cos(theta)**86 - 5.20110665760884e+32*cos(theta)**84 + 5.1803022309784e+33*cos(theta)**82 - 3.31479454895554e+34*cos(theta)**80 + 1.53139631209057e+35*cos(theta)**78 - 5.44234689373727e+35*cos(theta)**76 + 1.54797291887737e+36*cos(theta)**74 - 3.61997822847426e+36*cos(theta)**72 + 7.09560149691733e+36*cos(theta)**70 - 1.18260024948622e+37*cos(theta)**68 + 1.6943165838551e+37*cos(theta)**66 - 2.10440594810029e+37*cos(theta)**64 + 2.28090451148934e+37*cos(theta)**62 - 2.16852208709218e+37*cos(theta)**60 + 1.81564999723423e+37*cos(theta)**58 - 1.34284986372626e+37*cos(theta)**56 + 8.79246934582667e+36*cos(theta)**54 - 5.10426922266855e+36*cos(theta)**52 + 2.62947202379895e+36*cos(theta)**50 - 1.20235282909806e+36*cos(theta)**48 + 4.87861147921804e+35*cos(theta)**46 - 1.75507920785216e+35*cos(theta)**44 + 5.59025229167726e+34*cos(theta)**42 - 1.57345773884738e+34*cos(theta)**40 + 3.90361652767479e+33*cos(theta)**38 - 8.50927881846628e+32*cos(theta)**36 + 1.62351473520102e+32*cos(theta)**34 - 2.69864227095636e+31*cos(theta)**32 + 3.88654636003006e+30*cos(theta)**30 - 4.81803267772321e+29*cos(theta)**28 + 5.10144636464811e+28*cos(theta)**26 - 4.57118849878863e+27*cos(theta)**24 + 3.42839137409147e+26*cos(theta)**22 - 2.12378226713631e+25*cos(theta)**20 + 1.06920675875967e+24*cos(theta)**18 - 4.2880375908317e+22*cos(theta)**16 + 1.33583725571081e+21*cos(theta)**14 - 3.12898816652982e+19*cos(theta)**12 + 5.27627028592152e+17*cos(theta)**10 - 6.02772690699336e+15*cos(theta)**8 + 42620291261569.2*cos(theta)**6 - 160750407071.546*cos(theta)**4 + 241729935.445934*cos(theta)**2 - 60447.5957604235)*cos(3*phi)

#@torch.jit.script
def Yl89_m4(theta, phi):
    return 8.32940637874957e-8*(1.0 - cos(theta)**2)**2*(2.16610794916886e+33*cos(theta)**85 - 4.36892959239142e+34*cos(theta)**83 + 4.24784782940229e+35*cos(theta)**81 - 2.65183563916444e+36*cos(theta)**79 + 1.19448912343065e+37*cos(theta)**77 - 4.13618363924032e+37*cos(theta)**75 + 1.14549995996925e+38*cos(theta)**73 - 2.60638432450147e+38*cos(theta)**71 + 4.96692104784213e+38*cos(theta)**69 - 8.04168169650631e+38*cos(theta)**67 + 1.11824894534437e+39*cos(theta)**65 - 1.34681980678418e+39*cos(theta)**63 + 1.41416079712339e+39*cos(theta)**61 - 1.30111325225531e+39*cos(theta)**59 + 1.05307699839585e+39*cos(theta)**57 - 7.51995923686703e+38*cos(theta)**55 + 4.7479334467464e+38*cos(theta)**53 - 2.65421999578764e+38*cos(theta)**51 + 1.31473601189947e+38*cos(theta)**49 - 5.7712935796707e+37*cos(theta)**47 + 2.2441612804403e+37*cos(theta)**45 - 7.72234851454952e+36*cos(theta)**43 + 2.34790596250445e+36*cos(theta)**41 - 6.2938309553895e+35*cos(theta)**39 + 1.48337428051642e+35*cos(theta)**37 - 3.06334037464786e+34*cos(theta)**35 + 5.51995009968346e+33*cos(theta)**33 - 8.63565526706034e+32*cos(theta)**31 + 1.16596390800902e+32*cos(theta)**29 - 1.3490491497625e+31*cos(theta)**27 + 1.32637605480851e+30*cos(theta)**25 - 1.09708523970927e+29*cos(theta)**23 + 7.54246102300124e+27*cos(theta)**21 - 4.24756453427262e+26*cos(theta)**19 + 1.9245721657674e+25*cos(theta)**17 - 6.86086014533071e+23*cos(theta)**15 + 1.87017215799513e+22*cos(theta)**13 - 3.75478579983579e+20*cos(theta)**11 + 5.27627028592152e+18*cos(theta)**9 - 4.82218152559469e+16*cos(theta)**7 + 255721747569415.0*cos(theta)**5 - 643001628286.184*cos(theta)**3 + 483459870.891867*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl89_m5(theta, phi):
    return 9.31838524946863e-10*(1.0 - cos(theta)**2)**2.5*(1.84119175679353e+35*cos(theta)**84 - 3.62621156168488e+36*cos(theta)**82 + 3.44075674181585e+37*cos(theta)**80 - 2.0949501549399e+38*cos(theta)**78 + 9.19756625041598e+38*cos(theta)**76 - 3.10213772943024e+39*cos(theta)**74 + 8.36214970777553e+39*cos(theta)**72 - 1.85053287039604e+40*cos(theta)**70 + 3.42717552301107e+40*cos(theta)**68 - 5.38792673665923e+40*cos(theta)**66 + 7.26861814473839e+40*cos(theta)**64 - 8.48496478274036e+40*cos(theta)**62 + 8.6263808624527e+40*cos(theta)**60 - 7.67656818830632e+40*cos(theta)**58 + 6.00253889085636e+40*cos(theta)**56 - 4.13597758027687e+40*cos(theta)**54 + 2.51640472677559e+40*cos(theta)**52 - 1.3536521978517e+40*cos(theta)**50 + 6.44220645830742e+39*cos(theta)**48 - 2.71250798244523e+39*cos(theta)**46 + 1.00987257619813e+39*cos(theta)**44 - 3.32060986125629e+38*cos(theta)**42 + 9.62641444626824e+37*cos(theta)**40 - 2.45459407260191e+37*cos(theta)**38 + 5.48848483791075e+36*cos(theta)**36 - 1.07216913112675e+36*cos(theta)**34 + 1.82158353289554e+35*cos(theta)**32 - 2.6770531327887e+34*cos(theta)**30 + 3.38129533322615e+33*cos(theta)**28 - 3.64243270435875e+32*cos(theta)**26 + 3.31594013702127e+31*cos(theta)**24 - 2.52329605133132e+30*cos(theta)**22 + 1.58391681483026e+29*cos(theta)**20 - 8.07037261511798e+27*cos(theta)**18 + 3.27177268180458e+26*cos(theta)**16 - 1.02912902179961e+25*cos(theta)**14 + 2.43122380539367e+23*cos(theta)**12 - 4.13026437981937e+21*cos(theta)**10 + 4.74864325732937e+19*cos(theta)**8 - 3.37552706791628e+17*cos(theta)**6 + 1.27860873784708e+15*cos(theta)**4 - 1929004884858.55*cos(theta)**2 + 483459870.891867)*cos(5*phi)

#@torch.jit.script
def Yl89_m6(theta, phi):
    return 1.04313187372637e-11*(1.0 - cos(theta)**2)**3*(1.54660107570656e+37*cos(theta)**83 - 2.9734934805816e+38*cos(theta)**81 + 2.75260539345268e+39*cos(theta)**79 - 1.63406112085313e+40*cos(theta)**77 + 6.99015035031615e+40*cos(theta)**75 - 2.29558191977838e+41*cos(theta)**73 + 6.02074778959838e+41*cos(theta)**71 - 1.29537300927723e+42*cos(theta)**69 + 2.33047935564753e+42*cos(theta)**67 - 3.55603164619509e+42*cos(theta)**65 + 4.65191561263257e+42*cos(theta)**63 - 5.26067816529902e+42*cos(theta)**61 + 5.17582851747162e+42*cos(theta)**59 - 4.45240954921767e+42*cos(theta)**57 + 3.36142177887956e+42*cos(theta)**55 - 2.23342789334951e+42*cos(theta)**53 + 1.30853045792331e+42*cos(theta)**51 - 6.76826098925849e+41*cos(theta)**49 + 3.09225909998756e+41*cos(theta)**47 - 1.24775367192481e+41*cos(theta)**45 + 4.44343933527179e+40*cos(theta)**43 - 1.39465614172764e+40*cos(theta)**41 + 3.8505657785073e+39*cos(theta)**39 - 9.32745747588724e+38*cos(theta)**37 + 1.97585454164787e+38*cos(theta)**35 - 3.64537504583095e+37*cos(theta)**33 + 5.82906730526573e+36*cos(theta)**31 - 8.03115939836611e+35*cos(theta)**29 + 9.46762693303322e+34*cos(theta)**27 - 9.47032503133275e+33*cos(theta)**25 + 7.95825632885105e+32*cos(theta)**23 - 5.55125131292891e+31*cos(theta)**21 + 3.16783362966052e+30*cos(theta)**19 - 1.45266707072124e+29*cos(theta)**17 + 5.23483629088734e+27*cos(theta)**15 - 1.44078063051945e+26*cos(theta)**13 + 2.91746856647241e+24*cos(theta)**11 - 4.13026437981937e+22*cos(theta)**9 + 3.79891460586349e+20*cos(theta)**7 - 2.02531624074977e+18*cos(theta)**5 + 5.11443495138831e+15*cos(theta)**3 - 3858009769717.1*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl89_m7(theta, phi):
    return 1.168596424302e-13*(1.0 - cos(theta)**2)**3.5*(1.28367889283645e+39*cos(theta)**82 - 2.4085297192711e+40*cos(theta)**80 + 2.17455826082762e+41*cos(theta)**78 - 1.25822706305691e+42*cos(theta)**76 + 5.24261276273711e+42*cos(theta)**74 - 1.67577480143822e+43*cos(theta)**72 + 4.27473093061485e+43*cos(theta)**70 - 8.93807376401287e+43*cos(theta)**68 + 1.56142116828384e+44*cos(theta)**66 - 2.31142057002681e+44*cos(theta)**64 + 2.93070683595852e+44*cos(theta)**62 - 3.2090136808324e+44*cos(theta)**60 + 3.05373882530825e+44*cos(theta)**58 - 2.53787344305407e+44*cos(theta)**56 + 1.84878197838376e+44*cos(theta)**54 - 1.18371678347524e+44*cos(theta)**52 + 6.67350533540887e+43*cos(theta)**50 - 3.31644788473666e+43*cos(theta)**48 + 1.45336177699415e+43*cos(theta)**46 - 5.61489152366163e+42*cos(theta)**44 + 1.91067891416687e+42*cos(theta)**42 - 5.71809018108334e+41*cos(theta)**40 + 1.50172065361785e+41*cos(theta)**38 - 3.45115926607828e+40*cos(theta)**36 + 6.91549089576754e+39*cos(theta)**34 - 1.20297376512421e+39*cos(theta)**32 + 1.80701086463238e+38*cos(theta)**30 - 2.32903622552617e+37*cos(theta)**28 + 2.55625927191897e+36*cos(theta)**26 - 2.36758125783319e+35*cos(theta)**24 + 1.83039895563574e+34*cos(theta)**22 - 1.16576277571507e+33*cos(theta)**20 + 6.01888389635499e+31*cos(theta)**18 - 2.4695340202261e+30*cos(theta)**16 + 7.852254436331e+28*cos(theta)**14 - 1.87301481967529e+27*cos(theta)**12 + 3.20921542311965e+25*cos(theta)**10 - 3.71723794183743e+23*cos(theta)**8 + 2.65924022410445e+21*cos(theta)**6 - 1.01265812037488e+19*cos(theta)**4 + 1.53433048541649e+16*cos(theta)**2 - 3858009769717.1)*cos(7*phi)

#@torch.jit.script
def Yl89_m8(theta, phi):
    return 1.31030307370003e-15*(1.0 - cos(theta)**2)**4*(1.05261669212589e+41*cos(theta)**81 - 1.92682377541688e+42*cos(theta)**79 + 1.69615544344554e+43*cos(theta)**77 - 9.56252567923249e+43*cos(theta)**75 + 3.87953344442546e+44*cos(theta)**73 - 1.20655785703552e+45*cos(theta)**71 + 2.9923116514304e+45*cos(theta)**69 - 6.07789015952875e+45*cos(theta)**67 + 1.03053797106734e+46*cos(theta)**65 - 1.47930916481716e+46*cos(theta)**63 + 1.81703823829428e+46*cos(theta)**61 - 1.92540820849944e+46*cos(theta)**59 + 1.77116851867879e+46*cos(theta)**57 - 1.42120912811028e+46*cos(theta)**55 + 9.9834226832723e+45*cos(theta)**53 - 6.15532727407124e+45*cos(theta)**51 + 3.33675266770444e+45*cos(theta)**49 - 1.5918949846736e+45*cos(theta)**47 + 6.68546417417311e+44*cos(theta)**45 - 2.47055227041112e+44*cos(theta)**43 + 8.02485143950086e+43*cos(theta)**41 - 2.28723607243333e+43*cos(theta)**39 + 5.70653848374781e+42*cos(theta)**37 - 1.24241733578818e+42*cos(theta)**35 + 2.35126690456097e+41*cos(theta)**33 - 3.84951604839749e+40*cos(theta)**31 + 5.42103259389713e+39*cos(theta)**29 - 6.52130143147329e+38*cos(theta)**27 + 6.64627410698932e+37*cos(theta)**25 - 5.68219501879965e+36*cos(theta)**23 + 4.02687770239863e+35*cos(theta)**21 - 2.33152555143014e+34*cos(theta)**19 + 1.0833991013439e+33*cos(theta)**17 - 3.95125443236176e+31*cos(theta)**15 + 1.09931562108634e+30*cos(theta)**13 - 2.24761778361034e+28*cos(theta)**11 + 3.20921542311965e+26*cos(theta)**9 - 2.97379035346994e+24*cos(theta)**7 + 1.59554413446267e+22*cos(theta)**5 - 4.05063248149954e+19*cos(theta)**3 + 3.06866097083298e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl89_m9(theta, phi):
    return 1.47067331559185e-17*(1.0 - cos(theta)**2)**4.5*(8.52619520621969e+42*cos(theta)**80 - 1.52219078257933e+44*cos(theta)**78 + 1.30603969145307e+45*cos(theta)**76 - 7.17189425942437e+45*cos(theta)**74 + 2.83205941443059e+46*cos(theta)**72 - 8.56656078495217e+46*cos(theta)**70 + 2.06469503948697e+47*cos(theta)**68 - 4.07218640688427e+47*cos(theta)**66 + 6.69849681193769e+47*cos(theta)**64 - 9.31964773834809e+47*cos(theta)**62 + 1.10839332535951e+48*cos(theta)**60 - 1.13599084301467e+48*cos(theta)**58 + 1.00956605564691e+48*cos(theta)**56 - 7.81665020460654e+47*cos(theta)**54 + 5.29121402213432e+47*cos(theta)**52 - 3.13921690977633e+47*cos(theta)**50 + 1.63500880717517e+47*cos(theta)**48 - 7.48190642796591e+46*cos(theta)**46 + 3.0084588783779e+46*cos(theta)**44 - 1.06233747627678e+46*cos(theta)**42 + 3.29018909019535e+45*cos(theta)**40 - 8.92022068249e+44*cos(theta)**38 + 2.11141923898669e+44*cos(theta)**36 - 4.34846067525863e+43*cos(theta)**34 + 7.75918078505118e+42*cos(theta)**32 - 1.19334997500322e+42*cos(theta)**30 + 1.57209945223017e+41*cos(theta)**28 - 1.76075138649779e+40*cos(theta)**26 + 1.66156852674733e+39*cos(theta)**24 - 1.30690485432392e+38*cos(theta)**22 + 8.45644317503712e+36*cos(theta)**20 - 4.42989854771727e+35*cos(theta)**18 + 1.84177847228463e+34*cos(theta)**16 - 5.92688164854264e+32*cos(theta)**14 + 1.42911030741224e+31*cos(theta)**12 - 2.47237956197138e+29*cos(theta)**10 + 2.88829388080768e+27*cos(theta)**8 - 2.08165324742896e+25*cos(theta)**6 + 7.97772067231334e+22*cos(theta)**4 - 1.21518974444986e+20*cos(theta)**2 + 3.06866097083298e+16)*cos(9*phi)

#@torch.jit.script
def Yl89_m10(theta, phi):
    return 1.65254624516731e-19*(1.0 - cos(theta)**2)**5*(6.82095616497575e+44*cos(theta)**79 - 1.18730881041188e+46*cos(theta)**77 + 9.92590165504332e+46*cos(theta)**75 - 5.30720175197403e+47*cos(theta)**73 + 2.03908277839002e+48*cos(theta)**71 - 5.99659254946652e+48*cos(theta)**69 + 1.40399262685114e+49*cos(theta)**67 - 2.68764302854362e+49*cos(theta)**65 + 4.28703795964012e+49*cos(theta)**63 - 5.77818159777582e+49*cos(theta)**61 + 6.65035995215707e+49*cos(theta)**59 - 6.58874688948509e+49*cos(theta)**57 + 5.65356991162269e+49*cos(theta)**55 - 4.22099111048753e+49*cos(theta)**53 + 2.75143129150985e+49*cos(theta)**51 - 1.56960845488817e+49*cos(theta)**49 + 7.84804227444084e+48*cos(theta)**47 - 3.44167695686432e+48*cos(theta)**45 + 1.32372190648628e+48*cos(theta)**43 - 4.46181740036248e+47*cos(theta)**41 + 1.31607563607814e+47*cos(theta)**39 - 3.3896838593462e+46*cos(theta)**37 + 7.60110926035209e+45*cos(theta)**35 - 1.47847662958793e+45*cos(theta)**33 + 2.48293785121638e+44*cos(theta)**31 - 3.58004992500966e+43*cos(theta)**29 + 4.40187846624447e+42*cos(theta)**27 - 4.57795360489425e+41*cos(theta)**25 + 3.98776446419359e+40*cos(theta)**23 - 2.87519067951262e+39*cos(theta)**21 + 1.69128863500743e+38*cos(theta)**19 - 7.97381738589109e+36*cos(theta)**17 + 2.9468455556554e+35*cos(theta)**15 - 8.2976343079597e+33*cos(theta)**13 + 1.71493236889469e+32*cos(theta)**11 - 2.47237956197138e+30*cos(theta)**9 + 2.31063510464615e+28*cos(theta)**7 - 1.24899194845738e+26*cos(theta)**5 + 3.19108826892534e+23*cos(theta)**3 - 2.43037948889972e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl89_m11(theta, phi):
    return 1.85925978615847e-21*(1.0 - cos(theta)**2)**5.5*(5.38855537033084e+46*cos(theta)**78 - 9.14227784017148e+47*cos(theta)**76 + 7.44442624128249e+48*cos(theta)**74 - 3.87425727894104e+49*cos(theta)**72 + 1.44774877265692e+50*cos(theta)**70 - 4.1376488591319e+50*cos(theta)**68 + 9.40675059990265e+50*cos(theta)**66 - 1.74696796855335e+51*cos(theta)**64 + 2.70083391457328e+51*cos(theta)**62 - 3.52469077464325e+51*cos(theta)**60 + 3.92371237177267e+51*cos(theta)**58 - 3.7555857270065e+51*cos(theta)**56 + 3.10946345139248e+51*cos(theta)**54 - 2.23712528855839e+51*cos(theta)**52 + 1.40322995867002e+51*cos(theta)**50 - 7.69108142895202e+50*cos(theta)**48 + 3.68857986898719e+50*cos(theta)**46 - 1.54875463058894e+50*cos(theta)**44 + 5.69200419789099e+49*cos(theta)**42 - 1.82934513414862e+49*cos(theta)**40 + 5.13269498070475e+48*cos(theta)**38 - 1.25418302795809e+48*cos(theta)**36 + 2.66038824112323e+47*cos(theta)**34 - 4.87897287764018e+46*cos(theta)**32 + 7.69710733877078e+45*cos(theta)**30 - 1.0382144782528e+45*cos(theta)**28 + 1.18850718588601e+44*cos(theta)**26 - 1.14448840122356e+43*cos(theta)**24 + 9.17185826764527e+41*cos(theta)**22 - 6.03790042697651e+40*cos(theta)**20 + 3.21344840651411e+39*cos(theta)**18 - 1.35554895560148e+38*cos(theta)**16 + 4.4202683334831e+36*cos(theta)**14 - 1.07869246003476e+35*cos(theta)**12 + 1.88642560578416e+33*cos(theta)**10 - 2.22514160577424e+31*cos(theta)**8 + 1.6174445732523e+29*cos(theta)**6 - 6.24495974228688e+26*cos(theta)**4 + 9.57326480677601e+23*cos(theta)**2 - 2.43037948889972e+20)*cos(11*phi)

#@torch.jit.script
def Yl89_m12(theta, phi):
    return 2.09474946331826e-23*(1.0 - cos(theta)**2)**6*(4.20307318885806e+48*cos(theta)**77 - 6.94813115853033e+49*cos(theta)**75 + 5.50887541854904e+50*cos(theta)**73 - 2.78946524083755e+51*cos(theta)**71 + 1.01342414085984e+52*cos(theta)**69 - 2.81360122420969e+52*cos(theta)**67 + 6.20845539593575e+52*cos(theta)**65 - 1.11805949987414e+53*cos(theta)**63 + 1.67451702703543e+53*cos(theta)**61 - 2.11481446478595e+53*cos(theta)**59 + 2.27575317562815e+53*cos(theta)**57 - 2.10312800712364e+53*cos(theta)**55 + 1.67911026375194e+53*cos(theta)**53 - 1.16330515005036e+53*cos(theta)**51 + 7.01614979335011e+52*cos(theta)**49 - 3.69171908589697e+52*cos(theta)**47 + 1.69674673973411e+52*cos(theta)**45 - 6.81452037459135e+51*cos(theta)**43 + 2.39064176311421e+51*cos(theta)**41 - 7.31738053659446e+50*cos(theta)**39 + 1.9504240926678e+50*cos(theta)**37 - 4.51505890064914e+49*cos(theta)**35 + 9.04532001981898e+48*cos(theta)**33 - 1.56127132084486e+48*cos(theta)**31 + 2.30913220163123e+47*cos(theta)**29 - 2.90700053910785e+46*cos(theta)**27 + 3.09011868330362e+45*cos(theta)**25 - 2.74677216293655e+44*cos(theta)**23 + 2.01780881888196e+43*cos(theta)**21 - 1.2075800853953e+42*cos(theta)**19 + 5.78420713172539e+40*cos(theta)**17 - 2.16887832896238e+39*cos(theta)**15 + 6.18837566687634e+37*cos(theta)**13 - 1.29443095204171e+36*cos(theta)**11 + 1.88642560578416e+34*cos(theta)**9 - 1.78011328461939e+32*cos(theta)**7 + 9.70466743951381e+29*cos(theta)**5 - 2.49798389691475e+27*cos(theta)**3 + 1.9146529613552e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl89_m13(theta, phi):
    return 2.36366889105142e-25*(1.0 - cos(theta)**2)**6.5*(3.2363663554207e+50*cos(theta)**76 - 5.21109836889774e+51*cos(theta)**74 + 4.0214790555408e+52*cos(theta)**72 - 1.98052032099466e+53*cos(theta)**70 + 6.9926265719329e+53*cos(theta)**68 - 1.88511282022049e+54*cos(theta)**66 + 4.03549600735824e+54*cos(theta)**64 - 7.04377484920711e+54*cos(theta)**62 + 1.02145538649161e+55*cos(theta)**60 - 1.24774053422371e+55*cos(theta)**58 + 1.29717931010805e+55*cos(theta)**56 - 1.156720403918e+55*cos(theta)**54 + 8.89928439788528e+54*cos(theta)**52 - 5.93285626525685e+54*cos(theta)**50 + 3.43791339874155e+54*cos(theta)**48 - 1.73510797037158e+54*cos(theta)**46 + 7.63536032880349e+53*cos(theta)**44 - 2.93024376107428e+53*cos(theta)**42 + 9.80163122876828e+52*cos(theta)**40 - 2.85377840927184e+52*cos(theta)**38 + 7.21656914287088e+51*cos(theta)**36 - 1.5802706152272e+51*cos(theta)**34 + 2.98495560654027e+50*cos(theta)**32 - 4.83994109461906e+49*cos(theta)**30 + 6.69648338473057e+48*cos(theta)**28 - 7.84890145559118e+47*cos(theta)**26 + 7.72529670825904e+46*cos(theta)**24 - 6.31757597475406e+45*cos(theta)**22 + 4.23739851965211e+44*cos(theta)**20 - 2.29440216225107e+43*cos(theta)**18 + 9.83315212393317e+41*cos(theta)**16 - 3.25331749344356e+40*cos(theta)**14 + 8.04488836693925e+38*cos(theta)**12 - 1.42387404724588e+37*cos(theta)**10 + 1.69778304520574e+35*cos(theta)**8 - 1.24607929923357e+33*cos(theta)**6 + 4.85233371975691e+30*cos(theta)**4 - 7.49395169074426e+27*cos(theta)**2 + 1.9146529613552e+24)*cos(13*phi)

#@torch.jit.script
def Yl89_m14(theta, phi):
    return 2.67153723039434e-27*(1.0 - cos(theta)**2)**7*(2.45963843011974e+52*cos(theta)**75 - 3.85621279298433e+53*cos(theta)**73 + 2.89546491998938e+54*cos(theta)**71 - 1.38636422469626e+55*cos(theta)**69 + 4.75498606891437e+55*cos(theta)**67 - 1.24417446134552e+56*cos(theta)**65 + 2.58271744470927e+56*cos(theta)**63 - 4.36714040650841e+56*cos(theta)**61 + 6.12873231894968e+56*cos(theta)**59 - 7.23689509849752e+56*cos(theta)**57 + 7.26420413660506e+56*cos(theta)**55 - 6.24629018115721e+56*cos(theta)**53 + 4.62762788690034e+56*cos(theta)**51 - 2.96642813262843e+56*cos(theta)**49 + 1.65019843139595e+56*cos(theta)**47 - 7.98149666370925e+55*cos(theta)**45 + 3.35955854467354e+55*cos(theta)**43 - 1.2307023796512e+55*cos(theta)**41 + 3.92065249150731e+54*cos(theta)**39 - 1.0844357955233e+54*cos(theta)**37 + 2.59796489143352e+53*cos(theta)**35 - 5.37292009177248e+52*cos(theta)**33 + 9.55185794092885e+51*cos(theta)**31 - 1.45198232838572e+51*cos(theta)**29 + 1.87501534772456e+50*cos(theta)**27 - 2.04071437845371e+49*cos(theta)**25 + 1.85407120998217e+48*cos(theta)**23 - 1.38986671444589e+47*cos(theta)**21 + 8.47479703930423e+45*cos(theta)**19 - 4.12992389205193e+44*cos(theta)**17 + 1.57330433982931e+43*cos(theta)**15 - 4.55464449082099e+41*cos(theta)**13 + 9.65386604032709e+39*cos(theta)**11 - 1.42387404724588e+38*cos(theta)**9 + 1.3582264361646e+36*cos(theta)**7 - 7.47647579540144e+33*cos(theta)**5 + 1.94093348790276e+31*cos(theta)**3 - 1.49879033814885e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl89_m15(theta, phi):
    return 3.02492025183777e-29*(1.0 - cos(theta)**2)**7.5*(1.8447288225898e+54*cos(theta)**74 - 2.81503533887856e+55*cos(theta)**72 + 2.05578009319246e+56*cos(theta)**70 - 9.56591315040421e+56*cos(theta)**68 + 3.18584066617263e+57*cos(theta)**66 - 8.08713399874591e+57*cos(theta)**64 + 1.62711199016684e+58*cos(theta)**62 - 2.66395564797013e+58*cos(theta)**60 + 3.61595206818031e+58*cos(theta)**58 - 4.12503020614358e+58*cos(theta)**56 + 3.99531227513278e+58*cos(theta)**54 - 3.31053379601332e+58*cos(theta)**52 + 2.36009022231918e+58*cos(theta)**50 - 1.45354978498793e+58*cos(theta)**48 + 7.75593262756094e+57*cos(theta)**46 - 3.59167349866916e+57*cos(theta)**44 + 1.44461017420962e+57*cos(theta)**42 - 5.04587975656991e+56*cos(theta)**40 + 1.52905447168785e+56*cos(theta)**38 - 4.01241244343621e+55*cos(theta)**36 + 9.0928771200173e+54*cos(theta)**34 - 1.77306363028492e+54*cos(theta)**32 + 2.96107596168794e+53*cos(theta)**30 - 4.21074875231858e+52*cos(theta)**28 + 5.06254143885631e+51*cos(theta)**26 - 5.10178594613427e+50*cos(theta)**24 + 4.26436378295899e+49*cos(theta)**22 - 2.91872010033638e+48*cos(theta)**20 + 1.6102114374678e+47*cos(theta)**18 - 7.02087061648828e+45*cos(theta)**16 + 2.35995650974396e+44*cos(theta)**14 - 5.92103783806728e+42*cos(theta)**12 + 1.06192526443598e+41*cos(theta)**10 - 1.2814866425213e+39*cos(theta)**8 + 9.50758505315217e+36*cos(theta)**6 - 3.73823789770072e+34*cos(theta)**4 + 5.82280046370829e+31*cos(theta)**2 - 1.49879033814885e+28)*cos(15*phi)

#@torch.jit.script
def Yl89_m16(theta, phi):
    return 3.43165342252496e-31*(1.0 - cos(theta)**2)**8*(1.36509932871645e+56*cos(theta)**73 - 2.02682544399256e+57*cos(theta)**71 + 1.43904606523472e+58*cos(theta)**69 - 6.50482094227486e+58*cos(theta)**67 + 2.10265483967394e+59*cos(theta)**65 - 5.17576575919738e+59*cos(theta)**63 + 1.00880943390344e+60*cos(theta)**61 - 1.59837338878208e+60*cos(theta)**59 + 2.09725219954458e+60*cos(theta)**57 - 2.31001691544041e+60*cos(theta)**55 + 2.1574686285717e+60*cos(theta)**53 - 1.72147757392693e+60*cos(theta)**51 + 1.18004511115959e+60*cos(theta)**49 - 6.97703896794206e+59*cos(theta)**47 + 3.56772900867803e+59*cos(theta)**45 - 1.58033633941443e+59*cos(theta)**43 + 6.06736273168041e+58*cos(theta)**41 - 2.01835190262796e+58*cos(theta)**39 + 5.81040699241384e+57*cos(theta)**37 - 1.44446847963703e+57*cos(theta)**35 + 3.09157822080588e+56*cos(theta)**33 - 5.67380361691174e+55*cos(theta)**31 + 8.88322788506383e+54*cos(theta)**29 - 1.1790096506492e+54*cos(theta)**27 + 1.31626077410264e+53*cos(theta)**25 - 1.22442862707222e+52*cos(theta)**23 + 9.38160032250978e+50*cos(theta)**21 - 5.83744020067275e+49*cos(theta)**19 + 2.89838058744205e+48*cos(theta)**17 - 1.12333929863813e+47*cos(theta)**15 + 3.30393911364154e+45*cos(theta)**13 - 7.10524540568074e+43*cos(theta)**11 + 1.06192526443598e+42*cos(theta)**9 - 1.02518931401704e+40*cos(theta)**7 + 5.7045510318913e+37*cos(theta)**5 - 1.49529515908029e+35*cos(theta)**3 + 1.16456009274166e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl89_m17(theta, phi):
    return 3.90111773492035e-33*(1.0 - cos(theta)**2)**8.5*(9.96522509963011e+57*cos(theta)**72 - 1.43904606523472e+59*cos(theta)**70 + 9.92941785011957e+59*cos(theta)**68 - 4.35823003132416e+60*cos(theta)**66 + 1.36672564578806e+61*cos(theta)**64 - 3.26073242829435e+61*cos(theta)**62 + 6.153737546811e+61*cos(theta)**60 - 9.43040299381425e+61*cos(theta)**58 + 1.19543375374041e+62*cos(theta)**56 - 1.27050930349222e+62*cos(theta)**54 + 1.143458373143e+62*cos(theta)**52 - 8.77953562702733e+61*cos(theta)**50 + 5.78222104468198e+61*cos(theta)**48 - 3.27920831493277e+61*cos(theta)**46 + 1.60547805390512e+61*cos(theta)**44 - 6.79544625948205e+60*cos(theta)**42 + 2.48761871998897e+60*cos(theta)**40 - 7.87157242024906e+59*cos(theta)**38 + 2.14985058719312e+59*cos(theta)**36 - 5.05563967872962e+58*cos(theta)**34 + 1.02022081286594e+58*cos(theta)**32 - 1.75887912124264e+57*cos(theta)**30 + 2.57613608666851e+56*cos(theta)**28 - 3.18332605675285e+55*cos(theta)**26 + 3.2906519352566e+54*cos(theta)**24 - 2.81618584226612e+53*cos(theta)**22 + 1.97013606772705e+52*cos(theta)**20 - 1.10911363812782e+51*cos(theta)**18 + 4.92724699865148e+49*cos(theta)**16 - 1.68500894795719e+48*cos(theta)**14 + 4.29512084773401e+46*cos(theta)**12 - 7.81576994624882e+44*cos(theta)**10 + 9.55732737992382e+42*cos(theta)**8 - 7.17632519811926e+40*cos(theta)**6 + 2.85227551594565e+38*cos(theta)**4 - 4.48588547724087e+35*cos(theta)**2 + 1.16456009274166e+32)*cos(17*phi)

#@torch.jit.script
def Yl89_m18(theta, phi):
    return 4.44458197209647e-35*(1.0 - cos(theta)**2)**9*(7.17496207173368e+59*cos(theta)**71 - 1.0073322456643e+61*cos(theta)**69 + 6.75200413808131e+61*cos(theta)**67 - 2.87643182067395e+62*cos(theta)**65 + 8.74704413304358e+62*cos(theta)**63 - 2.0216541055425e+63*cos(theta)**61 + 3.6922425280866e+63*cos(theta)**59 - 5.46963373641227e+63*cos(theta)**57 + 6.6944290209463e+63*cos(theta)**55 - 6.86075023885801e+63*cos(theta)**53 + 5.94598354034361e+63*cos(theta)**51 - 4.38976781351367e+63*cos(theta)**49 + 2.77546610144735e+63*cos(theta)**47 - 1.50843582486907e+63*cos(theta)**45 + 7.06410343718251e+62*cos(theta)**43 - 2.85408742898246e+62*cos(theta)**41 + 9.95047487995587e+61*cos(theta)**39 - 2.99119751969464e+61*cos(theta)**37 + 7.73946211389523e+60*cos(theta)**35 - 1.71891749076807e+60*cos(theta)**33 + 3.26470660117101e+59*cos(theta)**31 - 5.27663736372791e+58*cos(theta)**29 + 7.21318104267183e+57*cos(theta)**27 - 8.27664774755741e+56*cos(theta)**25 + 7.89756464461585e+55*cos(theta)**23 - 6.19560885298546e+54*cos(theta)**21 + 3.94027213545411e+53*cos(theta)**19 - 1.99640454863008e+52*cos(theta)**17 + 7.88359519784236e+50*cos(theta)**15 - 2.35901252714006e+49*cos(theta)**13 + 5.15414501728081e+47*cos(theta)**11 - 7.81576994624882e+45*cos(theta)**9 + 7.64586190393906e+43*cos(theta)**7 - 4.30579511887155e+41*cos(theta)**5 + 1.14091020637826e+39*cos(theta)**3 - 8.97177095448173e+35*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl89_m19(theta, phi):
    return 5.07562897863914e-37*(1.0 - cos(theta)**2)**9.5*(5.09422307093091e+61*cos(theta)**70 - 6.9505924950837e+62*cos(theta)**68 + 4.52384277251448e+63*cos(theta)**66 - 1.86968068343806e+64*cos(theta)**64 + 5.51063780381745e+64*cos(theta)**62 - 1.23320900438092e+65*cos(theta)**60 + 2.17842309157109e+65*cos(theta)**58 - 3.11769122975499e+65*cos(theta)**56 + 3.68193596152047e+65*cos(theta)**54 - 3.63619762659475e+65*cos(theta)**52 + 3.03245160557524e+65*cos(theta)**50 - 2.1509862286217e+65*cos(theta)**48 + 1.30446906768025e+65*cos(theta)**46 - 6.78796121191083e+64*cos(theta)**44 + 3.03756447798848e+64*cos(theta)**42 - 1.17017584588281e+64*cos(theta)**40 + 3.88068520318279e+63*cos(theta)**38 - 1.10674308228702e+63*cos(theta)**36 + 2.70881173986333e+62*cos(theta)**34 - 5.67242771953463e+61*cos(theta)**32 + 1.01205904636301e+61*cos(theta)**30 - 1.5302248354811e+60*cos(theta)**28 + 1.94755888152139e+59*cos(theta)**26 - 2.06916193688935e+58*cos(theta)**24 + 1.81643986826165e+57*cos(theta)**22 - 1.30107785912695e+56*cos(theta)**20 + 7.4865170573628e+54*cos(theta)**18 - 3.39388773267114e+53*cos(theta)**16 + 1.18253927967635e+52*cos(theta)**14 - 3.06671628528208e+50*cos(theta)**12 + 5.66955951900889e+48*cos(theta)**10 - 7.03419295162393e+46*cos(theta)**8 + 5.35210333275734e+44*cos(theta)**6 - 2.15289755943578e+42*cos(theta)**4 + 3.42273061913478e+39*cos(theta)**2 - 8.97177095448173e+35)*cos(19*phi)

#@torch.jit.script
def Yl89_m20(theta, phi):
    return 5.81068856595213e-39*(1.0 - cos(theta)**2)**10*(3.56595614965164e+63*cos(theta)**69 - 4.72640289665692e+64*cos(theta)**67 + 2.98573622985956e+65*cos(theta)**65 - 1.19659563740036e+66*cos(theta)**63 + 3.41659543836682e+66*cos(theta)**61 - 7.39925402628554e+66*cos(theta)**59 + 1.26348539311123e+67*cos(theta)**57 - 1.7459070886628e+67*cos(theta)**55 + 1.98824541922105e+67*cos(theta)**53 - 1.89082276582927e+67*cos(theta)**51 + 1.51622580278762e+67*cos(theta)**49 - 1.03247338973841e+67*cos(theta)**47 + 6.00055771132917e+66*cos(theta)**45 - 2.98670293324076e+66*cos(theta)**43 + 1.27577708075516e+66*cos(theta)**41 - 4.68070338353124e+65*cos(theta)**39 + 1.47466037720946e+65*cos(theta)**37 - 3.98427509623327e+64*cos(theta)**35 + 9.20995991553533e+63*cos(theta)**33 - 1.81517687025108e+63*cos(theta)**31 + 3.03617713908904e+62*cos(theta)**29 - 4.28462953934707e+61*cos(theta)**27 + 5.06365309195562e+60*cos(theta)**25 - 4.96598864853445e+59*cos(theta)**23 + 3.99616771017562e+58*cos(theta)**21 - 2.60215571825389e+57*cos(theta)**19 + 1.3475730703253e+56*cos(theta)**17 - 5.43022037227382e+54*cos(theta)**15 + 1.6555549915469e+53*cos(theta)**13 - 3.6800595423385e+51*cos(theta)**11 + 5.66955951900889e+49*cos(theta)**9 - 5.62735436129915e+47*cos(theta)**7 + 3.2112619996544e+45*cos(theta)**5 - 8.61159023774311e+42*cos(theta)**3 + 6.84546123826956e+39*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl89_m21(theta, phi):
    return 6.66970631729821e-41*(1.0 - cos(theta)**2)**10.5*(2.46050974325963e+65*cos(theta)**68 - 3.16668994076013e+66*cos(theta)**66 + 1.94072854940871e+67*cos(theta)**64 - 7.53855251562227e+67*cos(theta)**62 + 2.08412321740376e+68*cos(theta)**60 - 4.36555987550847e+68*cos(theta)**58 + 7.20186674073403e+68*cos(theta)**56 - 9.60248898764537e+68*cos(theta)**54 + 1.05377007218716e+69*cos(theta)**52 - 9.64319610572927e+68*cos(theta)**50 + 7.42950643365934e+68*cos(theta)**48 - 4.85262493177055e+68*cos(theta)**46 + 2.70025097009813e+68*cos(theta)**44 - 1.28428226129353e+68*cos(theta)**42 + 5.23068603109616e+67*cos(theta)**40 - 1.82547431957718e+67*cos(theta)**38 + 5.456243395675e+66*cos(theta)**36 - 1.39449628368164e+66*cos(theta)**34 + 3.03928677212666e+65*cos(theta)**32 - 5.62704829777836e+64*cos(theta)**30 + 8.80491370335822e+63*cos(theta)**28 - 1.15684997562371e+63*cos(theta)**26 + 1.26591327298891e+62*cos(theta)**24 - 1.14217738916292e+61*cos(theta)**22 + 8.3919521913688e+59*cos(theta)**20 - 4.9440958646824e+58*cos(theta)**18 + 2.29087421955302e+57*cos(theta)**16 - 8.14533055841073e+55*cos(theta)**14 + 2.15222148901097e+54*cos(theta)**12 - 4.04806549657235e+52*cos(theta)**10 + 5.102603567108e+50*cos(theta)**8 - 3.9391480529094e+48*cos(theta)**6 + 1.6056309998272e+46*cos(theta)**4 - 2.58347707132293e+43*cos(theta)**2 + 6.84546123826956e+39)*cos(21*phi)

#@torch.jit.script
def Yl89_m22(theta, phi):
    return 7.67698630014625e-43*(1.0 - cos(theta)**2)**11*(1.67314662541655e+67*cos(theta)**67 - 2.09001536090169e+68*cos(theta)**65 + 1.24206627162157e+69*cos(theta)**63 - 4.67390255968581e+69*cos(theta)**61 + 1.25047393044226e+70*cos(theta)**59 - 2.53202472779491e+70*cos(theta)**57 + 4.03304537481106e+70*cos(theta)**55 - 5.1853440533285e+70*cos(theta)**53 + 5.47960437537322e+70*cos(theta)**51 - 4.82159805286463e+70*cos(theta)**49 + 3.56616308815648e+70*cos(theta)**47 - 2.23220746861445e+70*cos(theta)**45 + 1.18811042684318e+70*cos(theta)**43 - 5.39398549743282e+69*cos(theta)**41 + 2.09227441243846e+69*cos(theta)**39 - 6.9368024143933e+68*cos(theta)**37 + 1.964247622443e+68*cos(theta)**35 - 4.74128736451759e+67*cos(theta)**33 + 9.7257176708053e+66*cos(theta)**31 - 1.68811448933351e+66*cos(theta)**29 + 2.4653758369403e+65*cos(theta)**27 - 3.00780993662164e+64*cos(theta)**25 + 3.03819185517337e+63*cos(theta)**23 - 2.51279025615843e+62*cos(theta)**21 + 1.67839043827376e+61*cos(theta)**19 - 8.89937255642831e+59*cos(theta)**17 + 3.66539875128483e+58*cos(theta)**15 - 1.1403462781775e+57*cos(theta)**13 + 2.58266578681316e+55*cos(theta)**11 - 4.04806549657235e+53*cos(theta)**9 + 4.0820828536864e+51*cos(theta)**7 - 2.36348883174564e+49*cos(theta)**5 + 6.42252399930881e+46*cos(theta)**3 - 5.16695414264586e+43*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl89_m23(theta, phi):
    return 8.86225726032474e-45*(1.0 - cos(theta)**2)**11.5*(1.12100823902909e+69*cos(theta)**66 - 1.3585099845861e+70*cos(theta)**64 + 7.82501751121592e+70*cos(theta)**62 - 2.85108056140834e+71*cos(theta)**60 + 7.37779618960931e+71*cos(theta)**58 - 1.4432540948431e+72*cos(theta)**56 + 2.21817495614608e+72*cos(theta)**54 - 2.74823234826411e+72*cos(theta)**52 + 2.79459823144034e+72*cos(theta)**50 - 2.36258304590367e+72*cos(theta)**48 + 1.67609665143355e+72*cos(theta)**46 - 1.0044933608765e+72*cos(theta)**44 + 5.10887483542566e+71*cos(theta)**42 - 2.21153405394746e+71*cos(theta)**40 + 8.15987020851001e+70*cos(theta)**38 - 2.56661689332552e+70*cos(theta)**36 + 6.8748666785505e+69*cos(theta)**34 - 1.5646248302908e+69*cos(theta)**32 + 3.01497247794964e+68*cos(theta)**30 - 4.89553201906717e+67*cos(theta)**28 + 6.65651475973882e+66*cos(theta)**26 - 7.5195248415541e+65*cos(theta)**24 + 6.98784126689876e+64*cos(theta)**22 - 5.2768595379327e+63*cos(theta)**20 + 3.18894183272014e+62*cos(theta)**18 - 1.51289333459281e+61*cos(theta)**16 + 5.49809812692724e+59*cos(theta)**14 - 1.48245016163075e+58*cos(theta)**12 + 2.84093236549447e+56*cos(theta)**10 - 3.64325894691511e+54*cos(theta)**8 + 2.85745799758048e+52*cos(theta)**6 - 1.18174441587282e+50*cos(theta)**4 + 1.92675719979264e+47*cos(theta)**2 - 5.16695414264586e+43)*cos(23*phi)

#@torch.jit.script
def Yl89_m24(theta, phi):
    return 1.02620272462204e-46*(1.0 - cos(theta)**2)**12*(7.39865437759198e+70*cos(theta)**65 - 8.69446390135102e+71*cos(theta)**63 + 4.85151085695387e+72*cos(theta)**61 - 1.71064833684501e+73*cos(theta)**59 + 4.2791217899734e+73*cos(theta)**57 - 8.08222293112136e+73*cos(theta)**55 + 1.19781447631888e+74*cos(theta)**53 - 1.42908082109734e+74*cos(theta)**51 + 1.39729911572017e+74*cos(theta)**49 - 1.13403986203376e+74*cos(theta)**47 + 7.71004459659432e+73*cos(theta)**45 - 4.41977078785661e+73*cos(theta)**43 + 2.14572743087878e+73*cos(theta)**41 - 8.84613621578982e+72*cos(theta)**39 + 3.1007506792338e+72*cos(theta)**37 - 9.23982081597187e+71*cos(theta)**35 + 2.33745467070717e+71*cos(theta)**33 - 5.00679945693057e+70*cos(theta)**31 + 9.04491743384893e+69*cos(theta)**29 - 1.37074896533881e+69*cos(theta)**27 + 1.73069383753209e+68*cos(theta)**25 - 1.80468596197298e+67*cos(theta)**23 + 1.53732507871773e+66*cos(theta)**21 - 1.05537190758654e+65*cos(theta)**19 + 5.74009529889626e+63*cos(theta)**17 - 2.4206293353485e+62*cos(theta)**15 + 7.69733737769814e+60*cos(theta)**13 - 1.7789401939569e+59*cos(theta)**11 + 2.84093236549447e+57*cos(theta)**9 - 2.91460715753209e+55*cos(theta)**7 + 1.71447479854829e+53*cos(theta)**5 - 4.72697766349128e+50*cos(theta)**3 + 3.85351439958529e+47*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl89_m25(theta, phi):
    return 1.19213121397702e-48*(1.0 - cos(theta)**2)**12.5*(4.80912534543478e+72*cos(theta)**64 - 5.47751225785115e+73*cos(theta)**62 + 2.95942162274186e+74*cos(theta)**60 - 1.00928251873855e+75*cos(theta)**58 + 2.43909942028484e+75*cos(theta)**56 - 4.44522261211675e+75*cos(theta)**54 + 6.34841672449009e+75*cos(theta)**52 - 7.28831218759641e+75*cos(theta)**50 + 6.84676566702884e+75*cos(theta)**48 - 5.32998735155868e+75*cos(theta)**46 + 3.46952006846744e+75*cos(theta)**44 - 1.90050143877834e+75*cos(theta)**42 + 8.79748246660298e+74*cos(theta)**40 - 3.44999312415803e+74*cos(theta)**38 + 1.14727775131651e+74*cos(theta)**36 - 3.23393728559015e+73*cos(theta)**34 + 7.71360041333366e+72*cos(theta)**32 - 1.55210783164848e+72*cos(theta)**30 + 2.62302605581619e+71*cos(theta)**28 - 3.70102220641478e+70*cos(theta)**26 + 4.32673459383023e+69*cos(theta)**24 - 4.15077771253786e+68*cos(theta)**22 + 3.22838266530723e+67*cos(theta)**20 - 2.00520662441443e+66*cos(theta)**18 + 9.75816200812364e+64*cos(theta)**16 - 3.63094400302275e+63*cos(theta)**14 + 1.00065385910076e+62*cos(theta)**12 - 1.95683421335259e+60*cos(theta)**10 + 2.55683912894503e+58*cos(theta)**8 - 2.04022501027246e+56*cos(theta)**6 + 8.57237399274144e+53*cos(theta)**4 - 1.41809329904739e+51*cos(theta)**2 + 3.85351439958529e+47)*cos(25*phi)

#@torch.jit.script
def Yl89_m26(theta, phi):
    return 1.38958511135867e-50*(1.0 - cos(theta)**2)**13*(3.07784022107826e+74*cos(theta)**63 - 3.39605759986771e+75*cos(theta)**61 + 1.77565297364512e+76*cos(theta)**59 - 5.85383860868361e+76*cos(theta)**57 + 1.36589567535951e+77*cos(theta)**55 - 2.40042021054304e+77*cos(theta)**53 + 3.30117669673484e+77*cos(theta)**51 - 3.6441560937982e+77*cos(theta)**49 + 3.28644752017384e+77*cos(theta)**47 - 2.45179418171699e+77*cos(theta)**45 + 1.52658883012567e+77*cos(theta)**43 - 7.98210604286905e+76*cos(theta)**41 + 3.51899298664119e+76*cos(theta)**39 - 1.31099738718005e+76*cos(theta)**37 + 4.13019990473943e+75*cos(theta)**35 - 1.09953867710065e+75*cos(theta)**33 + 2.46835213226677e+74*cos(theta)**31 - 4.65632349494543e+73*cos(theta)**29 + 7.34447295628533e+72*cos(theta)**27 - 9.62265773667843e+71*cos(theta)**25 + 1.03841630251926e+71*cos(theta)**23 - 9.1317109675833e+69*cos(theta)**21 + 6.45676533061446e+68*cos(theta)**19 - 3.60937192394597e+67*cos(theta)**17 + 1.56130592129978e+66*cos(theta)**15 - 5.08332160423185e+64*cos(theta)**13 + 1.20078463092091e+63*cos(theta)**11 - 1.95683421335259e+61*cos(theta)**9 + 2.04547130315602e+59*cos(theta)**7 - 1.22413500616348e+57*cos(theta)**5 + 3.42894959709658e+54*cos(theta)**3 - 2.83618659809477e+51*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl89_m27(theta, phi):
    return 1.62549591679572e-52*(1.0 - cos(theta)**2)**13.5*(1.93903933927931e+76*cos(theta)**62 - 2.0715951359193e+77*cos(theta)**60 + 1.04763525445062e+78*cos(theta)**58 - 3.33668800694966e+78*cos(theta)**56 + 7.5124262144773e+78*cos(theta)**54 - 1.27222271158781e+79*cos(theta)**52 + 1.68360011533477e+79*cos(theta)**50 - 1.78563648596112e+79*cos(theta)**48 + 1.54463033448171e+79*cos(theta)**46 - 1.10330738177265e+79*cos(theta)**44 + 6.5643319695404e+78*cos(theta)**42 - 3.27266347757631e+78*cos(theta)**40 + 1.37240726479007e+78*cos(theta)**38 - 4.85069033256619e+77*cos(theta)**36 + 1.4455699666588e+77*cos(theta)**34 - 3.62847763443215e+76*cos(theta)**32 + 7.65189161002699e+75*cos(theta)**30 - 1.35033381353417e+75*cos(theta)**28 + 1.98300769819704e+74*cos(theta)**26 - 2.40566443416961e+73*cos(theta)**24 + 2.38835749579429e+72*cos(theta)**22 - 1.91765930319249e+71*cos(theta)**20 + 1.22678541281675e+70*cos(theta)**18 - 6.13593227070815e+68*cos(theta)**16 + 2.34195888194967e+67*cos(theta)**14 - 6.60831808550141e+65*cos(theta)**12 + 1.320863094013e+64*cos(theta)**10 - 1.76115079201733e+62*cos(theta)**8 + 1.43182991220921e+60*cos(theta)**6 - 6.12067503081739e+57*cos(theta)**4 + 1.02868487912897e+55*cos(theta)**2 - 2.83618659809477e+51)*cos(27*phi)

#@torch.jit.script
def Yl89_m28(theta, phi):
    return 1.90852172201028e-54*(1.0 - cos(theta)**2)**14*(1.20220439035317e+78*cos(theta)**61 - 1.24295708155158e+79*cos(theta)**59 + 6.07628447581359e+79*cos(theta)**57 - 1.86854528389181e+80*cos(theta)**55 + 4.05671015581774e+80*cos(theta)**53 - 6.61555810025663e+80*cos(theta)**51 + 8.41800057667385e+80*cos(theta)**49 - 8.57105513261338e+80*cos(theta)**47 + 7.10529953861584e+80*cos(theta)**45 - 4.85455247979965e+80*cos(theta)**43 + 2.75701942720697e+80*cos(theta)**41 - 1.30906539103052e+80*cos(theta)**39 + 5.21514760620225e+79*cos(theta)**37 - 1.74624851972383e+79*cos(theta)**35 + 4.91493788663992e+78*cos(theta)**33 - 1.16111284301829e+78*cos(theta)**31 + 2.2955674830081e+77*cos(theta)**29 - 3.78093467789569e+76*cos(theta)**27 + 5.1558200153123e+75*cos(theta)**25 - 5.77359464200706e+74*cos(theta)**23 + 5.25438649074743e+73*cos(theta)**21 - 3.83531860638499e+72*cos(theta)**19 + 2.20821374307014e+71*cos(theta)**17 - 9.81749163313303e+69*cos(theta)**15 + 3.27874243472954e+68*cos(theta)**13 - 7.92998170260169e+66*cos(theta)**11 + 1.320863094013e+65*cos(theta)**9 - 1.40892063361387e+63*cos(theta)**7 + 8.59097947325529e+60*cos(theta)**5 - 2.44827001232696e+58*cos(theta)**3 + 2.05736975825795e+55*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl89_m29(theta, phi):
    return 2.24952687544693e-56*(1.0 - cos(theta)**2)**14.5*(7.33344678115433e+79*cos(theta)**60 - 7.33344678115433e+80*cos(theta)**58 + 3.46348215121375e+81*cos(theta)**56 - 1.0276999061405e+82*cos(theta)**54 + 2.1500563825834e+82*cos(theta)**52 - 3.37393463113088e+82*cos(theta)**50 + 4.12482028257019e+82*cos(theta)**48 - 4.02839591232829e+82*cos(theta)**46 + 3.19738479237713e+82*cos(theta)**44 - 2.08745756631385e+82*cos(theta)**42 + 1.13037796515486e+82*cos(theta)**40 - 5.10535502501904e+81*cos(theta)**38 + 1.92960461429483e+81*cos(theta)**36 - 6.1118698190334e+80*cos(theta)**34 + 1.62192950259117e+80*cos(theta)**32 - 3.5994498133567e+79*cos(theta)**30 + 6.65714570072348e+78*cos(theta)**28 - 1.02085236303184e+78*cos(theta)**26 + 1.28895500382808e+77*cos(theta)**24 - 1.32792676766162e+76*cos(theta)**22 + 1.10342116305696e+75*cos(theta)**20 - 7.28710535213147e+73*cos(theta)**18 + 3.75396336321924e+72*cos(theta)**16 - 1.47262374496996e+71*cos(theta)**14 + 4.26236516514841e+69*cos(theta)**12 - 8.72297987286186e+67*cos(theta)**10 + 1.1887767846117e+66*cos(theta)**8 - 9.86244443529707e+63*cos(theta)**6 + 4.29548973662764e+61*cos(theta)**4 - 7.34481003698087e+58*cos(theta)**2 + 2.05736975825795e+55)*cos(29*phi)

#@torch.jit.script
def Yl89_m30(theta, phi):
    return 2.66220858884676e-58*(1.0 - cos(theta)**2)**15*(4.4000680686926e+81*cos(theta)**59 - 4.25339913306951e+82*cos(theta)**57 + 1.9395500046797e+83*cos(theta)**55 - 5.54957949315867e+83*cos(theta)**53 + 1.11802931894337e+84*cos(theta)**51 - 1.68696731556544e+84*cos(theta)**49 + 1.97991373563369e+84*cos(theta)**47 - 1.85306211967101e+84*cos(theta)**45 + 1.40684930864594e+84*cos(theta)**43 - 8.76732177851816e+83*cos(theta)**41 + 4.52151186061943e+83*cos(theta)**39 - 1.94003490950724e+83*cos(theta)**37 + 6.94657661146139e+82*cos(theta)**35 - 2.07803573847136e+82*cos(theta)**33 + 5.19017440829175e+81*cos(theta)**31 - 1.07983494400701e+81*cos(theta)**29 + 1.86400079620257e+80*cos(theta)**27 - 2.65421614388277e+79*cos(theta)**25 + 3.09349200918738e+78*cos(theta)**23 - 2.92143888885557e+77*cos(theta)**21 + 2.20684232611392e+76*cos(theta)**19 - 1.31167896338367e+75*cos(theta)**17 + 6.00634138115079e+73*cos(theta)**15 - 2.06167324295794e+72*cos(theta)**13 + 5.11483819817809e+70*cos(theta)**11 - 8.72297987286186e+68*cos(theta)**9 + 9.5102142768936e+66*cos(theta)**7 - 5.91746666117824e+64*cos(theta)**5 + 1.71819589465106e+62*cos(theta)**3 - 1.46896200739617e+59*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl89_m31(theta, phi):
    return 3.1639196910608e-60*(1.0 - cos(theta)**2)**15.5*(2.59604016052863e+83*cos(theta)**58 - 2.42443750584962e+84*cos(theta)**56 + 1.06675250257383e+85*cos(theta)**54 - 2.9412771313741e+85*cos(theta)**52 + 5.70194952661119e+85*cos(theta)**50 - 8.26613984627066e+85*cos(theta)**48 + 9.30559455747834e+85*cos(theta)**46 - 8.33877953851955e+85*cos(theta)**44 + 6.04945202717753e+85*cos(theta)**42 - 3.59460192919245e+85*cos(theta)**40 + 1.76338962564158e+85*cos(theta)**38 - 7.17812916517677e+84*cos(theta)**36 + 2.43130181401149e+84*cos(theta)**34 - 6.85751793695548e+83*cos(theta)**32 + 1.60895406657044e+83*cos(theta)**30 - 3.13152133762033e+82*cos(theta)**28 + 5.03280214974695e+81*cos(theta)**26 - 6.63554035970693e+80*cos(theta)**24 + 7.11503162113098e+79*cos(theta)**22 - 6.1350216665967e+78*cos(theta)**20 + 4.19300041961645e+77*cos(theta)**18 - 2.22985423775223e+76*cos(theta)**16 + 9.00951207172619e+74*cos(theta)**14 - 2.68017521584532e+73*cos(theta)**12 + 5.6263220179959e+71*cos(theta)**10 - 7.85068188557567e+69*cos(theta)**8 + 6.65714999382552e+67*cos(theta)**6 - 2.95873333058912e+65*cos(theta)**4 + 5.15458768395317e+62*cos(theta)**2 - 1.46896200739617e+59)*cos(31*phi)

#@torch.jit.script
def Yl89_m32(theta, phi):
    return 3.77675462261663e-62*(1.0 - cos(theta)**2)**16*(1.50570329310661e+85*cos(theta)**57 - 1.35768500327579e+86*cos(theta)**55 + 5.7604635138987e+86*cos(theta)**53 - 1.52946410831453e+87*cos(theta)**51 + 2.85097476330559e+87*cos(theta)**49 - 3.96774712620992e+87*cos(theta)**47 + 4.28057349644004e+87*cos(theta)**45 - 3.6690629969486e+87*cos(theta)**43 + 2.54076985141456e+87*cos(theta)**41 - 1.43784077167698e+87*cos(theta)**39 + 6.70088057743799e+86*cos(theta)**37 - 2.58412649946364e+86*cos(theta)**35 + 8.26642616763906e+85*cos(theta)**33 - 2.19440573982575e+85*cos(theta)**31 + 4.82686219971133e+84*cos(theta)**29 - 8.76825974533691e+83*cos(theta)**27 + 1.30852855893421e+83*cos(theta)**25 - 1.59252968632966e+82*cos(theta)**23 + 1.56530695664882e+81*cos(theta)**21 - 1.22700433331934e+80*cos(theta)**19 + 7.54740075530961e+78*cos(theta)**17 - 3.56776678040357e+77*cos(theta)**15 + 1.26133169004167e+76*cos(theta)**13 - 3.21621025901438e+74*cos(theta)**11 + 5.6263220179959e+72*cos(theta)**9 - 6.28054550846054e+70*cos(theta)**7 + 3.99428999629531e+68*cos(theta)**5 - 1.18349333223565e+66*cos(theta)**3 + 1.03091753679063e+63*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl89_m33(theta, phi):
    return 4.52899067270559e-64*(1.0 - cos(theta)**2)**16.5*(8.58250877070766e+86*cos(theta)**56 - 7.46726751801684e+87*cos(theta)**54 + 3.05304566236631e+88*cos(theta)**52 - 7.8002669524041e+88*cos(theta)**50 + 1.39697763401974e+89*cos(theta)**48 - 1.86484114931866e+89*cos(theta)**46 + 1.92625807339802e+89*cos(theta)**44 - 1.5776970886879e+89*cos(theta)**42 + 1.04171563907997e+89*cos(theta)**40 - 5.60757900954021e+88*cos(theta)**38 + 2.47932581365206e+88*cos(theta)**36 - 9.04444274812273e+87*cos(theta)**34 + 2.72792063532089e+87*cos(theta)**32 - 6.80265779345983e+86*cos(theta)**30 + 1.39979003791629e+86*cos(theta)**28 - 2.36743013124097e+85*cos(theta)**26 + 3.27132139733552e+84*cos(theta)**24 - 3.66281827855823e+83*cos(theta)**22 + 3.28714460896251e+82*cos(theta)**20 - 2.33130823330675e+81*cos(theta)**18 + 1.28305812840263e+80*cos(theta)**16 - 5.35165017060535e+78*cos(theta)**14 + 1.63973119705417e+77*cos(theta)**12 - 3.53783128491582e+75*cos(theta)**10 + 5.06368981619631e+73*cos(theta)**8 - 4.39638185592238e+71*cos(theta)**6 + 1.99714499814766e+69*cos(theta)**4 - 3.55047999670695e+66*cos(theta)**2 + 1.03091753679063e+63)*cos(33*phi)

#@torch.jit.script
def Yl89_m34(theta, phi):
    return 5.45701134971043e-66*(1.0 - cos(theta)**2)**17*(4.80620491159629e+88*cos(theta)**55 - 4.03232445972909e+89*cos(theta)**53 + 1.58758374443048e+90*cos(theta)**51 - 3.90013347620205e+90*cos(theta)**49 + 6.70549264329476e+90*cos(theta)**47 - 8.57826928686584e+90*cos(theta)**45 + 8.47553552295128e+90*cos(theta)**43 - 6.62632777248918e+90*cos(theta)**41 + 4.16686255631988e+90*cos(theta)**39 - 2.13088002362528e+90*cos(theta)**37 + 8.92557292914741e+89*cos(theta)**35 - 3.07511053436173e+89*cos(theta)**33 + 8.72934603302684e+88*cos(theta)**31 - 2.04079733803795e+88*cos(theta)**29 + 3.9194121061656e+87*cos(theta)**27 - 6.15531834122651e+86*cos(theta)**25 + 7.85117135360524e+85*cos(theta)**23 - 8.0582002128281e+84*cos(theta)**21 + 6.57428921792503e+83*cos(theta)**19 - 4.19635481995214e+82*cos(theta)**17 + 2.05289300544421e+81*cos(theta)**15 - 7.4923102388475e+79*cos(theta)**13 + 1.967677436465e+78*cos(theta)**11 - 3.53783128491582e+76*cos(theta)**9 + 4.05095185295705e+74*cos(theta)**7 - 2.63782911355343e+72*cos(theta)**5 + 7.98857999259063e+69*cos(theta)**3 - 7.10095999341389e+66*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl89_m35(theta, phi):
    return 6.60788794510886e-68*(1.0 - cos(theta)**2)**17.5*(2.64341270137796e+90*cos(theta)**54 - 2.13713196365642e+91*cos(theta)**52 + 8.09667709659546e+91*cos(theta)**50 - 1.91106540333901e+92*cos(theta)**48 + 3.15158154234854e+92*cos(theta)**46 - 3.86022117908963e+92*cos(theta)**44 + 3.64448027486905e+92*cos(theta)**42 - 2.71679438672056e+92*cos(theta)**40 + 1.62507639696475e+92*cos(theta)**38 - 7.88425608741354e+91*cos(theta)**36 + 3.12395052520159e+91*cos(theta)**34 - 1.01478647633937e+91*cos(theta)**32 + 2.70609727023832e+90*cos(theta)**30 - 5.91831228031006e+89*cos(theta)**28 + 1.05824126866471e+89*cos(theta)**26 - 1.53882958530663e+88*cos(theta)**24 + 1.80576941132921e+87*cos(theta)**22 - 1.6922220446939e+86*cos(theta)**20 + 1.24911495140575e+85*cos(theta)**18 - 7.13380319391864e+83*cos(theta)**16 + 3.07933950816632e+82*cos(theta)**14 - 9.74000331050175e+80*cos(theta)**12 + 2.1644451801115e+79*cos(theta)**10 - 3.18404815642424e+77*cos(theta)**8 + 2.83566629706993e+75*cos(theta)**6 - 1.31891455677671e+73*cos(theta)**4 + 2.39657399777719e+70*cos(theta)**2 - 7.10095999341389e+66)*cos(35*phi)

#@torch.jit.script
def Yl89_m36(theta, phi):
    return 8.04286507778352e-70*(1.0 - cos(theta)**2)**18*(1.4274428587441e+92*cos(theta)**53 - 1.11130862110134e+93*cos(theta)**51 + 4.04833854829773e+93*cos(theta)**49 - 9.17311393602723e+93*cos(theta)**47 + 1.44972750948033e+94*cos(theta)**45 - 1.69849731879944e+94*cos(theta)**43 + 1.530681715445e+94*cos(theta)**41 - 1.08671775468823e+94*cos(theta)**39 + 6.17529030846607e+93*cos(theta)**37 - 2.83833219146888e+93*cos(theta)**35 + 1.06214317856854e+93*cos(theta)**33 - 3.24731672428599e+92*cos(theta)**31 + 8.11829181071497e+91*cos(theta)**29 - 1.65712743848682e+91*cos(theta)**27 + 2.75142729852825e+90*cos(theta)**25 - 3.69319100473591e+89*cos(theta)**23 + 3.97269270492425e+88*cos(theta)**21 - 3.3844440893878e+87*cos(theta)**19 + 2.24840691253036e+86*cos(theta)**17 - 1.14140851102698e+85*cos(theta)**15 + 4.31107531143285e+83*cos(theta)**13 - 1.16880039726021e+82*cos(theta)**11 + 2.1644451801115e+80*cos(theta)**9 - 2.54723852513939e+78*cos(theta)**7 + 1.70139977824196e+76*cos(theta)**5 - 5.27565822710685e+73*cos(theta)**3 + 4.79314799555438e+70*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl89_m37(theta, phi):
    return 9.84209552655039e-72*(1.0 - cos(theta)**2)**18.5*(7.56544715134372e+93*cos(theta)**52 - 5.66767396761682e+94*cos(theta)**50 + 1.98368588866589e+95*cos(theta)**48 - 4.3113635499328e+95*cos(theta)**46 + 6.52377379266147e+95*cos(theta)**44 - 7.30353847083757e+95*cos(theta)**42 + 6.2757950333245e+95*cos(theta)**40 - 4.23819924328408e+95*cos(theta)**38 + 2.28485741413244e+95*cos(theta)**36 - 9.93416267014106e+94*cos(theta)**34 + 3.50507248927619e+94*cos(theta)**32 - 1.00666818452866e+94*cos(theta)**30 + 2.35430462510734e+93*cos(theta)**28 - 4.4742440839144e+92*cos(theta)**26 + 6.87856824632063e+91*cos(theta)**24 - 8.49433931089259e+90*cos(theta)**22 + 8.34265468034093e+89*cos(theta)**20 - 6.43044376983682e+88*cos(theta)**18 + 3.82229175130161e+87*cos(theta)**16 - 1.71211276654047e+86*cos(theta)**14 + 5.6043979048627e+84*cos(theta)**12 - 1.28568043698623e+83*cos(theta)**10 + 1.94800066210035e+81*cos(theta)**8 - 1.78306696759757e+79*cos(theta)**6 + 8.5069988912098e+76*cos(theta)**4 - 1.58269746813206e+74*cos(theta)**2 + 4.79314799555438e+70)*cos(37*phi)

#@torch.jit.script
def Yl89_m38(theta, phi):
    return 1.21111126490024e-73*(1.0 - cos(theta)**2)**19*(3.93403251869874e+95*cos(theta)**51 - 2.83383698380841e+96*cos(theta)**49 + 9.52169226559626e+96*cos(theta)**47 - 1.98322723296909e+97*cos(theta)**45 + 2.87046046877105e+97*cos(theta)**43 - 3.06748615775178e+97*cos(theta)**41 + 2.5103180133298e+97*cos(theta)**39 - 1.61051571244795e+97*cos(theta)**37 + 8.2254866908768e+96*cos(theta)**35 - 3.37761530784796e+96*cos(theta)**33 + 1.12162319656838e+96*cos(theta)**31 - 3.02000455358597e+95*cos(theta)**29 + 6.59205295030055e+94*cos(theta)**27 - 1.16330346181774e+94*cos(theta)**25 + 1.65085637911695e+93*cos(theta)**23 - 1.86875464839637e+92*cos(theta)**21 + 1.66853093606819e+91*cos(theta)**19 - 1.15747987857063e+90*cos(theta)**17 + 6.11566680208257e+88*cos(theta)**15 - 2.39695787315666e+87*cos(theta)**13 + 6.72527748583524e+85*cos(theta)**11 - 1.28568043698623e+84*cos(theta)**9 + 1.55840052968028e+82*cos(theta)**7 - 1.06984018055854e+80*cos(theta)**5 + 3.40279955648392e+77*cos(theta)**3 - 3.16539493626411e+74*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl89_m39(theta, phi):
    return 1.49897355401543e-75*(1.0 - cos(theta)**2)**19.5*(2.00635658453636e+97*cos(theta)**50 - 1.38858012206612e+98*cos(theta)**48 + 4.47519536483024e+98*cos(theta)**46 - 8.92452254836089e+98*cos(theta)**44 + 1.23429800157155e+99*cos(theta)**42 - 1.25766932467823e+99*cos(theta)**40 + 9.79024025198622e+98*cos(theta)**38 - 5.95890813605741e+98*cos(theta)**36 + 2.87892034180688e+98*cos(theta)**34 - 1.11461305158983e+98*cos(theta)**32 + 3.47703190936198e+97*cos(theta)**30 - 8.75801320539931e+96*cos(theta)**28 + 1.77985429658115e+96*cos(theta)**26 - 2.90825865454436e+95*cos(theta)**24 + 3.79696967196899e+94*cos(theta)**22 - 3.92438476163237e+93*cos(theta)**20 + 3.17020877852955e+92*cos(theta)**18 - 1.96771579357007e+91*cos(theta)**16 + 9.17350020312386e+89*cos(theta)**14 - 3.11604523510366e+88*cos(theta)**12 + 7.39780523441877e+86*cos(theta)**10 - 1.15711239328761e+85*cos(theta)**8 + 1.0908803707762e+83*cos(theta)**6 - 5.34920090279272e+80*cos(theta)**4 + 1.02083986694518e+78*cos(theta)**2 - 3.16539493626411e+74)*cos(39*phi)

#@torch.jit.script
def Yl89_m40(theta, phi):
    return 1.86644034437968e-77*(1.0 - cos(theta)**2)**20*(1.00317829226818e+99*cos(theta)**49 - 6.66518458591738e+99*cos(theta)**47 + 2.05858986782191e+100*cos(theta)**45 - 3.92678992127879e+100*cos(theta)**43 + 5.18405160660051e+100*cos(theta)**41 - 5.03067729871292e+100*cos(theta)**39 + 3.72029129575477e+100*cos(theta)**37 - 2.14520692898067e+100*cos(theta)**35 + 9.78832916214339e+99*cos(theta)**33 - 3.56676176508745e+99*cos(theta)**31 + 1.04310957280859e+99*cos(theta)**29 - 2.45224369751181e+98*cos(theta)**27 + 4.62762117111099e+97*cos(theta)**25 - 6.97982077090647e+96*cos(theta)**23 + 8.35333327833177e+95*cos(theta)**21 - 7.84876952326475e+94*cos(theta)**19 + 5.7063758013532e+93*cos(theta)**17 - 3.14834526971211e+92*cos(theta)**15 + 1.28429002843734e+91*cos(theta)**13 - 3.7392542821244e+89*cos(theta)**11 + 7.39780523441877e+87*cos(theta)**9 - 9.25689914630086e+85*cos(theta)**7 + 6.54528222465717e+83*cos(theta)**5 - 2.13968036111709e+81*cos(theta)**3 + 2.04167973389035e+78*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl89_m41(theta, phi):
    return 2.33853781656624e-79*(1.0 - cos(theta)**2)**20.5*(4.91557363211407e+100*cos(theta)**48 - 3.13263675538117e+101*cos(theta)**46 + 9.2636544051986e+101*cos(theta)**44 - 1.68851966614988e+102*cos(theta)**42 + 2.12546115870621e+102*cos(theta)**40 - 1.96196414649804e+102*cos(theta)**38 + 1.37650777942926e+102*cos(theta)**36 - 7.50822425143234e+101*cos(theta)**34 + 3.23014862350732e+101*cos(theta)**32 - 1.10569614717711e+101*cos(theta)**30 + 3.02501776114492e+100*cos(theta)**28 - 6.62105798328187e+99*cos(theta)**26 + 1.15690529277775e+99*cos(theta)**24 - 1.60535877730849e+98*cos(theta)**22 + 1.75419998844967e+97*cos(theta)**20 - 1.4912662094203e+96*cos(theta)**18 + 9.70083886230044e+94*cos(theta)**16 - 4.72251790456816e+93*cos(theta)**14 + 1.66957703696854e+92*cos(theta)**12 - 4.11317971033684e+90*cos(theta)**10 + 6.65802471097689e+88*cos(theta)**8 - 6.4798294024106e+86*cos(theta)**6 + 3.27264111232859e+84*cos(theta)**4 - 6.41904108335126e+81*cos(theta)**2 + 2.04167973389035e+78)*cos(41*phi)

#@torch.jit.script
def Yl89_m42(theta, phi):
    return 2.94909070805061e-81*(1.0 - cos(theta)**2)**21*(2.35947534341475e+102*cos(theta)**47 - 1.44101290747534e+103*cos(theta)**45 + 4.07600793828739e+103*cos(theta)**43 - 7.0917825978295e+103*cos(theta)**41 + 8.50184463482484e+103*cos(theta)**39 - 7.45546375669255e+103*cos(theta)**37 + 4.95542800594535e+103*cos(theta)**35 - 2.552796245487e+103*cos(theta)**33 + 1.03364755952234e+103*cos(theta)**31 - 3.31708844153133e+102*cos(theta)**29 + 8.47004973120578e+101*cos(theta)**27 - 1.72147507565329e+101*cos(theta)**25 + 2.77657270266659e+100*cos(theta)**23 - 3.53178931007867e+99*cos(theta)**21 + 3.50839997689934e+98*cos(theta)**19 - 2.68427917695654e+97*cos(theta)**17 + 1.55213421796807e+96*cos(theta)**15 - 6.61152506639543e+94*cos(theta)**13 + 2.00349244436225e+93*cos(theta)**11 - 4.11317971033684e+91*cos(theta)**9 + 5.32641976878151e+89*cos(theta)**7 - 3.88789764144636e+87*cos(theta)**5 + 1.30905644493143e+85*cos(theta)**3 - 1.28380821667025e+82*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl89_m43(theta, phi):
    return 3.74414135178388e-83*(1.0 - cos(theta)**2)**21.5*(1.10895341140493e+104*cos(theta)**46 - 6.48455808363902e+104*cos(theta)**44 + 1.75268341346358e+105*cos(theta)**42 - 2.90763086511009e+105*cos(theta)**40 + 3.31571940758169e+105*cos(theta)**38 - 2.75852158997624e+105*cos(theta)**36 + 1.73439980208087e+105*cos(theta)**34 - 8.42422761010709e+104*cos(theta)**32 + 3.20430743451926e+104*cos(theta)**30 - 9.61955648044085e+103*cos(theta)**28 + 2.28691342742556e+103*cos(theta)**26 - 4.30368768913322e+102*cos(theta)**24 + 6.38611721613316e+101*cos(theta)**22 - 7.41675755116521e+100*cos(theta)**20 + 6.66595995610875e+99*cos(theta)**18 - 4.56327460082613e+98*cos(theta)**16 + 2.3282013269521e+97*cos(theta)**14 - 8.59498258631406e+95*cos(theta)**12 + 2.20384168879848e+94*cos(theta)**10 - 3.70186173930315e+92*cos(theta)**8 + 3.72849383814706e+90*cos(theta)**6 - 1.94394882072318e+88*cos(theta)**4 + 3.9271693347943e+85*cos(theta)**2 - 1.28380821667025e+82)*cos(43*phi)

#@torch.jit.script
def Yl89_m44(theta, phi):
    return 4.78682444162545e-85*(1.0 - cos(theta)**2)**22*(5.1011856924627e+105*cos(theta)**45 - 2.85320555680117e+106*cos(theta)**43 + 7.36127033654702e+106*cos(theta)**41 - 1.16305234604404e+107*cos(theta)**39 + 1.25997337488104e+107*cos(theta)**37 - 9.93067772391447e+106*cos(theta)**35 + 5.89695932707496e+106*cos(theta)**33 - 2.69575283523427e+106*cos(theta)**31 + 9.61292230355778e+105*cos(theta)**29 - 2.69347581452344e+105*cos(theta)**27 + 5.94597491130645e+104*cos(theta)**25 - 1.03288504539197e+104*cos(theta)**23 + 1.4049457875493e+103*cos(theta)**21 - 1.48335151023304e+102*cos(theta)**19 + 1.19987279209958e+101*cos(theta)**17 - 7.3012393613218e+99*cos(theta)**15 + 3.25948185773295e+98*cos(theta)**13 - 1.03139791035769e+97*cos(theta)**11 + 2.20384168879848e+95*cos(theta)**9 - 2.96148939144252e+93*cos(theta)**7 + 2.23709630288824e+91*cos(theta)**5 - 7.77579528289272e+88*cos(theta)**3 + 7.85433866958861e+85*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl89_m45(theta, phi):
    return 6.16437206669811e-87*(1.0 - cos(theta)**2)**22.5*(2.29553356160821e+107*cos(theta)**44 - 1.2268783894245e+108*cos(theta)**42 + 3.01812083798428e+108*cos(theta)**40 - 4.53590414957175e+108*cos(theta)**38 + 4.66190148705985e+108*cos(theta)**36 - 3.47573720337007e+108*cos(theta)**34 + 1.94599657793474e+108*cos(theta)**32 - 8.35683378922623e+107*cos(theta)**30 + 2.78774746803176e+107*cos(theta)**28 - 7.27238469921328e+106*cos(theta)**26 + 1.48649372782661e+106*cos(theta)**24 - 2.37563560440154e+105*cos(theta)**22 + 2.95038615385352e+104*cos(theta)**20 - 2.81836786944278e+103*cos(theta)**18 + 2.03978374656928e+102*cos(theta)**16 - 1.09518590419827e+101*cos(theta)**14 + 4.23732641505283e+99*cos(theta)**12 - 1.13453770139346e+98*cos(theta)**10 + 1.98345751991863e+96*cos(theta)**8 - 2.07304257400977e+94*cos(theta)**6 + 1.11854815144412e+92*cos(theta)**4 - 2.33273858486782e+89*cos(theta)**2 + 7.85433866958861e+85)*cos(45*phi)

#@torch.jit.script
def Yl89_m46(theta, phi):
    return 7.99826190890544e-89*(1.0 - cos(theta)**2)**23*(1.01003476710761e+109*cos(theta)**43 - 5.15288923558291e+109*cos(theta)**41 + 1.20724833519371e+110*cos(theta)**39 - 1.72364357683726e+110*cos(theta)**37 + 1.67828453534155e+110*cos(theta)**35 - 1.18175064914582e+110*cos(theta)**33 + 6.22718904939116e+109*cos(theta)**31 - 2.50705013676787e+109*cos(theta)**29 + 7.80569291048892e+108*cos(theta)**27 - 1.89082002179545e+108*cos(theta)**25 + 3.56758494678387e+107*cos(theta)**23 - 5.22639832968338e+106*cos(theta)**21 + 5.90077230770704e+105*cos(theta)**19 - 5.07306216499701e+104*cos(theta)**17 + 3.26365399451085e+103*cos(theta)**15 - 1.53326026587758e+102*cos(theta)**13 + 5.0847916980634e+100*cos(theta)**11 - 1.13453770139346e+99*cos(theta)**9 + 1.5867660159349e+97*cos(theta)**7 - 1.24382554440586e+95*cos(theta)**5 + 4.47419260577647e+92*cos(theta)**3 - 4.66547716973563e+89*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl89_m47(theta, phi):
    return 1.04590427793794e-90*(1.0 - cos(theta)**2)**23.5*(4.34314949856274e+110*cos(theta)**42 - 2.11268458658899e+111*cos(theta)**40 + 4.70826850725547e+111*cos(theta)**38 - 6.37748123429788e+111*cos(theta)**36 + 5.87399587369541e+111*cos(theta)**34 - 3.89977714218121e+111*cos(theta)**32 + 1.93042860531126e+111*cos(theta)**30 - 7.27044539662682e+110*cos(theta)**28 + 2.10753708583201e+110*cos(theta)**26 - 4.72705005448863e+109*cos(theta)**24 + 8.20544537760291e+108*cos(theta)**22 - 1.09754364923351e+108*cos(theta)**20 + 1.12114673846434e+107*cos(theta)**18 - 8.62420568049491e+105*cos(theta)**16 + 4.89548099176627e+104*cos(theta)**14 - 1.99323834564085e+103*cos(theta)**12 + 5.59327086786974e+101*cos(theta)**10 - 1.02108393125411e+100*cos(theta)**8 + 1.11073621115443e+98*cos(theta)**6 - 6.2191277220293e+95*cos(theta)**4 + 1.34225778173294e+93*cos(theta)**2 - 4.66547716973563e+89)*cos(47*phi)

#@torch.jit.script
def Yl89_m48(theta, phi):
    return 1.37881821026187e-92*(1.0 - cos(theta)**2)**24*(1.82412278939635e+112*cos(theta)**41 - 8.45073834635598e+112*cos(theta)**39 + 1.78914203275708e+113*cos(theta)**37 - 2.29589324434724e+113*cos(theta)**35 + 1.99715859705644e+113*cos(theta)**33 - 1.24792868549799e+113*cos(theta)**31 + 5.79128581593378e+112*cos(theta)**29 - 2.03572471105551e+112*cos(theta)**27 + 5.47959642316322e+111*cos(theta)**25 - 1.13449201307727e+111*cos(theta)**23 + 1.80519798307264e+110*cos(theta)**21 - 2.19508729846702e+109*cos(theta)**19 + 2.01806412923581e+108*cos(theta)**17 - 1.37987290887919e+107*cos(theta)**15 + 6.85367338847277e+105*cos(theta)**13 - 2.39188601476902e+104*cos(theta)**11 + 5.59327086786974e+102*cos(theta)**9 - 8.16867145003288e+100*cos(theta)**7 + 6.66441726692659e+98*cos(theta)**5 - 2.48765108881172e+96*cos(theta)**3 + 2.68451556346588e+93*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl89_m49(theta, phi):
    return 1.83305518164533e-94*(1.0 - cos(theta)**2)**24.5*(7.47890343652504e+113*cos(theta)**40 - 3.29578795507883e+114*cos(theta)**38 + 6.61982552120119e+114*cos(theta)**36 - 8.03562635521532e+114*cos(theta)**34 + 6.59062337028625e+114*cos(theta)**32 - 3.86857892504376e+114*cos(theta)**30 + 1.6794728866208e+114*cos(theta)**28 - 5.49645671984988e+113*cos(theta)**26 + 1.36989910579081e+113*cos(theta)**24 - 2.60933163007772e+112*cos(theta)**22 + 3.79091576445254e+111*cos(theta)**20 - 4.17066586708734e+110*cos(theta)**18 + 3.43070901970087e+109*cos(theta)**16 - 2.06980936331878e+108*cos(theta)**14 + 8.90977540501461e+106*cos(theta)**12 - 2.63107461624592e+105*cos(theta)**10 + 5.03394378108276e+103*cos(theta)**8 - 5.71807001502302e+101*cos(theta)**6 + 3.3322086334633e+99*cos(theta)**4 - 7.46295326643516e+96*cos(theta)**2 + 2.68451556346588e+93)*cos(49*phi)

#@torch.jit.script
def Yl89_m50(theta, phi):
    return 2.45831846480124e-96*(1.0 - cos(theta)**2)**25*(2.99156137461002e+115*cos(theta)**39 - 1.25239942292996e+116*cos(theta)**37 + 2.38313718763243e+116*cos(theta)**35 - 2.73211296077321e+116*cos(theta)**33 + 2.1089994784916e+116*cos(theta)**31 - 1.16057367751313e+116*cos(theta)**29 + 4.70252408253823e+115*cos(theta)**27 - 1.42907874716097e+115*cos(theta)**25 + 3.28775785389793e+114*cos(theta)**23 - 5.74052958617099e+113*cos(theta)**21 + 7.58183152890509e+112*cos(theta)**19 - 7.50719856075721e+111*cos(theta)**17 + 5.4891344315214e+110*cos(theta)**15 - 2.89773310864629e+109*cos(theta)**13 + 1.06917304860175e+108*cos(theta)**11 - 2.63107461624592e+106*cos(theta)**9 + 4.02715502486621e+104*cos(theta)**7 - 3.43084200901381e+102*cos(theta)**5 + 1.33288345338532e+100*cos(theta)**3 - 1.49259065328703e+97*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl89_m51(theta, phi):
    return 3.32691589418808e-98*(1.0 - cos(theta)**2)**25.5*(1.16670893609791e+117*cos(theta)**38 - 4.63387786484084e+117*cos(theta)**36 + 8.34098015671351e+117*cos(theta)**34 - 9.01597277055159e+117*cos(theta)**32 + 6.53789838332396e+117*cos(theta)**30 - 3.36566366478808e+117*cos(theta)**28 + 1.26968150228532e+117*cos(theta)**26 - 3.57269686790242e+116*cos(theta)**24 + 7.56184306396525e+115*cos(theta)**22 - 1.20551121309591e+115*cos(theta)**20 + 1.44054799049197e+114*cos(theta)**18 - 1.27622375532873e+113*cos(theta)**16 + 8.2337016472821e+111*cos(theta)**14 - 3.76705304124018e+110*cos(theta)**12 + 1.17609035346193e+109*cos(theta)**10 - 2.36796715462133e+107*cos(theta)**8 + 2.81900851740635e+105*cos(theta)**6 - 1.71542100450691e+103*cos(theta)**4 + 3.99865036015596e+100*cos(theta)**2 - 1.49259065328703e+97)*cos(51*phi)

#@torch.jit.script
def Yl89_m52(theta, phi):
    return 4.54506885839889e-100*(1.0 - cos(theta)**2)**26*(4.43349395717204e+118*cos(theta)**37 - 1.6681960313427e+119*cos(theta)**35 + 2.83593325328259e+119*cos(theta)**33 - 2.88511128657651e+119*cos(theta)**31 + 1.96136951499719e+119*cos(theta)**29 - 9.42385826140661e+118*cos(theta)**27 + 3.30117190594184e+118*cos(theta)**25 - 8.57447248296581e+117*cos(theta)**23 + 1.66360547407235e+117*cos(theta)**21 - 2.41102242619182e+116*cos(theta)**19 + 2.59298638288554e+115*cos(theta)**17 - 2.04195800852596e+114*cos(theta)**15 + 1.15271823061949e+113*cos(theta)**13 - 4.52046364948821e+111*cos(theta)**11 + 1.17609035346193e+110*cos(theta)**9 - 1.89437372369707e+108*cos(theta)**7 + 1.69140511044381e+106*cos(theta)**5 - 6.86168401802762e+103*cos(theta)**3 + 7.99730072031191e+100*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl89_m53(theta, phi):
    return 6.2704026980257e-102*(1.0 - cos(theta)**2)**26.5*(1.64039276415366e+120*cos(theta)**36 - 5.83868610969945e+120*cos(theta)**34 + 9.35857973583255e+120*cos(theta)**32 - 8.94384498838718e+120*cos(theta)**30 + 5.68797159349185e+120*cos(theta)**28 - 2.54444173057978e+120*cos(theta)**26 + 8.25292976485459e+119*cos(theta)**24 - 1.97212867108214e+119*cos(theta)**22 + 3.49357149555194e+118*cos(theta)**20 - 4.58094260976445e+117*cos(theta)**18 + 4.40807685090542e+116*cos(theta)**16 - 3.06293701278894e+115*cos(theta)**14 + 1.49853369980534e+114*cos(theta)**12 - 4.97251001443703e+112*cos(theta)**10 + 1.05848131811574e+111*cos(theta)**8 - 1.32606160658795e+109*cos(theta)**6 + 8.45702555221904e+106*cos(theta)**4 - 2.05850520540829e+104*cos(theta)**2 + 7.99730072031191e+100)*cos(53*phi)

#@torch.jit.script
def Yl89_m54(theta, phi):
    return 8.73929025958482e-104*(1.0 - cos(theta)**2)**27*(5.90541395095316e+121*cos(theta)**35 - 1.98515327729781e+122*cos(theta)**33 + 2.99474551546642e+122*cos(theta)**31 - 2.68315349651615e+122*cos(theta)**29 + 1.59263204617772e+122*cos(theta)**27 - 6.61554849950744e+121*cos(theta)**25 + 1.9807031435651e+121*cos(theta)**23 - 4.3386830763807e+120*cos(theta)**21 + 6.98714299110389e+119*cos(theta)**19 - 8.24569669757602e+118*cos(theta)**17 + 7.05292296144867e+117*cos(theta)**15 - 4.28811181790452e+116*cos(theta)**13 + 1.79824043976641e+115*cos(theta)**11 - 4.97251001443703e+113*cos(theta)**9 + 8.46785054492588e+111*cos(theta)**7 - 7.95636963952768e+109*cos(theta)**5 + 3.38281022088762e+107*cos(theta)**3 - 4.11701041081657e+104*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl89_m55(theta, phi):
    return 1.23100805769927e-105*(1.0 - cos(theta)**2)**27.5*(2.06689488283361e+123*cos(theta)**34 - 6.55100581508279e+123*cos(theta)**32 + 9.28371109794589e+123*cos(theta)**30 - 7.78114513989685e+123*cos(theta)**28 + 4.30010652467984e+123*cos(theta)**26 - 1.65388712487686e+123*cos(theta)**24 + 4.55561723019973e+122*cos(theta)**22 - 9.11123446039947e+121*cos(theta)**20 + 1.32755716830974e+121*cos(theta)**18 - 1.40176843858792e+120*cos(theta)**16 + 1.0579384442173e+119*cos(theta)**14 - 5.57454536327587e+117*cos(theta)**12 + 1.97806448374305e+116*cos(theta)**10 - 4.47525901299333e+114*cos(theta)**8 + 5.92749538144812e+112*cos(theta)**6 - 3.97818481976384e+110*cos(theta)**4 + 1.01484306626629e+108*cos(theta)**2 - 4.11701041081657e+104)*cos(55*phi)

#@torch.jit.script
def Yl89_m56(theta, phi):
    return 1.75322411673177e-107*(1.0 - cos(theta)**2)**28*(7.02744260163426e+124*cos(theta)**33 - 2.09632186082649e+125*cos(theta)**31 + 2.78511332938377e+125*cos(theta)**29 - 2.17872063917112e+125*cos(theta)**27 + 1.11802769641676e+125*cos(theta)**25 - 3.96932909970446e+124*cos(theta)**23 + 1.00223579064394e+124*cos(theta)**21 - 1.82224689207989e+123*cos(theta)**19 + 2.38960290295753e+122*cos(theta)**17 - 2.24282950174068e+121*cos(theta)**15 + 1.48111382190422e+120*cos(theta)**13 - 6.68945443593105e+118*cos(theta)**11 + 1.97806448374305e+117*cos(theta)**9 - 3.58020721039466e+115*cos(theta)**7 + 3.55649722886887e+113*cos(theta)**5 - 1.59127392790554e+111*cos(theta)**3 + 2.02968613253257e+108*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl89_m57(theta, phi):
    return 2.52582954060277e-109*(1.0 - cos(theta)**2)**28.5*(2.31905605853931e+126*cos(theta)**32 - 6.49859776856212e+126*cos(theta)**30 + 8.07682865521293e+126*cos(theta)**28 - 5.88254572576202e+126*cos(theta)**26 + 2.79506924104189e+126*cos(theta)**24 - 9.12945692932027e+125*cos(theta)**22 + 2.10469516035228e+125*cos(theta)**20 - 3.4622690949518e+124*cos(theta)**18 + 4.0623249350278e+123*cos(theta)**16 - 3.36424425261101e+122*cos(theta)**14 + 1.92544796847549e+121*cos(theta)**12 - 7.35839987952415e+119*cos(theta)**10 + 1.78025803536875e+118*cos(theta)**8 - 2.50614504727626e+116*cos(theta)**6 + 1.77824861443444e+114*cos(theta)**4 - 4.7738217837166e+111*cos(theta)**2 + 2.02968613253257e+108)*cos(57*phi)

#@torch.jit.script
def Yl89_m58(theta, phi):
    return 3.68273425697931e-111*(1.0 - cos(theta)**2)**29*(7.42097938732578e+127*cos(theta)**31 - 1.94957933056864e+128*cos(theta)**29 + 2.26151202345962e+128*cos(theta)**27 - 1.52946188869812e+128*cos(theta)**25 + 6.70816617850054e+127*cos(theta)**23 - 2.00848052445046e+127*cos(theta)**21 + 4.20939032070455e+126*cos(theta)**19 - 6.23208437091324e+125*cos(theta)**17 + 6.49971989604448e+124*cos(theta)**15 - 4.70994195365542e+123*cos(theta)**13 + 2.31053756217058e+122*cos(theta)**11 - 7.35839987952415e+120*cos(theta)**9 + 1.424206428295e+119*cos(theta)**7 - 1.50368702836576e+117*cos(theta)**5 + 7.11299445773774e+114*cos(theta)**3 - 9.54764356743321e+111*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl89_m59(theta, phi):
    return 5.4369917879787e-113*(1.0 - cos(theta)**2)**29.5*(2.30050361007099e+129*cos(theta)**30 - 5.65378005864905e+129*cos(theta)**28 + 6.10608246334097e+129*cos(theta)**26 - 3.82365472174531e+129*cos(theta)**24 + 1.54287822105513e+129*cos(theta)**22 - 4.21780910134596e+128*cos(theta)**20 + 7.99784160933865e+127*cos(theta)**18 - 1.05945434305525e+127*cos(theta)**16 + 9.74957984406672e+125*cos(theta)**14 - 6.12292453975205e+124*cos(theta)**12 + 2.54159131838764e+123*cos(theta)**10 - 6.62255989157174e+121*cos(theta)**8 + 9.96944499806498e+119*cos(theta)**6 - 7.51843514182879e+117*cos(theta)**4 + 2.13389833732132e+115*cos(theta)**2 - 9.54764356743321e+111)*cos(59*phi)

#@torch.jit.script
def Yl89_m60(theta, phi):
    return 8.13214128810101e-115*(1.0 - cos(theta)**2)**30*(6.90151083021298e+130*cos(theta)**29 - 1.58305841642173e+131*cos(theta)**27 + 1.58758144046865e+131*cos(theta)**25 - 9.17677133218874e+130*cos(theta)**23 + 3.39433208632128e+130*cos(theta)**21 - 8.43561820269193e+129*cos(theta)**19 + 1.43961148968096e+129*cos(theta)**17 - 1.6951269488884e+128*cos(theta)**15 + 1.36494117816934e+127*cos(theta)**13 - 7.34750944770246e+125*cos(theta)**11 + 2.54159131838764e+124*cos(theta)**9 - 5.29804791325739e+122*cos(theta)**7 + 5.98166699883899e+120*cos(theta)**5 - 3.00737405673152e+118*cos(theta)**3 + 4.26779667464265e+115*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl89_m61(theta, phi):
    return 1.23299208012332e-116*(1.0 - cos(theta)**2)**30.5*(2.00143814076176e+132*cos(theta)**28 - 4.27425772433868e+132*cos(theta)**26 + 3.96895360117163e+132*cos(theta)**24 - 2.11065740640341e+132*cos(theta)**22 + 7.12809738127468e+131*cos(theta)**20 - 1.60276745851147e+131*cos(theta)**18 + 2.44733953245763e+130*cos(theta)**16 - 2.5426904233326e+129*cos(theta)**14 + 1.77442353162014e+128*cos(theta)**12 - 8.0822603924727e+126*cos(theta)**10 + 2.28743218654888e+125*cos(theta)**8 - 3.70863353928017e+123*cos(theta)**6 + 2.99083349941949e+121*cos(theta)**4 - 9.02212217019455e+118*cos(theta)**2 + 4.26779667464265e+115)*cos(61*phi)

#@torch.jit.script
def Yl89_m62(theta, phi):
    return 1.89623779144393e-118*(1.0 - cos(theta)**2)**31*(5.60402679413294e+133*cos(theta)**27 - 1.11130700832806e+134*cos(theta)**25 + 9.52548864281192e+133*cos(theta)**23 - 4.6434462940875e+133*cos(theta)**21 + 1.42561947625494e+133*cos(theta)**19 - 2.88498142532064e+132*cos(theta)**17 + 3.91574325193221e+131*cos(theta)**15 - 3.55976659266564e+130*cos(theta)**13 + 2.12930823794417e+129*cos(theta)**11 - 8.0822603924727e+127*cos(theta)**9 + 1.8299457492391e+126*cos(theta)**7 - 2.2251801235681e+124*cos(theta)**5 + 1.1963333997678e+122*cos(theta)**3 - 1.80442443403891e+119*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl89_m63(theta, phi):
    return 2.95998235141899e-120*(1.0 - cos(theta)**2)**31.5*(1.51308723441589e+135*cos(theta)**26 - 2.77826752082014e+135*cos(theta)**24 + 2.19086238784674e+135*cos(theta)**22 - 9.75123721758376e+134*cos(theta)**20 + 2.70867700488438e+134*cos(theta)**18 - 4.90446842304509e+133*cos(theta)**16 + 5.87361487789831e+132*cos(theta)**14 - 4.62769657046533e+131*cos(theta)**12 + 2.34223906173859e+130*cos(theta)**10 - 7.27403435322543e+128*cos(theta)**8 + 1.28096202446737e+127*cos(theta)**6 - 1.11259006178405e+125*cos(theta)**4 + 3.58900019930339e+122*cos(theta)**2 - 1.80442443403891e+119)*cos(63*phi)

#@torch.jit.script
def Yl89_m64(theta, phi):
    return 4.69306676041125e-122*(1.0 - cos(theta)**2)**32*(3.93402680948132e+136*cos(theta)**25 - 6.66784204996834e+136*cos(theta)**23 + 4.81989725326283e+136*cos(theta)**21 - 1.95024744351675e+136*cos(theta)**19 + 4.87561860879188e+135*cos(theta)**17 - 7.84714947687214e+134*cos(theta)**15 + 8.22306082905763e+133*cos(theta)**13 - 5.5532358845584e+132*cos(theta)**11 + 2.34223906173859e+131*cos(theta)**9 - 5.81922748258035e+129*cos(theta)**7 + 7.68577214680423e+127*cos(theta)**5 - 4.45036024713621e+125*cos(theta)**3 + 7.17800039860678e+122*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl89_m65(theta, phi):
    return 7.56356193448717e-124*(1.0 - cos(theta)**2)**32.5*(9.8350670237033e+137*cos(theta)**24 - 1.53360367149272e+138*cos(theta)**22 + 1.01217842318519e+138*cos(theta)**20 - 3.70547014268183e+137*cos(theta)**18 + 8.2885516349462e+136*cos(theta)**16 - 1.17707242153082e+136*cos(theta)**14 + 1.06899790777749e+135*cos(theta)**12 - 6.10855947301424e+133*cos(theta)**10 + 2.10801515556473e+132*cos(theta)**8 - 4.07345923780624e+130*cos(theta)**6 + 3.84288607340211e+128*cos(theta)**4 - 1.33510807414086e+126*cos(theta)**2 + 7.17800039860678e+122)*cos(65*phi)

#@torch.jit.script
def Yl89_m66(theta, phi):
    return 1.24009483179719e-125*(1.0 - cos(theta)**2)**33*(2.36041608568879e+139*cos(theta)**23 - 3.37392807728398e+139*cos(theta)**21 + 2.02435684637039e+139*cos(theta)**19 - 6.66984625682729e+138*cos(theta)**17 + 1.32616826159139e+138*cos(theta)**15 - 1.64790139014315e+137*cos(theta)**13 + 1.28279748933299e+136*cos(theta)**11 - 6.10855947301424e+134*cos(theta)**9 + 1.68641212445178e+133*cos(theta)**7 - 2.44407554268374e+131*cos(theta)**5 + 1.53715442936085e+129*cos(theta)**3 - 2.67021614828172e+126*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl89_m67(theta, phi):
    return 2.07027806328931e-127*(1.0 - cos(theta)**2)**33.5*(5.42895699708422e+140*cos(theta)**22 - 7.08524896229636e+140*cos(theta)**20 + 3.84627800810374e+140*cos(theta)**18 - 1.13387386366064e+140*cos(theta)**16 + 1.98925239238709e+139*cos(theta)**14 - 2.14227180718609e+138*cos(theta)**12 + 1.41107723826629e+137*cos(theta)**10 - 5.49770352571282e+135*cos(theta)**8 + 1.18048848711625e+134*cos(theta)**6 - 1.22203777134187e+132*cos(theta)**4 + 4.61146328808254e+129*cos(theta)**2 - 2.67021614828172e+126)*cos(67*phi)

#@torch.jit.script
def Yl89_m68(theta, phi):
    return 3.52263392866995e-129*(1.0 - cos(theta)**2)**34*(1.19437053935853e+142*cos(theta)**21 - 1.41704979245927e+142*cos(theta)**19 + 6.92330041458673e+141*cos(theta)**17 - 1.81419818185702e+141*cos(theta)**15 + 2.78495334934192e+140*cos(theta)**13 - 2.57072616862331e+139*cos(theta)**11 + 1.41107723826629e+138*cos(theta)**9 - 4.39816282057025e+136*cos(theta)**7 + 7.08293092269749e+134*cos(theta)**5 - 4.88815108536749e+132*cos(theta)**3 + 9.22292657616507e+129*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl89_m69(theta, phi):
    return 6.11546271788306e-131*(1.0 - cos(theta)**2)**34.5*(2.50817813265291e+143*cos(theta)**20 - 2.69239460567262e+143*cos(theta)**18 + 1.17696107047974e+143*cos(theta)**16 - 2.72129727278554e+142*cos(theta)**14 + 3.6204393541445e+141*cos(theta)**12 - 2.82779878548564e+140*cos(theta)**10 + 1.26996951443966e+139*cos(theta)**8 - 3.07871397439918e+137*cos(theta)**6 + 3.54146546134875e+135*cos(theta)**4 - 1.46644532561025e+133*cos(theta)**2 + 9.22292657616507e+129)*cos(69*phi)

#@torch.jit.script
def Yl89_m70(theta, phi):
    return 1.08446555619479e-132*(1.0 - cos(theta)**2)**35*(5.01635626530582e+144*cos(theta)**19 - 4.84631029021071e+144*cos(theta)**17 + 1.88313771276759e+144*cos(theta)**15 - 3.80981618189975e+143*cos(theta)**13 + 4.3445272249734e+142*cos(theta)**11 - 2.82779878548564e+141*cos(theta)**9 + 1.01597561155173e+140*cos(theta)**7 - 1.84722838463951e+138*cos(theta)**5 + 1.4165861845395e+136*cos(theta)**3 - 2.93289065122049e+133*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl89_m71(theta, phi):
    return 1.96688501270417e-134*(1.0 - cos(theta)**2)**35.5*(9.53107690408106e+145*cos(theta)**18 - 8.23872749335821e+145*cos(theta)**16 + 2.82470656915139e+145*cos(theta)**14 - 4.95276103646967e+144*cos(theta)**12 + 4.77897994747074e+143*cos(theta)**10 - 2.54501890693708e+142*cos(theta)**8 + 7.1118292808621e+140*cos(theta)**6 - 9.23614192319753e+138*cos(theta)**4 + 4.2497585536185e+136*cos(theta)**2 - 2.93289065122049e+133)*cos(71*phi)

#@torch.jit.script
def Yl89_m72(theta, phi):
    return 3.65367388073676e-136*(1.0 - cos(theta)**2)**36*(1.71559384273459e+147*cos(theta)**17 - 1.31819639893731e+147*cos(theta)**15 + 3.95458919681194e+146*cos(theta)**13 - 5.94331324376361e+145*cos(theta)**11 + 4.77897994747074e+144*cos(theta)**9 - 2.03601512554966e+143*cos(theta)**7 + 4.26709756851726e+141*cos(theta)**5 - 3.69445676927901e+139*cos(theta)**3 + 8.49951710723699e+136*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl89_m73(theta, phi):
    return 6.96222112353882e-138*(1.0 - cos(theta)**2)**36.5*(2.91650953264881e+148*cos(theta)**16 - 1.97729459840597e+148*cos(theta)**14 + 5.14096595585552e+147*cos(theta)**12 - 6.53764456813997e+146*cos(theta)**10 + 4.30108195272366e+145*cos(theta)**8 - 1.42521058788476e+144*cos(theta)**6 + 2.13354878425863e+142*cos(theta)**4 - 1.1083370307837e+140*cos(theta)**2 + 8.49951710723699e+136)*cos(73*phi)

#@torch.jit.script
def Yl89_m74(theta, phi):
    return 1.36330811253467e-139*(1.0 - cos(theta)**2)**37*(4.66641525223809e+149*cos(theta)**15 - 2.76821243776836e+149*cos(theta)**13 + 6.16915914702663e+148*cos(theta)**11 - 6.53764456813997e+147*cos(theta)**9 + 3.44086556217893e+146*cos(theta)**7 - 8.55126352730859e+144*cos(theta)**5 + 8.53419513703452e+142*cos(theta)**3 - 2.21667406156741e+140*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl89_m75(theta, phi):
    return 2.74869444967131e-141*(1.0 - cos(theta)**2)**37.5*(6.99962287835713e+150*cos(theta)**14 - 3.59867616909887e+150*cos(theta)**12 + 6.78607506172929e+149*cos(theta)**10 - 5.88388011132597e+148*cos(theta)**8 + 2.40860589352525e+147*cos(theta)**6 - 4.27563176365429e+145*cos(theta)**4 + 2.56025854111036e+143*cos(theta)**2 - 2.21667406156741e+140)*cos(75*phi)

#@torch.jit.script
def Yl89_m76(theta, phi):
    return 5.71900499082503e-143*(1.0 - cos(theta)**2)**38*(9.79947202969999e+151*cos(theta)**13 - 4.31841140291864e+151*cos(theta)**11 + 6.78607506172929e+150*cos(theta)**9 - 4.70710408906078e+149*cos(theta)**7 + 1.44516353611515e+148*cos(theta)**5 - 1.71025270546172e+146*cos(theta)**3 + 5.12051708222071e+143*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl89_m77(theta, phi):
    return 1.23110403680912e-144*(1.0 - cos(theta)**2)**38.5*(1.273931363861e+153*cos(theta)**12 - 4.7502525432105e+152*cos(theta)**10 + 6.10746755555636e+151*cos(theta)**8 - 3.29497286234254e+150*cos(theta)**6 + 7.22581768057576e+148*cos(theta)**4 - 5.13075811638515e+146*cos(theta)**2 + 5.12051708222071e+143)*cos(77*phi)

#@torch.jit.script
def Yl89_m78(theta, phi):
    return 2.75008360374433e-146*(1.0 - cos(theta)**2)**39*(1.5287176366332e+154*cos(theta)**11 - 4.7502525432105e+153*cos(theta)**9 + 4.88597404444509e+152*cos(theta)**7 - 1.97698371740553e+151*cos(theta)**5 + 2.8903270722303e+149*cos(theta)**3 - 1.02615162327703e+147*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl89_m79(theta, phi):
    return 6.39727342639955e-148*(1.0 - cos(theta)**2)**39.5*(1.68158940029652e+155*cos(theta)**10 - 4.27522728888945e+154*cos(theta)**8 + 3.42018183111156e+153*cos(theta)**6 - 9.88491858702763e+151*cos(theta)**4 + 8.67098121669091e+149*cos(theta)**2 - 1.02615162327703e+147)*cos(79*phi)

#@torch.jit.script
def Yl89_m80(theta, phi):
    return 1.55615037248401e-149*(1.0 - cos(theta)**2)**40*(1.68158940029652e+156*cos(theta)**9 - 3.42018183111156e+155*cos(theta)**7 + 2.05210909866694e+154*cos(theta)**5 - 3.95396743481105e+152*cos(theta)**3 + 1.73419624333818e+150*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl89_m81(theta, phi):
    return 3.97837617692343e-151*(1.0 - cos(theta)**2)**40.5*(1.51343046026687e+157*cos(theta)**8 - 2.39412728177809e+156*cos(theta)**6 + 1.02605454933347e+155*cos(theta)**4 - 1.18619023044332e+153*cos(theta)**2 + 1.73419624333818e+150)*cos(81*phi)

#@torch.jit.script
def Yl89_m82(theta, phi):
    return 1.07562972868882e-152*(1.0 - cos(theta)**2)**41*(1.21074436821349e+158*cos(theta)**7 - 1.43647636906686e+157*cos(theta)**5 + 4.10421819733387e+155*cos(theta)**3 - 2.37238046088663e+153*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl89_m83(theta, phi):
    return 3.0999133430702e-154*(1.0 - cos(theta)**2)**41.5*(8.47521057749445e+158*cos(theta)**6 - 7.18238184533428e+157*cos(theta)**4 + 1.23126545920016e+156*cos(theta)**2 - 2.37238046088663e+153)*cos(83*phi)

#@torch.jit.script
def Yl89_m84(theta, phi):
    return 9.62167928580298e-156*(1.0 - cos(theta)**2)**42*(5.08512634649667e+159*cos(theta)**5 - 2.87295273813371e+158*cos(theta)**3 + 2.46253091840032e+156*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl89_m85(theta, phi):
    return 3.26205478362367e-157*(1.0 - cos(theta)**2)**42.5*(2.54256317324833e+160*cos(theta)**4 - 8.61885821440113e+158*cos(theta)**2 + 2.46253091840032e+156)*cos(85*phi)

#@torch.jit.script
def Yl89_m86(theta, phi):
    return 1.23294081721955e-158*(1.0 - cos(theta)**2)**43*(1.01702526929933e+161*cos(theta)**3 - 1.72377164288023e+159*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl89_m87(theta, phi):
    return 5.36568618484204e-160*(1.0 - cos(theta)**2)**43.5*(3.051075807898e+161*cos(theta)**2 - 1.72377164288023e+159)*cos(87*phi)

#@torch.jit.script
def Yl89_m88(theta, phi):
    return 17.4022992356252*(1.0 - cos(theta)**2)**44*cos(88*phi)*cos(theta)

#@torch.jit.script
def Yl89_m89(theta, phi):
    return 1.30435747384896*(1.0 - cos(theta)**2)**44.5*cos(89*phi)

#@torch.jit.script
def Yl90_m_minus_90(theta, phi):
    return 1.30797567074086*(1.0 - cos(theta)**2)**45*sin(90*phi)

#@torch.jit.script
def Yl90_m_minus_89(theta, phi):
    return 17.5483350761546*(1.0 - cos(theta)**2)**44.5*sin(89*phi)*cos(theta)

#@torch.jit.script
def Yl90_m_minus_88(theta, phi):
    return 3.03977477475515e-162*(1.0 - cos(theta)**2)**44*(5.46142569613742e+163*cos(theta)**2 - 3.051075807898e+161)*sin(88*phi)

#@torch.jit.script
def Yl90_m_minus_87(theta, phi):
    return 7.02444530463506e-161*(1.0 - cos(theta)**2)**43.5*(1.82047523204581e+163*cos(theta)**3 - 3.051075807898e+161*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl90_m_minus_86(theta, phi):
    return 1.86908332990183e-159*(1.0 - cos(theta)**2)**43*(4.55118808011452e+162*cos(theta)**4 - 1.525537903949e+161*cos(theta)**2 + 4.30942910720057e+158)*sin(86*phi)

#@torch.jit.script
def Yl90_m_minus_85(theta, phi):
    return 5.54459718538947e-158*(1.0 - cos(theta)**2)**42.5*(9.10237616022904e+161*cos(theta)**5 - 5.08512634649667e+160*cos(theta)**3 + 4.30942910720057e+158*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl90_m_minus_84(theta, phi):
    return 1.79665483178156e-156*(1.0 - cos(theta)**2)**42*(1.51706269337151e+161*cos(theta)**6 - 1.27128158662417e+160*cos(theta)**4 + 2.15471455360028e+158*cos(theta)**2 - 4.10421819733387e+155)*sin(84*phi)

#@torch.jit.script
def Yl90_m_minus_83(theta, phi):
    return 6.27029962282424e-155*(1.0 - cos(theta)**2)**41.5*(2.16723241910215e+160*cos(theta)**7 - 2.54256317324833e+159*cos(theta)**5 + 7.18238184533428e+157*cos(theta)**3 - 4.10421819733387e+155*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl90_m_minus_82(theta, phi):
    return 2.33268630094631e-153*(1.0 - cos(theta)**2)**41*(2.70904052387769e+159*cos(theta)**8 - 4.23760528874722e+158*cos(theta)**6 + 1.79559546133357e+157*cos(theta)**4 - 2.05210909866694e+155*cos(theta)**2 + 2.96547557610829e+152)*sin(82*phi)

#@torch.jit.script
def Yl90_m_minus_81(theta, phi):
    return 9.17786820896213e-152*(1.0 - cos(theta)**2)**40.5*(3.01004502653077e+158*cos(theta)**9 - 6.05372184106746e+157*cos(theta)**7 + 3.59119092266714e+156*cos(theta)**5 - 6.84036366222312e+154*cos(theta)**3 + 2.96547557610829e+152*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl90_m_minus_80(theta, phi):
    return 3.79524548497779e-150*(1.0 - cos(theta)**2)**40*(3.01004502653077e+157*cos(theta)**10 - 7.56715230133433e+156*cos(theta)**8 + 5.98531820444523e+155*cos(theta)**6 - 1.71009091555578e+154*cos(theta)**4 + 1.48273778805415e+152*cos(theta)**2 - 1.73419624333818e+149)*sin(80*phi)

#@torch.jit.script
def Yl90_m_minus_79(theta, phi):
    return 1.64119685305045e-148*(1.0 - cos(theta)**2)**39.5*(2.73640456957342e+156*cos(theta)**11 - 8.40794700148259e+155*cos(theta)**9 + 8.5504545777789e+154*cos(theta)**7 - 3.42018183111156e+153*cos(theta)**5 + 4.94245929351382e+151*cos(theta)**3 - 1.73419624333818e+149*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl90_m_minus_78(theta, phi):
    return 7.39085447023436e-147*(1.0 - cos(theta)**2)**39*(2.28033714131119e+155*cos(theta)**12 - 8.40794700148259e+154*cos(theta)**10 + 1.06880682222236e+154*cos(theta)**8 - 5.7003030518526e+152*cos(theta)**6 + 1.23561482337845e+151*cos(theta)**4 - 8.67098121669091e+148*cos(theta)**2 + 8.55126352730859e+145)*sin(78*phi)

#@torch.jit.script
def Yl90_m_minus_77(theta, phi):
    return 3.45398914132051e-145*(1.0 - cos(theta)**2)**38.5*(1.7541054933163e+154*cos(theta)**13 - 7.64358818316599e+153*cos(theta)**11 + 1.18756313580263e+153*cos(theta)**9 - 8.14329007407515e+151*cos(theta)**7 + 2.47122964675691e+150*cos(theta)**5 - 2.8903270722303e+148*cos(theta)**3 + 8.55126352730859e+145*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl90_m_minus_76(theta, phi):
    return 1.67010286601711e-143*(1.0 - cos(theta)**2)**38*(1.25293249522593e+153*cos(theta)**14 - 6.36965681930499e+152*cos(theta)**12 + 1.18756313580263e+152*cos(theta)**10 - 1.01791125925939e+151*cos(theta)**8 + 4.11871607792818e+149*cos(theta)**6 - 7.22581768057576e+147*cos(theta)**4 + 4.27563176365429e+145*cos(theta)**2 - 3.65751220158622e+142)*sin(76*phi)

#@torch.jit.script
def Yl90_m_minus_75(theta, phi):
    return 8.33379656691093e-142*(1.0 - cos(theta)**2)**37.5*(8.35288330150618e+151*cos(theta)**15 - 4.89973601484999e+151*cos(theta)**13 + 1.07960285072966e+151*cos(theta)**11 - 1.13101251028821e+150*cos(theta)**9 + 5.88388011132597e+148*cos(theta)**7 - 1.44516353611515e+147*cos(theta)**5 + 1.42521058788476e+145*cos(theta)**3 - 3.65751220158622e+142*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl90_m_minus_74(theta, phi):
    return 4.28198220661008e-140*(1.0 - cos(theta)**2)**37*(5.22055206344136e+150*cos(theta)**16 - 3.49981143917857e+150*cos(theta)**14 + 8.99669042274716e+149*cos(theta)**12 - 1.13101251028821e+149*cos(theta)**10 + 7.35485013915747e+147*cos(theta)**8 - 2.40860589352525e+146*cos(theta)**6 + 3.56302646971191e+144*cos(theta)**4 - 1.82875610079311e+142*cos(theta)**2 + 1.38542128847963e+139)*sin(74*phi)

#@torch.jit.script
def Yl90_m_minus_73(theta, phi):
    return 2.26095148267755e-138*(1.0 - cos(theta)**2)**36.5*(3.07091297849492e+149*cos(theta)**17 - 2.33320762611904e+149*cos(theta)**15 + 6.92053109442089e+148*cos(theta)**13 - 1.0281931911711e+148*cos(theta)**11 + 8.17205571017496e+146*cos(theta)**9 - 3.44086556217893e+145*cos(theta)**7 + 7.12605293942382e+143*cos(theta)**5 - 6.09585366931037e+141*cos(theta)**3 + 1.38542128847963e+139*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl90_m_minus_72(theta, phi):
    return 1.22467625579179e-136*(1.0 - cos(theta)**2)**36*(1.70606276583051e+148*cos(theta)**18 - 1.4582547663244e+148*cos(theta)**16 + 4.94323649601492e+147*cos(theta)**14 - 8.56827659309254e+146*cos(theta)**12 + 8.17205571017496e+145*cos(theta)**10 - 4.30108195272366e+144*cos(theta)**8 + 1.18767548990397e+143*cos(theta)**6 - 1.52396341732759e+141*cos(theta)**4 + 6.92710644239815e+138*cos(theta)**2 - 4.721953948465e+135)*sin(72*phi)

#@torch.jit.script
def Yl90_m_minus_71(theta, phi):
    return 6.79447031427588e-135*(1.0 - cos(theta)**2)**35.5*(8.97927771489742e+146*cos(theta)**19 - 8.57796921367296e+146*cos(theta)**17 + 3.29549099734328e+146*cos(theta)**15 - 6.59098199468657e+145*cos(theta)**13 + 7.42914155470451e+144*cos(theta)**11 - 4.77897994747074e+143*cos(theta)**9 + 1.69667927129139e+142*cos(theta)**7 - 3.04792683465519e+140*cos(theta)**5 + 2.30903548079938e+138*cos(theta)**3 - 4.721953948465e+135*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl90_m_minus_70(theta, phi):
    return 3.85552515829005e-133*(1.0 - cos(theta)**2)**35*(4.48963885744871e+145*cos(theta)**20 - 4.76553845204053e+145*cos(theta)**18 + 2.05968187333955e+145*cos(theta)**16 - 4.70784428191898e+144*cos(theta)**14 + 6.19095129558709e+143*cos(theta)**12 - 4.77897994747074e+142*cos(theta)**10 + 2.12084908911423e+141*cos(theta)**8 - 5.07987805775864e+139*cos(theta)**6 + 5.77258870199846e+137*cos(theta)**4 - 2.3609769742325e+135*cos(theta)**2 + 1.46644532561025e+132)*sin(70*phi)

#@torch.jit.script
def Yl90_m_minus_69(theta, phi):
    return 2.23487470492771e-131*(1.0 - cos(theta)**2)**34.5*(2.13792326545177e+144*cos(theta)**21 - 2.50817813265291e+144*cos(theta)**19 + 1.21157757255268e+144*cos(theta)**17 - 3.13856285461265e+143*cos(theta)**15 + 4.76227022737469e+142*cos(theta)**13 - 4.3445272249734e+141*cos(theta)**11 + 2.3564989879047e+140*cos(theta)**9 - 7.25696865394092e+138*cos(theta)**7 + 1.15451774039969e+137*cos(theta)**5 - 7.86992324744166e+134*cos(theta)**3 + 1.46644532561025e+132*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl90_m_minus_68(theta, phi):
    return 1.32179188920369e-129*(1.0 - cos(theta)**2)**34*(9.71783302478076e+142*cos(theta)**22 - 1.25408906632646e+143*cos(theta)**20 + 6.73098651418154e+142*cos(theta)**18 - 1.96160178413291e+142*cos(theta)**16 + 3.40162159098192e+141*cos(theta)**14 - 3.6204393541445e+140*cos(theta)**12 + 2.3564989879047e+139*cos(theta)**10 - 9.07121081742615e+137*cos(theta)**8 + 1.92419623399949e+136*cos(theta)**6 - 1.96748081186041e+134*cos(theta)**4 + 7.33222662805123e+131*cos(theta)**2 - 4.19223935280231e+128)*sin(68*phi)

#@torch.jit.script
def Yl90_m_minus_67(theta, phi):
    return 7.96811409510254e-128*(1.0 - cos(theta)**2)**33.5*(4.22514479338294e+141*cos(theta)**23 - 5.97185269679265e+141*cos(theta)**21 + 3.54262448114818e+141*cos(theta)**19 - 1.15388340243112e+141*cos(theta)**17 + 2.26774772732128e+140*cos(theta)**15 - 2.78495334934192e+139*cos(theta)**13 + 2.14227180718609e+138*cos(theta)**11 - 1.00791231304735e+137*cos(theta)**9 + 2.74885176285641e+135*cos(theta)**7 - 3.93496162372083e+133*cos(theta)**5 + 2.44407554268374e+131*cos(theta)**3 - 4.19223935280231e+128*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl90_m_minus_66(theta, phi):
    return 4.89115010536715e-126*(1.0 - cos(theta)**2)**33*(1.76047699724289e+140*cos(theta)**24 - 2.71447849854211e+140*cos(theta)**22 + 1.77131224057409e+140*cos(theta)**20 - 6.41046334683956e+139*cos(theta)**18 + 1.4173423295758e+139*cos(theta)**16 - 1.98925239238709e+138*cos(theta)**14 + 1.78522650598841e+137*cos(theta)**12 - 1.00791231304735e+136*cos(theta)**10 + 3.43606470357051e+134*cos(theta)**8 - 6.55826937286805e+132*cos(theta)**6 + 6.11018885670936e+130*cos(theta)**4 - 2.09611967640115e+128*cos(theta)**2 + 1.11259006178405e+125)*sin(66*phi)

#@torch.jit.script
def Yl90_m_minus_65(theta, phi):
    return 3.05452226178839e-124*(1.0 - cos(theta)**2)**32.5*(7.04190798897157e+138*cos(theta)**25 - 1.1802080428444e+139*cos(theta)**23 + 8.43482019320995e+138*cos(theta)**21 - 3.37392807728398e+138*cos(theta)**19 + 8.33730782103412e+137*cos(theta)**17 - 1.32616826159139e+137*cos(theta)**15 + 1.37325115845262e+136*cos(theta)**13 - 9.16283920952136e+134*cos(theta)**11 + 3.8178496706339e+133*cos(theta)**9 - 9.36895624695435e+131*cos(theta)**7 + 1.22203777134187e+130*cos(theta)**5 - 6.98706558800384e+127*cos(theta)**3 + 1.11259006178405e+125*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl90_m_minus_64(theta, phi):
    return 1.93908040520439e-122*(1.0 - cos(theta)**2)**32*(2.70842614960445e+137*cos(theta)**26 - 4.91753351185165e+137*cos(theta)**24 + 3.8340091787318e+137*cos(theta)**22 - 1.68696403864199e+137*cos(theta)**20 + 4.63183767835229e+136*cos(theta)**18 - 8.2885516349462e+135*cos(theta)**16 + 9.80893684609017e+134*cos(theta)**14 - 7.6356993412678e+133*cos(theta)**12 + 3.8178496706339e+132*cos(theta)**10 - 1.17111953086929e+131*cos(theta)**8 + 2.03672961890312e+129*cos(theta)**6 - 1.74676639700096e+127*cos(theta)**4 + 5.56295030892026e+124*cos(theta)**2 - 2.76076938407953e+121)*sin(64*phi)

#@torch.jit.script
def Yl90_m_minus_63(theta, phi):
    return 1.25036860391688e-120*(1.0 - cos(theta)**2)**31.5*(1.0031207961498e+136*cos(theta)**27 - 1.96701340474066e+136*cos(theta)**25 + 1.66696051249209e+136*cos(theta)**23 - 8.03316208877138e+135*cos(theta)**21 + 2.43780930439594e+135*cos(theta)**19 - 4.87561860879188e+134*cos(theta)**17 + 6.53929123072678e+133*cos(theta)**15 - 5.87361487789831e+132*cos(theta)**13 + 3.470772427849e+131*cos(theta)**11 - 1.3012439231881e+130*cos(theta)**9 + 2.90961374129017e+128*cos(theta)**7 - 3.49353279400192e+126*cos(theta)**5 + 1.85431676964009e+124*cos(theta)**3 - 2.76076938407953e+121*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl90_m_minus_62(theta, phi):
    return 8.18394668238493e-119*(1.0 - cos(theta)**2)**31*(3.58257427196356e+134*cos(theta)**28 - 7.56543617207947e+134*cos(theta)**26 + 6.94566880205036e+134*cos(theta)**24 - 3.6514373130779e+134*cos(theta)**22 + 1.21890465219797e+134*cos(theta)**20 - 2.70867700488438e+133*cos(theta)**18 + 4.08705701920424e+132*cos(theta)**16 - 4.19543919849879e+131*cos(theta)**14 + 2.89231035654083e+130*cos(theta)**12 - 1.3012439231881e+129*cos(theta)**10 + 3.63701717661272e+127*cos(theta)**8 - 5.82255465666987e+125*cos(theta)**6 + 4.63579192410022e+123*cos(theta)**4 - 1.38038469203977e+121*cos(theta)**2 + 6.44437297871039e+117)*sin(62*phi)

#@torch.jit.script
def Yl90_m_minus_61(theta, phi):
    return 5.43354895429245e-117*(1.0 - cos(theta)**2)**30.5*(1.23537043860812e+133*cos(theta)**29 - 2.80201339706647e+133*cos(theta)**27 + 2.77826752082014e+133*cos(theta)**25 - 1.58758144046865e+133*cos(theta)**23 + 5.80430786760938e+132*cos(theta)**21 - 1.42561947625494e+132*cos(theta)**19 + 2.4041511877672e+131*cos(theta)**17 - 2.79695946566586e+130*cos(theta)**15 + 2.22485412041603e+129*cos(theta)**13 - 1.1829490210801e+128*cos(theta)**11 + 4.04113019623635e+126*cos(theta)**9 - 8.3179352238141e+124*cos(theta)**7 + 9.27158384820043e+122*cos(theta)**5 - 4.60128230679922e+120*cos(theta)**3 + 6.44437297871039e+117*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl90_m_minus_60(theta, phi):
    return 3.65706504865961e-115*(1.0 - cos(theta)**2)**30*(4.11790146202708e+131*cos(theta)**30 - 1.00071907038088e+132*cos(theta)**28 + 1.06856443108467e+132*cos(theta)**26 - 6.61492266861939e+131*cos(theta)**24 + 2.63832175800426e+131*cos(theta)**22 - 7.12809738127468e+130*cos(theta)**20 + 1.33563954875956e+130*cos(theta)**18 - 1.74809966604116e+129*cos(theta)**16 + 1.58918151458288e+128*cos(theta)**14 - 9.8579085090008e+126*cos(theta)**12 + 4.04113019623635e+125*cos(theta)**10 - 1.03974190297676e+124*cos(theta)**8 + 1.54526397470007e+122*cos(theta)**6 - 1.15032057669981e+120*cos(theta)**4 + 3.2221864893552e+117*cos(theta)**2 - 1.42259889154755e+114)*sin(60*phi)

#@torch.jit.script
def Yl90_m_minus_59(theta, phi):
    return 2.49378588056581e-113*(1.0 - cos(theta)**2)**29.5*(1.32835531033131e+130*cos(theta)**31 - 3.45075541510649e+130*cos(theta)**29 + 3.95764604105433e+130*cos(theta)**27 - 2.64596906744775e+130*cos(theta)**25 + 1.14709641652359e+130*cos(theta)**23 - 3.39433208632128e+129*cos(theta)**21 + 7.02968183557661e+128*cos(theta)**19 - 1.02829392120068e+128*cos(theta)**17 + 1.05945434305525e+127*cos(theta)**15 - 7.58300654538523e+125*cos(theta)**13 + 3.67375472385123e+124*cos(theta)**11 - 1.15526878108529e+123*cos(theta)**9 + 2.20751996385725e+121*cos(theta)**7 - 2.30064115339961e+119*cos(theta)**5 + 1.0740621631184e+117*cos(theta)**3 - 1.42259889154755e+114*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl90_m_minus_58(theta, phi):
    return 1.72197675682181e-111*(1.0 - cos(theta)**2)**29*(4.15111034478536e+128*cos(theta)**32 - 1.1502518050355e+129*cos(theta)**30 + 1.41344501466226e+129*cos(theta)**28 - 1.01768041055683e+129*cos(theta)**26 + 4.77956840218164e+128*cos(theta)**24 - 1.54287822105513e+128*cos(theta)**22 + 3.5148409177883e+127*cos(theta)**20 - 5.71274400667047e+126*cos(theta)**18 + 6.62158964409531e+125*cos(theta)**16 - 5.41643324670373e+124*cos(theta)**14 + 3.06146226987602e+123*cos(theta)**12 - 1.15526878108529e+122*cos(theta)**10 + 2.75939995482156e+120*cos(theta)**8 - 3.83440192233268e+118*cos(theta)**6 + 2.685155407796e+116*cos(theta)**4 - 7.11299445773774e+113*cos(theta)**2 + 2.98363861482288e+110)*sin(58*phi)

#@torch.jit.script
def Yl90_m_minus_57(theta, phi):
    return 1.20341414720173e-109*(1.0 - cos(theta)**2)**28.5*(1.25791222569253e+127*cos(theta)**33 - 3.71048969366289e+127*cos(theta)**31 + 4.87394832642159e+127*cos(theta)**29 - 3.76918670576603e+127*cos(theta)**27 + 1.91182736087266e+127*cos(theta)**25 - 6.70816617850054e+126*cos(theta)**23 + 1.67373377037538e+126*cos(theta)**21 - 3.00670737193182e+125*cos(theta)**19 + 3.89505273182077e+124*cos(theta)**17 - 3.61095549780249e+123*cos(theta)**15 + 2.35497097682771e+122*cos(theta)**13 - 1.05024434644117e+121*cos(theta)**11 + 3.06599994980173e+119*cos(theta)**9 - 5.47771703190383e+117*cos(theta)**7 + 5.370310815592e+115*cos(theta)**5 - 2.37099815257925e+113*cos(theta)**3 + 2.98363861482288e+110*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl90_m_minus_56(theta, phi):
    return 8.5077209857911e-108*(1.0 - cos(theta)**2)**28*(3.69974184027216e+125*cos(theta)**34 - 1.15952802926965e+126*cos(theta)**32 + 1.62464944214053e+126*cos(theta)**30 - 1.34613810920215e+126*cos(theta)**28 + 7.35318215720252e+125*cos(theta)**26 - 2.79506924104189e+125*cos(theta)**24 + 7.60788077443356e+124*cos(theta)**22 - 1.50335368596591e+124*cos(theta)**20 + 2.16391818434487e+123*cos(theta)**18 - 2.25684718612656e+122*cos(theta)**16 + 1.68212212630551e+121*cos(theta)**14 - 8.75203622034312e+119*cos(theta)**12 + 3.06599994980173e+118*cos(theta)**10 - 6.84714628987979e+116*cos(theta)**8 + 8.95051802598666e+114*cos(theta)**6 - 5.92749538144812e+112*cos(theta)**4 + 1.49181930741144e+110*cos(theta)**2 - 5.96966509568403e+106)*sin(56*phi)

#@torch.jit.script
def Yl90_m_minus_55(theta, phi):
    return 6.08168173009143e-106*(1.0 - cos(theta)**2)**27.5*(1.05706909722062e+124*cos(theta)**35 - 3.51372130081713e+124*cos(theta)**33 + 5.24080465206623e+124*cos(theta)**31 - 4.64185554897295e+124*cos(theta)**29 + 2.7234007989639e+124*cos(theta)**27 - 1.11802769641676e+124*cos(theta)**25 + 3.30777424975372e+123*cos(theta)**23 - 7.15882707602815e+122*cos(theta)**21 + 1.13890430754993e+122*cos(theta)**19 - 1.32755716830974e+121*cos(theta)**17 + 1.12141475087034e+120*cos(theta)**15 - 6.73233555411009e+118*cos(theta)**13 + 2.78727268163794e+117*cos(theta)**11 - 7.60794032208866e+115*cos(theta)**9 + 1.27864543228381e+114*cos(theta)**7 - 1.18549907628962e+112*cos(theta)**5 + 4.9727310247048e+109*cos(theta)**3 - 5.96966509568403e+106*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl90_m_minus_54(theta, phi):
    return 4.39398874506055e-104*(1.0 - cos(theta)**2)**27*(2.93630304783504e+122*cos(theta)**36 - 1.0334474414168e+123*cos(theta)**34 + 1.6377514537707e+123*cos(theta)**32 - 1.54728518299098e+123*cos(theta)**30 + 9.72643142487106e+122*cos(theta)**28 - 4.30010652467984e+122*cos(theta)**26 + 1.37823927073072e+122*cos(theta)**24 - 3.25401230728552e+121*cos(theta)**22 + 5.69452153774967e+120*cos(theta)**20 - 7.37531760172077e+119*cos(theta)**18 + 7.00884219293961e+118*cos(theta)**16 - 4.80881111007864e+117*cos(theta)**14 + 2.32272723469828e+116*cos(theta)**12 - 7.60794032208866e+114*cos(theta)**10 + 1.59830679035476e+113*cos(theta)**8 - 1.97583179381604e+111*cos(theta)**6 + 1.2431827561762e+109*cos(theta)**4 - 2.98483254784202e+106*cos(theta)**2 + 1.1436140030046e+103)*sin(54*phi)

#@torch.jit.script
def Yl90_m_minus_53(theta, phi):
    return 3.20731081164077e-102*(1.0 - cos(theta)**2)**26.5*(7.93595418333796e+120*cos(theta)**37 - 2.95270697547658e+121*cos(theta)**35 + 4.96288319324454e+121*cos(theta)**33 - 4.99124252577736e+121*cos(theta)**31 + 3.35394187064519e+121*cos(theta)**29 - 1.59263204617772e+121*cos(theta)**27 + 5.51295708292287e+120*cos(theta)**25 - 1.41478795968936e+120*cos(theta)**23 + 2.71167692273794e+119*cos(theta)**21 - 3.88174610616883e+118*cos(theta)**19 + 4.12284834878801e+117*cos(theta)**17 - 3.20587407338576e+116*cos(theta)**15 + 1.78671325746022e+115*cos(theta)**13 - 6.91630938371696e+113*cos(theta)**11 + 1.77589643372751e+112*cos(theta)**9 - 2.82261684830863e+110*cos(theta)**7 + 2.4863655123524e+108*cos(theta)**5 - 9.94944182614005e+105*cos(theta)**3 + 1.1436140030046e+103*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl90_m_minus_52(theta, phi):
    return 2.36429065301138e-100*(1.0 - cos(theta)**2)**26*(2.08840899561525e+119*cos(theta)**38 - 8.20196382076828e+119*cos(theta)**36 + 1.45967152742486e+120*cos(theta)**34 - 1.55976328930543e+120*cos(theta)**32 + 1.1179806235484e+120*cos(theta)**30 - 5.68797159349185e+119*cos(theta)**28 + 2.12036810881649e+119*cos(theta)**26 - 5.89494983203899e+118*cos(theta)**24 + 1.23258041942634e+118*cos(theta)**22 - 1.94087305308441e+117*cos(theta)**20 + 2.29047130488223e+116*cos(theta)**18 - 2.0036712958661e+115*cos(theta)**16 + 1.27622375532873e+114*cos(theta)**14 - 5.76359115309747e+112*cos(theta)**12 + 1.77589643372751e+111*cos(theta)**10 - 3.52827106038578e+109*cos(theta)**8 + 4.14394252058733e+107*cos(theta)**6 - 2.48736045653501e+105*cos(theta)**4 + 5.71807001502302e+102*cos(theta)**2 - 2.10455282113471e+99)*sin(52*phi)

#@torch.jit.script
def Yl90_m_minus_51(theta, phi):
    return 1.75945166675974e-98*(1.0 - cos(theta)**2)**25.5*(5.35489486055193e+117*cos(theta)**39 - 2.21674697858602e+118*cos(theta)**37 + 4.17049007835675e+118*cos(theta)**35 - 4.72655542213765e+118*cos(theta)**33 + 3.60638910822064e+118*cos(theta)**31 - 1.96136951499719e+118*cos(theta)**29 + 7.85321521783884e+117*cos(theta)**27 - 2.3579799328156e+117*cos(theta)**25 + 5.35904530185363e+116*cos(theta)**23 - 9.2422526337353e+115*cos(theta)**21 + 1.20551121309591e+115*cos(theta)**19 - 1.17863017403888e+114*cos(theta)**17 + 8.50815836885817e+112*cos(theta)**15 - 4.43353165622882e+111*cos(theta)**13 + 1.61445130338865e+110*cos(theta)**11 - 3.92030117820643e+108*cos(theta)**9 + 5.91991788655333e+106*cos(theta)**7 - 4.97472091307003e+104*cos(theta)**5 + 1.90602333834101e+102*cos(theta)**3 - 2.10455282113471e+99*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl90_m_minus_50(theta, phi):
    return 1.32134703033014e-96*(1.0 - cos(theta)**2)**25*(1.33872371513798e+116*cos(theta)**40 - 5.83354468048953e+116*cos(theta)**38 + 1.15846946621021e+117*cos(theta)**36 - 1.39016335945225e+117*cos(theta)**34 + 1.12699659631895e+117*cos(theta)**32 - 6.53789838332396e+116*cos(theta)**30 + 2.80471972065673e+116*cos(theta)**28 - 9.0691535877523e+115*cos(theta)**26 + 2.23293554243901e+115*cos(theta)**24 - 4.20102392442514e+114*cos(theta)**22 + 6.02755606547954e+113*cos(theta)**20 - 6.54794541132712e+112*cos(theta)**18 + 5.31759898053636e+111*cos(theta)**16 - 3.16680832587773e+110*cos(theta)**14 + 1.34537608615721e+109*cos(theta)**12 - 3.92030117820643e+107*cos(theta)**10 + 7.39989735819166e+105*cos(theta)**8 - 8.29120152178337e+103*cos(theta)**6 + 4.76505834585251e+101*cos(theta)**4 - 1.05227641056736e+99*cos(theta)**2 + 3.73147663321758e+95)*sin(50*phi)

#@torch.jit.script
def Yl90_m_minus_49(theta, phi):
    return 1.00108934536272e-94*(1.0 - cos(theta)**2)**24.5*(3.26517979301947e+114*cos(theta)**41 - 1.49578068730501e+115*cos(theta)**39 + 3.13099855732489e+115*cos(theta)**37 - 3.97189531272072e+115*cos(theta)**35 + 3.41514120096651e+115*cos(theta)**33 - 2.1089994784916e+115*cos(theta)**31 + 9.67144731260941e+114*cos(theta)**29 - 3.35894577324159e+114*cos(theta)**27 + 8.93174216975605e+113*cos(theta)**25 - 1.82653214105441e+113*cos(theta)**23 + 2.8702647930855e+112*cos(theta)**21 - 3.44628705859322e+111*cos(theta)**19 + 3.1279994003155e+110*cos(theta)**17 - 2.11120555058515e+109*cos(theta)**15 + 1.03490468165939e+108*cos(theta)**13 - 3.56391016200584e+106*cos(theta)**11 + 8.22210817576851e+104*cos(theta)**9 - 1.18445736025477e+103*cos(theta)**7 + 9.53011669170503e+100*cos(theta)**5 - 3.50758803522452e+98*cos(theta)**3 + 3.73147663321758e+95*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl90_m_minus_48(theta, phi):
    return 7.6490039379346e-93*(1.0 - cos(theta)**2)**24*(7.77423760242731e+112*cos(theta)**42 - 3.73945171826252e+113*cos(theta)**40 + 8.23946988769708e+113*cos(theta)**38 - 1.10330425353353e+114*cos(theta)**36 + 1.00445329440192e+114*cos(theta)**34 - 6.59062337028625e+113*cos(theta)**32 + 3.2238157708698e+113*cos(theta)**30 - 1.19962349044343e+113*cos(theta)**28 + 3.43528544990617e+112*cos(theta)**26 - 7.6105505877267e+111*cos(theta)**24 + 1.30466581503886e+111*cos(theta)**22 - 1.72314352929661e+110*cos(theta)**20 + 1.73777744461972e+109*cos(theta)**18 - 1.31950346911572e+108*cos(theta)**16 + 7.39217629756706e+106*cos(theta)**14 - 2.96992513500487e+105*cos(theta)**12 + 8.22210817576851e+103*cos(theta)**10 - 1.48057170031846e+102*cos(theta)**8 + 1.58835278195084e+100*cos(theta)**6 - 8.76897008806131e+97*cos(theta)**4 + 1.86573831660879e+95*cos(theta)**2 - 6.39170372253782e+91)*sin(48*phi)

#@torch.jit.script
def Yl90_m_minus_47(theta, phi):
    return 5.89221595168767e-91*(1.0 - cos(theta)**2)**23.5*(1.80796223312263e+111*cos(theta)**43 - 9.12061394698176e+111*cos(theta)**41 + 2.11268458658899e+112*cos(theta)**39 - 2.98190338792847e+112*cos(theta)**37 + 2.86986655543404e+112*cos(theta)**35 - 1.99715859705644e+112*cos(theta)**33 + 1.03994057124832e+112*cos(theta)**31 - 4.13663272566698e+111*cos(theta)**29 + 1.27232794440969e+111*cos(theta)**27 - 3.04422023509068e+110*cos(theta)**25 + 5.67246006538636e+109*cos(theta)**23 - 8.20544537760291e+108*cos(theta)**21 + 9.14619707694592e+107*cos(theta)**19 - 7.76178511244542e+106*cos(theta)**17 + 4.92811753171138e+105*cos(theta)**15 - 2.28455779615759e+104*cos(theta)**13 + 7.47464379615319e+102*cos(theta)**11 - 1.64507966702051e+101*cos(theta)**9 + 2.26907540278691e+99*cos(theta)**7 - 1.75379401761226e+97*cos(theta)**5 + 6.2191277220293e+94*cos(theta)**3 - 6.39170372253782e+91*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl90_m_minus_46(theta, phi):
    return 4.57472800038355e-89*(1.0 - cos(theta)**2)**23*(4.1090050752787e+109*cos(theta)**44 - 2.17157474928137e+110*cos(theta)**42 + 5.28171146647249e+110*cos(theta)**40 - 7.84711417875912e+110*cos(theta)**38 + 7.97185154287234e+110*cos(theta)**36 - 5.87399587369541e+110*cos(theta)**34 + 3.24981428515101e+110*cos(theta)**32 - 1.37887757522233e+110*cos(theta)**30 + 4.54402837289176e+109*cos(theta)**28 - 1.17085393657334e+109*cos(theta)**26 + 2.36352502724432e+108*cos(theta)**24 - 3.72974789891041e+107*cos(theta)**22 + 4.57309853847296e+106*cos(theta)**20 - 4.31210284024745e+105*cos(theta)**18 + 3.08007345731961e+104*cos(theta)**16 - 1.63182699725542e+103*cos(theta)**14 + 6.22886983012766e+101*cos(theta)**12 - 1.64507966702051e+100*cos(theta)**10 + 2.83634425348364e+98*cos(theta)**8 - 2.92299002935377e+96*cos(theta)**6 + 1.55478193050732e+94*cos(theta)**4 - 3.19585186126891e+91*cos(theta)**2 + 1.06033572039446e+88)*sin(46*phi)

#@torch.jit.script
def Yl90_m_minus_45(theta, phi):
    return 3.5788293339898e-87*(1.0 - cos(theta)**2)**22.5*(9.13112238950823e+107*cos(theta)**45 - 5.05017383553807e+108*cos(theta)**43 + 1.28822230889573e+109*cos(theta)**41 - 2.01208055865618e+109*cos(theta)**39 + 2.15455447104658e+109*cos(theta)**37 - 1.67828453534155e+109*cos(theta)**35 + 9.84792207621519e+108*cos(theta)**33 - 4.44799217813654e+108*cos(theta)**31 + 1.56690633547992e+108*cos(theta)**29 - 4.33649606138273e+107*cos(theta)**27 + 9.45410010897726e+106*cos(theta)**25 - 1.6216295212654e+106*cos(theta)**23 + 2.17766597070141e+105*cos(theta)**21 - 2.26952781065655e+104*cos(theta)**19 + 1.81180791607036e+103*cos(theta)**17 - 1.08788466483695e+102*cos(theta)**15 + 4.79143833086743e+100*cos(theta)**13 - 1.49552697001865e+99*cos(theta)**11 + 3.15149361498182e+97*cos(theta)**9 - 4.17570004193396e+95*cos(theta)**7 + 3.10956386101465e+93*cos(theta)**5 - 1.0652839537563e+91*cos(theta)**3 + 1.06033572039446e+88*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl90_m_minus_44(theta, phi):
    return 2.82024467884152e-85*(1.0 - cos(theta)**2)**22*(1.98502660641483e+106*cos(theta)**46 - 1.14776678080411e+107*cos(theta)**44 + 3.06719597356126e+107*cos(theta)**42 - 5.03020139664046e+107*cos(theta)**40 + 5.66988018696468e+107*cos(theta)**38 - 4.66190148705985e+107*cos(theta)**36 + 2.89644766947506e+107*cos(theta)**34 - 1.38999755566767e+107*cos(theta)**32 + 5.2230211182664e+106*cos(theta)**30 - 1.54874859335098e+106*cos(theta)**28 + 3.63619234960664e+105*cos(theta)**26 - 6.75678967193915e+104*cos(theta)**24 + 9.8984816850064e+103*cos(theta)**22 - 1.13476390532828e+103*cos(theta)**20 + 1.00655995337242e+102*cos(theta)**18 - 6.79927915523093e+100*cos(theta)**16 + 3.42245595061959e+99*cos(theta)**14 - 1.24627247501554e+98*cos(theta)**12 + 3.15149361498182e+96*cos(theta)**10 - 5.21962505241744e+94*cos(theta)**8 + 5.18260643502441e+92*cos(theta)**6 - 2.66320988439076e+90*cos(theta)**4 + 5.30167860197231e+87*cos(theta)**2 - 1.70746492817144e+84)*sin(44*phi)

#@torch.jit.script
def Yl90_m_minus_43(theta, phi):
    return 2.23814447133482e-83*(1.0 - cos(theta)**2)**21.5*(4.22346086471241e+104*cos(theta)**47 - 2.55059284623135e+105*cos(theta)**45 + 7.13301389200292e+105*cos(theta)**43 - 1.2268783894245e+106*cos(theta)**41 + 1.45381543255505e+106*cos(theta)**39 - 1.25997337488104e+106*cos(theta)**37 + 8.27556476992873e+105*cos(theta)**35 - 4.21211380505354e+105*cos(theta)**33 + 1.68484552202142e+105*cos(theta)**31 - 5.34051239086543e+104*cos(theta)**29 + 1.34673790726172e+104*cos(theta)**27 - 2.70271586877566e+103*cos(theta)**25 + 4.30368768913322e+102*cos(theta)**23 - 5.40363764442037e+101*cos(theta)**21 + 5.29768396511801e+100*cos(theta)**19 - 3.99957597366525e+99*cos(theta)**17 + 2.28163730041306e+98*cos(theta)**15 - 9.58671134627337e+96*cos(theta)**13 + 2.86499419543802e+95*cos(theta)**11 - 5.79958339157494e+93*cos(theta)**9 + 7.4037234786063e+91*cos(theta)**7 - 5.32641976878151e+89*cos(theta)**5 + 1.76722620065744e+87*cos(theta)**3 - 1.70746492817144e+84*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl90_m_minus_42(theta, phi):
    return 1.78827603200494e-81*(1.0 - cos(theta)**2)**21*(8.79887680148419e+102*cos(theta)**48 - 5.54476705702467e+103*cos(theta)**46 + 1.62113952090976e+104*cos(theta)**44 - 2.92113902243929e+104*cos(theta)**42 + 3.63453858138762e+104*cos(theta)**40 - 3.31571940758169e+104*cos(theta)**38 + 2.29876799164687e+104*cos(theta)**36 - 1.23885700148634e+104*cos(theta)**34 + 5.26514225631693e+103*cos(theta)**32 - 1.78017079695514e+103*cos(theta)**30 + 4.80977824022042e+102*cos(theta)**28 - 1.03950610337525e+102*cos(theta)**26 + 1.79320320380551e+101*cos(theta)**24 - 2.45619892928199e+100*cos(theta)**22 + 2.648841982559e+99*cos(theta)**20 - 2.22198665203625e+98*cos(theta)**18 + 1.42602331275816e+97*cos(theta)**16 - 6.84765096162384e+95*cos(theta)**14 + 2.38749516286502e+94*cos(theta)**12 - 5.79958339157494e+92*cos(theta)**10 + 9.25465434825788e+90*cos(theta)**8 - 8.87736628130252e+88*cos(theta)**6 + 4.41806550164359e+86*cos(theta)**4 - 8.53732464085718e+83*cos(theta)**2 + 2.67460045139636e+80)*sin(42*phi)

#@torch.jit.script
def Yl90_m_minus_41(theta, phi):
    return 1.43820091732168e-79*(1.0 - cos(theta)**2)**20.5*(1.79568914316004e+101*cos(theta)**49 - 1.17973767170738e+102*cos(theta)**47 + 3.60253226868835e+102*cos(theta)**45 - 6.79334656381231e+102*cos(theta)**43 + 8.86472824728687e+102*cos(theta)**41 - 8.50184463482484e+102*cos(theta)**39 + 6.21288646391046e+102*cos(theta)**37 - 3.5395914328181e+102*cos(theta)**35 + 1.59549765342937e+102*cos(theta)**33 - 5.74248644179079e+101*cos(theta)**31 + 1.65854422076566e+101*cos(theta)**29 - 3.85002260509353e+100*cos(theta)**27 + 7.17281281522203e+99*cos(theta)**25 - 1.06791257794869e+99*cos(theta)**23 + 1.2613533250281e+98*cos(theta)**21 - 1.16946665896645e+97*cos(theta)**19 + 8.3883724279892e+95*cos(theta)**17 - 4.56510064108256e+94*cos(theta)**15 + 1.8365347406654e+93*cos(theta)**13 - 5.2723485377954e+91*cos(theta)**11 + 1.02829492758421e+90*cos(theta)**9 - 1.26819518304322e+88*cos(theta)**7 + 8.83613100328718e+85*cos(theta)**5 - 2.84577488028573e+83*cos(theta)**3 + 2.67460045139636e+80*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl90_m_minus_40(theta, phi):
    return 1.16396577719155e-77*(1.0 - cos(theta)**2)**20*(3.59137828632008e+99*cos(theta)**50 - 2.45778681605704e+100*cos(theta)**48 + 7.83159188845293e+100*cos(theta)**46 - 1.54394240086643e+101*cos(theta)**44 + 2.11064958268735e+101*cos(theta)**42 - 2.12546115870621e+101*cos(theta)**40 + 1.6349701220817e+101*cos(theta)**38 - 9.83219842449474e+100*cos(theta)**36 + 4.69264015714521e+100*cos(theta)**34 - 1.79452701305962e+100*cos(theta)**32 + 5.52848073588554e+99*cos(theta)**30 - 1.37500807324769e+99*cos(theta)**28 + 2.75877415970078e+98*cos(theta)**26 - 4.44963574145287e+97*cos(theta)**24 + 5.73342420467317e+96*cos(theta)**22 - 5.84733329483224e+95*cos(theta)**20 + 4.66020690443845e+94*cos(theta)**18 - 2.8531879006766e+93*cos(theta)**16 + 1.31181052904671e+92*cos(theta)**14 - 4.39362378149617e+90*cos(theta)**12 + 1.02829492758421e+89*cos(theta)**10 - 1.58524397880402e+87*cos(theta)**8 + 1.47268850054786e+85*cos(theta)**6 - 7.11443720071432e+82*cos(theta)**4 + 1.33730022569818e+80*cos(theta)**2 - 4.0833594677807e+76)*sin(40*phi)

#@torch.jit.script
def Yl90_m_minus_39(theta, phi):
    return 9.4775694516246e-76*(1.0 - cos(theta)**2)**19.5*(7.04191820847074e+97*cos(theta)**51 - 5.01589146134089e+98*cos(theta)**49 + 1.66629614647935e+99*cos(theta)**47 - 3.43098311303652e+99*cos(theta)**45 + 4.90848740159849e+99*cos(theta)**43 - 5.18405160660051e+99*cos(theta)**41 + 4.19223108226077e+99*cos(theta)**39 - 2.65735092553912e+99*cos(theta)**37 + 1.34075433061292e+99*cos(theta)**35 - 5.43796064563522e+98*cos(theta)**33 + 1.78338088254372e+98*cos(theta)**31 - 4.74140714912997e+97*cos(theta)**29 + 1.02176820729659e+97*cos(theta)**27 - 1.77985429658115e+96*cos(theta)**25 + 2.4927931324666e+95*cos(theta)**23 - 2.78444442611059e+94*cos(theta)**21 + 2.45274047602023e+93*cos(theta)**19 - 1.67834582392741e+92*cos(theta)**17 + 8.74540352697808e+90*cos(theta)**15 - 3.3797106011509e+89*cos(theta)**13 + 9.34813570531099e+87*cos(theta)**11 - 1.76138219867114e+86*cos(theta)**9 + 2.10384071506838e+84*cos(theta)**7 - 1.42288744014286e+82*cos(theta)**5 + 4.45766741899393e+79*cos(theta)**3 - 4.0833594677807e+76*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl90_m_minus_38(theta, phi):
    return 7.76235503401608e-74*(1.0 - cos(theta)**2)**19*(1.35421504009053e+96*cos(theta)**52 - 1.00317829226818e+97*cos(theta)**50 + 3.4714503051653e+97*cos(theta)**48 - 7.45865894138374e+97*cos(theta)**46 + 1.11556531854511e+98*cos(theta)**44 - 1.23429800157155e+98*cos(theta)**42 + 1.04805777056519e+98*cos(theta)**40 - 6.99302875141873e+97*cos(theta)**38 + 3.72431758503588e+97*cos(theta)**36 - 1.59940018989271e+97*cos(theta)**34 + 5.57306525794914e+96*cos(theta)**32 - 1.58046904970999e+96*cos(theta)**30 + 3.64917216891638e+95*cos(theta)**28 - 6.84559344838904e+94*cos(theta)**26 + 1.03866380519441e+94*cos(theta)**24 - 1.265656557323e+93*cos(theta)**22 + 1.22637023801012e+92*cos(theta)**20 - 9.3241434662634e+90*cos(theta)**18 + 5.4658772043613e+89*cos(theta)**16 - 2.41407900082207e+88*cos(theta)**14 + 7.79011308775916e+86*cos(theta)**12 - 1.76138219867114e+85*cos(theta)**10 + 2.62980089383547e+83*cos(theta)**8 - 2.37147906690477e+81*cos(theta)**6 + 1.11441685474848e+79*cos(theta)**4 - 2.04167973389035e+76*cos(theta)**2 + 6.08729795435406e+72)*sin(38*phi)

#@torch.jit.script
def Yl90_m_minus_37(theta, phi):
    return 6.39346691626065e-72*(1.0 - cos(theta)**2)**18.5*(2.55512271715194e+94*cos(theta)**53 - 1.96701625934937e+95*cos(theta)**51 + 7.08459245952103e+95*cos(theta)**49 - 1.58694871093271e+96*cos(theta)**47 + 2.47903404121136e+96*cos(theta)**45 - 2.87046046877105e+96*cos(theta)**43 + 2.55623846479315e+96*cos(theta)**41 - 1.79308429523557e+96*cos(theta)**39 + 1.00657232027997e+96*cos(theta)**37 - 4.56971482826489e+95*cos(theta)**35 + 1.68880765392398e+95*cos(theta)**33 - 5.098287257129e+94*cos(theta)**31 + 1.25833523066082e+94*cos(theta)**29 - 2.53540498088483e+93*cos(theta)**27 + 4.15465522077766e+92*cos(theta)**25 - 5.5028545970565e+91*cos(theta)**23 + 5.83985827623865e+90*cos(theta)**21 - 4.90744392961231e+89*cos(theta)**19 + 3.21522188491841e+88*cos(theta)**17 - 1.60938600054805e+87*cos(theta)**15 + 5.99239468289166e+85*cos(theta)**13 - 1.60125654424649e+84*cos(theta)**11 + 2.92200099315052e+82*cos(theta)**9 - 3.38782723843539e+80*cos(theta)**7 + 2.22883370949697e+78*cos(theta)**5 - 6.80559911296784e+75*cos(theta)**3 + 6.08729795435406e+72*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl90_m_minus_36(theta, phi):
    return 5.294624471457e-70*(1.0 - cos(theta)**2)**18*(4.73170873546655e+92*cos(theta)**54 - 3.78272357567186e+93*cos(theta)**52 + 1.41691849190421e+94*cos(theta)**50 - 3.30614314777648e+94*cos(theta)**48 + 5.389204437416e+94*cos(theta)**46 - 6.52377379266147e+94*cos(theta)**44 + 6.08628205903131e+94*cos(theta)**42 - 4.48271073808893e+94*cos(theta)**40 + 2.64887452705255e+94*cos(theta)**38 - 1.26936523007358e+94*cos(theta)**36 + 4.96708133507053e+93*cos(theta)**34 - 1.59321476785281e+93*cos(theta)**32 + 4.1944507688694e+92*cos(theta)**30 - 9.05501778887438e+91*cos(theta)**28 + 1.59794431568371e+91*cos(theta)**26 - 2.29285608210688e+90*cos(theta)**24 + 2.65448103465393e+89*cos(theta)**22 - 2.45372196480616e+88*cos(theta)**20 + 1.78623438051023e+87*cos(theta)**18 - 1.00586625034253e+86*cos(theta)**16 + 4.28028191635119e+84*cos(theta)**14 - 1.33438045353874e+83*cos(theta)**12 + 2.92200099315052e+81*cos(theta)**10 - 4.23478404804424e+79*cos(theta)**8 + 3.71472284916161e+77*cos(theta)**6 - 1.70139977824196e+75*cos(theta)**4 + 3.04364897717703e+72*cos(theta)**2 - 8.87619999176736e+68)*sin(36*phi)

#@torch.jit.script
def Yl90_m_minus_35(theta, phi):
    return 4.40759599641002e-68*(1.0 - cos(theta)**2)**17.5*(8.60310679175736e+90*cos(theta)**55 - 7.13721429372049e+91*cos(theta)**53 + 2.77827155275334e+92*cos(theta)**51 - 6.74723091382955e+92*cos(theta)**49 + 1.1466392420034e+93*cos(theta)**47 - 1.44972750948033e+93*cos(theta)**45 + 1.41541443233286e+93*cos(theta)**43 - 1.09334408246071e+93*cos(theta)**41 + 6.79198596680141e+92*cos(theta)**39 - 3.4307168380367e+92*cos(theta)**37 + 1.41916609573444e+92*cos(theta)**35 - 4.82792353894792e+91*cos(theta)**33 + 1.35304863511916e+91*cos(theta)**31 - 3.12241992719806e+90*cos(theta)**29 + 5.91831228031006e+89*cos(theta)**27 - 9.1714243284275e+88*cos(theta)**25 + 1.15412218897997e+88*cos(theta)**23 - 1.16843903086007e+87*cos(theta)**21 + 9.40123358163279e+85*cos(theta)**19 - 5.91686029613252e+84*cos(theta)**17 + 2.85352127756746e+83*cos(theta)**15 - 1.02644650272211e+82*cos(theta)**13 + 2.65636453922775e+80*cos(theta)**11 - 4.70531560893804e+78*cos(theta)**9 + 5.30674692737373e+76*cos(theta)**7 - 3.40279955648392e+74*cos(theta)**5 + 1.01454965905901e+72*cos(theta)**3 - 8.87619999176736e+68*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl90_m_minus_34(theta, phi):
    return 3.68765938330789e-66*(1.0 - cos(theta)**2)**17*(1.53626906995667e+89*cos(theta)**56 - 1.32170635068898e+90*cos(theta)**54 + 5.34282990914105e+90*cos(theta)**52 - 1.34944618276591e+91*cos(theta)**50 + 2.38883175417376e+91*cos(theta)**48 - 3.15158154234854e+91*cos(theta)**46 + 3.21685098257469e+91*cos(theta)**44 - 2.60320019633503e+91*cos(theta)**42 + 1.69799649170035e+91*cos(theta)**40 - 9.02820220535975e+90*cos(theta)**38 + 3.94212804370677e+90*cos(theta)**36 - 1.41997751145527e+90*cos(theta)**34 + 4.22827698474738e+89*cos(theta)**32 - 1.04080664239935e+89*cos(theta)**30 + 2.11368295725359e+88*cos(theta)**28 - 3.52747089554904e+87*cos(theta)**26 + 4.80884245408321e+86*cos(theta)**24 - 5.31108650390943e+85*cos(theta)**22 + 4.70061679081639e+84*cos(theta)**20 - 3.28714460896251e+83*cos(theta)**18 + 1.78345079847966e+82*cos(theta)**16 - 7.33176073372934e+80*cos(theta)**14 + 2.21363711602312e+79*cos(theta)**12 - 4.70531560893804e+77*cos(theta)**10 + 6.63343365921716e+75*cos(theta)**8 - 5.67133259413987e+73*cos(theta)**6 + 2.53637414764752e+71*cos(theta)**4 - 4.43809999588368e+68*cos(theta)**2 + 1.26802857025248e+65)*sin(34*phi)

#@torch.jit.script
def Yl90_m_minus_33(theta, phi):
    return 3.10026680543058e-64*(1.0 - cos(theta)**2)**16.5*(2.69520889466083e+87*cos(theta)**57 - 2.40310245579815e+88*cos(theta)**55 + 1.00808111493227e+89*cos(theta)**53 - 2.64597290738414e+89*cos(theta)**51 + 4.87516684525257e+89*cos(theta)**49 - 6.70549264329476e+89*cos(theta)**47 + 7.14855773905486e+89*cos(theta)**45 - 6.0539539449652e+89*cos(theta)**43 + 4.14145485780574e+89*cos(theta)**41 - 2.31492364239993e+89*cos(theta)**39 + 1.06544001181264e+89*cos(theta)**37 - 4.05707860415791e+88*cos(theta)**35 + 1.28129605598405e+88*cos(theta)**33 - 3.3574407819334e+87*cos(theta)**31 + 7.28856192156411e+86*cos(theta)**29 - 1.3064707020552e+86*cos(theta)**27 + 1.92353698163329e+85*cos(theta)**25 - 2.30916804517801e+84*cos(theta)**23 + 2.23838894800781e+83*cos(theta)**21 - 1.73007610998027e+82*cos(theta)**19 + 1.04908870498804e+81*cos(theta)**17 - 4.88784048915289e+79*cos(theta)**15 + 1.70279778155625e+78*cos(theta)**13 - 4.27755964448913e+76*cos(theta)**11 + 7.37048184357463e+74*cos(theta)**9 - 8.10190370591409e+72*cos(theta)**7 + 5.07274829529505e+70*cos(theta)**5 - 1.47936666529456e+68*cos(theta)**3 + 1.26802857025248e+65*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl90_m_minus_32(theta, phi):
    return 2.61857865120515e-62*(1.0 - cos(theta)**2)**16*(4.64691188734625e+85*cos(theta)**58 - 4.29125438535383e+86*cos(theta)**56 + 1.86681687950421e+87*cos(theta)**54 - 5.08840943727719e+87*cos(theta)**52 + 9.75033369050513e+87*cos(theta)**50 - 1.39697763401974e+88*cos(theta)**48 + 1.55403429109888e+88*cos(theta)**46 - 1.37589862385573e+88*cos(theta)**44 + 9.86060680429937e+87*cos(theta)**42 - 5.78730910599984e+87*cos(theta)**40 + 2.80378950477011e+87*cos(theta)**38 - 1.12696627893275e+87*cos(theta)**36 + 3.76851781171781e+86*cos(theta)**34 - 1.04920024435419e+86*cos(theta)**32 + 2.42952064052137e+85*cos(theta)**30 - 4.66596679305429e+84*cos(theta)**28 + 7.39821916012802e+83*cos(theta)**26 - 9.62153352157506e+82*cos(theta)**24 + 1.01744952182173e+82*cos(theta)**22 - 8.65038054990135e+80*cos(theta)**20 + 5.82827058326687e+79*cos(theta)**18 - 3.05490030572056e+78*cos(theta)**16 + 1.21628412968304e+77*cos(theta)**14 - 3.56463303707427e+75*cos(theta)**12 + 7.37048184357463e+73*cos(theta)**10 - 1.01273796323926e+72*cos(theta)**8 + 8.45458049215842e+69*cos(theta)**6 - 3.6984166632364e+67*cos(theta)**4 + 6.3401428512624e+64*cos(theta)**2 - 1.77744402894937e+61)*sin(32*phi)

#@torch.jit.script
def Yl90_m_minus_31(theta, phi):
    return 2.22162904171772e-60*(1.0 - cos(theta)**2)**15.5*(7.87612184295975e+83*cos(theta)**59 - 7.52851646553304e+84*cos(theta)**57 + 3.39421250818947e+85*cos(theta)**55 - 9.6007725231645e+85*cos(theta)**53 + 1.91183013539316e+86*cos(theta)**51 - 2.85097476330559e+86*cos(theta)**49 + 3.30645593850826e+86*cos(theta)**47 - 3.05755249745717e+86*cos(theta)**45 + 2.29316437309288e+86*cos(theta)**43 - 1.41153880634142e+86*cos(theta)**41 + 7.18920385838489e+85*cos(theta)**39 - 3.04585480792636e+85*cos(theta)**37 + 1.07671937477652e+85*cos(theta)**35 - 3.17939467986118e+84*cos(theta)**33 + 7.83716335652055e+83*cos(theta)**31 - 1.60895406657044e+83*cos(theta)**29 + 2.74008117041778e+82*cos(theta)**27 - 3.84861340863002e+81*cos(theta)**25 + 4.42369357313796e+80*cos(theta)**23 - 4.11922883328636e+79*cos(theta)**21 + 3.06751083329835e+78*cos(theta)**19 - 1.79700017983562e+77*cos(theta)**17 + 8.10856086455357e+75*cos(theta)**15 - 2.74202541313406e+74*cos(theta)**13 + 6.7004380396133e+72*cos(theta)**11 - 1.12526440359918e+71*cos(theta)**9 + 1.20779721316549e+69*cos(theta)**7 - 7.3968333264728e+66*cos(theta)**5 + 2.1133809504208e+64*cos(theta)**3 - 1.77744402894937e+61*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl90_m_minus_30(theta, phi):
    return 1.89295310160517e-58*(1.0 - cos(theta)**2)**15*(1.31268697382663e+82*cos(theta)**60 - 1.29802008026432e+83*cos(theta)**58 + 6.06109376462406e+83*cos(theta)**56 - 1.77792083762306e+84*cos(theta)**54 + 3.67659641421762e+84*cos(theta)**52 - 5.70194952661119e+84*cos(theta)**50 + 6.88844987189221e+84*cos(theta)**48 - 6.64685325534167e+84*cos(theta)**46 + 5.21173721157472e+84*cos(theta)**44 - 3.36080668176529e+84*cos(theta)**42 + 1.79730096459622e+84*cos(theta)**40 - 8.0154073892799e+83*cos(theta)**38 + 2.99088715215699e+83*cos(theta)**36 - 9.35116082312111e+82*cos(theta)**34 + 2.44911354891267e+82*cos(theta)**32 - 5.36318022190148e+81*cos(theta)**30 + 9.78600418006352e+80*cos(theta)**28 - 1.48023592639616e+80*cos(theta)**26 + 1.84320565547415e+79*cos(theta)**24 - 1.87237674240289e+78*cos(theta)**22 + 1.53375541664918e+77*cos(theta)**20 - 9.98333433242012e+75*cos(theta)**18 + 5.06785054034598e+74*cos(theta)**16 - 1.95858958081004e+73*cos(theta)**14 + 5.58369836634441e+71*cos(theta)**12 - 1.12526440359918e+70*cos(theta)**10 + 1.50974651645686e+68*cos(theta)**8 - 1.23280555441213e+66*cos(theta)**6 + 5.283452376052e+63*cos(theta)**4 - 8.88722014474685e+60*cos(theta)**2 + 2.44827001232696e+57)*sin(30*phi)

#@torch.jit.script
def Yl90_m_minus_29(theta, phi):
    return 1.61955385759464e-56*(1.0 - cos(theta)**2)**14.5*(2.15194585873217e+80*cos(theta)**61 - 2.2000340343463e+81*cos(theta)**59 + 1.06334978326738e+82*cos(theta)**57 - 3.23258334113283e+82*cos(theta)**55 + 6.93697436644834e+82*cos(theta)**53 - 1.11802931894337e+83*cos(theta)**51 + 1.40580609630453e+83*cos(theta)**49 - 1.41422409688121e+83*cos(theta)**47 + 1.15816382479438e+83*cos(theta)**45 - 7.81582949247743e+82*cos(theta)**43 + 4.38366088925908e+82*cos(theta)**41 - 2.05523266391792e+82*cos(theta)**39 + 8.08347878961348e+81*cos(theta)**37 - 2.67176023517746e+81*cos(theta)**35 + 7.42155620882627e+80*cos(theta)**33 - 1.73005813609725e+80*cos(theta)**31 + 3.3744842000219e+79*cos(theta)**29 - 5.48235528294875e+78*cos(theta)**27 + 7.37282262189659e+77*cos(theta)**25 - 8.14076844522995e+76*cos(theta)**23 + 7.30359722213893e+75*cos(theta)**21 - 5.25438649074743e+74*cos(theta)**19 + 2.98108855314469e+73*cos(theta)**17 - 1.30572638720669e+72*cos(theta)**15 + 4.2951525894957e+70*cos(theta)**13 - 1.02296763963562e+69*cos(theta)**11 + 1.67749612939651e+67*cos(theta)**9 - 1.76115079201733e+65*cos(theta)**7 + 1.0566904752104e+63*cos(theta)**5 - 2.96240671491562e+60*cos(theta)**3 + 2.44827001232696e+57*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl90_m_minus_28(theta, phi):
    return 1.39112040310174e-54*(1.0 - cos(theta)**2)**14*(3.47088041730996e+78*cos(theta)**62 - 3.66672339057717e+79*cos(theta)**60 + 1.83336169528858e+80*cos(theta)**58 - 5.77247025202291e+80*cos(theta)**56 + 1.28462488267562e+81*cos(theta)**54 - 2.1500563825834e+81*cos(theta)**52 + 2.81161219260907e+81*cos(theta)**50 - 2.94630020183585e+81*cos(theta)**48 + 2.51774744520518e+81*cos(theta)**46 - 1.77632488465396e+81*cos(theta)**44 + 1.04372878315692e+81*cos(theta)**42 - 5.1380816597948e+80*cos(theta)**40 + 2.1272312604246e+80*cos(theta)**38 - 7.42155620882627e+79*cos(theta)**36 + 2.18281064965479e+79*cos(theta)**34 - 5.40643167530391e+78*cos(theta)**32 + 1.12482806667397e+78*cos(theta)**30 - 1.95798402962455e+77*cos(theta)**28 + 2.83570100842177e+76*cos(theta)**26 - 3.39198685217915e+75*cos(theta)**24 + 3.31981691915406e+74*cos(theta)**22 - 2.62719324537372e+73*cos(theta)**20 + 1.65616030730261e+72*cos(theta)**18 - 8.16078992004184e+70*cos(theta)**16 + 3.06796613535407e+69*cos(theta)**14 - 8.52473033029681e+67*cos(theta)**12 + 1.67749612939651e+66*cos(theta)**10 - 2.20143849002167e+64*cos(theta)**8 + 1.76115079201733e+62*cos(theta)**6 - 7.40601678728904e+59*cos(theta)**4 + 1.22413500616348e+57*cos(theta)**2 - 3.31833831977088e+53)*sin(28*phi)

#@torch.jit.script
def Yl90_m_minus_27(theta, phi):
    return 1.19943301459621e-52*(1.0 - cos(theta)**2)**13.5*(5.50933399573009e+76*cos(theta)**63 - 6.01102195176585e+77*cos(theta)**61 + 3.10739270387895e+78*cos(theta)**59 - 1.01271407930227e+79*cos(theta)**57 + 2.33568160486476e+79*cos(theta)**55 - 4.05671015581774e+79*cos(theta)**53 + 5.51296508354719e+79*cos(theta)**51 - 6.01285755476704e+79*cos(theta)**49 + 5.35690945788336e+79*cos(theta)**47 - 3.94738863256436e+79*cos(theta)**45 + 2.42727623989982e+79*cos(theta)**43 - 1.25319064873044e+79*cos(theta)**41 + 5.45443912929385e+78*cos(theta)**39 - 2.00582600238548e+78*cos(theta)**37 + 6.23660185615653e+77*cos(theta)**35 - 1.63831262887997e+77*cos(theta)**33 + 3.62847763443215e+76*cos(theta)**31 - 6.75166906767087e+75*cos(theta)**29 + 1.0502596327488e+75*cos(theta)**27 - 1.35679474087166e+74*cos(theta)**25 + 1.44339866050176e+73*cos(theta)**23 - 1.25104440255891e+72*cos(theta)**21 + 8.71663319632951e+70*cos(theta)**19 - 4.80046465884814e+69*cos(theta)**17 + 2.04531075690272e+68*cos(theta)**15 - 6.55748486945909e+66*cos(theta)**13 + 1.52499648126956e+65*cos(theta)**11 - 2.44604276669074e+63*cos(theta)**9 + 2.51592970288191e+61*cos(theta)**7 - 1.48120335745781e+59*cos(theta)**5 + 4.08045002054493e+56*cos(theta)**3 - 3.31833831977088e+53*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl90_m_minus_26(theta, phi):
    return 1.03790813654663e-50*(1.0 - cos(theta)**2)**13*(8.60833436832827e+74*cos(theta)**64 - 9.69519669639653e+75*cos(theta)**62 + 5.17898783979826e+76*cos(theta)**60 - 1.7460587574177e+77*cos(theta)**58 + 4.17086000868707e+77*cos(theta)**56 - 7.5124262144773e+77*cos(theta)**54 + 1.06018559298984e+78*cos(theta)**52 - 1.20257151095341e+78*cos(theta)**50 + 1.1160228037257e+78*cos(theta)**48 - 8.58127963600947e+77*cos(theta)**46 + 5.51653690886323e+77*cos(theta)**44 - 2.983787258882e+77*cos(theta)**42 + 1.36360978232346e+77*cos(theta)**40 - 5.27848947996179e+76*cos(theta)**38 + 1.73238940448793e+76*cos(theta)**36 - 4.81856655552933e+75*cos(theta)**34 + 1.13389926076005e+75*cos(theta)**32 - 2.25055635589029e+74*cos(theta)**30 + 3.75092725981715e+73*cos(theta)**28 - 5.21844131104484e+72*cos(theta)**26 + 6.01416108542402e+71*cos(theta)**24 - 5.68656546617687e+70*cos(theta)**22 + 4.35831659816476e+69*cos(theta)**20 - 2.66692481047119e+68*cos(theta)**18 + 1.2783192230642e+67*cos(theta)**16 - 4.68391776389935e+65*cos(theta)**14 + 1.27083040105796e+64*cos(theta)**12 - 2.44604276669074e+62*cos(theta)**10 + 3.14491212860238e+60*cos(theta)**8 - 2.46867226242968e+58*cos(theta)**6 + 1.02011250513623e+56*cos(theta)**4 - 1.65916915988544e+53*cos(theta)**2 + 4.43154155952308e+49)*sin(26*phi)

#@torch.jit.script
def Yl90_m_minus_25(theta, phi):
    return 9.01248571778017e-49*(1.0 - cos(theta)**2)**12.5*(1.32435913358896e+73*cos(theta)**65 - 1.53892011053913e+74*cos(theta)**63 + 8.49014399966928e+74*cos(theta)**61 - 2.95942162274186e+75*cos(theta)**59 + 7.31729826085452e+75*cos(theta)**57 - 1.36589567535951e+76*cos(theta)**55 + 2.00035017545254e+76*cos(theta)**53 - 2.3579833548106e+76*cos(theta)**51 + 2.27759755862388e+76*cos(theta)**49 - 1.82580417787436e+76*cos(theta)**47 + 1.2258970908585e+76*cos(theta)**45 - 6.93904013693488e+75*cos(theta)**43 + 3.3258775178621e+75*cos(theta)**41 - 1.35345884101584e+75*cos(theta)**39 + 4.68213352564304e+74*cos(theta)**37 - 1.37673330157981e+74*cos(theta)**35 + 3.43605836593954e+73*cos(theta)**33 - 7.25985921254933e+72*cos(theta)**31 + 1.2934231930404e+72*cos(theta)**29 - 1.93275604112772e+71*cos(theta)**27 + 2.40566443416961e+70*cos(theta)**25 - 2.47241976790299e+69*cos(theta)**23 + 2.07538885626893e+68*cos(theta)**21 - 1.4036446370901e+67*cos(theta)**19 + 7.5195248415541e+65*cos(theta)**17 - 3.12261184259957e+64*cos(theta)**15 + 9.77561846967664e+62*cos(theta)**13 - 2.22367524244613e+61*cos(theta)**11 + 3.4943468095582e+59*cos(theta)**9 - 3.52667466061383e+57*cos(theta)**7 + 2.04022501027246e+55*cos(theta)**5 - 5.5305638662848e+52*cos(theta)**3 + 4.43154155952308e+49*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl90_m_minus_24(theta, phi):
    return 7.85173217826566e-47*(1.0 - cos(theta)**2)**12*(2.00660474786207e+71*cos(theta)**66 - 2.40456267271739e+72*cos(theta)**64 + 1.36937806446279e+73*cos(theta)**62 - 4.93236937123644e+73*cos(theta)**60 + 1.26160314842319e+74*cos(theta)**58 - 2.43909942028484e+74*cos(theta)**56 + 3.70435217676396e+74*cos(theta)**54 - 4.53458337463578e+74*cos(theta)**52 + 4.55519511724776e+74*cos(theta)**50 - 3.80375870390491e+74*cos(theta)**48 + 2.66499367577934e+74*cos(theta)**46 - 1.57705457657611e+74*cos(theta)**44 + 7.91875599490977e+73*cos(theta)**42 - 3.38364710253961e+73*cos(theta)**40 + 1.23214040148501e+73*cos(theta)**38 - 3.82425917105502e+72*cos(theta)**36 + 1.01060540174692e+72*cos(theta)**34 - 2.26870600392166e+71*cos(theta)**32 + 4.31141064346799e+70*cos(theta)**30 - 6.90270014688471e+69*cos(theta)**28 + 9.25255551603695e+68*cos(theta)**26 - 1.03017490329291e+68*cos(theta)**24 + 9.43358571031333e+66*cos(theta)**22 - 7.01822318545049e+65*cos(theta)**20 + 4.17751380086339e+64*cos(theta)**18 - 1.95163240162473e+63*cos(theta)**16 + 6.9825846211976e+61*cos(theta)**14 - 1.85306270203844e+60*cos(theta)**12 + 3.4943468095582e+58*cos(theta)**10 - 4.40834332576729e+56*cos(theta)**8 + 3.40037501712077e+54*cos(theta)**6 - 1.3826409665712e+52*cos(theta)**4 + 2.21577077976154e+49*cos(theta)**2 - 5.83865818118983e+45)*sin(24*phi)

#@torch.jit.script
def Yl90_m_minus_23(theta, phi):
    return 6.86207253565265e-45*(1.0 - cos(theta)**2)**11.5*(2.99493245949562e+69*cos(theta)**67 - 3.69932718879599e+70*cos(theta)**65 + 2.17361597533776e+71*cos(theta)**63 - 8.08585142825645e+71*cos(theta)**61 + 2.13831042105626e+72*cos(theta)**59 - 4.2791217899734e+72*cos(theta)**57 + 6.73518577593447e+72*cos(theta)**55 - 8.55581768799203e+72*cos(theta)**53 + 8.93175513185835e+72*cos(theta)**51 - 7.76277286511206e+72*cos(theta)**49 + 5.67019931016881e+72*cos(theta)**47 - 3.50456572572469e+72*cos(theta)**45 + 1.84157116160692e+72*cos(theta)**43 - 8.25279781107221e+71*cos(theta)**41 + 3.15933436278208e+71*cos(theta)**39 - 1.0335835597446e+71*cos(theta)**37 + 2.88744400499121e+70*cos(theta)**35 - 6.8748666785505e+69*cos(theta)**33 + 1.39077762692516e+69*cos(theta)**31 - 2.38024142996025e+68*cos(theta)**29 + 3.42687241334702e+67*cos(theta)**27 - 4.12069961317165e+66*cos(theta)**25 + 4.10155900448406e+65*cos(theta)**23 - 3.34201104069071e+64*cos(theta)**21 + 2.19869147413863e+63*cos(theta)**19 - 1.14801905977925e+62*cos(theta)**17 + 4.65505641413173e+60*cos(theta)**15 - 1.42543284772188e+59*cos(theta)**13 + 3.17667891778018e+57*cos(theta)**11 - 4.89815925085254e+55*cos(theta)**9 + 4.85767859588682e+53*cos(theta)**7 - 2.7652819331424e+51*cos(theta)**5 + 7.38590259920513e+48*cos(theta)**3 - 5.83865818118983e+45*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl90_m_minus_22(theta, phi):
    return 6.01518491319549e-43*(1.0 - cos(theta)**2)**11*(4.40431244043474e+67*cos(theta)**68 - 5.60504119514544e+68*cos(theta)**66 + 3.39627496146524e+69*cos(theta)**64 - 1.30416958520265e+70*cos(theta)**62 + 3.56385070176043e+70*cos(theta)**60 - 7.37779618960931e+70*cos(theta)**58 + 1.20271174570258e+71*cos(theta)**56 - 1.58441068296149e+71*cos(theta)**54 + 1.71764521766507e+71*cos(theta)**52 - 1.55255457302241e+71*cos(theta)**50 + 1.18129152295183e+71*cos(theta)**48 - 7.61862114287976e+70*cos(theta)**46 + 4.1853890036521e+70*cos(theta)**44 - 1.9649518597791e+70*cos(theta)**42 + 7.8983359069552e+69*cos(theta)**40 - 2.71995673617e+69*cos(theta)**38 + 8.02067779164225e+68*cos(theta)**36 - 2.02201961133838e+68*cos(theta)**34 + 4.34618008414112e+67*cos(theta)**32 - 7.93413809986748e+66*cos(theta)**30 + 1.22388300476679e+66*cos(theta)**28 - 1.58488446660448e+65*cos(theta)**26 + 1.70898291853502e+64*cos(theta)**24 - 1.51909592758669e+63*cos(theta)**22 + 1.09934573706931e+62*cos(theta)**20 - 6.37788366544029e+60*cos(theta)**18 + 2.90941025883233e+59*cos(theta)**16 - 1.01816631980134e+58*cos(theta)**14 + 2.64723243148349e+56*cos(theta)**12 - 4.89815925085254e+54*cos(theta)**10 + 6.07209824485852e+52*cos(theta)**8 - 4.608803221904e+50*cos(theta)**6 + 1.84647564980128e+48*cos(theta)**4 - 2.91932909059491e+45*cos(theta)**2 + 7.59846197447921e+41)*sin(22*phi)

#@torch.jit.script
def Yl90_m_minus_21(theta, phi):
    return 5.28789154620833e-41*(1.0 - cos(theta)**2)**10.5*(6.38306150787643e+65*cos(theta)**69 - 8.36573312708274e+66*cos(theta)**67 + 5.22503840225422e+67*cos(theta)**65 - 2.07011045270262e+68*cos(theta)**63 + 5.84237819960726e+68*cos(theta)**61 - 1.25047393044226e+69*cos(theta)**59 + 2.11002060649576e+69*cos(theta)**57 - 2.88074669629361e+69*cos(theta)**55 + 3.24084003333031e+69*cos(theta)**53 - 3.04422465298512e+69*cos(theta)**51 + 2.41079902643232e+69*cos(theta)**49 - 1.62098322188931e+69*cos(theta)**47 + 9.30086445256022e+68*cos(theta)**45 - 4.56965548785837e+68*cos(theta)**43 + 1.92642339194029e+68*cos(theta)**41 - 6.97424804146155e+67*cos(theta)**39 + 2.1677507544979e+67*cos(theta)**37 - 5.77719888953823e+66*cos(theta)**35 + 1.31702426792155e+66*cos(theta)**33 - 2.55939938705403e+65*cos(theta)**31 + 4.22028622333377e+64*cos(theta)**29 - 5.86994246890548e+63*cos(theta)**27 + 6.83593167414009e+62*cos(theta)**25 - 6.60476490255081e+61*cos(theta)**23 + 5.23497970033006e+60*cos(theta)**21 - 3.35678087654752e+59*cos(theta)**19 + 1.71141779931314e+58*cos(theta)**17 - 6.78777546534227e+56*cos(theta)**15 + 2.03633263960268e+55*cos(theta)**13 - 4.45287204622958e+53*cos(theta)**11 + 6.74677582762058e+51*cos(theta)**9 - 6.58400460272e+49*cos(theta)**7 + 3.69295129960257e+47*cos(theta)**5 - 9.73109696864971e+44*cos(theta)**3 + 7.59846197447921e+41*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl90_m_minus_20(theta, phi):
    return 4.66114967282393e-39*(1.0 - cos(theta)**2)**10*(9.11865929696633e+63*cos(theta)**70 - 1.23025487162981e+65*cos(theta)**68 + 7.91672485190034e+65*cos(theta)**66 - 3.23454758234785e+66*cos(theta)**64 + 9.42319064452784e+66*cos(theta)**62 - 2.08412321740376e+67*cos(theta)**60 + 3.63796656292372e+67*cos(theta)**58 - 5.14419052909574e+67*cos(theta)**56 + 6.00155561727836e+67*cos(theta)**54 - 5.85427817881754e+67*cos(theta)**52 + 4.82159805286463e+67*cos(theta)**50 - 3.37704837893606e+67*cos(theta)**48 + 2.02192705490439e+67*cos(theta)**46 - 1.03855806542236e+67*cos(theta)**44 + 4.5867223617626e+66*cos(theta)**42 - 1.74356201036539e+66*cos(theta)**40 + 5.7046072486787e+65*cos(theta)**38 - 1.60477746931618e+65*cos(theta)**36 + 3.87360078800456e+64*cos(theta)**34 - 7.99812308454383e+63*cos(theta)**32 + 1.40676207444459e+63*cos(theta)**30 - 2.0964080246091e+62*cos(theta)**28 + 2.62920449005388e+61*cos(theta)**26 - 2.75198537606284e+60*cos(theta)**24 + 2.37953622742276e+59*cos(theta)**22 - 1.67839043827376e+58*cos(theta)**20 + 9.50787666285076e+56*cos(theta)**18 - 4.24235966583892e+55*cos(theta)**16 + 1.45452331400192e+54*cos(theta)**14 - 3.71072670519132e+52*cos(theta)**12 + 6.74677582762058e+50*cos(theta)**10 - 8.2300057534e+48*cos(theta)**8 + 6.15491883267094e+46*cos(theta)**6 - 2.43277424216243e+44*cos(theta)**4 + 3.79923098723961e+41*cos(theta)**2 - 9.77923034038509e+37)*sin(20*phi)

#@torch.jit.script
def Yl90_m_minus_19(theta, phi):
    return 4.11925393837239e-37*(1.0 - cos(theta)**2)**9.5*(1.28431821084033e+62*cos(theta)**71 - 1.78297807482582e+63*cos(theta)**69 + 1.18160072416423e+64*cos(theta)**67 - 4.97622704976592e+64*cos(theta)**65 + 1.49574454675045e+65*cos(theta)**63 - 3.41659543836682e+65*cos(theta)**61 + 6.16604502190462e+65*cos(theta)**59 - 9.02489566508024e+65*cos(theta)**57 + 1.09119193041425e+66*cos(theta)**55 - 1.10458078845614e+66*cos(theta)**53 + 9.45411382914634e+65*cos(theta)**51 - 6.89193546721646e+65*cos(theta)**49 + 4.30197245724339e+65*cos(theta)**47 - 2.30790681204968e+65*cos(theta)**45 + 1.06667961901456e+65*cos(theta)**43 - 4.25259026918387e+64*cos(theta)**41 + 1.46271980735351e+64*cos(theta)**39 - 4.33723640355723e+63*cos(theta)**37 + 1.10674308228702e+63*cos(theta)**35 - 2.42367366198298e+62*cos(theta)**33 + 4.53794217562771e+61*cos(theta)**31 - 7.22899318830724e+60*cos(theta)**29 + 9.73779440760697e+59*cos(theta)**27 - 1.10079415042514e+59*cos(theta)**25 + 1.03458096844468e+58*cos(theta)**23 - 7.99233542035124e+56*cos(theta)**21 + 5.00414561202672e+55*cos(theta)**19 - 2.4955056857876e+54*cos(theta)**17 + 9.69682209334611e+52*cos(theta)**15 - 2.85440515783948e+51*cos(theta)**13 + 6.13343257056416e+49*cos(theta)**11 - 9.14445083711111e+47*cos(theta)**9 + 8.79274118952992e+45*cos(theta)**7 - 4.86554848432486e+43*cos(theta)**5 + 1.26641032907987e+41*cos(theta)**3 - 9.77923034038509e+37*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl90_m_minus_18(theta, phi):
    return 3.64920333241427e-35*(1.0 - cos(theta)**2)**9*(1.78377529283379e+60*cos(theta)**72 - 2.54711153546546e+61*cos(theta)**70 + 1.73764812377093e+62*cos(theta)**68 - 7.53973795419079e+62*cos(theta)**66 + 2.33710085429758e+63*cos(theta)**64 - 5.51063780381745e+63*cos(theta)**62 + 1.02767417031744e+64*cos(theta)**60 - 1.55601649397935e+64*cos(theta)**58 + 1.94855701859687e+64*cos(theta)**56 - 2.04551997862248e+64*cos(theta)**54 + 1.81809881329737e+64*cos(theta)**52 - 1.37838709344329e+64*cos(theta)**50 + 8.96244261925707e+63*cos(theta)**48 - 5.01718872184713e+63*cos(theta)**46 + 2.42427186139672e+63*cos(theta)**44 - 1.01252149266283e+63*cos(theta)**42 + 3.65679951838378e+62*cos(theta)**40 - 1.14137800093611e+62*cos(theta)**38 + 3.07428633968616e+61*cos(theta)**36 - 7.12845194700877e+60*cos(theta)**34 + 1.41810692988366e+60*cos(theta)**32 - 2.40966439610241e+59*cos(theta)**30 + 3.47778371700249e+58*cos(theta)**28 - 4.23382365548129e+57*cos(theta)**26 + 4.31075403518615e+56*cos(theta)**24 - 3.63287973652329e+55*cos(theta)**22 + 2.50207280601336e+54*cos(theta)**20 - 1.38639204765978e+53*cos(theta)**18 + 6.06051380834132e+51*cos(theta)**16 - 2.0388608270282e+50*cos(theta)**14 + 5.11119380880347e+48*cos(theta)**12 - 9.14445083711112e+46*cos(theta)**10 + 1.09909264869124e+45*cos(theta)**8 - 8.10924747387476e+42*cos(theta)**6 + 3.16602582269967e+40*cos(theta)**4 - 4.88961517019254e+37*cos(theta)**2 + 1.24607929923357e+34)*sin(18*phi)

#@torch.jit.script
def Yl90_m_minus_17(theta, phi):
    return 3.24019666432327e-33*(1.0 - cos(theta)**2)**8.5*(2.44352779840245e+58*cos(theta)**73 - 3.58748103586684e+59*cos(theta)**71 + 2.51833061416076e+60*cos(theta)**69 - 1.12533402301355e+61*cos(theta)**67 + 3.59553977584243e+61*cos(theta)**65 - 8.74704413304358e+61*cos(theta)**63 + 1.68471175461875e+62*cos(theta)**61 - 2.63731609149043e+62*cos(theta)**59 + 3.41852108525767e+62*cos(theta)**57 - 3.71912723385906e+62*cos(theta)**55 + 3.43037511942901e+62*cos(theta)**53 - 2.70271979106528e+62*cos(theta)**51 + 1.82906992229736e+62*cos(theta)**49 - 1.06748696209513e+62*cos(theta)**47 + 5.38727080310383e+61*cos(theta)**45 - 2.3547011457275e+61*cos(theta)**43 + 8.9190232155702e+60*cos(theta)**41 - 2.92661025881055e+60*cos(theta)**39 + 8.30888199915179e+59*cos(theta)**37 - 2.03670055628822e+59*cos(theta)**35 + 4.29729372692018e+58*cos(theta)**33 - 7.77311095516908e+57*cos(theta)**31 + 1.19923576448362e+57*cos(theta)**29 - 1.56808283536344e+56*cos(theta)**27 + 1.72430161407446e+55*cos(theta)**25 - 1.57951292892317e+54*cos(theta)**23 + 1.19146324095874e+53*cos(theta)**21 - 7.29680025084094e+51*cos(theta)**19 + 3.56500812255372e+50*cos(theta)**17 - 1.35924055135213e+49*cos(theta)**15 + 3.93168754523344e+47*cos(theta)**13 - 8.31313712464647e+45*cos(theta)**11 + 1.22121405410138e+44*cos(theta)**9 - 1.15846392483925e+42*cos(theta)**7 + 6.33205164539934e+39*cos(theta)**5 - 1.62987172339751e+37*cos(theta)**3 + 1.24607929923357e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl90_m_minus_16(theta, phi):
    return 2.88322887896897e-31*(1.0 - cos(theta)**2)**8*(3.30206459243574e+56*cos(theta)**74 - 4.98261254981505e+57*cos(theta)**72 + 3.5976151630868e+58*cos(theta)**70 - 1.65490297501993e+59*cos(theta)**68 + 5.4477875391552e+59*cos(theta)**66 - 1.36672564578806e+60*cos(theta)**64 + 2.71727702357863e+60*cos(theta)**62 - 4.39552681915071e+60*cos(theta)**60 + 5.89400187113391e+60*cos(theta)**58 - 6.64129863189117e+60*cos(theta)**56 + 6.35254651746112e+60*cos(theta)**54 - 5.19753805974092e+60*cos(theta)**52 + 3.65813984459472e+60*cos(theta)**50 - 2.22393117103153e+60*cos(theta)**48 + 1.1711458267617e+60*cos(theta)**46 - 5.35159351301705e+59*cos(theta)**44 + 2.12357695608814e+59*cos(theta)**42 - 7.31652564702637e+58*cos(theta)**40 + 2.18654789451363e+58*cos(theta)**38 - 5.65750154524505e+57*cos(theta)**36 + 1.26390991968241e+57*cos(theta)**34 - 2.42909717349034e+56*cos(theta)**32 + 3.99745254827872e+55*cos(theta)**30 - 5.60029584058372e+54*cos(theta)**28 + 6.63192928490177e+53*cos(theta)**26 - 6.58130387051321e+52*cos(theta)**24 + 5.41574200435792e+51*cos(theta)**22 - 3.64840012542047e+50*cos(theta)**20 + 1.9805600680854e+49*cos(theta)**18 - 8.49525344595082e+47*cos(theta)**16 + 2.80834824659531e+46*cos(theta)**14 - 6.92761427053872e+44*cos(theta)**12 + 1.22121405410138e+43*cos(theta)**10 - 1.44807990604906e+41*cos(theta)**8 + 1.05534194089989e+39*cos(theta)**6 - 4.07467930849379e+36*cos(theta)**4 + 6.23039649616787e+33*cos(theta)**2 - 1.57372985505629e+30)*sin(16*phi)

#@torch.jit.script
def Yl90_m_minus_15(theta, phi):
    return 2.57076680602771e-29*(1.0 - cos(theta)**2)**7.5*(4.40275278991433e+54*cos(theta)**75 - 6.82549664358227e+55*cos(theta)**73 + 5.06706360998141e+56*cos(theta)**71 - 2.39841010872453e+57*cos(theta)**69 + 8.13102617784358e+57*cos(theta)**67 - 2.10265483967394e+58*cos(theta)**65 + 4.31313813266449e+58*cos(theta)**63 - 7.20578167073887e+58*cos(theta)**61 + 9.98983367988798e+58*cos(theta)**59 - 1.1651401108581e+59*cos(theta)**57 + 1.1550084577202e+59*cos(theta)**55 - 9.80667558441683e+58*cos(theta)**53 + 7.17282322469553e+58*cos(theta)**51 - 4.53863504292149e+58*cos(theta)**49 + 2.49179963140788e+58*cos(theta)**47 - 1.18924300289268e+58*cos(theta)**45 + 4.9385510606701e+57*cos(theta)**43 - 1.78451845049424e+57*cos(theta)**41 + 5.60653306285546e+56*cos(theta)**39 - 1.52905447168785e+56*cos(theta)**37 + 3.61117119909259e+55*cos(theta)**35 - 7.36090052572829e+54*cos(theta)**33 + 1.28950082202539e+54*cos(theta)**31 - 1.93113649675301e+53*cos(theta)**29 + 2.45627010551917e+52*cos(theta)**27 - 2.63252154820528e+51*cos(theta)**25 + 2.35467043667736e+50*cos(theta)**23 - 1.73733339305737e+49*cos(theta)**21 + 1.04240003583442e+48*cos(theta)**19 - 4.99720790938284e+46*cos(theta)**17 + 1.87223216439688e+45*cos(theta)**15 - 5.32893405426056e+43*cos(theta)**13 + 1.11019459463762e+42*cos(theta)**11 - 1.60897767338785e+40*cos(theta)**9 + 1.5076313441427e+38*cos(theta)**7 - 8.14935861698757e+35*cos(theta)**5 + 2.07679883205596e+33*cos(theta)**3 - 1.57372985505629e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl90_m_minus_14(theta, phi):
    return 2.296487729738e-27*(1.0 - cos(theta)**2)**7*(5.79309577620306e+52*cos(theta)**76 - 9.22364411294901e+53*cos(theta)**74 + 7.0375883471964e+54*cos(theta)**72 - 3.42630015532076e+55*cos(theta)**70 + 1.19573914380053e+56*cos(theta)**68 - 3.18584066617263e+56*cos(theta)**66 + 6.73927833228826e+56*cos(theta)**64 - 1.16222285011917e+57*cos(theta)**62 + 1.66497227998133e+57*cos(theta)**60 - 2.00886226010017e+57*cos(theta)**58 + 2.06251510307179e+57*cos(theta)**56 - 1.81605103415126e+57*cos(theta)**54 + 1.37938908167222e+57*cos(theta)**52 - 9.07727008584298e+56*cos(theta)**50 + 5.19124923209975e+56*cos(theta)**48 - 2.58531087585365e+56*cos(theta)**46 + 1.12239796833411e+56*cos(theta)**44 - 4.24885345355771e+55*cos(theta)**42 + 1.40163326571386e+55*cos(theta)**40 - 4.02382755707329e+54*cos(theta)**38 + 1.00310311085905e+54*cos(theta)**36 - 2.16497074286126e+53*cos(theta)**34 + 4.02969006882936e+52*cos(theta)**32 - 6.43712165584335e+51*cos(theta)**30 + 8.77239323399705e+50*cos(theta)**28 - 1.01250828777126e+50*cos(theta)**26 + 9.81112681948898e+48*cos(theta)**24 - 7.89696996844257e+47*cos(theta)**22 + 5.2120001791721e+46*cos(theta)**20 - 2.7762266163238e+45*cos(theta)**18 + 1.17014510274805e+44*cos(theta)**16 - 3.80638146732897e+42*cos(theta)**14 + 9.25162162198013e+40*cos(theta)**12 - 1.60897767338785e+39*cos(theta)**10 + 1.88453918017838e+37*cos(theta)**8 - 1.3582264361646e+35*cos(theta)**6 + 5.19199708013989e+32*cos(theta)**4 - 7.86864927528147e+29*cos(theta)**2 + 1.97209255019586e+26)*sin(14*phi)

#@torch.jit.script
def Yl90_m_minus_13(theta, phi):
    return 2.05506783318313e-25*(1.0 - cos(theta)**2)**6.5*(7.52350100805592e+50*cos(theta)**77 - 1.22981921505987e+52*cos(theta)**75 + 9.64053198246083e+52*cos(theta)**73 - 4.82577486664896e+53*cos(theta)**71 + 1.73295528087033e+54*cos(theta)**69 - 4.75498606891437e+54*cos(theta)**67 + 1.03681205112127e+55*cos(theta)**65 - 1.84479817479234e+55*cos(theta)**63 + 2.72946275406775e+55*cos(theta)**61 - 3.40485128830538e+55*cos(theta)**59 + 3.61844754924876e+55*cos(theta)**57 - 3.30191097118412e+55*cos(theta)**55 + 2.60262090881551e+55*cos(theta)**53 - 1.77985687957706e+55*cos(theta)**51 + 1.05943861879587e+55*cos(theta)**49 - 5.50066143798648e+54*cos(theta)**47 + 2.49421770740914e+54*cos(theta)**45 - 9.88105454315746e+53*cos(theta)**43 + 3.41861772125333e+53*cos(theta)**41 - 1.03175065565982e+53*cos(theta)**39 + 2.71108948880825e+52*cos(theta)**37 - 6.18563069388932e+51*cos(theta)**35 + 1.22111820267556e+51*cos(theta)**33 - 2.07649085672366e+50*cos(theta)**31 + 3.02496318413691e+49*cos(theta)**29 - 3.75003069544912e+48*cos(theta)**27 + 3.92445072779559e+47*cos(theta)**25 - 3.43346520367068e+46*cos(theta)**23 + 2.48190484722481e+45*cos(theta)**21 - 1.46117190332831e+44*cos(theta)**19 + 6.88320648675322e+42*cos(theta)**17 - 2.53758764488598e+41*cos(theta)**15 + 7.11663201690779e+39*cos(theta)**13 - 1.46270697580714e+38*cos(theta)**11 + 2.09393242242042e+36*cos(theta)**9 - 1.94032348023514e+34*cos(theta)**7 + 1.03839941602798e+32*cos(theta)**5 - 2.62288309176049e+29*cos(theta)**3 + 1.97209255019586e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl90_m_minus_12(theta, phi):
    return 1.8420103887068e-23*(1.0 - cos(theta)**2)**6*(9.64551411289221e+48*cos(theta)**78 - 1.61818317771035e+50*cos(theta)**76 + 1.30277459222444e+51*cos(theta)**74 - 6.702465092568e+51*cos(theta)**72 + 2.47565040124333e+52*cos(theta)**70 - 6.9926265719329e+52*cos(theta)**68 + 1.57092735018374e+53*cos(theta)**66 - 2.88249714811303e+53*cos(theta)**64 + 4.40235928075444e+53*cos(theta)**62 - 5.67475214717563e+53*cos(theta)**60 + 6.23870267111855e+53*cos(theta)**58 - 5.89626959140021e+53*cos(theta)**56 + 4.81966834965834e+53*cos(theta)**54 - 3.42280169149434e+53*cos(theta)**52 + 2.11887723759173e+53*cos(theta)**50 - 1.14597113291385e+53*cos(theta)**48 + 5.42221240741117e+52*cos(theta)**46 - 2.24569421435397e+52*cos(theta)**44 + 8.13956600298411e+51*cos(theta)**42 - 2.57937663914955e+51*cos(theta)**40 + 7.1344460231796e+50*cos(theta)**38 - 1.71823074830259e+50*cos(theta)**36 + 3.59152412551636e+49*cos(theta)**34 - 6.48903392726145e+48*cos(theta)**32 + 1.00832106137897e+48*cos(theta)**30 - 1.33929667694611e+47*cos(theta)**28 + 1.50940412607523e+46*cos(theta)**26 - 1.43061050152945e+45*cos(theta)**24 + 1.12813856692037e+44*cos(theta)**22 - 7.30585951664157e+42*cos(theta)**20 + 3.82400360375179e+41*cos(theta)**18 - 1.58599227805374e+40*cos(theta)**16 + 5.08330858350557e+38*cos(theta)**14 - 1.21892247983928e+37*cos(theta)**12 + 2.09393242242042e+35*cos(theta)**10 - 2.42540435029392e+33*cos(theta)**8 + 1.73066569337996e+31*cos(theta)**6 - 6.55720772940123e+28*cos(theta)**4 + 9.86046275097929e+25*cos(theta)**2 - 2.45468328378872e+22)*sin(12*phi)

#@torch.jit.script
def Yl90_m_minus_11(theta, phi):
    return 1.65350573959125e-21*(1.0 - cos(theta)**2)**5.5*(1.22095115353066e+47*cos(theta)**79 - 2.10153659442903e+48*cos(theta)**77 + 1.73703278963258e+49*cos(theta)**75 - 9.18145903091507e+49*cos(theta)**73 + 3.48683155104694e+50*cos(theta)**71 - 1.01342414085984e+51*cos(theta)**69 + 2.34466768684141e+51*cos(theta)**67 - 4.43461099709697e+51*cos(theta)**65 + 6.9878718742134e+51*cos(theta)**63 - 9.30287237241907e+51*cos(theta)**61 + 1.05740723239297e+52*cos(theta)**59 - 1.03443326164916e+52*cos(theta)**57 + 8.76303336301517e+51*cos(theta)**55 - 6.45811639904592e+51*cos(theta)**53 + 4.15466125017987e+51*cos(theta)**51 - 2.33871659778337e+51*cos(theta)**49 + 1.1536622143428e+51*cos(theta)**47 - 4.99043158745326e+50*cos(theta)**45 + 1.89292232627538e+50*cos(theta)**43 - 6.29116253451109e+49*cos(theta)**41 + 1.82934513414862e+49*cos(theta)**39 - 4.6438668873043e+48*cos(theta)**37 + 1.02614975014753e+48*cos(theta)**35 - 1.96637391735195e+47*cos(theta)**33 + 3.25264858509346e+46*cos(theta)**31 - 4.61826440326246e+45*cos(theta)**29 + 5.59038565213047e+44*cos(theta)**27 - 5.72244200611781e+43*cos(theta)**25 + 4.90495029095812e+42*cos(theta)**23 - 3.47898072221027e+41*cos(theta)**21 + 2.01263347565884e+40*cos(theta)**19 - 9.32936634149257e+38*cos(theta)**17 + 3.38887238900371e+37*cos(theta)**15 - 9.37632676799446e+35*cos(theta)**13 + 1.90357492947311e+34*cos(theta)**11 - 2.6948937225488e+32*cos(theta)**9 + 2.47237956197138e+30*cos(theta)**7 - 1.31144154588025e+28*cos(theta)**5 + 3.2868209169931e+25*cos(theta)**3 - 2.45468328378872e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl90_m_minus_10(theta, phi):
    return 1.48631680153858e-19*(1.0 - cos(theta)**2)**5*(1.52618894191332e+45*cos(theta)**80 - 2.69427768516542e+46*cos(theta)**78 + 2.28556946004287e+47*cos(theta)**76 - 1.24073770688042e+48*cos(theta)**74 + 4.8428215986763e+48*cos(theta)**72 - 1.44774877265692e+49*cos(theta)**70 + 3.44804071594325e+49*cos(theta)**68 - 6.71910757135904e+49*cos(theta)**66 + 1.09185498034584e+50*cos(theta)**64 - 1.50046328587404e+50*cos(theta)**62 + 1.76234538732162e+50*cos(theta)**60 - 1.78350562353303e+50*cos(theta)**58 + 1.56482738625271e+50*cos(theta)**56 - 1.1959474813048e+50*cos(theta)**54 + 7.98973317342282e+49*cos(theta)**52 - 4.67743319556674e+49*cos(theta)**50 + 2.40346294654751e+49*cos(theta)**48 - 1.08487643205506e+49*cos(theta)**46 + 4.3020961960804e+48*cos(theta)**44 - 1.49789584155026e+48*cos(theta)**42 + 4.57336283537154e+47*cos(theta)**40 - 1.22207023350113e+47*cos(theta)**38 + 2.85041597263203e+46*cos(theta)**36 - 5.78345269809398e+45*cos(theta)**34 + 1.01645268284171e+45*cos(theta)**32 - 1.53942146775415e+44*cos(theta)**30 + 1.99656630433231e+43*cos(theta)**28 - 2.20093923312223e+42*cos(theta)**26 + 2.04372928789922e+41*cos(theta)**24 - 1.58135487373194e+40*cos(theta)**22 + 1.00631673782942e+39*cos(theta)**20 - 5.18298130082921e+37*cos(theta)**18 + 2.11804524312732e+36*cos(theta)**16 - 6.69737626285319e+34*cos(theta)**14 + 1.58631244122759e+33*cos(theta)**12 - 2.6948937225488e+31*cos(theta)**10 + 3.09047445246422e+29*cos(theta)**8 - 2.18573590980041e+27*cos(theta)**6 + 8.21705229248274e+24*cos(theta)**4 - 1.22734164189436e+22*cos(theta)**2 + 3.03797436112465e+18)*sin(10*phi)

#@torch.jit.script
def Yl90_m_minus_9(theta, phi):
    return 1.33768512138472e-17*(1.0 - cos(theta)**2)**4.5*(1.88418387890534e+43*cos(theta)**81 - 3.41047808248788e+44*cos(theta)**79 + 2.9682720260297e+45*cos(theta)**77 - 1.65431694250722e+46*cos(theta)**75 + 6.63400218996754e+46*cos(theta)**73 - 2.03908277839002e+47*cos(theta)**71 + 4.99716045788876e+47*cos(theta)**69 - 1.00285187632224e+48*cos(theta)**67 + 1.67977689283976e+48*cos(theta)**65 - 2.38168775535562e+48*cos(theta)**63 + 2.88909079888791e+48*cos(theta)**61 - 3.02289088734412e+48*cos(theta)**59 + 2.74531120395212e+48*cos(theta)**57 - 2.17444996600873e+48*cos(theta)**55 + 1.50749682517412e+48*cos(theta)**53 - 9.17143763836615e+47*cos(theta)**51 + 4.90502642152552e+47*cos(theta)**49 - 2.30824772777672e+47*cos(theta)**47 + 9.56021376906755e+46*cos(theta)**45 - 3.48347870127967e+46*cos(theta)**43 + 1.11545435009062e+46*cos(theta)**41 - 3.13351341923367e+45*cos(theta)**39 + 7.70382695305955e+44*cos(theta)**37 - 1.65241505659828e+44*cos(theta)**35 + 3.08015964497486e+43*cos(theta)**33 - 4.96587570243276e+42*cos(theta)**31 + 6.88471139424935e+41*cos(theta)**29 - 8.15162678934161e+40*cos(theta)**27 + 8.17491715159687e+39*cos(theta)**25 - 6.87545597274758e+38*cos(theta)**23 + 4.79198446585437e+37*cos(theta)**21 - 2.72788489517327e+36*cos(theta)**19 + 1.24590896654548e+35*cos(theta)**17 - 4.46491750856879e+33*cos(theta)**15 + 1.22024033940584e+32*cos(theta)**13 - 2.44990338413527e+30*cos(theta)**11 + 3.43386050273802e+28*cos(theta)**9 - 3.12247987114344e+26*cos(theta)**7 + 1.64341045849655e+24*cos(theta)**5 - 4.09113880631453e+21*cos(theta)**3 + 3.03797436112465e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl90_m_minus_8(theta, phi):
    return 1.20525355203382e-15*(1.0 - cos(theta)**2)**4*(2.29778521817724e+41*cos(theta)**82 - 4.26309760310984e+42*cos(theta)**80 + 3.80547695644834e+43*cos(theta)**78 - 2.17673281908845e+44*cos(theta)**76 + 8.96486782428046e+44*cos(theta)**74 - 2.83205941443059e+45*cos(theta)**72 + 7.1388006541268e+45*cos(theta)**70 - 1.47478217106212e+46*cos(theta)**68 + 2.54511650430267e+46*cos(theta)**66 - 3.72138711774316e+46*cos(theta)**64 + 4.65982386917405e+46*cos(theta)**62 - 5.03815147890687e+46*cos(theta)**60 + 4.73329517922779e+46*cos(theta)**58 - 3.88294636787273e+46*cos(theta)**56 + 2.79166078735948e+46*cos(theta)**54 - 1.76373800737811e+46*cos(theta)**52 + 9.81005284305105e+45*cos(theta)**50 - 4.80884943286816e+45*cos(theta)**48 + 2.07830734110164e+45*cos(theta)**46 - 7.9169970483629e+44*cos(theta)**44 + 2.65584369069195e+44*cos(theta)**42 - 7.83378354808417e+43*cos(theta)**40 + 2.02732288238409e+43*cos(theta)**38 - 4.59004182388411e+42*cos(theta)**36 + 9.05929307345548e+41*cos(theta)**34 - 1.55183615701024e+41*cos(theta)**32 + 2.29490379808312e+40*cos(theta)**30 - 2.91129528190772e+39*cos(theta)**28 + 3.14419890446033e+38*cos(theta)**26 - 2.86477332197816e+37*cos(theta)**24 + 2.17817475720653e+36*cos(theta)**22 - 1.36394244758663e+35*cos(theta)**20 + 6.92171648080823e+33*cos(theta)**18 - 2.79057344285549e+32*cos(theta)**16 + 8.71600242432741e+30*cos(theta)**14 - 2.04158615344606e+29*cos(theta)**12 + 3.43386050273802e+27*cos(theta)**10 - 3.9030998389293e+25*cos(theta)**8 + 2.73901743082758e+23*cos(theta)**6 - 1.02278470157863e+21*cos(theta)**4 + 1.51898718056233e+18*cos(theta)**2 - 374226947662559.0)*sin(8*phi)

#@torch.jit.script
def Yl90_m_minus_7(theta, phi):
    return 1.08700240285979e-13*(1.0 - cos(theta)**2)**3.5*(2.76841592551475e+39*cos(theta)**83 - 5.26308346062944e+40*cos(theta)**81 + 4.8170594385422e+41*cos(theta)**79 - 2.82692573907591e+42*cos(theta)**77 + 1.19531570990406e+43*cos(theta)**75 - 3.87953344442546e+43*cos(theta)**73 + 1.00546488086293e+44*cos(theta)**71 - 2.13736546530743e+44*cos(theta)**69 + 3.79868134970547e+44*cos(theta)**67 - 5.7252109503741e+44*cos(theta)**65 + 7.39654582408579e+44*cos(theta)**63 - 8.25926471951946e+44*cos(theta)**61 + 8.02253420208101e+44*cos(theta)**59 - 6.81218661030303e+44*cos(theta)**57 + 5.07574688610814e+44*cos(theta)**55 - 3.32780756109077e+44*cos(theta)**53 + 1.92353977314726e+44*cos(theta)**51 - 9.81397843442482e+43*cos(theta)**49 + 4.42193051298222e+43*cos(theta)**47 - 1.75933267741398e+43*cos(theta)**45 + 6.17638067602779e+42*cos(theta)**43 - 1.91067891416687e+42*cos(theta)**41 + 5.19826380098485e+41*cos(theta)**39 - 1.240551844293e+41*cos(theta)**37 + 2.58836944955871e+40*cos(theta)**35 - 4.70253380912193e+39*cos(theta)**33 + 7.40291547768747e+38*cos(theta)**31 - 1.00389492479576e+38*cos(theta)**29 + 1.16451811276309e+37*cos(theta)**27 - 1.14590932879126e+36*cos(theta)**25 + 9.47032503133275e+34*cos(theta)**23 - 6.49496403612682e+33*cos(theta)**21 + 3.6430086741096e+32*cos(theta)**19 - 1.641513789915e+31*cos(theta)**17 + 5.81066828288494e+29*cos(theta)**15 - 1.5704508872662e+28*cos(theta)**13 + 3.12169136612548e+26*cos(theta)**11 - 4.33677759881033e+24*cos(theta)**9 + 3.9128820440394e+22*cos(theta)**7 - 2.04556940315727e+20*cos(theta)**5 + 5.06329060187442e+17*cos(theta)**3 - 374226947662559.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl90_m_minus_6(theta, phi):
    return 9.81196553994633e-12*(1.0 - cos(theta)**2)**3*(3.29573324466042e+37*cos(theta)**84 - 6.41839446418224e+38*cos(theta)**82 + 6.02132429817775e+39*cos(theta)**80 - 3.62426376804603e+40*cos(theta)**78 + 1.57278382882113e+41*cos(theta)**76 - 5.24261276273711e+41*cos(theta)**74 + 1.39647900119851e+42*cos(theta)**72 - 3.05337923615347e+42*cos(theta)**70 + 5.58629610250805e+42*cos(theta)**68 - 8.67456204602136e+42*cos(theta)**66 + 1.1557102850134e+43*cos(theta)**64 - 1.33213947089024e+43*cos(theta)**62 + 1.33708903368017e+43*cos(theta)**60 - 1.17451493281087e+43*cos(theta)**58 + 9.06383372519311e+42*cos(theta)**56 - 6.16260659461253e+42*cos(theta)**54 + 3.69911494836012e+42*cos(theta)**52 - 1.96279568688496e+42*cos(theta)**50 + 9.21235523537962e+41*cos(theta)**48 - 3.82463625524778e+41*cos(theta)**46 + 1.40372288091541e+41*cos(theta)**44 - 4.54923550992112e+40*cos(theta)**42 + 1.29956595024621e+40*cos(theta)**40 - 3.26461011656053e+39*cos(theta)**38 + 7.18991513766308e+38*cos(theta)**36 - 1.38309817915351e+38*cos(theta)**34 + 2.31341108677734e+37*cos(theta)**32 - 3.34631641598588e+36*cos(theta)**30 + 4.15899325986817e+35*cos(theta)**28 - 4.40734357227409e+34*cos(theta)**26 + 3.94596876305531e+33*cos(theta)**24 - 2.95225638005765e+32*cos(theta)**22 + 1.8215043370548e+31*cos(theta)**20 - 9.11952105508331e+29*cos(theta)**18 + 3.63166767680309e+28*cos(theta)**16 - 1.12175063376157e+27*cos(theta)**14 + 2.60140947177123e+25*cos(theta)**12 - 4.33677759881033e+23*cos(theta)**10 + 4.89110255504925e+21*cos(theta)**8 - 3.40928233859544e+19*cos(theta)**6 + 1.26582265046861e+17*cos(theta)**4 - 187113473831279.0*cos(theta)**2 + 45928687734.7274)*sin(6*phi)

#@torch.jit.script
def Yl90_m_minus_5(theta, phi):
    return 8.86341519335458e-10*(1.0 - cos(theta)**2)**2.5*(3.87733322901225e+35*cos(theta)**85 - 7.73300537853282e+36*cos(theta)**83 + 7.43373370145401e+37*cos(theta)**81 - 4.58767565575447e+38*cos(theta)**79 + 2.04257640106641e+39*cos(theta)**77 - 6.99015035031615e+39*cos(theta)**75 + 1.91298493314865e+40*cos(theta)**73 - 4.30053413542742e+40*cos(theta)**71 + 8.09608130798268e+40*cos(theta)**69 - 1.29471075313752e+41*cos(theta)**67 + 1.77801582309754e+41*cos(theta)**65 - 2.11450709665117e+41*cos(theta)**63 + 2.19194923554126e+41*cos(theta)**61 - 1.99070327595062e+41*cos(theta)**59 + 1.59014626757774e+41*cos(theta)**57 - 1.12047392629319e+41*cos(theta)**55 + 6.97946216671721e+40*cos(theta)**53 - 3.84861899389208e+40*cos(theta)**51 + 1.88007249701625e+40*cos(theta)**49 - 8.13752394733569e+39*cos(theta)**47 + 3.11938417981202e+39*cos(theta)**45 - 1.05796174649328e+39*cos(theta)**43 + 3.16967304938101e+38*cos(theta)**41 - 8.37079517066804e+37*cos(theta)**39 + 1.94322030747651e+37*cos(theta)**37 - 3.95170908329574e+36*cos(theta)**35 + 7.01033662659799e+35*cos(theta)**33 - 1.07945690838254e+35*cos(theta)**31 + 1.43413560685109e+34*cos(theta)**29 - 1.63234947121262e+33*cos(theta)**27 + 1.57838750522212e+32*cos(theta)**25 - 1.28358973045985e+31*cos(theta)**23 + 8.67383017645142e+29*cos(theta)**21 - 4.79974792372806e+28*cos(theta)**19 + 2.13627510400182e+27*cos(theta)**17 - 7.47833755841048e+25*cos(theta)**15 + 2.00108420905479e+24*cos(theta)**13 - 3.94252508982758e+22*cos(theta)**11 + 5.43455839449917e+20*cos(theta)**9 - 4.87040334085063e+18*cos(theta)**7 + 2.53164530093721e+16*cos(theta)**5 - 62371157943759.8*cos(theta)**3 + 45928687734.7274*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl90_m_minus_4(theta, phi):
    return 8.01146836122801e-8*(1.0 - cos(theta)**2)**2*(4.50852701047937e+33*cos(theta)**86 - 9.20595878396764e+34*cos(theta)**84 + 9.0655289042122e+35*cos(theta)**82 - 5.73459456969309e+36*cos(theta)**80 + 2.61868769367488e+37*cos(theta)**78 - 9.19756625041598e+37*cos(theta)**76 + 2.5851147745252e+38*cos(theta)**74 - 5.97296407698252e+38*cos(theta)**72 + 1.15658304399753e+39*cos(theta)**70 - 1.90398640167282e+39*cos(theta)**68 + 2.69396336832961e+39*cos(theta)**66 - 3.30391733851745e+39*cos(theta)**64 + 3.53540199280848e+39*cos(theta)**62 - 3.31783879325104e+39*cos(theta)**60 + 2.74163149582369e+39*cos(theta)**58 - 2.00084629695212e+39*cos(theta)**56 + 1.29249299383652e+39*cos(theta)**54 - 7.40119037286939e+38*cos(theta)**52 + 3.7601449940325e+38*cos(theta)**50 - 1.69531748902827e+38*cos(theta)**48 + 6.78126995611308e+37*cos(theta)**46 - 2.40445851475746e+37*cos(theta)**44 + 7.5468405937643e+36*cos(theta)**42 - 2.09269879266701e+36*cos(theta)**40 + 5.11373765125397e+35*cos(theta)**38 - 1.09769696758215e+35*cos(theta)**36 + 2.06186371370529e+34*cos(theta)**34 - 3.37330283869544e+33*cos(theta)**32 + 4.78045202283697e+32*cos(theta)**30 - 5.82981954004509e+31*cos(theta)**28 + 6.07072117393125e+30*cos(theta)**26 - 5.34829054358269e+29*cos(theta)**24 + 3.94265008020519e+28*cos(theta)**22 - 2.39987396186403e+27*cos(theta)**20 + 1.18681950222323e+26*cos(theta)**18 - 4.67396097400655e+24*cos(theta)**16 + 1.42934586361057e+23*cos(theta)**14 - 3.28543757485631e+21*cos(theta)**12 + 5.43455839449917e+19*cos(theta)**10 - 6.08800417606329e+17*cos(theta)**8 + 4.21940883489535e+15*cos(theta)**6 - 15592789485940.0*cos(theta)**4 + 22964343867.3637*cos(theta)**2 - 5621626.40571939)*sin(4*phi)

#@torch.jit.script
def Yl90_m_minus_3(theta, phi):
    return 7.24495471157403e-6*(1.0 - cos(theta)**2)**1.5*(5.18221495457398e+31*cos(theta)**87 - 1.08305397458443e+33*cos(theta)**85 + 1.09223239809786e+34*cos(theta)**83 - 7.07974638233715e+34*cos(theta)**81 + 3.31479454895554e+35*cos(theta)**79 - 1.19448912343065e+36*cos(theta)**77 + 3.44681969936694e+36*cos(theta)**75 - 8.18214257120894e+36*cos(theta)**73 + 1.62899020281342e+37*cos(theta)**71 - 2.75940058213452e+37*cos(theta)**69 + 4.02084084825315e+37*cos(theta)**67 - 5.08294975156531e+37*cos(theta)**65 + 5.6117491949341e+37*cos(theta)**63 - 5.43907998893613e+37*cos(theta)**61 + 4.64683304376896e+37*cos(theta)**59 - 3.51025666131951e+37*cos(theta)**57 + 2.34998726152095e+37*cos(theta)**55 - 1.39645101374894e+37*cos(theta)**53 + 7.37283332163235e+36*cos(theta)**51 - 3.45983161026177e+36*cos(theta)**49 + 1.44282339491768e+36*cos(theta)**47 - 5.34324114390547e+35*cos(theta)**45 + 1.75507920785216e+35*cos(theta)**43 - 5.1041433967488e+34*cos(theta)**41 + 1.31121478237281e+34*cos(theta)**39 - 2.96674856103284e+33*cos(theta)**37 + 5.89103918201512e+32*cos(theta)**35 - 1.02221298142286e+32*cos(theta)**33 + 1.54208129768935e+31*cos(theta)**31 - 2.01028260001555e+30*cos(theta)**29 + 2.24841524960417e+29*cos(theta)**27 - 2.13931621743308e+28*cos(theta)**25 + 1.71419568704574e+27*cos(theta)**23 - 1.14279712469716e+26*cos(theta)**21 + 6.24641843275385e+24*cos(theta)**19 - 2.74938880823915e+23*cos(theta)**17 + 9.52897242407044e+21*cos(theta)**15 - 2.5272596729664e+20*cos(theta)**13 + 4.94050763136288e+18*cos(theta)**11 - 6.76444908451477e+16*cos(theta)**9 + 602772690699336.0*cos(theta)**7 - 3118557897187.99*cos(theta)**5 + 7654781289.12123*cos(theta)**3 - 5621626.40571939*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl90_m_minus_2(theta, phi):
    return 0.00065541818256458*(1.0 - cos(theta)**2)*(5.88888063019771e+29*cos(theta)**88 - 1.25936508672608e+31*cos(theta)**86 + 1.30027666440221e+32*cos(theta)**84 - 8.63383705163067e+32*cos(theta)**82 + 4.14349318619443e+33*cos(theta)**80 - 1.53139631209057e+34*cos(theta)**78 + 4.53528907811439e+34*cos(theta)**76 - 1.10569494205526e+35*cos(theta)**74 + 2.26248639279641e+35*cos(theta)**72 - 3.94200083162074e+35*cos(theta)**70 + 5.91300124743111e+35*cos(theta)**68 - 7.70143901752319e+35*cos(theta)**66 + 8.76835811708453e+35*cos(theta)**64 - 8.7727096595744e+35*cos(theta)**62 + 7.74472173961493e+35*cos(theta)**60 - 6.05216665744743e+35*cos(theta)**58 + 4.19640582414455e+35*cos(theta)**56 - 2.58602039583137e+35*cos(theta)**54 + 1.41785256185237e+35*cos(theta)**52 - 6.91966322052355e+34*cos(theta)**50 + 3.00588207274516e+34*cos(theta)**48 - 1.16157416171858e+34*cos(theta)**46 + 3.98881638148219e+33*cos(theta)**44 - 1.21527223732114e+33*cos(theta)**42 + 3.27803695593203e+32*cos(theta)**40 - 7.80723305534957e+31*cos(theta)**38 + 1.63639977278198e+31*cos(theta)**36 - 3.00650876889077e+30*cos(theta)**34 + 4.81900405527921e+29*cos(theta)**32 - 6.70094200005183e+28*cos(theta)**30 + 8.03005446287202e+27*cos(theta)**28 - 8.22813929781953e+26*cos(theta)**26 + 7.14248202935723e+25*cos(theta)**24 - 5.19453238498708e+24*cos(theta)**22 + 3.12320921637693e+23*cos(theta)**20 - 1.52743822679953e+22*cos(theta)**18 + 5.95560776504402e+20*cos(theta)**16 - 1.80518548069028e+19*cos(theta)**14 + 4.1170896928024e+17*cos(theta)**12 - 6.76444908451477e+15*cos(theta)**10 + 75346586337417.0*cos(theta)**8 - 519759649531.332*cos(theta)**6 + 1913695322.28031*cos(theta)**4 - 2810813.20285969*cos(theta)**2 + 686.90449727754)*sin(2*phi)

#@torch.jit.script
def Yl90_m_minus_1(theta, phi):
    return 0.0593071974988607*(1.0 - cos(theta)**2)**0.5*(6.61671980921091e+27*cos(theta)**89 - 1.44754607669664e+29*cos(theta)**87 + 1.52973725223789e+30*cos(theta)**85 - 1.04022133152177e+31*cos(theta)**83 + 5.11542368665979e+31*cos(theta)**81 - 1.93847634441845e+32*cos(theta)**79 + 5.88998581573297e+32*cos(theta)**77 - 1.47425992274035e+33*cos(theta)**75 + 3.09929642848823e+33*cos(theta)**73 - 5.55211384735315e+33*cos(theta)**71 + 8.56956702526248e+33*cos(theta)**69 - 1.14946851007809e+34*cos(theta)**67 + 1.34897817185916e+34*cos(theta)**65 - 1.39249359675784e+34*cos(theta)**63 + 1.26962651469097e+34*cos(theta)**61 - 1.0257909588894e+34*cos(theta)**59 + 7.36211548095535e+33*cos(theta)**57 - 4.70185526514795e+33*cos(theta)**55 + 2.67519351292901e+33*cos(theta)**53 - 1.35679670990658e+33*cos(theta)**51 + 6.134453209684e+32*cos(theta)**49 - 2.47143438663528e+32*cos(theta)**47 + 8.86403640329375e+31*cos(theta)**45 - 2.82621450539801e+31*cos(theta)**43 + 7.9952120876391e+30*cos(theta)**41 - 2.00185462957681e+30*cos(theta)**39 + 4.42270208859994e+29*cos(theta)**37 - 8.59002505397363e+28*cos(theta)**35 + 1.46030425917552e+28*cos(theta)**33 - 2.16159419356511e+27*cos(theta)**31 + 2.76898429754208e+26*cos(theta)**29 - 3.04745899919242e+25*cos(theta)**27 + 2.85699281174289e+24*cos(theta)**25 - 2.25849234129873e+23*cos(theta)**23 + 1.48724248398901e+22*cos(theta)**21 - 8.03914856210277e+20*cos(theta)**19 + 3.50329868532001e+19*cos(theta)**17 - 1.20345698712685e+18*cos(theta)**15 + 3.16699207138646e+16*cos(theta)**13 - 614949916774070.0*cos(theta)**11 + 8371842926379.67*cos(theta)**9 - 74251378504.476*cos(theta)**7 + 382739064.456062*cos(theta)**5 - 936937.734286565*cos(theta)**3 + 686.90449727754*cos(theta))*sin(phi)

#@torch.jit.script
def Yl90_m0(theta, phi):
    return 8.76565680656663e+26*cos(theta)**90 - 1.96125449778209e+28*cos(theta)**88 + 2.12081418573724e+29*cos(theta)**86 - 1.47649063787993e+30*cos(theta)**84 + 7.43792827116968e+30*cos(theta)**82 - 2.88904792848591e+31*cos(theta)**80 + 9.00334462920658e+31*cos(theta)**78 - 2.31283523708361e+32*cos(theta)**76 + 4.99362153461233e+32*cos(theta)**74 - 9.19411844920784e+32*cos(theta)**72 + 1.45963768671896e+33*cos(theta)**70 - 2.01545169435465e+33*cos(theta)**68 + 2.43694212300419e+33*cos(theta)**66 - 2.59416419545608e+33*cos(theta)**64 + 2.44156630160572e+33*cos(theta)**62 - 2.03841142443109e+33*cos(theta)**60 + 1.51341787803818e+33*cos(theta)**58 - 1.0010723298908e+33*cos(theta)**56 + 5.90671029897255e+32*cos(theta)**54 - 3.11096887663957e+32*cos(theta)**52 + 1.46281728029222e+32*cos(theta)**50 - 6.13892144007528e+31*cos(theta)**48 + 2.29751273536991e+31*cos(theta)**46 - 7.65837578456637e+30*cos(theta)**44 + 2.26968154517537e+30*cos(theta)**42 - 5.96701010807938e+29*cos(theta)**40 + 1.38767676932079e+29*cos(theta)**38 - 2.84495995576702e+28*cos(theta)**36 + 5.12092792038064e+27*cos(theta)**34 - 8.05394046350866e+26*cos(theta)**32 + 1.1004833250414e+26*cos(theta)**30 - 1.29766941283006e+25*cos(theta)**28 + 1.31014700333805e+24*cos(theta)**26 - 1.12199677492718e+23*cos(theta)**24 + 8.06015382300629e+21*cos(theta)**22 - 4.7925238947605e+20*cos(theta)**20 + 2.32053909277394e+19*cos(theta)**18 - 8.96798386447115e+17*cos(theta)**16 + 2.69713800435223e+16*cos(theta)**14 - 611002136908271.0*cos(theta)**12 + 9981718078204.43*cos(theta)**10 - 110662062951.269*cos(theta)**8 + 760564006.537929*cos(theta)**6 - 2792768.68985776*cos(theta)**4 + 4094.96875345712*cos(theta)**2 - 0.999992369586599

#@torch.jit.script
def Yl90_m1(theta, phi):
    return 0.0593071974988607*(1.0 - cos(theta)**2)**0.5*(6.61671980921091e+27*cos(theta)**89 - 1.44754607669664e+29*cos(theta)**87 + 1.52973725223789e+30*cos(theta)**85 - 1.04022133152177e+31*cos(theta)**83 + 5.11542368665979e+31*cos(theta)**81 - 1.93847634441845e+32*cos(theta)**79 + 5.88998581573297e+32*cos(theta)**77 - 1.47425992274035e+33*cos(theta)**75 + 3.09929642848823e+33*cos(theta)**73 - 5.55211384735315e+33*cos(theta)**71 + 8.56956702526248e+33*cos(theta)**69 - 1.14946851007809e+34*cos(theta)**67 + 1.34897817185916e+34*cos(theta)**65 - 1.39249359675784e+34*cos(theta)**63 + 1.26962651469097e+34*cos(theta)**61 - 1.0257909588894e+34*cos(theta)**59 + 7.36211548095535e+33*cos(theta)**57 - 4.70185526514795e+33*cos(theta)**55 + 2.67519351292901e+33*cos(theta)**53 - 1.35679670990658e+33*cos(theta)**51 + 6.134453209684e+32*cos(theta)**49 - 2.47143438663528e+32*cos(theta)**47 + 8.86403640329375e+31*cos(theta)**45 - 2.82621450539801e+31*cos(theta)**43 + 7.9952120876391e+30*cos(theta)**41 - 2.00185462957681e+30*cos(theta)**39 + 4.42270208859994e+29*cos(theta)**37 - 8.59002505397363e+28*cos(theta)**35 + 1.46030425917552e+28*cos(theta)**33 - 2.16159419356511e+27*cos(theta)**31 + 2.76898429754208e+26*cos(theta)**29 - 3.04745899919242e+25*cos(theta)**27 + 2.85699281174289e+24*cos(theta)**25 - 2.25849234129873e+23*cos(theta)**23 + 1.48724248398901e+22*cos(theta)**21 - 8.03914856210277e+20*cos(theta)**19 + 3.50329868532001e+19*cos(theta)**17 - 1.20345698712685e+18*cos(theta)**15 + 3.16699207138646e+16*cos(theta)**13 - 614949916774070.0*cos(theta)**11 + 8371842926379.67*cos(theta)**9 - 74251378504.476*cos(theta)**7 + 382739064.456062*cos(theta)**5 - 936937.734286565*cos(theta)**3 + 686.90449727754*cos(theta))*cos(phi)

#@torch.jit.script
def Yl90_m2(theta, phi):
    return 0.00065541818256458*(1.0 - cos(theta)**2)*(5.88888063019771e+29*cos(theta)**88 - 1.25936508672608e+31*cos(theta)**86 + 1.30027666440221e+32*cos(theta)**84 - 8.63383705163067e+32*cos(theta)**82 + 4.14349318619443e+33*cos(theta)**80 - 1.53139631209057e+34*cos(theta)**78 + 4.53528907811439e+34*cos(theta)**76 - 1.10569494205526e+35*cos(theta)**74 + 2.26248639279641e+35*cos(theta)**72 - 3.94200083162074e+35*cos(theta)**70 + 5.91300124743111e+35*cos(theta)**68 - 7.70143901752319e+35*cos(theta)**66 + 8.76835811708453e+35*cos(theta)**64 - 8.7727096595744e+35*cos(theta)**62 + 7.74472173961493e+35*cos(theta)**60 - 6.05216665744743e+35*cos(theta)**58 + 4.19640582414455e+35*cos(theta)**56 - 2.58602039583137e+35*cos(theta)**54 + 1.41785256185237e+35*cos(theta)**52 - 6.91966322052355e+34*cos(theta)**50 + 3.00588207274516e+34*cos(theta)**48 - 1.16157416171858e+34*cos(theta)**46 + 3.98881638148219e+33*cos(theta)**44 - 1.21527223732114e+33*cos(theta)**42 + 3.27803695593203e+32*cos(theta)**40 - 7.80723305534957e+31*cos(theta)**38 + 1.63639977278198e+31*cos(theta)**36 - 3.00650876889077e+30*cos(theta)**34 + 4.81900405527921e+29*cos(theta)**32 - 6.70094200005183e+28*cos(theta)**30 + 8.03005446287202e+27*cos(theta)**28 - 8.22813929781953e+26*cos(theta)**26 + 7.14248202935723e+25*cos(theta)**24 - 5.19453238498708e+24*cos(theta)**22 + 3.12320921637693e+23*cos(theta)**20 - 1.52743822679953e+22*cos(theta)**18 + 5.95560776504402e+20*cos(theta)**16 - 1.80518548069028e+19*cos(theta)**14 + 4.1170896928024e+17*cos(theta)**12 - 6.76444908451477e+15*cos(theta)**10 + 75346586337417.0*cos(theta)**8 - 519759649531.332*cos(theta)**6 + 1913695322.28031*cos(theta)**4 - 2810813.20285969*cos(theta)**2 + 686.90449727754)*cos(2*phi)

#@torch.jit.script
def Yl90_m3(theta, phi):
    return 7.24495471157403e-6*(1.0 - cos(theta)**2)**1.5*(5.18221495457398e+31*cos(theta)**87 - 1.08305397458443e+33*cos(theta)**85 + 1.09223239809786e+34*cos(theta)**83 - 7.07974638233715e+34*cos(theta)**81 + 3.31479454895554e+35*cos(theta)**79 - 1.19448912343065e+36*cos(theta)**77 + 3.44681969936694e+36*cos(theta)**75 - 8.18214257120894e+36*cos(theta)**73 + 1.62899020281342e+37*cos(theta)**71 - 2.75940058213452e+37*cos(theta)**69 + 4.02084084825315e+37*cos(theta)**67 - 5.08294975156531e+37*cos(theta)**65 + 5.6117491949341e+37*cos(theta)**63 - 5.43907998893613e+37*cos(theta)**61 + 4.64683304376896e+37*cos(theta)**59 - 3.51025666131951e+37*cos(theta)**57 + 2.34998726152095e+37*cos(theta)**55 - 1.39645101374894e+37*cos(theta)**53 + 7.37283332163235e+36*cos(theta)**51 - 3.45983161026177e+36*cos(theta)**49 + 1.44282339491768e+36*cos(theta)**47 - 5.34324114390547e+35*cos(theta)**45 + 1.75507920785216e+35*cos(theta)**43 - 5.1041433967488e+34*cos(theta)**41 + 1.31121478237281e+34*cos(theta)**39 - 2.96674856103284e+33*cos(theta)**37 + 5.89103918201512e+32*cos(theta)**35 - 1.02221298142286e+32*cos(theta)**33 + 1.54208129768935e+31*cos(theta)**31 - 2.01028260001555e+30*cos(theta)**29 + 2.24841524960417e+29*cos(theta)**27 - 2.13931621743308e+28*cos(theta)**25 + 1.71419568704574e+27*cos(theta)**23 - 1.14279712469716e+26*cos(theta)**21 + 6.24641843275385e+24*cos(theta)**19 - 2.74938880823915e+23*cos(theta)**17 + 9.52897242407044e+21*cos(theta)**15 - 2.5272596729664e+20*cos(theta)**13 + 4.94050763136288e+18*cos(theta)**11 - 6.76444908451477e+16*cos(theta)**9 + 602772690699336.0*cos(theta)**7 - 3118557897187.99*cos(theta)**5 + 7654781289.12123*cos(theta)**3 - 5621626.40571939*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl90_m4(theta, phi):
    return 8.01146836122801e-8*(1.0 - cos(theta)**2)**2*(4.50852701047937e+33*cos(theta)**86 - 9.20595878396764e+34*cos(theta)**84 + 9.0655289042122e+35*cos(theta)**82 - 5.73459456969309e+36*cos(theta)**80 + 2.61868769367488e+37*cos(theta)**78 - 9.19756625041598e+37*cos(theta)**76 + 2.5851147745252e+38*cos(theta)**74 - 5.97296407698252e+38*cos(theta)**72 + 1.15658304399753e+39*cos(theta)**70 - 1.90398640167282e+39*cos(theta)**68 + 2.69396336832961e+39*cos(theta)**66 - 3.30391733851745e+39*cos(theta)**64 + 3.53540199280848e+39*cos(theta)**62 - 3.31783879325104e+39*cos(theta)**60 + 2.74163149582369e+39*cos(theta)**58 - 2.00084629695212e+39*cos(theta)**56 + 1.29249299383652e+39*cos(theta)**54 - 7.40119037286939e+38*cos(theta)**52 + 3.7601449940325e+38*cos(theta)**50 - 1.69531748902827e+38*cos(theta)**48 + 6.78126995611308e+37*cos(theta)**46 - 2.40445851475746e+37*cos(theta)**44 + 7.5468405937643e+36*cos(theta)**42 - 2.09269879266701e+36*cos(theta)**40 + 5.11373765125397e+35*cos(theta)**38 - 1.09769696758215e+35*cos(theta)**36 + 2.06186371370529e+34*cos(theta)**34 - 3.37330283869544e+33*cos(theta)**32 + 4.78045202283697e+32*cos(theta)**30 - 5.82981954004509e+31*cos(theta)**28 + 6.07072117393125e+30*cos(theta)**26 - 5.34829054358269e+29*cos(theta)**24 + 3.94265008020519e+28*cos(theta)**22 - 2.39987396186403e+27*cos(theta)**20 + 1.18681950222323e+26*cos(theta)**18 - 4.67396097400655e+24*cos(theta)**16 + 1.42934586361057e+23*cos(theta)**14 - 3.28543757485631e+21*cos(theta)**12 + 5.43455839449917e+19*cos(theta)**10 - 6.08800417606329e+17*cos(theta)**8 + 4.21940883489535e+15*cos(theta)**6 - 15592789485940.0*cos(theta)**4 + 22964343867.3637*cos(theta)**2 - 5621626.40571939)*cos(4*phi)

#@torch.jit.script
def Yl90_m5(theta, phi):
    return 8.86341519335458e-10*(1.0 - cos(theta)**2)**2.5*(3.87733322901225e+35*cos(theta)**85 - 7.73300537853282e+36*cos(theta)**83 + 7.43373370145401e+37*cos(theta)**81 - 4.58767565575447e+38*cos(theta)**79 + 2.04257640106641e+39*cos(theta)**77 - 6.99015035031615e+39*cos(theta)**75 + 1.91298493314865e+40*cos(theta)**73 - 4.30053413542742e+40*cos(theta)**71 + 8.09608130798268e+40*cos(theta)**69 - 1.29471075313752e+41*cos(theta)**67 + 1.77801582309754e+41*cos(theta)**65 - 2.11450709665117e+41*cos(theta)**63 + 2.19194923554126e+41*cos(theta)**61 - 1.99070327595062e+41*cos(theta)**59 + 1.59014626757774e+41*cos(theta)**57 - 1.12047392629319e+41*cos(theta)**55 + 6.97946216671721e+40*cos(theta)**53 - 3.84861899389208e+40*cos(theta)**51 + 1.88007249701625e+40*cos(theta)**49 - 8.13752394733569e+39*cos(theta)**47 + 3.11938417981202e+39*cos(theta)**45 - 1.05796174649328e+39*cos(theta)**43 + 3.16967304938101e+38*cos(theta)**41 - 8.37079517066804e+37*cos(theta)**39 + 1.94322030747651e+37*cos(theta)**37 - 3.95170908329574e+36*cos(theta)**35 + 7.01033662659799e+35*cos(theta)**33 - 1.07945690838254e+35*cos(theta)**31 + 1.43413560685109e+34*cos(theta)**29 - 1.63234947121262e+33*cos(theta)**27 + 1.57838750522212e+32*cos(theta)**25 - 1.28358973045985e+31*cos(theta)**23 + 8.67383017645142e+29*cos(theta)**21 - 4.79974792372806e+28*cos(theta)**19 + 2.13627510400182e+27*cos(theta)**17 - 7.47833755841048e+25*cos(theta)**15 + 2.00108420905479e+24*cos(theta)**13 - 3.94252508982758e+22*cos(theta)**11 + 5.43455839449917e+20*cos(theta)**9 - 4.87040334085063e+18*cos(theta)**7 + 2.53164530093721e+16*cos(theta)**5 - 62371157943759.8*cos(theta)**3 + 45928687734.7274*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl90_m6(theta, phi):
    return 9.81196553994633e-12*(1.0 - cos(theta)**2)**3*(3.29573324466042e+37*cos(theta)**84 - 6.41839446418224e+38*cos(theta)**82 + 6.02132429817775e+39*cos(theta)**80 - 3.62426376804603e+40*cos(theta)**78 + 1.57278382882113e+41*cos(theta)**76 - 5.24261276273711e+41*cos(theta)**74 + 1.39647900119851e+42*cos(theta)**72 - 3.05337923615347e+42*cos(theta)**70 + 5.58629610250805e+42*cos(theta)**68 - 8.67456204602136e+42*cos(theta)**66 + 1.1557102850134e+43*cos(theta)**64 - 1.33213947089024e+43*cos(theta)**62 + 1.33708903368017e+43*cos(theta)**60 - 1.17451493281087e+43*cos(theta)**58 + 9.06383372519311e+42*cos(theta)**56 - 6.16260659461253e+42*cos(theta)**54 + 3.69911494836012e+42*cos(theta)**52 - 1.96279568688496e+42*cos(theta)**50 + 9.21235523537962e+41*cos(theta)**48 - 3.82463625524778e+41*cos(theta)**46 + 1.40372288091541e+41*cos(theta)**44 - 4.54923550992112e+40*cos(theta)**42 + 1.29956595024621e+40*cos(theta)**40 - 3.26461011656053e+39*cos(theta)**38 + 7.18991513766308e+38*cos(theta)**36 - 1.38309817915351e+38*cos(theta)**34 + 2.31341108677734e+37*cos(theta)**32 - 3.34631641598588e+36*cos(theta)**30 + 4.15899325986817e+35*cos(theta)**28 - 4.40734357227409e+34*cos(theta)**26 + 3.94596876305531e+33*cos(theta)**24 - 2.95225638005765e+32*cos(theta)**22 + 1.8215043370548e+31*cos(theta)**20 - 9.11952105508331e+29*cos(theta)**18 + 3.63166767680309e+28*cos(theta)**16 - 1.12175063376157e+27*cos(theta)**14 + 2.60140947177123e+25*cos(theta)**12 - 4.33677759881033e+23*cos(theta)**10 + 4.89110255504925e+21*cos(theta)**8 - 3.40928233859544e+19*cos(theta)**6 + 1.26582265046861e+17*cos(theta)**4 - 187113473831279.0*cos(theta)**2 + 45928687734.7274)*cos(6*phi)

#@torch.jit.script
def Yl90_m7(theta, phi):
    return 1.08700240285979e-13*(1.0 - cos(theta)**2)**3.5*(2.76841592551475e+39*cos(theta)**83 - 5.26308346062944e+40*cos(theta)**81 + 4.8170594385422e+41*cos(theta)**79 - 2.82692573907591e+42*cos(theta)**77 + 1.19531570990406e+43*cos(theta)**75 - 3.87953344442546e+43*cos(theta)**73 + 1.00546488086293e+44*cos(theta)**71 - 2.13736546530743e+44*cos(theta)**69 + 3.79868134970547e+44*cos(theta)**67 - 5.7252109503741e+44*cos(theta)**65 + 7.39654582408579e+44*cos(theta)**63 - 8.25926471951946e+44*cos(theta)**61 + 8.02253420208101e+44*cos(theta)**59 - 6.81218661030303e+44*cos(theta)**57 + 5.07574688610814e+44*cos(theta)**55 - 3.32780756109077e+44*cos(theta)**53 + 1.92353977314726e+44*cos(theta)**51 - 9.81397843442482e+43*cos(theta)**49 + 4.42193051298222e+43*cos(theta)**47 - 1.75933267741398e+43*cos(theta)**45 + 6.17638067602779e+42*cos(theta)**43 - 1.91067891416687e+42*cos(theta)**41 + 5.19826380098485e+41*cos(theta)**39 - 1.240551844293e+41*cos(theta)**37 + 2.58836944955871e+40*cos(theta)**35 - 4.70253380912193e+39*cos(theta)**33 + 7.40291547768747e+38*cos(theta)**31 - 1.00389492479576e+38*cos(theta)**29 + 1.16451811276309e+37*cos(theta)**27 - 1.14590932879126e+36*cos(theta)**25 + 9.47032503133275e+34*cos(theta)**23 - 6.49496403612682e+33*cos(theta)**21 + 3.6430086741096e+32*cos(theta)**19 - 1.641513789915e+31*cos(theta)**17 + 5.81066828288494e+29*cos(theta)**15 - 1.5704508872662e+28*cos(theta)**13 + 3.12169136612548e+26*cos(theta)**11 - 4.33677759881033e+24*cos(theta)**9 + 3.9128820440394e+22*cos(theta)**7 - 2.04556940315727e+20*cos(theta)**5 + 5.06329060187442e+17*cos(theta)**3 - 374226947662559.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl90_m8(theta, phi):
    return 1.20525355203382e-15*(1.0 - cos(theta)**2)**4*(2.29778521817724e+41*cos(theta)**82 - 4.26309760310984e+42*cos(theta)**80 + 3.80547695644834e+43*cos(theta)**78 - 2.17673281908845e+44*cos(theta)**76 + 8.96486782428046e+44*cos(theta)**74 - 2.83205941443059e+45*cos(theta)**72 + 7.1388006541268e+45*cos(theta)**70 - 1.47478217106212e+46*cos(theta)**68 + 2.54511650430267e+46*cos(theta)**66 - 3.72138711774316e+46*cos(theta)**64 + 4.65982386917405e+46*cos(theta)**62 - 5.03815147890687e+46*cos(theta)**60 + 4.73329517922779e+46*cos(theta)**58 - 3.88294636787273e+46*cos(theta)**56 + 2.79166078735948e+46*cos(theta)**54 - 1.76373800737811e+46*cos(theta)**52 + 9.81005284305105e+45*cos(theta)**50 - 4.80884943286816e+45*cos(theta)**48 + 2.07830734110164e+45*cos(theta)**46 - 7.9169970483629e+44*cos(theta)**44 + 2.65584369069195e+44*cos(theta)**42 - 7.83378354808417e+43*cos(theta)**40 + 2.02732288238409e+43*cos(theta)**38 - 4.59004182388411e+42*cos(theta)**36 + 9.05929307345548e+41*cos(theta)**34 - 1.55183615701024e+41*cos(theta)**32 + 2.29490379808312e+40*cos(theta)**30 - 2.91129528190772e+39*cos(theta)**28 + 3.14419890446033e+38*cos(theta)**26 - 2.86477332197816e+37*cos(theta)**24 + 2.17817475720653e+36*cos(theta)**22 - 1.36394244758663e+35*cos(theta)**20 + 6.92171648080823e+33*cos(theta)**18 - 2.79057344285549e+32*cos(theta)**16 + 8.71600242432741e+30*cos(theta)**14 - 2.04158615344606e+29*cos(theta)**12 + 3.43386050273802e+27*cos(theta)**10 - 3.9030998389293e+25*cos(theta)**8 + 2.73901743082758e+23*cos(theta)**6 - 1.02278470157863e+21*cos(theta)**4 + 1.51898718056233e+18*cos(theta)**2 - 374226947662559.0)*cos(8*phi)

#@torch.jit.script
def Yl90_m9(theta, phi):
    return 1.33768512138472e-17*(1.0 - cos(theta)**2)**4.5*(1.88418387890534e+43*cos(theta)**81 - 3.41047808248788e+44*cos(theta)**79 + 2.9682720260297e+45*cos(theta)**77 - 1.65431694250722e+46*cos(theta)**75 + 6.63400218996754e+46*cos(theta)**73 - 2.03908277839002e+47*cos(theta)**71 + 4.99716045788876e+47*cos(theta)**69 - 1.00285187632224e+48*cos(theta)**67 + 1.67977689283976e+48*cos(theta)**65 - 2.38168775535562e+48*cos(theta)**63 + 2.88909079888791e+48*cos(theta)**61 - 3.02289088734412e+48*cos(theta)**59 + 2.74531120395212e+48*cos(theta)**57 - 2.17444996600873e+48*cos(theta)**55 + 1.50749682517412e+48*cos(theta)**53 - 9.17143763836615e+47*cos(theta)**51 + 4.90502642152552e+47*cos(theta)**49 - 2.30824772777672e+47*cos(theta)**47 + 9.56021376906755e+46*cos(theta)**45 - 3.48347870127967e+46*cos(theta)**43 + 1.11545435009062e+46*cos(theta)**41 - 3.13351341923367e+45*cos(theta)**39 + 7.70382695305955e+44*cos(theta)**37 - 1.65241505659828e+44*cos(theta)**35 + 3.08015964497486e+43*cos(theta)**33 - 4.96587570243276e+42*cos(theta)**31 + 6.88471139424935e+41*cos(theta)**29 - 8.15162678934161e+40*cos(theta)**27 + 8.17491715159687e+39*cos(theta)**25 - 6.87545597274758e+38*cos(theta)**23 + 4.79198446585437e+37*cos(theta)**21 - 2.72788489517327e+36*cos(theta)**19 + 1.24590896654548e+35*cos(theta)**17 - 4.46491750856879e+33*cos(theta)**15 + 1.22024033940584e+32*cos(theta)**13 - 2.44990338413527e+30*cos(theta)**11 + 3.43386050273802e+28*cos(theta)**9 - 3.12247987114344e+26*cos(theta)**7 + 1.64341045849655e+24*cos(theta)**5 - 4.09113880631453e+21*cos(theta)**3 + 3.03797436112465e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl90_m10(theta, phi):
    return 1.48631680153858e-19*(1.0 - cos(theta)**2)**5*(1.52618894191332e+45*cos(theta)**80 - 2.69427768516542e+46*cos(theta)**78 + 2.28556946004287e+47*cos(theta)**76 - 1.24073770688042e+48*cos(theta)**74 + 4.8428215986763e+48*cos(theta)**72 - 1.44774877265692e+49*cos(theta)**70 + 3.44804071594325e+49*cos(theta)**68 - 6.71910757135904e+49*cos(theta)**66 + 1.09185498034584e+50*cos(theta)**64 - 1.50046328587404e+50*cos(theta)**62 + 1.76234538732162e+50*cos(theta)**60 - 1.78350562353303e+50*cos(theta)**58 + 1.56482738625271e+50*cos(theta)**56 - 1.1959474813048e+50*cos(theta)**54 + 7.98973317342282e+49*cos(theta)**52 - 4.67743319556674e+49*cos(theta)**50 + 2.40346294654751e+49*cos(theta)**48 - 1.08487643205506e+49*cos(theta)**46 + 4.3020961960804e+48*cos(theta)**44 - 1.49789584155026e+48*cos(theta)**42 + 4.57336283537154e+47*cos(theta)**40 - 1.22207023350113e+47*cos(theta)**38 + 2.85041597263203e+46*cos(theta)**36 - 5.78345269809398e+45*cos(theta)**34 + 1.01645268284171e+45*cos(theta)**32 - 1.53942146775415e+44*cos(theta)**30 + 1.99656630433231e+43*cos(theta)**28 - 2.20093923312223e+42*cos(theta)**26 + 2.04372928789922e+41*cos(theta)**24 - 1.58135487373194e+40*cos(theta)**22 + 1.00631673782942e+39*cos(theta)**20 - 5.18298130082921e+37*cos(theta)**18 + 2.11804524312732e+36*cos(theta)**16 - 6.69737626285319e+34*cos(theta)**14 + 1.58631244122759e+33*cos(theta)**12 - 2.6948937225488e+31*cos(theta)**10 + 3.09047445246422e+29*cos(theta)**8 - 2.18573590980041e+27*cos(theta)**6 + 8.21705229248274e+24*cos(theta)**4 - 1.22734164189436e+22*cos(theta)**2 + 3.03797436112465e+18)*cos(10*phi)

#@torch.jit.script
def Yl90_m11(theta, phi):
    return 1.65350573959125e-21*(1.0 - cos(theta)**2)**5.5*(1.22095115353066e+47*cos(theta)**79 - 2.10153659442903e+48*cos(theta)**77 + 1.73703278963258e+49*cos(theta)**75 - 9.18145903091507e+49*cos(theta)**73 + 3.48683155104694e+50*cos(theta)**71 - 1.01342414085984e+51*cos(theta)**69 + 2.34466768684141e+51*cos(theta)**67 - 4.43461099709697e+51*cos(theta)**65 + 6.9878718742134e+51*cos(theta)**63 - 9.30287237241907e+51*cos(theta)**61 + 1.05740723239297e+52*cos(theta)**59 - 1.03443326164916e+52*cos(theta)**57 + 8.76303336301517e+51*cos(theta)**55 - 6.45811639904592e+51*cos(theta)**53 + 4.15466125017987e+51*cos(theta)**51 - 2.33871659778337e+51*cos(theta)**49 + 1.1536622143428e+51*cos(theta)**47 - 4.99043158745326e+50*cos(theta)**45 + 1.89292232627538e+50*cos(theta)**43 - 6.29116253451109e+49*cos(theta)**41 + 1.82934513414862e+49*cos(theta)**39 - 4.6438668873043e+48*cos(theta)**37 + 1.02614975014753e+48*cos(theta)**35 - 1.96637391735195e+47*cos(theta)**33 + 3.25264858509346e+46*cos(theta)**31 - 4.61826440326246e+45*cos(theta)**29 + 5.59038565213047e+44*cos(theta)**27 - 5.72244200611781e+43*cos(theta)**25 + 4.90495029095812e+42*cos(theta)**23 - 3.47898072221027e+41*cos(theta)**21 + 2.01263347565884e+40*cos(theta)**19 - 9.32936634149257e+38*cos(theta)**17 + 3.38887238900371e+37*cos(theta)**15 - 9.37632676799446e+35*cos(theta)**13 + 1.90357492947311e+34*cos(theta)**11 - 2.6948937225488e+32*cos(theta)**9 + 2.47237956197138e+30*cos(theta)**7 - 1.31144154588025e+28*cos(theta)**5 + 3.2868209169931e+25*cos(theta)**3 - 2.45468328378872e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl90_m12(theta, phi):
    return 1.8420103887068e-23*(1.0 - cos(theta)**2)**6*(9.64551411289221e+48*cos(theta)**78 - 1.61818317771035e+50*cos(theta)**76 + 1.30277459222444e+51*cos(theta)**74 - 6.702465092568e+51*cos(theta)**72 + 2.47565040124333e+52*cos(theta)**70 - 6.9926265719329e+52*cos(theta)**68 + 1.57092735018374e+53*cos(theta)**66 - 2.88249714811303e+53*cos(theta)**64 + 4.40235928075444e+53*cos(theta)**62 - 5.67475214717563e+53*cos(theta)**60 + 6.23870267111855e+53*cos(theta)**58 - 5.89626959140021e+53*cos(theta)**56 + 4.81966834965834e+53*cos(theta)**54 - 3.42280169149434e+53*cos(theta)**52 + 2.11887723759173e+53*cos(theta)**50 - 1.14597113291385e+53*cos(theta)**48 + 5.42221240741117e+52*cos(theta)**46 - 2.24569421435397e+52*cos(theta)**44 + 8.13956600298411e+51*cos(theta)**42 - 2.57937663914955e+51*cos(theta)**40 + 7.1344460231796e+50*cos(theta)**38 - 1.71823074830259e+50*cos(theta)**36 + 3.59152412551636e+49*cos(theta)**34 - 6.48903392726145e+48*cos(theta)**32 + 1.00832106137897e+48*cos(theta)**30 - 1.33929667694611e+47*cos(theta)**28 + 1.50940412607523e+46*cos(theta)**26 - 1.43061050152945e+45*cos(theta)**24 + 1.12813856692037e+44*cos(theta)**22 - 7.30585951664157e+42*cos(theta)**20 + 3.82400360375179e+41*cos(theta)**18 - 1.58599227805374e+40*cos(theta)**16 + 5.08330858350557e+38*cos(theta)**14 - 1.21892247983928e+37*cos(theta)**12 + 2.09393242242042e+35*cos(theta)**10 - 2.42540435029392e+33*cos(theta)**8 + 1.73066569337996e+31*cos(theta)**6 - 6.55720772940123e+28*cos(theta)**4 + 9.86046275097929e+25*cos(theta)**2 - 2.45468328378872e+22)*cos(12*phi)

#@torch.jit.script
def Yl90_m13(theta, phi):
    return 2.05506783318313e-25*(1.0 - cos(theta)**2)**6.5*(7.52350100805592e+50*cos(theta)**77 - 1.22981921505987e+52*cos(theta)**75 + 9.64053198246083e+52*cos(theta)**73 - 4.82577486664896e+53*cos(theta)**71 + 1.73295528087033e+54*cos(theta)**69 - 4.75498606891437e+54*cos(theta)**67 + 1.03681205112127e+55*cos(theta)**65 - 1.84479817479234e+55*cos(theta)**63 + 2.72946275406775e+55*cos(theta)**61 - 3.40485128830538e+55*cos(theta)**59 + 3.61844754924876e+55*cos(theta)**57 - 3.30191097118412e+55*cos(theta)**55 + 2.60262090881551e+55*cos(theta)**53 - 1.77985687957706e+55*cos(theta)**51 + 1.05943861879587e+55*cos(theta)**49 - 5.50066143798648e+54*cos(theta)**47 + 2.49421770740914e+54*cos(theta)**45 - 9.88105454315746e+53*cos(theta)**43 + 3.41861772125333e+53*cos(theta)**41 - 1.03175065565982e+53*cos(theta)**39 + 2.71108948880825e+52*cos(theta)**37 - 6.18563069388932e+51*cos(theta)**35 + 1.22111820267556e+51*cos(theta)**33 - 2.07649085672366e+50*cos(theta)**31 + 3.02496318413691e+49*cos(theta)**29 - 3.75003069544912e+48*cos(theta)**27 + 3.92445072779559e+47*cos(theta)**25 - 3.43346520367068e+46*cos(theta)**23 + 2.48190484722481e+45*cos(theta)**21 - 1.46117190332831e+44*cos(theta)**19 + 6.88320648675322e+42*cos(theta)**17 - 2.53758764488598e+41*cos(theta)**15 + 7.11663201690779e+39*cos(theta)**13 - 1.46270697580714e+38*cos(theta)**11 + 2.09393242242042e+36*cos(theta)**9 - 1.94032348023514e+34*cos(theta)**7 + 1.03839941602798e+32*cos(theta)**5 - 2.62288309176049e+29*cos(theta)**3 + 1.97209255019586e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl90_m14(theta, phi):
    return 2.296487729738e-27*(1.0 - cos(theta)**2)**7*(5.79309577620306e+52*cos(theta)**76 - 9.22364411294901e+53*cos(theta)**74 + 7.0375883471964e+54*cos(theta)**72 - 3.42630015532076e+55*cos(theta)**70 + 1.19573914380053e+56*cos(theta)**68 - 3.18584066617263e+56*cos(theta)**66 + 6.73927833228826e+56*cos(theta)**64 - 1.16222285011917e+57*cos(theta)**62 + 1.66497227998133e+57*cos(theta)**60 - 2.00886226010017e+57*cos(theta)**58 + 2.06251510307179e+57*cos(theta)**56 - 1.81605103415126e+57*cos(theta)**54 + 1.37938908167222e+57*cos(theta)**52 - 9.07727008584298e+56*cos(theta)**50 + 5.19124923209975e+56*cos(theta)**48 - 2.58531087585365e+56*cos(theta)**46 + 1.12239796833411e+56*cos(theta)**44 - 4.24885345355771e+55*cos(theta)**42 + 1.40163326571386e+55*cos(theta)**40 - 4.02382755707329e+54*cos(theta)**38 + 1.00310311085905e+54*cos(theta)**36 - 2.16497074286126e+53*cos(theta)**34 + 4.02969006882936e+52*cos(theta)**32 - 6.43712165584335e+51*cos(theta)**30 + 8.77239323399705e+50*cos(theta)**28 - 1.01250828777126e+50*cos(theta)**26 + 9.81112681948898e+48*cos(theta)**24 - 7.89696996844257e+47*cos(theta)**22 + 5.2120001791721e+46*cos(theta)**20 - 2.7762266163238e+45*cos(theta)**18 + 1.17014510274805e+44*cos(theta)**16 - 3.80638146732897e+42*cos(theta)**14 + 9.25162162198013e+40*cos(theta)**12 - 1.60897767338785e+39*cos(theta)**10 + 1.88453918017838e+37*cos(theta)**8 - 1.3582264361646e+35*cos(theta)**6 + 5.19199708013989e+32*cos(theta)**4 - 7.86864927528147e+29*cos(theta)**2 + 1.97209255019586e+26)*cos(14*phi)

#@torch.jit.script
def Yl90_m15(theta, phi):
    return 2.57076680602771e-29*(1.0 - cos(theta)**2)**7.5*(4.40275278991433e+54*cos(theta)**75 - 6.82549664358227e+55*cos(theta)**73 + 5.06706360998141e+56*cos(theta)**71 - 2.39841010872453e+57*cos(theta)**69 + 8.13102617784358e+57*cos(theta)**67 - 2.10265483967394e+58*cos(theta)**65 + 4.31313813266449e+58*cos(theta)**63 - 7.20578167073887e+58*cos(theta)**61 + 9.98983367988798e+58*cos(theta)**59 - 1.1651401108581e+59*cos(theta)**57 + 1.1550084577202e+59*cos(theta)**55 - 9.80667558441683e+58*cos(theta)**53 + 7.17282322469553e+58*cos(theta)**51 - 4.53863504292149e+58*cos(theta)**49 + 2.49179963140788e+58*cos(theta)**47 - 1.18924300289268e+58*cos(theta)**45 + 4.9385510606701e+57*cos(theta)**43 - 1.78451845049424e+57*cos(theta)**41 + 5.60653306285546e+56*cos(theta)**39 - 1.52905447168785e+56*cos(theta)**37 + 3.61117119909259e+55*cos(theta)**35 - 7.36090052572829e+54*cos(theta)**33 + 1.28950082202539e+54*cos(theta)**31 - 1.93113649675301e+53*cos(theta)**29 + 2.45627010551917e+52*cos(theta)**27 - 2.63252154820528e+51*cos(theta)**25 + 2.35467043667736e+50*cos(theta)**23 - 1.73733339305737e+49*cos(theta)**21 + 1.04240003583442e+48*cos(theta)**19 - 4.99720790938284e+46*cos(theta)**17 + 1.87223216439688e+45*cos(theta)**15 - 5.32893405426056e+43*cos(theta)**13 + 1.11019459463762e+42*cos(theta)**11 - 1.60897767338785e+40*cos(theta)**9 + 1.5076313441427e+38*cos(theta)**7 - 8.14935861698757e+35*cos(theta)**5 + 2.07679883205596e+33*cos(theta)**3 - 1.57372985505629e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl90_m16(theta, phi):
    return 2.88322887896897e-31*(1.0 - cos(theta)**2)**8*(3.30206459243574e+56*cos(theta)**74 - 4.98261254981505e+57*cos(theta)**72 + 3.5976151630868e+58*cos(theta)**70 - 1.65490297501993e+59*cos(theta)**68 + 5.4477875391552e+59*cos(theta)**66 - 1.36672564578806e+60*cos(theta)**64 + 2.71727702357863e+60*cos(theta)**62 - 4.39552681915071e+60*cos(theta)**60 + 5.89400187113391e+60*cos(theta)**58 - 6.64129863189117e+60*cos(theta)**56 + 6.35254651746112e+60*cos(theta)**54 - 5.19753805974092e+60*cos(theta)**52 + 3.65813984459472e+60*cos(theta)**50 - 2.22393117103153e+60*cos(theta)**48 + 1.1711458267617e+60*cos(theta)**46 - 5.35159351301705e+59*cos(theta)**44 + 2.12357695608814e+59*cos(theta)**42 - 7.31652564702637e+58*cos(theta)**40 + 2.18654789451363e+58*cos(theta)**38 - 5.65750154524505e+57*cos(theta)**36 + 1.26390991968241e+57*cos(theta)**34 - 2.42909717349034e+56*cos(theta)**32 + 3.99745254827872e+55*cos(theta)**30 - 5.60029584058372e+54*cos(theta)**28 + 6.63192928490177e+53*cos(theta)**26 - 6.58130387051321e+52*cos(theta)**24 + 5.41574200435792e+51*cos(theta)**22 - 3.64840012542047e+50*cos(theta)**20 + 1.9805600680854e+49*cos(theta)**18 - 8.49525344595082e+47*cos(theta)**16 + 2.80834824659531e+46*cos(theta)**14 - 6.92761427053872e+44*cos(theta)**12 + 1.22121405410138e+43*cos(theta)**10 - 1.44807990604906e+41*cos(theta)**8 + 1.05534194089989e+39*cos(theta)**6 - 4.07467930849379e+36*cos(theta)**4 + 6.23039649616787e+33*cos(theta)**2 - 1.57372985505629e+30)*cos(16*phi)

#@torch.jit.script
def Yl90_m17(theta, phi):
    return 3.24019666432327e-33*(1.0 - cos(theta)**2)**8.5*(2.44352779840245e+58*cos(theta)**73 - 3.58748103586684e+59*cos(theta)**71 + 2.51833061416076e+60*cos(theta)**69 - 1.12533402301355e+61*cos(theta)**67 + 3.59553977584243e+61*cos(theta)**65 - 8.74704413304358e+61*cos(theta)**63 + 1.68471175461875e+62*cos(theta)**61 - 2.63731609149043e+62*cos(theta)**59 + 3.41852108525767e+62*cos(theta)**57 - 3.71912723385906e+62*cos(theta)**55 + 3.43037511942901e+62*cos(theta)**53 - 2.70271979106528e+62*cos(theta)**51 + 1.82906992229736e+62*cos(theta)**49 - 1.06748696209513e+62*cos(theta)**47 + 5.38727080310383e+61*cos(theta)**45 - 2.3547011457275e+61*cos(theta)**43 + 8.9190232155702e+60*cos(theta)**41 - 2.92661025881055e+60*cos(theta)**39 + 8.30888199915179e+59*cos(theta)**37 - 2.03670055628822e+59*cos(theta)**35 + 4.29729372692018e+58*cos(theta)**33 - 7.77311095516908e+57*cos(theta)**31 + 1.19923576448362e+57*cos(theta)**29 - 1.56808283536344e+56*cos(theta)**27 + 1.72430161407446e+55*cos(theta)**25 - 1.57951292892317e+54*cos(theta)**23 + 1.19146324095874e+53*cos(theta)**21 - 7.29680025084094e+51*cos(theta)**19 + 3.56500812255372e+50*cos(theta)**17 - 1.35924055135213e+49*cos(theta)**15 + 3.93168754523344e+47*cos(theta)**13 - 8.31313712464647e+45*cos(theta)**11 + 1.22121405410138e+44*cos(theta)**9 - 1.15846392483925e+42*cos(theta)**7 + 6.33205164539934e+39*cos(theta)**5 - 1.62987172339751e+37*cos(theta)**3 + 1.24607929923357e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl90_m18(theta, phi):
    return 3.64920333241427e-35*(1.0 - cos(theta)**2)**9*(1.78377529283379e+60*cos(theta)**72 - 2.54711153546546e+61*cos(theta)**70 + 1.73764812377093e+62*cos(theta)**68 - 7.53973795419079e+62*cos(theta)**66 + 2.33710085429758e+63*cos(theta)**64 - 5.51063780381745e+63*cos(theta)**62 + 1.02767417031744e+64*cos(theta)**60 - 1.55601649397935e+64*cos(theta)**58 + 1.94855701859687e+64*cos(theta)**56 - 2.04551997862248e+64*cos(theta)**54 + 1.81809881329737e+64*cos(theta)**52 - 1.37838709344329e+64*cos(theta)**50 + 8.96244261925707e+63*cos(theta)**48 - 5.01718872184713e+63*cos(theta)**46 + 2.42427186139672e+63*cos(theta)**44 - 1.01252149266283e+63*cos(theta)**42 + 3.65679951838378e+62*cos(theta)**40 - 1.14137800093611e+62*cos(theta)**38 + 3.07428633968616e+61*cos(theta)**36 - 7.12845194700877e+60*cos(theta)**34 + 1.41810692988366e+60*cos(theta)**32 - 2.40966439610241e+59*cos(theta)**30 + 3.47778371700249e+58*cos(theta)**28 - 4.23382365548129e+57*cos(theta)**26 + 4.31075403518615e+56*cos(theta)**24 - 3.63287973652329e+55*cos(theta)**22 + 2.50207280601336e+54*cos(theta)**20 - 1.38639204765978e+53*cos(theta)**18 + 6.06051380834132e+51*cos(theta)**16 - 2.0388608270282e+50*cos(theta)**14 + 5.11119380880347e+48*cos(theta)**12 - 9.14445083711112e+46*cos(theta)**10 + 1.09909264869124e+45*cos(theta)**8 - 8.10924747387476e+42*cos(theta)**6 + 3.16602582269967e+40*cos(theta)**4 - 4.88961517019254e+37*cos(theta)**2 + 1.24607929923357e+34)*cos(18*phi)

#@torch.jit.script
def Yl90_m19(theta, phi):
    return 4.11925393837239e-37*(1.0 - cos(theta)**2)**9.5*(1.28431821084033e+62*cos(theta)**71 - 1.78297807482582e+63*cos(theta)**69 + 1.18160072416423e+64*cos(theta)**67 - 4.97622704976592e+64*cos(theta)**65 + 1.49574454675045e+65*cos(theta)**63 - 3.41659543836682e+65*cos(theta)**61 + 6.16604502190462e+65*cos(theta)**59 - 9.02489566508024e+65*cos(theta)**57 + 1.09119193041425e+66*cos(theta)**55 - 1.10458078845614e+66*cos(theta)**53 + 9.45411382914634e+65*cos(theta)**51 - 6.89193546721646e+65*cos(theta)**49 + 4.30197245724339e+65*cos(theta)**47 - 2.30790681204968e+65*cos(theta)**45 + 1.06667961901456e+65*cos(theta)**43 - 4.25259026918387e+64*cos(theta)**41 + 1.46271980735351e+64*cos(theta)**39 - 4.33723640355723e+63*cos(theta)**37 + 1.10674308228702e+63*cos(theta)**35 - 2.42367366198298e+62*cos(theta)**33 + 4.53794217562771e+61*cos(theta)**31 - 7.22899318830724e+60*cos(theta)**29 + 9.73779440760697e+59*cos(theta)**27 - 1.10079415042514e+59*cos(theta)**25 + 1.03458096844468e+58*cos(theta)**23 - 7.99233542035124e+56*cos(theta)**21 + 5.00414561202672e+55*cos(theta)**19 - 2.4955056857876e+54*cos(theta)**17 + 9.69682209334611e+52*cos(theta)**15 - 2.85440515783948e+51*cos(theta)**13 + 6.13343257056416e+49*cos(theta)**11 - 9.14445083711111e+47*cos(theta)**9 + 8.79274118952992e+45*cos(theta)**7 - 4.86554848432486e+43*cos(theta)**5 + 1.26641032907987e+41*cos(theta)**3 - 9.77923034038509e+37*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl90_m20(theta, phi):
    return 4.66114967282393e-39*(1.0 - cos(theta)**2)**10*(9.11865929696633e+63*cos(theta)**70 - 1.23025487162981e+65*cos(theta)**68 + 7.91672485190034e+65*cos(theta)**66 - 3.23454758234785e+66*cos(theta)**64 + 9.42319064452784e+66*cos(theta)**62 - 2.08412321740376e+67*cos(theta)**60 + 3.63796656292372e+67*cos(theta)**58 - 5.14419052909574e+67*cos(theta)**56 + 6.00155561727836e+67*cos(theta)**54 - 5.85427817881754e+67*cos(theta)**52 + 4.82159805286463e+67*cos(theta)**50 - 3.37704837893606e+67*cos(theta)**48 + 2.02192705490439e+67*cos(theta)**46 - 1.03855806542236e+67*cos(theta)**44 + 4.5867223617626e+66*cos(theta)**42 - 1.74356201036539e+66*cos(theta)**40 + 5.7046072486787e+65*cos(theta)**38 - 1.60477746931618e+65*cos(theta)**36 + 3.87360078800456e+64*cos(theta)**34 - 7.99812308454383e+63*cos(theta)**32 + 1.40676207444459e+63*cos(theta)**30 - 2.0964080246091e+62*cos(theta)**28 + 2.62920449005388e+61*cos(theta)**26 - 2.75198537606284e+60*cos(theta)**24 + 2.37953622742276e+59*cos(theta)**22 - 1.67839043827376e+58*cos(theta)**20 + 9.50787666285076e+56*cos(theta)**18 - 4.24235966583892e+55*cos(theta)**16 + 1.45452331400192e+54*cos(theta)**14 - 3.71072670519132e+52*cos(theta)**12 + 6.74677582762058e+50*cos(theta)**10 - 8.2300057534e+48*cos(theta)**8 + 6.15491883267094e+46*cos(theta)**6 - 2.43277424216243e+44*cos(theta)**4 + 3.79923098723961e+41*cos(theta)**2 - 9.77923034038509e+37)*cos(20*phi)

#@torch.jit.script
def Yl90_m21(theta, phi):
    return 5.28789154620833e-41*(1.0 - cos(theta)**2)**10.5*(6.38306150787643e+65*cos(theta)**69 - 8.36573312708274e+66*cos(theta)**67 + 5.22503840225422e+67*cos(theta)**65 - 2.07011045270262e+68*cos(theta)**63 + 5.84237819960726e+68*cos(theta)**61 - 1.25047393044226e+69*cos(theta)**59 + 2.11002060649576e+69*cos(theta)**57 - 2.88074669629361e+69*cos(theta)**55 + 3.24084003333031e+69*cos(theta)**53 - 3.04422465298512e+69*cos(theta)**51 + 2.41079902643232e+69*cos(theta)**49 - 1.62098322188931e+69*cos(theta)**47 + 9.30086445256022e+68*cos(theta)**45 - 4.56965548785837e+68*cos(theta)**43 + 1.92642339194029e+68*cos(theta)**41 - 6.97424804146155e+67*cos(theta)**39 + 2.1677507544979e+67*cos(theta)**37 - 5.77719888953823e+66*cos(theta)**35 + 1.31702426792155e+66*cos(theta)**33 - 2.55939938705403e+65*cos(theta)**31 + 4.22028622333377e+64*cos(theta)**29 - 5.86994246890548e+63*cos(theta)**27 + 6.83593167414009e+62*cos(theta)**25 - 6.60476490255081e+61*cos(theta)**23 + 5.23497970033006e+60*cos(theta)**21 - 3.35678087654752e+59*cos(theta)**19 + 1.71141779931314e+58*cos(theta)**17 - 6.78777546534227e+56*cos(theta)**15 + 2.03633263960268e+55*cos(theta)**13 - 4.45287204622958e+53*cos(theta)**11 + 6.74677582762058e+51*cos(theta)**9 - 6.58400460272e+49*cos(theta)**7 + 3.69295129960257e+47*cos(theta)**5 - 9.73109696864971e+44*cos(theta)**3 + 7.59846197447921e+41*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl90_m22(theta, phi):
    return 6.01518491319549e-43*(1.0 - cos(theta)**2)**11*(4.40431244043474e+67*cos(theta)**68 - 5.60504119514544e+68*cos(theta)**66 + 3.39627496146524e+69*cos(theta)**64 - 1.30416958520265e+70*cos(theta)**62 + 3.56385070176043e+70*cos(theta)**60 - 7.37779618960931e+70*cos(theta)**58 + 1.20271174570258e+71*cos(theta)**56 - 1.58441068296149e+71*cos(theta)**54 + 1.71764521766507e+71*cos(theta)**52 - 1.55255457302241e+71*cos(theta)**50 + 1.18129152295183e+71*cos(theta)**48 - 7.61862114287976e+70*cos(theta)**46 + 4.1853890036521e+70*cos(theta)**44 - 1.9649518597791e+70*cos(theta)**42 + 7.8983359069552e+69*cos(theta)**40 - 2.71995673617e+69*cos(theta)**38 + 8.02067779164225e+68*cos(theta)**36 - 2.02201961133838e+68*cos(theta)**34 + 4.34618008414112e+67*cos(theta)**32 - 7.93413809986748e+66*cos(theta)**30 + 1.22388300476679e+66*cos(theta)**28 - 1.58488446660448e+65*cos(theta)**26 + 1.70898291853502e+64*cos(theta)**24 - 1.51909592758669e+63*cos(theta)**22 + 1.09934573706931e+62*cos(theta)**20 - 6.37788366544029e+60*cos(theta)**18 + 2.90941025883233e+59*cos(theta)**16 - 1.01816631980134e+58*cos(theta)**14 + 2.64723243148349e+56*cos(theta)**12 - 4.89815925085254e+54*cos(theta)**10 + 6.07209824485852e+52*cos(theta)**8 - 4.608803221904e+50*cos(theta)**6 + 1.84647564980128e+48*cos(theta)**4 - 2.91932909059491e+45*cos(theta)**2 + 7.59846197447921e+41)*cos(22*phi)

#@torch.jit.script
def Yl90_m23(theta, phi):
    return 6.86207253565265e-45*(1.0 - cos(theta)**2)**11.5*(2.99493245949562e+69*cos(theta)**67 - 3.69932718879599e+70*cos(theta)**65 + 2.17361597533776e+71*cos(theta)**63 - 8.08585142825645e+71*cos(theta)**61 + 2.13831042105626e+72*cos(theta)**59 - 4.2791217899734e+72*cos(theta)**57 + 6.73518577593447e+72*cos(theta)**55 - 8.55581768799203e+72*cos(theta)**53 + 8.93175513185835e+72*cos(theta)**51 - 7.76277286511206e+72*cos(theta)**49 + 5.67019931016881e+72*cos(theta)**47 - 3.50456572572469e+72*cos(theta)**45 + 1.84157116160692e+72*cos(theta)**43 - 8.25279781107221e+71*cos(theta)**41 + 3.15933436278208e+71*cos(theta)**39 - 1.0335835597446e+71*cos(theta)**37 + 2.88744400499121e+70*cos(theta)**35 - 6.8748666785505e+69*cos(theta)**33 + 1.39077762692516e+69*cos(theta)**31 - 2.38024142996025e+68*cos(theta)**29 + 3.42687241334702e+67*cos(theta)**27 - 4.12069961317165e+66*cos(theta)**25 + 4.10155900448406e+65*cos(theta)**23 - 3.34201104069071e+64*cos(theta)**21 + 2.19869147413863e+63*cos(theta)**19 - 1.14801905977925e+62*cos(theta)**17 + 4.65505641413173e+60*cos(theta)**15 - 1.42543284772188e+59*cos(theta)**13 + 3.17667891778018e+57*cos(theta)**11 - 4.89815925085254e+55*cos(theta)**9 + 4.85767859588682e+53*cos(theta)**7 - 2.7652819331424e+51*cos(theta)**5 + 7.38590259920513e+48*cos(theta)**3 - 5.83865818118983e+45*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl90_m24(theta, phi):
    return 7.85173217826566e-47*(1.0 - cos(theta)**2)**12*(2.00660474786207e+71*cos(theta)**66 - 2.40456267271739e+72*cos(theta)**64 + 1.36937806446279e+73*cos(theta)**62 - 4.93236937123644e+73*cos(theta)**60 + 1.26160314842319e+74*cos(theta)**58 - 2.43909942028484e+74*cos(theta)**56 + 3.70435217676396e+74*cos(theta)**54 - 4.53458337463578e+74*cos(theta)**52 + 4.55519511724776e+74*cos(theta)**50 - 3.80375870390491e+74*cos(theta)**48 + 2.66499367577934e+74*cos(theta)**46 - 1.57705457657611e+74*cos(theta)**44 + 7.91875599490977e+73*cos(theta)**42 - 3.38364710253961e+73*cos(theta)**40 + 1.23214040148501e+73*cos(theta)**38 - 3.82425917105502e+72*cos(theta)**36 + 1.01060540174692e+72*cos(theta)**34 - 2.26870600392166e+71*cos(theta)**32 + 4.31141064346799e+70*cos(theta)**30 - 6.90270014688471e+69*cos(theta)**28 + 9.25255551603695e+68*cos(theta)**26 - 1.03017490329291e+68*cos(theta)**24 + 9.43358571031333e+66*cos(theta)**22 - 7.01822318545049e+65*cos(theta)**20 + 4.17751380086339e+64*cos(theta)**18 - 1.95163240162473e+63*cos(theta)**16 + 6.9825846211976e+61*cos(theta)**14 - 1.85306270203844e+60*cos(theta)**12 + 3.4943468095582e+58*cos(theta)**10 - 4.40834332576729e+56*cos(theta)**8 + 3.40037501712077e+54*cos(theta)**6 - 1.3826409665712e+52*cos(theta)**4 + 2.21577077976154e+49*cos(theta)**2 - 5.83865818118983e+45)*cos(24*phi)

#@torch.jit.script
def Yl90_m25(theta, phi):
    return 9.01248571778017e-49*(1.0 - cos(theta)**2)**12.5*(1.32435913358896e+73*cos(theta)**65 - 1.53892011053913e+74*cos(theta)**63 + 8.49014399966928e+74*cos(theta)**61 - 2.95942162274186e+75*cos(theta)**59 + 7.31729826085452e+75*cos(theta)**57 - 1.36589567535951e+76*cos(theta)**55 + 2.00035017545254e+76*cos(theta)**53 - 2.3579833548106e+76*cos(theta)**51 + 2.27759755862388e+76*cos(theta)**49 - 1.82580417787436e+76*cos(theta)**47 + 1.2258970908585e+76*cos(theta)**45 - 6.93904013693488e+75*cos(theta)**43 + 3.3258775178621e+75*cos(theta)**41 - 1.35345884101584e+75*cos(theta)**39 + 4.68213352564304e+74*cos(theta)**37 - 1.37673330157981e+74*cos(theta)**35 + 3.43605836593954e+73*cos(theta)**33 - 7.25985921254933e+72*cos(theta)**31 + 1.2934231930404e+72*cos(theta)**29 - 1.93275604112772e+71*cos(theta)**27 + 2.40566443416961e+70*cos(theta)**25 - 2.47241976790299e+69*cos(theta)**23 + 2.07538885626893e+68*cos(theta)**21 - 1.4036446370901e+67*cos(theta)**19 + 7.5195248415541e+65*cos(theta)**17 - 3.12261184259957e+64*cos(theta)**15 + 9.77561846967664e+62*cos(theta)**13 - 2.22367524244613e+61*cos(theta)**11 + 3.4943468095582e+59*cos(theta)**9 - 3.52667466061383e+57*cos(theta)**7 + 2.04022501027246e+55*cos(theta)**5 - 5.5305638662848e+52*cos(theta)**3 + 4.43154155952308e+49*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl90_m26(theta, phi):
    return 1.03790813654663e-50*(1.0 - cos(theta)**2)**13*(8.60833436832827e+74*cos(theta)**64 - 9.69519669639653e+75*cos(theta)**62 + 5.17898783979826e+76*cos(theta)**60 - 1.7460587574177e+77*cos(theta)**58 + 4.17086000868707e+77*cos(theta)**56 - 7.5124262144773e+77*cos(theta)**54 + 1.06018559298984e+78*cos(theta)**52 - 1.20257151095341e+78*cos(theta)**50 + 1.1160228037257e+78*cos(theta)**48 - 8.58127963600947e+77*cos(theta)**46 + 5.51653690886323e+77*cos(theta)**44 - 2.983787258882e+77*cos(theta)**42 + 1.36360978232346e+77*cos(theta)**40 - 5.27848947996179e+76*cos(theta)**38 + 1.73238940448793e+76*cos(theta)**36 - 4.81856655552933e+75*cos(theta)**34 + 1.13389926076005e+75*cos(theta)**32 - 2.25055635589029e+74*cos(theta)**30 + 3.75092725981715e+73*cos(theta)**28 - 5.21844131104484e+72*cos(theta)**26 + 6.01416108542402e+71*cos(theta)**24 - 5.68656546617687e+70*cos(theta)**22 + 4.35831659816476e+69*cos(theta)**20 - 2.66692481047119e+68*cos(theta)**18 + 1.2783192230642e+67*cos(theta)**16 - 4.68391776389935e+65*cos(theta)**14 + 1.27083040105796e+64*cos(theta)**12 - 2.44604276669074e+62*cos(theta)**10 + 3.14491212860238e+60*cos(theta)**8 - 2.46867226242968e+58*cos(theta)**6 + 1.02011250513623e+56*cos(theta)**4 - 1.65916915988544e+53*cos(theta)**2 + 4.43154155952308e+49)*cos(26*phi)

#@torch.jit.script
def Yl90_m27(theta, phi):
    return 1.19943301459621e-52*(1.0 - cos(theta)**2)**13.5*(5.50933399573009e+76*cos(theta)**63 - 6.01102195176585e+77*cos(theta)**61 + 3.10739270387895e+78*cos(theta)**59 - 1.01271407930227e+79*cos(theta)**57 + 2.33568160486476e+79*cos(theta)**55 - 4.05671015581774e+79*cos(theta)**53 + 5.51296508354719e+79*cos(theta)**51 - 6.01285755476704e+79*cos(theta)**49 + 5.35690945788336e+79*cos(theta)**47 - 3.94738863256436e+79*cos(theta)**45 + 2.42727623989982e+79*cos(theta)**43 - 1.25319064873044e+79*cos(theta)**41 + 5.45443912929385e+78*cos(theta)**39 - 2.00582600238548e+78*cos(theta)**37 + 6.23660185615653e+77*cos(theta)**35 - 1.63831262887997e+77*cos(theta)**33 + 3.62847763443215e+76*cos(theta)**31 - 6.75166906767087e+75*cos(theta)**29 + 1.0502596327488e+75*cos(theta)**27 - 1.35679474087166e+74*cos(theta)**25 + 1.44339866050176e+73*cos(theta)**23 - 1.25104440255891e+72*cos(theta)**21 + 8.71663319632951e+70*cos(theta)**19 - 4.80046465884814e+69*cos(theta)**17 + 2.04531075690272e+68*cos(theta)**15 - 6.55748486945909e+66*cos(theta)**13 + 1.52499648126956e+65*cos(theta)**11 - 2.44604276669074e+63*cos(theta)**9 + 2.51592970288191e+61*cos(theta)**7 - 1.48120335745781e+59*cos(theta)**5 + 4.08045002054493e+56*cos(theta)**3 - 3.31833831977088e+53*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl90_m28(theta, phi):
    return 1.39112040310174e-54*(1.0 - cos(theta)**2)**14*(3.47088041730996e+78*cos(theta)**62 - 3.66672339057717e+79*cos(theta)**60 + 1.83336169528858e+80*cos(theta)**58 - 5.77247025202291e+80*cos(theta)**56 + 1.28462488267562e+81*cos(theta)**54 - 2.1500563825834e+81*cos(theta)**52 + 2.81161219260907e+81*cos(theta)**50 - 2.94630020183585e+81*cos(theta)**48 + 2.51774744520518e+81*cos(theta)**46 - 1.77632488465396e+81*cos(theta)**44 + 1.04372878315692e+81*cos(theta)**42 - 5.1380816597948e+80*cos(theta)**40 + 2.1272312604246e+80*cos(theta)**38 - 7.42155620882627e+79*cos(theta)**36 + 2.18281064965479e+79*cos(theta)**34 - 5.40643167530391e+78*cos(theta)**32 + 1.12482806667397e+78*cos(theta)**30 - 1.95798402962455e+77*cos(theta)**28 + 2.83570100842177e+76*cos(theta)**26 - 3.39198685217915e+75*cos(theta)**24 + 3.31981691915406e+74*cos(theta)**22 - 2.62719324537372e+73*cos(theta)**20 + 1.65616030730261e+72*cos(theta)**18 - 8.16078992004184e+70*cos(theta)**16 + 3.06796613535407e+69*cos(theta)**14 - 8.52473033029681e+67*cos(theta)**12 + 1.67749612939651e+66*cos(theta)**10 - 2.20143849002167e+64*cos(theta)**8 + 1.76115079201733e+62*cos(theta)**6 - 7.40601678728904e+59*cos(theta)**4 + 1.22413500616348e+57*cos(theta)**2 - 3.31833831977088e+53)*cos(28*phi)

#@torch.jit.script
def Yl90_m29(theta, phi):
    return 1.61955385759464e-56*(1.0 - cos(theta)**2)**14.5*(2.15194585873217e+80*cos(theta)**61 - 2.2000340343463e+81*cos(theta)**59 + 1.06334978326738e+82*cos(theta)**57 - 3.23258334113283e+82*cos(theta)**55 + 6.93697436644834e+82*cos(theta)**53 - 1.11802931894337e+83*cos(theta)**51 + 1.40580609630453e+83*cos(theta)**49 - 1.41422409688121e+83*cos(theta)**47 + 1.15816382479438e+83*cos(theta)**45 - 7.81582949247743e+82*cos(theta)**43 + 4.38366088925908e+82*cos(theta)**41 - 2.05523266391792e+82*cos(theta)**39 + 8.08347878961348e+81*cos(theta)**37 - 2.67176023517746e+81*cos(theta)**35 + 7.42155620882627e+80*cos(theta)**33 - 1.73005813609725e+80*cos(theta)**31 + 3.3744842000219e+79*cos(theta)**29 - 5.48235528294875e+78*cos(theta)**27 + 7.37282262189659e+77*cos(theta)**25 - 8.14076844522995e+76*cos(theta)**23 + 7.30359722213893e+75*cos(theta)**21 - 5.25438649074743e+74*cos(theta)**19 + 2.98108855314469e+73*cos(theta)**17 - 1.30572638720669e+72*cos(theta)**15 + 4.2951525894957e+70*cos(theta)**13 - 1.02296763963562e+69*cos(theta)**11 + 1.67749612939651e+67*cos(theta)**9 - 1.76115079201733e+65*cos(theta)**7 + 1.0566904752104e+63*cos(theta)**5 - 2.96240671491562e+60*cos(theta)**3 + 2.44827001232696e+57*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl90_m30(theta, phi):
    return 1.89295310160517e-58*(1.0 - cos(theta)**2)**15*(1.31268697382663e+82*cos(theta)**60 - 1.29802008026432e+83*cos(theta)**58 + 6.06109376462406e+83*cos(theta)**56 - 1.77792083762306e+84*cos(theta)**54 + 3.67659641421762e+84*cos(theta)**52 - 5.70194952661119e+84*cos(theta)**50 + 6.88844987189221e+84*cos(theta)**48 - 6.64685325534167e+84*cos(theta)**46 + 5.21173721157472e+84*cos(theta)**44 - 3.36080668176529e+84*cos(theta)**42 + 1.79730096459622e+84*cos(theta)**40 - 8.0154073892799e+83*cos(theta)**38 + 2.99088715215699e+83*cos(theta)**36 - 9.35116082312111e+82*cos(theta)**34 + 2.44911354891267e+82*cos(theta)**32 - 5.36318022190148e+81*cos(theta)**30 + 9.78600418006352e+80*cos(theta)**28 - 1.48023592639616e+80*cos(theta)**26 + 1.84320565547415e+79*cos(theta)**24 - 1.87237674240289e+78*cos(theta)**22 + 1.53375541664918e+77*cos(theta)**20 - 9.98333433242012e+75*cos(theta)**18 + 5.06785054034598e+74*cos(theta)**16 - 1.95858958081004e+73*cos(theta)**14 + 5.58369836634441e+71*cos(theta)**12 - 1.12526440359918e+70*cos(theta)**10 + 1.50974651645686e+68*cos(theta)**8 - 1.23280555441213e+66*cos(theta)**6 + 5.283452376052e+63*cos(theta)**4 - 8.88722014474685e+60*cos(theta)**2 + 2.44827001232696e+57)*cos(30*phi)

#@torch.jit.script
def Yl90_m31(theta, phi):
    return 2.22162904171772e-60*(1.0 - cos(theta)**2)**15.5*(7.87612184295975e+83*cos(theta)**59 - 7.52851646553304e+84*cos(theta)**57 + 3.39421250818947e+85*cos(theta)**55 - 9.6007725231645e+85*cos(theta)**53 + 1.91183013539316e+86*cos(theta)**51 - 2.85097476330559e+86*cos(theta)**49 + 3.30645593850826e+86*cos(theta)**47 - 3.05755249745717e+86*cos(theta)**45 + 2.29316437309288e+86*cos(theta)**43 - 1.41153880634142e+86*cos(theta)**41 + 7.18920385838489e+85*cos(theta)**39 - 3.04585480792636e+85*cos(theta)**37 + 1.07671937477652e+85*cos(theta)**35 - 3.17939467986118e+84*cos(theta)**33 + 7.83716335652055e+83*cos(theta)**31 - 1.60895406657044e+83*cos(theta)**29 + 2.74008117041778e+82*cos(theta)**27 - 3.84861340863002e+81*cos(theta)**25 + 4.42369357313796e+80*cos(theta)**23 - 4.11922883328636e+79*cos(theta)**21 + 3.06751083329835e+78*cos(theta)**19 - 1.79700017983562e+77*cos(theta)**17 + 8.10856086455357e+75*cos(theta)**15 - 2.74202541313406e+74*cos(theta)**13 + 6.7004380396133e+72*cos(theta)**11 - 1.12526440359918e+71*cos(theta)**9 + 1.20779721316549e+69*cos(theta)**7 - 7.3968333264728e+66*cos(theta)**5 + 2.1133809504208e+64*cos(theta)**3 - 1.77744402894937e+61*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl90_m32(theta, phi):
    return 2.61857865120515e-62*(1.0 - cos(theta)**2)**16*(4.64691188734625e+85*cos(theta)**58 - 4.29125438535383e+86*cos(theta)**56 + 1.86681687950421e+87*cos(theta)**54 - 5.08840943727719e+87*cos(theta)**52 + 9.75033369050513e+87*cos(theta)**50 - 1.39697763401974e+88*cos(theta)**48 + 1.55403429109888e+88*cos(theta)**46 - 1.37589862385573e+88*cos(theta)**44 + 9.86060680429937e+87*cos(theta)**42 - 5.78730910599984e+87*cos(theta)**40 + 2.80378950477011e+87*cos(theta)**38 - 1.12696627893275e+87*cos(theta)**36 + 3.76851781171781e+86*cos(theta)**34 - 1.04920024435419e+86*cos(theta)**32 + 2.42952064052137e+85*cos(theta)**30 - 4.66596679305429e+84*cos(theta)**28 + 7.39821916012802e+83*cos(theta)**26 - 9.62153352157506e+82*cos(theta)**24 + 1.01744952182173e+82*cos(theta)**22 - 8.65038054990135e+80*cos(theta)**20 + 5.82827058326687e+79*cos(theta)**18 - 3.05490030572056e+78*cos(theta)**16 + 1.21628412968304e+77*cos(theta)**14 - 3.56463303707427e+75*cos(theta)**12 + 7.37048184357463e+73*cos(theta)**10 - 1.01273796323926e+72*cos(theta)**8 + 8.45458049215842e+69*cos(theta)**6 - 3.6984166632364e+67*cos(theta)**4 + 6.3401428512624e+64*cos(theta)**2 - 1.77744402894937e+61)*cos(32*phi)

#@torch.jit.script
def Yl90_m33(theta, phi):
    return 3.10026680543058e-64*(1.0 - cos(theta)**2)**16.5*(2.69520889466083e+87*cos(theta)**57 - 2.40310245579815e+88*cos(theta)**55 + 1.00808111493227e+89*cos(theta)**53 - 2.64597290738414e+89*cos(theta)**51 + 4.87516684525257e+89*cos(theta)**49 - 6.70549264329476e+89*cos(theta)**47 + 7.14855773905486e+89*cos(theta)**45 - 6.0539539449652e+89*cos(theta)**43 + 4.14145485780574e+89*cos(theta)**41 - 2.31492364239993e+89*cos(theta)**39 + 1.06544001181264e+89*cos(theta)**37 - 4.05707860415791e+88*cos(theta)**35 + 1.28129605598405e+88*cos(theta)**33 - 3.3574407819334e+87*cos(theta)**31 + 7.28856192156411e+86*cos(theta)**29 - 1.3064707020552e+86*cos(theta)**27 + 1.92353698163329e+85*cos(theta)**25 - 2.30916804517801e+84*cos(theta)**23 + 2.23838894800781e+83*cos(theta)**21 - 1.73007610998027e+82*cos(theta)**19 + 1.04908870498804e+81*cos(theta)**17 - 4.88784048915289e+79*cos(theta)**15 + 1.70279778155625e+78*cos(theta)**13 - 4.27755964448913e+76*cos(theta)**11 + 7.37048184357463e+74*cos(theta)**9 - 8.10190370591409e+72*cos(theta)**7 + 5.07274829529505e+70*cos(theta)**5 - 1.47936666529456e+68*cos(theta)**3 + 1.26802857025248e+65*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl90_m34(theta, phi):
    return 3.68765938330789e-66*(1.0 - cos(theta)**2)**17*(1.53626906995667e+89*cos(theta)**56 - 1.32170635068898e+90*cos(theta)**54 + 5.34282990914105e+90*cos(theta)**52 - 1.34944618276591e+91*cos(theta)**50 + 2.38883175417376e+91*cos(theta)**48 - 3.15158154234854e+91*cos(theta)**46 + 3.21685098257469e+91*cos(theta)**44 - 2.60320019633503e+91*cos(theta)**42 + 1.69799649170035e+91*cos(theta)**40 - 9.02820220535975e+90*cos(theta)**38 + 3.94212804370677e+90*cos(theta)**36 - 1.41997751145527e+90*cos(theta)**34 + 4.22827698474738e+89*cos(theta)**32 - 1.04080664239935e+89*cos(theta)**30 + 2.11368295725359e+88*cos(theta)**28 - 3.52747089554904e+87*cos(theta)**26 + 4.80884245408321e+86*cos(theta)**24 - 5.31108650390943e+85*cos(theta)**22 + 4.70061679081639e+84*cos(theta)**20 - 3.28714460896251e+83*cos(theta)**18 + 1.78345079847966e+82*cos(theta)**16 - 7.33176073372934e+80*cos(theta)**14 + 2.21363711602312e+79*cos(theta)**12 - 4.70531560893804e+77*cos(theta)**10 + 6.63343365921716e+75*cos(theta)**8 - 5.67133259413987e+73*cos(theta)**6 + 2.53637414764752e+71*cos(theta)**4 - 4.43809999588368e+68*cos(theta)**2 + 1.26802857025248e+65)*cos(34*phi)

#@torch.jit.script
def Yl90_m35(theta, phi):
    return 4.40759599641002e-68*(1.0 - cos(theta)**2)**17.5*(8.60310679175736e+90*cos(theta)**55 - 7.13721429372049e+91*cos(theta)**53 + 2.77827155275334e+92*cos(theta)**51 - 6.74723091382955e+92*cos(theta)**49 + 1.1466392420034e+93*cos(theta)**47 - 1.44972750948033e+93*cos(theta)**45 + 1.41541443233286e+93*cos(theta)**43 - 1.09334408246071e+93*cos(theta)**41 + 6.79198596680141e+92*cos(theta)**39 - 3.4307168380367e+92*cos(theta)**37 + 1.41916609573444e+92*cos(theta)**35 - 4.82792353894792e+91*cos(theta)**33 + 1.35304863511916e+91*cos(theta)**31 - 3.12241992719806e+90*cos(theta)**29 + 5.91831228031006e+89*cos(theta)**27 - 9.1714243284275e+88*cos(theta)**25 + 1.15412218897997e+88*cos(theta)**23 - 1.16843903086007e+87*cos(theta)**21 + 9.40123358163279e+85*cos(theta)**19 - 5.91686029613252e+84*cos(theta)**17 + 2.85352127756746e+83*cos(theta)**15 - 1.02644650272211e+82*cos(theta)**13 + 2.65636453922775e+80*cos(theta)**11 - 4.70531560893804e+78*cos(theta)**9 + 5.30674692737373e+76*cos(theta)**7 - 3.40279955648392e+74*cos(theta)**5 + 1.01454965905901e+72*cos(theta)**3 - 8.87619999176736e+68*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl90_m36(theta, phi):
    return 5.294624471457e-70*(1.0 - cos(theta)**2)**18*(4.73170873546655e+92*cos(theta)**54 - 3.78272357567186e+93*cos(theta)**52 + 1.41691849190421e+94*cos(theta)**50 - 3.30614314777648e+94*cos(theta)**48 + 5.389204437416e+94*cos(theta)**46 - 6.52377379266147e+94*cos(theta)**44 + 6.08628205903131e+94*cos(theta)**42 - 4.48271073808893e+94*cos(theta)**40 + 2.64887452705255e+94*cos(theta)**38 - 1.26936523007358e+94*cos(theta)**36 + 4.96708133507053e+93*cos(theta)**34 - 1.59321476785281e+93*cos(theta)**32 + 4.1944507688694e+92*cos(theta)**30 - 9.05501778887438e+91*cos(theta)**28 + 1.59794431568371e+91*cos(theta)**26 - 2.29285608210688e+90*cos(theta)**24 + 2.65448103465393e+89*cos(theta)**22 - 2.45372196480616e+88*cos(theta)**20 + 1.78623438051023e+87*cos(theta)**18 - 1.00586625034253e+86*cos(theta)**16 + 4.28028191635119e+84*cos(theta)**14 - 1.33438045353874e+83*cos(theta)**12 + 2.92200099315052e+81*cos(theta)**10 - 4.23478404804424e+79*cos(theta)**8 + 3.71472284916161e+77*cos(theta)**6 - 1.70139977824196e+75*cos(theta)**4 + 3.04364897717703e+72*cos(theta)**2 - 8.87619999176736e+68)*cos(36*phi)

#@torch.jit.script
def Yl90_m37(theta, phi):
    return 6.39346691626065e-72*(1.0 - cos(theta)**2)**18.5*(2.55512271715194e+94*cos(theta)**53 - 1.96701625934937e+95*cos(theta)**51 + 7.08459245952103e+95*cos(theta)**49 - 1.58694871093271e+96*cos(theta)**47 + 2.47903404121136e+96*cos(theta)**45 - 2.87046046877105e+96*cos(theta)**43 + 2.55623846479315e+96*cos(theta)**41 - 1.79308429523557e+96*cos(theta)**39 + 1.00657232027997e+96*cos(theta)**37 - 4.56971482826489e+95*cos(theta)**35 + 1.68880765392398e+95*cos(theta)**33 - 5.098287257129e+94*cos(theta)**31 + 1.25833523066082e+94*cos(theta)**29 - 2.53540498088483e+93*cos(theta)**27 + 4.15465522077766e+92*cos(theta)**25 - 5.5028545970565e+91*cos(theta)**23 + 5.83985827623865e+90*cos(theta)**21 - 4.90744392961231e+89*cos(theta)**19 + 3.21522188491841e+88*cos(theta)**17 - 1.60938600054805e+87*cos(theta)**15 + 5.99239468289166e+85*cos(theta)**13 - 1.60125654424649e+84*cos(theta)**11 + 2.92200099315052e+82*cos(theta)**9 - 3.38782723843539e+80*cos(theta)**7 + 2.22883370949697e+78*cos(theta)**5 - 6.80559911296784e+75*cos(theta)**3 + 6.08729795435406e+72*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl90_m38(theta, phi):
    return 7.76235503401608e-74*(1.0 - cos(theta)**2)**19*(1.35421504009053e+96*cos(theta)**52 - 1.00317829226818e+97*cos(theta)**50 + 3.4714503051653e+97*cos(theta)**48 - 7.45865894138374e+97*cos(theta)**46 + 1.11556531854511e+98*cos(theta)**44 - 1.23429800157155e+98*cos(theta)**42 + 1.04805777056519e+98*cos(theta)**40 - 6.99302875141873e+97*cos(theta)**38 + 3.72431758503588e+97*cos(theta)**36 - 1.59940018989271e+97*cos(theta)**34 + 5.57306525794914e+96*cos(theta)**32 - 1.58046904970999e+96*cos(theta)**30 + 3.64917216891638e+95*cos(theta)**28 - 6.84559344838904e+94*cos(theta)**26 + 1.03866380519441e+94*cos(theta)**24 - 1.265656557323e+93*cos(theta)**22 + 1.22637023801012e+92*cos(theta)**20 - 9.3241434662634e+90*cos(theta)**18 + 5.4658772043613e+89*cos(theta)**16 - 2.41407900082207e+88*cos(theta)**14 + 7.79011308775916e+86*cos(theta)**12 - 1.76138219867114e+85*cos(theta)**10 + 2.62980089383547e+83*cos(theta)**8 - 2.37147906690477e+81*cos(theta)**6 + 1.11441685474848e+79*cos(theta)**4 - 2.04167973389035e+76*cos(theta)**2 + 6.08729795435406e+72)*cos(38*phi)

#@torch.jit.script
def Yl90_m39(theta, phi):
    return 9.4775694516246e-76*(1.0 - cos(theta)**2)**19.5*(7.04191820847074e+97*cos(theta)**51 - 5.01589146134089e+98*cos(theta)**49 + 1.66629614647935e+99*cos(theta)**47 - 3.43098311303652e+99*cos(theta)**45 + 4.90848740159849e+99*cos(theta)**43 - 5.18405160660051e+99*cos(theta)**41 + 4.19223108226077e+99*cos(theta)**39 - 2.65735092553912e+99*cos(theta)**37 + 1.34075433061292e+99*cos(theta)**35 - 5.43796064563522e+98*cos(theta)**33 + 1.78338088254372e+98*cos(theta)**31 - 4.74140714912997e+97*cos(theta)**29 + 1.02176820729659e+97*cos(theta)**27 - 1.77985429658115e+96*cos(theta)**25 + 2.4927931324666e+95*cos(theta)**23 - 2.78444442611059e+94*cos(theta)**21 + 2.45274047602023e+93*cos(theta)**19 - 1.67834582392741e+92*cos(theta)**17 + 8.74540352697808e+90*cos(theta)**15 - 3.3797106011509e+89*cos(theta)**13 + 9.34813570531099e+87*cos(theta)**11 - 1.76138219867114e+86*cos(theta)**9 + 2.10384071506838e+84*cos(theta)**7 - 1.42288744014286e+82*cos(theta)**5 + 4.45766741899393e+79*cos(theta)**3 - 4.0833594677807e+76*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl90_m40(theta, phi):
    return 1.16396577719155e-77*(1.0 - cos(theta)**2)**20*(3.59137828632008e+99*cos(theta)**50 - 2.45778681605704e+100*cos(theta)**48 + 7.83159188845293e+100*cos(theta)**46 - 1.54394240086643e+101*cos(theta)**44 + 2.11064958268735e+101*cos(theta)**42 - 2.12546115870621e+101*cos(theta)**40 + 1.6349701220817e+101*cos(theta)**38 - 9.83219842449474e+100*cos(theta)**36 + 4.69264015714521e+100*cos(theta)**34 - 1.79452701305962e+100*cos(theta)**32 + 5.52848073588554e+99*cos(theta)**30 - 1.37500807324769e+99*cos(theta)**28 + 2.75877415970078e+98*cos(theta)**26 - 4.44963574145287e+97*cos(theta)**24 + 5.73342420467317e+96*cos(theta)**22 - 5.84733329483224e+95*cos(theta)**20 + 4.66020690443845e+94*cos(theta)**18 - 2.8531879006766e+93*cos(theta)**16 + 1.31181052904671e+92*cos(theta)**14 - 4.39362378149617e+90*cos(theta)**12 + 1.02829492758421e+89*cos(theta)**10 - 1.58524397880402e+87*cos(theta)**8 + 1.47268850054786e+85*cos(theta)**6 - 7.11443720071432e+82*cos(theta)**4 + 1.33730022569818e+80*cos(theta)**2 - 4.0833594677807e+76)*cos(40*phi)

#@torch.jit.script
def Yl90_m41(theta, phi):
    return 1.43820091732168e-79*(1.0 - cos(theta)**2)**20.5*(1.79568914316004e+101*cos(theta)**49 - 1.17973767170738e+102*cos(theta)**47 + 3.60253226868835e+102*cos(theta)**45 - 6.79334656381231e+102*cos(theta)**43 + 8.86472824728687e+102*cos(theta)**41 - 8.50184463482484e+102*cos(theta)**39 + 6.21288646391046e+102*cos(theta)**37 - 3.5395914328181e+102*cos(theta)**35 + 1.59549765342937e+102*cos(theta)**33 - 5.74248644179079e+101*cos(theta)**31 + 1.65854422076566e+101*cos(theta)**29 - 3.85002260509353e+100*cos(theta)**27 + 7.17281281522203e+99*cos(theta)**25 - 1.06791257794869e+99*cos(theta)**23 + 1.2613533250281e+98*cos(theta)**21 - 1.16946665896645e+97*cos(theta)**19 + 8.3883724279892e+95*cos(theta)**17 - 4.56510064108256e+94*cos(theta)**15 + 1.8365347406654e+93*cos(theta)**13 - 5.2723485377954e+91*cos(theta)**11 + 1.02829492758421e+90*cos(theta)**9 - 1.26819518304322e+88*cos(theta)**7 + 8.83613100328718e+85*cos(theta)**5 - 2.84577488028573e+83*cos(theta)**3 + 2.67460045139636e+80*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl90_m42(theta, phi):
    return 1.78827603200494e-81*(1.0 - cos(theta)**2)**21*(8.79887680148419e+102*cos(theta)**48 - 5.54476705702467e+103*cos(theta)**46 + 1.62113952090976e+104*cos(theta)**44 - 2.92113902243929e+104*cos(theta)**42 + 3.63453858138762e+104*cos(theta)**40 - 3.31571940758169e+104*cos(theta)**38 + 2.29876799164687e+104*cos(theta)**36 - 1.23885700148634e+104*cos(theta)**34 + 5.26514225631693e+103*cos(theta)**32 - 1.78017079695514e+103*cos(theta)**30 + 4.80977824022042e+102*cos(theta)**28 - 1.03950610337525e+102*cos(theta)**26 + 1.79320320380551e+101*cos(theta)**24 - 2.45619892928199e+100*cos(theta)**22 + 2.648841982559e+99*cos(theta)**20 - 2.22198665203625e+98*cos(theta)**18 + 1.42602331275816e+97*cos(theta)**16 - 6.84765096162384e+95*cos(theta)**14 + 2.38749516286502e+94*cos(theta)**12 - 5.79958339157494e+92*cos(theta)**10 + 9.25465434825788e+90*cos(theta)**8 - 8.87736628130252e+88*cos(theta)**6 + 4.41806550164359e+86*cos(theta)**4 - 8.53732464085718e+83*cos(theta)**2 + 2.67460045139636e+80)*cos(42*phi)

#@torch.jit.script
def Yl90_m43(theta, phi):
    return 2.23814447133482e-83*(1.0 - cos(theta)**2)**21.5*(4.22346086471241e+104*cos(theta)**47 - 2.55059284623135e+105*cos(theta)**45 + 7.13301389200292e+105*cos(theta)**43 - 1.2268783894245e+106*cos(theta)**41 + 1.45381543255505e+106*cos(theta)**39 - 1.25997337488104e+106*cos(theta)**37 + 8.27556476992873e+105*cos(theta)**35 - 4.21211380505354e+105*cos(theta)**33 + 1.68484552202142e+105*cos(theta)**31 - 5.34051239086543e+104*cos(theta)**29 + 1.34673790726172e+104*cos(theta)**27 - 2.70271586877566e+103*cos(theta)**25 + 4.30368768913322e+102*cos(theta)**23 - 5.40363764442037e+101*cos(theta)**21 + 5.29768396511801e+100*cos(theta)**19 - 3.99957597366525e+99*cos(theta)**17 + 2.28163730041306e+98*cos(theta)**15 - 9.58671134627337e+96*cos(theta)**13 + 2.86499419543802e+95*cos(theta)**11 - 5.79958339157494e+93*cos(theta)**9 + 7.4037234786063e+91*cos(theta)**7 - 5.32641976878151e+89*cos(theta)**5 + 1.76722620065744e+87*cos(theta)**3 - 1.70746492817144e+84*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl90_m44(theta, phi):
    return 2.82024467884152e-85*(1.0 - cos(theta)**2)**22*(1.98502660641483e+106*cos(theta)**46 - 1.14776678080411e+107*cos(theta)**44 + 3.06719597356126e+107*cos(theta)**42 - 5.03020139664046e+107*cos(theta)**40 + 5.66988018696468e+107*cos(theta)**38 - 4.66190148705985e+107*cos(theta)**36 + 2.89644766947506e+107*cos(theta)**34 - 1.38999755566767e+107*cos(theta)**32 + 5.2230211182664e+106*cos(theta)**30 - 1.54874859335098e+106*cos(theta)**28 + 3.63619234960664e+105*cos(theta)**26 - 6.75678967193915e+104*cos(theta)**24 + 9.8984816850064e+103*cos(theta)**22 - 1.13476390532828e+103*cos(theta)**20 + 1.00655995337242e+102*cos(theta)**18 - 6.79927915523093e+100*cos(theta)**16 + 3.42245595061959e+99*cos(theta)**14 - 1.24627247501554e+98*cos(theta)**12 + 3.15149361498182e+96*cos(theta)**10 - 5.21962505241744e+94*cos(theta)**8 + 5.18260643502441e+92*cos(theta)**6 - 2.66320988439076e+90*cos(theta)**4 + 5.30167860197231e+87*cos(theta)**2 - 1.70746492817144e+84)*cos(44*phi)

#@torch.jit.script
def Yl90_m45(theta, phi):
    return 3.5788293339898e-87*(1.0 - cos(theta)**2)**22.5*(9.13112238950823e+107*cos(theta)**45 - 5.05017383553807e+108*cos(theta)**43 + 1.28822230889573e+109*cos(theta)**41 - 2.01208055865618e+109*cos(theta)**39 + 2.15455447104658e+109*cos(theta)**37 - 1.67828453534155e+109*cos(theta)**35 + 9.84792207621519e+108*cos(theta)**33 - 4.44799217813654e+108*cos(theta)**31 + 1.56690633547992e+108*cos(theta)**29 - 4.33649606138273e+107*cos(theta)**27 + 9.45410010897726e+106*cos(theta)**25 - 1.6216295212654e+106*cos(theta)**23 + 2.17766597070141e+105*cos(theta)**21 - 2.26952781065655e+104*cos(theta)**19 + 1.81180791607036e+103*cos(theta)**17 - 1.08788466483695e+102*cos(theta)**15 + 4.79143833086743e+100*cos(theta)**13 - 1.49552697001865e+99*cos(theta)**11 + 3.15149361498182e+97*cos(theta)**9 - 4.17570004193396e+95*cos(theta)**7 + 3.10956386101465e+93*cos(theta)**5 - 1.0652839537563e+91*cos(theta)**3 + 1.06033572039446e+88*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl90_m46(theta, phi):
    return 4.57472800038355e-89*(1.0 - cos(theta)**2)**23*(4.1090050752787e+109*cos(theta)**44 - 2.17157474928137e+110*cos(theta)**42 + 5.28171146647249e+110*cos(theta)**40 - 7.84711417875912e+110*cos(theta)**38 + 7.97185154287234e+110*cos(theta)**36 - 5.87399587369541e+110*cos(theta)**34 + 3.24981428515101e+110*cos(theta)**32 - 1.37887757522233e+110*cos(theta)**30 + 4.54402837289176e+109*cos(theta)**28 - 1.17085393657334e+109*cos(theta)**26 + 2.36352502724432e+108*cos(theta)**24 - 3.72974789891041e+107*cos(theta)**22 + 4.57309853847296e+106*cos(theta)**20 - 4.31210284024745e+105*cos(theta)**18 + 3.08007345731961e+104*cos(theta)**16 - 1.63182699725542e+103*cos(theta)**14 + 6.22886983012766e+101*cos(theta)**12 - 1.64507966702051e+100*cos(theta)**10 + 2.83634425348364e+98*cos(theta)**8 - 2.92299002935377e+96*cos(theta)**6 + 1.55478193050732e+94*cos(theta)**4 - 3.19585186126891e+91*cos(theta)**2 + 1.06033572039446e+88)*cos(46*phi)

#@torch.jit.script
def Yl90_m47(theta, phi):
    return 5.89221595168767e-91*(1.0 - cos(theta)**2)**23.5*(1.80796223312263e+111*cos(theta)**43 - 9.12061394698176e+111*cos(theta)**41 + 2.11268458658899e+112*cos(theta)**39 - 2.98190338792847e+112*cos(theta)**37 + 2.86986655543404e+112*cos(theta)**35 - 1.99715859705644e+112*cos(theta)**33 + 1.03994057124832e+112*cos(theta)**31 - 4.13663272566698e+111*cos(theta)**29 + 1.27232794440969e+111*cos(theta)**27 - 3.04422023509068e+110*cos(theta)**25 + 5.67246006538636e+109*cos(theta)**23 - 8.20544537760291e+108*cos(theta)**21 + 9.14619707694592e+107*cos(theta)**19 - 7.76178511244542e+106*cos(theta)**17 + 4.92811753171138e+105*cos(theta)**15 - 2.28455779615759e+104*cos(theta)**13 + 7.47464379615319e+102*cos(theta)**11 - 1.64507966702051e+101*cos(theta)**9 + 2.26907540278691e+99*cos(theta)**7 - 1.75379401761226e+97*cos(theta)**5 + 6.2191277220293e+94*cos(theta)**3 - 6.39170372253782e+91*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl90_m48(theta, phi):
    return 7.6490039379346e-93*(1.0 - cos(theta)**2)**24*(7.77423760242731e+112*cos(theta)**42 - 3.73945171826252e+113*cos(theta)**40 + 8.23946988769708e+113*cos(theta)**38 - 1.10330425353353e+114*cos(theta)**36 + 1.00445329440192e+114*cos(theta)**34 - 6.59062337028625e+113*cos(theta)**32 + 3.2238157708698e+113*cos(theta)**30 - 1.19962349044343e+113*cos(theta)**28 + 3.43528544990617e+112*cos(theta)**26 - 7.6105505877267e+111*cos(theta)**24 + 1.30466581503886e+111*cos(theta)**22 - 1.72314352929661e+110*cos(theta)**20 + 1.73777744461972e+109*cos(theta)**18 - 1.31950346911572e+108*cos(theta)**16 + 7.39217629756706e+106*cos(theta)**14 - 2.96992513500487e+105*cos(theta)**12 + 8.22210817576851e+103*cos(theta)**10 - 1.48057170031846e+102*cos(theta)**8 + 1.58835278195084e+100*cos(theta)**6 - 8.76897008806131e+97*cos(theta)**4 + 1.86573831660879e+95*cos(theta)**2 - 6.39170372253782e+91)*cos(48*phi)

#@torch.jit.script
def Yl90_m49(theta, phi):
    return 1.00108934536272e-94*(1.0 - cos(theta)**2)**24.5*(3.26517979301947e+114*cos(theta)**41 - 1.49578068730501e+115*cos(theta)**39 + 3.13099855732489e+115*cos(theta)**37 - 3.97189531272072e+115*cos(theta)**35 + 3.41514120096651e+115*cos(theta)**33 - 2.1089994784916e+115*cos(theta)**31 + 9.67144731260941e+114*cos(theta)**29 - 3.35894577324159e+114*cos(theta)**27 + 8.93174216975605e+113*cos(theta)**25 - 1.82653214105441e+113*cos(theta)**23 + 2.8702647930855e+112*cos(theta)**21 - 3.44628705859322e+111*cos(theta)**19 + 3.1279994003155e+110*cos(theta)**17 - 2.11120555058515e+109*cos(theta)**15 + 1.03490468165939e+108*cos(theta)**13 - 3.56391016200584e+106*cos(theta)**11 + 8.22210817576851e+104*cos(theta)**9 - 1.18445736025477e+103*cos(theta)**7 + 9.53011669170503e+100*cos(theta)**5 - 3.50758803522452e+98*cos(theta)**3 + 3.73147663321758e+95*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl90_m50(theta, phi):
    return 1.32134703033014e-96*(1.0 - cos(theta)**2)**25*(1.33872371513798e+116*cos(theta)**40 - 5.83354468048953e+116*cos(theta)**38 + 1.15846946621021e+117*cos(theta)**36 - 1.39016335945225e+117*cos(theta)**34 + 1.12699659631895e+117*cos(theta)**32 - 6.53789838332396e+116*cos(theta)**30 + 2.80471972065673e+116*cos(theta)**28 - 9.0691535877523e+115*cos(theta)**26 + 2.23293554243901e+115*cos(theta)**24 - 4.20102392442514e+114*cos(theta)**22 + 6.02755606547954e+113*cos(theta)**20 - 6.54794541132712e+112*cos(theta)**18 + 5.31759898053636e+111*cos(theta)**16 - 3.16680832587773e+110*cos(theta)**14 + 1.34537608615721e+109*cos(theta)**12 - 3.92030117820643e+107*cos(theta)**10 + 7.39989735819166e+105*cos(theta)**8 - 8.29120152178337e+103*cos(theta)**6 + 4.76505834585251e+101*cos(theta)**4 - 1.05227641056736e+99*cos(theta)**2 + 3.73147663321758e+95)*cos(50*phi)

#@torch.jit.script
def Yl90_m51(theta, phi):
    return 1.75945166675974e-98*(1.0 - cos(theta)**2)**25.5*(5.35489486055193e+117*cos(theta)**39 - 2.21674697858602e+118*cos(theta)**37 + 4.17049007835675e+118*cos(theta)**35 - 4.72655542213765e+118*cos(theta)**33 + 3.60638910822064e+118*cos(theta)**31 - 1.96136951499719e+118*cos(theta)**29 + 7.85321521783884e+117*cos(theta)**27 - 2.3579799328156e+117*cos(theta)**25 + 5.35904530185363e+116*cos(theta)**23 - 9.2422526337353e+115*cos(theta)**21 + 1.20551121309591e+115*cos(theta)**19 - 1.17863017403888e+114*cos(theta)**17 + 8.50815836885817e+112*cos(theta)**15 - 4.43353165622882e+111*cos(theta)**13 + 1.61445130338865e+110*cos(theta)**11 - 3.92030117820643e+108*cos(theta)**9 + 5.91991788655333e+106*cos(theta)**7 - 4.97472091307003e+104*cos(theta)**5 + 1.90602333834101e+102*cos(theta)**3 - 2.10455282113471e+99*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl90_m52(theta, phi):
    return 2.36429065301138e-100*(1.0 - cos(theta)**2)**26*(2.08840899561525e+119*cos(theta)**38 - 8.20196382076828e+119*cos(theta)**36 + 1.45967152742486e+120*cos(theta)**34 - 1.55976328930543e+120*cos(theta)**32 + 1.1179806235484e+120*cos(theta)**30 - 5.68797159349185e+119*cos(theta)**28 + 2.12036810881649e+119*cos(theta)**26 - 5.89494983203899e+118*cos(theta)**24 + 1.23258041942634e+118*cos(theta)**22 - 1.94087305308441e+117*cos(theta)**20 + 2.29047130488223e+116*cos(theta)**18 - 2.0036712958661e+115*cos(theta)**16 + 1.27622375532873e+114*cos(theta)**14 - 5.76359115309747e+112*cos(theta)**12 + 1.77589643372751e+111*cos(theta)**10 - 3.52827106038578e+109*cos(theta)**8 + 4.14394252058733e+107*cos(theta)**6 - 2.48736045653501e+105*cos(theta)**4 + 5.71807001502302e+102*cos(theta)**2 - 2.10455282113471e+99)*cos(52*phi)

#@torch.jit.script
def Yl90_m53(theta, phi):
    return 3.20731081164077e-102*(1.0 - cos(theta)**2)**26.5*(7.93595418333796e+120*cos(theta)**37 - 2.95270697547658e+121*cos(theta)**35 + 4.96288319324454e+121*cos(theta)**33 - 4.99124252577736e+121*cos(theta)**31 + 3.35394187064519e+121*cos(theta)**29 - 1.59263204617772e+121*cos(theta)**27 + 5.51295708292287e+120*cos(theta)**25 - 1.41478795968936e+120*cos(theta)**23 + 2.71167692273794e+119*cos(theta)**21 - 3.88174610616883e+118*cos(theta)**19 + 4.12284834878801e+117*cos(theta)**17 - 3.20587407338576e+116*cos(theta)**15 + 1.78671325746022e+115*cos(theta)**13 - 6.91630938371696e+113*cos(theta)**11 + 1.77589643372751e+112*cos(theta)**9 - 2.82261684830863e+110*cos(theta)**7 + 2.4863655123524e+108*cos(theta)**5 - 9.94944182614005e+105*cos(theta)**3 + 1.1436140030046e+103*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl90_m54(theta, phi):
    return 4.39398874506055e-104*(1.0 - cos(theta)**2)**27*(2.93630304783504e+122*cos(theta)**36 - 1.0334474414168e+123*cos(theta)**34 + 1.6377514537707e+123*cos(theta)**32 - 1.54728518299098e+123*cos(theta)**30 + 9.72643142487106e+122*cos(theta)**28 - 4.30010652467984e+122*cos(theta)**26 + 1.37823927073072e+122*cos(theta)**24 - 3.25401230728552e+121*cos(theta)**22 + 5.69452153774967e+120*cos(theta)**20 - 7.37531760172077e+119*cos(theta)**18 + 7.00884219293961e+118*cos(theta)**16 - 4.80881111007864e+117*cos(theta)**14 + 2.32272723469828e+116*cos(theta)**12 - 7.60794032208866e+114*cos(theta)**10 + 1.59830679035476e+113*cos(theta)**8 - 1.97583179381604e+111*cos(theta)**6 + 1.2431827561762e+109*cos(theta)**4 - 2.98483254784202e+106*cos(theta)**2 + 1.1436140030046e+103)*cos(54*phi)

#@torch.jit.script
def Yl90_m55(theta, phi):
    return 6.08168173009143e-106*(1.0 - cos(theta)**2)**27.5*(1.05706909722062e+124*cos(theta)**35 - 3.51372130081713e+124*cos(theta)**33 + 5.24080465206623e+124*cos(theta)**31 - 4.64185554897295e+124*cos(theta)**29 + 2.7234007989639e+124*cos(theta)**27 - 1.11802769641676e+124*cos(theta)**25 + 3.30777424975372e+123*cos(theta)**23 - 7.15882707602815e+122*cos(theta)**21 + 1.13890430754993e+122*cos(theta)**19 - 1.32755716830974e+121*cos(theta)**17 + 1.12141475087034e+120*cos(theta)**15 - 6.73233555411009e+118*cos(theta)**13 + 2.78727268163794e+117*cos(theta)**11 - 7.60794032208866e+115*cos(theta)**9 + 1.27864543228381e+114*cos(theta)**7 - 1.18549907628962e+112*cos(theta)**5 + 4.9727310247048e+109*cos(theta)**3 - 5.96966509568403e+106*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl90_m56(theta, phi):
    return 8.5077209857911e-108*(1.0 - cos(theta)**2)**28*(3.69974184027216e+125*cos(theta)**34 - 1.15952802926965e+126*cos(theta)**32 + 1.62464944214053e+126*cos(theta)**30 - 1.34613810920215e+126*cos(theta)**28 + 7.35318215720252e+125*cos(theta)**26 - 2.79506924104189e+125*cos(theta)**24 + 7.60788077443356e+124*cos(theta)**22 - 1.50335368596591e+124*cos(theta)**20 + 2.16391818434487e+123*cos(theta)**18 - 2.25684718612656e+122*cos(theta)**16 + 1.68212212630551e+121*cos(theta)**14 - 8.75203622034312e+119*cos(theta)**12 + 3.06599994980173e+118*cos(theta)**10 - 6.84714628987979e+116*cos(theta)**8 + 8.95051802598666e+114*cos(theta)**6 - 5.92749538144812e+112*cos(theta)**4 + 1.49181930741144e+110*cos(theta)**2 - 5.96966509568403e+106)*cos(56*phi)

#@torch.jit.script
def Yl90_m57(theta, phi):
    return 1.20341414720173e-109*(1.0 - cos(theta)**2)**28.5*(1.25791222569253e+127*cos(theta)**33 - 3.71048969366289e+127*cos(theta)**31 + 4.87394832642159e+127*cos(theta)**29 - 3.76918670576603e+127*cos(theta)**27 + 1.91182736087266e+127*cos(theta)**25 - 6.70816617850054e+126*cos(theta)**23 + 1.67373377037538e+126*cos(theta)**21 - 3.00670737193182e+125*cos(theta)**19 + 3.89505273182077e+124*cos(theta)**17 - 3.61095549780249e+123*cos(theta)**15 + 2.35497097682771e+122*cos(theta)**13 - 1.05024434644117e+121*cos(theta)**11 + 3.06599994980173e+119*cos(theta)**9 - 5.47771703190383e+117*cos(theta)**7 + 5.370310815592e+115*cos(theta)**5 - 2.37099815257925e+113*cos(theta)**3 + 2.98363861482288e+110*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl90_m58(theta, phi):
    return 1.72197675682181e-111*(1.0 - cos(theta)**2)**29*(4.15111034478536e+128*cos(theta)**32 - 1.1502518050355e+129*cos(theta)**30 + 1.41344501466226e+129*cos(theta)**28 - 1.01768041055683e+129*cos(theta)**26 + 4.77956840218164e+128*cos(theta)**24 - 1.54287822105513e+128*cos(theta)**22 + 3.5148409177883e+127*cos(theta)**20 - 5.71274400667047e+126*cos(theta)**18 + 6.62158964409531e+125*cos(theta)**16 - 5.41643324670373e+124*cos(theta)**14 + 3.06146226987602e+123*cos(theta)**12 - 1.15526878108529e+122*cos(theta)**10 + 2.75939995482156e+120*cos(theta)**8 - 3.83440192233268e+118*cos(theta)**6 + 2.685155407796e+116*cos(theta)**4 - 7.11299445773774e+113*cos(theta)**2 + 2.98363861482288e+110)*cos(58*phi)

#@torch.jit.script
def Yl90_m59(theta, phi):
    return 2.49378588056581e-113*(1.0 - cos(theta)**2)**29.5*(1.32835531033131e+130*cos(theta)**31 - 3.45075541510649e+130*cos(theta)**29 + 3.95764604105433e+130*cos(theta)**27 - 2.64596906744775e+130*cos(theta)**25 + 1.14709641652359e+130*cos(theta)**23 - 3.39433208632128e+129*cos(theta)**21 + 7.02968183557661e+128*cos(theta)**19 - 1.02829392120068e+128*cos(theta)**17 + 1.05945434305525e+127*cos(theta)**15 - 7.58300654538523e+125*cos(theta)**13 + 3.67375472385123e+124*cos(theta)**11 - 1.15526878108529e+123*cos(theta)**9 + 2.20751996385725e+121*cos(theta)**7 - 2.30064115339961e+119*cos(theta)**5 + 1.0740621631184e+117*cos(theta)**3 - 1.42259889154755e+114*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl90_m60(theta, phi):
    return 3.65706504865961e-115*(1.0 - cos(theta)**2)**30*(4.11790146202708e+131*cos(theta)**30 - 1.00071907038088e+132*cos(theta)**28 + 1.06856443108467e+132*cos(theta)**26 - 6.61492266861939e+131*cos(theta)**24 + 2.63832175800426e+131*cos(theta)**22 - 7.12809738127468e+130*cos(theta)**20 + 1.33563954875956e+130*cos(theta)**18 - 1.74809966604116e+129*cos(theta)**16 + 1.58918151458288e+128*cos(theta)**14 - 9.8579085090008e+126*cos(theta)**12 + 4.04113019623635e+125*cos(theta)**10 - 1.03974190297676e+124*cos(theta)**8 + 1.54526397470007e+122*cos(theta)**6 - 1.15032057669981e+120*cos(theta)**4 + 3.2221864893552e+117*cos(theta)**2 - 1.42259889154755e+114)*cos(60*phi)

#@torch.jit.script
def Yl90_m61(theta, phi):
    return 5.43354895429245e-117*(1.0 - cos(theta)**2)**30.5*(1.23537043860812e+133*cos(theta)**29 - 2.80201339706647e+133*cos(theta)**27 + 2.77826752082014e+133*cos(theta)**25 - 1.58758144046865e+133*cos(theta)**23 + 5.80430786760938e+132*cos(theta)**21 - 1.42561947625494e+132*cos(theta)**19 + 2.4041511877672e+131*cos(theta)**17 - 2.79695946566586e+130*cos(theta)**15 + 2.22485412041603e+129*cos(theta)**13 - 1.1829490210801e+128*cos(theta)**11 + 4.04113019623635e+126*cos(theta)**9 - 8.3179352238141e+124*cos(theta)**7 + 9.27158384820043e+122*cos(theta)**5 - 4.60128230679922e+120*cos(theta)**3 + 6.44437297871039e+117*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl90_m62(theta, phi):
    return 8.18394668238493e-119*(1.0 - cos(theta)**2)**31*(3.58257427196356e+134*cos(theta)**28 - 7.56543617207947e+134*cos(theta)**26 + 6.94566880205036e+134*cos(theta)**24 - 3.6514373130779e+134*cos(theta)**22 + 1.21890465219797e+134*cos(theta)**20 - 2.70867700488438e+133*cos(theta)**18 + 4.08705701920424e+132*cos(theta)**16 - 4.19543919849879e+131*cos(theta)**14 + 2.89231035654083e+130*cos(theta)**12 - 1.3012439231881e+129*cos(theta)**10 + 3.63701717661272e+127*cos(theta)**8 - 5.82255465666987e+125*cos(theta)**6 + 4.63579192410022e+123*cos(theta)**4 - 1.38038469203977e+121*cos(theta)**2 + 6.44437297871039e+117)*cos(62*phi)

#@torch.jit.script
def Yl90_m63(theta, phi):
    return 1.25036860391688e-120*(1.0 - cos(theta)**2)**31.5*(1.0031207961498e+136*cos(theta)**27 - 1.96701340474066e+136*cos(theta)**25 + 1.66696051249209e+136*cos(theta)**23 - 8.03316208877138e+135*cos(theta)**21 + 2.43780930439594e+135*cos(theta)**19 - 4.87561860879188e+134*cos(theta)**17 + 6.53929123072678e+133*cos(theta)**15 - 5.87361487789831e+132*cos(theta)**13 + 3.470772427849e+131*cos(theta)**11 - 1.3012439231881e+130*cos(theta)**9 + 2.90961374129017e+128*cos(theta)**7 - 3.49353279400192e+126*cos(theta)**5 + 1.85431676964009e+124*cos(theta)**3 - 2.76076938407953e+121*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl90_m64(theta, phi):
    return 1.93908040520439e-122*(1.0 - cos(theta)**2)**32*(2.70842614960445e+137*cos(theta)**26 - 4.91753351185165e+137*cos(theta)**24 + 3.8340091787318e+137*cos(theta)**22 - 1.68696403864199e+137*cos(theta)**20 + 4.63183767835229e+136*cos(theta)**18 - 8.2885516349462e+135*cos(theta)**16 + 9.80893684609017e+134*cos(theta)**14 - 7.6356993412678e+133*cos(theta)**12 + 3.8178496706339e+132*cos(theta)**10 - 1.17111953086929e+131*cos(theta)**8 + 2.03672961890312e+129*cos(theta)**6 - 1.74676639700096e+127*cos(theta)**4 + 5.56295030892026e+124*cos(theta)**2 - 2.76076938407953e+121)*cos(64*phi)

#@torch.jit.script
def Yl90_m65(theta, phi):
    return 3.05452226178839e-124*(1.0 - cos(theta)**2)**32.5*(7.04190798897157e+138*cos(theta)**25 - 1.1802080428444e+139*cos(theta)**23 + 8.43482019320995e+138*cos(theta)**21 - 3.37392807728398e+138*cos(theta)**19 + 8.33730782103412e+137*cos(theta)**17 - 1.32616826159139e+137*cos(theta)**15 + 1.37325115845262e+136*cos(theta)**13 - 9.16283920952136e+134*cos(theta)**11 + 3.8178496706339e+133*cos(theta)**9 - 9.36895624695435e+131*cos(theta)**7 + 1.22203777134187e+130*cos(theta)**5 - 6.98706558800384e+127*cos(theta)**3 + 1.11259006178405e+125*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl90_m66(theta, phi):
    return 4.89115010536715e-126*(1.0 - cos(theta)**2)**33*(1.76047699724289e+140*cos(theta)**24 - 2.71447849854211e+140*cos(theta)**22 + 1.77131224057409e+140*cos(theta)**20 - 6.41046334683956e+139*cos(theta)**18 + 1.4173423295758e+139*cos(theta)**16 - 1.98925239238709e+138*cos(theta)**14 + 1.78522650598841e+137*cos(theta)**12 - 1.00791231304735e+136*cos(theta)**10 + 3.43606470357051e+134*cos(theta)**8 - 6.55826937286805e+132*cos(theta)**6 + 6.11018885670936e+130*cos(theta)**4 - 2.09611967640115e+128*cos(theta)**2 + 1.11259006178405e+125)*cos(66*phi)

#@torch.jit.script
def Yl90_m67(theta, phi):
    return 7.96811409510254e-128*(1.0 - cos(theta)**2)**33.5*(4.22514479338294e+141*cos(theta)**23 - 5.97185269679265e+141*cos(theta)**21 + 3.54262448114818e+141*cos(theta)**19 - 1.15388340243112e+141*cos(theta)**17 + 2.26774772732128e+140*cos(theta)**15 - 2.78495334934192e+139*cos(theta)**13 + 2.14227180718609e+138*cos(theta)**11 - 1.00791231304735e+137*cos(theta)**9 + 2.74885176285641e+135*cos(theta)**7 - 3.93496162372083e+133*cos(theta)**5 + 2.44407554268374e+131*cos(theta)**3 - 4.19223935280231e+128*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl90_m68(theta, phi):
    return 1.32179188920369e-129*(1.0 - cos(theta)**2)**34*(9.71783302478076e+142*cos(theta)**22 - 1.25408906632646e+143*cos(theta)**20 + 6.73098651418154e+142*cos(theta)**18 - 1.96160178413291e+142*cos(theta)**16 + 3.40162159098192e+141*cos(theta)**14 - 3.6204393541445e+140*cos(theta)**12 + 2.3564989879047e+139*cos(theta)**10 - 9.07121081742615e+137*cos(theta)**8 + 1.92419623399949e+136*cos(theta)**6 - 1.96748081186041e+134*cos(theta)**4 + 7.33222662805123e+131*cos(theta)**2 - 4.19223935280231e+128)*cos(68*phi)

#@torch.jit.script
def Yl90_m69(theta, phi):
    return 2.23487470492771e-131*(1.0 - cos(theta)**2)**34.5*(2.13792326545177e+144*cos(theta)**21 - 2.50817813265291e+144*cos(theta)**19 + 1.21157757255268e+144*cos(theta)**17 - 3.13856285461265e+143*cos(theta)**15 + 4.76227022737469e+142*cos(theta)**13 - 4.3445272249734e+141*cos(theta)**11 + 2.3564989879047e+140*cos(theta)**9 - 7.25696865394092e+138*cos(theta)**7 + 1.15451774039969e+137*cos(theta)**5 - 7.86992324744166e+134*cos(theta)**3 + 1.46644532561025e+132*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl90_m70(theta, phi):
    return 3.85552515829005e-133*(1.0 - cos(theta)**2)**35*(4.48963885744871e+145*cos(theta)**20 - 4.76553845204053e+145*cos(theta)**18 + 2.05968187333955e+145*cos(theta)**16 - 4.70784428191898e+144*cos(theta)**14 + 6.19095129558709e+143*cos(theta)**12 - 4.77897994747074e+142*cos(theta)**10 + 2.12084908911423e+141*cos(theta)**8 - 5.07987805775864e+139*cos(theta)**6 + 5.77258870199846e+137*cos(theta)**4 - 2.3609769742325e+135*cos(theta)**2 + 1.46644532561025e+132)*cos(70*phi)

#@torch.jit.script
def Yl90_m71(theta, phi):
    return 6.79447031427588e-135*(1.0 - cos(theta)**2)**35.5*(8.97927771489742e+146*cos(theta)**19 - 8.57796921367296e+146*cos(theta)**17 + 3.29549099734328e+146*cos(theta)**15 - 6.59098199468657e+145*cos(theta)**13 + 7.42914155470451e+144*cos(theta)**11 - 4.77897994747074e+143*cos(theta)**9 + 1.69667927129139e+142*cos(theta)**7 - 3.04792683465519e+140*cos(theta)**5 + 2.30903548079938e+138*cos(theta)**3 - 4.721953948465e+135*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl90_m72(theta, phi):
    return 1.22467625579179e-136*(1.0 - cos(theta)**2)**36*(1.70606276583051e+148*cos(theta)**18 - 1.4582547663244e+148*cos(theta)**16 + 4.94323649601492e+147*cos(theta)**14 - 8.56827659309254e+146*cos(theta)**12 + 8.17205571017496e+145*cos(theta)**10 - 4.30108195272366e+144*cos(theta)**8 + 1.18767548990397e+143*cos(theta)**6 - 1.52396341732759e+141*cos(theta)**4 + 6.92710644239815e+138*cos(theta)**2 - 4.721953948465e+135)*cos(72*phi)

#@torch.jit.script
def Yl90_m73(theta, phi):
    return 2.26095148267755e-138*(1.0 - cos(theta)**2)**36.5*(3.07091297849492e+149*cos(theta)**17 - 2.33320762611904e+149*cos(theta)**15 + 6.92053109442089e+148*cos(theta)**13 - 1.0281931911711e+148*cos(theta)**11 + 8.17205571017496e+146*cos(theta)**9 - 3.44086556217893e+145*cos(theta)**7 + 7.12605293942382e+143*cos(theta)**5 - 6.09585366931037e+141*cos(theta)**3 + 1.38542128847963e+139*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl90_m74(theta, phi):
    return 4.28198220661008e-140*(1.0 - cos(theta)**2)**37*(5.22055206344136e+150*cos(theta)**16 - 3.49981143917857e+150*cos(theta)**14 + 8.99669042274716e+149*cos(theta)**12 - 1.13101251028821e+149*cos(theta)**10 + 7.35485013915747e+147*cos(theta)**8 - 2.40860589352525e+146*cos(theta)**6 + 3.56302646971191e+144*cos(theta)**4 - 1.82875610079311e+142*cos(theta)**2 + 1.38542128847963e+139)*cos(74*phi)

#@torch.jit.script
def Yl90_m75(theta, phi):
    return 8.33379656691093e-142*(1.0 - cos(theta)**2)**37.5*(8.35288330150618e+151*cos(theta)**15 - 4.89973601484999e+151*cos(theta)**13 + 1.07960285072966e+151*cos(theta)**11 - 1.13101251028821e+150*cos(theta)**9 + 5.88388011132597e+148*cos(theta)**7 - 1.44516353611515e+147*cos(theta)**5 + 1.42521058788476e+145*cos(theta)**3 - 3.65751220158622e+142*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl90_m76(theta, phi):
    return 1.67010286601711e-143*(1.0 - cos(theta)**2)**38*(1.25293249522593e+153*cos(theta)**14 - 6.36965681930499e+152*cos(theta)**12 + 1.18756313580263e+152*cos(theta)**10 - 1.01791125925939e+151*cos(theta)**8 + 4.11871607792818e+149*cos(theta)**6 - 7.22581768057576e+147*cos(theta)**4 + 4.27563176365429e+145*cos(theta)**2 - 3.65751220158622e+142)*cos(76*phi)

#@torch.jit.script
def Yl90_m77(theta, phi):
    return 3.45398914132051e-145*(1.0 - cos(theta)**2)**38.5*(1.7541054933163e+154*cos(theta)**13 - 7.64358818316599e+153*cos(theta)**11 + 1.18756313580263e+153*cos(theta)**9 - 8.14329007407515e+151*cos(theta)**7 + 2.47122964675691e+150*cos(theta)**5 - 2.8903270722303e+148*cos(theta)**3 + 8.55126352730859e+145*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl90_m78(theta, phi):
    return 7.39085447023436e-147*(1.0 - cos(theta)**2)**39*(2.28033714131119e+155*cos(theta)**12 - 8.40794700148259e+154*cos(theta)**10 + 1.06880682222236e+154*cos(theta)**8 - 5.7003030518526e+152*cos(theta)**6 + 1.23561482337845e+151*cos(theta)**4 - 8.67098121669091e+148*cos(theta)**2 + 8.55126352730859e+145)*cos(78*phi)

#@torch.jit.script
def Yl90_m79(theta, phi):
    return 1.64119685305045e-148*(1.0 - cos(theta)**2)**39.5*(2.73640456957342e+156*cos(theta)**11 - 8.40794700148259e+155*cos(theta)**9 + 8.5504545777789e+154*cos(theta)**7 - 3.42018183111156e+153*cos(theta)**5 + 4.94245929351382e+151*cos(theta)**3 - 1.73419624333818e+149*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl90_m80(theta, phi):
    return 3.79524548497779e-150*(1.0 - cos(theta)**2)**40*(3.01004502653077e+157*cos(theta)**10 - 7.56715230133433e+156*cos(theta)**8 + 5.98531820444523e+155*cos(theta)**6 - 1.71009091555578e+154*cos(theta)**4 + 1.48273778805415e+152*cos(theta)**2 - 1.73419624333818e+149)*cos(80*phi)

#@torch.jit.script
def Yl90_m81(theta, phi):
    return 9.17786820896213e-152*(1.0 - cos(theta)**2)**40.5*(3.01004502653077e+158*cos(theta)**9 - 6.05372184106746e+157*cos(theta)**7 + 3.59119092266714e+156*cos(theta)**5 - 6.84036366222312e+154*cos(theta)**3 + 2.96547557610829e+152*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl90_m82(theta, phi):
    return 2.33268630094631e-153*(1.0 - cos(theta)**2)**41*(2.70904052387769e+159*cos(theta)**8 - 4.23760528874722e+158*cos(theta)**6 + 1.79559546133357e+157*cos(theta)**4 - 2.05210909866694e+155*cos(theta)**2 + 2.96547557610829e+152)*cos(82*phi)

#@torch.jit.script
def Yl90_m83(theta, phi):
    return 6.27029962282424e-155*(1.0 - cos(theta)**2)**41.5*(2.16723241910215e+160*cos(theta)**7 - 2.54256317324833e+159*cos(theta)**5 + 7.18238184533428e+157*cos(theta)**3 - 4.10421819733387e+155*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl90_m84(theta, phi):
    return 1.79665483178156e-156*(1.0 - cos(theta)**2)**42*(1.51706269337151e+161*cos(theta)**6 - 1.27128158662417e+160*cos(theta)**4 + 2.15471455360028e+158*cos(theta)**2 - 4.10421819733387e+155)*cos(84*phi)

#@torch.jit.script
def Yl90_m85(theta, phi):
    return 5.54459718538947e-158*(1.0 - cos(theta)**2)**42.5*(9.10237616022904e+161*cos(theta)**5 - 5.08512634649667e+160*cos(theta)**3 + 4.30942910720057e+158*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl90_m86(theta, phi):
    return 1.86908332990183e-159*(1.0 - cos(theta)**2)**43*(4.55118808011452e+162*cos(theta)**4 - 1.525537903949e+161*cos(theta)**2 + 4.30942910720057e+158)*cos(86*phi)

#@torch.jit.script
def Yl90_m87(theta, phi):
    return 7.02444530463506e-161*(1.0 - cos(theta)**2)**43.5*(1.82047523204581e+163*cos(theta)**3 - 3.051075807898e+161*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl90_m88(theta, phi):
    return 3.03977477475515e-162*(1.0 - cos(theta)**2)**44*(5.46142569613742e+163*cos(theta)**2 - 3.051075807898e+161)*cos(88*phi)

#@torch.jit.script
def Yl90_m89(theta, phi):
    return 17.5483350761546*(1.0 - cos(theta)**2)**44.5*cos(89*phi)*cos(theta)

#@torch.jit.script
def Yl90_m90(theta, phi):
    return 1.30797567074086*(1.0 - cos(theta)**2)**45*cos(90*phi)

#@torch.jit.script
def Yl91_m_minus_91(theta, phi):
    return 1.31156408810318*(1.0 - cos(theta)**2)**45.5*sin(91*phi)

#@torch.jit.script
def Yl91_m_minus_90(theta, phi):
    return 17.6939669099597*(1.0 - cos(theta)**2)**45*sin(90*phi)*cos(theta)

#@torch.jit.script
def Yl91_m_minus_89(theta, phi):
    return 1.70280491915874e-164*(1.0 - cos(theta)**2)**44.5*(9.88518051000874e+165*cos(theta)**2 - 5.46142569613742e+163)*sin(89*phi)

#@torch.jit.script
def Yl91_m_minus_88(theta, phi):
    return 3.95696105624512e-163*(1.0 - cos(theta)**2)**44*(3.29506017000291e+165*cos(theta)**3 - 5.46142569613742e+163*cos(theta))*sin(88*phi)

#@torch.jit.script
def Yl91_m_minus_87(theta, phi):
    return 1.05881061636435e-161*(1.0 - cos(theta)**2)**43.5*(8.23765042500728e+164*cos(theta)**4 - 2.73071284806871e+163*cos(theta)**2 + 7.627689519745e+160)*sin(87*phi)

#@torch.jit.script
def Yl91_m_minus_86(theta, phi):
    return 3.15873571224314e-160*(1.0 - cos(theta)**2)**43*(1.64753008500146e+164*cos(theta)**5 - 9.10237616022904e+162*cos(theta)**3 + 7.627689519745e+160*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl91_m_minus_85(theta, phi):
    return 1.02937958015436e-158*(1.0 - cos(theta)**2)**42.5*(2.74588347500243e+163*cos(theta)**6 - 2.27559404005726e+162*cos(theta)**4 + 3.8138447598725e+160*cos(theta)**2 - 7.18238184533428e+157)*sin(85*phi)

#@torch.jit.script
def Yl91_m_minus_84(theta, phi):
    return 3.61310766278528e-157*(1.0 - cos(theta)**2)**42*(3.9226906785749e+162*cos(theta)**7 - 4.55118808011452e+161*cos(theta)**5 + 1.27128158662417e+160*cos(theta)**3 - 7.18238184533428e+157*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl91_m_minus_83(theta, phi):
    return 1.35190109756701e-155*(1.0 - cos(theta)**2)**41.5*(4.90336334821862e+161*cos(theta)**8 - 7.58531346685753e+160*cos(theta)**6 + 3.17820396656042e+159*cos(theta)**4 - 3.59119092266714e+157*cos(theta)**2 + 5.13027274666734e+154)*sin(83*phi)

#@torch.jit.script
def Yl91_m_minus_82(theta, phi):
    return 5.3498400728677e-154*(1.0 - cos(theta)**2)**41*(5.44818149802069e+160*cos(theta)**9 - 1.08361620955108e+160*cos(theta)**7 + 6.35640793312084e+158*cos(theta)**5 - 1.19706364088905e+157*cos(theta)**3 + 5.13027274666734e+154*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl91_m_minus_81(theta, phi):
    return 2.2251733557883e-152*(1.0 - cos(theta)**2)**40.5*(5.44818149802069e+159*cos(theta)**10 - 1.35452026193884e+159*cos(theta)**8 + 1.05940132218681e+158*cos(theta)**6 - 2.99265910222262e+156*cos(theta)**4 + 2.56513637333367e+154*cos(theta)**2 - 2.96547557610829e+151)*sin(81*phi)

#@torch.jit.script
def Yl91_m_minus_80(theta, phi):
    return 9.67886465892713e-151*(1.0 - cos(theta)**2)**40*(4.9528922709279e+158*cos(theta)**11 - 1.50502251326538e+158*cos(theta)**9 + 1.51343046026687e+157*cos(theta)**7 - 5.98531820444523e+155*cos(theta)**5 + 8.5504545777789e+153*cos(theta)**3 - 2.96547557610829e+151*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl91_m_minus_79(theta, phi):
    return 4.38442954177759e-149*(1.0 - cos(theta)**2)**39.5*(4.12741022577325e+157*cos(theta)**12 - 1.50502251326538e+157*cos(theta)**10 + 1.89178807533358e+156*cos(theta)**8 - 9.97553034074205e+154*cos(theta)**6 + 2.13761364444473e+153*cos(theta)**4 - 1.48273778805415e+151*cos(theta)**2 + 1.44516353611515e+148)*sin(79*phi)

#@torch.jit.script
def Yl91_m_minus_78(theta, phi):
    return 2.06114826053476e-147*(1.0 - cos(theta)**2)**39*(3.1749309429025e+156*cos(theta)**13 - 1.36820228478671e+156*cos(theta)**11 + 2.10198675037065e+155*cos(theta)**9 - 1.42507576296315e+154*cos(theta)**7 + 4.27522728888945e+152*cos(theta)**5 - 4.94245929351382e+150*cos(theta)**3 + 1.44516353611515e+148*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl91_m_minus_77(theta, phi):
    return 1.0025743798546e-145*(1.0 - cos(theta)**2)**38.5*(2.26780781635893e+155*cos(theta)**14 - 1.14016857065559e+155*cos(theta)**12 + 2.10198675037065e+154*cos(theta)**10 - 1.78134470370394e+153*cos(theta)**8 + 7.12537881481575e+151*cos(theta)**6 - 1.23561482337845e+150*cos(theta)**4 + 7.22581768057576e+147*cos(theta)**2 - 6.10804537664899e+144)*sin(77*phi)

#@torch.jit.script
def Yl91_m_minus_76(theta, phi):
    return 5.03288344350919e-144*(1.0 - cos(theta)**2)**38*(1.51187187757262e+154*cos(theta)**15 - 8.77052746658149e+153*cos(theta)**13 + 1.9108970457915e+153*cos(theta)**11 - 1.97927189300438e+152*cos(theta)**9 + 1.01791125925939e+151*cos(theta)**7 - 2.47122964675691e+149*cos(theta)**5 + 2.40860589352525e+147*cos(theta)**3 - 6.10804537664899e+144*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl91_m_minus_75(theta, phi):
    return 2.60156750632951e-142*(1.0 - cos(theta)**2)**37.5*(9.44919923482887e+152*cos(theta)**16 - 6.26466247612963e+152*cos(theta)**14 + 1.59241420482625e+152*cos(theta)**12 - 1.97927189300438e+151*cos(theta)**10 + 1.27238907407424e+150*cos(theta)**8 - 4.11871607792818e+148*cos(theta)**6 + 6.02151473381313e+146*cos(theta)**4 - 3.0540226883245e+144*cos(theta)**2 + 2.28594512599139e+141)*sin(75*phi)

#@torch.jit.script
def Yl91_m_minus_74(theta, phi):
    return 1.38201769701949e-140*(1.0 - cos(theta)**2)**37*(5.5583524910758e+151*cos(theta)**17 - 4.17644165075309e+151*cos(theta)**15 + 1.2249340037125e+151*cos(theta)**13 - 1.79933808454943e+150*cos(theta)**11 + 1.41376563786027e+149*cos(theta)**9 - 5.88388011132597e+147*cos(theta)**7 + 1.20430294676263e+146*cos(theta)**5 - 1.01800756277483e+144*cos(theta)**3 + 2.28594512599139e+141*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl91_m_minus_73(theta, phi):
    return 7.5316794655501e-139*(1.0 - cos(theta)**2)**36.5*(3.08797360615322e+150*cos(theta)**18 - 2.61027603172068e+150*cos(theta)**16 + 8.74952859794642e+149*cos(theta)**14 - 1.49944840379119e+149*cos(theta)**12 + 1.41376563786027e+148*cos(theta)**10 - 7.35485013915747e+146*cos(theta)**8 + 2.00717157793771e+145*cos(theta)**6 - 2.54501890693708e+143*cos(theta)**4 + 1.14297256299569e+141*cos(theta)**2 - 7.69678493599794e+137)*sin(73*phi)

#@torch.jit.script
def Yl91_m_minus_72(theta, phi):
    return 4.20426956083568e-137*(1.0 - cos(theta)**2)**36*(1.62524926639643e+149*cos(theta)**19 - 1.53545648924746e+149*cos(theta)**17 + 5.83301906529761e+148*cos(theta)**15 - 1.15342184907015e+148*cos(theta)**13 + 1.28524148896388e+147*cos(theta)**11 - 8.17205571017496e+145*cos(theta)**9 + 2.86738796848244e+144*cos(theta)**7 - 5.09003781387416e+142*cos(theta)**5 + 3.80990854331898e+140*cos(theta)**3 - 7.69678493599794e+137*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl91_m_minus_71(theta, phi):
    return 2.40048697311509e-135*(1.0 - cos(theta)**2)**35.5*(8.12624633198217e+147*cos(theta)**20 - 8.53031382915255e+147*cos(theta)**18 + 3.64563691581101e+147*cos(theta)**16 - 8.23872749335821e+146*cos(theta)**14 + 1.07103457413657e+146*cos(theta)**12 - 8.17205571017496e+144*cos(theta)**10 + 3.58423496060305e+143*cos(theta)**8 - 8.48339635645693e+141*cos(theta)**6 + 9.52477135829745e+139*cos(theta)**4 - 3.84839246799897e+137*cos(theta)**2 + 2.3609769742325e+134)*sin(71*phi)

#@torch.jit.script
def Yl91_m_minus_70(theta, phi):
    return 1.40012402603984e-133*(1.0 - cos(theta)**2)**35*(3.8696411104677e+146*cos(theta)**21 - 4.48963885744871e+146*cos(theta)**19 + 2.14449230341824e+146*cos(theta)**17 - 5.49248499557214e+145*cos(theta)**15 + 8.23872749335821e+144*cos(theta)**13 - 7.42914155470451e+143*cos(theta)**11 + 3.98248328955895e+142*cos(theta)**9 - 1.21191376520813e+141*cos(theta)**7 + 1.90495427165949e+139*cos(theta)**5 - 1.28279748933299e+137*cos(theta)**3 + 2.3609769742325e+134*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl91_m_minus_69(theta, phi):
    return 8.33279670647098e-132*(1.0 - cos(theta)**2)**34.5*(1.75892777748532e+145*cos(theta)**22 - 2.24481942872436e+145*cos(theta)**20 + 1.19138461301013e+145*cos(theta)**18 - 3.43280312223259e+144*cos(theta)**16 + 5.88480535239872e+143*cos(theta)**14 - 6.19095129558709e+142*cos(theta)**12 + 3.98248328955895e+141*cos(theta)**10 - 1.51489220651017e+140*cos(theta)**8 + 3.17492378609915e+138*cos(theta)**6 - 3.20699372333248e+136*cos(theta)**4 + 1.18048848711625e+134*cos(theta)**2 - 6.66566057095567e+130)*sin(69*phi)

#@torch.jit.script
def Yl91_m_minus_68(theta, phi):
    return 5.05492476206179e-130*(1.0 - cos(theta)**2)**34*(7.64751207602312e+143*cos(theta)**23 - 1.06896163272588e+144*cos(theta)**21 + 6.27044533163228e+143*cos(theta)**19 - 2.01929595425446e+143*cos(theta)**17 + 3.92320356826581e+142*cos(theta)**15 - 4.76227022737469e+141*cos(theta)**13 + 3.6204393541445e+140*cos(theta)**11 - 1.68321356278907e+139*cos(theta)**9 + 4.53560540871307e+137*cos(theta)**7 - 6.41398744666495e+135*cos(theta)**5 + 3.93496162372083e+133*cos(theta)**3 - 6.66566057095567e+130*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl91_m_minus_67(theta, phi):
    return 3.1226181444423e-128*(1.0 - cos(theta)**2)**33.5*(3.18646336500963e+142*cos(theta)**24 - 4.85891651239038e+142*cos(theta)**22 + 3.13522266581614e+142*cos(theta)**20 - 1.12183108569692e+142*cos(theta)**18 + 2.45200223016613e+141*cos(theta)**16 - 3.40162159098192e+140*cos(theta)**14 + 3.01703279512042e+139*cos(theta)**12 - 1.68321356278907e+138*cos(theta)**10 + 5.66950676089134e+136*cos(theta)**8 - 1.06899790777749e+135*cos(theta)**6 + 9.83740405930207e+132*cos(theta)**4 - 3.33283028547783e+130*cos(theta)**2 + 1.74676639700096e+127)*sin(67*phi)

#@torch.jit.script
def Yl91_m_minus_66(theta, phi):
    return 1.96253507230319e-126*(1.0 - cos(theta)**2)**33*(1.27458534600385e+141*cos(theta)**25 - 2.11257239669147e+141*cos(theta)**23 + 1.49296317419816e+141*cos(theta)**21 - 5.90437413524697e+140*cos(theta)**19 + 1.4423542530389e+140*cos(theta)**17 - 2.26774772732128e+139*cos(theta)**15 + 2.32079445778494e+138*cos(theta)**13 - 1.53019414799007e+137*cos(theta)**11 + 6.29945195654593e+135*cos(theta)**9 - 1.52713986825356e+134*cos(theta)**7 + 1.96748081186041e+132*cos(theta)**5 - 1.11094342849261e+130*cos(theta)**3 + 1.74676639700096e+127*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl91_m_minus_65(theta, phi):
    return 1.25387408621049e-124*(1.0 - cos(theta)**2)**32.5*(4.90225133078405e+139*cos(theta)**26 - 8.80238498621446e+139*cos(theta)**24 + 6.78619624635528e+139*cos(theta)**22 - 2.95218706762348e+139*cos(theta)**20 + 8.01307918354945e+138*cos(theta)**18 - 1.4173423295758e+138*cos(theta)**16 + 1.65771032698924e+137*cos(theta)**14 - 1.27516178999172e+136*cos(theta)**12 + 6.29945195654593e+134*cos(theta)**10 - 1.90892483531695e+133*cos(theta)**8 + 3.27913468643402e+131*cos(theta)**6 - 2.77735857123153e+129*cos(theta)**4 + 8.73383198500481e+126*cos(theta)**2 - 4.27919254532328e+123)*sin(65*phi)

#@torch.jit.script
def Yl91_m_minus_64(theta, phi):
    return 8.13763315945349e-123*(1.0 - cos(theta)**2)**32*(1.81564864103113e+138*cos(theta)**27 - 3.52095399448578e+138*cos(theta)**25 + 2.95052010711099e+138*cos(theta)**23 - 1.40580336553499e+138*cos(theta)**21 + 4.21741009660498e+137*cos(theta)**19 - 8.33730782103411e+136*cos(theta)**17 + 1.10514021799283e+136*cos(theta)**15 - 9.80893684609017e+134*cos(theta)**13 + 5.72677450595085e+133*cos(theta)**11 - 2.12102759479661e+132*cos(theta)**9 + 4.68447812347718e+130*cos(theta)**7 - 5.55471714246306e+128*cos(theta)**5 + 2.91127732833494e+126*cos(theta)**3 - 4.27919254532328e+123*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl91_m_minus_63(theta, phi):
    return 5.36096501313161e-121*(1.0 - cos(theta)**2)**31.5*(6.48445943225404e+136*cos(theta)**28 - 1.35421307480222e+137*cos(theta)**26 + 1.22938337796291e+137*cos(theta)**24 - 6.39001529788633e+136*cos(theta)**22 + 2.10870504830249e+136*cos(theta)**20 - 4.63183767835229e+135*cos(theta)**18 + 6.90712636245516e+134*cos(theta)**16 - 7.00638346149298e+133*cos(theta)**14 + 4.77231208829237e+132*cos(theta)**12 - 2.12102759479661e+131*cos(theta)**10 + 5.85559765434647e+129*cos(theta)**8 - 9.25786190410509e+127*cos(theta)**6 + 7.27819332083734e+125*cos(theta)**4 - 2.13959627266164e+123*cos(theta)**2 + 9.8598906574269e+119)*sin(63*phi)

#@torch.jit.script
def Yl91_m_minus_62(theta, phi):
    return 3.58263308565707e-119*(1.0 - cos(theta)**2)**31*(2.2360204938807e+135*cos(theta)**29 - 5.01560398074898e+135*cos(theta)**27 + 4.91753351185165e+135*cos(theta)**25 - 2.77826752082014e+135*cos(theta)**23 + 1.00414526109642e+135*cos(theta)**21 - 2.43780930439594e+134*cos(theta)**19 + 4.06301550732657e+133*cos(theta)**17 - 4.67092230766199e+132*cos(theta)**15 + 3.67100929868644e+131*cos(theta)**13 - 1.92820690436056e+130*cos(theta)**11 + 6.50621961594052e+128*cos(theta)**9 - 1.32255170058644e+127*cos(theta)**7 + 1.45563866416747e+125*cos(theta)**5 - 7.13198757553879e+122*cos(theta)**3 + 9.8598906574269e+119*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl91_m_minus_61(theta, phi):
    return 2.42721739041605e-117*(1.0 - cos(theta)**2)**30.5*(7.45340164626901e+133*cos(theta)**30 - 1.79128713598178e+134*cos(theta)**28 + 1.89135904301987e+134*cos(theta)**26 - 1.15761146700839e+134*cos(theta)**24 + 4.56429664134738e+133*cos(theta)**22 - 1.21890465219797e+133*cos(theta)**20 + 2.25723083740365e+132*cos(theta)**18 - 2.91932644228874e+131*cos(theta)**16 + 2.62214949906174e+130*cos(theta)**14 - 1.60683908696713e+129*cos(theta)**12 + 6.50621961594052e+127*cos(theta)**10 - 1.65318962573305e+126*cos(theta)**8 + 2.42606444027911e+124*cos(theta)**6 - 1.7829968938847e+122*cos(theta)**4 + 4.92994532871345e+119*cos(theta)**2 - 2.1481243262368e+116)*sin(61*phi)

#@torch.jit.script
def Yl91_m_minus_60(theta, phi):
    return 1.66613932894921e-115*(1.0 - cos(theta)**2)**30*(2.40432311169968e+132*cos(theta)**31 - 6.17685219304061e+132*cos(theta)**29 + 7.00503349266617e+132*cos(theta)**27 - 4.63044586803357e+132*cos(theta)**25 + 1.98447680058582e+132*cos(theta)**23 - 5.80430786760938e+131*cos(theta)**21 + 1.18801623021245e+131*cos(theta)**19 - 1.71725084840514e+130*cos(theta)**17 + 1.74809966604116e+129*cos(theta)**15 - 1.23603006689779e+128*cos(theta)**13 + 5.91474510540048e+126*cos(theta)**11 - 1.83687736192561e+125*cos(theta)**9 + 3.46580634325588e+123*cos(theta)**7 - 3.5659937877694e+121*cos(theta)**5 + 1.64331510957115e+119*cos(theta)**3 - 2.1481243262368e+116*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl91_m_minus_59(theta, phi):
    return 1.15817658036646e-113*(1.0 - cos(theta)**2)**29.5*(7.5135097240615e+130*cos(theta)**32 - 2.05895073101354e+131*cos(theta)**30 + 2.5017976759522e+131*cos(theta)**28 - 1.78094071847445e+131*cos(theta)**26 + 8.26865333577423e+130*cos(theta)**24 - 2.63832175800426e+130*cos(theta)**22 + 5.94008115106223e+129*cos(theta)**20 - 9.54028249113968e+128*cos(theta)**18 + 1.09256229127573e+128*cos(theta)**16 - 8.82878619212709e+126*cos(theta)**14 + 4.9289542545004e+125*cos(theta)**12 - 1.83687736192561e+124*cos(theta)**10 + 4.33225792906984e+122*cos(theta)**8 - 5.94332297961566e+120*cos(theta)**6 + 4.10828777392788e+118*cos(theta)**4 - 1.0740621631184e+116*cos(theta)**2 + 4.44562153608609e+112)*sin(59*phi)

#@torch.jit.script
def Yl91_m_minus_58(theta, phi):
    return 8.14849452781386e-112*(1.0 - cos(theta)**2)**29*(2.27682112850348e+129*cos(theta)**33 - 6.64177655165657e+129*cos(theta)**31 + 8.62688853776622e+129*cos(theta)**29 - 6.59607673509056e+129*cos(theta)**27 + 3.30746133430969e+129*cos(theta)**25 - 1.14709641652359e+129*cos(theta)**23 + 2.8286100719344e+128*cos(theta)**21 - 5.02120131112615e+127*cos(theta)**19 + 6.42683700750428e+126*cos(theta)**17 - 5.88585746141806e+125*cos(theta)**15 + 3.79150327269261e+124*cos(theta)**13 - 1.66988851084147e+123*cos(theta)**11 + 4.81361992118872e+121*cos(theta)**9 - 8.49046139945094e+119*cos(theta)**7 + 8.21657554785575e+117*cos(theta)**5 - 3.58020721039466e+115*cos(theta)**3 + 4.44562153608609e+112*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl91_m_minus_57(theta, phi):
    return 5.79975931321007e-110*(1.0 - cos(theta)**2)**28.5*(6.6965327308926e+127*cos(theta)**34 - 2.07555517239268e+128*cos(theta)**32 + 2.87562951258874e+128*cos(theta)**30 - 2.35574169110377e+128*cos(theta)**28 + 1.27210051319604e+128*cos(theta)**26 - 4.77956840218164e+127*cos(theta)**24 + 1.28573185087927e+127*cos(theta)**22 - 2.51060065556307e+126*cos(theta)**20 + 3.57046500416904e+125*cos(theta)**18 - 3.67866091338629e+124*cos(theta)**16 + 2.70821662335187e+123*cos(theta)**14 - 1.39157375903456e+122*cos(theta)**12 + 4.81361992118872e+120*cos(theta)**10 - 1.06130767493137e+119*cos(theta)**8 + 1.36942925797596e+117*cos(theta)**6 - 8.95051802598666e+114*cos(theta)**4 + 2.22281076804304e+112*cos(theta)**2 - 8.77540769065552e+108)*sin(57*phi)

#@torch.jit.script
def Yl91_m_minus_56(theta, phi):
    return 4.1742153503652e-108*(1.0 - cos(theta)**2)**28*(1.91329506596931e+126*cos(theta)**35 - 6.28956112846266e+126*cos(theta)**33 + 9.27622423415723e+126*cos(theta)**31 - 8.12324721070266e+126*cos(theta)**29 + 4.71148338220754e+126*cos(theta)**27 - 1.91182736087266e+126*cos(theta)**25 + 5.59013848208379e+125*cos(theta)**23 - 1.1955241216967e+125*cos(theta)**21 + 1.87919210745739e+124*cos(theta)**19 - 2.16391818434487e+123*cos(theta)**17 + 1.80547774890124e+122*cos(theta)**15 - 1.0704413531035e+121*cos(theta)**13 + 4.37601811017156e+119*cos(theta)**11 - 1.17923074992374e+118*cos(theta)**9 + 1.95632751139423e+116*cos(theta)**7 - 1.79010360519733e+114*cos(theta)**5 + 7.40936922681015e+111*cos(theta)**3 - 8.77540769065552e+108*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl91_m_minus_55(theta, phi):
    return 3.03658028879791e-106*(1.0 - cos(theta)**2)**27.5*(5.31470851658143e+124*cos(theta)**36 - 1.84987092013608e+125*cos(theta)**34 + 2.89882007317413e+125*cos(theta)**32 - 2.70774907023422e+125*cos(theta)**30 + 1.68267263650269e+125*cos(theta)**28 - 7.35318215720252e+124*cos(theta)**26 + 2.32922436753491e+124*cos(theta)**24 - 5.43420055316683e+123*cos(theta)**22 + 9.39596053728695e+122*cos(theta)**20 - 1.20217676908049e+122*cos(theta)**18 + 1.12842359306328e+121*cos(theta)**16 - 7.64600966502503e+119*cos(theta)**14 + 3.6466817584763e+118*cos(theta)**12 - 1.17923074992374e+117*cos(theta)**10 + 2.44540938924278e+115*cos(theta)**8 - 2.98350600866222e+113*cos(theta)**6 + 1.85234230670254e+111*cos(theta)**4 - 4.38770384532776e+108*cos(theta)**2 + 1.65824030435667e+105)*sin(55*phi)

#@torch.jit.script
def Yl91_m_minus_54(theta, phi):
    return 2.23183486914707e-104*(1.0 - cos(theta)**2)**27*(1.43640770718417e+123*cos(theta)**37 - 5.28534548610308e+123*cos(theta)**35 + 8.78430325204283e+123*cos(theta)**33 - 8.73467442011038e+123*cos(theta)**31 + 5.80231943621618e+123*cos(theta)**29 - 2.7234007989639e+123*cos(theta)**27 + 9.31689747013965e+122*cos(theta)**25 - 2.36269589268123e+122*cos(theta)**23 + 4.4742669225176e+121*cos(theta)**21 - 6.32724615305519e+120*cos(theta)**19 + 6.63778584154869e+119*cos(theta)**17 - 5.09733977668336e+118*cos(theta)**15 + 2.80513981421254e+117*cos(theta)**13 - 1.07202795447613e+116*cos(theta)**11 + 2.71712154360309e+114*cos(theta)**9 - 4.26215144094603e+112*cos(theta)**7 + 3.70468461340507e+110*cos(theta)**5 - 1.46256794844259e+108*cos(theta)**3 + 1.65824030435667e+105*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl91_m_minus_53(theta, phi):
    return 1.65667705742867e-102*(1.0 - cos(theta)**2)**26.5*(3.78002028206361e+121*cos(theta)**38 - 1.46815152391752e+122*cos(theta)**36 + 2.58361860354201e+122*cos(theta)**34 - 2.72958575628449e+122*cos(theta)**32 + 1.93410647873873e+122*cos(theta)**30 - 9.72643142487106e+121*cos(theta)**28 + 3.58342210389986e+121*cos(theta)**26 - 9.84456621950512e+120*cos(theta)**24 + 2.03375769205345e+120*cos(theta)**22 - 3.16362307652759e+119*cos(theta)**20 + 3.68765880086038e+118*cos(theta)**18 - 3.1858373604271e+117*cos(theta)**16 + 2.0036712958661e+116*cos(theta)**14 - 8.93356628730108e+114*cos(theta)**12 + 2.71712154360309e+113*cos(theta)**10 - 5.32768930118253e+111*cos(theta)**8 + 6.17447435567512e+109*cos(theta)**6 - 3.65641987110647e+107*cos(theta)**4 + 8.29120152178337e+104*cos(theta)**2 - 3.00951053422264e+101)*sin(53*phi)

#@torch.jit.script
def Yl91_m_minus_52(theta, phi):
    return 1.24151338891615e-100*(1.0 - cos(theta)**2)**26*(9.69235969759899e+119*cos(theta)**39 - 3.96797709166898e+120*cos(theta)**37 + 7.38176743869145e+120*cos(theta)**35 - 8.27147198874089e+120*cos(theta)**33 + 6.2390531572217e+120*cos(theta)**31 - 3.35394187064519e+120*cos(theta)**29 + 1.32719337181476e+120*cos(theta)**27 - 3.93782648780205e+119*cos(theta)**25 + 8.84242474805849e+118*cos(theta)**23 - 1.50648717929885e+118*cos(theta)**21 + 1.94087305308441e+117*cos(theta)**19 - 1.87402197672182e+116*cos(theta)**17 + 1.33578086391073e+115*cos(theta)**15 - 6.87197406715468e+113*cos(theta)**13 + 2.47011049418463e+112*cos(theta)**11 - 5.9196547790917e+110*cos(theta)**9 + 8.82067765096446e+108*cos(theta)**7 - 7.31283974221294e+106*cos(theta)**5 + 2.76373384059446e+104*cos(theta)**3 - 3.00951053422264e+101*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl91_m_minus_51(theta, phi):
    return 9.38965038251594e-99*(1.0 - cos(theta)**2)**25.5*(2.42308992439975e+118*cos(theta)**40 - 1.04420449780763e+119*cos(theta)**38 + 2.05049095519207e+119*cos(theta)**36 - 2.43278587904144e+119*cos(theta)**34 + 1.94970411163178e+119*cos(theta)**32 - 1.1179806235484e+119*cos(theta)**30 + 4.73997632790987e+118*cos(theta)**28 - 1.51454864915463e+118*cos(theta)**26 + 3.68434364502437e+117*cos(theta)**24 - 6.84766899681297e+116*cos(theta)**22 + 9.70436526542206e+115*cos(theta)**20 - 1.04112332040101e+115*cos(theta)**18 + 8.34863039944208e+113*cos(theta)**16 - 4.90855290511048e+112*cos(theta)**14 + 2.05842541182052e+111*cos(theta)**12 - 5.91965477909171e+109*cos(theta)**10 + 1.10258470637056e+108*cos(theta)**8 - 1.21880662370216e+106*cos(theta)**6 + 6.90933460148615e+103*cos(theta)**4 - 1.50475526711132e+101*cos(theta)**2 + 5.26138205283678e+97)*sin(51*phi)

#@torch.jit.script
def Yl91_m_minus_50(theta, phi):
    return 7.16449398582233e-97*(1.0 - cos(theta)**2)**25*(5.90997542536524e+116*cos(theta)**41 - 2.67744743027596e+117*cos(theta)**39 + 5.54186744646505e+117*cos(theta)**37 - 6.95081679726125e+117*cos(theta)**35 + 5.90819427767207e+117*cos(theta)**33 - 3.60638910822064e+117*cos(theta)**31 + 1.63447459583099e+117*cos(theta)**29 - 5.60943944131346e+116*cos(theta)**27 + 1.47373745800975e+116*cos(theta)**25 - 2.97724738991868e+115*cos(theta)**23 + 4.62112631686765e+114*cos(theta)**21 - 5.47959642316322e+113*cos(theta)**19 + 4.91095905849534e+112*cos(theta)**17 - 3.27236860340699e+111*cos(theta)**15 + 1.58340416293887e+110*cos(theta)**13 - 5.38150434462882e+108*cos(theta)**11 + 1.22509411818951e+107*cos(theta)**9 - 1.74115231957451e+105*cos(theta)**7 + 1.38186692029723e+103*cos(theta)**5 - 5.01585089037107e+100*cos(theta)**3 + 5.26138205283678e+97*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl91_m_minus_49(theta, phi):
    return 5.51340281912741e-95*(1.0 - cos(theta)**2)**24.5*(1.40713700603934e+115*cos(theta)**42 - 6.69361857568991e+115*cos(theta)**40 + 1.45838617012238e+116*cos(theta)**38 - 1.93078244368368e+116*cos(theta)**36 + 1.73770419931531e+116*cos(theta)**34 - 1.12699659631895e+116*cos(theta)**32 + 5.44824865276997e+115*cos(theta)**30 - 2.00337122904052e+115*cos(theta)**28 + 5.66822099234519e+114*cos(theta)**26 - 1.24051974579945e+114*cos(theta)**24 + 2.10051196221257e+113*cos(theta)**22 - 2.73979821158161e+112*cos(theta)**20 + 2.72831058805297e+111*cos(theta)**18 - 2.04523037712937e+110*cos(theta)**16 + 1.13100297352776e+109*cos(theta)**14 - 4.48458695385735e+107*cos(theta)**12 + 1.22509411818951e+106*cos(theta)**10 - 2.17644039946814e+104*cos(theta)**8 + 2.30311153382871e+102*cos(theta)**6 - 1.25396272259277e+100*cos(theta)**4 + 2.63069102641839e+97*cos(theta)**2 - 8.88446817432757e+93)*sin(49*phi)

#@torch.jit.script
def Yl91_m_minus_48(theta, phi):
    return 4.27777531070406e-93*(1.0 - cos(theta)**2)**24*(3.27241164195196e+113*cos(theta)**43 - 1.63258989650973e+114*cos(theta)**41 + 3.73945171826252e+114*cos(theta)**39 - 5.21833092887482e+114*cos(theta)**37 + 4.9648691409009e+114*cos(theta)**35 - 3.41514120096651e+114*cos(theta)**33 + 1.75749956540967e+114*cos(theta)**31 - 6.90817665186387e+113*cos(theta)**29 + 2.099341108276e+113*cos(theta)**27 - 4.96207898319781e+112*cos(theta)**25 + 9.13266070527204e+111*cos(theta)**23 - 1.30466581503886e+111*cos(theta)**21 + 1.43595294108051e+110*cos(theta)**19 - 1.20307669242904e+109*cos(theta)**17 + 7.54001982351841e+107*cos(theta)**15 - 3.44968227219796e+106*cos(theta)**13 + 1.11372192562683e+105*cos(theta)**11 - 2.41826711052015e+103*cos(theta)**9 + 3.29015933404102e+101*cos(theta)**7 - 2.50792544518553e+99*cos(theta)**5 + 8.76897008806131e+96*cos(theta)**3 - 8.88446817432757e+93*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl91_m_minus_47(theta, phi):
    return 3.34542815794696e-91*(1.0 - cos(theta)**2)**23.5*(7.43729918625445e+111*cos(theta)**44 - 3.88711880121365e+112*cos(theta)**42 + 9.3486292956563e+112*cos(theta)**40 - 1.37324498128285e+113*cos(theta)**38 + 1.37913031691692e+113*cos(theta)**36 - 1.00445329440192e+113*cos(theta)**34 + 5.49218614190521e+112*cos(theta)**32 - 2.30272555062129e+112*cos(theta)**30 + 7.49764681527141e+111*cos(theta)**28 - 1.90849191661454e+111*cos(theta)**26 + 3.80527529386335e+110*cos(theta)**24 - 5.93029915926756e+109*cos(theta)**22 + 7.17976470540254e+108*cos(theta)**20 - 6.68375940238355e+107*cos(theta)**18 + 4.712512389699e+106*cos(theta)**16 - 2.46405876585569e+105*cos(theta)**14 + 9.28101604689022e+103*cos(theta)**12 - 2.41826711052015e+102*cos(theta)**10 + 4.11269916755128e+100*cos(theta)**8 - 4.17987574197589e+98*cos(theta)**6 + 2.19224252201533e+96*cos(theta)**4 - 4.44223408716378e+93*cos(theta)**2 + 1.45265993694041e+90)*sin(47*phi)

#@torch.jit.script
def Yl91_m_minus_46(theta, phi):
    return 2.63631625886393e-89*(1.0 - cos(theta)**2)**23*(1.65273315250099e+110*cos(theta)**45 - 9.03981116561315e+110*cos(theta)**43 + 2.28015348674544e+111*cos(theta)**41 - 3.52114097764832e+111*cos(theta)**39 + 3.72737923491058e+111*cos(theta)**37 - 2.86986655543404e+111*cos(theta)**35 + 1.66429883088037e+111*cos(theta)**33 - 7.42814693748803e+110*cos(theta)**31 + 2.58539545354187e+110*cos(theta)**29 - 7.06848858005385e+109*cos(theta)**27 + 1.52211011754534e+109*cos(theta)**25 - 2.57839093881198e+108*cos(theta)**23 + 3.41893557400121e+107*cos(theta)**21 - 3.51776810651766e+106*cos(theta)**19 + 2.77206611158765e+105*cos(theta)**17 - 1.64270584390379e+104*cos(theta)**15 + 7.13924311299247e+102*cos(theta)**13 - 2.19842464592741e+101*cos(theta)**11 + 4.56966574172364e+99*cos(theta)**9 - 5.97125105996556e+97*cos(theta)**7 + 4.38448504403065e+95*cos(theta)**5 - 1.48074469572126e+93*cos(theta)**3 + 1.45265993694041e+90*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl91_m_minus_45(theta, phi):
    return 2.09284327775303e-87*(1.0 - cos(theta)**2)**22.5*(3.59289815761085e+108*cos(theta)**46 - 2.05450253763935e+109*cos(theta)**44 + 5.42893687320343e+109*cos(theta)**42 - 8.80285244412081e+109*cos(theta)**40 + 9.8088927234489e+109*cos(theta)**38 - 7.97185154287234e+109*cos(theta)**36 + 4.89499656141284e+109*cos(theta)**34 - 2.32129591796501e+109*cos(theta)**32 + 8.61798484513955e+108*cos(theta)**30 - 2.52446020716209e+108*cos(theta)**28 + 5.85426968286669e+107*cos(theta)**26 - 1.07432955783833e+107*cos(theta)**24 + 1.55406162454601e+106*cos(theta)**22 - 1.75888405325883e+105*cos(theta)**20 + 1.54003672865981e+104*cos(theta)**18 - 1.02669115243987e+103*cos(theta)**16 + 5.0994593664232e+101*cos(theta)**14 - 1.83202053827284e+100*cos(theta)**12 + 4.56966574172364e+98*cos(theta)**10 - 7.46406382495695e+96*cos(theta)**8 + 7.30747507338442e+94*cos(theta)**6 - 3.70186173930315e+92*cos(theta)**4 + 7.26329968470206e+89*cos(theta)**2 - 2.30507765303144e+86)*sin(45*phi)

#@torch.jit.script
def Yl91_m_minus_44(theta, phi):
    return 1.67322787335225e-85*(1.0 - cos(theta)**2)**22*(7.64446416512946e+106*cos(theta)**47 - 4.56556119475411e+107*cos(theta)**45 + 1.26254345888452e+108*cos(theta)**43 - 2.14703718149288e+108*cos(theta)**41 + 2.51510069832023e+108*cos(theta)**39 - 2.15455447104658e+108*cos(theta)**37 + 1.39857044611796e+108*cos(theta)**35 - 7.03423005443942e+107*cos(theta)**33 + 2.77999511133534e+107*cos(theta)**31 - 8.70503519711066e+106*cos(theta)**29 + 2.16824803069137e+106*cos(theta)**27 - 4.2973182313533e+105*cos(theta)**25 + 6.75678967193915e+104*cos(theta)**23 - 8.37563834885157e+103*cos(theta)**21 + 8.10545646663055e+102*cos(theta)**19 - 6.03935972023453e+101*cos(theta)**17 + 3.39963957761546e+100*cos(theta)**15 - 1.40924656790219e+99*cos(theta)**13 + 4.15424158338513e+97*cos(theta)**11 - 8.29340424995216e+95*cos(theta)**9 + 1.04392501048349e+94*cos(theta)**7 - 7.4037234786063e+91*cos(theta)**5 + 2.42109989490069e+89*cos(theta)**3 - 2.30507765303144e+86*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl91_m_minus_43(theta, phi):
    return 1.34692245599869e-83*(1.0 - cos(theta)**2)**21.5*(1.59259670106864e+105*cos(theta)**48 - 9.92513303207416e+105*cos(theta)**46 + 2.86941695201027e+106*cos(theta)**44 - 5.11199328926876e+106*cos(theta)**42 + 6.28775174580058e+106*cos(theta)**40 - 5.66988018696468e+106*cos(theta)**38 + 3.88491790588321e+106*cos(theta)**36 - 2.06889119248218e+106*cos(theta)**34 + 8.68748472292294e+105*cos(theta)**32 - 2.90167839903689e+105*cos(theta)**30 + 7.74374296675488e+104*cos(theta)**28 - 1.65281470436665e+104*cos(theta)**26 + 2.81532902997465e+103*cos(theta)**24 - 3.80710834038708e+102*cos(theta)**22 + 4.05272823331528e+101*cos(theta)**20 - 3.35519984457474e+100*cos(theta)**18 + 2.12477473600966e+99*cos(theta)**16 - 1.0066046913587e+98*cos(theta)**14 + 3.46186798615427e+96*cos(theta)**12 - 8.29340424995216e+94*cos(theta)**10 + 1.30490626310436e+93*cos(theta)**8 - 1.23395391310105e+91*cos(theta)**6 + 6.05274973725172e+88*cos(theta)**4 - 1.15253882651572e+86*cos(theta)**2 + 3.55721860035716e+82)*sin(43*phi)

#@torch.jit.script
def Yl91_m_minus_42(theta, phi):
    return 1.09142282699425e-81*(1.0 - cos(theta)**2)**21*(3.25019734911967e+103*cos(theta)**49 - 2.1117304323562e+104*cos(theta)**47 + 6.37648211557837e+104*cos(theta)**45 - 1.18883564866715e+105*cos(theta)**43 + 1.53359798678063e+105*cos(theta)**41 - 1.45381543255505e+105*cos(theta)**39 + 1.04997781240087e+105*cos(theta)**37 - 5.91111769280624e+104*cos(theta)**35 + 2.63257112815847e+104*cos(theta)**33 - 9.36025290011899e+103*cos(theta)**31 + 2.67025619543272e+103*cos(theta)**29 - 6.12153594209872e+102*cos(theta)**27 + 1.12613161198986e+102*cos(theta)**25 - 1.65526449582047e+101*cos(theta)**23 + 1.92987058729299e+100*cos(theta)**21 - 1.76589465503934e+99*cos(theta)**19 + 1.24986749177039e+98*cos(theta)**17 - 6.71069794239136e+96*cos(theta)**15 + 2.66297537396483e+95*cos(theta)**13 - 7.53945840904742e+93*cos(theta)**11 + 1.44989584789373e+92*cos(theta)**9 - 1.76279130443007e+90*cos(theta)**7 + 1.21054994745034e+88*cos(theta)**5 - 3.84179608838573e+85*cos(theta)**3 + 3.55721860035716e+82*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl91_m_minus_41(theta, phi):
    return 8.90028380751955e-80*(1.0 - cos(theta)**2)**20.5*(6.50039469823934e+101*cos(theta)**50 - 4.39943840074209e+102*cos(theta)**48 + 1.38619176425617e+103*cos(theta)**46 - 2.70189920151626e+103*cos(theta)**44 + 3.65142377804912e+103*cos(theta)**42 - 3.63453858138762e+103*cos(theta)**40 + 2.76309950631807e+103*cos(theta)**38 - 1.64197713689062e+103*cos(theta)**36 + 7.7428562592896e+102*cos(theta)**34 - 2.92507903128718e+102*cos(theta)**32 + 8.90085398477572e+101*cos(theta)**30 - 2.18626283646383e+101*cos(theta)**28 + 4.33127543073023e+100*cos(theta)**26 - 6.89693539925195e+99*cos(theta)**24 + 8.77213903314995e+98*cos(theta)**22 - 8.82947327519668e+97*cos(theta)**20 + 6.94370828761328e+96*cos(theta)**18 - 4.1941862139946e+95*cos(theta)**16 + 1.90212526711773e+94*cos(theta)**14 - 6.28288200753952e+92*cos(theta)**12 + 1.44989584789373e+91*cos(theta)**10 - 2.20348913053759e+89*cos(theta)**8 + 2.01758324575057e+87*cos(theta)**6 - 9.60449022096433e+84*cos(theta)**4 + 1.77860930017858e+82*cos(theta)**2 - 5.34920090279272e+78)*sin(41*phi)

#@torch.jit.script
def Yl91_m_minus_40(theta, phi):
    return 7.30257303341627e-78*(1.0 - cos(theta)**2)**20*(1.2745871957332e+100*cos(theta)**51 - 8.97844571580019e+100*cos(theta)**49 + 2.94934417926844e+101*cos(theta)**47 - 6.00422044781391e+101*cos(theta)**45 + 8.49168320476539e+101*cos(theta)**43 - 8.86472824728687e+101*cos(theta)**41 + 7.0848705290207e+101*cos(theta)**39 - 4.43777604565033e+101*cos(theta)**37 + 2.21224464551132e+101*cos(theta)**35 - 8.86387585238541e+100*cos(theta)**33 + 2.8712432208954e+100*cos(theta)**31 - 7.53883736711665e+99*cos(theta)**29 + 1.60417608545564e+99*cos(theta)**27 - 2.75877415970078e+98*cos(theta)**25 + 3.81397349267389e+97*cos(theta)**23 - 4.20451108342699e+96*cos(theta)**21 + 3.65458330927015e+95*cos(theta)**19 - 2.46716836117329e+94*cos(theta)**17 + 1.26808351141182e+93*cos(theta)**15 - 4.83298615964578e+91*cos(theta)**13 + 1.31808713444885e+90*cos(theta)**11 - 2.44832125615288e+88*cos(theta)**9 + 2.88226177964368e+86*cos(theta)**7 - 1.92089804419287e+84*cos(theta)**5 + 5.92869766726193e+81*cos(theta)**3 - 5.34920090279272e+78*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl91_m_minus_39(theta, phi):
    return 6.02716705137558e-76*(1.0 - cos(theta)**2)**19.5*(2.45112922256385e+98*cos(theta)**52 - 1.79568914316004e+99*cos(theta)**50 + 6.14446704014259e+99*cos(theta)**48 - 1.30526531474215e+100*cos(theta)**46 + 1.92992800108304e+100*cos(theta)**44 - 2.11064958268735e+100*cos(theta)**42 + 1.77121763225517e+100*cos(theta)**40 - 1.16783580148693e+100*cos(theta)**38 + 6.14512401530921e+99*cos(theta)**36 - 2.60702230952512e+99*cos(theta)**34 + 8.97263506529811e+98*cos(theta)**32 - 2.51294578903888e+98*cos(theta)**30 + 5.72920030519871e+97*cos(theta)**28 - 1.0610669845003e+97*cos(theta)**26 + 1.58915562194745e+96*cos(theta)**24 - 1.91114140155772e+95*cos(theta)**22 + 1.82729165463507e+94*cos(theta)**20 - 1.37064908954072e+93*cos(theta)**18 + 7.92552194632389e+91*cos(theta)**16 - 3.45213297117556e+90*cos(theta)**14 + 1.09840594537404e+89*cos(theta)**12 - 2.44832125615288e+87*cos(theta)**10 + 3.6028272245546e+85*cos(theta)**8 - 3.20149674032144e+83*cos(theta)**6 + 1.48217441681548e+81*cos(theta)**4 - 2.67460045139636e+78*cos(theta)**2 + 7.85261436111674e+74)*sin(39*phi)

#@torch.jit.script
def Yl91_m_minus_38(theta, phi):
    return 5.00291172181902e-74*(1.0 - cos(theta)**2)**19*(4.624772118045e+96*cos(theta)**53 - 3.52095910423537e+97*cos(theta)**51 + 1.25397286533522e+98*cos(theta)**49 - 2.77716024413224e+98*cos(theta)**47 + 4.28872889129565e+98*cos(theta)**45 - 4.90848740159849e+98*cos(theta)**43 + 4.32004300550042e+98*cos(theta)**41 - 2.99445077304341e+98*cos(theta)**39 + 1.66084432846195e+98*cos(theta)**37 - 7.44863517007177e+97*cos(theta)**35 + 2.71898032281761e+97*cos(theta)**33 - 8.10627673883511e+96*cos(theta)**31 + 1.97558631213749e+96*cos(theta)**29 - 3.92987772037148e+95*cos(theta)**27 + 6.35662248778982e+94*cos(theta)**25 - 8.30931044155532e+93*cos(theta)**23 + 8.70138883159559e+92*cos(theta)**21 - 7.2139425765301e+91*cos(theta)**19 + 4.6620717331317e+90*cos(theta)**17 - 2.30142198078371e+89*cos(theta)**15 + 8.44927650287724e+87*cos(theta)**13 - 2.22574659650262e+86*cos(theta)**11 + 4.00314136061622e+84*cos(theta)**9 - 4.57356677188778e+82*cos(theta)**7 + 2.96434883363097e+80*cos(theta)**5 - 8.91533483798787e+77*cos(theta)**3 + 7.85261436111674e+74*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl91_m_minus_37(theta, phi):
    return 4.17555852073138e-72*(1.0 - cos(theta)**2)**18.5*(8.56439281119445e+94*cos(theta)**54 - 6.77107520045263e+95*cos(theta)**52 + 2.50794573067044e+96*cos(theta)**50 - 5.78575050860884e+96*cos(theta)**48 + 9.32332367672967e+96*cos(theta)**46 - 1.11556531854511e+97*cos(theta)**44 + 1.02858166797629e+97*cos(theta)**42 - 7.48612693260851e+96*cos(theta)**40 + 4.37064296963671e+96*cos(theta)**38 - 2.06906532501994e+96*cos(theta)**36 + 7.99700094946356e+95*cos(theta)**34 - 2.53321148088597e+95*cos(theta)**32 + 6.58528770712496e+94*cos(theta)**30 - 1.40352775727553e+94*cos(theta)**28 + 2.44485480299608e+93*cos(theta)**26 - 3.46221268398138e+92*cos(theta)**24 + 3.95517674163436e+91*cos(theta)**22 - 3.60697128826505e+90*cos(theta)**20 + 2.59003985173983e+89*cos(theta)**18 - 1.43838873798982e+88*cos(theta)**16 + 6.03519750205517e+86*cos(theta)**14 - 1.85478883041885e+85*cos(theta)**12 + 4.00314136061622e+83*cos(theta)**10 - 5.71695846485972e+81*cos(theta)**8 + 4.94058138938494e+79*cos(theta)**6 - 2.22883370949697e+77*cos(theta)**4 + 3.92630718055837e+74*cos(theta)**2 - 1.12727739895446e+71)*sin(37*phi)

#@torch.jit.script
def Yl91_m_minus_36(theta, phi):
    return 3.50349017807627e-70*(1.0 - cos(theta)**2)**18*(1.55716232930808e+93*cos(theta)**55 - 1.27756135857597e+94*cos(theta)**53 + 4.91754064837342e+94*cos(theta)**51 - 1.18076540992017e+95*cos(theta)**49 + 1.98368588866589e+95*cos(theta)**47 - 2.47903404121136e+95*cos(theta)**45 + 2.39205039064254e+95*cos(theta)**43 - 1.82588461770939e+95*cos(theta)**41 + 1.12067768452223e+95*cos(theta)**39 - 5.59206844599983e+94*cos(theta)**37 + 2.28485741413244e+94*cos(theta)**35 - 7.67639842692719e+93*cos(theta)**33 + 2.12428635713708e+93*cos(theta)**31 - 4.839750887157e+92*cos(theta)**29 + 9.05501778887438e+91*cos(theta)**27 - 1.38488507359255e+91*cos(theta)**25 + 1.71964206158016e+90*cos(theta)**23 - 1.71760537536431e+89*cos(theta)**21 + 1.36317886933675e+88*cos(theta)**19 - 8.46111022346951e+86*cos(theta)**17 + 4.02346500137011e+85*cos(theta)**15 - 1.42676063878373e+84*cos(theta)**13 + 3.63921941874202e+82*cos(theta)**11 - 6.35217607206636e+80*cos(theta)**9 + 7.05797341340706e+78*cos(theta)**7 - 4.45766741899393e+76*cos(theta)**5 + 1.30876906018612e+74*cos(theta)**3 - 1.12727739895446e+71*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl91_m_minus_35(theta, phi):
    return 2.95458697044207e-68*(1.0 - cos(theta)**2)**17.5*(2.78064701662158e+91*cos(theta)**56 - 2.36585436773327e+92*cos(theta)**54 + 9.45680893917965e+92*cos(theta)**52 - 2.36153081984034e+93*cos(theta)**50 + 4.1326789347206e+93*cos(theta)**48 - 5.389204437416e+93*cos(theta)**46 + 5.43647816055122e+93*cos(theta)**44 - 4.34734432787951e+93*cos(theta)**42 + 2.80169421130558e+93*cos(theta)**40 - 1.47159695947364e+93*cos(theta)**38 + 6.3468261503679e+92*cos(theta)**36 - 2.25776424321388e+92*cos(theta)**34 + 6.63839486605338e+91*cos(theta)**32 - 1.613250295719e+91*cos(theta)**30 + 3.23393492459799e+90*cos(theta)**28 - 5.32648105227905e+89*cos(theta)**26 + 7.16517525658399e+88*cos(theta)**24 - 7.80729716074686e+87*cos(theta)**22 + 6.81589434668377e+86*cos(theta)**20 - 4.70061679081639e+85*cos(theta)**18 + 2.51466562585632e+84*cos(theta)**16 - 1.01911474198838e+83*cos(theta)**14 + 3.03268284895168e+81*cos(theta)**12 - 6.35217607206636e+79*cos(theta)**10 + 8.82246676675883e+77*cos(theta)**8 - 7.42944569832322e+75*cos(theta)**6 + 3.27192265046531e+73*cos(theta)**4 - 5.63638699477228e+70*cos(theta)**2 + 1.5850357128156e+67)*sin(35*phi)

#@torch.jit.script
def Yl91_m_minus_34(theta, phi):
    return 2.50391440507732e-66*(1.0 - cos(theta)**2)**17*(4.8783280993361e+89*cos(theta)**57 - 4.30155339587868e+90*cos(theta)**55 + 1.78430357343012e+91*cos(theta)**53 - 4.63045258792224e+91*cos(theta)**51 + 8.43403864228694e+91*cos(theta)**49 - 1.1466392420034e+92*cos(theta)**47 + 1.20810625790027e+92*cos(theta)**45 - 1.01101030880919e+92*cos(theta)**43 + 6.83340051537947e+91*cos(theta)**41 - 3.77332553711189e+91*cos(theta)**39 + 1.71535841901835e+91*cos(theta)**37 - 6.45075498061108e+90*cos(theta)**35 + 2.01163480789496e+90*cos(theta)**33 - 5.20403321199677e+89*cos(theta)**31 + 1.11514997399931e+89*cos(theta)**29 - 1.97277076010335e+88*cos(theta)**27 + 2.86607010263359e+87*cos(theta)**25 - 3.39447702641168e+86*cos(theta)**23 + 3.24566397461132e+85*cos(theta)**21 - 2.47400883727179e+84*cos(theta)**19 + 1.47921507403313e+83*cos(theta)**17 - 6.79409827992252e+81*cos(theta)**15 + 2.33283296073206e+80*cos(theta)**13 - 5.77470552006032e+78*cos(theta)**11 + 9.80274085195425e+76*cos(theta)**9 - 1.06134938547475e+75*cos(theta)**7 + 6.54384530093061e+72*cos(theta)**5 - 1.87879566492409e+70*cos(theta)**3 + 1.5850357128156e+67*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl91_m_minus_33(theta, phi):
    return 2.13200629156353e-64*(1.0 - cos(theta)**2)**16.5*(8.41091051609672e+87*cos(theta)**58 - 7.68134534978336e+88*cos(theta)**56 + 3.30426587672245e+89*cos(theta)**54 - 8.90471651523508e+89*cos(theta)**52 + 1.68680772845739e+90*cos(theta)**50 - 2.38883175417376e+90*cos(theta)**48 + 2.62631795195711e+90*cos(theta)**46 - 2.29775070183906e+90*cos(theta)**44 + 1.6270001227094e+90*cos(theta)**42 - 9.43331384277973e+89*cos(theta)**40 + 4.51410110267987e+89*cos(theta)**38 - 1.79187638350308e+89*cos(theta)**36 + 5.91657296439695e+88*cos(theta)**34 - 1.62626037874899e+88*cos(theta)**32 + 3.7171665799977e+87*cos(theta)**30 - 7.04560985751197e+86*cos(theta)**28 + 1.10233465485907e+86*cos(theta)**26 - 1.41436542767153e+85*cos(theta)**24 + 1.47530180664151e+84*cos(theta)**22 - 1.23700441863589e+83*cos(theta)**20 + 8.21786152240628e+81*cos(theta)**18 - 4.24631142495157e+80*cos(theta)**16 + 1.66630925766576e+79*cos(theta)**14 - 4.81225460005027e+77*cos(theta)**12 + 9.80274085195425e+75*cos(theta)**10 - 1.32668673184343e+74*cos(theta)**8 + 1.09064088348844e+72*cos(theta)**6 - 4.69698916231023e+69*cos(theta)**4 + 7.925178564078e+66*cos(theta)**2 - 2.18625615560773e+63)*sin(33*phi)

#@torch.jit.script
def Yl91_m_minus_32(theta, phi):
    return 1.82358214106964e-62*(1.0 - cos(theta)**2)**16*(1.42557805357572e+86*cos(theta)**59 - 1.34760444733041e+87*cos(theta)**57 + 6.00775613949536e+87*cos(theta)**55 - 1.68013519155379e+88*cos(theta)**53 + 3.30746613423017e+88*cos(theta)**51 - 4.87516684525257e+88*cos(theta)**49 + 5.58791053607896e+88*cos(theta)**47 - 5.10611267075347e+88*cos(theta)**45 + 3.78372121560325e+88*cos(theta)**43 - 2.30080825433652e+88*cos(theta)**41 + 1.15746182119997e+88*cos(theta)**39 - 4.84290914460291e+87*cos(theta)**37 + 1.69044941839913e+87*cos(theta)**35 - 4.92806175378482e+86*cos(theta)**33 + 1.19908599354764e+86*cos(theta)**31 - 2.42952064052137e+85*cos(theta)**29 + 4.0827209439225e+84*cos(theta)**27 - 5.65746171068613e+83*cos(theta)**25 + 6.41435568105004e+82*cos(theta)**23 - 5.89049723159949e+81*cos(theta)**21 + 4.32519027495067e+80*cos(theta)**19 - 2.49783024997151e+79*cos(theta)**17 + 1.11087283844384e+78*cos(theta)**15 - 3.70173430773098e+76*cos(theta)**13 + 8.91158259268568e+74*cos(theta)**11 - 1.47409636871493e+73*cos(theta)**9 + 1.55805840498348e+71*cos(theta)**7 - 9.39397832462046e+68*cos(theta)**5 + 2.641726188026e+66*cos(theta)**3 - 2.18625615560773e+63*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl91_m_minus_31(theta, phi):
    return 1.56658336740129e-60*(1.0 - cos(theta)**2)**15.5*(2.37596342262619e+84*cos(theta)**60 - 2.32345594367313e+85*cos(theta)**58 + 1.07281359633846e+86*cos(theta)**56 - 3.11136146584035e+86*cos(theta)**54 + 6.36051179659648e+86*cos(theta)**52 - 9.75033369050513e+86*cos(theta)**50 + 1.16414802834978e+87*cos(theta)**48 - 1.11002449364206e+87*cos(theta)**46 + 8.59936639909829e+86*cos(theta)**44 - 5.47811489127743e+86*cos(theta)**42 + 2.89365455299992e+86*cos(theta)**40 - 1.2744497748955e+86*cos(theta)**38 + 4.69569282888647e+85*cos(theta)**36 - 1.44942992758377e+85*cos(theta)**34 + 3.74714372983639e+84*cos(theta)**32 - 8.09840213507123e+83*cos(theta)**30 + 1.45811462282946e+83*cos(theta)**28 - 2.17594681180236e+82*cos(theta)**26 + 2.67264820043752e+81*cos(theta)**24 - 2.67749874163613e+80*cos(theta)**22 + 2.16259513747534e+79*cos(theta)**20 - 1.3876834722064e+78*cos(theta)**18 + 6.94295524027399e+76*cos(theta)**16 - 2.64409593409355e+75*cos(theta)**14 + 7.42631882723807e+73*cos(theta)**12 - 1.47409636871493e+72*cos(theta)**10 + 1.94757300622935e+70*cos(theta)**8 - 1.56566305410341e+68*cos(theta)**6 + 6.604315470065e+65*cos(theta)**4 - 1.09312807780386e+63*cos(theta)**2 + 2.96240671491562e+59)*sin(31*phi)

#@torch.jit.script
def Yl91_m_minus_30(theta, phi):
    return 1.35144490130788e-58*(1.0 - cos(theta)**2)**15*(3.89502200430523e+82*cos(theta)**61 - 3.93806092147988e+83*cos(theta)**59 + 1.88212911638326e+84*cos(theta)**57 - 5.65702084698245e+84*cos(theta)**55 + 1.20009656539556e+85*cos(theta)**53 - 1.91183013539316e+85*cos(theta)**51 + 2.37581230275466e+85*cos(theta)**49 - 2.36175424179162e+85*cos(theta)**47 + 1.91097031091073e+85*cos(theta)**45 - 1.27398020727382e+85*cos(theta)**43 + 7.05769403170712e+84*cos(theta)**41 - 3.2678199356295e+84*cos(theta)**39 + 1.26910616996932e+84*cos(theta)**37 - 4.14122836452506e+83*cos(theta)**35 + 1.13549809995042e+83*cos(theta)**33 - 2.61238778550685e+82*cos(theta)**31 + 5.02798145803264e+81*cos(theta)**29 - 8.05906226593466e+80*cos(theta)**27 + 1.06905928017501e+80*cos(theta)**25 - 1.16412988766788e+79*cos(theta)**23 + 1.02980720832159e+78*cos(theta)**21 - 7.30359722213893e+76*cos(theta)**19 + 4.08409131780823e+75*cos(theta)**17 - 1.76273062272904e+74*cos(theta)**15 + 5.71255294402928e+72*cos(theta)**13 - 1.34008760792266e+71*cos(theta)**11 + 2.1639700069215e+69*cos(theta)**9 - 2.23666150586201e+67*cos(theta)**7 + 1.320863094013e+65*cos(theta)**5 - 3.64376025934621e+62*cos(theta)**3 + 2.96240671491562e+59*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl91_m_minus_29(theta, phi):
    return 1.17054165736105e-56*(1.0 - cos(theta)**2)**14.5*(6.28229355533102e+80*cos(theta)**62 - 6.56343486913313e+81*cos(theta)**60 + 3.24505020066079e+82*cos(theta)**58 - 1.01018229410401e+83*cos(theta)**56 + 2.22240104702882e+83*cos(theta)**54 - 3.67659641421762e+83*cos(theta)**52 + 4.75162460550932e+83*cos(theta)**50 - 4.92032133706587e+83*cos(theta)**48 + 4.15428328458855e+83*cos(theta)**46 - 2.89540956198596e+83*cos(theta)**44 + 1.68040334088265e+83*cos(theta)**42 - 8.16954983907374e+82*cos(theta)**40 + 3.33975307886662e+82*cos(theta)**38 - 1.15034121236807e+82*cos(theta)**36 + 3.33970029397182e+81*cos(theta)**34 - 8.1637118297089e+80*cos(theta)**32 + 1.67599381934421e+80*cos(theta)**30 - 2.87823652354809e+79*cos(theta)**28 + 4.11176646221156e+78*cos(theta)**26 - 4.85054119861618e+77*cos(theta)**24 + 4.68094185600722e+76*cos(theta)**22 - 3.65179861106946e+75*cos(theta)**20 + 2.26893962100457e+74*cos(theta)**18 - 1.10170663920565e+73*cos(theta)**16 + 4.08039496002092e+71*cos(theta)**14 - 1.11673967326888e+70*cos(theta)**12 + 2.1639700069215e+68*cos(theta)**10 - 2.79582688232752e+66*cos(theta)**8 + 2.20143849002167e+64*cos(theta)**6 - 9.10940064836552e+61*cos(theta)**4 + 1.48120335745781e+59*cos(theta)**2 - 3.94882260052735e+55)*sin(29*phi)

#@torch.jit.script
def Yl91_m_minus_28(theta, phi):
    return 1.01776560923568e-54*(1.0 - cos(theta)**2)**14*(9.97189453227146e+78*cos(theta)**63 - 1.07597292936609e+80*cos(theta)**61 + 5.50008508586575e+80*cos(theta)**59 - 1.77224963877896e+81*cos(theta)**57 + 4.04072917641604e+81*cos(theta)**55 - 6.93697436644834e+81*cos(theta)**53 + 9.31691099119475e+81*cos(theta)**51 - 1.0041472116461e+82*cos(theta)**49 + 8.83890060550755e+81*cos(theta)**47 - 6.4342434710799e+81*cos(theta)**45 + 3.90791474623871e+81*cos(theta)**43 - 1.9925731314814e+81*cos(theta)**41 + 8.56346943299134e+80*cos(theta)**39 - 3.10903030369749e+80*cos(theta)**37 + 9.5420008399195e+79*cos(theta)**35 - 2.47385206960876e+79*cos(theta)**33 + 5.40643167530391e+78*cos(theta)**31 - 9.92495352947618e+77*cos(theta)**29 + 1.52287646748576e+77*cos(theta)**27 - 1.94021647944647e+76*cos(theta)**25 + 2.03519211130749e+75*cos(theta)**23 - 1.73895171955689e+74*cos(theta)**21 + 1.19417874789714e+73*cos(theta)**19 - 6.48062728944499e+71*cos(theta)**17 + 2.72026330668061e+70*cos(theta)**15 - 8.59030517899141e+68*cos(theta)**13 + 1.96724546083773e+67*cos(theta)**11 - 3.10647431369724e+65*cos(theta)**9 + 3.14491212860238e+63*cos(theta)**7 - 1.8218801296731e+61*cos(theta)**5 + 4.93734452485936e+58*cos(theta)**3 - 3.94882260052735e+55*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl91_m_minus_27(theta, phi):
    return 8.88200962506307e-53*(1.0 - cos(theta)**2)**13.5*(1.55810852066742e+77*cos(theta)**64 - 1.73544020865498e+78*cos(theta)**62 + 9.16680847644292e+78*cos(theta)**60 - 3.05560282548097e+79*cos(theta)**58 + 7.21558781502864e+79*cos(theta)**56 - 1.28462488267562e+80*cos(theta)**54 + 1.79171365215284e+80*cos(theta)**52 - 2.00829442329219e+80*cos(theta)**50 + 1.84143762614741e+80*cos(theta)**48 - 1.39874858066954e+80*cos(theta)**46 + 8.88162442326981e+79*cos(theta)**44 - 4.74422174162238e+79*cos(theta)**42 + 2.14086735824784e+79*cos(theta)**40 - 8.18165869394077e+78*cos(theta)**38 + 2.65055578886653e+78*cos(theta)**36 - 7.27603549884929e+77*cos(theta)**34 + 1.68950989853247e+77*cos(theta)**32 - 3.30831784315873e+76*cos(theta)**30 + 5.43884452673487e+75*cos(theta)**28 - 7.46237107479412e+74*cos(theta)**26 + 8.47996713044787e+73*cos(theta)**24 - 7.90432599798585e+72*cos(theta)**22 + 5.97089373948572e+71*cos(theta)**20 - 3.6003484941361e+70*cos(theta)**18 + 1.70016456667538e+69*cos(theta)**16 - 6.13593227070815e+67*cos(theta)**14 + 1.63937121736477e+66*cos(theta)**12 - 3.10647431369724e+64*cos(theta)**10 + 3.93114016075298e+62*cos(theta)**8 - 3.03646688278851e+60*cos(theta)**6 + 1.23433613121484e+58*cos(theta)**4 - 1.97441130026367e+55*cos(theta)**2 + 5.184903624642e+51)*sin(27*phi)

#@torch.jit.script
def Yl91_m_minus_26(theta, phi):
    return 7.77873401328519e-51*(1.0 - cos(theta)**2)**13*(2.39709003179602e+75*cos(theta)**65 - 2.75466699786504e+76*cos(theta)**63 + 1.50275548794146e+77*cos(theta)**61 - 5.17898783979826e+77*cos(theta)**59 + 1.26589259912783e+78*cos(theta)**57 - 2.33568160486476e+78*cos(theta)**55 + 3.38059179651479e+78*cos(theta)**53 - 3.93783220253371e+78*cos(theta)**51 + 3.7580359717294e+78*cos(theta)**49 - 2.9760608099352e+78*cos(theta)**47 + 1.97369431628218e+78*cos(theta)**45 - 1.10330738177265e+78*cos(theta)**43 + 5.2216277030435e+77*cos(theta)**41 - 2.09786120357456e+77*cos(theta)**39 + 7.16366429423386e+76*cos(theta)**37 - 2.07886728538551e+76*cos(theta)**35 + 5.11972696524991e+75*cos(theta)**33 - 1.06719930424475e+75*cos(theta)**31 + 1.87546362990858e+74*cos(theta)**29 - 2.76384113881264e+73*cos(theta)**27 + 3.39198685217915e+72*cos(theta)**25 - 3.43666347738515e+71*cos(theta)**23 + 2.84328273308844e+70*cos(theta)**21 - 1.89492026007163e+69*cos(theta)**19 + 1.0000968039267e+68*cos(theta)**17 - 4.09062151380543e+66*cos(theta)**15 + 1.26105478258829e+65*cos(theta)**13 - 2.82406755790658e+63*cos(theta)**11 + 4.36793351194775e+61*cos(theta)**9 - 4.33780983255501e+59*cos(theta)**7 + 2.46867226242968e+57*cos(theta)**5 - 6.58137100087892e+54*cos(theta)**3 + 5.184903624642e+51*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl91_m_minus_25(theta, phi):
    return 6.83555559851118e-49*(1.0 - cos(theta)**2)**12.5*(3.63195459363034e+73*cos(theta)**66 - 4.30416718416413e+74*cos(theta)**64 + 2.42379917409913e+75*cos(theta)**62 - 8.63164639966376e+75*cos(theta)**60 + 2.18257344677212e+76*cos(theta)**58 - 4.17086000868707e+76*cos(theta)**56 + 6.26035517873109e+76*cos(theta)**54 - 7.57275423564174e+76*cos(theta)**52 + 7.5160719434588e+76*cos(theta)**50 - 6.200126687365e+76*cos(theta)**48 + 4.29063981800474e+76*cos(theta)**46 - 2.50751677675602e+76*cos(theta)**44 + 1.24324469120083e+76*cos(theta)**42 - 5.24465300893639e+75*cos(theta)**40 + 1.88517481427207e+75*cos(theta)**38 - 5.77463134829309e+74*cos(theta)**36 + 1.50580204860292e+74*cos(theta)**34 - 3.33499782576485e+73*cos(theta)**32 + 6.25154543302859e+72*cos(theta)**30 - 9.87086121004514e+71*cos(theta)**28 + 1.30461032776121e+71*cos(theta)**26 - 1.43194311557715e+70*cos(theta)**24 + 1.29240124231293e+69*cos(theta)**22 - 9.47460130035817e+67*cos(theta)**20 + 5.55609335514831e+66*cos(theta)**18 - 2.55663844612839e+65*cos(theta)**16 + 9.0075341613449e+63*cos(theta)**14 - 2.35338963158882e+62*cos(theta)**12 + 4.36793351194775e+60*cos(theta)**10 - 5.42226229069376e+58*cos(theta)**8 + 4.11445377071614e+56*cos(theta)**6 - 1.64534275021973e+54*cos(theta)**4 + 2.592451812321e+51*cos(theta)**2 - 6.7144569083683e+47)*sin(25*phi)

#@torch.jit.script
def Yl91_m_minus_24(theta, phi):
    return 6.02615386200106e-47*(1.0 - cos(theta)**2)**12*(5.42082775168708e+71*cos(theta)**67 - 6.62179566794482e+72*cos(theta)**65 + 3.84730027634783e+73*cos(theta)**63 - 1.41502399994488e+74*cos(theta)**61 + 3.69927702842733e+74*cos(theta)**59 - 7.31729826085452e+74*cos(theta)**57 + 1.13824639613292e+75*cos(theta)**55 - 1.42882155389467e+75*cos(theta)**53 + 1.47373959675663e+75*cos(theta)**51 - 1.26533197701327e+75*cos(theta)**49 + 9.12902088937178e+74*cos(theta)**47 - 5.57225950390226e+74*cos(theta)**45 + 2.89126672372287e+74*cos(theta)**43 - 1.27918366071619e+74*cos(theta)**41 + 4.83378157505658e+73*cos(theta)**39 - 1.56071117521435e+73*cos(theta)**37 + 4.3022915674369e+72*cos(theta)**35 - 1.01060540174692e+72*cos(theta)**33 + 2.01662755904148e+71*cos(theta)**31 - 3.40374524484315e+70*cos(theta)**29 + 4.8318901028193e+69*cos(theta)**27 - 5.72777246230859e+68*cos(theta)**25 + 5.61913583614316e+67*cos(theta)**23 - 4.51171490493246e+66*cos(theta)**21 + 2.92425966060437e+65*cos(theta)**19 - 1.50390496831082e+64*cos(theta)**17 + 6.00502277422993e+62*cos(theta)**15 - 1.81029971660678e+61*cos(theta)**13 + 3.97084864722523e+59*cos(theta)**11 - 6.02473587854863e+57*cos(theta)**9 + 5.87779110102305e+55*cos(theta)**7 - 3.29068550043946e+53*cos(theta)**5 + 8.64150604107e+50*cos(theta)**3 - 6.7144569083683e+47*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl91_m_minus_23(theta, phi):
    return 5.32897389261526e-45*(1.0 - cos(theta)**2)**11.5*(7.97180551718688e+69*cos(theta)**68 - 1.00330237393103e+71*cos(theta)**66 + 6.01140668179348e+71*cos(theta)**64 - 2.28229677410464e+72*cos(theta)**62 + 6.16546171404555e+72*cos(theta)**60 - 1.26160314842319e+73*cos(theta)**58 + 2.03258285023737e+73*cos(theta)**56 - 2.64596584054568e+73*cos(theta)**54 + 2.83411460914736e+73*cos(theta)**52 - 2.53066395402653e+73*cos(theta)**50 + 1.90187935195245e+73*cos(theta)**48 - 1.21136076171788e+73*cos(theta)**46 + 6.57106073573379e+72*cos(theta)**44 - 3.0456753826576e+72*cos(theta)**42 + 1.20844539376415e+72*cos(theta)**40 - 4.1071346716167e+71*cos(theta)**38 + 1.1950809909547e+71*cos(theta)**36 - 2.97236882866742e+70*cos(theta)**34 + 6.30196112200462e+69*cos(theta)**32 - 1.13458174828105e+69*cos(theta)**30 + 1.72567503672118e+68*cos(theta)**28 - 2.20298940858023e+67*cos(theta)**26 + 2.34130659839298e+66*cos(theta)**24 - 2.05077950224203e+65*cos(theta)**22 + 1.46212983030219e+64*cos(theta)**20 - 8.35502760172678e+62*cos(theta)**18 + 3.75313923389371e+61*cos(theta)**16 - 1.2930712261477e+60*cos(theta)**14 + 3.30904053935436e+58*cos(theta)**12 - 6.02473587854863e+56*cos(theta)**10 + 7.34723887627881e+54*cos(theta)**8 - 5.48447583406576e+52*cos(theta)**6 + 2.1603765102675e+50*cos(theta)**4 - 3.35722845418415e+47*cos(theta)**2 + 8.58626203116151e+43)*sin(23*phi)

#@torch.jit.script
def Yl91_m_minus_22(theta, phi):
    return 4.72629215111746e-43*(1.0 - cos(theta)**2)**11*(1.15533413292563e+68*cos(theta)**69 - 1.49746622974781e+69*cos(theta)**67 + 9.24831797198997e+69*cos(theta)**65 - 3.62269329222959e+70*cos(theta)**63 + 1.01073142853206e+71*cos(theta)**61 - 2.13831042105626e+71*cos(theta)**59 + 3.56593482497783e+71*cos(theta)**57 - 4.81084698281033e+71*cos(theta)**55 + 5.34738605499502e+71*cos(theta)**53 - 4.96208618436575e+71*cos(theta)**51 + 3.88138643255603e+71*cos(theta)**49 - 2.577363322804e+71*cos(theta)**47 + 1.46023571905195e+71*cos(theta)**45 - 7.08296600618047e+70*cos(theta)**43 + 2.94742778966865e+70*cos(theta)**41 - 1.05311145426069e+70*cos(theta)**39 + 3.22994862420188e+69*cos(theta)**37 - 8.4924823676212e+68*cos(theta)**35 + 1.90968518848625e+68*cos(theta)**33 - 3.65994112348726e+67*cos(theta)**31 + 5.95060357490061e+66*cos(theta)**29 - 8.15922003177862e+65*cos(theta)**27 + 9.36522639357193e+64*cos(theta)**25 - 8.9164326184436e+63*cos(theta)**23 + 6.96252300143898e+62*cos(theta)**21 - 4.39738294827725e+61*cos(theta)**19 + 2.20772896111395e+60*cos(theta)**17 - 8.62047484098469e+58*cos(theta)**15 + 2.54541579950335e+57*cos(theta)**13 - 5.47703261686239e+55*cos(theta)**11 + 8.1635987514209e+53*cos(theta)**9 - 7.8349654772368e+51*cos(theta)**7 + 4.320753020535e+49*cos(theta)**5 - 1.11907615139472e+47*cos(theta)**3 + 8.58626203116151e+43*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl91_m_minus_21(theta, phi):
    return 4.20347825743065e-41*(1.0 - cos(theta)**2)**10.5*(1.65047733275091e+66*cos(theta)**70 - 2.20215622021737e+67*cos(theta)**68 + 1.40126029878636e+68*cos(theta)**66 - 5.66045826910874e+68*cos(theta)**64 + 1.63021198150332e+69*cos(theta)**62 - 3.56385070176043e+69*cos(theta)**60 + 6.14816349134109e+69*cos(theta)**58 - 8.59079818358988e+69*cos(theta)**56 + 9.90256676850929e+69*cos(theta)**54 - 9.54247343147259e+69*cos(theta)**52 + 7.76277286511206e+69*cos(theta)**50 - 5.36950692250834e+69*cos(theta)**48 + 3.1744254761999e+69*cos(theta)**46 - 1.60976500140465e+69*cos(theta)**44 + 7.01768521349678e+68*cos(theta)**42 - 2.63277863565173e+68*cos(theta)**40 + 8.49986480053126e+67*cos(theta)**38 - 2.35902287989478e+67*cos(theta)**36 + 5.61672114260662e+66*cos(theta)**34 - 1.14373160108977e+66*cos(theta)**32 + 1.98353452496687e+65*cos(theta)**30 - 2.91400715420665e+64*cos(theta)**28 + 3.60201015137382e+63*cos(theta)**26 - 3.71518025768483e+62*cos(theta)**24 + 3.16478318247226e+61*cos(theta)**22 - 2.19869147413863e+60*cos(theta)**20 + 1.22651608950775e+59*cos(theta)**18 - 5.38779677561543e+57*cos(theta)**16 + 1.81815414250239e+56*cos(theta)**14 - 4.56419384738532e+54*cos(theta)**12 + 8.1635987514209e+52*cos(theta)**10 - 9.793706846546e+50*cos(theta)**8 + 7.201255034225e+48*cos(theta)**6 - 2.79769037848679e+46*cos(theta)**4 + 4.29313101558076e+43*cos(theta)**2 - 1.08549456778274e+40)*sin(21*phi)

#@torch.jit.script
def Yl91_m_minus_20(theta, phi):
    return 3.74840916485146e-39*(1.0 - cos(theta)**2)**10*(2.32461596162099e+64*cos(theta)**71 - 3.19153075393822e+65*cos(theta)**69 + 2.09143328177069e+66*cos(theta)**67 - 8.70839733709037e+66*cos(theta)**65 + 2.58763806587828e+67*cos(theta)**63 - 5.84237819960726e+67*cos(theta)**61 + 1.04206160870188e+68*cos(theta)**59 - 1.5071575760684e+68*cos(theta)**57 + 1.80046668518351e+68*cos(theta)**55 - 1.80046668518351e+68*cos(theta)**53 + 1.52211232649256e+68*cos(theta)**51 - 1.09581773928742e+68*cos(theta)**49 + 6.75409675787213e+67*cos(theta)**47 - 3.57725555867701e+67*cos(theta)**45 + 1.63201981709227e+67*cos(theta)**43 - 6.42141130646764e+66*cos(theta)**41 + 2.17945251295673e+66*cos(theta)**39 - 6.37573751322913e+65*cos(theta)**37 + 1.60477746931618e+65*cos(theta)**35 - 3.46585333663566e+64*cos(theta)**33 + 6.39849846763507e+63*cos(theta)**31 - 1.00483005317471e+63*cos(theta)**29 + 1.33407783384215e+62*cos(theta)**27 - 1.48607210307393e+61*cos(theta)**25 + 1.37599268803142e+60*cos(theta)**23 - 1.04699594006601e+59*cos(theta)**21 + 6.45534783951446e+57*cos(theta)**19 - 3.16929222095025e+56*cos(theta)**17 + 1.21210276166826e+55*cos(theta)**15 - 3.51091834414256e+53*cos(theta)**13 + 7.42145341038264e+51*cos(theta)**11 - 1.08818964961622e+50*cos(theta)**9 + 1.028750719175e+48*cos(theta)**7 - 5.59538075697358e+45*cos(theta)**5 + 1.43104367186025e+43*cos(theta)**3 - 1.08549456778274e+40*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl91_m_minus_19(theta, phi):
    return 3.35100232120186e-37*(1.0 - cos(theta)**2)**9.5*(3.22863328002916e+62*cos(theta)**72 - 4.55932964848317e+63*cos(theta)**70 + 3.07563717907454e+64*cos(theta)**68 - 1.31945414198339e+65*cos(theta)**66 + 4.04318447793481e+65*cos(theta)**64 - 9.42319064452784e+65*cos(theta)**62 + 1.73676934783647e+66*cos(theta)**60 - 2.59854754494552e+66*cos(theta)**58 + 3.21511908068484e+66*cos(theta)**56 - 3.33419756515464e+66*cos(theta)**54 + 2.92713908940877e+66*cos(theta)**52 - 2.19163547857483e+66*cos(theta)**50 + 1.40710349122336e+66*cos(theta)**48 - 7.77664251886306e+65*cos(theta)**46 + 3.70913594793699e+65*cos(theta)**44 - 1.52890745392087e+65*cos(theta)**42 + 5.44863128239183e+64*cos(theta)**40 - 1.67782566137609e+64*cos(theta)**38 + 4.45771519254493e+63*cos(theta)**36 - 1.01936862842225e+63*cos(theta)**34 + 1.99953077113596e+62*cos(theta)**32 - 3.34943351058236e+61*cos(theta)**30 + 4.76456369229341e+60*cos(theta)**28 - 5.71566193489974e+59*cos(theta)**26 + 5.73330286679758e+58*cos(theta)**24 - 4.75907245484551e+57*cos(theta)**22 + 3.22767391975723e+56*cos(theta)**20 - 1.76071790052792e+55*cos(theta)**18 + 7.57564226042665e+53*cos(theta)**16 - 2.50779881724468e+52*cos(theta)**14 + 6.1845445086522e+50*cos(theta)**12 - 1.08818964961622e+49*cos(theta)**10 + 1.28593839896875e+47*cos(theta)**8 - 9.32563459495597e+44*cos(theta)**6 + 3.57760917965063e+42*cos(theta)**4 - 5.42747283891372e+39*cos(theta)**2 + 1.3582264361646e+36)*sin(19*phi)

#@torch.jit.script
def Yl91_m_minus_18(theta, phi):
    return 3.00284213621534e-35*(1.0 - cos(theta)**2)**9*(4.42278531510844e+60*cos(theta)**73 - 6.42159105420164e+61*cos(theta)**71 + 4.45744518706455e+62*cos(theta)**69 - 1.96933454027372e+63*cos(theta)**67 + 6.22028381220741e+63*cos(theta)**65 - 1.49574454675045e+64*cos(theta)**63 + 2.84716286530568e+64*cos(theta)**61 - 4.40431787278901e+64*cos(theta)**59 + 5.64055979067515e+64*cos(theta)**57 - 6.06217739119026e+64*cos(theta)**55 + 5.5229039422807e+64*cos(theta)**53 - 4.29732446779379e+64*cos(theta)**51 + 2.87163977800686e+64*cos(theta)**49 - 1.65460479124746e+64*cos(theta)**47 + 8.24252432874886e+63*cos(theta)**45 - 3.55559873004853e+63*cos(theta)**43 + 1.32893445911996e+63*cos(theta)**41 - 4.30211708045151e+62*cos(theta)**39 + 1.20478788987701e+62*cos(theta)**37 - 2.91248179549215e+61*cos(theta)**35 + 6.05918415495745e+60*cos(theta)**33 - 1.0804624227685e+60*cos(theta)**31 + 1.64295299734256e+59*cos(theta)**29 - 2.11691182774065e+58*cos(theta)**27 + 2.29332114671903e+57*cos(theta)**25 - 2.06916193688935e+56*cos(theta)**23 + 1.53698758083678e+55*cos(theta)**21 - 9.26693631856799e+53*cos(theta)**19 + 4.45626015319214e+52*cos(theta)**17 - 1.67186587816312e+51*cos(theta)**15 + 4.75734192973246e+49*cos(theta)**13 - 9.8926331783293e+47*cos(theta)**11 + 1.42882044329861e+46*cos(theta)**9 - 1.33223351356514e+44*cos(theta)**7 + 7.15521835930126e+41*cos(theta)**5 - 1.80915761297124e+39*cos(theta)**3 + 1.3582264361646e+36*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl91_m_minus_17(theta, phi):
    return 2.69687992278696e-33*(1.0 - cos(theta)**2)**8.5*(5.9767369123087e+58*cos(theta)**74 - 8.91887646416895e+59*cos(theta)**72 + 6.36777883866364e+60*cos(theta)**70 - 2.89608020628488e+61*cos(theta)**68 + 9.42467244273849e+61*cos(theta)**66 - 2.33710085429758e+62*cos(theta)**64 + 4.59219816984788e+62*cos(theta)**62 - 7.34052978798169e+62*cos(theta)**60 + 9.72510308737095e+62*cos(theta)**58 - 1.08253167699826e+63*cos(theta)**56 + 1.02275998931124e+63*cos(theta)**54 - 8.26408551498806e+62*cos(theta)**52 + 5.74327955601371e+62*cos(theta)**50 - 3.44709331509887e+62*cos(theta)**48 + 1.7918531149454e+62*cos(theta)**46 - 8.08090620465575e+61*cos(theta)**44 + 3.16412966457133e+61*cos(theta)**42 - 1.07552927011288e+61*cos(theta)**40 + 3.17049444704476e+60*cos(theta)**38 - 8.09022720970042e+59*cos(theta)**36 + 1.78211298675219e+59*cos(theta)**34 - 3.37644507115157e+58*cos(theta)**32 + 5.47650999114185e+57*cos(theta)**30 - 7.56039938478802e+56*cos(theta)**28 + 8.82046594891936e+55*cos(theta)**26 - 8.6215080703723e+54*cos(theta)**24 + 6.98630718562171e+53*cos(theta)**22 - 4.633468159284e+52*cos(theta)**20 + 2.47570008510675e+51*cos(theta)**18 - 1.04491617385195e+50*cos(theta)**16 + 3.39810137838033e+48*cos(theta)**14 - 8.24386098194108e+46*cos(theta)**12 + 1.42882044329861e+45*cos(theta)**10 - 1.66529189195642e+43*cos(theta)**8 + 1.19253639321688e+41*cos(theta)**6 - 4.5228940324281e+38*cos(theta)**4 + 6.79113218082298e+35*cos(theta)**2 - 1.68389094491023e+32)*sin(17*phi)

#@torch.jit.script
def Yl91_m_minus_16(theta, phi):
    return 2.42719193050827e-31*(1.0 - cos(theta)**2)**8*(7.96898254974493e+56*cos(theta)**75 - 1.22176389920123e+58*cos(theta)**73 + 8.9687025896671e+58*cos(theta)**71 - 4.19721769026794e+59*cos(theta)**69 + 1.40666752876694e+60*cos(theta)**67 - 3.59553977584243e+60*cos(theta)**65 + 7.28920344420298e+60*cos(theta)**63 - 1.20336553901339e+61*cos(theta)**61 + 1.64832255718152e+61*cos(theta)**59 - 1.8991783806987e+61*cos(theta)**57 + 1.85956361692953e+61*cos(theta)**55 - 1.55926141792228e+61*cos(theta)**53 + 1.1261332462772e+61*cos(theta)**51 - 7.03488431652831e+60*cos(theta)**49 + 3.81245343605405e+60*cos(theta)**47 - 1.79575693436794e+60*cos(theta)**45 + 7.35844108039844e+59*cos(theta)**43 - 2.62324212222653e+59*cos(theta)**41 + 8.12947294114041e+58*cos(theta)**39 - 2.18654789451363e+58*cos(theta)**37 + 5.09175139072055e+57*cos(theta)**35 - 1.02316517307623e+57*cos(theta)**33 + 1.76661612617479e+56*cos(theta)**31 - 2.60703427061656e+55*cos(theta)**29 + 3.2668392403405e+54*cos(theta)**27 - 3.44860322814892e+53*cos(theta)**25 + 3.03752486331379e+52*cos(theta)**23 - 2.20641340918286e+51*cos(theta)**21 + 1.30300004479302e+50*cos(theta)**19 - 6.14656572854089e+48*cos(theta)**17 + 2.26540091892022e+47*cos(theta)**15 - 6.34143152457006e+45*cos(theta)**13 + 1.29892767572601e+44*cos(theta)**11 - 1.85032432439603e+42*cos(theta)**9 + 1.70362341888125e+40*cos(theta)**7 - 9.04578806485621e+37*cos(theta)**5 + 2.26371072694099e+35*cos(theta)**3 - 1.68389094491023e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl91_m_minus_15(theta, phi):
    return 2.18878349199524e-29*(1.0 - cos(theta)**2)**7.5*(1.04855033549275e+55*cos(theta)**76 - 1.65103229621787e+56*cos(theta)**74 + 1.24565313745376e+57*cos(theta)**72 - 5.99602527181134e+57*cos(theta)**70 + 2.06862871877491e+58*cos(theta)**68 - 5.4477875391552e+58*cos(theta)**66 + 1.13893803815672e+59*cos(theta)**64 - 1.94091215969902e+59*cos(theta)**62 + 2.74720426196919e+59*cos(theta)**60 - 3.27444548396328e+59*cos(theta)**58 + 3.32064931594559e+59*cos(theta)**56 - 2.88752114430051e+59*cos(theta)**54 + 2.16564085822538e+59*cos(theta)**52 - 1.40697686330566e+59*cos(theta)**50 + 7.94261132511261e+58*cos(theta)**48 - 3.90381942253901e+58*cos(theta)**46 + 1.67237297281783e+58*cos(theta)**44 - 6.24581457672983e+57*cos(theta)**42 + 2.0323682352851e+57*cos(theta)**40 - 5.75407340661481e+56*cos(theta)**38 + 1.41437538631126e+56*cos(theta)**36 - 3.00930933257716e+55*cos(theta)**34 + 5.52067539429622e+54*cos(theta)**32 - 8.69011423538853e+53*cos(theta)**30 + 1.16672830012161e+53*cos(theta)**28 - 1.32638585698035e+52*cos(theta)**26 + 1.26563535971408e+51*cos(theta)**24 - 1.00291518599221e+50*cos(theta)**22 + 6.51500022396512e+48*cos(theta)**20 - 3.41475873807827e+47*cos(theta)**18 + 1.41587557432514e+46*cos(theta)**16 - 4.52959394612147e+44*cos(theta)**14 + 1.08243972977168e+43*cos(theta)**12 - 1.85032432439603e+41*cos(theta)**10 + 2.12952927360156e+39*cos(theta)**8 - 1.5076313441427e+37*cos(theta)**6 + 5.65927681735248e+34*cos(theta)**4 - 8.41945472455117e+31*cos(theta)**2 + 2.07069717770565e+28)*sin(15*phi)

#@torch.jit.script
def Yl91_m_minus_14(theta, phi):
    return 1.9774299141302e-27*(1.0 - cos(theta)**2)**7*(1.36175368245812e+53*cos(theta)**77 - 2.20137639495716e+54*cos(theta)**75 + 1.70637416089557e+55*cos(theta)**73 - 8.44510601663568e+55*cos(theta)**71 + 2.99801263590567e+56*cos(theta)**69 - 8.13102617784358e+56*cos(theta)**67 + 1.75221236639495e+57*cos(theta)**65 - 3.0808129519032e+57*cos(theta)**63 + 4.50361354421179e+57*cos(theta)**61 - 5.54990759993777e+57*cos(theta)**59 + 5.8257005542905e+57*cos(theta)**57 - 5.25003844418274e+57*cos(theta)**55 + 4.08611482684034e+57*cos(theta)**53 - 2.75877816334444e+57*cos(theta)**51 + 1.62094108675768e+57*cos(theta)**49 - 8.30599877135959e+56*cos(theta)**47 + 3.71638438403962e+56*cos(theta)**45 - 1.45251501784415e+56*cos(theta)**43 + 4.95699569581732e+55*cos(theta)**41 - 1.47540343759354e+55*cos(theta)**39 + 3.82263617921963e+54*cos(theta)**37 - 8.59802666450616e+53*cos(theta)**35 + 1.67293193766552e+53*cos(theta)**33 - 2.80326265657694e+52*cos(theta)**31 + 4.0232010349021e+51*cos(theta)**29 - 4.91254021103835e+50*cos(theta)**27 + 5.06254143885631e+49*cos(theta)**25 - 4.36050080866177e+48*cos(theta)**23 + 3.10238105903101e+47*cos(theta)**21 - 1.79724144109383e+46*cos(theta)**19 + 8.32867984897139e+44*cos(theta)**17 - 3.01972929741432e+43*cos(theta)**15 + 8.32645945978212e+41*cos(theta)**13 - 1.68211302217821e+40*cos(theta)**11 + 2.36614363733507e+38*cos(theta)**9 - 2.153759063061e+36*cos(theta)**7 + 1.1318553634705e+34*cos(theta)**5 - 2.80648490818372e+31*cos(theta)**3 + 2.07069717770565e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl91_m_minus_13(theta, phi):
    return 1.78954675951153e-25*(1.0 - cos(theta)**2)**6.5*(1.74583805443349e+51*cos(theta)**78 - 2.89654788810153e+52*cos(theta)**76 + 2.30591102823725e+53*cos(theta)**74 - 1.1729313911994e+54*cos(theta)**72 + 4.28287519415095e+54*cos(theta)**70 - 1.19573914380053e+55*cos(theta)**68 + 2.65486722181053e+55*cos(theta)**66 - 4.81377023734876e+55*cos(theta)**64 + 7.26389281324483e+55*cos(theta)**62 - 9.24984599989628e+55*cos(theta)**60 + 1.00443113005009e+56*cos(theta)**58 - 9.37506865032633e+55*cos(theta)**56 + 7.5668793089636e+55*cos(theta)**54 - 5.30534262181622e+55*cos(theta)**52 + 3.24188217351535e+55*cos(theta)**50 - 1.73041641069991e+55*cos(theta)**48 + 8.07909648704265e+54*cos(theta)**46 - 3.30117049510033e+54*cos(theta)**44 + 1.1802370704327e+54*cos(theta)**42 - 3.68850859398385e+53*cos(theta)**40 + 1.00595688926832e+53*cos(theta)**38 - 2.3883407401406e+52*cos(theta)**36 + 4.92038805195742e+51*cos(theta)**34 - 8.76019580180295e+50*cos(theta)**32 + 1.34106701163403e+50*cos(theta)**30 - 1.75447864679941e+49*cos(theta)**28 + 1.94713132263704e+48*cos(theta)**26 - 1.8168753369424e+47*cos(theta)**24 + 1.41017320865046e+46*cos(theta)**22 - 8.98620720546914e+44*cos(theta)**20 + 4.62704436053966e+43*cos(theta)**18 - 1.88733081088395e+42*cos(theta)**16 + 5.94747104270151e+40*cos(theta)**14 - 1.40176085181517e+39*cos(theta)**12 + 2.36614363733507e+37*cos(theta)**10 - 2.69219882882625e+35*cos(theta)**8 + 1.88642560578416e+33*cos(theta)**6 - 7.01621227045931e+30*cos(theta)**4 + 1.03534858885283e+28*cos(theta)**2 - 2.52832378230238e+24)*sin(13*phi)

#@torch.jit.script
def Yl91_m_minus_12(theta, phi):
    return 1.62208372158755e-23*(1.0 - cos(theta)**2)**6*(2.20992158789049e+49*cos(theta)**79 - 3.76175050402796e+50*cos(theta)**77 + 3.07454803764967e+51*cos(theta)**75 - 1.60675533041014e+52*cos(theta)**73 + 6.0322185833112e+52*cos(theta)**71 - 1.73295528087033e+53*cos(theta)**69 + 3.96248839076198e+53*cos(theta)**67 - 7.40580036515193e+53*cos(theta)**65 + 1.15299885924521e+54*cos(theta)**63 - 1.51636819670431e+54*cos(theta)**61 + 1.70242564415269e+54*cos(theta)**59 - 1.64474888602216e+54*cos(theta)**57 + 1.37579623799338e+54*cos(theta)**55 - 1.00100804185212e+54*cos(theta)**53 + 6.3566317127752e+53*cos(theta)**51 - 3.53146206265289e+53*cos(theta)**49 + 1.71895669937078e+53*cos(theta)**47 - 7.33593443355629e+52*cos(theta)**45 + 2.74473737309929e+52*cos(theta)**43 - 8.99636242435086e+51*cos(theta)**41 + 2.57937663914955e+51*cos(theta)**39 - 6.45497497335297e+50*cos(theta)**37 + 1.40582515770212e+50*cos(theta)**35 - 2.65460478842514e+49*cos(theta)**33 + 4.3260226181743e+48*cos(theta)**31 - 6.04992636827383e+47*cos(theta)**29 + 7.21159749124831e+46*cos(theta)**27 - 7.26750134776962e+45*cos(theta)**25 + 6.13118786369765e+44*cos(theta)**23 - 4.27914628831864e+43*cos(theta)**21 + 2.43528650554719e+42*cos(theta)**19 - 1.11019459463762e+41*cos(theta)**17 + 3.96498069513434e+39*cos(theta)**15 - 1.07827757831936e+38*cos(theta)**13 + 2.15103967030461e+36*cos(theta)**11 - 2.99133203202917e+34*cos(theta)**9 + 2.6948937225488e+32*cos(theta)**7 - 1.40324245409186e+30*cos(theta)**5 + 3.45116196284275e+27*cos(theta)**3 - 2.52832378230238e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl91_m_minus_11(theta, phi):
    return 1.47243750776309e-21*(1.0 - cos(theta)**2)**5.5*(2.76240198486312e+47*cos(theta)**80 - 4.8227570564461e+48*cos(theta)**78 + 4.04545794427588e+49*cos(theta)**76 - 2.17129098704073e+50*cos(theta)**74 + 8.37808136571e+50*cos(theta)**72 - 2.47565040124333e+51*cos(theta)**70 + 5.82718880994409e+51*cos(theta)**68 - 1.12209096441696e+52*cos(theta)**66 + 1.80156071757064e+52*cos(theta)**64 - 2.44575515597469e+52*cos(theta)**62 + 2.83737607358781e+52*cos(theta)**60 - 2.83577394141752e+52*cos(theta)**58 + 2.45677899641675e+52*cos(theta)**56 - 1.85371859602244e+52*cos(theta)**54 + 1.22242917553369e+52*cos(theta)**52 - 7.06292412530578e+51*cos(theta)**50 + 3.58115979035578e+51*cos(theta)**48 - 1.59476835512093e+51*cos(theta)**46 + 6.23803948431658e+50*cos(theta)**44 - 2.14199105341687e+50*cos(theta)**42 + 6.44844159787387e+49*cos(theta)**40 - 1.69867762456657e+49*cos(theta)**38 + 3.90506988250589e+48*cos(theta)**36 - 7.80766114242687e+47*cos(theta)**34 + 1.35188206817947e+47*cos(theta)**32 - 2.01664212275794e+46*cos(theta)**30 + 2.57557053258868e+45*cos(theta)**28 - 2.79519282606524e+44*cos(theta)**26 + 2.55466160987402e+43*cos(theta)**24 - 1.94506649469029e+42*cos(theta)**22 + 1.2176432527736e+41*cos(theta)**20 - 6.16774774798676e+39*cos(theta)**18 + 2.47811293445896e+38*cos(theta)**16 - 7.70198270228116e+36*cos(theta)**14 + 1.79253305858718e+35*cos(theta)**12 - 2.99133203202917e+33*cos(theta)**10 + 3.368617153186e+31*cos(theta)**8 - 2.33873742348644e+29*cos(theta)**6 + 8.62790490710688e+26*cos(theta)**4 - 1.26416189115119e+24*cos(theta)**2 + 3.0683541047359e+20)*sin(11*phi)

#@torch.jit.script
def Yl91_m_minus_10(theta, phi):
    return 1.33838008929746e-19*(1.0 - cos(theta)**2)**5*(3.41037282081866e+45*cos(theta)**81 - 6.1047557676533e+46*cos(theta)**79 + 5.25384148607257e+47*cos(theta)**77 - 2.89505464938764e+48*cos(theta)**75 + 1.14768237886438e+49*cos(theta)**73 - 3.48683155104694e+49*cos(theta)**71 + 8.44520117383201e+49*cos(theta)**69 - 1.67476263345815e+50*cos(theta)**67 + 2.7716318731856e+50*cos(theta)**65 - 3.88215104122967e+50*cos(theta)**63 + 4.65143618620953e+50*cos(theta)**61 - 4.80639651087716e+50*cos(theta)**59 + 4.31013859020483e+50*cos(theta)**57 - 3.37039744731353e+50*cos(theta)**55 + 2.3064701425164e+50*cos(theta)**53 - 1.38488708339329e+50*cos(theta)**51 + 7.30848936807303e+49*cos(theta)**49 - 3.39312415983177e+49*cos(theta)**47 + 1.38623099651479e+49*cos(theta)**45 - 4.98137454282993e+48*cos(theta)**43 + 1.57279063362777e+48*cos(theta)**41 - 4.3555836527348e+47*cos(theta)**39 + 1.05542429256916e+47*cos(theta)**37 - 2.23076032640768e+46*cos(theta)**35 + 4.09661232781657e+45*cos(theta)**33 - 6.50529717018691e+44*cos(theta)**31 + 8.88127769858166e+43*cos(theta)**29 - 1.03525660224638e+43*cos(theta)**27 + 1.02186464394961e+42*cos(theta)**25 - 8.45681084647952e+40*cos(theta)**23 + 5.79830120368379e+39*cos(theta)**21 - 3.24618302525619e+38*cos(theta)**19 + 1.45771349085821e+37*cos(theta)**17 - 5.13465513485411e+35*cos(theta)**15 + 1.3788715835286e+34*cos(theta)**13 - 2.71939275639015e+32*cos(theta)**11 + 3.74290794798445e+30*cos(theta)**9 - 3.34105346212348e+28*cos(theta)**7 + 1.72558098142138e+26*cos(theta)**5 - 4.21387297050397e+23*cos(theta)**3 + 3.0683541047359e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl91_m_minus_9(theta, phi):
    return 1.2179994164083e-17*(1.0 - cos(theta)**2)**4.5*(4.15899124490081e+43*cos(theta)**82 - 7.63094470956662e+44*cos(theta)**80 + 6.73569421291355e+45*cos(theta)**78 - 3.80928243340478e+46*cos(theta)**76 + 1.55092213360052e+47*cos(theta)**74 - 4.8428215986763e+47*cos(theta)**72 + 1.20645731054743e+48*cos(theta)**70 - 2.46288622567375e+48*cos(theta)**68 + 4.1994422320994e+48*cos(theta)**66 - 6.06586100192135e+48*cos(theta)**64 + 7.50231642937021e+48*cos(theta)**62 - 8.01066085146193e+48*cos(theta)**60 + 7.43127343138764e+48*cos(theta)**58 - 6.01856687020273e+48*cos(theta)**56 + 4.27124100466e+48*cos(theta)**54 - 2.66324439114094e+48*cos(theta)**52 + 1.46169787361461e+48*cos(theta)**50 - 7.06900866631619e+47*cos(theta)**48 + 3.01354564459738e+47*cos(theta)**46 - 1.13213057791589e+47*cos(theta)**44 + 3.74473960387565e+46*cos(theta)**42 - 1.0888959131837e+46*cos(theta)**40 + 2.77743234886621e+45*cos(theta)**38 - 6.19655646224355e+44*cos(theta)**36 + 1.20488597876958e+44*cos(theta)**34 - 2.03290536568341e+43*cos(theta)**32 + 2.96042589952722e+42*cos(theta)**30 - 3.6973450080228e+41*cos(theta)**28 + 3.93024863057542e+40*cos(theta)**26 - 3.52367118603313e+39*cos(theta)**24 + 2.6355914562199e+38*cos(theta)**22 - 1.62309151262809e+37*cos(theta)**20 + 8.09840828254563e+35*cos(theta)**18 - 3.20915945928382e+34*cos(theta)**16 + 9.84908273948998e+32*cos(theta)**14 - 2.26616063032513e+31*cos(theta)**12 + 3.74290794798445e+29*cos(theta)**10 - 4.17631682765435e+27*cos(theta)**8 + 2.87596830236896e+25*cos(theta)**6 - 1.05346824262599e+23*cos(theta)**4 + 1.53417705236795e+20*cos(theta)**2 - 3.70484678185933e+16)*sin(9*phi)

#@torch.jit.script
def Yl91_m_minus_8(theta, phi):
    return 1.10965027826244e-15*(1.0 - cos(theta)**2)**4*(5.0108328251817e+41*cos(theta)**83 - 9.42091939452669e+42*cos(theta)**81 + 8.52619520621969e+43*cos(theta)**79 - 4.94712004338284e+44*cos(theta)**77 + 2.06789617813403e+45*cos(theta)**75 - 6.63400218996754e+45*cos(theta)**73 + 1.69923564865835e+46*cos(theta)**71 - 3.5694003270634e+46*cos(theta)**69 + 6.26782422701403e+46*cos(theta)**67 - 9.33209384910977e+46*cos(theta)**65 + 1.19084387767781e+47*cos(theta)**63 - 1.31322309040359e+47*cos(theta)**61 + 1.25953786972672e+47*cos(theta)**59 - 1.05588892459697e+47*cos(theta)**57 + 7.76589273574545e+46*cos(theta)**55 - 5.02498941724706e+46*cos(theta)**53 + 2.86607426198942e+46*cos(theta)**51 - 1.44265482986045e+46*cos(theta)**49 + 6.41179924382421e+45*cos(theta)**47 - 2.51584572870199e+45*cos(theta)**45 + 8.70869675319919e+44*cos(theta)**43 - 2.65584369069195e+44*cos(theta)**41 + 7.12162140734925e+43*cos(theta)**39 - 1.67474498979555e+43*cos(theta)**37 + 3.44253136791308e+42*cos(theta)**35 - 6.16031928994973e+41*cos(theta)**33 + 9.54976096621684e+40*cos(theta)**31 - 1.27494655449062e+40*cos(theta)**29 + 1.45564764095386e+39*cos(theta)**27 - 1.40946847441325e+38*cos(theta)**25 + 1.14590932879126e+37*cos(theta)**23 - 7.72900720299092e+35*cos(theta)**21 + 4.26232014870823e+34*cos(theta)**19 - 1.88774085840225e+33*cos(theta)**17 + 6.56605515965999e+31*cos(theta)**15 - 1.74320048486548e+30*cos(theta)**13 + 3.40264358907677e+28*cos(theta)**11 - 4.64035203072706e+26*cos(theta)**9 + 4.10852614624137e+24*cos(theta)**7 - 2.10693648525198e+22*cos(theta)**5 + 5.11392350789317e+19*cos(theta)**3 - 3.70484678185933e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl91_m_minus_7(theta, phi):
    return 1.01191344601396e-13*(1.0 - cos(theta)**2)**3.5*(5.96527717283535e+39*cos(theta)**84 - 1.14889260908862e+41*cos(theta)**82 + 1.06577440077746e+42*cos(theta)**80 - 6.34246159408056e+42*cos(theta)**78 + 2.72091602386056e+43*cos(theta)**76 - 8.96486782428046e+43*cos(theta)**74 + 2.36004951202549e+44*cos(theta)**72 - 5.09914332437629e+44*cos(theta)**70 + 9.21738856913828e+44*cos(theta)**68 - 1.41395361350148e+45*cos(theta)**66 + 1.86069355887158e+45*cos(theta)**64 - 2.11810175871548e+45*cos(theta)**62 + 2.09922978287786e+45*cos(theta)**60 - 1.82049814585684e+45*cos(theta)**58 + 1.38676655995455e+45*cos(theta)**56 - 9.30553595786492e+44*cos(theta)**54 + 5.51168127305658e+44*cos(theta)**52 - 2.8853096597209e+44*cos(theta)**50 + 1.33579150913004e+44*cos(theta)**48 - 5.46922984500432e+43*cos(theta)**46 + 1.97924926209072e+43*cos(theta)**44 - 6.32343735879036e+42*cos(theta)**42 + 1.78040535183731e+42*cos(theta)**40 - 4.40722365735672e+41*cos(theta)**38 + 9.5625871330919e+40*cos(theta)**36 - 1.8118586146911e+40*cos(theta)**34 + 2.98430030194276e+39*cos(theta)**32 - 4.24982184830207e+38*cos(theta)**30 + 5.19874157483521e+37*cos(theta)**28 - 5.42103259389713e+36*cos(theta)**26 + 4.77462220329693e+35*cos(theta)**24 - 3.5131850922686e+34*cos(theta)**22 + 2.13116007435411e+33*cos(theta)**20 - 1.04874492133458e+32*cos(theta)**18 + 4.10378447478749e+30*cos(theta)**16 - 1.24514320347534e+29*cos(theta)**14 + 2.83553632423064e+27*cos(theta)**12 - 4.64035203072706e+25*cos(theta)**10 + 5.13565768280171e+23*cos(theta)**8 - 3.51156080875331e+21*cos(theta)**6 + 1.27848087697329e+19*cos(theta)**4 - 1.85242339092967e+16*cos(theta)**2 + 4455082710268.56)*sin(7*phi)

#@torch.jit.script
def Yl91_m_minus_6(theta, phi):
    return 9.23561599955551e-12*(1.0 - cos(theta)**2)**3*(7.01797314451218e+37*cos(theta)**85 - 1.38420796275737e+39*cos(theta)**83 + 1.31577086515736e+40*cos(theta)**81 - 8.02843239757033e+40*cos(theta)**79 + 3.53365717384488e+41*cos(theta)**77 - 1.19531570990406e+42*cos(theta)**75 + 3.23294453702122e+42*cos(theta)**73 - 7.18189200616379e+42*cos(theta)**71 + 1.33585341581714e+43*cos(theta)**69 - 2.11037852761415e+43*cos(theta)**67 + 2.86260547518705e+43*cos(theta)**65 - 3.36206628367536e+43*cos(theta)**63 + 3.44136029979978e+43*cos(theta)**61 - 3.08559007772346e+43*cos(theta)**59 + 2.43292378939394e+43*cos(theta)**57 - 1.69191562870271e+43*cos(theta)**55 + 1.03993986284086e+43*cos(theta)**53 - 5.65746992102136e+42*cos(theta)**51 + 2.72610512067356e+42*cos(theta)**49 - 1.163665924469e+42*cos(theta)**47 + 4.39833169353494e+41*cos(theta)**45 - 1.47056682762566e+41*cos(theta)**43 + 4.34245207765198e+40*cos(theta)**41 - 1.13005734804018e+40*cos(theta)**39 + 2.58448300894376e+39*cos(theta)**37 - 5.17673889911742e+38*cos(theta)**35 + 9.0433342483114e+37*cos(theta)**33 - 1.37091027364583e+37*cos(theta)**31 + 1.79266950856386e+36*cos(theta)**29 - 2.00778984959153e+35*cos(theta)**27 + 1.90984888131877e+34*cos(theta)**25 - 1.52747177924722e+33*cos(theta)**23 + 1.01483813064482e+32*cos(theta)**21 - 5.51971011228727e+30*cos(theta)**19 + 2.41399086752205e+29*cos(theta)**17 - 8.30095468983563e+27*cos(theta)**15 + 2.18118178786972e+26*cos(theta)**13 - 4.21850184611551e+24*cos(theta)**11 + 5.70628631422412e+22*cos(theta)**9 - 5.01651544107615e+20*cos(theta)**7 + 2.55696175394658e+18*cos(theta)**5 - 6.17474463643222e+15*cos(theta)**3 + 4455082710268.56*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl91_m_minus_5(theta, phi):
    return 8.43530830093822e-10*(1.0 - cos(theta)**2)**2.5*(8.16043388896765e+35*cos(theta)**86 - 1.64786662233021e+37*cos(theta)**84 + 1.60459861604556e+38*cos(theta)**82 - 1.00355404969629e+39*cos(theta)**80 + 4.53032971005754e+39*cos(theta)**78 - 1.57278382882113e+40*cos(theta)**76 + 4.36884396894759e+40*cos(theta)**74 - 9.97485000856082e+40*cos(theta)**72 + 1.90836202259592e+41*cos(theta)**70 - 3.10349783472669e+41*cos(theta)**68 + 4.33728102301068e+41*cos(theta)**66 - 5.25322856824275e+41*cos(theta)**64 + 5.55058112870932e+41*cos(theta)**62 - 5.14265012953911e+41*cos(theta)**60 + 4.19469618861024e+41*cos(theta)**58 - 3.0212779083977e+41*cos(theta)**56 + 1.92581456081642e+41*cos(theta)**54 - 1.0879749848118e+41*cos(theta)**52 + 5.45221024134712e+40*cos(theta)**50 - 2.42430400931043e+40*cos(theta)**48 + 9.56159063811944e+39*cos(theta)**46 - 3.34219733551287e+39*cos(theta)**44 + 1.03391716134571e+39*cos(theta)**42 - 2.82514337010046e+38*cos(theta)**40 + 6.80127107616778e+37*cos(theta)**38 - 1.43798302753262e+37*cos(theta)**36 + 2.65980419067982e+36*cos(theta)**34 - 4.28409460514321e+35*cos(theta)**32 + 5.97556502854622e+34*cos(theta)**30 - 7.17067803425546e+33*cos(theta)**28 + 7.34557262045681e+32*cos(theta)**26 - 6.36446574686341e+31*cos(theta)**24 + 4.61290059384007e+30*cos(theta)**22 - 2.75985505614363e+29*cos(theta)**20 + 1.34110603751225e+28*cos(theta)**18 - 5.18809668114727e+26*cos(theta)**16 + 1.55798699133552e+25*cos(theta)**14 - 3.51541820509626e+23*cos(theta)**12 + 5.70628631422412e+21*cos(theta)**10 - 6.27064430134519e+19*cos(theta)**8 + 4.26160292324431e+17*cos(theta)**6 - 1.54368615910806e+15*cos(theta)**4 + 2227541355134.28*cos(theta)**2 - 534054508.543342)*sin(5*phi)

#@torch.jit.script
def Yl91_m_minus_4(theta, phi):
    return 7.7089672917547e-8*(1.0 - cos(theta)**2)**2*(9.37980906777891e+33*cos(theta)**87 - 1.93866661450613e+35*cos(theta)**85 + 1.93325134463321e+36*cos(theta)**83 - 1.238955616909e+37*cos(theta)**81 + 5.73459456969309e+37*cos(theta)**79 - 2.04257640106641e+38*cos(theta)**77 + 5.82512529193012e+38*cos(theta)**75 - 1.36641780939189e+39*cos(theta)**73 + 2.68783383464214e+39*cos(theta)**71 - 4.49782294887926e+39*cos(theta)**69 + 6.47355376568758e+39*cos(theta)**67 - 8.08189010498884e+39*cos(theta)**65 + 8.81044623604654e+39*cos(theta)**63 - 8.430573982851e+39*cos(theta)**61 + 7.10965455696651e+39*cos(theta)**59 - 5.30048755859246e+39*cos(theta)**57 + 3.50148101966621e+39*cos(theta)**55 - 2.05278299021094e+39*cos(theta)**53 + 1.06906083163669e+39*cos(theta)**51 - 4.94755920267434e+38*cos(theta)**49 + 2.03438098683392e+38*cos(theta)**47 - 7.42710519002861e+37*cos(theta)**45 + 2.40445851475746e+37*cos(theta)**43 - 6.89059358561088e+36*cos(theta)**41 + 1.74391566055584e+36*cos(theta)**39 - 3.88644061495302e+35*cos(theta)**37 + 7.5994405447995e+34*cos(theta)**35 - 1.29821048640703e+34*cos(theta)**33 + 1.92760162211168e+33*cos(theta)**31 - 2.47264759801912e+32*cos(theta)**29 + 2.72058245202104e+31*cos(theta)**27 - 2.54578629874536e+30*cos(theta)**25 + 2.00560895384351e+29*cos(theta)**23 - 1.31421669340173e+28*cos(theta)**21 + 7.05845282901185e+26*cos(theta)**19 - 3.05182157714545e+25*cos(theta)**17 + 1.03865799422368e+24*cos(theta)**15 - 2.70416785007404e+22*cos(theta)**13 + 5.18753301293102e+20*cos(theta)**11 - 6.96738255705021e+18*cos(theta)**9 + 6.08800417606329e+16*cos(theta)**7 - 308737231821611.0*cos(theta)**5 + 742513785044.76*cos(theta)**3 - 534054508.543342*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl91_m_minus_3(theta, phi):
    return 7.04854280867098e-6*(1.0 - cos(theta)**2)**1.5*(1.06588739406579e+32*cos(theta)**88 - 2.25426350523968e+33*cos(theta)**86 + 2.30148969599191e+34*cos(theta)**84 - 1.51092148403537e+35*cos(theta)**82 + 7.16824321211637e+35*cos(theta)**80 - 2.61868769367488e+36*cos(theta)**78 + 7.66463854201332e+36*cos(theta)**76 - 1.84651055323229e+37*cos(theta)**74 + 3.73310254811408e+37*cos(theta)**72 - 6.42546135554181e+37*cos(theta)**70 + 9.51993200836409e+37*cos(theta)**68 - 1.22452880378619e+38*cos(theta)**66 + 1.37663222438227e+38*cos(theta)**64 - 1.35976999723403e+38*cos(theta)**62 + 1.18494242616108e+38*cos(theta)**60 - 9.13877165274562e+37*cos(theta)**58 + 6.25264467797538e+37*cos(theta)**56 - 3.80144998187212e+37*cos(theta)**54 + 2.05588621468594e+37*cos(theta)**52 - 9.89511840534868e+36*cos(theta)**50 + 4.23829372257067e+36*cos(theta)**48 - 1.61458808478883e+36*cos(theta)**46 + 5.4646784426306e+35*cos(theta)**44 - 1.64061752038354e+35*cos(theta)**42 + 4.3597891513896e+34*cos(theta)**40 - 1.02274753025079e+34*cos(theta)**38 + 2.11095570688875e+33*cos(theta)**36 - 3.81826613649128e+32*cos(theta)**34 + 6.02375506909901e+31*cos(theta)**32 - 8.24215866006375e+30*cos(theta)**30 + 9.71636590007515e+29*cos(theta)**28 - 9.79148576440524e+28*cos(theta)**26 + 8.35670397434796e+27*cos(theta)**24 - 5.97371224273514e+26*cos(theta)**22 + 3.52922641450593e+25*cos(theta)**20 - 1.69545643174747e+24*cos(theta)**18 + 6.49161246389799e+22*cos(theta)**16 - 1.9315484643386e+21*cos(theta)**14 + 4.32294417744252e+19*cos(theta)**12 - 6.96738255705021e+17*cos(theta)**10 + 7.61000522007912e+15*cos(theta)**8 - 51456205303601.9*cos(theta)**6 + 185628446261.19*cos(theta)**4 - 267027254.271671*cos(theta)**2 + 63882.1182468112)*sin(3*phi)

#@torch.jit.script
def Yl91_m_minus_2(theta, phi):
    return 0.000644700893128692*(1.0 - cos(theta)**2)*(1.19762628546717e+30*cos(theta)**89 - 2.59110747728699e+31*cos(theta)**87 + 2.70763493646107e+32*cos(theta)**85 - 1.82038733016309e+33*cos(theta)**83 + 8.84968297792144e+33*cos(theta)**81 - 3.31479454895554e+34*cos(theta)**79 + 9.95407602858873e+34*cos(theta)**77 - 2.46201407097638e+35*cos(theta)**75 + 5.11383910700559e+35*cos(theta)**73 - 9.04994557118564e+35*cos(theta)**71 + 1.37970029106726e+36*cos(theta)**69 - 1.82765493102416e+36*cos(theta)**67 + 2.11789572981888e+36*cos(theta)**65 - 2.15836507497465e+36*cos(theta)**63 + 1.94252856747719e+36*cos(theta)**61 - 1.54894434792299e+36*cos(theta)**59 + 1.09695520666235e+36*cos(theta)**57 - 6.91172723976749e+35*cos(theta)**55 + 3.87903059374706e+35*cos(theta)**53 - 1.94021929516641e+35*cos(theta)**51 + 8.64957902565444e+34*cos(theta)**49 - 3.43529379742304e+34*cos(theta)**47 + 1.21437298725124e+34*cos(theta)**45 - 3.81538958228731e+33*cos(theta)**43 + 1.063363207656e+33*cos(theta)**41 - 2.62242956474563e+32*cos(theta)**39 + 5.70528569429392e+31*cos(theta)**37 - 1.09093318185465e+31*cos(theta)**35 + 1.8253803239694e+30*cos(theta)**33 - 2.65876085808508e+29*cos(theta)**31 + 3.35047100002591e+28*cos(theta)**29 - 3.62647620903898e+27*cos(theta)**27 + 3.34268158973918e+26*cos(theta)**25 - 2.59726619249354e+25*cos(theta)**23 + 1.68058400690758e+24*cos(theta)**21 - 8.92345490393407e+22*cos(theta)**19 + 3.81859556699881e+21*cos(theta)**17 - 1.28769897622573e+20*cos(theta)**15 + 3.32534167495578e+18*cos(theta)**13 - 6.33398414277292e+16*cos(theta)**11 + 845556135564346.0*cos(theta)**9 - 7350886471943.12*cos(theta)**7 + 37125689252.238*cos(theta)**5 - 89009084.7572237*cos(theta)**3 + 63882.1182468112*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl91_m_minus_1(theta, phi):
    return 0.0589822045383166*(1.0 - cos(theta)**2)**0.5*(1.3306958727413e+28*cos(theta)**90 - 2.94444031509885e+29*cos(theta)**88 + 3.1484127168152e+30*cos(theta)**86 - 2.16712777400368e+31*cos(theta)**84 + 1.07922963145383e+32*cos(theta)**82 - 4.14349318619443e+32*cos(theta)**80 + 1.27616359340881e+33*cos(theta)**78 - 3.23949219865314e+33*cos(theta)**76 + 6.91059338784539e+33*cos(theta)**74 - 1.25693688488689e+34*cos(theta)**72 + 1.97100041581037e+34*cos(theta)**70 - 2.68772783974141e+34*cos(theta)**68 + 3.208932923968e+34*cos(theta)**66 - 3.3724454296479e+34*cos(theta)**64 + 3.13311059270514e+34*cos(theta)**62 - 2.58157391320498e+34*cos(theta)**60 + 1.89130208045232e+34*cos(theta)**58 - 1.23423700710134e+34*cos(theta)**56 + 7.18338998842048e+33*cos(theta)**54 - 3.73119095224309e+33*cos(theta)**52 + 1.72991580513089e+33*cos(theta)**50 - 7.15686207796466e+32*cos(theta)**48 + 2.63994127663314e+32*cos(theta)**46 - 8.67133995974389e+31*cos(theta)**44 + 2.53181716108572e+31*cos(theta)**42 - 6.55607391186406e+30*cos(theta)**40 + 1.50139097218261e+30*cos(theta)**38 - 3.03036994959625e+29*cos(theta)**36 + 5.36876565873352e+28*cos(theta)**34 - 8.30862768151587e+27*cos(theta)**32 + 1.1168236666753e+27*cos(theta)**30 - 1.29517007465678e+26*cos(theta)**28 + 1.2856467652843e+25*cos(theta)**26 - 1.08219424687231e+24*cos(theta)**24 + 7.63901821321629e+22*cos(theta)**22 - 4.46172745196704e+21*cos(theta)**20 + 2.12144198166601e+20*cos(theta)**18 - 8.04811860141084e+18*cos(theta)**16 + 2.37524405353985e+17*cos(theta)**14 - 5.27832011897743e+15*cos(theta)**12 + 84555613556434.6*cos(theta)**10 - 918860808992.89*cos(theta)**8 + 6187614875.373*cos(theta)**6 - 22252271.1893059*cos(theta)**4 + 31941.0591234056*cos(theta)**2 - 7.63227219197267)*sin(phi)

#@torch.jit.script
def Yl91_m0(theta, phi):
    return 1.75310489795454e+27*cos(theta)**91 - 3.96627876084189e+28*cos(theta)**89 + 4.33853285683152e+29*cos(theta)**87 - 3.05658218783554e+30*cos(theta)**85 + 1.55885691579613e+31*cos(theta)**83 - 6.13270529994707e+31*cos(theta)**81 + 1.93664377893065e+32*cos(theta)**79 - 5.04378654512709e+32*cos(theta)**77 + 1.10464965801212e+33*cos(theta)**75 - 2.06424431042668e+33*cos(theta)**73 + 3.32811904773087e+33*cos(theta)**71 - 4.66989036341683e+33*cos(theta)**69 + 5.74190922042761e+33*cos(theta)**67 - 6.2201672152697e+33*cos(theta)**65 + 5.96218792984376e+33*cos(theta)**63 - 5.07370502265136e+33*cos(theta)**61 + 3.84307954944205e+33*cos(theta)**59 - 2.59593727165233e+33*cos(theta)**57 + 1.56580343369505e+33*cos(theta)**55 - 8.43999309995338e+32*cos(theta)**53 + 4.06654212997754e+32*cos(theta)**51 - 1.75104397694068e+32*cos(theta)**49 + 6.73390358692689e+31*cos(theta)**47 - 2.31017130354426e+31*cos(theta)**45 + 7.05885676082969e+30*cos(theta)**43 - 1.91703688873059e+30*cos(theta)**41 + 4.61529726588104e+29*cos(theta)**39 - 9.81893561302857e+28*cos(theta)**37 + 1.83897950457734e+28*cos(theta)**35 - 3.01846291096143e+27*cos(theta)**33 + 4.3191014010505e+26*cos(theta)**31 - 5.35425793518657e+25*cos(theta)**29 + 5.70858382795627e+24*cos(theta)**27 - 5.18962166177843e+23*cos(theta)**25 + 3.98180690162028e+22*cos(theta)**23 - 2.54714828346379e+21*cos(theta)**21 + 1.33859144025875e+20*cos(theta)**19 - 5.67565425946557e+18*cos(theta)**17 + 1.89839886691421e+17*cos(theta)**15 - 4.86768940234412e+15*cos(theta)**13 + 92155284801660.6*cos(theta)**11 - 1223989534917.01*cos(theta)**9 + 10597311990.6235*cos(theta)**7 - 53354963.2709404*cos(theta)**5 + 127643.452801293*cos(theta)**3 - 91.5006830116795*cos(theta)

#@torch.jit.script
def Yl91_m1(theta, phi):
    return 0.0589822045383166*(1.0 - cos(theta)**2)**0.5*(1.3306958727413e+28*cos(theta)**90 - 2.94444031509885e+29*cos(theta)**88 + 3.1484127168152e+30*cos(theta)**86 - 2.16712777400368e+31*cos(theta)**84 + 1.07922963145383e+32*cos(theta)**82 - 4.14349318619443e+32*cos(theta)**80 + 1.27616359340881e+33*cos(theta)**78 - 3.23949219865314e+33*cos(theta)**76 + 6.91059338784539e+33*cos(theta)**74 - 1.25693688488689e+34*cos(theta)**72 + 1.97100041581037e+34*cos(theta)**70 - 2.68772783974141e+34*cos(theta)**68 + 3.208932923968e+34*cos(theta)**66 - 3.3724454296479e+34*cos(theta)**64 + 3.13311059270514e+34*cos(theta)**62 - 2.58157391320498e+34*cos(theta)**60 + 1.89130208045232e+34*cos(theta)**58 - 1.23423700710134e+34*cos(theta)**56 + 7.18338998842048e+33*cos(theta)**54 - 3.73119095224309e+33*cos(theta)**52 + 1.72991580513089e+33*cos(theta)**50 - 7.15686207796466e+32*cos(theta)**48 + 2.63994127663314e+32*cos(theta)**46 - 8.67133995974389e+31*cos(theta)**44 + 2.53181716108572e+31*cos(theta)**42 - 6.55607391186406e+30*cos(theta)**40 + 1.50139097218261e+30*cos(theta)**38 - 3.03036994959625e+29*cos(theta)**36 + 5.36876565873352e+28*cos(theta)**34 - 8.30862768151587e+27*cos(theta)**32 + 1.1168236666753e+27*cos(theta)**30 - 1.29517007465678e+26*cos(theta)**28 + 1.2856467652843e+25*cos(theta)**26 - 1.08219424687231e+24*cos(theta)**24 + 7.63901821321629e+22*cos(theta)**22 - 4.46172745196704e+21*cos(theta)**20 + 2.12144198166601e+20*cos(theta)**18 - 8.04811860141084e+18*cos(theta)**16 + 2.37524405353985e+17*cos(theta)**14 - 5.27832011897743e+15*cos(theta)**12 + 84555613556434.6*cos(theta)**10 - 918860808992.89*cos(theta)**8 + 6187614875.373*cos(theta)**6 - 22252271.1893059*cos(theta)**4 + 31941.0591234056*cos(theta)**2 - 7.63227219197267)*cos(phi)

#@torch.jit.script
def Yl91_m2(theta, phi):
    return 0.000644700893128692*(1.0 - cos(theta)**2)*(1.19762628546717e+30*cos(theta)**89 - 2.59110747728699e+31*cos(theta)**87 + 2.70763493646107e+32*cos(theta)**85 - 1.82038733016309e+33*cos(theta)**83 + 8.84968297792144e+33*cos(theta)**81 - 3.31479454895554e+34*cos(theta)**79 + 9.95407602858873e+34*cos(theta)**77 - 2.46201407097638e+35*cos(theta)**75 + 5.11383910700559e+35*cos(theta)**73 - 9.04994557118564e+35*cos(theta)**71 + 1.37970029106726e+36*cos(theta)**69 - 1.82765493102416e+36*cos(theta)**67 + 2.11789572981888e+36*cos(theta)**65 - 2.15836507497465e+36*cos(theta)**63 + 1.94252856747719e+36*cos(theta)**61 - 1.54894434792299e+36*cos(theta)**59 + 1.09695520666235e+36*cos(theta)**57 - 6.91172723976749e+35*cos(theta)**55 + 3.87903059374706e+35*cos(theta)**53 - 1.94021929516641e+35*cos(theta)**51 + 8.64957902565444e+34*cos(theta)**49 - 3.43529379742304e+34*cos(theta)**47 + 1.21437298725124e+34*cos(theta)**45 - 3.81538958228731e+33*cos(theta)**43 + 1.063363207656e+33*cos(theta)**41 - 2.62242956474563e+32*cos(theta)**39 + 5.70528569429392e+31*cos(theta)**37 - 1.09093318185465e+31*cos(theta)**35 + 1.8253803239694e+30*cos(theta)**33 - 2.65876085808508e+29*cos(theta)**31 + 3.35047100002591e+28*cos(theta)**29 - 3.62647620903898e+27*cos(theta)**27 + 3.34268158973918e+26*cos(theta)**25 - 2.59726619249354e+25*cos(theta)**23 + 1.68058400690758e+24*cos(theta)**21 - 8.92345490393407e+22*cos(theta)**19 + 3.81859556699881e+21*cos(theta)**17 - 1.28769897622573e+20*cos(theta)**15 + 3.32534167495578e+18*cos(theta)**13 - 6.33398414277292e+16*cos(theta)**11 + 845556135564346.0*cos(theta)**9 - 7350886471943.12*cos(theta)**7 + 37125689252.238*cos(theta)**5 - 89009084.7572237*cos(theta)**3 + 63882.1182468112*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl91_m3(theta, phi):
    return 7.04854280867098e-6*(1.0 - cos(theta)**2)**1.5*(1.06588739406579e+32*cos(theta)**88 - 2.25426350523968e+33*cos(theta)**86 + 2.30148969599191e+34*cos(theta)**84 - 1.51092148403537e+35*cos(theta)**82 + 7.16824321211637e+35*cos(theta)**80 - 2.61868769367488e+36*cos(theta)**78 + 7.66463854201332e+36*cos(theta)**76 - 1.84651055323229e+37*cos(theta)**74 + 3.73310254811408e+37*cos(theta)**72 - 6.42546135554181e+37*cos(theta)**70 + 9.51993200836409e+37*cos(theta)**68 - 1.22452880378619e+38*cos(theta)**66 + 1.37663222438227e+38*cos(theta)**64 - 1.35976999723403e+38*cos(theta)**62 + 1.18494242616108e+38*cos(theta)**60 - 9.13877165274562e+37*cos(theta)**58 + 6.25264467797538e+37*cos(theta)**56 - 3.80144998187212e+37*cos(theta)**54 + 2.05588621468594e+37*cos(theta)**52 - 9.89511840534868e+36*cos(theta)**50 + 4.23829372257067e+36*cos(theta)**48 - 1.61458808478883e+36*cos(theta)**46 + 5.4646784426306e+35*cos(theta)**44 - 1.64061752038354e+35*cos(theta)**42 + 4.3597891513896e+34*cos(theta)**40 - 1.02274753025079e+34*cos(theta)**38 + 2.11095570688875e+33*cos(theta)**36 - 3.81826613649128e+32*cos(theta)**34 + 6.02375506909901e+31*cos(theta)**32 - 8.24215866006375e+30*cos(theta)**30 + 9.71636590007515e+29*cos(theta)**28 - 9.79148576440524e+28*cos(theta)**26 + 8.35670397434796e+27*cos(theta)**24 - 5.97371224273514e+26*cos(theta)**22 + 3.52922641450593e+25*cos(theta)**20 - 1.69545643174747e+24*cos(theta)**18 + 6.49161246389799e+22*cos(theta)**16 - 1.9315484643386e+21*cos(theta)**14 + 4.32294417744252e+19*cos(theta)**12 - 6.96738255705021e+17*cos(theta)**10 + 7.61000522007912e+15*cos(theta)**8 - 51456205303601.9*cos(theta)**6 + 185628446261.19*cos(theta)**4 - 267027254.271671*cos(theta)**2 + 63882.1182468112)*cos(3*phi)

#@torch.jit.script
def Yl91_m4(theta, phi):
    return 7.7089672917547e-8*(1.0 - cos(theta)**2)**2*(9.37980906777891e+33*cos(theta)**87 - 1.93866661450613e+35*cos(theta)**85 + 1.93325134463321e+36*cos(theta)**83 - 1.238955616909e+37*cos(theta)**81 + 5.73459456969309e+37*cos(theta)**79 - 2.04257640106641e+38*cos(theta)**77 + 5.82512529193012e+38*cos(theta)**75 - 1.36641780939189e+39*cos(theta)**73 + 2.68783383464214e+39*cos(theta)**71 - 4.49782294887926e+39*cos(theta)**69 + 6.47355376568758e+39*cos(theta)**67 - 8.08189010498884e+39*cos(theta)**65 + 8.81044623604654e+39*cos(theta)**63 - 8.430573982851e+39*cos(theta)**61 + 7.10965455696651e+39*cos(theta)**59 - 5.30048755859246e+39*cos(theta)**57 + 3.50148101966621e+39*cos(theta)**55 - 2.05278299021094e+39*cos(theta)**53 + 1.06906083163669e+39*cos(theta)**51 - 4.94755920267434e+38*cos(theta)**49 + 2.03438098683392e+38*cos(theta)**47 - 7.42710519002861e+37*cos(theta)**45 + 2.40445851475746e+37*cos(theta)**43 - 6.89059358561088e+36*cos(theta)**41 + 1.74391566055584e+36*cos(theta)**39 - 3.88644061495302e+35*cos(theta)**37 + 7.5994405447995e+34*cos(theta)**35 - 1.29821048640703e+34*cos(theta)**33 + 1.92760162211168e+33*cos(theta)**31 - 2.47264759801912e+32*cos(theta)**29 + 2.72058245202104e+31*cos(theta)**27 - 2.54578629874536e+30*cos(theta)**25 + 2.00560895384351e+29*cos(theta)**23 - 1.31421669340173e+28*cos(theta)**21 + 7.05845282901185e+26*cos(theta)**19 - 3.05182157714545e+25*cos(theta)**17 + 1.03865799422368e+24*cos(theta)**15 - 2.70416785007404e+22*cos(theta)**13 + 5.18753301293102e+20*cos(theta)**11 - 6.96738255705021e+18*cos(theta)**9 + 6.08800417606329e+16*cos(theta)**7 - 308737231821611.0*cos(theta)**5 + 742513785044.76*cos(theta)**3 - 534054508.543342*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl91_m5(theta, phi):
    return 8.43530830093822e-10*(1.0 - cos(theta)**2)**2.5*(8.16043388896765e+35*cos(theta)**86 - 1.64786662233021e+37*cos(theta)**84 + 1.60459861604556e+38*cos(theta)**82 - 1.00355404969629e+39*cos(theta)**80 + 4.53032971005754e+39*cos(theta)**78 - 1.57278382882113e+40*cos(theta)**76 + 4.36884396894759e+40*cos(theta)**74 - 9.97485000856082e+40*cos(theta)**72 + 1.90836202259592e+41*cos(theta)**70 - 3.10349783472669e+41*cos(theta)**68 + 4.33728102301068e+41*cos(theta)**66 - 5.25322856824275e+41*cos(theta)**64 + 5.55058112870932e+41*cos(theta)**62 - 5.14265012953911e+41*cos(theta)**60 + 4.19469618861024e+41*cos(theta)**58 - 3.0212779083977e+41*cos(theta)**56 + 1.92581456081642e+41*cos(theta)**54 - 1.0879749848118e+41*cos(theta)**52 + 5.45221024134712e+40*cos(theta)**50 - 2.42430400931043e+40*cos(theta)**48 + 9.56159063811944e+39*cos(theta)**46 - 3.34219733551287e+39*cos(theta)**44 + 1.03391716134571e+39*cos(theta)**42 - 2.82514337010046e+38*cos(theta)**40 + 6.80127107616778e+37*cos(theta)**38 - 1.43798302753262e+37*cos(theta)**36 + 2.65980419067982e+36*cos(theta)**34 - 4.28409460514321e+35*cos(theta)**32 + 5.97556502854622e+34*cos(theta)**30 - 7.17067803425546e+33*cos(theta)**28 + 7.34557262045681e+32*cos(theta)**26 - 6.36446574686341e+31*cos(theta)**24 + 4.61290059384007e+30*cos(theta)**22 - 2.75985505614363e+29*cos(theta)**20 + 1.34110603751225e+28*cos(theta)**18 - 5.18809668114727e+26*cos(theta)**16 + 1.55798699133552e+25*cos(theta)**14 - 3.51541820509626e+23*cos(theta)**12 + 5.70628631422412e+21*cos(theta)**10 - 6.27064430134519e+19*cos(theta)**8 + 4.26160292324431e+17*cos(theta)**6 - 1.54368615910806e+15*cos(theta)**4 + 2227541355134.28*cos(theta)**2 - 534054508.543342)*cos(5*phi)

#@torch.jit.script
def Yl91_m6(theta, phi):
    return 9.23561599955551e-12*(1.0 - cos(theta)**2)**3*(7.01797314451218e+37*cos(theta)**85 - 1.38420796275737e+39*cos(theta)**83 + 1.31577086515736e+40*cos(theta)**81 - 8.02843239757033e+40*cos(theta)**79 + 3.53365717384488e+41*cos(theta)**77 - 1.19531570990406e+42*cos(theta)**75 + 3.23294453702122e+42*cos(theta)**73 - 7.18189200616379e+42*cos(theta)**71 + 1.33585341581714e+43*cos(theta)**69 - 2.11037852761415e+43*cos(theta)**67 + 2.86260547518705e+43*cos(theta)**65 - 3.36206628367536e+43*cos(theta)**63 + 3.44136029979978e+43*cos(theta)**61 - 3.08559007772346e+43*cos(theta)**59 + 2.43292378939394e+43*cos(theta)**57 - 1.69191562870271e+43*cos(theta)**55 + 1.03993986284086e+43*cos(theta)**53 - 5.65746992102136e+42*cos(theta)**51 + 2.72610512067356e+42*cos(theta)**49 - 1.163665924469e+42*cos(theta)**47 + 4.39833169353494e+41*cos(theta)**45 - 1.47056682762566e+41*cos(theta)**43 + 4.34245207765198e+40*cos(theta)**41 - 1.13005734804018e+40*cos(theta)**39 + 2.58448300894376e+39*cos(theta)**37 - 5.17673889911742e+38*cos(theta)**35 + 9.0433342483114e+37*cos(theta)**33 - 1.37091027364583e+37*cos(theta)**31 + 1.79266950856386e+36*cos(theta)**29 - 2.00778984959153e+35*cos(theta)**27 + 1.90984888131877e+34*cos(theta)**25 - 1.52747177924722e+33*cos(theta)**23 + 1.01483813064482e+32*cos(theta)**21 - 5.51971011228727e+30*cos(theta)**19 + 2.41399086752205e+29*cos(theta)**17 - 8.30095468983563e+27*cos(theta)**15 + 2.18118178786972e+26*cos(theta)**13 - 4.21850184611551e+24*cos(theta)**11 + 5.70628631422412e+22*cos(theta)**9 - 5.01651544107615e+20*cos(theta)**7 + 2.55696175394658e+18*cos(theta)**5 - 6.17474463643222e+15*cos(theta)**3 + 4455082710268.56*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl91_m7(theta, phi):
    return 1.01191344601396e-13*(1.0 - cos(theta)**2)**3.5*(5.96527717283535e+39*cos(theta)**84 - 1.14889260908862e+41*cos(theta)**82 + 1.06577440077746e+42*cos(theta)**80 - 6.34246159408056e+42*cos(theta)**78 + 2.72091602386056e+43*cos(theta)**76 - 8.96486782428046e+43*cos(theta)**74 + 2.36004951202549e+44*cos(theta)**72 - 5.09914332437629e+44*cos(theta)**70 + 9.21738856913828e+44*cos(theta)**68 - 1.41395361350148e+45*cos(theta)**66 + 1.86069355887158e+45*cos(theta)**64 - 2.11810175871548e+45*cos(theta)**62 + 2.09922978287786e+45*cos(theta)**60 - 1.82049814585684e+45*cos(theta)**58 + 1.38676655995455e+45*cos(theta)**56 - 9.30553595786492e+44*cos(theta)**54 + 5.51168127305658e+44*cos(theta)**52 - 2.8853096597209e+44*cos(theta)**50 + 1.33579150913004e+44*cos(theta)**48 - 5.46922984500432e+43*cos(theta)**46 + 1.97924926209072e+43*cos(theta)**44 - 6.32343735879036e+42*cos(theta)**42 + 1.78040535183731e+42*cos(theta)**40 - 4.40722365735672e+41*cos(theta)**38 + 9.5625871330919e+40*cos(theta)**36 - 1.8118586146911e+40*cos(theta)**34 + 2.98430030194276e+39*cos(theta)**32 - 4.24982184830207e+38*cos(theta)**30 + 5.19874157483521e+37*cos(theta)**28 - 5.42103259389713e+36*cos(theta)**26 + 4.77462220329693e+35*cos(theta)**24 - 3.5131850922686e+34*cos(theta)**22 + 2.13116007435411e+33*cos(theta)**20 - 1.04874492133458e+32*cos(theta)**18 + 4.10378447478749e+30*cos(theta)**16 - 1.24514320347534e+29*cos(theta)**14 + 2.83553632423064e+27*cos(theta)**12 - 4.64035203072706e+25*cos(theta)**10 + 5.13565768280171e+23*cos(theta)**8 - 3.51156080875331e+21*cos(theta)**6 + 1.27848087697329e+19*cos(theta)**4 - 1.85242339092967e+16*cos(theta)**2 + 4455082710268.56)*cos(7*phi)

#@torch.jit.script
def Yl91_m8(theta, phi):
    return 1.10965027826244e-15*(1.0 - cos(theta)**2)**4*(5.0108328251817e+41*cos(theta)**83 - 9.42091939452669e+42*cos(theta)**81 + 8.52619520621969e+43*cos(theta)**79 - 4.94712004338284e+44*cos(theta)**77 + 2.06789617813403e+45*cos(theta)**75 - 6.63400218996754e+45*cos(theta)**73 + 1.69923564865835e+46*cos(theta)**71 - 3.5694003270634e+46*cos(theta)**69 + 6.26782422701403e+46*cos(theta)**67 - 9.33209384910977e+46*cos(theta)**65 + 1.19084387767781e+47*cos(theta)**63 - 1.31322309040359e+47*cos(theta)**61 + 1.25953786972672e+47*cos(theta)**59 - 1.05588892459697e+47*cos(theta)**57 + 7.76589273574545e+46*cos(theta)**55 - 5.02498941724706e+46*cos(theta)**53 + 2.86607426198942e+46*cos(theta)**51 - 1.44265482986045e+46*cos(theta)**49 + 6.41179924382421e+45*cos(theta)**47 - 2.51584572870199e+45*cos(theta)**45 + 8.70869675319919e+44*cos(theta)**43 - 2.65584369069195e+44*cos(theta)**41 + 7.12162140734925e+43*cos(theta)**39 - 1.67474498979555e+43*cos(theta)**37 + 3.44253136791308e+42*cos(theta)**35 - 6.16031928994973e+41*cos(theta)**33 + 9.54976096621684e+40*cos(theta)**31 - 1.27494655449062e+40*cos(theta)**29 + 1.45564764095386e+39*cos(theta)**27 - 1.40946847441325e+38*cos(theta)**25 + 1.14590932879126e+37*cos(theta)**23 - 7.72900720299092e+35*cos(theta)**21 + 4.26232014870823e+34*cos(theta)**19 - 1.88774085840225e+33*cos(theta)**17 + 6.56605515965999e+31*cos(theta)**15 - 1.74320048486548e+30*cos(theta)**13 + 3.40264358907677e+28*cos(theta)**11 - 4.64035203072706e+26*cos(theta)**9 + 4.10852614624137e+24*cos(theta)**7 - 2.10693648525198e+22*cos(theta)**5 + 5.11392350789317e+19*cos(theta)**3 - 3.70484678185933e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl91_m9(theta, phi):
    return 1.2179994164083e-17*(1.0 - cos(theta)**2)**4.5*(4.15899124490081e+43*cos(theta)**82 - 7.63094470956662e+44*cos(theta)**80 + 6.73569421291355e+45*cos(theta)**78 - 3.80928243340478e+46*cos(theta)**76 + 1.55092213360052e+47*cos(theta)**74 - 4.8428215986763e+47*cos(theta)**72 + 1.20645731054743e+48*cos(theta)**70 - 2.46288622567375e+48*cos(theta)**68 + 4.1994422320994e+48*cos(theta)**66 - 6.06586100192135e+48*cos(theta)**64 + 7.50231642937021e+48*cos(theta)**62 - 8.01066085146193e+48*cos(theta)**60 + 7.43127343138764e+48*cos(theta)**58 - 6.01856687020273e+48*cos(theta)**56 + 4.27124100466e+48*cos(theta)**54 - 2.66324439114094e+48*cos(theta)**52 + 1.46169787361461e+48*cos(theta)**50 - 7.06900866631619e+47*cos(theta)**48 + 3.01354564459738e+47*cos(theta)**46 - 1.13213057791589e+47*cos(theta)**44 + 3.74473960387565e+46*cos(theta)**42 - 1.0888959131837e+46*cos(theta)**40 + 2.77743234886621e+45*cos(theta)**38 - 6.19655646224355e+44*cos(theta)**36 + 1.20488597876958e+44*cos(theta)**34 - 2.03290536568341e+43*cos(theta)**32 + 2.96042589952722e+42*cos(theta)**30 - 3.6973450080228e+41*cos(theta)**28 + 3.93024863057542e+40*cos(theta)**26 - 3.52367118603313e+39*cos(theta)**24 + 2.6355914562199e+38*cos(theta)**22 - 1.62309151262809e+37*cos(theta)**20 + 8.09840828254563e+35*cos(theta)**18 - 3.20915945928382e+34*cos(theta)**16 + 9.84908273948998e+32*cos(theta)**14 - 2.26616063032513e+31*cos(theta)**12 + 3.74290794798445e+29*cos(theta)**10 - 4.17631682765435e+27*cos(theta)**8 + 2.87596830236896e+25*cos(theta)**6 - 1.05346824262599e+23*cos(theta)**4 + 1.53417705236795e+20*cos(theta)**2 - 3.70484678185933e+16)*cos(9*phi)

#@torch.jit.script
def Yl91_m10(theta, phi):
    return 1.33838008929746e-19*(1.0 - cos(theta)**2)**5*(3.41037282081866e+45*cos(theta)**81 - 6.1047557676533e+46*cos(theta)**79 + 5.25384148607257e+47*cos(theta)**77 - 2.89505464938764e+48*cos(theta)**75 + 1.14768237886438e+49*cos(theta)**73 - 3.48683155104694e+49*cos(theta)**71 + 8.44520117383201e+49*cos(theta)**69 - 1.67476263345815e+50*cos(theta)**67 + 2.7716318731856e+50*cos(theta)**65 - 3.88215104122967e+50*cos(theta)**63 + 4.65143618620953e+50*cos(theta)**61 - 4.80639651087716e+50*cos(theta)**59 + 4.31013859020483e+50*cos(theta)**57 - 3.37039744731353e+50*cos(theta)**55 + 2.3064701425164e+50*cos(theta)**53 - 1.38488708339329e+50*cos(theta)**51 + 7.30848936807303e+49*cos(theta)**49 - 3.39312415983177e+49*cos(theta)**47 + 1.38623099651479e+49*cos(theta)**45 - 4.98137454282993e+48*cos(theta)**43 + 1.57279063362777e+48*cos(theta)**41 - 4.3555836527348e+47*cos(theta)**39 + 1.05542429256916e+47*cos(theta)**37 - 2.23076032640768e+46*cos(theta)**35 + 4.09661232781657e+45*cos(theta)**33 - 6.50529717018691e+44*cos(theta)**31 + 8.88127769858166e+43*cos(theta)**29 - 1.03525660224638e+43*cos(theta)**27 + 1.02186464394961e+42*cos(theta)**25 - 8.45681084647952e+40*cos(theta)**23 + 5.79830120368379e+39*cos(theta)**21 - 3.24618302525619e+38*cos(theta)**19 + 1.45771349085821e+37*cos(theta)**17 - 5.13465513485411e+35*cos(theta)**15 + 1.3788715835286e+34*cos(theta)**13 - 2.71939275639015e+32*cos(theta)**11 + 3.74290794798445e+30*cos(theta)**9 - 3.34105346212348e+28*cos(theta)**7 + 1.72558098142138e+26*cos(theta)**5 - 4.21387297050397e+23*cos(theta)**3 + 3.0683541047359e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl91_m11(theta, phi):
    return 1.47243750776309e-21*(1.0 - cos(theta)**2)**5.5*(2.76240198486312e+47*cos(theta)**80 - 4.8227570564461e+48*cos(theta)**78 + 4.04545794427588e+49*cos(theta)**76 - 2.17129098704073e+50*cos(theta)**74 + 8.37808136571e+50*cos(theta)**72 - 2.47565040124333e+51*cos(theta)**70 + 5.82718880994409e+51*cos(theta)**68 - 1.12209096441696e+52*cos(theta)**66 + 1.80156071757064e+52*cos(theta)**64 - 2.44575515597469e+52*cos(theta)**62 + 2.83737607358781e+52*cos(theta)**60 - 2.83577394141752e+52*cos(theta)**58 + 2.45677899641675e+52*cos(theta)**56 - 1.85371859602244e+52*cos(theta)**54 + 1.22242917553369e+52*cos(theta)**52 - 7.06292412530578e+51*cos(theta)**50 + 3.58115979035578e+51*cos(theta)**48 - 1.59476835512093e+51*cos(theta)**46 + 6.23803948431658e+50*cos(theta)**44 - 2.14199105341687e+50*cos(theta)**42 + 6.44844159787387e+49*cos(theta)**40 - 1.69867762456657e+49*cos(theta)**38 + 3.90506988250589e+48*cos(theta)**36 - 7.80766114242687e+47*cos(theta)**34 + 1.35188206817947e+47*cos(theta)**32 - 2.01664212275794e+46*cos(theta)**30 + 2.57557053258868e+45*cos(theta)**28 - 2.79519282606524e+44*cos(theta)**26 + 2.55466160987402e+43*cos(theta)**24 - 1.94506649469029e+42*cos(theta)**22 + 1.2176432527736e+41*cos(theta)**20 - 6.16774774798676e+39*cos(theta)**18 + 2.47811293445896e+38*cos(theta)**16 - 7.70198270228116e+36*cos(theta)**14 + 1.79253305858718e+35*cos(theta)**12 - 2.99133203202917e+33*cos(theta)**10 + 3.368617153186e+31*cos(theta)**8 - 2.33873742348644e+29*cos(theta)**6 + 8.62790490710688e+26*cos(theta)**4 - 1.26416189115119e+24*cos(theta)**2 + 3.0683541047359e+20)*cos(11*phi)

#@torch.jit.script
def Yl91_m12(theta, phi):
    return 1.62208372158755e-23*(1.0 - cos(theta)**2)**6*(2.20992158789049e+49*cos(theta)**79 - 3.76175050402796e+50*cos(theta)**77 + 3.07454803764967e+51*cos(theta)**75 - 1.60675533041014e+52*cos(theta)**73 + 6.0322185833112e+52*cos(theta)**71 - 1.73295528087033e+53*cos(theta)**69 + 3.96248839076198e+53*cos(theta)**67 - 7.40580036515193e+53*cos(theta)**65 + 1.15299885924521e+54*cos(theta)**63 - 1.51636819670431e+54*cos(theta)**61 + 1.70242564415269e+54*cos(theta)**59 - 1.64474888602216e+54*cos(theta)**57 + 1.37579623799338e+54*cos(theta)**55 - 1.00100804185212e+54*cos(theta)**53 + 6.3566317127752e+53*cos(theta)**51 - 3.53146206265289e+53*cos(theta)**49 + 1.71895669937078e+53*cos(theta)**47 - 7.33593443355629e+52*cos(theta)**45 + 2.74473737309929e+52*cos(theta)**43 - 8.99636242435086e+51*cos(theta)**41 + 2.57937663914955e+51*cos(theta)**39 - 6.45497497335297e+50*cos(theta)**37 + 1.40582515770212e+50*cos(theta)**35 - 2.65460478842514e+49*cos(theta)**33 + 4.3260226181743e+48*cos(theta)**31 - 6.04992636827383e+47*cos(theta)**29 + 7.21159749124831e+46*cos(theta)**27 - 7.26750134776962e+45*cos(theta)**25 + 6.13118786369765e+44*cos(theta)**23 - 4.27914628831864e+43*cos(theta)**21 + 2.43528650554719e+42*cos(theta)**19 - 1.11019459463762e+41*cos(theta)**17 + 3.96498069513434e+39*cos(theta)**15 - 1.07827757831936e+38*cos(theta)**13 + 2.15103967030461e+36*cos(theta)**11 - 2.99133203202917e+34*cos(theta)**9 + 2.6948937225488e+32*cos(theta)**7 - 1.40324245409186e+30*cos(theta)**5 + 3.45116196284275e+27*cos(theta)**3 - 2.52832378230238e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl91_m13(theta, phi):
    return 1.78954675951153e-25*(1.0 - cos(theta)**2)**6.5*(1.74583805443349e+51*cos(theta)**78 - 2.89654788810153e+52*cos(theta)**76 + 2.30591102823725e+53*cos(theta)**74 - 1.1729313911994e+54*cos(theta)**72 + 4.28287519415095e+54*cos(theta)**70 - 1.19573914380053e+55*cos(theta)**68 + 2.65486722181053e+55*cos(theta)**66 - 4.81377023734876e+55*cos(theta)**64 + 7.26389281324483e+55*cos(theta)**62 - 9.24984599989628e+55*cos(theta)**60 + 1.00443113005009e+56*cos(theta)**58 - 9.37506865032633e+55*cos(theta)**56 + 7.5668793089636e+55*cos(theta)**54 - 5.30534262181622e+55*cos(theta)**52 + 3.24188217351535e+55*cos(theta)**50 - 1.73041641069991e+55*cos(theta)**48 + 8.07909648704265e+54*cos(theta)**46 - 3.30117049510033e+54*cos(theta)**44 + 1.1802370704327e+54*cos(theta)**42 - 3.68850859398385e+53*cos(theta)**40 + 1.00595688926832e+53*cos(theta)**38 - 2.3883407401406e+52*cos(theta)**36 + 4.92038805195742e+51*cos(theta)**34 - 8.76019580180295e+50*cos(theta)**32 + 1.34106701163403e+50*cos(theta)**30 - 1.75447864679941e+49*cos(theta)**28 + 1.94713132263704e+48*cos(theta)**26 - 1.8168753369424e+47*cos(theta)**24 + 1.41017320865046e+46*cos(theta)**22 - 8.98620720546914e+44*cos(theta)**20 + 4.62704436053966e+43*cos(theta)**18 - 1.88733081088395e+42*cos(theta)**16 + 5.94747104270151e+40*cos(theta)**14 - 1.40176085181517e+39*cos(theta)**12 + 2.36614363733507e+37*cos(theta)**10 - 2.69219882882625e+35*cos(theta)**8 + 1.88642560578416e+33*cos(theta)**6 - 7.01621227045931e+30*cos(theta)**4 + 1.03534858885283e+28*cos(theta)**2 - 2.52832378230238e+24)*cos(13*phi)

#@torch.jit.script
def Yl91_m14(theta, phi):
    return 1.9774299141302e-27*(1.0 - cos(theta)**2)**7*(1.36175368245812e+53*cos(theta)**77 - 2.20137639495716e+54*cos(theta)**75 + 1.70637416089557e+55*cos(theta)**73 - 8.44510601663568e+55*cos(theta)**71 + 2.99801263590567e+56*cos(theta)**69 - 8.13102617784358e+56*cos(theta)**67 + 1.75221236639495e+57*cos(theta)**65 - 3.0808129519032e+57*cos(theta)**63 + 4.50361354421179e+57*cos(theta)**61 - 5.54990759993777e+57*cos(theta)**59 + 5.8257005542905e+57*cos(theta)**57 - 5.25003844418274e+57*cos(theta)**55 + 4.08611482684034e+57*cos(theta)**53 - 2.75877816334444e+57*cos(theta)**51 + 1.62094108675768e+57*cos(theta)**49 - 8.30599877135959e+56*cos(theta)**47 + 3.71638438403962e+56*cos(theta)**45 - 1.45251501784415e+56*cos(theta)**43 + 4.95699569581732e+55*cos(theta)**41 - 1.47540343759354e+55*cos(theta)**39 + 3.82263617921963e+54*cos(theta)**37 - 8.59802666450616e+53*cos(theta)**35 + 1.67293193766552e+53*cos(theta)**33 - 2.80326265657694e+52*cos(theta)**31 + 4.0232010349021e+51*cos(theta)**29 - 4.91254021103835e+50*cos(theta)**27 + 5.06254143885631e+49*cos(theta)**25 - 4.36050080866177e+48*cos(theta)**23 + 3.10238105903101e+47*cos(theta)**21 - 1.79724144109383e+46*cos(theta)**19 + 8.32867984897139e+44*cos(theta)**17 - 3.01972929741432e+43*cos(theta)**15 + 8.32645945978212e+41*cos(theta)**13 - 1.68211302217821e+40*cos(theta)**11 + 2.36614363733507e+38*cos(theta)**9 - 2.153759063061e+36*cos(theta)**7 + 1.1318553634705e+34*cos(theta)**5 - 2.80648490818372e+31*cos(theta)**3 + 2.07069717770565e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl91_m15(theta, phi):
    return 2.18878349199524e-29*(1.0 - cos(theta)**2)**7.5*(1.04855033549275e+55*cos(theta)**76 - 1.65103229621787e+56*cos(theta)**74 + 1.24565313745376e+57*cos(theta)**72 - 5.99602527181134e+57*cos(theta)**70 + 2.06862871877491e+58*cos(theta)**68 - 5.4477875391552e+58*cos(theta)**66 + 1.13893803815672e+59*cos(theta)**64 - 1.94091215969902e+59*cos(theta)**62 + 2.74720426196919e+59*cos(theta)**60 - 3.27444548396328e+59*cos(theta)**58 + 3.32064931594559e+59*cos(theta)**56 - 2.88752114430051e+59*cos(theta)**54 + 2.16564085822538e+59*cos(theta)**52 - 1.40697686330566e+59*cos(theta)**50 + 7.94261132511261e+58*cos(theta)**48 - 3.90381942253901e+58*cos(theta)**46 + 1.67237297281783e+58*cos(theta)**44 - 6.24581457672983e+57*cos(theta)**42 + 2.0323682352851e+57*cos(theta)**40 - 5.75407340661481e+56*cos(theta)**38 + 1.41437538631126e+56*cos(theta)**36 - 3.00930933257716e+55*cos(theta)**34 + 5.52067539429622e+54*cos(theta)**32 - 8.69011423538853e+53*cos(theta)**30 + 1.16672830012161e+53*cos(theta)**28 - 1.32638585698035e+52*cos(theta)**26 + 1.26563535971408e+51*cos(theta)**24 - 1.00291518599221e+50*cos(theta)**22 + 6.51500022396512e+48*cos(theta)**20 - 3.41475873807827e+47*cos(theta)**18 + 1.41587557432514e+46*cos(theta)**16 - 4.52959394612147e+44*cos(theta)**14 + 1.08243972977168e+43*cos(theta)**12 - 1.85032432439603e+41*cos(theta)**10 + 2.12952927360156e+39*cos(theta)**8 - 1.5076313441427e+37*cos(theta)**6 + 5.65927681735248e+34*cos(theta)**4 - 8.41945472455117e+31*cos(theta)**2 + 2.07069717770565e+28)*cos(15*phi)

#@torch.jit.script
def Yl91_m16(theta, phi):
    return 2.42719193050827e-31*(1.0 - cos(theta)**2)**8*(7.96898254974493e+56*cos(theta)**75 - 1.22176389920123e+58*cos(theta)**73 + 8.9687025896671e+58*cos(theta)**71 - 4.19721769026794e+59*cos(theta)**69 + 1.40666752876694e+60*cos(theta)**67 - 3.59553977584243e+60*cos(theta)**65 + 7.28920344420298e+60*cos(theta)**63 - 1.20336553901339e+61*cos(theta)**61 + 1.64832255718152e+61*cos(theta)**59 - 1.8991783806987e+61*cos(theta)**57 + 1.85956361692953e+61*cos(theta)**55 - 1.55926141792228e+61*cos(theta)**53 + 1.1261332462772e+61*cos(theta)**51 - 7.03488431652831e+60*cos(theta)**49 + 3.81245343605405e+60*cos(theta)**47 - 1.79575693436794e+60*cos(theta)**45 + 7.35844108039844e+59*cos(theta)**43 - 2.62324212222653e+59*cos(theta)**41 + 8.12947294114041e+58*cos(theta)**39 - 2.18654789451363e+58*cos(theta)**37 + 5.09175139072055e+57*cos(theta)**35 - 1.02316517307623e+57*cos(theta)**33 + 1.76661612617479e+56*cos(theta)**31 - 2.60703427061656e+55*cos(theta)**29 + 3.2668392403405e+54*cos(theta)**27 - 3.44860322814892e+53*cos(theta)**25 + 3.03752486331379e+52*cos(theta)**23 - 2.20641340918286e+51*cos(theta)**21 + 1.30300004479302e+50*cos(theta)**19 - 6.14656572854089e+48*cos(theta)**17 + 2.26540091892022e+47*cos(theta)**15 - 6.34143152457006e+45*cos(theta)**13 + 1.29892767572601e+44*cos(theta)**11 - 1.85032432439603e+42*cos(theta)**9 + 1.70362341888125e+40*cos(theta)**7 - 9.04578806485621e+37*cos(theta)**5 + 2.26371072694099e+35*cos(theta)**3 - 1.68389094491023e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl91_m17(theta, phi):
    return 2.69687992278696e-33*(1.0 - cos(theta)**2)**8.5*(5.9767369123087e+58*cos(theta)**74 - 8.91887646416895e+59*cos(theta)**72 + 6.36777883866364e+60*cos(theta)**70 - 2.89608020628488e+61*cos(theta)**68 + 9.42467244273849e+61*cos(theta)**66 - 2.33710085429758e+62*cos(theta)**64 + 4.59219816984788e+62*cos(theta)**62 - 7.34052978798169e+62*cos(theta)**60 + 9.72510308737095e+62*cos(theta)**58 - 1.08253167699826e+63*cos(theta)**56 + 1.02275998931124e+63*cos(theta)**54 - 8.26408551498806e+62*cos(theta)**52 + 5.74327955601371e+62*cos(theta)**50 - 3.44709331509887e+62*cos(theta)**48 + 1.7918531149454e+62*cos(theta)**46 - 8.08090620465575e+61*cos(theta)**44 + 3.16412966457133e+61*cos(theta)**42 - 1.07552927011288e+61*cos(theta)**40 + 3.17049444704476e+60*cos(theta)**38 - 8.09022720970042e+59*cos(theta)**36 + 1.78211298675219e+59*cos(theta)**34 - 3.37644507115157e+58*cos(theta)**32 + 5.47650999114185e+57*cos(theta)**30 - 7.56039938478802e+56*cos(theta)**28 + 8.82046594891936e+55*cos(theta)**26 - 8.6215080703723e+54*cos(theta)**24 + 6.98630718562171e+53*cos(theta)**22 - 4.633468159284e+52*cos(theta)**20 + 2.47570008510675e+51*cos(theta)**18 - 1.04491617385195e+50*cos(theta)**16 + 3.39810137838033e+48*cos(theta)**14 - 8.24386098194108e+46*cos(theta)**12 + 1.42882044329861e+45*cos(theta)**10 - 1.66529189195642e+43*cos(theta)**8 + 1.19253639321688e+41*cos(theta)**6 - 4.5228940324281e+38*cos(theta)**4 + 6.79113218082298e+35*cos(theta)**2 - 1.68389094491023e+32)*cos(17*phi)

#@torch.jit.script
def Yl91_m18(theta, phi):
    return 3.00284213621534e-35*(1.0 - cos(theta)**2)**9*(4.42278531510844e+60*cos(theta)**73 - 6.42159105420164e+61*cos(theta)**71 + 4.45744518706455e+62*cos(theta)**69 - 1.96933454027372e+63*cos(theta)**67 + 6.22028381220741e+63*cos(theta)**65 - 1.49574454675045e+64*cos(theta)**63 + 2.84716286530568e+64*cos(theta)**61 - 4.40431787278901e+64*cos(theta)**59 + 5.64055979067515e+64*cos(theta)**57 - 6.06217739119026e+64*cos(theta)**55 + 5.5229039422807e+64*cos(theta)**53 - 4.29732446779379e+64*cos(theta)**51 + 2.87163977800686e+64*cos(theta)**49 - 1.65460479124746e+64*cos(theta)**47 + 8.24252432874886e+63*cos(theta)**45 - 3.55559873004853e+63*cos(theta)**43 + 1.32893445911996e+63*cos(theta)**41 - 4.30211708045151e+62*cos(theta)**39 + 1.20478788987701e+62*cos(theta)**37 - 2.91248179549215e+61*cos(theta)**35 + 6.05918415495745e+60*cos(theta)**33 - 1.0804624227685e+60*cos(theta)**31 + 1.64295299734256e+59*cos(theta)**29 - 2.11691182774065e+58*cos(theta)**27 + 2.29332114671903e+57*cos(theta)**25 - 2.06916193688935e+56*cos(theta)**23 + 1.53698758083678e+55*cos(theta)**21 - 9.26693631856799e+53*cos(theta)**19 + 4.45626015319214e+52*cos(theta)**17 - 1.67186587816312e+51*cos(theta)**15 + 4.75734192973246e+49*cos(theta)**13 - 9.8926331783293e+47*cos(theta)**11 + 1.42882044329861e+46*cos(theta)**9 - 1.33223351356514e+44*cos(theta)**7 + 7.15521835930126e+41*cos(theta)**5 - 1.80915761297124e+39*cos(theta)**3 + 1.3582264361646e+36*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl91_m19(theta, phi):
    return 3.35100232120186e-37*(1.0 - cos(theta)**2)**9.5*(3.22863328002916e+62*cos(theta)**72 - 4.55932964848317e+63*cos(theta)**70 + 3.07563717907454e+64*cos(theta)**68 - 1.31945414198339e+65*cos(theta)**66 + 4.04318447793481e+65*cos(theta)**64 - 9.42319064452784e+65*cos(theta)**62 + 1.73676934783647e+66*cos(theta)**60 - 2.59854754494552e+66*cos(theta)**58 + 3.21511908068484e+66*cos(theta)**56 - 3.33419756515464e+66*cos(theta)**54 + 2.92713908940877e+66*cos(theta)**52 - 2.19163547857483e+66*cos(theta)**50 + 1.40710349122336e+66*cos(theta)**48 - 7.77664251886306e+65*cos(theta)**46 + 3.70913594793699e+65*cos(theta)**44 - 1.52890745392087e+65*cos(theta)**42 + 5.44863128239183e+64*cos(theta)**40 - 1.67782566137609e+64*cos(theta)**38 + 4.45771519254493e+63*cos(theta)**36 - 1.01936862842225e+63*cos(theta)**34 + 1.99953077113596e+62*cos(theta)**32 - 3.34943351058236e+61*cos(theta)**30 + 4.76456369229341e+60*cos(theta)**28 - 5.71566193489974e+59*cos(theta)**26 + 5.73330286679758e+58*cos(theta)**24 - 4.75907245484551e+57*cos(theta)**22 + 3.22767391975723e+56*cos(theta)**20 - 1.76071790052792e+55*cos(theta)**18 + 7.57564226042665e+53*cos(theta)**16 - 2.50779881724468e+52*cos(theta)**14 + 6.1845445086522e+50*cos(theta)**12 - 1.08818964961622e+49*cos(theta)**10 + 1.28593839896875e+47*cos(theta)**8 - 9.32563459495597e+44*cos(theta)**6 + 3.57760917965063e+42*cos(theta)**4 - 5.42747283891372e+39*cos(theta)**2 + 1.3582264361646e+36)*cos(19*phi)

#@torch.jit.script
def Yl91_m20(theta, phi):
    return 3.74840916485146e-39*(1.0 - cos(theta)**2)**10*(2.32461596162099e+64*cos(theta)**71 - 3.19153075393822e+65*cos(theta)**69 + 2.09143328177069e+66*cos(theta)**67 - 8.70839733709037e+66*cos(theta)**65 + 2.58763806587828e+67*cos(theta)**63 - 5.84237819960726e+67*cos(theta)**61 + 1.04206160870188e+68*cos(theta)**59 - 1.5071575760684e+68*cos(theta)**57 + 1.80046668518351e+68*cos(theta)**55 - 1.80046668518351e+68*cos(theta)**53 + 1.52211232649256e+68*cos(theta)**51 - 1.09581773928742e+68*cos(theta)**49 + 6.75409675787213e+67*cos(theta)**47 - 3.57725555867701e+67*cos(theta)**45 + 1.63201981709227e+67*cos(theta)**43 - 6.42141130646764e+66*cos(theta)**41 + 2.17945251295673e+66*cos(theta)**39 - 6.37573751322913e+65*cos(theta)**37 + 1.60477746931618e+65*cos(theta)**35 - 3.46585333663566e+64*cos(theta)**33 + 6.39849846763507e+63*cos(theta)**31 - 1.00483005317471e+63*cos(theta)**29 + 1.33407783384215e+62*cos(theta)**27 - 1.48607210307393e+61*cos(theta)**25 + 1.37599268803142e+60*cos(theta)**23 - 1.04699594006601e+59*cos(theta)**21 + 6.45534783951446e+57*cos(theta)**19 - 3.16929222095025e+56*cos(theta)**17 + 1.21210276166826e+55*cos(theta)**15 - 3.51091834414256e+53*cos(theta)**13 + 7.42145341038264e+51*cos(theta)**11 - 1.08818964961622e+50*cos(theta)**9 + 1.028750719175e+48*cos(theta)**7 - 5.59538075697358e+45*cos(theta)**5 + 1.43104367186025e+43*cos(theta)**3 - 1.08549456778274e+40*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl91_m21(theta, phi):
    return 4.20347825743065e-41*(1.0 - cos(theta)**2)**10.5*(1.65047733275091e+66*cos(theta)**70 - 2.20215622021737e+67*cos(theta)**68 + 1.40126029878636e+68*cos(theta)**66 - 5.66045826910874e+68*cos(theta)**64 + 1.63021198150332e+69*cos(theta)**62 - 3.56385070176043e+69*cos(theta)**60 + 6.14816349134109e+69*cos(theta)**58 - 8.59079818358988e+69*cos(theta)**56 + 9.90256676850929e+69*cos(theta)**54 - 9.54247343147259e+69*cos(theta)**52 + 7.76277286511206e+69*cos(theta)**50 - 5.36950692250834e+69*cos(theta)**48 + 3.1744254761999e+69*cos(theta)**46 - 1.60976500140465e+69*cos(theta)**44 + 7.01768521349678e+68*cos(theta)**42 - 2.63277863565173e+68*cos(theta)**40 + 8.49986480053126e+67*cos(theta)**38 - 2.35902287989478e+67*cos(theta)**36 + 5.61672114260662e+66*cos(theta)**34 - 1.14373160108977e+66*cos(theta)**32 + 1.98353452496687e+65*cos(theta)**30 - 2.91400715420665e+64*cos(theta)**28 + 3.60201015137382e+63*cos(theta)**26 - 3.71518025768483e+62*cos(theta)**24 + 3.16478318247226e+61*cos(theta)**22 - 2.19869147413863e+60*cos(theta)**20 + 1.22651608950775e+59*cos(theta)**18 - 5.38779677561543e+57*cos(theta)**16 + 1.81815414250239e+56*cos(theta)**14 - 4.56419384738532e+54*cos(theta)**12 + 8.1635987514209e+52*cos(theta)**10 - 9.793706846546e+50*cos(theta)**8 + 7.201255034225e+48*cos(theta)**6 - 2.79769037848679e+46*cos(theta)**4 + 4.29313101558076e+43*cos(theta)**2 - 1.08549456778274e+40)*cos(21*phi)

#@torch.jit.script
def Yl91_m22(theta, phi):
    return 4.72629215111746e-43*(1.0 - cos(theta)**2)**11*(1.15533413292563e+68*cos(theta)**69 - 1.49746622974781e+69*cos(theta)**67 + 9.24831797198997e+69*cos(theta)**65 - 3.62269329222959e+70*cos(theta)**63 + 1.01073142853206e+71*cos(theta)**61 - 2.13831042105626e+71*cos(theta)**59 + 3.56593482497783e+71*cos(theta)**57 - 4.81084698281033e+71*cos(theta)**55 + 5.34738605499502e+71*cos(theta)**53 - 4.96208618436575e+71*cos(theta)**51 + 3.88138643255603e+71*cos(theta)**49 - 2.577363322804e+71*cos(theta)**47 + 1.46023571905195e+71*cos(theta)**45 - 7.08296600618047e+70*cos(theta)**43 + 2.94742778966865e+70*cos(theta)**41 - 1.05311145426069e+70*cos(theta)**39 + 3.22994862420188e+69*cos(theta)**37 - 8.4924823676212e+68*cos(theta)**35 + 1.90968518848625e+68*cos(theta)**33 - 3.65994112348726e+67*cos(theta)**31 + 5.95060357490061e+66*cos(theta)**29 - 8.15922003177862e+65*cos(theta)**27 + 9.36522639357193e+64*cos(theta)**25 - 8.9164326184436e+63*cos(theta)**23 + 6.96252300143898e+62*cos(theta)**21 - 4.39738294827725e+61*cos(theta)**19 + 2.20772896111395e+60*cos(theta)**17 - 8.62047484098469e+58*cos(theta)**15 + 2.54541579950335e+57*cos(theta)**13 - 5.47703261686239e+55*cos(theta)**11 + 8.1635987514209e+53*cos(theta)**9 - 7.8349654772368e+51*cos(theta)**7 + 4.320753020535e+49*cos(theta)**5 - 1.11907615139472e+47*cos(theta)**3 + 8.58626203116151e+43*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl91_m23(theta, phi):
    return 5.32897389261526e-45*(1.0 - cos(theta)**2)**11.5*(7.97180551718688e+69*cos(theta)**68 - 1.00330237393103e+71*cos(theta)**66 + 6.01140668179348e+71*cos(theta)**64 - 2.28229677410464e+72*cos(theta)**62 + 6.16546171404555e+72*cos(theta)**60 - 1.26160314842319e+73*cos(theta)**58 + 2.03258285023737e+73*cos(theta)**56 - 2.64596584054568e+73*cos(theta)**54 + 2.83411460914736e+73*cos(theta)**52 - 2.53066395402653e+73*cos(theta)**50 + 1.90187935195245e+73*cos(theta)**48 - 1.21136076171788e+73*cos(theta)**46 + 6.57106073573379e+72*cos(theta)**44 - 3.0456753826576e+72*cos(theta)**42 + 1.20844539376415e+72*cos(theta)**40 - 4.1071346716167e+71*cos(theta)**38 + 1.1950809909547e+71*cos(theta)**36 - 2.97236882866742e+70*cos(theta)**34 + 6.30196112200462e+69*cos(theta)**32 - 1.13458174828105e+69*cos(theta)**30 + 1.72567503672118e+68*cos(theta)**28 - 2.20298940858023e+67*cos(theta)**26 + 2.34130659839298e+66*cos(theta)**24 - 2.05077950224203e+65*cos(theta)**22 + 1.46212983030219e+64*cos(theta)**20 - 8.35502760172678e+62*cos(theta)**18 + 3.75313923389371e+61*cos(theta)**16 - 1.2930712261477e+60*cos(theta)**14 + 3.30904053935436e+58*cos(theta)**12 - 6.02473587854863e+56*cos(theta)**10 + 7.34723887627881e+54*cos(theta)**8 - 5.48447583406576e+52*cos(theta)**6 + 2.1603765102675e+50*cos(theta)**4 - 3.35722845418415e+47*cos(theta)**2 + 8.58626203116151e+43)*cos(23*phi)

#@torch.jit.script
def Yl91_m24(theta, phi):
    return 6.02615386200106e-47*(1.0 - cos(theta)**2)**12*(5.42082775168708e+71*cos(theta)**67 - 6.62179566794482e+72*cos(theta)**65 + 3.84730027634783e+73*cos(theta)**63 - 1.41502399994488e+74*cos(theta)**61 + 3.69927702842733e+74*cos(theta)**59 - 7.31729826085452e+74*cos(theta)**57 + 1.13824639613292e+75*cos(theta)**55 - 1.42882155389467e+75*cos(theta)**53 + 1.47373959675663e+75*cos(theta)**51 - 1.26533197701327e+75*cos(theta)**49 + 9.12902088937178e+74*cos(theta)**47 - 5.57225950390226e+74*cos(theta)**45 + 2.89126672372287e+74*cos(theta)**43 - 1.27918366071619e+74*cos(theta)**41 + 4.83378157505658e+73*cos(theta)**39 - 1.56071117521435e+73*cos(theta)**37 + 4.3022915674369e+72*cos(theta)**35 - 1.01060540174692e+72*cos(theta)**33 + 2.01662755904148e+71*cos(theta)**31 - 3.40374524484315e+70*cos(theta)**29 + 4.8318901028193e+69*cos(theta)**27 - 5.72777246230859e+68*cos(theta)**25 + 5.61913583614316e+67*cos(theta)**23 - 4.51171490493246e+66*cos(theta)**21 + 2.92425966060437e+65*cos(theta)**19 - 1.50390496831082e+64*cos(theta)**17 + 6.00502277422993e+62*cos(theta)**15 - 1.81029971660678e+61*cos(theta)**13 + 3.97084864722523e+59*cos(theta)**11 - 6.02473587854863e+57*cos(theta)**9 + 5.87779110102305e+55*cos(theta)**7 - 3.29068550043946e+53*cos(theta)**5 + 8.64150604107e+50*cos(theta)**3 - 6.7144569083683e+47*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl91_m25(theta, phi):
    return 6.83555559851118e-49*(1.0 - cos(theta)**2)**12.5*(3.63195459363034e+73*cos(theta)**66 - 4.30416718416413e+74*cos(theta)**64 + 2.42379917409913e+75*cos(theta)**62 - 8.63164639966376e+75*cos(theta)**60 + 2.18257344677212e+76*cos(theta)**58 - 4.17086000868707e+76*cos(theta)**56 + 6.26035517873109e+76*cos(theta)**54 - 7.57275423564174e+76*cos(theta)**52 + 7.5160719434588e+76*cos(theta)**50 - 6.200126687365e+76*cos(theta)**48 + 4.29063981800474e+76*cos(theta)**46 - 2.50751677675602e+76*cos(theta)**44 + 1.24324469120083e+76*cos(theta)**42 - 5.24465300893639e+75*cos(theta)**40 + 1.88517481427207e+75*cos(theta)**38 - 5.77463134829309e+74*cos(theta)**36 + 1.50580204860292e+74*cos(theta)**34 - 3.33499782576485e+73*cos(theta)**32 + 6.25154543302859e+72*cos(theta)**30 - 9.87086121004514e+71*cos(theta)**28 + 1.30461032776121e+71*cos(theta)**26 - 1.43194311557715e+70*cos(theta)**24 + 1.29240124231293e+69*cos(theta)**22 - 9.47460130035817e+67*cos(theta)**20 + 5.55609335514831e+66*cos(theta)**18 - 2.55663844612839e+65*cos(theta)**16 + 9.0075341613449e+63*cos(theta)**14 - 2.35338963158882e+62*cos(theta)**12 + 4.36793351194775e+60*cos(theta)**10 - 5.42226229069376e+58*cos(theta)**8 + 4.11445377071614e+56*cos(theta)**6 - 1.64534275021973e+54*cos(theta)**4 + 2.592451812321e+51*cos(theta)**2 - 6.7144569083683e+47)*cos(25*phi)

#@torch.jit.script
def Yl91_m26(theta, phi):
    return 7.77873401328519e-51*(1.0 - cos(theta)**2)**13*(2.39709003179602e+75*cos(theta)**65 - 2.75466699786504e+76*cos(theta)**63 + 1.50275548794146e+77*cos(theta)**61 - 5.17898783979826e+77*cos(theta)**59 + 1.26589259912783e+78*cos(theta)**57 - 2.33568160486476e+78*cos(theta)**55 + 3.38059179651479e+78*cos(theta)**53 - 3.93783220253371e+78*cos(theta)**51 + 3.7580359717294e+78*cos(theta)**49 - 2.9760608099352e+78*cos(theta)**47 + 1.97369431628218e+78*cos(theta)**45 - 1.10330738177265e+78*cos(theta)**43 + 5.2216277030435e+77*cos(theta)**41 - 2.09786120357456e+77*cos(theta)**39 + 7.16366429423386e+76*cos(theta)**37 - 2.07886728538551e+76*cos(theta)**35 + 5.11972696524991e+75*cos(theta)**33 - 1.06719930424475e+75*cos(theta)**31 + 1.87546362990858e+74*cos(theta)**29 - 2.76384113881264e+73*cos(theta)**27 + 3.39198685217915e+72*cos(theta)**25 - 3.43666347738515e+71*cos(theta)**23 + 2.84328273308844e+70*cos(theta)**21 - 1.89492026007163e+69*cos(theta)**19 + 1.0000968039267e+68*cos(theta)**17 - 4.09062151380543e+66*cos(theta)**15 + 1.26105478258829e+65*cos(theta)**13 - 2.82406755790658e+63*cos(theta)**11 + 4.36793351194775e+61*cos(theta)**9 - 4.33780983255501e+59*cos(theta)**7 + 2.46867226242968e+57*cos(theta)**5 - 6.58137100087892e+54*cos(theta)**3 + 5.184903624642e+51*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl91_m27(theta, phi):
    return 8.88200962506307e-53*(1.0 - cos(theta)**2)**13.5*(1.55810852066742e+77*cos(theta)**64 - 1.73544020865498e+78*cos(theta)**62 + 9.16680847644292e+78*cos(theta)**60 - 3.05560282548097e+79*cos(theta)**58 + 7.21558781502864e+79*cos(theta)**56 - 1.28462488267562e+80*cos(theta)**54 + 1.79171365215284e+80*cos(theta)**52 - 2.00829442329219e+80*cos(theta)**50 + 1.84143762614741e+80*cos(theta)**48 - 1.39874858066954e+80*cos(theta)**46 + 8.88162442326981e+79*cos(theta)**44 - 4.74422174162238e+79*cos(theta)**42 + 2.14086735824784e+79*cos(theta)**40 - 8.18165869394077e+78*cos(theta)**38 + 2.65055578886653e+78*cos(theta)**36 - 7.27603549884929e+77*cos(theta)**34 + 1.68950989853247e+77*cos(theta)**32 - 3.30831784315873e+76*cos(theta)**30 + 5.43884452673487e+75*cos(theta)**28 - 7.46237107479412e+74*cos(theta)**26 + 8.47996713044787e+73*cos(theta)**24 - 7.90432599798585e+72*cos(theta)**22 + 5.97089373948572e+71*cos(theta)**20 - 3.6003484941361e+70*cos(theta)**18 + 1.70016456667538e+69*cos(theta)**16 - 6.13593227070815e+67*cos(theta)**14 + 1.63937121736477e+66*cos(theta)**12 - 3.10647431369724e+64*cos(theta)**10 + 3.93114016075298e+62*cos(theta)**8 - 3.03646688278851e+60*cos(theta)**6 + 1.23433613121484e+58*cos(theta)**4 - 1.97441130026367e+55*cos(theta)**2 + 5.184903624642e+51)*cos(27*phi)

#@torch.jit.script
def Yl91_m28(theta, phi):
    return 1.01776560923568e-54*(1.0 - cos(theta)**2)**14*(9.97189453227146e+78*cos(theta)**63 - 1.07597292936609e+80*cos(theta)**61 + 5.50008508586575e+80*cos(theta)**59 - 1.77224963877896e+81*cos(theta)**57 + 4.04072917641604e+81*cos(theta)**55 - 6.93697436644834e+81*cos(theta)**53 + 9.31691099119475e+81*cos(theta)**51 - 1.0041472116461e+82*cos(theta)**49 + 8.83890060550755e+81*cos(theta)**47 - 6.4342434710799e+81*cos(theta)**45 + 3.90791474623871e+81*cos(theta)**43 - 1.9925731314814e+81*cos(theta)**41 + 8.56346943299134e+80*cos(theta)**39 - 3.10903030369749e+80*cos(theta)**37 + 9.5420008399195e+79*cos(theta)**35 - 2.47385206960876e+79*cos(theta)**33 + 5.40643167530391e+78*cos(theta)**31 - 9.92495352947618e+77*cos(theta)**29 + 1.52287646748576e+77*cos(theta)**27 - 1.94021647944647e+76*cos(theta)**25 + 2.03519211130749e+75*cos(theta)**23 - 1.73895171955689e+74*cos(theta)**21 + 1.19417874789714e+73*cos(theta)**19 - 6.48062728944499e+71*cos(theta)**17 + 2.72026330668061e+70*cos(theta)**15 - 8.59030517899141e+68*cos(theta)**13 + 1.96724546083773e+67*cos(theta)**11 - 3.10647431369724e+65*cos(theta)**9 + 3.14491212860238e+63*cos(theta)**7 - 1.8218801296731e+61*cos(theta)**5 + 4.93734452485936e+58*cos(theta)**3 - 3.94882260052735e+55*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl91_m29(theta, phi):
    return 1.17054165736105e-56*(1.0 - cos(theta)**2)**14.5*(6.28229355533102e+80*cos(theta)**62 - 6.56343486913313e+81*cos(theta)**60 + 3.24505020066079e+82*cos(theta)**58 - 1.01018229410401e+83*cos(theta)**56 + 2.22240104702882e+83*cos(theta)**54 - 3.67659641421762e+83*cos(theta)**52 + 4.75162460550932e+83*cos(theta)**50 - 4.92032133706587e+83*cos(theta)**48 + 4.15428328458855e+83*cos(theta)**46 - 2.89540956198596e+83*cos(theta)**44 + 1.68040334088265e+83*cos(theta)**42 - 8.16954983907374e+82*cos(theta)**40 + 3.33975307886662e+82*cos(theta)**38 - 1.15034121236807e+82*cos(theta)**36 + 3.33970029397182e+81*cos(theta)**34 - 8.1637118297089e+80*cos(theta)**32 + 1.67599381934421e+80*cos(theta)**30 - 2.87823652354809e+79*cos(theta)**28 + 4.11176646221156e+78*cos(theta)**26 - 4.85054119861618e+77*cos(theta)**24 + 4.68094185600722e+76*cos(theta)**22 - 3.65179861106946e+75*cos(theta)**20 + 2.26893962100457e+74*cos(theta)**18 - 1.10170663920565e+73*cos(theta)**16 + 4.08039496002092e+71*cos(theta)**14 - 1.11673967326888e+70*cos(theta)**12 + 2.1639700069215e+68*cos(theta)**10 - 2.79582688232752e+66*cos(theta)**8 + 2.20143849002167e+64*cos(theta)**6 - 9.10940064836552e+61*cos(theta)**4 + 1.48120335745781e+59*cos(theta)**2 - 3.94882260052735e+55)*cos(29*phi)

#@torch.jit.script
def Yl91_m30(theta, phi):
    return 1.35144490130788e-58*(1.0 - cos(theta)**2)**15*(3.89502200430523e+82*cos(theta)**61 - 3.93806092147988e+83*cos(theta)**59 + 1.88212911638326e+84*cos(theta)**57 - 5.65702084698245e+84*cos(theta)**55 + 1.20009656539556e+85*cos(theta)**53 - 1.91183013539316e+85*cos(theta)**51 + 2.37581230275466e+85*cos(theta)**49 - 2.36175424179162e+85*cos(theta)**47 + 1.91097031091073e+85*cos(theta)**45 - 1.27398020727382e+85*cos(theta)**43 + 7.05769403170712e+84*cos(theta)**41 - 3.2678199356295e+84*cos(theta)**39 + 1.26910616996932e+84*cos(theta)**37 - 4.14122836452506e+83*cos(theta)**35 + 1.13549809995042e+83*cos(theta)**33 - 2.61238778550685e+82*cos(theta)**31 + 5.02798145803264e+81*cos(theta)**29 - 8.05906226593466e+80*cos(theta)**27 + 1.06905928017501e+80*cos(theta)**25 - 1.16412988766788e+79*cos(theta)**23 + 1.02980720832159e+78*cos(theta)**21 - 7.30359722213893e+76*cos(theta)**19 + 4.08409131780823e+75*cos(theta)**17 - 1.76273062272904e+74*cos(theta)**15 + 5.71255294402928e+72*cos(theta)**13 - 1.34008760792266e+71*cos(theta)**11 + 2.1639700069215e+69*cos(theta)**9 - 2.23666150586201e+67*cos(theta)**7 + 1.320863094013e+65*cos(theta)**5 - 3.64376025934621e+62*cos(theta)**3 + 2.96240671491562e+59*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl91_m31(theta, phi):
    return 1.56658336740129e-60*(1.0 - cos(theta)**2)**15.5*(2.37596342262619e+84*cos(theta)**60 - 2.32345594367313e+85*cos(theta)**58 + 1.07281359633846e+86*cos(theta)**56 - 3.11136146584035e+86*cos(theta)**54 + 6.36051179659648e+86*cos(theta)**52 - 9.75033369050513e+86*cos(theta)**50 + 1.16414802834978e+87*cos(theta)**48 - 1.11002449364206e+87*cos(theta)**46 + 8.59936639909829e+86*cos(theta)**44 - 5.47811489127743e+86*cos(theta)**42 + 2.89365455299992e+86*cos(theta)**40 - 1.2744497748955e+86*cos(theta)**38 + 4.69569282888647e+85*cos(theta)**36 - 1.44942992758377e+85*cos(theta)**34 + 3.74714372983639e+84*cos(theta)**32 - 8.09840213507123e+83*cos(theta)**30 + 1.45811462282946e+83*cos(theta)**28 - 2.17594681180236e+82*cos(theta)**26 + 2.67264820043752e+81*cos(theta)**24 - 2.67749874163613e+80*cos(theta)**22 + 2.16259513747534e+79*cos(theta)**20 - 1.3876834722064e+78*cos(theta)**18 + 6.94295524027399e+76*cos(theta)**16 - 2.64409593409355e+75*cos(theta)**14 + 7.42631882723807e+73*cos(theta)**12 - 1.47409636871493e+72*cos(theta)**10 + 1.94757300622935e+70*cos(theta)**8 - 1.56566305410341e+68*cos(theta)**6 + 6.604315470065e+65*cos(theta)**4 - 1.09312807780386e+63*cos(theta)**2 + 2.96240671491562e+59)*cos(31*phi)

#@torch.jit.script
def Yl91_m32(theta, phi):
    return 1.82358214106964e-62*(1.0 - cos(theta)**2)**16*(1.42557805357572e+86*cos(theta)**59 - 1.34760444733041e+87*cos(theta)**57 + 6.00775613949536e+87*cos(theta)**55 - 1.68013519155379e+88*cos(theta)**53 + 3.30746613423017e+88*cos(theta)**51 - 4.87516684525257e+88*cos(theta)**49 + 5.58791053607896e+88*cos(theta)**47 - 5.10611267075347e+88*cos(theta)**45 + 3.78372121560325e+88*cos(theta)**43 - 2.30080825433652e+88*cos(theta)**41 + 1.15746182119997e+88*cos(theta)**39 - 4.84290914460291e+87*cos(theta)**37 + 1.69044941839913e+87*cos(theta)**35 - 4.92806175378482e+86*cos(theta)**33 + 1.19908599354764e+86*cos(theta)**31 - 2.42952064052137e+85*cos(theta)**29 + 4.0827209439225e+84*cos(theta)**27 - 5.65746171068613e+83*cos(theta)**25 + 6.41435568105004e+82*cos(theta)**23 - 5.89049723159949e+81*cos(theta)**21 + 4.32519027495067e+80*cos(theta)**19 - 2.49783024997151e+79*cos(theta)**17 + 1.11087283844384e+78*cos(theta)**15 - 3.70173430773098e+76*cos(theta)**13 + 8.91158259268568e+74*cos(theta)**11 - 1.47409636871493e+73*cos(theta)**9 + 1.55805840498348e+71*cos(theta)**7 - 9.39397832462046e+68*cos(theta)**5 + 2.641726188026e+66*cos(theta)**3 - 2.18625615560773e+63*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl91_m33(theta, phi):
    return 2.13200629156353e-64*(1.0 - cos(theta)**2)**16.5*(8.41091051609672e+87*cos(theta)**58 - 7.68134534978336e+88*cos(theta)**56 + 3.30426587672245e+89*cos(theta)**54 - 8.90471651523508e+89*cos(theta)**52 + 1.68680772845739e+90*cos(theta)**50 - 2.38883175417376e+90*cos(theta)**48 + 2.62631795195711e+90*cos(theta)**46 - 2.29775070183906e+90*cos(theta)**44 + 1.6270001227094e+90*cos(theta)**42 - 9.43331384277973e+89*cos(theta)**40 + 4.51410110267987e+89*cos(theta)**38 - 1.79187638350308e+89*cos(theta)**36 + 5.91657296439695e+88*cos(theta)**34 - 1.62626037874899e+88*cos(theta)**32 + 3.7171665799977e+87*cos(theta)**30 - 7.04560985751197e+86*cos(theta)**28 + 1.10233465485907e+86*cos(theta)**26 - 1.41436542767153e+85*cos(theta)**24 + 1.47530180664151e+84*cos(theta)**22 - 1.23700441863589e+83*cos(theta)**20 + 8.21786152240628e+81*cos(theta)**18 - 4.24631142495157e+80*cos(theta)**16 + 1.66630925766576e+79*cos(theta)**14 - 4.81225460005027e+77*cos(theta)**12 + 9.80274085195425e+75*cos(theta)**10 - 1.32668673184343e+74*cos(theta)**8 + 1.09064088348844e+72*cos(theta)**6 - 4.69698916231023e+69*cos(theta)**4 + 7.925178564078e+66*cos(theta)**2 - 2.18625615560773e+63)*cos(33*phi)

#@torch.jit.script
def Yl91_m34(theta, phi):
    return 2.50391440507732e-66*(1.0 - cos(theta)**2)**17*(4.8783280993361e+89*cos(theta)**57 - 4.30155339587868e+90*cos(theta)**55 + 1.78430357343012e+91*cos(theta)**53 - 4.63045258792224e+91*cos(theta)**51 + 8.43403864228694e+91*cos(theta)**49 - 1.1466392420034e+92*cos(theta)**47 + 1.20810625790027e+92*cos(theta)**45 - 1.01101030880919e+92*cos(theta)**43 + 6.83340051537947e+91*cos(theta)**41 - 3.77332553711189e+91*cos(theta)**39 + 1.71535841901835e+91*cos(theta)**37 - 6.45075498061108e+90*cos(theta)**35 + 2.01163480789496e+90*cos(theta)**33 - 5.20403321199677e+89*cos(theta)**31 + 1.11514997399931e+89*cos(theta)**29 - 1.97277076010335e+88*cos(theta)**27 + 2.86607010263359e+87*cos(theta)**25 - 3.39447702641168e+86*cos(theta)**23 + 3.24566397461132e+85*cos(theta)**21 - 2.47400883727179e+84*cos(theta)**19 + 1.47921507403313e+83*cos(theta)**17 - 6.79409827992252e+81*cos(theta)**15 + 2.33283296073206e+80*cos(theta)**13 - 5.77470552006032e+78*cos(theta)**11 + 9.80274085195425e+76*cos(theta)**9 - 1.06134938547475e+75*cos(theta)**7 + 6.54384530093061e+72*cos(theta)**5 - 1.87879566492409e+70*cos(theta)**3 + 1.5850357128156e+67*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl91_m35(theta, phi):
    return 2.95458697044207e-68*(1.0 - cos(theta)**2)**17.5*(2.78064701662158e+91*cos(theta)**56 - 2.36585436773327e+92*cos(theta)**54 + 9.45680893917965e+92*cos(theta)**52 - 2.36153081984034e+93*cos(theta)**50 + 4.1326789347206e+93*cos(theta)**48 - 5.389204437416e+93*cos(theta)**46 + 5.43647816055122e+93*cos(theta)**44 - 4.34734432787951e+93*cos(theta)**42 + 2.80169421130558e+93*cos(theta)**40 - 1.47159695947364e+93*cos(theta)**38 + 6.3468261503679e+92*cos(theta)**36 - 2.25776424321388e+92*cos(theta)**34 + 6.63839486605338e+91*cos(theta)**32 - 1.613250295719e+91*cos(theta)**30 + 3.23393492459799e+90*cos(theta)**28 - 5.32648105227905e+89*cos(theta)**26 + 7.16517525658399e+88*cos(theta)**24 - 7.80729716074686e+87*cos(theta)**22 + 6.81589434668377e+86*cos(theta)**20 - 4.70061679081639e+85*cos(theta)**18 + 2.51466562585632e+84*cos(theta)**16 - 1.01911474198838e+83*cos(theta)**14 + 3.03268284895168e+81*cos(theta)**12 - 6.35217607206636e+79*cos(theta)**10 + 8.82246676675883e+77*cos(theta)**8 - 7.42944569832322e+75*cos(theta)**6 + 3.27192265046531e+73*cos(theta)**4 - 5.63638699477228e+70*cos(theta)**2 + 1.5850357128156e+67)*cos(35*phi)

#@torch.jit.script
def Yl91_m36(theta, phi):
    return 3.50349017807627e-70*(1.0 - cos(theta)**2)**18*(1.55716232930808e+93*cos(theta)**55 - 1.27756135857597e+94*cos(theta)**53 + 4.91754064837342e+94*cos(theta)**51 - 1.18076540992017e+95*cos(theta)**49 + 1.98368588866589e+95*cos(theta)**47 - 2.47903404121136e+95*cos(theta)**45 + 2.39205039064254e+95*cos(theta)**43 - 1.82588461770939e+95*cos(theta)**41 + 1.12067768452223e+95*cos(theta)**39 - 5.59206844599983e+94*cos(theta)**37 + 2.28485741413244e+94*cos(theta)**35 - 7.67639842692719e+93*cos(theta)**33 + 2.12428635713708e+93*cos(theta)**31 - 4.839750887157e+92*cos(theta)**29 + 9.05501778887438e+91*cos(theta)**27 - 1.38488507359255e+91*cos(theta)**25 + 1.71964206158016e+90*cos(theta)**23 - 1.71760537536431e+89*cos(theta)**21 + 1.36317886933675e+88*cos(theta)**19 - 8.46111022346951e+86*cos(theta)**17 + 4.02346500137011e+85*cos(theta)**15 - 1.42676063878373e+84*cos(theta)**13 + 3.63921941874202e+82*cos(theta)**11 - 6.35217607206636e+80*cos(theta)**9 + 7.05797341340706e+78*cos(theta)**7 - 4.45766741899393e+76*cos(theta)**5 + 1.30876906018612e+74*cos(theta)**3 - 1.12727739895446e+71*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl91_m37(theta, phi):
    return 4.17555852073138e-72*(1.0 - cos(theta)**2)**18.5*(8.56439281119445e+94*cos(theta)**54 - 6.77107520045263e+95*cos(theta)**52 + 2.50794573067044e+96*cos(theta)**50 - 5.78575050860884e+96*cos(theta)**48 + 9.32332367672967e+96*cos(theta)**46 - 1.11556531854511e+97*cos(theta)**44 + 1.02858166797629e+97*cos(theta)**42 - 7.48612693260851e+96*cos(theta)**40 + 4.37064296963671e+96*cos(theta)**38 - 2.06906532501994e+96*cos(theta)**36 + 7.99700094946356e+95*cos(theta)**34 - 2.53321148088597e+95*cos(theta)**32 + 6.58528770712496e+94*cos(theta)**30 - 1.40352775727553e+94*cos(theta)**28 + 2.44485480299608e+93*cos(theta)**26 - 3.46221268398138e+92*cos(theta)**24 + 3.95517674163436e+91*cos(theta)**22 - 3.60697128826505e+90*cos(theta)**20 + 2.59003985173983e+89*cos(theta)**18 - 1.43838873798982e+88*cos(theta)**16 + 6.03519750205517e+86*cos(theta)**14 - 1.85478883041885e+85*cos(theta)**12 + 4.00314136061622e+83*cos(theta)**10 - 5.71695846485972e+81*cos(theta)**8 + 4.94058138938494e+79*cos(theta)**6 - 2.22883370949697e+77*cos(theta)**4 + 3.92630718055837e+74*cos(theta)**2 - 1.12727739895446e+71)*cos(37*phi)

#@torch.jit.script
def Yl91_m38(theta, phi):
    return 5.00291172181902e-74*(1.0 - cos(theta)**2)**19*(4.624772118045e+96*cos(theta)**53 - 3.52095910423537e+97*cos(theta)**51 + 1.25397286533522e+98*cos(theta)**49 - 2.77716024413224e+98*cos(theta)**47 + 4.28872889129565e+98*cos(theta)**45 - 4.90848740159849e+98*cos(theta)**43 + 4.32004300550042e+98*cos(theta)**41 - 2.99445077304341e+98*cos(theta)**39 + 1.66084432846195e+98*cos(theta)**37 - 7.44863517007177e+97*cos(theta)**35 + 2.71898032281761e+97*cos(theta)**33 - 8.10627673883511e+96*cos(theta)**31 + 1.97558631213749e+96*cos(theta)**29 - 3.92987772037148e+95*cos(theta)**27 + 6.35662248778982e+94*cos(theta)**25 - 8.30931044155532e+93*cos(theta)**23 + 8.70138883159559e+92*cos(theta)**21 - 7.2139425765301e+91*cos(theta)**19 + 4.6620717331317e+90*cos(theta)**17 - 2.30142198078371e+89*cos(theta)**15 + 8.44927650287724e+87*cos(theta)**13 - 2.22574659650262e+86*cos(theta)**11 + 4.00314136061622e+84*cos(theta)**9 - 4.57356677188778e+82*cos(theta)**7 + 2.96434883363097e+80*cos(theta)**5 - 8.91533483798787e+77*cos(theta)**3 + 7.85261436111674e+74*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl91_m39(theta, phi):
    return 6.02716705137558e-76*(1.0 - cos(theta)**2)**19.5*(2.45112922256385e+98*cos(theta)**52 - 1.79568914316004e+99*cos(theta)**50 + 6.14446704014259e+99*cos(theta)**48 - 1.30526531474215e+100*cos(theta)**46 + 1.92992800108304e+100*cos(theta)**44 - 2.11064958268735e+100*cos(theta)**42 + 1.77121763225517e+100*cos(theta)**40 - 1.16783580148693e+100*cos(theta)**38 + 6.14512401530921e+99*cos(theta)**36 - 2.60702230952512e+99*cos(theta)**34 + 8.97263506529811e+98*cos(theta)**32 - 2.51294578903888e+98*cos(theta)**30 + 5.72920030519871e+97*cos(theta)**28 - 1.0610669845003e+97*cos(theta)**26 + 1.58915562194745e+96*cos(theta)**24 - 1.91114140155772e+95*cos(theta)**22 + 1.82729165463507e+94*cos(theta)**20 - 1.37064908954072e+93*cos(theta)**18 + 7.92552194632389e+91*cos(theta)**16 - 3.45213297117556e+90*cos(theta)**14 + 1.09840594537404e+89*cos(theta)**12 - 2.44832125615288e+87*cos(theta)**10 + 3.6028272245546e+85*cos(theta)**8 - 3.20149674032144e+83*cos(theta)**6 + 1.48217441681548e+81*cos(theta)**4 - 2.67460045139636e+78*cos(theta)**2 + 7.85261436111674e+74)*cos(39*phi)

#@torch.jit.script
def Yl91_m40(theta, phi):
    return 7.30257303341627e-78*(1.0 - cos(theta)**2)**20*(1.2745871957332e+100*cos(theta)**51 - 8.97844571580019e+100*cos(theta)**49 + 2.94934417926844e+101*cos(theta)**47 - 6.00422044781391e+101*cos(theta)**45 + 8.49168320476539e+101*cos(theta)**43 - 8.86472824728687e+101*cos(theta)**41 + 7.0848705290207e+101*cos(theta)**39 - 4.43777604565033e+101*cos(theta)**37 + 2.21224464551132e+101*cos(theta)**35 - 8.86387585238541e+100*cos(theta)**33 + 2.8712432208954e+100*cos(theta)**31 - 7.53883736711665e+99*cos(theta)**29 + 1.60417608545564e+99*cos(theta)**27 - 2.75877415970078e+98*cos(theta)**25 + 3.81397349267389e+97*cos(theta)**23 - 4.20451108342699e+96*cos(theta)**21 + 3.65458330927015e+95*cos(theta)**19 - 2.46716836117329e+94*cos(theta)**17 + 1.26808351141182e+93*cos(theta)**15 - 4.83298615964578e+91*cos(theta)**13 + 1.31808713444885e+90*cos(theta)**11 - 2.44832125615288e+88*cos(theta)**9 + 2.88226177964368e+86*cos(theta)**7 - 1.92089804419287e+84*cos(theta)**5 + 5.92869766726193e+81*cos(theta)**3 - 5.34920090279272e+78*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl91_m41(theta, phi):
    return 8.90028380751955e-80*(1.0 - cos(theta)**2)**20.5*(6.50039469823934e+101*cos(theta)**50 - 4.39943840074209e+102*cos(theta)**48 + 1.38619176425617e+103*cos(theta)**46 - 2.70189920151626e+103*cos(theta)**44 + 3.65142377804912e+103*cos(theta)**42 - 3.63453858138762e+103*cos(theta)**40 + 2.76309950631807e+103*cos(theta)**38 - 1.64197713689062e+103*cos(theta)**36 + 7.7428562592896e+102*cos(theta)**34 - 2.92507903128718e+102*cos(theta)**32 + 8.90085398477572e+101*cos(theta)**30 - 2.18626283646383e+101*cos(theta)**28 + 4.33127543073023e+100*cos(theta)**26 - 6.89693539925195e+99*cos(theta)**24 + 8.77213903314995e+98*cos(theta)**22 - 8.82947327519668e+97*cos(theta)**20 + 6.94370828761328e+96*cos(theta)**18 - 4.1941862139946e+95*cos(theta)**16 + 1.90212526711773e+94*cos(theta)**14 - 6.28288200753952e+92*cos(theta)**12 + 1.44989584789373e+91*cos(theta)**10 - 2.20348913053759e+89*cos(theta)**8 + 2.01758324575057e+87*cos(theta)**6 - 9.60449022096433e+84*cos(theta)**4 + 1.77860930017858e+82*cos(theta)**2 - 5.34920090279272e+78)*cos(41*phi)

#@torch.jit.script
def Yl91_m42(theta, phi):
    return 1.09142282699425e-81*(1.0 - cos(theta)**2)**21*(3.25019734911967e+103*cos(theta)**49 - 2.1117304323562e+104*cos(theta)**47 + 6.37648211557837e+104*cos(theta)**45 - 1.18883564866715e+105*cos(theta)**43 + 1.53359798678063e+105*cos(theta)**41 - 1.45381543255505e+105*cos(theta)**39 + 1.04997781240087e+105*cos(theta)**37 - 5.91111769280624e+104*cos(theta)**35 + 2.63257112815847e+104*cos(theta)**33 - 9.36025290011899e+103*cos(theta)**31 + 2.67025619543272e+103*cos(theta)**29 - 6.12153594209872e+102*cos(theta)**27 + 1.12613161198986e+102*cos(theta)**25 - 1.65526449582047e+101*cos(theta)**23 + 1.92987058729299e+100*cos(theta)**21 - 1.76589465503934e+99*cos(theta)**19 + 1.24986749177039e+98*cos(theta)**17 - 6.71069794239136e+96*cos(theta)**15 + 2.66297537396483e+95*cos(theta)**13 - 7.53945840904742e+93*cos(theta)**11 + 1.44989584789373e+92*cos(theta)**9 - 1.76279130443007e+90*cos(theta)**7 + 1.21054994745034e+88*cos(theta)**5 - 3.84179608838573e+85*cos(theta)**3 + 3.55721860035716e+82*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl91_m43(theta, phi):
    return 1.34692245599869e-83*(1.0 - cos(theta)**2)**21.5*(1.59259670106864e+105*cos(theta)**48 - 9.92513303207416e+105*cos(theta)**46 + 2.86941695201027e+106*cos(theta)**44 - 5.11199328926876e+106*cos(theta)**42 + 6.28775174580058e+106*cos(theta)**40 - 5.66988018696468e+106*cos(theta)**38 + 3.88491790588321e+106*cos(theta)**36 - 2.06889119248218e+106*cos(theta)**34 + 8.68748472292294e+105*cos(theta)**32 - 2.90167839903689e+105*cos(theta)**30 + 7.74374296675488e+104*cos(theta)**28 - 1.65281470436665e+104*cos(theta)**26 + 2.81532902997465e+103*cos(theta)**24 - 3.80710834038708e+102*cos(theta)**22 + 4.05272823331528e+101*cos(theta)**20 - 3.35519984457474e+100*cos(theta)**18 + 2.12477473600966e+99*cos(theta)**16 - 1.0066046913587e+98*cos(theta)**14 + 3.46186798615427e+96*cos(theta)**12 - 8.29340424995216e+94*cos(theta)**10 + 1.30490626310436e+93*cos(theta)**8 - 1.23395391310105e+91*cos(theta)**6 + 6.05274973725172e+88*cos(theta)**4 - 1.15253882651572e+86*cos(theta)**2 + 3.55721860035716e+82)*cos(43*phi)

#@torch.jit.script
def Yl91_m44(theta, phi):
    return 1.67322787335225e-85*(1.0 - cos(theta)**2)**22*(7.64446416512946e+106*cos(theta)**47 - 4.56556119475411e+107*cos(theta)**45 + 1.26254345888452e+108*cos(theta)**43 - 2.14703718149288e+108*cos(theta)**41 + 2.51510069832023e+108*cos(theta)**39 - 2.15455447104658e+108*cos(theta)**37 + 1.39857044611796e+108*cos(theta)**35 - 7.03423005443942e+107*cos(theta)**33 + 2.77999511133534e+107*cos(theta)**31 - 8.70503519711066e+106*cos(theta)**29 + 2.16824803069137e+106*cos(theta)**27 - 4.2973182313533e+105*cos(theta)**25 + 6.75678967193915e+104*cos(theta)**23 - 8.37563834885157e+103*cos(theta)**21 + 8.10545646663055e+102*cos(theta)**19 - 6.03935972023453e+101*cos(theta)**17 + 3.39963957761546e+100*cos(theta)**15 - 1.40924656790219e+99*cos(theta)**13 + 4.15424158338513e+97*cos(theta)**11 - 8.29340424995216e+95*cos(theta)**9 + 1.04392501048349e+94*cos(theta)**7 - 7.4037234786063e+91*cos(theta)**5 + 2.42109989490069e+89*cos(theta)**3 - 2.30507765303144e+86*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl91_m45(theta, phi):
    return 2.09284327775303e-87*(1.0 - cos(theta)**2)**22.5*(3.59289815761085e+108*cos(theta)**46 - 2.05450253763935e+109*cos(theta)**44 + 5.42893687320343e+109*cos(theta)**42 - 8.80285244412081e+109*cos(theta)**40 + 9.8088927234489e+109*cos(theta)**38 - 7.97185154287234e+109*cos(theta)**36 + 4.89499656141284e+109*cos(theta)**34 - 2.32129591796501e+109*cos(theta)**32 + 8.61798484513955e+108*cos(theta)**30 - 2.52446020716209e+108*cos(theta)**28 + 5.85426968286669e+107*cos(theta)**26 - 1.07432955783833e+107*cos(theta)**24 + 1.55406162454601e+106*cos(theta)**22 - 1.75888405325883e+105*cos(theta)**20 + 1.54003672865981e+104*cos(theta)**18 - 1.02669115243987e+103*cos(theta)**16 + 5.0994593664232e+101*cos(theta)**14 - 1.83202053827284e+100*cos(theta)**12 + 4.56966574172364e+98*cos(theta)**10 - 7.46406382495695e+96*cos(theta)**8 + 7.30747507338442e+94*cos(theta)**6 - 3.70186173930315e+92*cos(theta)**4 + 7.26329968470206e+89*cos(theta)**2 - 2.30507765303144e+86)*cos(45*phi)

#@torch.jit.script
def Yl91_m46(theta, phi):
    return 2.63631625886393e-89*(1.0 - cos(theta)**2)**23*(1.65273315250099e+110*cos(theta)**45 - 9.03981116561315e+110*cos(theta)**43 + 2.28015348674544e+111*cos(theta)**41 - 3.52114097764832e+111*cos(theta)**39 + 3.72737923491058e+111*cos(theta)**37 - 2.86986655543404e+111*cos(theta)**35 + 1.66429883088037e+111*cos(theta)**33 - 7.42814693748803e+110*cos(theta)**31 + 2.58539545354187e+110*cos(theta)**29 - 7.06848858005385e+109*cos(theta)**27 + 1.52211011754534e+109*cos(theta)**25 - 2.57839093881198e+108*cos(theta)**23 + 3.41893557400121e+107*cos(theta)**21 - 3.51776810651766e+106*cos(theta)**19 + 2.77206611158765e+105*cos(theta)**17 - 1.64270584390379e+104*cos(theta)**15 + 7.13924311299247e+102*cos(theta)**13 - 2.19842464592741e+101*cos(theta)**11 + 4.56966574172364e+99*cos(theta)**9 - 5.97125105996556e+97*cos(theta)**7 + 4.38448504403065e+95*cos(theta)**5 - 1.48074469572126e+93*cos(theta)**3 + 1.45265993694041e+90*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl91_m47(theta, phi):
    return 3.34542815794696e-91*(1.0 - cos(theta)**2)**23.5*(7.43729918625445e+111*cos(theta)**44 - 3.88711880121365e+112*cos(theta)**42 + 9.3486292956563e+112*cos(theta)**40 - 1.37324498128285e+113*cos(theta)**38 + 1.37913031691692e+113*cos(theta)**36 - 1.00445329440192e+113*cos(theta)**34 + 5.49218614190521e+112*cos(theta)**32 - 2.30272555062129e+112*cos(theta)**30 + 7.49764681527141e+111*cos(theta)**28 - 1.90849191661454e+111*cos(theta)**26 + 3.80527529386335e+110*cos(theta)**24 - 5.93029915926756e+109*cos(theta)**22 + 7.17976470540254e+108*cos(theta)**20 - 6.68375940238355e+107*cos(theta)**18 + 4.712512389699e+106*cos(theta)**16 - 2.46405876585569e+105*cos(theta)**14 + 9.28101604689022e+103*cos(theta)**12 - 2.41826711052015e+102*cos(theta)**10 + 4.11269916755128e+100*cos(theta)**8 - 4.17987574197589e+98*cos(theta)**6 + 2.19224252201533e+96*cos(theta)**4 - 4.44223408716378e+93*cos(theta)**2 + 1.45265993694041e+90)*cos(47*phi)

#@torch.jit.script
def Yl91_m48(theta, phi):
    return 4.27777531070406e-93*(1.0 - cos(theta)**2)**24*(3.27241164195196e+113*cos(theta)**43 - 1.63258989650973e+114*cos(theta)**41 + 3.73945171826252e+114*cos(theta)**39 - 5.21833092887482e+114*cos(theta)**37 + 4.9648691409009e+114*cos(theta)**35 - 3.41514120096651e+114*cos(theta)**33 + 1.75749956540967e+114*cos(theta)**31 - 6.90817665186387e+113*cos(theta)**29 + 2.099341108276e+113*cos(theta)**27 - 4.96207898319781e+112*cos(theta)**25 + 9.13266070527204e+111*cos(theta)**23 - 1.30466581503886e+111*cos(theta)**21 + 1.43595294108051e+110*cos(theta)**19 - 1.20307669242904e+109*cos(theta)**17 + 7.54001982351841e+107*cos(theta)**15 - 3.44968227219796e+106*cos(theta)**13 + 1.11372192562683e+105*cos(theta)**11 - 2.41826711052015e+103*cos(theta)**9 + 3.29015933404102e+101*cos(theta)**7 - 2.50792544518553e+99*cos(theta)**5 + 8.76897008806131e+96*cos(theta)**3 - 8.88446817432757e+93*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl91_m49(theta, phi):
    return 5.51340281912741e-95*(1.0 - cos(theta)**2)**24.5*(1.40713700603934e+115*cos(theta)**42 - 6.69361857568991e+115*cos(theta)**40 + 1.45838617012238e+116*cos(theta)**38 - 1.93078244368368e+116*cos(theta)**36 + 1.73770419931531e+116*cos(theta)**34 - 1.12699659631895e+116*cos(theta)**32 + 5.44824865276997e+115*cos(theta)**30 - 2.00337122904052e+115*cos(theta)**28 + 5.66822099234519e+114*cos(theta)**26 - 1.24051974579945e+114*cos(theta)**24 + 2.10051196221257e+113*cos(theta)**22 - 2.73979821158161e+112*cos(theta)**20 + 2.72831058805297e+111*cos(theta)**18 - 2.04523037712937e+110*cos(theta)**16 + 1.13100297352776e+109*cos(theta)**14 - 4.48458695385735e+107*cos(theta)**12 + 1.22509411818951e+106*cos(theta)**10 - 2.17644039946814e+104*cos(theta)**8 + 2.30311153382871e+102*cos(theta)**6 - 1.25396272259277e+100*cos(theta)**4 + 2.63069102641839e+97*cos(theta)**2 - 8.88446817432757e+93)*cos(49*phi)

#@torch.jit.script
def Yl91_m50(theta, phi):
    return 7.16449398582233e-97*(1.0 - cos(theta)**2)**25*(5.90997542536524e+116*cos(theta)**41 - 2.67744743027596e+117*cos(theta)**39 + 5.54186744646505e+117*cos(theta)**37 - 6.95081679726125e+117*cos(theta)**35 + 5.90819427767207e+117*cos(theta)**33 - 3.60638910822064e+117*cos(theta)**31 + 1.63447459583099e+117*cos(theta)**29 - 5.60943944131346e+116*cos(theta)**27 + 1.47373745800975e+116*cos(theta)**25 - 2.97724738991868e+115*cos(theta)**23 + 4.62112631686765e+114*cos(theta)**21 - 5.47959642316322e+113*cos(theta)**19 + 4.91095905849534e+112*cos(theta)**17 - 3.27236860340699e+111*cos(theta)**15 + 1.58340416293887e+110*cos(theta)**13 - 5.38150434462882e+108*cos(theta)**11 + 1.22509411818951e+107*cos(theta)**9 - 1.74115231957451e+105*cos(theta)**7 + 1.38186692029723e+103*cos(theta)**5 - 5.01585089037107e+100*cos(theta)**3 + 5.26138205283678e+97*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl91_m51(theta, phi):
    return 9.38965038251594e-99*(1.0 - cos(theta)**2)**25.5*(2.42308992439975e+118*cos(theta)**40 - 1.04420449780763e+119*cos(theta)**38 + 2.05049095519207e+119*cos(theta)**36 - 2.43278587904144e+119*cos(theta)**34 + 1.94970411163178e+119*cos(theta)**32 - 1.1179806235484e+119*cos(theta)**30 + 4.73997632790987e+118*cos(theta)**28 - 1.51454864915463e+118*cos(theta)**26 + 3.68434364502437e+117*cos(theta)**24 - 6.84766899681297e+116*cos(theta)**22 + 9.70436526542206e+115*cos(theta)**20 - 1.04112332040101e+115*cos(theta)**18 + 8.34863039944208e+113*cos(theta)**16 - 4.90855290511048e+112*cos(theta)**14 + 2.05842541182052e+111*cos(theta)**12 - 5.91965477909171e+109*cos(theta)**10 + 1.10258470637056e+108*cos(theta)**8 - 1.21880662370216e+106*cos(theta)**6 + 6.90933460148615e+103*cos(theta)**4 - 1.50475526711132e+101*cos(theta)**2 + 5.26138205283678e+97)*cos(51*phi)

#@torch.jit.script
def Yl91_m52(theta, phi):
    return 1.24151338891615e-100*(1.0 - cos(theta)**2)**26*(9.69235969759899e+119*cos(theta)**39 - 3.96797709166898e+120*cos(theta)**37 + 7.38176743869145e+120*cos(theta)**35 - 8.27147198874089e+120*cos(theta)**33 + 6.2390531572217e+120*cos(theta)**31 - 3.35394187064519e+120*cos(theta)**29 + 1.32719337181476e+120*cos(theta)**27 - 3.93782648780205e+119*cos(theta)**25 + 8.84242474805849e+118*cos(theta)**23 - 1.50648717929885e+118*cos(theta)**21 + 1.94087305308441e+117*cos(theta)**19 - 1.87402197672182e+116*cos(theta)**17 + 1.33578086391073e+115*cos(theta)**15 - 6.87197406715468e+113*cos(theta)**13 + 2.47011049418463e+112*cos(theta)**11 - 5.9196547790917e+110*cos(theta)**9 + 8.82067765096446e+108*cos(theta)**7 - 7.31283974221294e+106*cos(theta)**5 + 2.76373384059446e+104*cos(theta)**3 - 3.00951053422264e+101*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl91_m53(theta, phi):
    return 1.65667705742867e-102*(1.0 - cos(theta)**2)**26.5*(3.78002028206361e+121*cos(theta)**38 - 1.46815152391752e+122*cos(theta)**36 + 2.58361860354201e+122*cos(theta)**34 - 2.72958575628449e+122*cos(theta)**32 + 1.93410647873873e+122*cos(theta)**30 - 9.72643142487106e+121*cos(theta)**28 + 3.58342210389986e+121*cos(theta)**26 - 9.84456621950512e+120*cos(theta)**24 + 2.03375769205345e+120*cos(theta)**22 - 3.16362307652759e+119*cos(theta)**20 + 3.68765880086038e+118*cos(theta)**18 - 3.1858373604271e+117*cos(theta)**16 + 2.0036712958661e+116*cos(theta)**14 - 8.93356628730108e+114*cos(theta)**12 + 2.71712154360309e+113*cos(theta)**10 - 5.32768930118253e+111*cos(theta)**8 + 6.17447435567512e+109*cos(theta)**6 - 3.65641987110647e+107*cos(theta)**4 + 8.29120152178337e+104*cos(theta)**2 - 3.00951053422264e+101)*cos(53*phi)

#@torch.jit.script
def Yl91_m54(theta, phi):
    return 2.23183486914707e-104*(1.0 - cos(theta)**2)**27*(1.43640770718417e+123*cos(theta)**37 - 5.28534548610308e+123*cos(theta)**35 + 8.78430325204283e+123*cos(theta)**33 - 8.73467442011038e+123*cos(theta)**31 + 5.80231943621618e+123*cos(theta)**29 - 2.7234007989639e+123*cos(theta)**27 + 9.31689747013965e+122*cos(theta)**25 - 2.36269589268123e+122*cos(theta)**23 + 4.4742669225176e+121*cos(theta)**21 - 6.32724615305519e+120*cos(theta)**19 + 6.63778584154869e+119*cos(theta)**17 - 5.09733977668336e+118*cos(theta)**15 + 2.80513981421254e+117*cos(theta)**13 - 1.07202795447613e+116*cos(theta)**11 + 2.71712154360309e+114*cos(theta)**9 - 4.26215144094603e+112*cos(theta)**7 + 3.70468461340507e+110*cos(theta)**5 - 1.46256794844259e+108*cos(theta)**3 + 1.65824030435667e+105*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl91_m55(theta, phi):
    return 3.03658028879791e-106*(1.0 - cos(theta)**2)**27.5*(5.31470851658143e+124*cos(theta)**36 - 1.84987092013608e+125*cos(theta)**34 + 2.89882007317413e+125*cos(theta)**32 - 2.70774907023422e+125*cos(theta)**30 + 1.68267263650269e+125*cos(theta)**28 - 7.35318215720252e+124*cos(theta)**26 + 2.32922436753491e+124*cos(theta)**24 - 5.43420055316683e+123*cos(theta)**22 + 9.39596053728695e+122*cos(theta)**20 - 1.20217676908049e+122*cos(theta)**18 + 1.12842359306328e+121*cos(theta)**16 - 7.64600966502503e+119*cos(theta)**14 + 3.6466817584763e+118*cos(theta)**12 - 1.17923074992374e+117*cos(theta)**10 + 2.44540938924278e+115*cos(theta)**8 - 2.98350600866222e+113*cos(theta)**6 + 1.85234230670254e+111*cos(theta)**4 - 4.38770384532776e+108*cos(theta)**2 + 1.65824030435667e+105)*cos(55*phi)

#@torch.jit.script
def Yl91_m56(theta, phi):
    return 4.1742153503652e-108*(1.0 - cos(theta)**2)**28*(1.91329506596931e+126*cos(theta)**35 - 6.28956112846266e+126*cos(theta)**33 + 9.27622423415723e+126*cos(theta)**31 - 8.12324721070266e+126*cos(theta)**29 + 4.71148338220754e+126*cos(theta)**27 - 1.91182736087266e+126*cos(theta)**25 + 5.59013848208379e+125*cos(theta)**23 - 1.1955241216967e+125*cos(theta)**21 + 1.87919210745739e+124*cos(theta)**19 - 2.16391818434487e+123*cos(theta)**17 + 1.80547774890124e+122*cos(theta)**15 - 1.0704413531035e+121*cos(theta)**13 + 4.37601811017156e+119*cos(theta)**11 - 1.17923074992374e+118*cos(theta)**9 + 1.95632751139423e+116*cos(theta)**7 - 1.79010360519733e+114*cos(theta)**5 + 7.40936922681015e+111*cos(theta)**3 - 8.77540769065552e+108*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl91_m57(theta, phi):
    return 5.79975931321007e-110*(1.0 - cos(theta)**2)**28.5*(6.6965327308926e+127*cos(theta)**34 - 2.07555517239268e+128*cos(theta)**32 + 2.87562951258874e+128*cos(theta)**30 - 2.35574169110377e+128*cos(theta)**28 + 1.27210051319604e+128*cos(theta)**26 - 4.77956840218164e+127*cos(theta)**24 + 1.28573185087927e+127*cos(theta)**22 - 2.51060065556307e+126*cos(theta)**20 + 3.57046500416904e+125*cos(theta)**18 - 3.67866091338629e+124*cos(theta)**16 + 2.70821662335187e+123*cos(theta)**14 - 1.39157375903456e+122*cos(theta)**12 + 4.81361992118872e+120*cos(theta)**10 - 1.06130767493137e+119*cos(theta)**8 + 1.36942925797596e+117*cos(theta)**6 - 8.95051802598666e+114*cos(theta)**4 + 2.22281076804304e+112*cos(theta)**2 - 8.77540769065552e+108)*cos(57*phi)

#@torch.jit.script
def Yl91_m58(theta, phi):
    return 8.14849452781386e-112*(1.0 - cos(theta)**2)**29*(2.27682112850348e+129*cos(theta)**33 - 6.64177655165657e+129*cos(theta)**31 + 8.62688853776622e+129*cos(theta)**29 - 6.59607673509056e+129*cos(theta)**27 + 3.30746133430969e+129*cos(theta)**25 - 1.14709641652359e+129*cos(theta)**23 + 2.8286100719344e+128*cos(theta)**21 - 5.02120131112615e+127*cos(theta)**19 + 6.42683700750428e+126*cos(theta)**17 - 5.88585746141806e+125*cos(theta)**15 + 3.79150327269261e+124*cos(theta)**13 - 1.66988851084147e+123*cos(theta)**11 + 4.81361992118872e+121*cos(theta)**9 - 8.49046139945094e+119*cos(theta)**7 + 8.21657554785575e+117*cos(theta)**5 - 3.58020721039466e+115*cos(theta)**3 + 4.44562153608609e+112*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl91_m59(theta, phi):
    return 1.15817658036646e-113*(1.0 - cos(theta)**2)**29.5*(7.5135097240615e+130*cos(theta)**32 - 2.05895073101354e+131*cos(theta)**30 + 2.5017976759522e+131*cos(theta)**28 - 1.78094071847445e+131*cos(theta)**26 + 8.26865333577423e+130*cos(theta)**24 - 2.63832175800426e+130*cos(theta)**22 + 5.94008115106223e+129*cos(theta)**20 - 9.54028249113968e+128*cos(theta)**18 + 1.09256229127573e+128*cos(theta)**16 - 8.82878619212709e+126*cos(theta)**14 + 4.9289542545004e+125*cos(theta)**12 - 1.83687736192561e+124*cos(theta)**10 + 4.33225792906984e+122*cos(theta)**8 - 5.94332297961566e+120*cos(theta)**6 + 4.10828777392788e+118*cos(theta)**4 - 1.0740621631184e+116*cos(theta)**2 + 4.44562153608609e+112)*cos(59*phi)

#@torch.jit.script
def Yl91_m60(theta, phi):
    return 1.66613932894921e-115*(1.0 - cos(theta)**2)**30*(2.40432311169968e+132*cos(theta)**31 - 6.17685219304061e+132*cos(theta)**29 + 7.00503349266617e+132*cos(theta)**27 - 4.63044586803357e+132*cos(theta)**25 + 1.98447680058582e+132*cos(theta)**23 - 5.80430786760938e+131*cos(theta)**21 + 1.18801623021245e+131*cos(theta)**19 - 1.71725084840514e+130*cos(theta)**17 + 1.74809966604116e+129*cos(theta)**15 - 1.23603006689779e+128*cos(theta)**13 + 5.91474510540048e+126*cos(theta)**11 - 1.83687736192561e+125*cos(theta)**9 + 3.46580634325588e+123*cos(theta)**7 - 3.5659937877694e+121*cos(theta)**5 + 1.64331510957115e+119*cos(theta)**3 - 2.1481243262368e+116*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl91_m61(theta, phi):
    return 2.42721739041605e-117*(1.0 - cos(theta)**2)**30.5*(7.45340164626901e+133*cos(theta)**30 - 1.79128713598178e+134*cos(theta)**28 + 1.89135904301987e+134*cos(theta)**26 - 1.15761146700839e+134*cos(theta)**24 + 4.56429664134738e+133*cos(theta)**22 - 1.21890465219797e+133*cos(theta)**20 + 2.25723083740365e+132*cos(theta)**18 - 2.91932644228874e+131*cos(theta)**16 + 2.62214949906174e+130*cos(theta)**14 - 1.60683908696713e+129*cos(theta)**12 + 6.50621961594052e+127*cos(theta)**10 - 1.65318962573305e+126*cos(theta)**8 + 2.42606444027911e+124*cos(theta)**6 - 1.7829968938847e+122*cos(theta)**4 + 4.92994532871345e+119*cos(theta)**2 - 2.1481243262368e+116)*cos(61*phi)

#@torch.jit.script
def Yl91_m62(theta, phi):
    return 3.58263308565707e-119*(1.0 - cos(theta)**2)**31*(2.2360204938807e+135*cos(theta)**29 - 5.01560398074898e+135*cos(theta)**27 + 4.91753351185165e+135*cos(theta)**25 - 2.77826752082014e+135*cos(theta)**23 + 1.00414526109642e+135*cos(theta)**21 - 2.43780930439594e+134*cos(theta)**19 + 4.06301550732657e+133*cos(theta)**17 - 4.67092230766199e+132*cos(theta)**15 + 3.67100929868644e+131*cos(theta)**13 - 1.92820690436056e+130*cos(theta)**11 + 6.50621961594052e+128*cos(theta)**9 - 1.32255170058644e+127*cos(theta)**7 + 1.45563866416747e+125*cos(theta)**5 - 7.13198757553879e+122*cos(theta)**3 + 9.8598906574269e+119*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl91_m63(theta, phi):
    return 5.36096501313161e-121*(1.0 - cos(theta)**2)**31.5*(6.48445943225404e+136*cos(theta)**28 - 1.35421307480222e+137*cos(theta)**26 + 1.22938337796291e+137*cos(theta)**24 - 6.39001529788633e+136*cos(theta)**22 + 2.10870504830249e+136*cos(theta)**20 - 4.63183767835229e+135*cos(theta)**18 + 6.90712636245516e+134*cos(theta)**16 - 7.00638346149298e+133*cos(theta)**14 + 4.77231208829237e+132*cos(theta)**12 - 2.12102759479661e+131*cos(theta)**10 + 5.85559765434647e+129*cos(theta)**8 - 9.25786190410509e+127*cos(theta)**6 + 7.27819332083734e+125*cos(theta)**4 - 2.13959627266164e+123*cos(theta)**2 + 9.8598906574269e+119)*cos(63*phi)

#@torch.jit.script
def Yl91_m64(theta, phi):
    return 8.13763315945349e-123*(1.0 - cos(theta)**2)**32*(1.81564864103113e+138*cos(theta)**27 - 3.52095399448578e+138*cos(theta)**25 + 2.95052010711099e+138*cos(theta)**23 - 1.40580336553499e+138*cos(theta)**21 + 4.21741009660498e+137*cos(theta)**19 - 8.33730782103411e+136*cos(theta)**17 + 1.10514021799283e+136*cos(theta)**15 - 9.80893684609017e+134*cos(theta)**13 + 5.72677450595085e+133*cos(theta)**11 - 2.12102759479661e+132*cos(theta)**9 + 4.68447812347718e+130*cos(theta)**7 - 5.55471714246306e+128*cos(theta)**5 + 2.91127732833494e+126*cos(theta)**3 - 4.27919254532328e+123*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl91_m65(theta, phi):
    return 1.25387408621049e-124*(1.0 - cos(theta)**2)**32.5*(4.90225133078405e+139*cos(theta)**26 - 8.80238498621446e+139*cos(theta)**24 + 6.78619624635528e+139*cos(theta)**22 - 2.95218706762348e+139*cos(theta)**20 + 8.01307918354945e+138*cos(theta)**18 - 1.4173423295758e+138*cos(theta)**16 + 1.65771032698924e+137*cos(theta)**14 - 1.27516178999172e+136*cos(theta)**12 + 6.29945195654593e+134*cos(theta)**10 - 1.90892483531695e+133*cos(theta)**8 + 3.27913468643402e+131*cos(theta)**6 - 2.77735857123153e+129*cos(theta)**4 + 8.73383198500481e+126*cos(theta)**2 - 4.27919254532328e+123)*cos(65*phi)

#@torch.jit.script
def Yl91_m66(theta, phi):
    return 1.96253507230319e-126*(1.0 - cos(theta)**2)**33*(1.27458534600385e+141*cos(theta)**25 - 2.11257239669147e+141*cos(theta)**23 + 1.49296317419816e+141*cos(theta)**21 - 5.90437413524697e+140*cos(theta)**19 + 1.4423542530389e+140*cos(theta)**17 - 2.26774772732128e+139*cos(theta)**15 + 2.32079445778494e+138*cos(theta)**13 - 1.53019414799007e+137*cos(theta)**11 + 6.29945195654593e+135*cos(theta)**9 - 1.52713986825356e+134*cos(theta)**7 + 1.96748081186041e+132*cos(theta)**5 - 1.11094342849261e+130*cos(theta)**3 + 1.74676639700096e+127*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl91_m67(theta, phi):
    return 3.1226181444423e-128*(1.0 - cos(theta)**2)**33.5*(3.18646336500963e+142*cos(theta)**24 - 4.85891651239038e+142*cos(theta)**22 + 3.13522266581614e+142*cos(theta)**20 - 1.12183108569692e+142*cos(theta)**18 + 2.45200223016613e+141*cos(theta)**16 - 3.40162159098192e+140*cos(theta)**14 + 3.01703279512042e+139*cos(theta)**12 - 1.68321356278907e+138*cos(theta)**10 + 5.66950676089134e+136*cos(theta)**8 - 1.06899790777749e+135*cos(theta)**6 + 9.83740405930207e+132*cos(theta)**4 - 3.33283028547783e+130*cos(theta)**2 + 1.74676639700096e+127)*cos(67*phi)

#@torch.jit.script
def Yl91_m68(theta, phi):
    return 5.05492476206179e-130*(1.0 - cos(theta)**2)**34*(7.64751207602312e+143*cos(theta)**23 - 1.06896163272588e+144*cos(theta)**21 + 6.27044533163228e+143*cos(theta)**19 - 2.01929595425446e+143*cos(theta)**17 + 3.92320356826581e+142*cos(theta)**15 - 4.76227022737469e+141*cos(theta)**13 + 3.6204393541445e+140*cos(theta)**11 - 1.68321356278907e+139*cos(theta)**9 + 4.53560540871307e+137*cos(theta)**7 - 6.41398744666495e+135*cos(theta)**5 + 3.93496162372083e+133*cos(theta)**3 - 6.66566057095567e+130*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl91_m69(theta, phi):
    return 8.33279670647098e-132*(1.0 - cos(theta)**2)**34.5*(1.75892777748532e+145*cos(theta)**22 - 2.24481942872436e+145*cos(theta)**20 + 1.19138461301013e+145*cos(theta)**18 - 3.43280312223259e+144*cos(theta)**16 + 5.88480535239872e+143*cos(theta)**14 - 6.19095129558709e+142*cos(theta)**12 + 3.98248328955895e+141*cos(theta)**10 - 1.51489220651017e+140*cos(theta)**8 + 3.17492378609915e+138*cos(theta)**6 - 3.20699372333248e+136*cos(theta)**4 + 1.18048848711625e+134*cos(theta)**2 - 6.66566057095567e+130)*cos(69*phi)

#@torch.jit.script
def Yl91_m70(theta, phi):
    return 1.40012402603984e-133*(1.0 - cos(theta)**2)**35*(3.8696411104677e+146*cos(theta)**21 - 4.48963885744871e+146*cos(theta)**19 + 2.14449230341824e+146*cos(theta)**17 - 5.49248499557214e+145*cos(theta)**15 + 8.23872749335821e+144*cos(theta)**13 - 7.42914155470451e+143*cos(theta)**11 + 3.98248328955895e+142*cos(theta)**9 - 1.21191376520813e+141*cos(theta)**7 + 1.90495427165949e+139*cos(theta)**5 - 1.28279748933299e+137*cos(theta)**3 + 2.3609769742325e+134*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl91_m71(theta, phi):
    return 2.40048697311509e-135*(1.0 - cos(theta)**2)**35.5*(8.12624633198217e+147*cos(theta)**20 - 8.53031382915255e+147*cos(theta)**18 + 3.64563691581101e+147*cos(theta)**16 - 8.23872749335821e+146*cos(theta)**14 + 1.07103457413657e+146*cos(theta)**12 - 8.17205571017496e+144*cos(theta)**10 + 3.58423496060305e+143*cos(theta)**8 - 8.48339635645693e+141*cos(theta)**6 + 9.52477135829745e+139*cos(theta)**4 - 3.84839246799897e+137*cos(theta)**2 + 2.3609769742325e+134)*cos(71*phi)

#@torch.jit.script
def Yl91_m72(theta, phi):
    return 4.20426956083568e-137*(1.0 - cos(theta)**2)**36*(1.62524926639643e+149*cos(theta)**19 - 1.53545648924746e+149*cos(theta)**17 + 5.83301906529761e+148*cos(theta)**15 - 1.15342184907015e+148*cos(theta)**13 + 1.28524148896388e+147*cos(theta)**11 - 8.17205571017496e+145*cos(theta)**9 + 2.86738796848244e+144*cos(theta)**7 - 5.09003781387416e+142*cos(theta)**5 + 3.80990854331898e+140*cos(theta)**3 - 7.69678493599794e+137*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl91_m73(theta, phi):
    return 7.5316794655501e-139*(1.0 - cos(theta)**2)**36.5*(3.08797360615322e+150*cos(theta)**18 - 2.61027603172068e+150*cos(theta)**16 + 8.74952859794642e+149*cos(theta)**14 - 1.49944840379119e+149*cos(theta)**12 + 1.41376563786027e+148*cos(theta)**10 - 7.35485013915747e+146*cos(theta)**8 + 2.00717157793771e+145*cos(theta)**6 - 2.54501890693708e+143*cos(theta)**4 + 1.14297256299569e+141*cos(theta)**2 - 7.69678493599794e+137)*cos(73*phi)

#@torch.jit.script
def Yl91_m74(theta, phi):
    return 1.38201769701949e-140*(1.0 - cos(theta)**2)**37*(5.5583524910758e+151*cos(theta)**17 - 4.17644165075309e+151*cos(theta)**15 + 1.2249340037125e+151*cos(theta)**13 - 1.79933808454943e+150*cos(theta)**11 + 1.41376563786027e+149*cos(theta)**9 - 5.88388011132597e+147*cos(theta)**7 + 1.20430294676263e+146*cos(theta)**5 - 1.01800756277483e+144*cos(theta)**3 + 2.28594512599139e+141*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl91_m75(theta, phi):
    return 2.60156750632951e-142*(1.0 - cos(theta)**2)**37.5*(9.44919923482887e+152*cos(theta)**16 - 6.26466247612963e+152*cos(theta)**14 + 1.59241420482625e+152*cos(theta)**12 - 1.97927189300438e+151*cos(theta)**10 + 1.27238907407424e+150*cos(theta)**8 - 4.11871607792818e+148*cos(theta)**6 + 6.02151473381313e+146*cos(theta)**4 - 3.0540226883245e+144*cos(theta)**2 + 2.28594512599139e+141)*cos(75*phi)

#@torch.jit.script
def Yl91_m76(theta, phi):
    return 5.03288344350919e-144*(1.0 - cos(theta)**2)**38*(1.51187187757262e+154*cos(theta)**15 - 8.77052746658149e+153*cos(theta)**13 + 1.9108970457915e+153*cos(theta)**11 - 1.97927189300438e+152*cos(theta)**9 + 1.01791125925939e+151*cos(theta)**7 - 2.47122964675691e+149*cos(theta)**5 + 2.40860589352525e+147*cos(theta)**3 - 6.10804537664899e+144*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl91_m77(theta, phi):
    return 1.0025743798546e-145*(1.0 - cos(theta)**2)**38.5*(2.26780781635893e+155*cos(theta)**14 - 1.14016857065559e+155*cos(theta)**12 + 2.10198675037065e+154*cos(theta)**10 - 1.78134470370394e+153*cos(theta)**8 + 7.12537881481575e+151*cos(theta)**6 - 1.23561482337845e+150*cos(theta)**4 + 7.22581768057576e+147*cos(theta)**2 - 6.10804537664899e+144)*cos(77*phi)

#@torch.jit.script
def Yl91_m78(theta, phi):
    return 2.06114826053476e-147*(1.0 - cos(theta)**2)**39*(3.1749309429025e+156*cos(theta)**13 - 1.36820228478671e+156*cos(theta)**11 + 2.10198675037065e+155*cos(theta)**9 - 1.42507576296315e+154*cos(theta)**7 + 4.27522728888945e+152*cos(theta)**5 - 4.94245929351382e+150*cos(theta)**3 + 1.44516353611515e+148*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl91_m79(theta, phi):
    return 4.38442954177759e-149*(1.0 - cos(theta)**2)**39.5*(4.12741022577325e+157*cos(theta)**12 - 1.50502251326538e+157*cos(theta)**10 + 1.89178807533358e+156*cos(theta)**8 - 9.97553034074205e+154*cos(theta)**6 + 2.13761364444473e+153*cos(theta)**4 - 1.48273778805415e+151*cos(theta)**2 + 1.44516353611515e+148)*cos(79*phi)

#@torch.jit.script
def Yl91_m80(theta, phi):
    return 9.67886465892713e-151*(1.0 - cos(theta)**2)**40*(4.9528922709279e+158*cos(theta)**11 - 1.50502251326538e+158*cos(theta)**9 + 1.51343046026687e+157*cos(theta)**7 - 5.98531820444523e+155*cos(theta)**5 + 8.5504545777789e+153*cos(theta)**3 - 2.96547557610829e+151*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl91_m81(theta, phi):
    return 2.2251733557883e-152*(1.0 - cos(theta)**2)**40.5*(5.44818149802069e+159*cos(theta)**10 - 1.35452026193884e+159*cos(theta)**8 + 1.05940132218681e+158*cos(theta)**6 - 2.99265910222262e+156*cos(theta)**4 + 2.56513637333367e+154*cos(theta)**2 - 2.96547557610829e+151)*cos(81*phi)

#@torch.jit.script
def Yl91_m82(theta, phi):
    return 5.3498400728677e-154*(1.0 - cos(theta)**2)**41*(5.44818149802069e+160*cos(theta)**9 - 1.08361620955108e+160*cos(theta)**7 + 6.35640793312084e+158*cos(theta)**5 - 1.19706364088905e+157*cos(theta)**3 + 5.13027274666734e+154*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl91_m83(theta, phi):
    return 1.35190109756701e-155*(1.0 - cos(theta)**2)**41.5*(4.90336334821862e+161*cos(theta)**8 - 7.58531346685753e+160*cos(theta)**6 + 3.17820396656042e+159*cos(theta)**4 - 3.59119092266714e+157*cos(theta)**2 + 5.13027274666734e+154)*cos(83*phi)

#@torch.jit.script
def Yl91_m84(theta, phi):
    return 3.61310766278528e-157*(1.0 - cos(theta)**2)**42*(3.9226906785749e+162*cos(theta)**7 - 4.55118808011452e+161*cos(theta)**5 + 1.27128158662417e+160*cos(theta)**3 - 7.18238184533428e+157*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl91_m85(theta, phi):
    return 1.02937958015436e-158*(1.0 - cos(theta)**2)**42.5*(2.74588347500243e+163*cos(theta)**6 - 2.27559404005726e+162*cos(theta)**4 + 3.8138447598725e+160*cos(theta)**2 - 7.18238184533428e+157)*cos(85*phi)

#@torch.jit.script
def Yl91_m86(theta, phi):
    return 3.15873571224314e-160*(1.0 - cos(theta)**2)**43*(1.64753008500146e+164*cos(theta)**5 - 9.10237616022904e+162*cos(theta)**3 + 7.627689519745e+160*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl91_m87(theta, phi):
    return 1.05881061636435e-161*(1.0 - cos(theta)**2)**43.5*(8.23765042500728e+164*cos(theta)**4 - 2.73071284806871e+163*cos(theta)**2 + 7.627689519745e+160)*cos(87*phi)

#@torch.jit.script
def Yl91_m88(theta, phi):
    return 3.95696105624512e-163*(1.0 - cos(theta)**2)**44*(3.29506017000291e+165*cos(theta)**3 - 5.46142569613742e+163*cos(theta))*cos(88*phi)

#@torch.jit.script
def Yl91_m89(theta, phi):
    return 1.70280491915874e-164*(1.0 - cos(theta)**2)**44.5*(9.88518051000874e+165*cos(theta)**2 - 5.46142569613742e+163)*cos(89*phi)

#@torch.jit.script
def Yl91_m90(theta, phi):
    return 17.6939669099597*(1.0 - cos(theta)**2)**45*cos(90*phi)*cos(theta)

#@torch.jit.script
def Yl91_m91(theta, phi):
    return 1.31156408810318*(1.0 - cos(theta)**2)**45.5*cos(91*phi)

#@torch.jit.script
def Yl92_m_minus_92(theta, phi):
    return 1.31512329162961*(1.0 - cos(theta)**2)**46*sin(92*phi)

#@torch.jit.script
def Yl92_m_minus_91(theta, phi):
    return 17.8392002646519*(1.0 - cos(theta)**2)**45.5*sin(91*phi)*cos(theta)

#@torch.jit.script
def Yl92_m_minus_90(theta, phi):
    return 9.43300867924983e-167*(1.0 - cos(theta)**2)**45*(1.8089880333316e+168*cos(theta)**2 - 9.88518051000874e+165)*sin(90*phi)

#@torch.jit.script
def Yl92_m_minus_89(theta, phi):
    return 2.20417745196638e-165*(1.0 - cos(theta)**2)**44.5*(6.02996011110533e+167*cos(theta)**3 - 9.88518051000874e+165*cos(theta))*sin(89*phi)

#@torch.jit.script
def Yl92_m_minus_88(theta, phi):
    return 5.93083495435852e-164*(1.0 - cos(theta)**2)**44*(1.50749002777633e+167*cos(theta)**4 - 4.94259025500437e+165*cos(theta)**2 + 1.36535642403436e+163)*sin(88*phi)

#@torch.jit.script
def Yl92_m_minus_87(theta, phi):
    return 1.77925048630756e-162*(1.0 - cos(theta)**2)**43.5*(3.01498005555266e+166*cos(theta)**5 - 1.64753008500146e+165*cos(theta)**3 + 1.36535642403436e+163*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl92_m_minus_86(theta, phi):
    return 5.83094887879286e-161*(1.0 - cos(theta)**2)**43*(5.02496675925444e+165*cos(theta)**6 - 4.11882521250364e+164*cos(theta)**4 + 6.82678212017178e+162*cos(theta)**2 - 1.27128158662417e+160)*sin(86*phi)

#@torch.jit.script
def Yl92_m_minus_85(theta, phi):
    return 2.05825062066215e-159*(1.0 - cos(theta)**2)**42.5*(7.17852394179206e+164*cos(theta)**7 - 8.23765042500728e+163*cos(theta)**5 + 2.27559404005726e+162*cos(theta)**3 - 1.27128158662417e+160*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl92_m_minus_84(theta, phi):
    return 7.74515086639239e-158*(1.0 - cos(theta)**2)**42*(8.97315492724007e+163*cos(theta)**8 - 1.37294173750121e+163*cos(theta)**6 + 5.68898510014315e+161*cos(theta)**4 - 6.35640793312084e+159*cos(theta)**2 + 8.97797730666785e+156)*sin(84*phi)

#@torch.jit.script
def Yl92_m_minus_83(theta, phi):
    return 3.08253112422235e-156*(1.0 - cos(theta)**2)**41.5*(9.97017214137786e+162*cos(theta)**9 - 1.96134533928745e+162*cos(theta)**7 + 1.13779702002863e+161*cos(theta)**5 - 2.11880264437361e+159*cos(theta)**3 + 8.97797730666785e+156*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl92_m_minus_82(theta, phi):
    return 1.28951528609199e-154*(1.0 - cos(theta)**2)**41*(9.97017214137786e+161*cos(theta)**10 - 2.45168167410931e+161*cos(theta)**8 + 1.89632836671438e+160*cos(theta)**6 - 5.29700661093403e+158*cos(theta)**4 + 4.48898865333392e+156*cos(theta)**2 - 5.13027274666734e+153)*sin(82*phi)

#@torch.jit.script
def Yl92_m_minus_81(theta, phi):
    return 5.64153726766583e-153*(1.0 - cos(theta)**2)**40.5*(9.06379285579805e+160*cos(theta)**11 - 2.72409074901034e+160*cos(theta)**9 + 2.70904052387769e+159*cos(theta)**7 - 1.05940132218681e+158*cos(theta)**5 + 1.49632955111131e+156*cos(theta)**3 - 5.13027274666734e+153*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl92_m_minus_80(theta, phi):
    return 2.57046169264107e-151*(1.0 - cos(theta)**2)**40*(7.55316071316504e+159*cos(theta)**12 - 2.72409074901034e+159*cos(theta)**10 + 3.38630065484711e+158*cos(theta)**8 - 1.76566887031134e+157*cos(theta)**6 + 3.74082387777827e+155*cos(theta)**4 - 2.56513637333367e+153*cos(theta)**2 + 2.47122964675691e+150)*sin(80*phi)

#@torch.jit.script
def Yl92_m_minus_79(theta, phi):
    return 1.21547781257485e-149*(1.0 - cos(theta)**2)**39.5*(5.81012362551157e+158*cos(theta)**13 - 2.47644613546395e+158*cos(theta)**11 + 3.76255628316346e+157*cos(theta)**9 - 2.52238410044478e+156*cos(theta)**7 + 7.48164775555654e+154*cos(theta)**5 - 8.5504545777789e+152*cos(theta)**3 + 2.47122964675691e+150*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl92_m_minus_78(theta, phi):
    return 5.94715296002301e-148*(1.0 - cos(theta)**2)**39*(4.15008830393684e+157*cos(theta)**14 - 2.06370511288662e+157*cos(theta)**12 + 3.76255628316346e+156*cos(theta)**10 - 3.15298012555597e+155*cos(theta)**8 + 1.24694129259276e+154*cos(theta)**6 - 2.13761364444473e+152*cos(theta)**4 + 1.23561482337845e+150*cos(theta)**2 - 1.03225966865368e+147)*sin(78*phi)

#@torch.jit.script
def Yl92_m_minus_77(theta, phi):
    return 3.00316503444735e-146*(1.0 - cos(theta)**2)**38.5*(2.76672553595789e+156*cos(theta)**15 - 1.58746547145125e+156*cos(theta)**13 + 3.42050571196678e+155*cos(theta)**11 - 3.50331125061775e+154*cos(theta)**9 + 1.78134470370394e+153*cos(theta)**7 - 4.27522728888945e+151*cos(theta)**5 + 4.11871607792818e+149*cos(theta)**3 - 1.03225966865368e+147*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl92_m_minus_76(theta, phi):
    return 1.56164581791262e-144*(1.0 - cos(theta)**2)**38*(1.72920345997368e+155*cos(theta)**16 - 1.13390390817946e+155*cos(theta)**14 + 2.85042142663898e+154*cos(theta)**12 - 3.50331125061775e+153*cos(theta)**10 + 2.22668087962992e+152*cos(theta)**8 - 7.12537881481575e+150*cos(theta)**6 + 1.02967901948205e+149*cos(theta)**4 - 5.1612983432684e+146*cos(theta)**2 + 3.81752836040562e+143)*sin(76*phi)

#@torch.jit.script
def Yl92_m_minus_75(theta, phi):
    return 8.34567837787017e-143*(1.0 - cos(theta)**2)**37.5*(1.01717850586687e+154*cos(theta)**17 - 7.55935938786309e+153*cos(theta)**15 + 2.19263186664537e+153*cos(theta)**13 - 3.1848284096525e+152*cos(theta)**11 + 2.47408986625547e+151*cos(theta)**9 - 1.01791125925939e+150*cos(theta)**7 + 2.05935803896409e+148*cos(theta)**5 - 1.72043278108947e+146*cos(theta)**3 + 3.81752836040562e+143*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl92_m_minus_74(theta, phi):
    return 4.57568513827241e-141*(1.0 - cos(theta)**2)**37*(5.6509916992604e+152*cos(theta)**18 - 4.72459961741443e+152*cos(theta)**16 + 1.56616561903241e+152*cos(theta)**14 - 2.65402367471041e+151*cos(theta)**12 + 2.47408986625547e+150*cos(theta)**10 - 1.27238907407424e+149*cos(theta)**8 + 3.43226339827348e+147*cos(theta)**6 - 4.30108195272366e+145*cos(theta)**4 + 1.90876418020281e+143*cos(theta)**2 - 1.26996951443966e+140)*sin(74*phi)

#@torch.jit.script
def Yl92_m_minus_73(theta, phi):
    return 2.56972693499622e-139*(1.0 - cos(theta)**2)**36.5*(2.97420615750547e+151*cos(theta)**19 - 2.7791762455379e+151*cos(theta)**17 + 1.04411041268827e+151*cos(theta)**15 - 2.04155667285416e+150*cos(theta)**13 + 2.24917260568679e+149*cos(theta)**11 - 1.41376563786027e+148*cos(theta)**9 + 4.90323342610498e+146*cos(theta)**7 - 8.60216390544733e+144*cos(theta)**5 + 6.3625472673427e+142*cos(theta)**3 - 1.26996951443966e+140*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl92_m_minus_72(theta, phi):
    return 1.47619573625819e-137*(1.0 - cos(theta)**2)**36*(1.48710307875274e+150*cos(theta)**20 - 1.54398680307661e+150*cos(theta)**18 + 6.5256900793017e+149*cos(theta)**16 - 1.4582547663244e+149*cos(theta)**14 + 1.87431050473899e+148*cos(theta)**12 - 1.41376563786027e+147*cos(theta)**10 + 6.12904178263122e+145*cos(theta)**8 - 1.43369398424122e+144*cos(theta)**6 + 1.59063681683567e+142*cos(theta)**4 - 6.3498475721983e+139*cos(theta)**2 + 3.84839246799897e+136)*sin(72*phi)

#@torch.jit.script
def Yl92_m_minus_71(theta, phi):
    return 8.66314369349615e-136*(1.0 - cos(theta)**2)**35.5*(7.08144323215589e+148*cos(theta)**21 - 8.12624633198217e+148*cos(theta)**19 + 3.83864122311865e+148*cos(theta)**17 - 9.72169844216269e+147*cos(theta)**15 + 1.44177731133769e+147*cos(theta)**13 - 1.28524148896388e+146*cos(theta)**11 + 6.8100464251458e+144*cos(theta)**9 - 2.04813426320174e+143*cos(theta)**7 + 3.18127363367135e+141*cos(theta)**5 - 2.11661585739943e+139*cos(theta)**3 + 3.84839246799897e+136*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl92_m_minus_70(theta, phi):
    return 5.18776936971783e-134*(1.0 - cos(theta)**2)**35*(3.21883783279813e+147*cos(theta)**22 - 4.06312316599108e+147*cos(theta)**20 + 2.13257845728814e+147*cos(theta)**18 - 6.07606152635168e+146*cos(theta)**16 + 1.02984093666978e+146*cos(theta)**14 - 1.07103457413657e+145*cos(theta)**12 + 6.8100464251458e+143*cos(theta)**10 - 2.56016782900218e+142*cos(theta)**8 + 5.30212272278558e+140*cos(theta)**6 - 5.29153964349858e+138*cos(theta)**4 + 1.92419623399949e+136*cos(theta)**2 - 1.07317135192386e+133)*sin(70*phi)

#@torch.jit.script
def Yl92_m_minus_69(theta, phi):
    return 3.16666473675985e-132*(1.0 - cos(theta)**2)**34.5*(1.39949470991223e+146*cos(theta)**23 - 1.93482055523385e+146*cos(theta)**21 + 1.12240971436218e+146*cos(theta)**19 - 3.5741538390304e+145*cos(theta)**17 + 6.86560624446517e+144*cos(theta)**15 - 8.23872749335821e+143*cos(theta)**13 + 6.19095129558709e+142*cos(theta)**11 - 2.84463092111353e+141*cos(theta)**9 + 7.57446103255083e+139*cos(theta)**7 - 1.05830792869972e+138*cos(theta)**5 + 6.41398744666495e+135*cos(theta)**3 - 1.07317135192386e+133*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl92_m_minus_68(theta, phi):
    return 1.9684330342856e-130*(1.0 - cos(theta)**2)**34*(5.83122795796763e+144*cos(theta)**24 - 8.79463888742659e+144*cos(theta)**22 + 5.61204857181089e+144*cos(theta)**20 - 1.98564102168356e+144*cos(theta)**18 + 4.29100390279073e+143*cos(theta)**16 - 5.88480535239872e+142*cos(theta)**14 + 5.15912607965591e+141*cos(theta)**12 - 2.84463092111353e+140*cos(theta)**10 + 9.46807629068854e+138*cos(theta)**8 - 1.76384654783286e+137*cos(theta)**6 + 1.60349686166624e+135*cos(theta)**4 - 5.36585675961931e+132*cos(theta)**2 + 2.77735857123153e+129)*sin(68*phi)

#@torch.jit.script
def Yl92_m_minus_67(theta, phi):
    return 1.24494636197176e-128*(1.0 - cos(theta)**2)**33.5*(2.33249118318705e+143*cos(theta)**25 - 3.82375603801156e+143*cos(theta)**23 + 2.67240408181471e+143*cos(theta)**21 - 1.04507422193871e+143*cos(theta)**19 + 2.52411994281808e+142*cos(theta)**17 - 3.92320356826581e+141*cos(theta)**15 + 3.96855852281224e+140*cos(theta)**13 - 2.58602811010321e+139*cos(theta)**11 + 1.05200847674317e+138*cos(theta)**9 - 2.51978078261837e+136*cos(theta)**7 + 3.20699372333248e+134*cos(theta)**5 - 1.7886189198731e+132*cos(theta)**3 + 2.77735857123153e+129*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl92_m_minus_66(theta, phi):
    return 8.00453073594444e-127*(1.0 - cos(theta)**2)**33*(8.97111993533482e+141*cos(theta)**26 - 1.59323168250482e+142*cos(theta)**24 + 1.2147291280976e+142*cos(theta)**22 - 5.22537110969357e+141*cos(theta)**20 + 1.40228885712115e+141*cos(theta)**18 - 2.45200223016613e+140*cos(theta)**16 + 2.8346846591516e+139*cos(theta)**14 - 2.15502342508601e+138*cos(theta)**12 + 1.05200847674317e+137*cos(theta)**10 - 3.14972597827297e+135*cos(theta)**8 + 5.34498953888746e+133*cos(theta)**6 - 4.47154729968276e+131*cos(theta)**4 + 1.38867928561576e+129*cos(theta)**2 - 6.71833229615754e+125)*sin(66*phi)

#@torch.jit.script
def Yl92_m_minus_65(theta, phi):
    return 5.22812908680753e-125*(1.0 - cos(theta)**2)**32.5*(3.32263701308697e+140*cos(theta)**27 - 6.37292673001927e+140*cos(theta)**25 + 5.28143099172867e+140*cos(theta)**23 - 2.48827195699694e+140*cos(theta)**21 + 7.38046766905871e+139*cos(theta)**19 - 1.4423542530389e+139*cos(theta)**17 + 1.88978977276773e+138*cos(theta)**15 - 1.65771032698924e+137*cos(theta)**13 + 9.56371342493792e+135*cos(theta)**11 - 3.49969553141441e+134*cos(theta)**9 + 7.6356993412678e+132*cos(theta)**7 - 8.94309459936552e+130*cos(theta)**5 + 4.62893095205255e+128*cos(theta)**3 - 6.71833229615754e+125*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl92_m_minus_64(theta, phi):
    return 3.46637180864413e-123*(1.0 - cos(theta)**2)**32*(1.18665607610249e+139*cos(theta)**28 - 2.45112566539203e+139*cos(theta)**26 + 2.20059624655361e+139*cos(theta)**24 - 1.13103270772588e+139*cos(theta)**22 + 3.69023383452935e+138*cos(theta)**20 - 8.01307918354946e+137*cos(theta)**18 + 1.18111860797983e+137*cos(theta)**16 - 1.18407880499231e+136*cos(theta)**14 + 7.96976118744827e+134*cos(theta)**12 - 3.49969553141441e+133*cos(theta)**10 + 9.54462417658475e+131*cos(theta)**8 - 1.49051576656092e+130*cos(theta)**6 + 1.15723273801314e+128*cos(theta)**4 - 3.35916614807877e+125*cos(theta)**2 + 1.52828305190117e+122)*sin(64*phi)

#@torch.jit.script
def Yl92_m_minus_63(theta, phi):
    return 2.33150548841968e-121*(1.0 - cos(theta)**2)**31.5*(4.09191750380168e+137*cos(theta)**29 - 9.07824320515565e+137*cos(theta)**27 + 8.80238498621446e+137*cos(theta)**25 - 4.91753351185165e+137*cos(theta)**23 + 1.75725420691874e+137*cos(theta)**21 - 4.21741009660498e+136*cos(theta)**19 + 6.94775651752843e+135*cos(theta)**17 - 7.89385869994876e+134*cos(theta)**15 + 6.13058552880636e+133*cos(theta)**13 - 3.18154139219492e+132*cos(theta)**11 + 1.06051379739831e+131*cos(theta)**9 - 2.12930823794417e+129*cos(theta)**7 + 2.31446547602627e+127*cos(theta)**5 - 1.11972204935959e+125*cos(theta)**3 + 1.52828305190117e+122*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl92_m_minus_62(theta, phi):
    return 1.58987477392937e-119*(1.0 - cos(theta)**2)**31*(1.36397250126723e+136*cos(theta)**30 - 3.24222971612702e+136*cos(theta)**28 + 3.38553268700556e+136*cos(theta)**26 - 2.04897229660486e+136*cos(theta)**24 + 7.98751912235791e+135*cos(theta)**22 - 2.10870504830249e+135*cos(theta)**20 + 3.85986473196024e+134*cos(theta)**18 - 4.93366168746797e+133*cos(theta)**16 + 4.37898966343311e+132*cos(theta)**14 - 2.65128449349576e+131*cos(theta)**12 + 1.06051379739831e+130*cos(theta)**10 - 2.66163529743021e+128*cos(theta)**8 + 3.85744246004379e+126*cos(theta)**6 - 2.79930512339898e+124*cos(theta)**4 + 7.64141525950585e+121*cos(theta)**2 - 3.2866302191423e+118)*sin(62*phi)

#@torch.jit.script
def Yl92_m_minus_61(theta, phi):
    return 1.09851028114502e-117*(1.0 - cos(theta)**2)**30.5*(4.39991129441041e+134*cos(theta)**31 - 1.11801024694035e+135*cos(theta)**29 + 1.25390099518724e+135*cos(theta)**27 - 8.19588918641942e+134*cos(theta)**25 + 3.47283440102518e+134*cos(theta)**23 - 1.00414526109642e+134*cos(theta)**21 + 2.03150775366328e+133*cos(theta)**19 - 2.90215393380469e+132*cos(theta)**17 + 2.91932644228874e+131*cos(theta)**15 - 2.03944961038136e+130*cos(theta)**13 + 9.64103452180278e+128*cos(theta)**11 - 2.95737255270024e+127*cos(theta)**9 + 5.51063208577684e+125*cos(theta)**7 - 5.59861024679795e+123*cos(theta)**5 + 2.54713841983528e+121*cos(theta)**3 - 3.2866302191423e+118*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl92_m_minus_60(theta, phi):
    return 7.68643272641954e-116*(1.0 - cos(theta)**2)**30*(1.37497227950325e+133*cos(theta)**32 - 3.7267008231345e+133*cos(theta)**30 + 4.47821783995445e+133*cos(theta)**28 - 3.15226507169978e+133*cos(theta)**26 + 1.44701433376049e+133*cos(theta)**24 - 4.56429664134738e+132*cos(theta)**22 + 1.01575387683164e+132*cos(theta)**20 - 1.61230774100261e+131*cos(theta)**18 + 1.82457902643046e+130*cos(theta)**16 - 1.45674972170097e+129*cos(theta)**14 + 8.03419543483565e+127*cos(theta)**12 - 2.95737255270024e+126*cos(theta)**10 + 6.88829010722105e+124*cos(theta)**8 - 9.33101707799659e+122*cos(theta)**6 + 6.36784604958821e+120*cos(theta)**4 - 1.64331510957115e+118*cos(theta)**2 + 6.71288851948999e+114)*sin(60*phi)

#@torch.jit.script
def Yl92_m_minus_59(theta, phi):
    return 5.44381796405602e-114*(1.0 - cos(theta)**2)**29.5*(4.16658266516138e+131*cos(theta)**33 - 1.20216155584984e+132*cos(theta)**31 + 1.54421304826015e+132*cos(theta)**29 - 1.16750558211103e+132*cos(theta)**27 + 5.78805733504196e+131*cos(theta)**25 - 1.98447680058582e+131*cos(theta)**23 + 4.83692322300782e+130*cos(theta)**21 - 8.48583021580319e+129*cos(theta)**19 + 1.07328178025321e+129*cos(theta)**17 - 9.71166481133979e+127*cos(theta)**15 + 6.18015033448896e+126*cos(theta)**13 - 2.68852050245476e+125*cos(theta)**11 + 7.65365567469006e+123*cos(theta)**9 - 1.3330024397138e+122*cos(theta)**7 + 1.27356920991764e+120*cos(theta)**5 - 5.47771703190383e+117*cos(theta)**3 + 6.71288851948999e+114*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl92_m_minus_58(theta, phi):
    return 3.90060098918551e-112*(1.0 - cos(theta)**2)**29*(1.22546548975335e+130*cos(theta)**34 - 3.75675486203075e+130*cos(theta)**32 + 5.14737682753385e+130*cos(theta)**30 - 4.16966279325367e+130*cos(theta)**28 + 2.22617589809306e+130*cos(theta)**26 - 8.26865333577423e+129*cos(theta)**24 + 2.19860146500355e+129*cos(theta)**22 - 4.24291510790159e+128*cos(theta)**20 + 5.9626765569623e+127*cos(theta)**18 - 6.06979050708737e+126*cos(theta)**16 + 4.41439309606354e+125*cos(theta)**14 - 2.24043375204564e+124*cos(theta)**12 + 7.65365567469006e+122*cos(theta)**10 - 1.66625304964225e+121*cos(theta)**8 + 2.12261534986274e+119*cos(theta)**6 - 1.36942925797596e+117*cos(theta)**4 + 3.356444259745e+114*cos(theta)**2 - 1.30753574590767e+111)*sin(58*phi)

#@torch.jit.script
def Yl92_m_minus_57(theta, phi):
    return 2.82625392354232e-110*(1.0 - cos(theta)**2)**28.5*(3.50132997072385e+128*cos(theta)**35 - 1.13841056425174e+129*cos(theta)**33 + 1.66044413791414e+129*cos(theta)**31 - 1.43781475629437e+129*cos(theta)**29 + 8.2450959188632e+128*cos(theta)**27 - 3.30746133430969e+128*cos(theta)**25 + 9.55913680436328e+127*cos(theta)**23 - 2.02043576566743e+127*cos(theta)**21 + 3.13825081945384e+126*cos(theta)**19 - 3.57046500416904e+125*cos(theta)**17 + 2.94292873070903e+124*cos(theta)**15 - 1.72341057849664e+123*cos(theta)**13 + 6.95786879517278e+121*cos(theta)**11 - 1.85139227738028e+120*cos(theta)**9 + 3.03230764266105e+118*cos(theta)**7 - 2.73885851595192e+116*cos(theta)**5 + 1.11881475324833e+114*cos(theta)**3 - 1.30753574590767e+111*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl92_m_minus_56(theta, phi):
    return 2.0699295421143e-108*(1.0 - cos(theta)**2)**28*(9.72591658534402e+126*cos(theta)**36 - 3.3482663654463e+127*cos(theta)**34 + 5.1888879309817e+127*cos(theta)**32 - 4.79271585431457e+127*cos(theta)**30 + 2.94467711387971e+127*cos(theta)**28 - 1.27210051319604e+127*cos(theta)**26 + 3.9829736684847e+126*cos(theta)**24 - 9.18379893485194e+125*cos(theta)**22 + 1.56912540972692e+125*cos(theta)**20 - 1.9835916689828e+124*cos(theta)**18 + 1.83933045669314e+123*cos(theta)**16 - 1.23100755606903e+122*cos(theta)**14 + 5.79822399597732e+120*cos(theta)**12 - 1.85139227738028e+119*cos(theta)**10 + 3.79038455332631e+117*cos(theta)**8 - 4.5647641932532e+115*cos(theta)**6 + 2.79703688312083e+113*cos(theta)**4 - 6.53767872953836e+110*cos(theta)**2 + 2.43761324740431e+107)*sin(56*phi)

#@torch.jit.script
def Yl92_m_minus_55(theta, phi):
    return 1.53174786116458e-106*(1.0 - cos(theta)**2)**27.5*(2.62862610414703e+125*cos(theta)**37 - 9.56647532984657e+125*cos(theta)**35 + 1.57239028211567e+126*cos(theta)**33 - 1.54603737235954e+126*cos(theta)**31 + 1.01540590133783e+126*cos(theta)**29 - 4.71148338220754e+125*cos(theta)**27 + 1.59318946739388e+125*cos(theta)**25 - 3.99295605863128e+124*cos(theta)**23 + 7.47202576060439e+123*cos(theta)**21 - 1.04399561525411e+123*cos(theta)**19 + 1.08195909217244e+122*cos(theta)**17 - 8.2067170404602e+120*cos(theta)**15 + 4.46017230459794e+119*cos(theta)**13 - 1.68308388852752e+118*cos(theta)**11 + 4.21153839258479e+116*cos(theta)**9 - 6.52109170464742e+114*cos(theta)**7 + 5.59407376624166e+112*cos(theta)**5 - 2.17922624317946e+110*cos(theta)**3 + 2.43761324740431e+107*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl92_m_minus_54(theta, phi):
    return 1.14482142432251e-104*(1.0 - cos(theta)**2)**27*(6.9174371161764e+123*cos(theta)**38 - 2.65735425829072e+124*cos(theta)**36 + 4.6246773003402e+124*cos(theta)**34 - 4.83136678862356e+124*cos(theta)**32 + 3.38468633779277e+124*cos(theta)**30 - 1.68267263650269e+124*cos(theta)**28 + 6.12765179766877e+123*cos(theta)**26 - 1.66373169109637e+123*cos(theta)**24 + 3.39637534572927e+122*cos(theta)**22 - 5.21997807627053e+121*cos(theta)**20 + 6.01088384540243e+120*cos(theta)**18 - 5.12919815028763e+119*cos(theta)**16 + 3.1858373604271e+118*cos(theta)**14 - 1.40256990710627e+117*cos(theta)**12 + 4.21153839258479e+115*cos(theta)**10 - 8.15136463080928e+113*cos(theta)**8 + 9.32345627706944e+111*cos(theta)**6 - 5.44806560794864e+109*cos(theta)**4 + 1.21880662370216e+107*cos(theta)**2 - 4.36379027462283e+103)*sin(54*phi)

#@torch.jit.script
def Yl92_m_minus_53(theta, phi):
    return 8.63866195477575e-103*(1.0 - cos(theta)**2)**26.5*(1.77370182466062e+122*cos(theta)**39 - 7.18203853592085e+122*cos(theta)**37 + 1.32133637152577e+123*cos(theta)**35 - 1.46405054200714e+123*cos(theta)**33 + 1.0918343025138e+123*cos(theta)**31 - 5.80231943621618e+122*cos(theta)**29 + 2.26950066580325e+122*cos(theta)**27 - 6.65492676438546e+121*cos(theta)**25 + 1.47668493292577e+121*cos(theta)**23 - 2.48570384584311e+120*cos(theta)**21 + 3.16362307652759e+119*cos(theta)**19 - 3.01717538252213e+118*cos(theta)**17 + 2.12389157361806e+117*cos(theta)**15 - 1.07889992854328e+116*cos(theta)**13 + 3.82867126598618e+114*cos(theta)**11 - 9.05707181201031e+112*cos(theta)**9 + 1.33192232529563e+111*cos(theta)**7 - 1.08961312158973e+109*cos(theta)**5 + 4.06268874567385e+106*cos(theta)**3 - 4.36379027462283e+103*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl92_m_minus_52(theta, phi):
    return 6.57900893858309e-101*(1.0 - cos(theta)**2)**26*(4.43425456165154e+120*cos(theta)**40 - 1.8900101410318e+121*cos(theta)**38 + 3.67037880979381e+121*cos(theta)**36 - 4.30603100590335e+121*cos(theta)**34 + 3.41198219535562e+121*cos(theta)**32 - 1.93410647873873e+121*cos(theta)**30 + 8.10535952072588e+120*cos(theta)**28 - 2.55958721707133e+120*cos(theta)**26 + 6.1528538871907e+119*cos(theta)**24 - 1.12986538447414e+119*cos(theta)**22 + 1.5818115382638e+118*cos(theta)**20 - 1.67620854584563e+117*cos(theta)**18 + 1.32743223351129e+116*cos(theta)**16 - 7.70642806102346e+114*cos(theta)**14 + 3.19055938832181e+113*cos(theta)**12 - 9.05707181201031e+111*cos(theta)**10 + 1.66490290661954e+110*cos(theta)**8 - 1.81602186931621e+108*cos(theta)**6 + 1.01567218641846e+106*cos(theta)**4 - 2.18189513731141e+103*cos(theta)**2 + 7.5237763355566e+99)*sin(52*phi)

#@torch.jit.script
def Yl92_m_minus_51(theta, phi):
    return 5.05514539115145e-99*(1.0 - cos(theta)**2)**25.5*(1.08152550284184e+119*cos(theta)**41 - 4.8461798487995e+119*cos(theta)**39 + 9.91994272917245e+119*cos(theta)**37 - 1.23029457311524e+120*cos(theta)**35 + 1.03393399859261e+120*cos(theta)**33 - 6.2390531572217e+119*cos(theta)**31 + 2.79495155887099e+119*cos(theta)**29 - 9.47995265581974e+118*cos(theta)**27 + 2.46114155487628e+118*cos(theta)**25 - 4.91245819336583e+117*cos(theta)**23 + 7.53243589649427e+116*cos(theta)**21 - 8.82215024129279e+115*cos(theta)**19 + 7.80842490300759e+114*cos(theta)**17 - 5.13761870734897e+113*cos(theta)**15 + 2.45427645255524e+112*cos(theta)**13 - 8.2337016472821e+110*cos(theta)**11 + 1.84989211846616e+109*cos(theta)**9 - 2.59431695616602e+107*cos(theta)**7 + 2.03134437283693e+105*cos(theta)**5 - 7.27298379103805e+102*cos(theta)**3 + 7.5237763355566e+99*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl92_m_minus_50(theta, phi):
    return 3.91765614269084e-97*(1.0 - cos(theta)**2)**25*(2.575060721052e+117*cos(theta)**42 - 1.21154496219987e+118*cos(theta)**40 + 2.61051124451906e+118*cos(theta)**38 - 3.41748492532012e+118*cos(theta)**36 + 3.0409823488018e+118*cos(theta)**34 - 1.94970411163178e+118*cos(theta)**32 + 9.31650519623665e+117*cos(theta)**30 - 3.38569737707848e+117*cos(theta)**28 + 9.46592905721646e+116*cos(theta)**26 - 2.04685758056909e+116*cos(theta)**24 + 3.42383449840649e+115*cos(theta)**22 - 4.41107512064639e+114*cos(theta)**20 + 4.33801383500422e+113*cos(theta)**18 - 3.21101169209311e+112*cos(theta)**16 + 1.75305460896803e+111*cos(theta)**14 - 6.86141803940175e+109*cos(theta)**12 + 1.84989211846616e+108*cos(theta)**10 - 3.24289619520752e+106*cos(theta)**8 + 3.38557395472821e+104*cos(theta)**6 - 1.81824594775951e+102*cos(theta)**4 + 3.7618881677783e+99*cos(theta)**2 - 1.25271001258019e+96)*sin(50*phi)

#@torch.jit.script
def Yl92_m_minus_49(theta, phi):
    return 3.06129170542975e-95*(1.0 - cos(theta)**2)**24.5*(5.98851330477209e+115*cos(theta)**43 - 2.95498771268262e+116*cos(theta)**41 + 6.69361857568991e+116*cos(theta)**39 - 9.23644574410842e+116*cos(theta)**37 + 8.68852099657657e+116*cos(theta)**35 - 5.90819427767207e+116*cos(theta)**33 + 3.00532425685053e+116*cos(theta)**31 - 1.16748185416499e+116*cos(theta)**29 + 3.50589965082091e+115*cos(theta)**27 - 8.18743032227638e+114*cos(theta)**25 + 1.48862369495934e+114*cos(theta)**23 - 2.10051196221257e+113*cos(theta)**21 + 2.28316517631801e+112*cos(theta)**19 - 1.88883040711359e+111*cos(theta)**17 + 1.16870307264535e+110*cos(theta)**15 - 5.27801387646288e+108*cos(theta)**13 + 1.68172010769651e+107*cos(theta)**11 - 3.60321799467502e+105*cos(theta)**9 + 4.8365342210403e+103*cos(theta)**7 - 3.63649189551902e+101*cos(theta)**5 + 1.25396272259277e+99*cos(theta)**3 - 1.25271001258019e+96*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl92_m_minus_48(theta, phi):
    return 2.41124094281695e-93*(1.0 - cos(theta)**2)**24*(1.36102575108456e+114*cos(theta)**44 - 7.03568503019671e+114*cos(theta)**42 + 1.67340464392248e+115*cos(theta)**40 - 2.43064361687064e+115*cos(theta)**38 + 2.4134780546046e+115*cos(theta)**36 - 1.73770419931531e+115*cos(theta)**34 + 9.39163830265791e+114*cos(theta)**32 - 3.89160618054998e+114*cos(theta)**30 + 1.25210701815033e+114*cos(theta)**28 - 3.14901166241399e+113*cos(theta)**26 + 6.20259872899726e+112*cos(theta)**24 - 9.54778164642076e+111*cos(theta)**22 + 1.141582588159e+111*cos(theta)**20 - 1.04935022617422e+110*cos(theta)**18 + 7.30439420403346e+108*cos(theta)**16 - 3.7700099117592e+107*cos(theta)**14 + 1.40143342308042e+106*cos(theta)**12 - 3.60321799467503e+104*cos(theta)**10 + 6.04566777630038e+102*cos(theta)**8 - 6.06081982586504e+100*cos(theta)**6 + 3.13490680648192e+98*cos(theta)**4 - 6.26355006290093e+95*cos(theta)**2 + 2.01919731234717e+92)*sin(48*phi)

#@torch.jit.script
def Yl92_m_minus_47(theta, phi):
    return 1.91386316572517e-91*(1.0 - cos(theta)**2)**23.5*(3.02450166907681e+112*cos(theta)**45 - 1.63620582097598e+113*cos(theta)**43 + 4.08147474127434e+113*cos(theta)**41 - 6.23241953043753e+113*cos(theta)**39 + 6.52291366109352e+113*cos(theta)**37 - 4.9648691409009e+113*cos(theta)**35 + 2.84595100080543e+113*cos(theta)**33 - 1.25535683243548e+113*cos(theta)**31 + 4.31761040741492e+112*cos(theta)**29 - 1.16630061570889e+112*cos(theta)**27 + 2.4810394915989e+111*cos(theta)**25 - 4.15120941148729e+110*cos(theta)**23 + 5.43610756266193e+109*cos(theta)**21 - 5.52289592723273e+108*cos(theta)**19 + 4.29670247296086e+107*cos(theta)**17 - 2.5133399411728e+106*cos(theta)**15 + 1.07802571006186e+105*cos(theta)**13 - 3.27565272243184e+103*cos(theta)**11 + 6.71740864033375e+101*cos(theta)**9 - 8.65831403695006e+99*cos(theta)**7 + 6.26981361296383e+97*cos(theta)**5 - 2.08785002096698e+95*cos(theta)**3 + 2.01919731234717e+92*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl92_m_minus_46(theta, phi):
    return 1.53037266560346e-89*(1.0 - cos(theta)**2)**23*(6.57500362842785e+110*cos(theta)**46 - 3.71864959312723e+111*cos(theta)**44 + 9.71779700303413e+111*cos(theta)**42 - 1.55810488260938e+112*cos(theta)**40 + 1.71655622660356e+112*cos(theta)**38 - 1.37913031691692e+112*cos(theta)**36 + 8.37044412001596e+111*cos(theta)**34 - 3.92299010136086e+111*cos(theta)**32 + 1.43920346913831e+111*cos(theta)**30 - 4.16535934181745e+110*cos(theta)**28 + 9.5424595830727e+109*cos(theta)**26 - 1.7296705881197e+109*cos(theta)**24 + 2.47095798302815e+108*cos(theta)**22 - 2.76144796361636e+107*cos(theta)**20 + 2.3870569294227e+106*cos(theta)**18 - 1.570837463233e+105*cos(theta)**16 + 7.70018364329903e+103*cos(theta)**14 - 2.72971060202653e+102*cos(theta)**12 + 6.71740864033375e+100*cos(theta)**10 - 1.08228925461876e+99*cos(theta)**8 + 1.04496893549397e+97*cos(theta)**6 - 5.21962505241744e+94*cos(theta)**4 + 1.00959865617359e+92*cos(theta)**2 - 3.15795638465307e+88)*sin(46*phi)

#@torch.jit.script
def Yl92_m_minus_45(theta, phi):
    return 1.23249643628823e-87*(1.0 - cos(theta)**2)**22.5*(1.39893694221869e+109*cos(theta)**47 - 8.26366576250495e+109*cos(theta)**45 + 2.25995279140329e+110*cos(theta)**43 - 3.8002558112424e+110*cos(theta)**41 + 4.4014262220604e+110*cos(theta)**39 - 3.72737923491058e+110*cos(theta)**37 + 2.3915554628617e+110*cos(theta)**35 - 1.18878487920026e+110*cos(theta)**33 + 4.64259183593002e+109*cos(theta)**31 - 1.43633080752326e+109*cos(theta)**29 + 3.53424429002693e+108*cos(theta)**27 - 6.91868235247882e+107*cos(theta)**25 + 1.07432955783833e+107*cos(theta)**23 - 1.3149752207697e+106*cos(theta)**21 + 1.25634575232774e+105*cos(theta)**19 - 9.24022037195883e+103*cos(theta)**17 + 5.13345576219935e+102*cos(theta)**15 - 2.09977738617426e+101*cos(theta)**13 + 6.10673512757614e+99*cos(theta)**11 - 1.20254361624306e+98*cos(theta)**9 + 1.49281276499139e+96*cos(theta)**7 - 1.04392501048349e+94*cos(theta)**5 + 3.36532885391196e+91*cos(theta)**3 - 3.15795638465307e+88*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl92_m_minus_44(theta, phi):
    return 9.9946266227838e-86*(1.0 - cos(theta)**2)**22*(2.91445196295561e+107*cos(theta)**48 - 1.79644907880542e+108*cos(theta)**46 + 5.13625634409838e+108*cos(theta)**44 - 9.04822812200571e+108*cos(theta)**42 + 1.1003565555151e+109*cos(theta)**40 - 9.8088927234489e+108*cos(theta)**38 + 6.64320961906029e+108*cos(theta)**36 - 3.49642611529489e+108*cos(theta)**34 + 1.45080994872813e+108*cos(theta)**32 - 4.78776935841086e+107*cos(theta)**30 + 1.26223010358105e+107*cos(theta)**28 - 2.66103167403031e+106*cos(theta)**26 + 4.47637315765969e+105*cos(theta)**24 - 5.97716009440771e+104*cos(theta)**22 + 6.28172876163868e+103*cos(theta)**20 - 5.13345576219935e+102*cos(theta)**18 + 3.20840985137459e+101*cos(theta)**16 - 1.49984099012447e+100*cos(theta)**14 + 5.08894593964678e+98*cos(theta)**12 - 1.20254361624306e+97*cos(theta)**10 + 1.86601595623924e+95*cos(theta)**8 - 1.73987501747248e+93*cos(theta)**6 + 8.41332213477989e+90*cos(theta)**4 - 1.57897819232654e+88*cos(theta)**2 + 4.80224511048216e+84)*sin(44*phi)

#@torch.jit.script
def Yl92_m_minus_43(theta, phi):
    return 8.15894618621495e-84*(1.0 - cos(theta)**2)**21.5*(5.94786114888899e+105*cos(theta)**49 - 3.82223208256473e+106*cos(theta)**47 + 1.14139029868853e+107*cos(theta)**45 - 2.10423909814086e+107*cos(theta)**43 + 2.6837964768661e+107*cos(theta)**41 - 2.51510069832023e+107*cos(theta)**39 + 1.79546205920548e+107*cos(theta)**37 - 9.98978890084254e+106*cos(theta)**35 + 4.39639378402464e+106*cos(theta)**33 - 1.54444172851963e+106*cos(theta)**31 + 4.35251759855533e+105*cos(theta)**29 - 9.85567286677894e+104*cos(theta)**27 + 1.79054926306388e+104*cos(theta)**25 - 2.59876525843814e+103*cos(theta)**23 + 2.99129941030413e+102*cos(theta)**21 - 2.70181882221018e+101*cos(theta)**19 + 1.88729991257329e+100*cos(theta)**17 - 9.99893993416313e+98*cos(theta)**15 + 3.91457379972829e+97*cos(theta)**13 - 1.09322146931188e+96*cos(theta)**11 + 2.07335106248804e+94*cos(theta)**9 - 2.4855357392464e+92*cos(theta)**7 + 1.68266442695598e+90*cos(theta)**5 - 5.26326064108845e+87*cos(theta)**3 + 4.80224511048216e+84*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl92_m_minus_42(theta, phi):
    return 6.70325830749101e-82*(1.0 - cos(theta)**2)**21*(1.1895722297778e+104*cos(theta)**50 - 7.96298350534319e+104*cos(theta)**48 + 2.48128325801854e+105*cos(theta)**46 - 4.78236158668378e+105*cos(theta)**44 + 6.38999161158595e+105*cos(theta)**42 - 6.28775174580058e+105*cos(theta)**40 + 4.7249001558039e+105*cos(theta)**38 - 2.77494136134515e+105*cos(theta)**36 + 1.29305699530136e+105*cos(theta)**34 - 4.82638040162385e+104*cos(theta)**32 + 1.45083919951844e+104*cos(theta)**30 - 3.51988316670676e+103*cos(theta)**28 + 6.88672793486106e+102*cos(theta)**26 - 1.08281885768256e+102*cos(theta)**24 + 1.35968155013824e+101*cos(theta)**22 - 1.35090941110509e+100*cos(theta)**20 + 1.04849995142961e+99*cos(theta)**18 - 6.24933745885195e+97*cos(theta)**16 + 2.79612414266307e+96*cos(theta)**14 - 9.1101789109323e+94*cos(theta)**12 + 2.07335106248804e+93*cos(theta)**10 - 3.106919674058e+91*cos(theta)**8 + 2.8044407115933e+89*cos(theta)**6 - 1.31581516027211e+87*cos(theta)**4 + 2.40112255524108e+84*cos(theta)**2 - 7.11443720071432e+80)*sin(42*phi)

#@torch.jit.script
def Yl92_m_minus_41(theta, phi):
    return 5.54145029768469e-80*(1.0 - cos(theta)**2)**20.5*(2.33249456819176e+102*cos(theta)**51 - 1.62509867455983e+103*cos(theta)**49 + 5.27932608089051e+103*cos(theta)**47 - 1.06274701926306e+104*cos(theta)**45 + 1.48604456083394e+104*cos(theta)**43 - 1.53359798678063e+104*cos(theta)**41 + 1.21151286046254e+104*cos(theta)**39 - 7.49984151714905e+103*cos(theta)**37 + 3.6944485580039e+103*cos(theta)**35 - 1.46253951564359e+103*cos(theta)**33 + 4.68012645005949e+102*cos(theta)**31 - 1.21375281610578e+102*cos(theta)**29 + 2.55063997587447e+101*cos(theta)**27 - 4.33127543073023e+100*cos(theta)**25 + 5.91165891364453e+99*cos(theta)**23 - 6.4329019576433e+98*cos(theta)**21 + 5.51842079699793e+97*cos(theta)**19 - 3.67608085814821e+96*cos(theta)**17 + 1.86408276177538e+95*cos(theta)**15 - 7.00782993148638e+93*cos(theta)**13 + 1.88486460226186e+92*cos(theta)**11 - 3.45213297117556e+90*cos(theta)**9 + 4.00634387370471e+88*cos(theta)**7 - 2.63163032054423e+86*cos(theta)**5 + 8.00374185080361e+83*cos(theta)**3 - 7.11443720071432e+80*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl92_m_minus_40(theta, phi):
    return 4.60840813529167e-78*(1.0 - cos(theta)**2)**20*(4.48556647729185e+100*cos(theta)**52 - 3.25019734911967e+101*cos(theta)**50 + 1.09985960018552e+102*cos(theta)**48 - 2.31031960709361e+102*cos(theta)**46 + 3.37737400189532e+102*cos(theta)**44 - 3.65142377804912e+102*cos(theta)**42 + 3.02878215115635e+102*cos(theta)**40 - 1.97364250451291e+102*cos(theta)**38 + 1.02623571055664e+102*cos(theta)**36 - 4.30158681071645e+101*cos(theta)**34 + 1.46253951564359e+101*cos(theta)**32 - 4.0458427203526e+100*cos(theta)**30 + 9.10942848526595e+99*cos(theta)**28 - 1.66587516566547e+99*cos(theta)**26 + 2.46319121401855e+98*cos(theta)**24 - 2.92404634438332e+97*cos(theta)**22 + 2.75921039849896e+96*cos(theta)**20 - 2.04226714341567e+95*cos(theta)**18 + 1.16505172610961e+94*cos(theta)**16 - 5.00559280820456e+92*cos(theta)**14 + 1.57072050188488e+91*cos(theta)**12 - 3.45213297117556e+89*cos(theta)**10 + 5.00792984213089e+87*cos(theta)**8 - 4.38605053424038e+85*cos(theta)**6 + 2.0009354627009e+83*cos(theta)**4 - 3.55721860035716e+80*cos(theta)**2 + 1.02869248130629e+77)*sin(40*phi)

#@torch.jit.script
def Yl92_m_minus_39(theta, phi):
    return 3.85456909508432e-76*(1.0 - cos(theta)**2)**19.5*(8.46333297602236e+98*cos(theta)**53 - 6.37293597866602e+99*cos(theta)**51 + 2.24461142895005e+100*cos(theta)**49 - 4.91557363211407e+100*cos(theta)**47 + 7.50527555976739e+100*cos(theta)**45 - 8.49168320476539e+100*cos(theta)**43 + 7.38727353940573e+100*cos(theta)**41 - 5.06062180644335e+100*cos(theta)**39 + 2.77361002853145e+100*cos(theta)**37 - 1.22902480306184e+100*cos(theta)**35 + 4.4319379261927e+99*cos(theta)**33 - 1.30511055495245e+99*cos(theta)**31 + 3.1411822362986e+98*cos(theta)**29 - 6.16990802098323e+97*cos(theta)**27 + 9.85276485607422e+96*cos(theta)**25 - 1.27132449755796e+96*cos(theta)**23 + 1.31390971357093e+95*cos(theta)**21 - 1.07487744390299e+94*cos(theta)**19 + 6.8532454477036e+92*cos(theta)**17 - 3.33706187213637e+91*cos(theta)**15 + 1.20824653991145e+90*cos(theta)**13 - 3.13830270106869e+88*cos(theta)**11 + 5.56436649125654e+86*cos(theta)**9 - 6.26578647748625e+84*cos(theta)**7 + 4.0018709254018e+82*cos(theta)**5 - 1.18573953345239e+80*cos(theta)**3 + 1.02869248130629e+77*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl92_m_minus_38(theta, phi):
    return 3.24196530482212e-74*(1.0 - cos(theta)**2)**19*(1.56728388444859e+97*cos(theta)**54 - 1.22556461128193e+98*cos(theta)**52 + 4.48922285790009e+98*cos(theta)**50 - 1.02407784002376e+99*cos(theta)**48 + 1.63158164342769e+99*cos(theta)**46 - 1.92992800108304e+99*cos(theta)**44 + 1.75887465223946e+99*cos(theta)**42 - 1.26515545161084e+99*cos(theta)**40 + 7.2989737592933e+98*cos(theta)**38 - 3.41395778628289e+98*cos(theta)**36 + 1.30351115476256e+98*cos(theta)**34 - 4.07847048422641e+97*cos(theta)**32 + 1.04706074543287e+97*cos(theta)**30 - 2.20353857892258e+96*cos(theta)**28 + 3.78952494464393e+95*cos(theta)**26 - 5.29718540649152e+94*cos(theta)**24 + 5.97231687986788e+93*cos(theta)**22 - 5.37438721951493e+92*cos(theta)**20 + 3.80735858205755e+91*cos(theta)**18 - 2.08566367008523e+90*cos(theta)**16 + 8.6303324279389e+88*cos(theta)**14 - 2.61525225089057e+87*cos(theta)**12 + 5.56436649125654e+85*cos(theta)**10 - 7.83223309685782e+83*cos(theta)**8 + 6.66978487566967e+81*cos(theta)**6 - 2.96434883363097e+79*cos(theta)**4 + 5.14346240653146e+76*cos(theta)**2 - 1.45418784465125e+73)*sin(38*phi)

#@torch.jit.script
def Yl92_m_minus_37(theta, phi):
    return 2.74133040911422e-72*(1.0 - cos(theta)**2)**18.5*(2.84960706263379e+95*cos(theta)**55 - 2.3123860590225e+96*cos(theta)**53 + 8.80239776058842e+96*cos(theta)**51 - 2.0899547755587e+97*cos(theta)**49 + 3.4714503051653e+97*cos(theta)**47 - 4.28872889129565e+97*cos(theta)**45 + 4.09040616799874e+97*cos(theta)**43 - 3.08574500392887e+97*cos(theta)**41 + 1.87153173315213e+97*cos(theta)**39 - 9.22691293589971e+96*cos(theta)**37 + 3.72431758503588e+96*cos(theta)**35 - 1.23590014673528e+96*cos(theta)**33 + 3.37761530784796e+95*cos(theta)**31 - 7.59840889283649e+94*cos(theta)**29 + 1.40352775727553e+94*cos(theta)**27 - 2.11887416259661e+93*cos(theta)**25 + 2.59665951298604e+92*cos(theta)**23 - 2.55923200929282e+91*cos(theta)**21 + 2.00387293792503e+90*cos(theta)**19 - 1.22686098240308e+89*cos(theta)**17 + 5.75355495195926e+87*cos(theta)**15 - 2.01173250068506e+86*cos(theta)**13 + 5.0585149920514e+84*cos(theta)**11 - 8.70248121873091e+82*cos(theta)**9 + 9.52826410809953e+80*cos(theta)**7 - 5.92869766726193e+78*cos(theta)**5 + 1.71448746884382e+76*cos(theta)**3 - 1.45418784465125e+73*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl92_m_minus_36(theta, phi):
    return 2.329969587437e-70*(1.0 - cos(theta)**2)**18*(5.08858404041748e+93*cos(theta)**56 - 4.28219640559723e+94*cos(theta)**54 + 1.69276880011316e+95*cos(theta)**52 - 4.17990955111741e+95*cos(theta)**50 + 7.23218813576105e+95*cos(theta)**48 - 9.32332367672967e+95*cos(theta)**46 + 9.29637765454259e+95*cos(theta)**44 - 7.34701191411637e+95*cos(theta)**42 + 4.67882933288032e+95*cos(theta)**40 - 2.4281349831315e+95*cos(theta)**38 + 1.03453266250997e+95*cos(theta)**36 - 3.63500043157434e+94*cos(theta)**34 + 1.05550478370249e+94*cos(theta)**32 - 2.53280296427883e+93*cos(theta)**30 + 5.01259913312689e+92*cos(theta)**28 - 8.14951600998695e+91*cos(theta)**26 + 1.08194146374418e+91*cos(theta)**24 - 1.16328727695128e+90*cos(theta)**22 + 1.00193646896251e+89*cos(theta)**20 - 6.81589434668377e+87*cos(theta)**18 + 3.59597184497454e+86*cos(theta)**16 - 1.43695178620361e+85*cos(theta)**14 + 4.21542916004283e+83*cos(theta)**12 - 8.70248121873091e+81*cos(theta)**10 + 1.19103301351244e+80*cos(theta)**8 - 9.88116277876989e+77*cos(theta)**6 + 4.28621867210955e+75*cos(theta)**4 - 7.27093922325624e+72*cos(theta)**2 + 2.01299535527581e+69)*sin(36*phi)

#@torch.jit.script
def Yl92_m_minus_35(theta, phi):
    return 1.99018140879344e-68*(1.0 - cos(theta)**2)**17.5*(8.92734042178506e+91*cos(theta)**57 - 7.78581164654041e+92*cos(theta)**55 + 3.19390339643992e+93*cos(theta)**53 - 8.19590108062237e+93*cos(theta)**51 + 1.47595676240021e+94*cos(theta)**49 - 1.98368588866589e+94*cos(theta)**47 + 2.06586170100947e+94*cos(theta)**45 - 1.70860742188753e+94*cos(theta)**43 + 1.14117788606837e+94*cos(theta)**41 - 6.22598713623462e+93*cos(theta)**39 + 2.79603422299991e+93*cos(theta)**37 - 1.03857155187838e+93*cos(theta)**35 + 3.19849934455299e+92*cos(theta)**33 - 8.17033214283493e+91*cos(theta)**31 + 1.72848245969893e+91*cos(theta)**29 - 3.01833926295813e+90*cos(theta)**27 + 4.32776585497673e+89*cos(theta)**25 - 5.0577707693534e+88*cos(theta)**23 + 4.77112604267864e+87*cos(theta)**21 - 3.58731281404409e+86*cos(theta)**19 + 2.11527755586738e+85*cos(theta)**17 - 9.57967857469075e+83*cos(theta)**15 + 3.24263781541757e+82*cos(theta)**13 - 7.91134656248264e+80*cos(theta)**11 + 1.32337001501382e+79*cos(theta)**9 - 1.41159468268141e+77*cos(theta)**7 + 8.5724373442191e+74*cos(theta)**5 - 2.42364640775208e+72*cos(theta)**3 + 2.01299535527581e+69*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl92_m_minus_34(theta, phi):
    return 1.70808123770373e-66*(1.0 - cos(theta)**2)**17*(1.5391966244457e+90*cos(theta)**58 - 1.39032350831079e+91*cos(theta)**56 + 5.91463591933319e+91*cos(theta)**54 - 1.57613482319661e+92*cos(theta)**52 + 2.95191352480043e+92*cos(theta)**50 - 4.1326789347206e+92*cos(theta)**48 + 4.49100369784666e+92*cos(theta)**46 - 3.88319868610802e+92*cos(theta)**44 + 2.71709020492469e+92*cos(theta)**42 - 1.55649678405866e+92*cos(theta)**40 + 7.35798479736819e+91*cos(theta)**38 - 2.88492097743996e+91*cos(theta)**36 + 9.40735101339116e+90*cos(theta)**34 - 2.55322879463592e+90*cos(theta)**32 + 5.76160819899643e+89*cos(theta)**30 - 1.07797830819933e+89*cos(theta)**28 + 1.6645253288372e+88*cos(theta)**26 - 2.10740448723058e+87*cos(theta)**24 + 2.16869365576302e+86*cos(theta)**22 - 1.79365640702204e+85*cos(theta)**20 + 1.1751541977041e+84*cos(theta)**18 - 5.98729910918172e+82*cos(theta)**16 + 2.3161698681554e+81*cos(theta)**14 - 6.59278880206887e+79*cos(theta)**12 + 1.32337001501382e+78*cos(theta)**10 - 1.76449335335177e+76*cos(theta)**8 + 1.42873955736985e+74*cos(theta)**6 - 6.0591160193802e+71*cos(theta)**4 + 1.00649767763791e+69*cos(theta)**2 - 2.73282019450966e+65)*sin(34*phi)

#@torch.jit.script
def Yl92_m_minus_33(theta, phi):
    return 1.47271869749464e-64*(1.0 - cos(theta)**2)**16.5*(2.60880783804356e+88*cos(theta)**59 - 2.43916404966805e+89*cos(theta)**57 + 1.07538834896967e+90*cos(theta)**55 - 2.97383928905021e+90*cos(theta)**53 + 5.7880657349028e+90*cos(theta)**51 - 8.43403864228694e+90*cos(theta)**49 + 9.55532701669503e+90*cos(theta)**47 - 8.62933041357337e+90*cos(theta)**45 + 6.31881443005742e+90*cos(theta)**43 - 3.79633361965526e+90*cos(theta)**41 + 1.88666276855595e+90*cos(theta)**39 - 7.79708372281069e+89*cos(theta)**37 + 2.68781457525462e+89*cos(theta)**35 - 7.73705695344217e+88*cos(theta)**33 + 1.85858328999885e+88*cos(theta)**31 - 3.7171665799977e+87*cos(theta)**29 + 6.16490862532297e+86*cos(theta)**27 - 8.42961794892234e+85*cos(theta)**25 + 9.42910285114355e+84*cos(theta)**23 - 8.54122098581926e+83*cos(theta)**21 + 6.18502209317946e+82*cos(theta)**19 - 3.52194065245983e+81*cos(theta)**17 + 1.54411324543694e+80*cos(theta)**15 - 5.07137600159144e+78*cos(theta)**13 + 1.20306365001257e+77*cos(theta)**11 - 1.96054817039085e+75*cos(theta)**9 + 2.04105651052836e+73*cos(theta)**7 - 1.21182320387604e+71*cos(theta)**5 + 3.35499225879302e+68*cos(theta)**3 - 2.73282019450966e+65*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl92_m_minus_32(theta, phi):
    return 1.27541180465869e-62*(1.0 - cos(theta)**2)**16*(4.34801306340593e+86*cos(theta)**60 - 4.20545525804836e+87*cos(theta)**58 + 1.92033633744584e+88*cos(theta)**56 - 5.50710979453742e+88*cos(theta)**54 + 1.11308956440438e+89*cos(theta)**52 - 1.68680772845739e+89*cos(theta)**50 + 1.99069312847813e+89*cos(theta)**48 - 1.87594139425508e+89*cos(theta)**46 + 1.43609418864941e+89*cos(theta)**44 - 9.03888957060776e+88*cos(theta)**42 + 4.71665692138987e+88*cos(theta)**40 - 2.05186413758176e+88*cos(theta)**38 + 7.46615159792949e+87*cos(theta)**36 - 2.27560498630652e+87*cos(theta)**34 + 5.8080727812464e+86*cos(theta)**32 - 1.2390555266659e+86*cos(theta)**30 + 2.20175308047249e+85*cos(theta)**28 - 3.24216074958551e+84*cos(theta)**26 + 3.92879285464315e+83*cos(theta)**24 - 3.88237317537239e+82*cos(theta)**22 + 3.09251104658973e+81*cos(theta)**20 - 1.95663369581102e+80*cos(theta)**18 + 9.65070778398085e+78*cos(theta)**16 - 3.62241142970817e+77*cos(theta)**14 + 1.00255304167714e+76*cos(theta)**12 - 1.96054817039085e+74*cos(theta)**10 + 2.55132063816045e+72*cos(theta)**8 - 2.0197053397934e+70*cos(theta)**6 + 8.38748064698256e+67*cos(theta)**4 - 1.36641009725483e+65*cos(theta)**2 + 3.64376025934621e+61)*sin(32*phi)

#@torch.jit.script
def Yl92_m_minus_31(theta, phi):
    return 1.10924171186194e-60*(1.0 - cos(theta)**2)**15.5*(7.12789026787858e+84*cos(theta)**61 - 7.12789026787858e+85*cos(theta)**59 + 3.36901111832603e+86*cos(theta)**57 - 1.00129268991589e+87*cos(theta)**55 + 2.10016898944224e+87*cos(theta)**53 - 3.30746613423017e+87*cos(theta)**51 + 4.06263903771047e+87*cos(theta)**49 - 3.99136466862783e+87*cos(theta)**47 + 3.19132041922092e+87*cos(theta)**45 - 2.1020673420018e+87*cos(theta)**43 + 1.15040412716826e+87*cos(theta)**41 - 5.26119009636349e+86*cos(theta)**39 + 2.01787881025121e+86*cos(theta)**37 - 6.50172853230435e+85*cos(theta)**35 + 1.76002205492315e+85*cos(theta)**33 - 3.99695331182548e+84*cos(theta)**31 + 7.59225200162928e+83*cos(theta)**29 - 1.20080027762426e+83*cos(theta)**27 + 1.57151714185726e+82*cos(theta)**25 - 1.68798833711843e+81*cos(theta)**23 + 1.47262430789987e+80*cos(theta)**21 - 1.02980720832159e+79*cos(theta)**19 + 5.67688693175344e+77*cos(theta)**17 - 2.41494095313878e+76*cos(theta)**15 + 7.71194647443953e+74*cos(theta)**13 - 1.78231651853714e+73*cos(theta)**11 + 2.83480070906716e+71*cos(theta)**9 - 2.885293342562e+69*cos(theta)**7 + 1.67749612939651e+67*cos(theta)**5 - 4.55470032418276e+64*cos(theta)**3 + 3.64376025934621e+61*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl92_m_minus_30(theta, phi):
    return 9.68667196672842e-59*(1.0 - cos(theta)**2)**15*(1.14965972062558e+83*cos(theta)**62 - 1.1879817113131e+84*cos(theta)**60 + 5.80863985918282e+84*cos(theta)**58 - 1.7880226605641e+85*cos(theta)**56 + 3.88920183230044e+85*cos(theta)**54 - 6.36051179659648e+85*cos(theta)**52 + 8.12527807542094e+85*cos(theta)**50 - 8.31534305964132e+85*cos(theta)**48 + 6.93765308526287e+85*cos(theta)**46 - 4.77742577727683e+85*cos(theta)**44 + 2.73905744563872e+85*cos(theta)**42 - 1.31529752409087e+85*cos(theta)**40 + 5.31020739539793e+84*cos(theta)**38 - 1.80603570341787e+84*cos(theta)**36 + 5.17653545565633e+83*cos(theta)**34 - 1.24904790994546e+83*cos(theta)**32 + 2.53075066720976e+82*cos(theta)**30 - 4.28857242008666e+81*cos(theta)**28 + 6.044296699451e+80*cos(theta)**26 - 7.03328473799346e+79*cos(theta)**24 + 6.69374685409033e+78*cos(theta)**22 - 5.14903604160794e+77*cos(theta)**20 + 3.15382607319636e+76*cos(theta)**18 - 1.50933809571174e+75*cos(theta)**16 + 5.50853319602824e+73*cos(theta)**14 - 1.48526376544761e+72*cos(theta)**12 + 2.83480070906716e+70*cos(theta)**10 - 3.6066166782025e+68*cos(theta)**8 + 2.79582688232752e+66*cos(theta)**6 - 1.13867508104569e+64*cos(theta)**4 + 1.8218801296731e+61*cos(theta)**2 - 4.77807534663809e+57)*sin(30*phi)

#@torch.jit.script
def Yl92_m_minus_29(theta, phi):
    return 8.49228934738827e-57*(1.0 - cos(theta)**2)**14.5*(1.82485669940568e+81*cos(theta)**63 - 1.94751100215262e+82*cos(theta)**61 + 9.84515230369969e+82*cos(theta)**59 - 3.13688186063877e+83*cos(theta)**57 + 7.07127605872807e+83*cos(theta)**55 - 1.20009656539556e+84*cos(theta)**53 + 1.5931917794943e+84*cos(theta)**51 - 1.6970087876819e+84*cos(theta)**49 + 1.47609640111976e+84*cos(theta)**47 - 1.06165017272818e+84*cos(theta)**45 + 6.3699010363691e+83*cos(theta)**43 - 3.20804274168505e+83*cos(theta)**41 + 1.36159163984562e+83*cos(theta)**39 - 4.88117757680506e+82*cos(theta)**37 + 1.47901013018752e+82*cos(theta)**35 - 3.7849936665014e+81*cos(theta)**33 + 8.1637118297089e+80*cos(theta)**31 - 1.47881807589195e+80*cos(theta)**29 + 2.23862840720407e+79*cos(theta)**27 - 2.81331389519738e+78*cos(theta)**25 + 2.91032471916971e+77*cos(theta)**23 - 2.45192192457521e+76*cos(theta)**21 + 1.65990845957703e+75*cos(theta)**19 - 8.87845938653963e+73*cos(theta)**17 + 3.67235546401883e+72*cos(theta)**15 - 1.14251058880586e+71*cos(theta)**13 + 2.57709155369742e+69*cos(theta)**11 - 4.00735186466944e+67*cos(theta)**9 + 3.99403840332503e+65*cos(theta)**7 - 2.27735016209138e+63*cos(theta)**5 + 6.07293376557701e+60*cos(theta)**3 - 4.77807534663809e+57*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl92_m_minus_28(theta, phi):
    return 7.47321462570168e-55*(1.0 - cos(theta)**2)**14*(2.85133859282137e+79*cos(theta)**64 - 3.14114677766551e+80*cos(theta)**62 + 1.64085871728328e+81*cos(theta)**60 - 5.40841700110132e+81*cos(theta)**58 + 1.26272786763001e+82*cos(theta)**56 - 2.22240104702882e+82*cos(theta)**54 + 3.06383034518135e+82*cos(theta)**52 - 3.3940175753638e+82*cos(theta)**50 + 3.07520083566617e+82*cos(theta)**48 - 2.30793515810475e+82*cos(theta)**46 + 1.44770478099298e+82*cos(theta)**44 - 7.63819700401203e+81*cos(theta)**42 + 3.40397909961406e+81*cos(theta)**40 - 1.2845204149487e+81*cos(theta)**38 + 4.10836147274312e+80*cos(theta)**36 - 1.11323343132394e+80*cos(theta)**34 + 2.55115994678403e+79*cos(theta)**32 - 4.9293935863065e+78*cos(theta)**30 + 7.99510145430026e+77*cos(theta)**28 - 1.08204380584515e+77*cos(theta)**26 + 1.21263529965405e+76*cos(theta)**24 - 1.11450996571601e+75*cos(theta)**22 + 8.29954229788515e+73*cos(theta)**20 - 4.93247743696646e+72*cos(theta)**18 + 2.29522216501177e+71*cos(theta)**16 - 8.16078992004184e+69*cos(theta)**14 + 2.14757629474785e+68*cos(theta)**12 - 4.00735186466944e+66*cos(theta)**10 + 4.99254800415628e+64*cos(theta)**8 - 3.79558360348563e+62*cos(theta)**6 + 1.51823344139425e+60*cos(theta)**4 - 2.38903767331905e+57*cos(theta)**2 + 6.17003531332398e+53)*sin(28*phi)

#@torch.jit.script
def Yl92_m_minus_27(theta, phi):
    return 6.6001644476941e-53*(1.0 - cos(theta)**2)**13.5*(4.38667475818673e+77*cos(theta)**65 - 4.98594726613573e+78*cos(theta)**63 + 2.68993232341522e+79*cos(theta)**61 - 9.16680847644292e+79*cos(theta)**59 + 2.2153120484737e+80*cos(theta)**57 - 4.04072917641604e+80*cos(theta)**55 + 5.78081197204028e+80*cos(theta)**53 - 6.65493642228197e+80*cos(theta)**51 + 6.2759200727881e+80*cos(theta)**49 - 4.91050033639308e+80*cos(theta)**47 + 3.21712173553995e+80*cos(theta)**45 - 1.77632488465396e+80*cos(theta)**43 + 8.30238804783917e+79*cos(theta)**41 - 3.29364208961205e+79*cos(theta)**39 + 1.11036796560625e+79*cos(theta)**37 - 3.18066694663983e+78*cos(theta)**35 + 7.73078771752737e+77*cos(theta)**33 - 1.59012696332468e+77*cos(theta)**31 + 2.75693153596561e+76*cos(theta)**29 - 4.00756965127833e+75*cos(theta)**27 + 4.85054119861618e+74*cos(theta)**25 - 4.84569550311307e+73*cos(theta)**23 + 3.95216299899293e+72*cos(theta)**21 - 2.59604075629814e+71*cos(theta)**19 + 1.35013068530104e+70*cos(theta)**17 - 5.44052661336122e+68*cos(theta)**15 + 1.65198176519065e+67*cos(theta)**13 - 3.64304714969949e+65*cos(theta)**11 + 5.54727556017365e+63*cos(theta)**9 - 5.42226229069376e+61*cos(theta)**7 + 3.03646688278851e+59*cos(theta)**5 - 7.96345891106349e+56*cos(theta)**3 + 6.17003531332398e+53*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl92_m_minus_26(theta, phi):
    return 5.84925028499633e-51*(1.0 - cos(theta)**2)**13*(6.64647690634352e+75*cos(theta)**66 - 7.79054260333708e+76*cos(theta)**64 + 4.33860052163745e+77*cos(theta)**62 - 1.52780141274049e+78*cos(theta)**60 + 3.81950353185121e+78*cos(theta)**58 - 7.21558781502864e+78*cos(theta)**56 + 1.07052073556302e+79*cos(theta)**54 - 1.27979546582345e+79*cos(theta)**52 + 1.25518401455762e+79*cos(theta)**50 - 1.02302090341523e+79*cos(theta)**48 + 6.99374290334772e+78*cos(theta)**46 - 4.03710201057718e+78*cos(theta)**44 + 1.97675905900933e+78*cos(theta)**42 - 8.23410522403014e+77*cos(theta)**40 + 2.9220209621217e+77*cos(theta)**38 - 8.83518596288842e+76*cos(theta)**36 + 2.2737610933904e+76*cos(theta)**34 - 4.96914676038962e+75*cos(theta)**32 + 9.18977178655202e+74*cos(theta)**30 - 1.43127487545654e+74*cos(theta)**28 + 1.86559276869853e+73*cos(theta)**26 - 2.01903979296378e+72*cos(theta)**24 + 1.79643772681497e+71*cos(theta)**22 - 1.29802037814907e+70*cos(theta)**20 + 7.50072602945022e+68*cos(theta)**18 - 3.40032913335076e+67*cos(theta)**16 + 1.17998697513618e+66*cos(theta)**14 - 3.03587262474958e+64*cos(theta)**12 + 5.54727556017365e+62*cos(theta)**10 - 6.7778278633672e+60*cos(theta)**8 + 5.06077813798085e+58*cos(theta)**6 - 1.99086472776587e+56*cos(theta)**4 + 3.08501765666199e+53*cos(theta)**2 - 7.85591458279091e+49)*sin(26*phi)

#@torch.jit.script
def Yl92_m_minus_25(theta, phi):
    return 5.20090127435586e-49*(1.0 - cos(theta)**2)**12.5*(9.92011478558735e+73*cos(theta)**67 - 1.19854501589801e+75*cos(theta)**65 + 6.88666749466261e+75*cos(theta)**63 - 2.50459247990244e+76*cos(theta)**61 + 6.47373479974782e+76*cos(theta)**59 - 1.26589259912783e+77*cos(theta)**57 + 1.9464013373873e+77*cos(theta)**55 - 2.41470842608199e+77*cos(theta)**53 + 2.46114512658357e+77*cos(theta)**51 - 2.08779776207189e+77*cos(theta)**49 + 1.4880304049676e+77*cos(theta)**47 - 8.97133780128263e+76*cos(theta)**45 + 4.59711409071936e+76*cos(theta)**43 - 2.00831834732442e+76*cos(theta)**41 + 7.4923614413377e+75*cos(theta)**39 - 2.38788809807795e+75*cos(theta)**37 + 6.49646026682972e+74*cos(theta)**35 - 1.50580204860292e+74*cos(theta)**33 + 2.96444251179098e+73*cos(theta)**31 - 4.93543060502257e+72*cos(theta)**29 + 6.9096028470316e+71*cos(theta)**27 - 8.07615917185511e+70*cos(theta)**25 + 7.81059881223899e+69*cos(theta)**23 - 6.18104941975747e+68*cos(theta)**21 + 3.9477505418159e+67*cos(theta)**19 - 2.00019360785339e+66*cos(theta)**17 + 7.86657983424121e+64*cos(theta)**15 - 2.33528663442275e+63*cos(theta)**13 + 5.04297778197604e+61*cos(theta)**11 - 7.53091984818578e+59*cos(theta)**9 + 7.22968305425835e+57*cos(theta)**7 - 3.98172945553174e+55*cos(theta)**5 + 1.02833921888733e+53*cos(theta)**3 - 7.85591458279091e+49*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl92_m_minus_24(theta, phi):
    return 4.63901735355543e-47*(1.0 - cos(theta)**2)**12*(1.4588404096452e+72*cos(theta)**68 - 1.81597729681517e+73*cos(theta)**66 + 1.07604179604103e+74*cos(theta)**64 - 4.03966529016522e+74*cos(theta)**62 + 1.07895579995797e+75*cos(theta)**60 - 2.18257344677212e+75*cos(theta)**58 + 3.4757166739059e+75*cos(theta)**56 - 4.4716822705222e+75*cos(theta)**54 + 4.73297139727609e+75*cos(theta)**52 - 4.17559552414378e+75*cos(theta)**50 + 3.1000633436825e+75*cos(theta)**48 - 1.95029082636579e+75*cos(theta)**46 + 1.04479865698167e+75*cos(theta)**44 - 4.78171035077244e+74*cos(theta)**42 + 1.87309036033443e+74*cos(theta)**40 - 6.28391604757356e+73*cos(theta)**38 + 1.80457229634159e+73*cos(theta)**36 - 4.42882955471446e+72*cos(theta)**34 + 9.2638828493468e+71*cos(theta)**32 - 1.64514353500752e+71*cos(theta)**30 + 2.46771530251128e+70*cos(theta)**28 - 3.10621506609812e+69*cos(theta)**26 + 3.25441617176624e+68*cos(theta)**24 - 2.80956791807158e+67*cos(theta)**22 + 1.97387527090795e+66*cos(theta)**20 - 1.11121867102966e+65*cos(theta)**18 + 4.91661239640076e+63*cos(theta)**16 - 1.66806188173054e+62*cos(theta)**14 + 4.20248148498004e+60*cos(theta)**12 - 7.53091984818578e+58*cos(theta)**10 + 9.03710381782294e+56*cos(theta)**8 - 6.63621575921957e+54*cos(theta)**6 + 2.57084804721833e+52*cos(theta)**4 - 3.92795729139546e+49*cos(theta)**2 + 9.87420133583574e+45)*sin(24*phi)

#@torch.jit.script
def Yl92_m_minus_23(theta, phi):
    return 4.15030044672352e-45*(1.0 - cos(theta)**2)**11.5*(2.11426146325391e+70*cos(theta)**69 - 2.71041387584354e+71*cos(theta)**67 + 1.6554489169862e+72*cos(theta)**65 - 6.41216712724638e+72*cos(theta)**63 + 1.7687799999311e+73*cos(theta)**61 - 3.69927702842733e+73*cos(theta)**59 + 6.0977485507121e+73*cos(theta)**57 - 8.13033140094946e+73*cos(theta)**55 + 8.93013471184168e+73*cos(theta)**53 - 8.18744220420348e+73*cos(theta)**51 + 6.32665988506633e+73*cos(theta)**49 - 4.14955494971445e+73*cos(theta)**47 + 2.32177479329261e+73*cos(theta)**45 - 1.11202566297033e+73*cos(theta)**43 + 4.5685130739864e+72*cos(theta)**41 - 1.61126052501886e+72*cos(theta)**39 + 4.87722242254484e+71*cos(theta)**37 - 1.26537987277556e+71*cos(theta)**35 + 2.80723722707479e+70*cos(theta)**33 - 5.30691462905653e+69*cos(theta)**31 + 8.50936311210788e+68*cos(theta)**29 - 1.15045002448079e+68*cos(theta)**27 + 1.3017664687065e+67*cos(theta)**25 - 1.22155126872677e+66*cos(theta)**23 + 9.39940605194263e+64*cos(theta)**21 - 5.84851932120875e+63*cos(theta)**19 + 2.89212493905927e+62*cos(theta)**17 - 1.11204125448702e+61*cos(theta)**15 + 3.23267806536926e+59*cos(theta)**13 - 6.84629077107798e+57*cos(theta)**11 + 1.00412264642477e+56*cos(theta)**9 - 9.48030822745653e+53*cos(theta)**7 + 5.14169609443665e+51*cos(theta)**5 - 1.30931909713182e+49*cos(theta)**3 + 9.87420133583574e+45*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl92_m_minus_22(theta, phi):
    return 3.72372394350724e-43*(1.0 - cos(theta)**2)**11*(3.02037351893416e+68*cos(theta)**70 - 3.98590275859344e+69*cos(theta)**68 + 2.50825593482758e+70*cos(theta)**66 - 1.00190111363225e+71*cos(theta)**64 + 2.8528709676308e+71*cos(theta)**62 - 6.16546171404555e+71*cos(theta)**60 + 1.05133595701933e+72*cos(theta)**58 - 1.45184489302669e+72*cos(theta)**56 + 1.65372865034105e+72*cos(theta)**54 - 1.57450811619298e+72*cos(theta)**52 + 1.26533197701327e+72*cos(theta)**50 - 8.64490614523843e+71*cos(theta)**48 + 5.04733650715784e+71*cos(theta)**46 - 2.5273310522053e+71*cos(theta)**44 + 1.087741208092e+71*cos(theta)**42 - 4.02815131254715e+70*cos(theta)**40 + 1.28347958488022e+70*cos(theta)**38 - 3.51494409104322e+69*cos(theta)**36 + 8.25658007963173e+68*cos(theta)**34 - 1.65841082158016e+68*cos(theta)**32 + 2.83645437070263e+67*cos(theta)**30 - 4.10875008743138e+66*cos(theta)**28 + 5.00679411040961e+65*cos(theta)**26 - 5.08979695302822e+64*cos(theta)**24 + 4.27245729633756e+63*cos(theta)**22 - 2.92425966060437e+62*cos(theta)**20 + 1.60673607725515e+61*cos(theta)**18 - 6.95025784054391e+59*cos(theta)**16 + 2.30905576097804e+58*cos(theta)**14 - 5.70524230923165e+56*cos(theta)**12 + 1.00412264642477e+55*cos(theta)**10 - 1.18503852843207e+53*cos(theta)**8 + 8.56949349072775e+50*cos(theta)**6 - 3.27329774282955e+48*cos(theta)**4 + 4.93710066791787e+45*cos(theta)**2 - 1.2266088615945e+42)*sin(22*phi)

#@torch.jit.script
def Yl92_m_minus_21(theta, phi):
    return 3.35011007789734e-41*(1.0 - cos(theta)**2)**10.5*(4.25404720976642e+66*cos(theta)**71 - 5.77667066462817e+67*cos(theta)**69 + 3.74366557436953e+68*cos(theta)**67 - 1.541386328665e+69*cos(theta)**65 + 4.52836661528699e+69*cos(theta)**63 - 1.01073142853206e+70*cos(theta)**61 + 1.78192535088022e+70*cos(theta)**59 - 2.5470963035556e+70*cos(theta)**57 + 3.00677936425646e+70*cos(theta)**55 - 2.97077003055279e+70*cos(theta)**53 + 2.48104309218287e+70*cos(theta)**51 - 1.76426656025274e+70*cos(theta)**49 + 1.07390138450167e+70*cos(theta)**47 - 5.6162912271229e+69*cos(theta)**45 + 2.52963071649303e+69*cos(theta)**43 - 9.82475929889549e+68*cos(theta)**41 + 3.29097329456467e+68*cos(theta)**39 - 9.49984889471141e+67*cos(theta)**37 + 2.35902287989478e+67*cos(theta)**35 - 5.02548733812171e+66*cos(theta)**33 + 9.14985280871815e+65*cos(theta)**31 - 1.41681037497634e+65*cos(theta)**29 + 1.8543681890406e+64*cos(theta)**27 - 2.03591878121129e+63*cos(theta)**25 + 1.85759012884242e+62*cos(theta)**23 - 1.3925046002878e+61*cos(theta)**21 + 8.45650566976395e+59*cos(theta)**19 - 4.08838696502583e+58*cos(theta)**17 + 1.53937050731869e+57*cos(theta)**15 - 4.38864793017819e+55*cos(theta)**13 + 9.12838769477065e+53*cos(theta)**11 - 1.31670947603563e+52*cos(theta)**9 + 1.22421335581825e+50*cos(theta)**7 - 6.54659548565909e+47*cos(theta)**5 + 1.64570022263929e+45*cos(theta)**3 - 1.2266088615945e+42*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl92_m_minus_20(theta, phi):
    return 3.02179186207228e-39*(1.0 - cos(theta)**2)**10*(5.90839890245336e+64*cos(theta)**72 - 8.25238666375453e+65*cos(theta)**70 + 5.50539055054342e+66*cos(theta)**68 - 2.3354338313106e+67*cos(theta)**66 + 7.07557283638592e+67*cos(theta)**64 - 1.63021198150332e+68*cos(theta)**62 + 2.96987558480036e+68*cos(theta)**60 - 4.39154535095792e+68*cos(theta)**58 + 5.36924886474367e+68*cos(theta)**56 - 5.50142598250516e+68*cos(theta)**54 + 4.7712367157363e+68*cos(theta)**52 - 3.52853312050548e+68*cos(theta)**50 + 2.23729455104514e+68*cos(theta)**48 - 1.2209328754615e+68*cos(theta)**46 + 5.74916071930233e+67*cos(theta)**44 - 2.33922840449893e+67*cos(theta)**42 + 8.22743323641167e+66*cos(theta)**40 - 2.49996023545037e+66*cos(theta)**38 + 6.55284133304105e+65*cos(theta)**36 - 1.47808451121227e+65*cos(theta)**34 + 2.85932900272442e+64*cos(theta)**32 - 4.72270124992112e+63*cos(theta)**30 + 6.62274353228784e+62*cos(theta)**28 - 7.83045685081265e+61*cos(theta)**26 + 7.73995887017673e+60*cos(theta)**24 - 6.32956636494453e+59*cos(theta)**22 + 4.22825283488197e+58*cos(theta)**20 - 2.27132609168101e+57*cos(theta)**18 + 9.62106567074184e+55*cos(theta)**16 - 3.13474852155585e+54*cos(theta)**14 + 7.6069897456422e+52*cos(theta)**12 - 1.31670947603563e+51*cos(theta)**10 + 1.53026669477281e+49*cos(theta)**8 - 1.09109924760985e+47*cos(theta)**6 + 4.11425055659822e+44*cos(theta)**4 - 6.13304430797251e+41*cos(theta)**2 + 1.5076313441427e+38)*sin(20*phi)

#@torch.jit.script
def Yl92_m_minus_19(theta, phi):
    return 2.7323415644396e-37*(1.0 - cos(theta)**2)**9.5*(8.09369712664844e+62*cos(theta)**73 - 1.1623079808105e+64*cos(theta)**71 + 7.97882688484554e+64*cos(theta)**69 - 3.48572213628448e+65*cos(theta)**67 + 1.0885496671363e+66*cos(theta)**65 - 2.58763806587828e+66*cos(theta)**63 + 4.86864849967272e+66*cos(theta)**61 - 7.44329720501343e+66*cos(theta)**59 + 9.4197348504275e+66*cos(theta)**57 - 1.00025926954639e+67*cos(theta)**55 + 9.00233342591754e+66*cos(theta)**53 - 6.918692393148e+66*cos(theta)**51 + 4.5659072470309e+66*cos(theta)**49 - 2.59772952225851e+66*cos(theta)**47 + 1.27759127095607e+66*cos(theta)**45 - 5.44006605697425e+65*cos(theta)**43 + 2.00669103327114e+65*cos(theta)**41 - 6.41015444987274e+64*cos(theta)**39 + 1.7710381981192e+64*cos(theta)**37 - 4.22309860346362e+63*cos(theta)**35 + 8.66463334158915e+62*cos(theta)**33 - 1.52345201610359e+62*cos(theta)**31 + 2.28370466630615e+61*cos(theta)**29 - 2.90016920400468e+60*cos(theta)**27 + 3.09598354807069e+59*cos(theta)**25 - 2.75198537606284e+58*cos(theta)**23 + 2.01345373089618e+57*cos(theta)**21 - 1.19543478509527e+56*cos(theta)**19 + 5.65945039455402e+54*cos(theta)**17 - 2.0898323477039e+53*cos(theta)**15 + 5.85153057357093e+51*cos(theta)**13 - 1.19700861457784e+50*cos(theta)**11 + 1.70029632752535e+48*cos(theta)**9 - 1.55871321087121e+46*cos(theta)**7 + 8.22850111319645e+43*cos(theta)**5 - 2.0443481026575e+41*cos(theta)**3 + 1.5076313441427e+38*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl92_m_minus_18(theta, phi):
    return 2.47635177527373e-35*(1.0 - cos(theta)**2)**9*(1.09374285495249e+61*cos(theta)**74 - 1.61431664001458e+62*cos(theta)**72 + 1.13983241212079e+63*cos(theta)**70 - 5.12606196512423e+63*cos(theta)**68 + 1.64931767747924e+64*cos(theta)**66 - 4.04318447793481e+64*cos(theta)**64 + 7.85265887043987e+64*cos(theta)**62 - 1.24054953416891e+65*cos(theta)**60 + 1.62409221559095e+65*cos(theta)**58 - 1.78617726704713e+65*cos(theta)**56 + 1.66709878257732e+65*cos(theta)**54 - 1.33051776791308e+65*cos(theta)**52 + 9.1318144940618e+64*cos(theta)**50 - 5.41193650470523e+64*cos(theta)**48 + 2.77737232816538e+64*cos(theta)**46 - 1.23637864931233e+64*cos(theta)**44 + 4.77783579350271e+63*cos(theta)**42 - 1.60253861246819e+63*cos(theta)**40 + 4.6606268371558e+62*cos(theta)**38 - 1.17308294540656e+62*cos(theta)**36 + 2.54842157105563e+61*cos(theta)**34 - 4.76078755032371e+60*cos(theta)**32 + 7.61234888768717e+59*cos(theta)**30 - 1.03577471571596e+59*cos(theta)**28 + 1.19076290310411e+58*cos(theta)**26 - 1.14666057335952e+57*cos(theta)**24 + 9.15206241316444e+55*cos(theta)**22 - 5.97717392547635e+54*cos(theta)**20 + 3.14413910808557e+53*cos(theta)**18 - 1.30614521731494e+52*cos(theta)**16 + 4.1796646954078e+50*cos(theta)**14 - 9.97507178814871e+48*cos(theta)**12 + 1.70029632752535e+47*cos(theta)**10 - 1.94839151358902e+45*cos(theta)**8 + 1.37141685219941e+43*cos(theta)**6 - 5.11087025664376e+40*cos(theta)**4 + 7.5381567207135e+37*cos(theta)**2 - 1.83544112995216e+34)*sin(18*phi)

#@torch.jit.script
def Yl92_m_minus_17(theta, phi):
    return 2.24925819878324e-33*(1.0 - cos(theta)**2)**8.5*(1.45832380660332e+59*cos(theta)**75 - 2.21139265755422e+60*cos(theta)**73 + 1.60539776355041e+61*cos(theta)**71 - 7.42907531177424e+61*cos(theta)**69 + 2.46166817534214e+62*cos(theta)**67 - 6.22028381220741e+62*cos(theta)**65 + 1.24645378895871e+63*cos(theta)**63 - 2.03368776093263e+63*cos(theta)**61 + 2.75269867049313e+63*cos(theta)**59 - 3.13364432815286e+63*cos(theta)**57 + 3.03108869559513e+63*cos(theta)**55 - 2.51041088285486e+63*cos(theta)**53 + 1.79055186158075e+63*cos(theta)**51 - 1.10447683769494e+63*cos(theta)**49 + 5.90930282588378e+62*cos(theta)**47 - 2.74750810958295e+62*cos(theta)**45 + 1.11112460314017e+62*cos(theta)**43 - 3.90863076211753e+61*cos(theta)**41 + 1.19503252234764e+61*cos(theta)**39 - 3.17049444704476e+60*cos(theta)**37 + 7.28120448873038e+59*cos(theta)**35 - 1.44266289403749e+59*cos(theta)**33 + 2.45559641538296e+58*cos(theta)**31 - 3.57163695074469e+57*cos(theta)**29 + 4.41023297445968e+56*cos(theta)**27 - 4.58664229343806e+55*cos(theta)**25 + 3.97915757094106e+54*cos(theta)**23 - 2.84627329784588e+53*cos(theta)**21 + 1.65481005688714e+52*cos(theta)**19 - 7.68320716067611e+50*cos(theta)**17 + 2.78644313027187e+49*cos(theta)**15 - 7.67313214472978e+47*cos(theta)**13 + 1.54572393411395e+46*cos(theta)**11 - 2.16487945954335e+44*cos(theta)**9 + 1.95916693171344e+42*cos(theta)**7 - 1.02217405132875e+40*cos(theta)**5 + 2.5127189069045e+37*cos(theta)**3 - 1.83544112995216e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl92_m_minus_16(theta, phi):
    return 2.04719568416579e-31*(1.0 - cos(theta)**2)**8*(1.91884711395174e+57*cos(theta)**76 - 2.98836845615435e+58*cos(theta)**74 + 2.22971911604224e+59*cos(theta)**72 - 1.06129647311061e+60*cos(theta)**70 + 3.62010025785609e+60*cos(theta)**68 - 9.42467244273849e+60*cos(theta)**66 + 1.94758404524798e+61*cos(theta)**64 - 3.28014154989134e+61*cos(theta)**62 + 4.58783111748855e+61*cos(theta)**60 - 5.40283504853942e+61*cos(theta)**58 + 5.4126583849913e+61*cos(theta)**56 - 4.64890904232382e+61*cos(theta)**54 + 3.44336896457836e+61*cos(theta)**52 - 2.20895367538989e+61*cos(theta)**50 + 1.23110475539245e+61*cos(theta)**48 - 5.97284371648468e+60*cos(theta)**46 + 2.52528318895492e+60*cos(theta)**44 - 9.30626371932745e+59*cos(theta)**42 + 2.9875813058691e+59*cos(theta)**40 - 8.34340643959148e+58*cos(theta)**38 + 2.02255680242511e+58*cos(theta)**36 - 4.24312615893379e+57*cos(theta)**34 + 7.67373879807175e+56*cos(theta)**32 - 1.19054565024823e+56*cos(theta)**30 + 1.57508320516417e+55*cos(theta)**28 - 1.76409318978387e+54*cos(theta)**26 + 1.65798232122544e+53*cos(theta)**24 - 1.29376058992995e+52*cos(theta)**22 + 8.27405028443571e+50*cos(theta)**20 - 4.26844842259784e+49*cos(theta)**18 + 1.74152695641992e+48*cos(theta)**16 - 5.48080867480698e+46*cos(theta)**14 + 1.28810327842829e+45*cos(theta)**12 - 2.16487945954335e+43*cos(theta)**10 + 2.4489586646418e+41*cos(theta)**8 - 1.70362341888125e+39*cos(theta)**6 + 6.28179726726125e+36*cos(theta)**4 - 9.17720564976078e+33*cos(theta)**2 + 2.21564598014505e+30)*sin(16*phi)

#@torch.jit.script
def Yl92_m_minus_15(theta, phi):
    return 1.86688083625133e-29*(1.0 - cos(theta)**2)**7.5*(2.49200923889836e+55*cos(theta)**77 - 3.98449127487246e+56*cos(theta)**75 + 3.05440974800306e+57*cos(theta)**73 - 1.49478376494452e+58*cos(theta)**71 + 5.24652211283492e+58*cos(theta)**69 - 1.40666752876694e+59*cos(theta)**67 + 2.99628314653536e+59*cos(theta)**65 - 5.20657388871641e+59*cos(theta)**63 + 7.5210346188337e+59*cos(theta)**61 - 9.15734753989731e+59*cos(theta)**59 + 9.49589190349352e+59*cos(theta)**57 - 8.45256189513422e+59*cos(theta)**55 + 6.49692257467615e+59*cos(theta)**53 - 4.33128171645076e+59*cos(theta)**51 + 2.5124586844744e+59*cos(theta)**49 - 1.27081781201802e+59*cos(theta)**47 + 5.61174041989982e+58*cos(theta)**45 - 2.16424737658778e+58*cos(theta)**43 + 7.28678367285147e+57*cos(theta)**41 - 2.13933498451063e+57*cos(theta)**39 + 5.46636973628407e+56*cos(theta)**37 - 1.21232175969537e+56*cos(theta)**35 + 2.32537539335507e+55*cos(theta)**33 - 3.84046983951041e+54*cos(theta)**31 + 5.43132139711783e+53*cos(theta)**29 - 6.533678480681e+52*cos(theta)**27 + 6.63192928490177e+51*cos(theta)**25 - 5.62504604317368e+50*cos(theta)**23 + 3.94002394496938e+49*cos(theta)**21 - 2.24655180136728e+48*cos(theta)**19 + 1.02442762142348e+47*cos(theta)**17 - 3.65387244987132e+45*cos(theta)**15 + 9.90848675714072e+43*cos(theta)**13 - 1.9680722359485e+42*cos(theta)**11 + 2.72106518293533e+40*cos(theta)**9 - 2.43374774125893e+38*cos(theta)**7 + 1.25635945345225e+36*cos(theta)**5 - 3.05906854992026e+33*cos(theta)**3 + 2.21564598014505e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl92_m_minus_14(theta, phi):
    return 1.70551595998805e-27*(1.0 - cos(theta)**2)**7*(3.19488363961329e+53*cos(theta)**78 - 5.24275167746377e+54*cos(theta)**76 + 4.12758074054468e+55*cos(theta)**74 - 2.07608856242294e+56*cos(theta)**72 + 7.49503158976417e+56*cos(theta)**70 - 2.06862871877491e+57*cos(theta)**68 + 4.539822949296e+57*cos(theta)**66 - 8.1352717011194e+57*cos(theta)**64 + 1.21307009981189e+58*cos(theta)**62 - 1.52622458998289e+58*cos(theta)**60 + 1.63722274198164e+58*cos(theta)**58 - 1.50938605270254e+58*cos(theta)**56 + 1.20313381012521e+58*cos(theta)**54 - 8.32938791625147e+57*cos(theta)**52 + 5.02491736894879e+57*cos(theta)**50 - 2.64753710837087e+57*cos(theta)**48 + 1.21994356954344e+57*cos(theta)**46 - 4.9187440376995e+56*cos(theta)**44 + 1.73494849353606e+56*cos(theta)**42 - 5.34833746127659e+55*cos(theta)**40 + 1.4385183516537e+55*cos(theta)**38 - 3.36756044359825e+54*cos(theta)**36 + 6.83933939222081e+53*cos(theta)**34 - 1.200146824847e+53*cos(theta)**32 + 1.81044046570594e+52*cos(theta)**30 - 2.33345660024322e+51*cos(theta)**28 + 2.55074203265453e+50*cos(theta)**26 - 2.3437691846557e+49*cos(theta)**24 + 1.79091997498608e+48*cos(theta)**22 - 1.12327590068364e+47*cos(theta)**20 + 5.69126456346379e+45*cos(theta)**18 - 2.28367028116958e+44*cos(theta)**16 + 7.0774905408148e+42*cos(theta)**14 - 1.64006019662375e+41*cos(theta)**12 + 2.72106518293533e+39*cos(theta)**10 - 3.04218467657366e+37*cos(theta)**8 + 2.09393242242042e+35*cos(theta)**6 - 7.64767137480065e+32*cos(theta)**4 + 1.10782299007252e+30*cos(theta)**2 - 2.6547399714175e+26)*sin(14*phi)

#@torch.jit.script
def Yl92_m_minus_13(theta, phi):
    return 1.56071019065575e-25*(1.0 - cos(theta)**2)**6.5*(4.0441565058396e+51*cos(theta)**79 - 6.80876841229061e+52*cos(theta)**77 + 5.50344098739291e+53*cos(theta)**75 - 2.84395693482594e+54*cos(theta)**73 + 1.05563825207946e+55*cos(theta)**71 - 2.99801263590567e+55*cos(theta)**69 + 6.77585514820298e+55*cos(theta)**67 - 1.25158026171068e+56*cos(theta)**65 + 1.9255080949395e+56*cos(theta)**63 - 2.50200752456211e+56*cos(theta)**61 + 2.77495379996888e+56*cos(theta)**59 - 2.64804570649568e+56*cos(theta)**57 + 2.18751601840948e+56*cos(theta)**55 - 1.57158262570782e+56*cos(theta)**53 + 9.85277915480156e+55*cos(theta)**51 - 5.40313695585892e+55*cos(theta)**49 + 2.59562461604987e+55*cos(theta)**47 - 1.09305423059989e+55*cos(theta)**45 + 4.03476393845596e+54*cos(theta)**43 - 1.30447255153087e+54*cos(theta)**41 + 3.68850859398385e+53*cos(theta)**39 - 9.10151471242769e+52*cos(theta)**37 + 1.95409696920595e+52*cos(theta)**35 - 3.63680856014244e+51*cos(theta)**33 + 5.8401305345353e+50*cos(theta)**31 - 8.04640206980419e+49*cos(theta)**29 + 9.44719271353529e+48*cos(theta)**27 - 9.3750767386228e+47*cos(theta)**25 + 7.78660858689602e+46*cos(theta)**23 - 5.3489328603983e+45*cos(theta)**21 + 2.99540240182305e+44*cos(theta)**19 - 1.34333545951152e+43*cos(theta)**17 + 4.71832702720987e+41*cos(theta)**15 - 1.26158476663365e+40*cos(theta)**13 + 2.4736956208503e+38*cos(theta)**11 - 3.38020519619296e+36*cos(theta)**9 + 2.99133203202917e+34*cos(theta)**7 - 1.52953427496013e+32*cos(theta)**5 + 3.69274330024174e+29*cos(theta)**3 - 2.6547399714175e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl92_m_minus_12(theta, phi):
    return 1.43041451731379e-23*(1.0 - cos(theta)**2)**6*(5.0551956322995e+49*cos(theta)**80 - 8.72919027216745e+50*cos(theta)**78 + 7.24136972025383e+51*cos(theta)**76 - 3.84318504706209e+52*cos(theta)**74 + 1.46616423899925e+53*cos(theta)**72 - 4.28287519415095e+53*cos(theta)**70 + 9.96449286500439e+53*cos(theta)**68 - 1.89633372986466e+54*cos(theta)**66 + 3.00860639834297e+54*cos(theta)**64 - 4.03549600735824e+54*cos(theta)**62 + 4.62492299994814e+54*cos(theta)**60 - 4.56559604568221e+54*cos(theta)**58 + 3.90627860430264e+54*cos(theta)**56 - 2.91033819575523e+54*cos(theta)**54 + 1.89476522207722e+54*cos(theta)**52 - 1.08062739117178e+54*cos(theta)**50 + 5.40755128343723e+53*cos(theta)**48 - 2.37620484913019e+53*cos(theta)**46 + 9.16991804194537e+52*cos(theta)**44 - 3.10588702745446e+52*cos(theta)**42 + 9.22127148495963e+51*cos(theta)**40 - 2.39513545063887e+51*cos(theta)**38 + 5.42804713668318e+50*cos(theta)**36 - 1.06964957651248e+50*cos(theta)**34 + 1.82504079204228e+49*cos(theta)**32 - 2.68213402326806e+48*cos(theta)**30 + 3.37399739769117e+47*cos(theta)**28 - 3.60579874562416e+46*cos(theta)**26 + 3.24442024454001e+45*cos(theta)**24 - 2.43133311836286e+44*cos(theta)**22 + 1.49770120091152e+43*cos(theta)**20 - 7.46297477506397e+41*cos(theta)**18 + 2.94895439200617e+40*cos(theta)**16 - 9.01131976166896e+38*cos(theta)**14 + 2.06141301737525e+37*cos(theta)**12 - 3.38020519619296e+35*cos(theta)**10 + 3.73916504003646e+33*cos(theta)**8 - 2.54922379160022e+31*cos(theta)**6 + 9.23185825060436e+28*cos(theta)**4 - 1.32736998570875e+26*cos(theta)**2 + 3.16040472787798e+22)*sin(12*phi)

#@torch.jit.script
def Yl92_m_minus_11(theta, phi):
    return 1.31286807653569e-21*(1.0 - cos(theta)**2)**5.5*(6.24098226209815e+47*cos(theta)**81 - 1.10496079394525e+49*cos(theta)**79 + 9.4043762600699e+49*cos(theta)**77 - 5.12424672941612e+50*cos(theta)**75 + 2.00844416301267e+51*cos(theta)**73 - 6.0322185833112e+51*cos(theta)**71 + 1.44412940072527e+52*cos(theta)**69 - 2.83034885054427e+52*cos(theta)**67 + 4.62862522821996e+52*cos(theta)**65 - 6.40554921802895e+52*cos(theta)**63 + 7.58184098352154e+52*cos(theta)**61 - 7.73829838251222e+52*cos(theta)**59 + 6.85312035842568e+52*cos(theta)**57 - 5.29152399228224e+52*cos(theta)**55 + 3.57502872090042e+52*cos(theta)**53 - 2.11887723759173e+52*cos(theta)**51 + 1.10358189457903e+52*cos(theta)**49 - 5.05575499814934e+51*cos(theta)**47 + 2.03775956487675e+51*cos(theta)**45 - 7.2229930871034e+50*cos(theta)**43 + 2.24909060608772e+50*cos(theta)**41 - 6.14137295035607e+49*cos(theta)**39 + 1.46703976667113e+49*cos(theta)**37 - 3.05614164717852e+48*cos(theta)**35 + 5.53042664255237e+47*cos(theta)**33 - 8.65204523634859e+46*cos(theta)**31 + 1.1634473785142e+46*cos(theta)**29 - 1.33548101689784e+45*cos(theta)**27 + 1.297768097816e+44*cos(theta)**25 - 1.05710135580994e+43*cos(theta)**23 + 7.13191048053106e+41*cos(theta)**21 - 3.92788146055999e+40*cos(theta)**19 + 1.73467905412127e+39*cos(theta)**17 - 6.00754650777931e+37*cos(theta)**15 + 1.58570232105789e+36*cos(theta)**13 - 3.07291381472087e+34*cos(theta)**11 + 4.15462782226273e+32*cos(theta)**9 - 3.64174827371459e+30*cos(theta)**7 + 1.84637165012087e+28*cos(theta)**5 - 4.42456661902917e+25*cos(theta)**3 + 3.16040472787798e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl92_m_minus_10(theta, phi):
    return 1.20655361938957e-19*(1.0 - cos(theta)**2)**5*(7.61095397816848e+45*cos(theta)**82 - 1.38120099243156e+47*cos(theta)**80 + 1.20568926411153e+48*cos(theta)**78 - 6.74242990712647e+48*cos(theta)**76 + 2.71411373380091e+49*cos(theta)**74 - 8.37808136571e+49*cos(theta)**72 + 2.06304200103611e+50*cos(theta)**70 - 4.16227772138863e+50*cos(theta)**68 + 7.013068527606e+50*cos(theta)**66 - 1.00086706531702e+51*cos(theta)**64 + 1.22287757798734e+51*cos(theta)**62 - 1.28971639708537e+51*cos(theta)**60 + 1.18157247559063e+51*cos(theta)**58 - 9.44914998621828e+50*cos(theta)**56 + 6.620423557223e+50*cos(theta)**54 - 4.07476391844564e+50*cos(theta)**52 + 2.20716378915805e+50*cos(theta)**50 - 1.05328229128111e+50*cos(theta)**48 + 4.42991209755815e+49*cos(theta)**46 - 1.64158933797805e+49*cos(theta)**44 + 5.35497763354218e+48*cos(theta)**42 - 1.53534323758902e+48*cos(theta)**40 + 3.86063096492403e+47*cos(theta)**38 - 8.48928235327366e+46*cos(theta)**36 + 1.62659607133893e+46*cos(theta)**34 - 2.70376413635894e+45*cos(theta)**32 + 3.87815792838066e+44*cos(theta)**30 - 4.76957506034941e+43*cos(theta)**28 + 4.99141576083078e+42*cos(theta)**26 - 4.40458898254142e+41*cos(theta)**24 + 3.24177749115048e+40*cos(theta)**22 - 1.96394073027999e+39*cos(theta)**20 + 9.6371058562293e+37*cos(theta)**18 - 3.75471656736207e+36*cos(theta)**16 + 1.13264451504135e+35*cos(theta)**14 - 2.56076151226739e+33*cos(theta)**12 + 4.15462782226273e+31*cos(theta)**10 - 4.55218534214324e+29*cos(theta)**8 + 3.07728608353479e+27*cos(theta)**6 - 1.10614165475729e+25*cos(theta)**4 + 1.58020236393899e+22*cos(theta)**2 - 3.74189524967793e+18)*sin(10*phi)

#@torch.jit.script
def Yl92_m_minus_9(theta, phi):
    return 1.11016046922451e-17*(1.0 - cos(theta)**2)**4.5*(9.16982407008251e+43*cos(theta)**83 - 1.70518641040933e+45*cos(theta)**81 + 1.52618894191332e+46*cos(theta)**79 - 8.75640247678762e+46*cos(theta)**77 + 3.61881831173454e+47*cos(theta)**75 - 1.14768237886438e+48*cos(theta)**73 + 2.90569295920578e+48*cos(theta)**71 - 6.03228655273715e+48*cos(theta)**69 + 1.04672664591134e+49*cos(theta)**67 - 1.53979548510311e+49*cos(theta)**65 + 1.94107552061483e+49*cos(theta)**63 - 2.11428917554979e+49*cos(theta)**61 + 2.00266521286548e+49*cos(theta)**59 - 1.65774561161724e+49*cos(theta)**57 + 1.20371337404055e+49*cos(theta)**55 - 7.688233808388e+48*cos(theta)**53 + 4.32777213560403e+48*cos(theta)**51 - 2.14955569649207e+48*cos(theta)**49 + 9.42534488842159e+47*cos(theta)**47 - 3.64797630661788e+47*cos(theta)**45 + 1.24534363570748e+47*cos(theta)**43 - 3.74473960387565e+46*cos(theta)**41 + 9.89905375621545e+45*cos(theta)**39 - 2.29440063601991e+45*cos(theta)**37 + 4.64741734668266e+44*cos(theta)**35 - 8.19322465563314e+43*cos(theta)**33 + 1.25101868657441e+43*cos(theta)**31 - 1.6446810552929e+42*cos(theta)**29 + 1.8486725040114e+41*cos(theta)**27 - 1.76183559301657e+40*cos(theta)**25 + 1.40946847441325e+39*cos(theta)**23 - 9.35209871561902e+37*cos(theta)**21 + 5.07216097696279e+36*cos(theta)**19 - 2.20865680433063e+35*cos(theta)**17 + 7.55096343360898e+33*cos(theta)**15 - 1.969816547898e+32*cos(theta)**13 + 3.77693438387521e+30*cos(theta)**11 - 5.05798371349249e+28*cos(theta)**9 + 4.39612297647827e+26*cos(theta)**7 - 2.21228330951458e+24*cos(theta)**5 + 5.26734121312996e+21*cos(theta)**3 - 3.74189524967793e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl92_m_minus_8(theta, phi):
    return 1.02255361584935e-15*(1.0 - cos(theta)**2)**4*(1.09164572262887e+42*cos(theta)**84 - 2.0794956224504e+43*cos(theta)**82 + 1.90773617739166e+44*cos(theta)**80 - 1.12261570215226e+45*cos(theta)**78 + 4.76160304175598e+45*cos(theta)**76 - 1.55092213360052e+46*cos(theta)**74 + 4.03568466556359e+46*cos(theta)**72 - 8.61755221819593e+46*cos(theta)**70 + 1.53930389104609e+47*cos(theta)**68 - 2.33302346227744e+47*cos(theta)**66 + 3.03293050096068e+47*cos(theta)**64 - 3.41014383153192e+47*cos(theta)**62 + 3.3377753547758e+47*cos(theta)**60 - 2.85818208899525e+47*cos(theta)**58 + 2.14948816792955e+47*cos(theta)**56 - 1.42374700155333e+47*cos(theta)**54 + 8.32263872231544e+46*cos(theta)**52 - 4.29911139298413e+46*cos(theta)**50 + 1.96361351842117e+46*cos(theta)**48 - 7.93038327525626e+45*cos(theta)**46 + 2.83032644478974e+45*cos(theta)**44 - 8.91604667589441e+44*cos(theta)**42 + 2.47476343905386e+44*cos(theta)**40 - 6.03789641057871e+43*cos(theta)**38 + 1.29094926296741e+43*cos(theta)**36 - 2.40977195753916e+42*cos(theta)**34 + 3.90943339554502e+41*cos(theta)**32 - 5.48227018430967e+40*cos(theta)**30 + 6.60240180004071e+39*cos(theta)**28 - 6.77629074237141e+38*cos(theta)**26 + 5.87278531005522e+37*cos(theta)**24 - 4.25095396164501e+36*cos(theta)**22 + 2.5360804884814e+35*cos(theta)**20 - 1.22703155796146e+34*cos(theta)**18 + 4.71935214600561e+32*cos(theta)**16 - 1.40701181992714e+31*cos(theta)**14 + 3.14744531989601e+29*cos(theta)**12 - 5.05798371349249e+27*cos(theta)**10 + 5.49515372059783e+25*cos(theta)**8 - 3.68713884919097e+23*cos(theta)**6 + 1.31683530328249e+21*cos(theta)**4 - 1.87094762483896e+18*cos(theta)**2 + 441053188316587.0)*sin(8*phi)

#@torch.jit.script
def Yl92_m_minus_7(theta, phi):
    return 9.42747852128868e-14*(1.0 - cos(theta)**2)**3.5*(1.28428908544573e+40*cos(theta)**85 - 2.50541641259085e+41*cos(theta)**83 + 2.35522984863167e+42*cos(theta)**81 - 1.42103253436995e+43*cos(theta)**79 + 6.18390005422855e+43*cos(theta)**77 - 2.06789617813403e+44*cos(theta)**75 + 5.52833515830628e+44*cos(theta)**73 - 1.21373974904168e+45*cos(theta)**71 + 2.23087520441463e+45*cos(theta)**69 - 3.48212457056335e+45*cos(theta)**67 + 4.66604692455489e+45*cos(theta)**65 - 5.41292671671733e+45*cos(theta)**63 + 5.47176287668164e+45*cos(theta)**61 - 4.84437642202584e+45*cos(theta)**59 + 3.77103187356061e+45*cos(theta)**57 - 2.58863091191515e+45*cos(theta)**55 + 1.57030919288971e+45*cos(theta)**53 - 8.42963018232183e+44*cos(theta)**51 + 4.00737452739013e+44*cos(theta)**49 - 1.68731559048006e+44*cos(theta)**47 + 6.28961432175497e+43*cos(theta)**45 - 2.07349922695219e+43*cos(theta)**43 + 6.03600838793625e+42*cos(theta)**41 - 1.54817856681505e+42*cos(theta)**39 + 3.48905206207407e+41*cos(theta)**37 - 6.88506273582617e+40*cos(theta)**35 + 1.18467678652879e+40*cos(theta)**33 - 1.76847425300312e+39*cos(theta)**31 + 2.27669027587611e+38*cos(theta)**29 - 2.50973731198941e+37*cos(theta)**27 + 2.34911412402209e+36*cos(theta)**25 - 1.84824085288913e+35*cos(theta)**23 + 1.20765737546733e+34*cos(theta)**21 - 6.4580608313761e+32*cos(theta)**19 + 2.77608949765036e+31*cos(theta)**17 - 9.38007879951426e+29*cos(theta)**15 + 2.42111178453539e+28*cos(theta)**13 - 4.5981670122659e+26*cos(theta)**11 + 6.10572635621981e+24*cos(theta)**9 - 5.26734121312996e+22*cos(theta)**7 + 2.63367060656498e+20*cos(theta)**5 - 6.23649208279654e+17*cos(theta)**3 + 441053188316587.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl92_m_minus_6(theta, phi):
    return 8.69886066509475e-12*(1.0 - cos(theta)**2)**3*(1.49335940168108e+38*cos(theta)**86 - 2.98263858641768e+39*cos(theta)**84 + 2.87223152272155e+40*cos(theta)**82 - 1.77629066796244e+41*cos(theta)**80 + 7.9280769926007e+41*cos(theta)**78 - 2.72091602386056e+42*cos(theta)**76 + 7.47072318690038e+42*cos(theta)**74 - 1.68574965144678e+43*cos(theta)**72 + 3.18696457773518e+43*cos(theta)**70 - 5.12077142729904e+43*cos(theta)**68 + 7.06976806750741e+43*cos(theta)**66 - 8.45769799487082e+43*cos(theta)**64 + 8.82542399464781e+43*cos(theta)**62 - 8.0739607033764e+43*cos(theta)**60 + 6.50177909234587e+43*cos(theta)**58 - 4.62255519984848e+43*cos(theta)**56 + 2.90797998683279e+43*cos(theta)**54 - 1.62108272736958e+43*cos(theta)**52 + 8.01474905478027e+42*cos(theta)**50 - 3.51524081350012e+42*cos(theta)**48 + 1.36730746125108e+42*cos(theta)**46 - 4.71249824307315e+41*cos(theta)**44 + 1.43714485427054e+41*cos(theta)**42 - 3.87044641703763e+40*cos(theta)**40 + 9.1817159528265e+39*cos(theta)**38 - 1.91251742661838e+39*cos(theta)**36 + 3.48434348979057e+38*cos(theta)**34 - 5.52648204063475e+37*cos(theta)**32 + 7.58896758625369e+36*cos(theta)**30 - 8.96334754281932e+35*cos(theta)**28 + 9.03505432316188e+34*cos(theta)**26 - 7.70100355370472e+33*cos(theta)**24 + 5.48935170666969e+32*cos(theta)**22 - 3.22903041568805e+31*cos(theta)**20 + 1.54227194313909e+30*cos(theta)**18 - 5.86254924969642e+28*cos(theta)**16 + 1.72936556038242e+27*cos(theta)**14 - 3.83180584355492e+25*cos(theta)**12 + 6.10572635621981e+23*cos(theta)**10 - 6.58417651641245e+21*cos(theta)**8 + 4.38945101094163e+19*cos(theta)**6 - 1.55912302069914e+17*cos(theta)**4 + 220526594158294.0*cos(theta)**2 - 51803287328.7042)*sin(6*phi)

#@torch.jit.script
def Yl92_m_minus_5(theta, phi):
    return 8.0322097084169e-10*(1.0 - cos(theta)**2)**2.5*(1.71650505940354e+36*cos(theta)**87 - 3.50898657225609e+37*cos(theta)**85 + 3.46051990689344e+38*cos(theta)**83 - 2.19295144192893e+39*cos(theta)**81 + 1.00355404969629e+40*cos(theta)**79 - 3.53365717384488e+40*cos(theta)**77 + 9.96096424920051e+40*cos(theta)**75 - 2.3092460978723e+41*cos(theta)**73 + 4.48868250385237e+41*cos(theta)**71 - 7.42140786565079e+41*cos(theta)**69 + 1.05518926380708e+42*cos(theta)**67 - 1.3011843069032e+42*cos(theta)**65 + 1.4008609515314e+42*cos(theta)**63 - 1.32360011530761e+42*cos(theta)**61 + 1.10199645632981e+42*cos(theta)**59 - 8.10974596464646e+41*cos(theta)**57 + 5.28723633969598e+41*cos(theta)**55 - 3.05864665541431e+41*cos(theta)**53 + 1.57151942250593e+41*cos(theta)**51 - 7.17396084387779e+40*cos(theta)**49 + 2.90916481117251e+40*cos(theta)**47 - 1.04722183179403e+40*cos(theta)**45 + 3.34219733551287e+39*cos(theta)**43 - 9.44011321228691e+38*cos(theta)**41 + 2.35428614175039e+38*cos(theta)**39 - 5.16896601788751e+37*cos(theta)**37 + 9.95526711368734e+36*cos(theta)**35 - 1.67469152746507e+36*cos(theta)**33 + 2.44805406008184e+35*cos(theta)**31 - 3.0908094975239e+34*cos(theta)**29 + 3.34631641598588e+33*cos(theta)**27 - 3.08040142148189e+32*cos(theta)**25 + 2.38667465507378e+31*cos(theta)**23 - 1.53763353128002e+30*cos(theta)**21 + 8.11722075336363e+28*cos(theta)**19 - 3.44855838217436e+27*cos(theta)**17 + 1.15291037358828e+26*cos(theta)**15 - 2.94754295658071e+24*cos(theta)**13 + 5.55066032383619e+22*cos(theta)**11 - 7.31575168490272e+20*cos(theta)**9 + 6.27064430134519e+18*cos(theta)**7 - 3.11824604139827e+16*cos(theta)**5 + 73508864719431.2*cos(theta)**3 - 51803287328.7042*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl92_m_minus_4(theta, phi):
    return 7.42099675879653e-8*(1.0 - cos(theta)**2)**2*(1.95057393114039e+34*cos(theta)**88 - 4.08021694448383e+35*cos(theta)**86 + 4.11966655582552e+36*cos(theta)**84 - 2.6743310267426e+37*cos(theta)**82 + 1.25444256212036e+38*cos(theta)**80 - 4.53032971005754e+38*cos(theta)**78 + 1.31065319068428e+39*cos(theta)**76 - 3.12060283496257e+39*cos(theta)**74 + 6.23428125535051e+39*cos(theta)**72 - 1.0602011236644e+40*cos(theta)**70 + 1.55174891736335e+40*cos(theta)**68 - 1.97149137409576e+40*cos(theta)**66 + 2.18884523676781e+40*cos(theta)**64 - 2.13483889565743e+40*cos(theta)**62 + 1.83666076054968e+40*cos(theta)**60 - 1.39823206287008e+40*cos(theta)**58 + 9.44149346374282e+39*cos(theta)**56 - 5.66416047298946e+39*cos(theta)**54 + 3.02215273558834e+39*cos(theta)**52 - 1.43479216877556e+39*cos(theta)**50 + 6.06076002327606e+38*cos(theta)**48 - 2.27656919955225e+38*cos(theta)**46 + 7.59590303525653e+37*cos(theta)**44 - 2.24764600292546e+37*cos(theta)**42 + 5.88571535437596e+36*cos(theta)**40 - 1.36025421523356e+36*cos(theta)**38 + 2.76535197602426e+35*cos(theta)**36 - 4.92556331607375e+34*cos(theta)**34 + 7.65016893775574e+33*cos(theta)**32 - 1.03026983250797e+33*cos(theta)**30 + 1.19511300570924e+32*cos(theta)**28 - 1.18476977749303e+31*cos(theta)**26 + 9.94447772947407e+29*cos(theta)**24 - 6.98924332400011e+28*cos(theta)**22 + 4.05861037668181e+27*cos(theta)**20 - 1.91586576787465e+26*cos(theta)**18 + 7.20568983492676e+24*cos(theta)**16 - 2.10538782612908e+23*cos(theta)**14 + 4.62555026986349e+21*cos(theta)**12 - 7.31575168490272e+19*cos(theta)**10 + 7.83830537668149e+17*cos(theta)**8 - 5.19707673566379e+15*cos(theta)**6 + 18377216179857.8*cos(theta)**4 - 25901643664.3521*cos(theta)**2 + 6068801.23344707)*sin(4*phi)

#@torch.jit.script
def Yl92_m_minus_3(theta, phi):
    return 6.85950633855616e-6*(1.0 - cos(theta)**2)**1.5*(2.19165610240493e+32*cos(theta)**89 - 4.68990453388946e+33*cos(theta)**87 + 4.84666653626532e+34*cos(theta)**85 - 3.22208557438868e+35*cos(theta)**83 + 1.54869452113625e+36*cos(theta)**81 - 5.73459456969309e+36*cos(theta)**79 + 1.70214700088867e+37*cos(theta)**77 - 4.16080377995009e+37*cos(theta)**75 + 8.54011130869933e+37*cos(theta)**73 - 1.49324101924563e+38*cos(theta)**71 + 2.24891147443963e+38*cos(theta)**69 - 2.9425244389489e+38*cos(theta)**67 + 3.36745421041202e+38*cos(theta)**65 - 3.38863316771021e+38*cos(theta)**63 + 3.01091927958964e+38*cos(theta)**61 - 2.36988485232217e+38*cos(theta)**59 + 1.65640236206014e+38*cos(theta)**57 - 1.02984735872536e+38*cos(theta)**55 + 5.70217497280818e+37*cos(theta)**53 - 2.81331797799129e+37*cos(theta)**51 + 1.23688980066858e+37*cos(theta)**49 - 4.84376425436648e+36*cos(theta)**47 + 1.68797845227923e+36*cos(theta)**45 - 5.22708372773362e+35*cos(theta)**43 + 1.4355403303356e+35*cos(theta)**41 - 3.48783132111168e+34*cos(theta)**39 + 7.47392425952503e+33*cos(theta)**37 - 1.4073038045925e+33*cos(theta)**35 + 2.31823301144113e+32*cos(theta)**33 - 3.32345107260635e+31*cos(theta)**31 + 4.12107933003187e+30*cos(theta)**29 - 4.38803621293716e+29*cos(theta)**27 + 3.97779109178963e+28*cos(theta)**25 - 3.03880144521744e+27*cos(theta)**23 + 1.93267160794372e+26*cos(theta)**21 - 1.00835040414455e+25*cos(theta)**19 + 4.23864107936868e+23*cos(theta)**17 - 1.40359188408605e+22*cos(theta)**15 + 3.55811559220269e+20*cos(theta)**13 - 6.65068334991157e+18*cos(theta)**11 + 8.70922819631277e+16*cos(theta)**9 - 742439533666255.0*cos(theta)**7 + 3675443235971.56*cos(theta)**5 - 8633881221.4507*cos(theta)**3 + 6068801.23344707*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl92_m_minus_2(theta, phi):
    return 0.000634272553902751*(1.0 - cos(theta)**2)*(2.43517344711659e+30*cos(theta)**90 - 5.32943697032893e+31*cos(theta)**88 + 5.63565876309921e+32*cos(theta)**86 - 3.83581615998652e+33*cos(theta)**84 + 1.88865185504421e+34*cos(theta)**82 - 7.16824321211636e+34*cos(theta)**80 + 2.18223974472907e+35*cos(theta)**78 - 5.4747418157238e+35*cos(theta)**76 + 1.15406909577018e+36*cos(theta)**74 - 2.07394586006338e+36*cos(theta)**72 + 3.2127306777709e+36*cos(theta)**70 - 4.32724182198368e+36*cos(theta)**68 + 5.10220334910912e+36*cos(theta)**66 - 5.2947393245472e+36*cos(theta)**64 + 4.85632141869297e+36*cos(theta)**62 - 3.94980808720362e+36*cos(theta)**60 + 2.85586614148301e+36*cos(theta)**58 - 1.83901314058099e+36*cos(theta)**56 + 1.05595832829781e+36*cos(theta)**54 - 5.41022688075248e+35*cos(theta)**52 + 2.47377960133717e+35*cos(theta)**50 - 1.00911755299302e+35*cos(theta)**48 + 3.66951837452006e+34*cos(theta)**46 - 1.18797357448491e+34*cos(theta)**44 + 3.41795316746572e+33*cos(theta)**42 - 8.7195783027792e+32*cos(theta)**40 + 1.96682217355922e+32*cos(theta)**38 - 3.90917723497917e+31*cos(theta)**36 + 6.81833238659157e+30*cos(theta)**34 - 1.03857846018948e+30*cos(theta)**32 + 1.37369311001062e+29*cos(theta)**30 - 1.5671557903347e+28*cos(theta)**28 + 1.52991965068832e+27*cos(theta)**26 - 1.2661672688406e+26*cos(theta)**24 + 8.78487094519873e+24*cos(theta)**22 - 5.04175202072275e+23*cos(theta)**20 + 2.35480059964927e+22*cos(theta)**18 - 8.77244927553782e+20*cos(theta)**16 + 2.54151113728763e+19*cos(theta)**14 - 5.54223612492631e+17*cos(theta)**12 + 8.70922819631277e+15*cos(theta)**10 - 92804941708281.9*cos(theta)**8 + 612573872661.927*cos(theta)**6 - 2158470305.36267*cos(theta)**4 + 3034400.61672353*cos(theta)**2 - 709.801313853458)*sin(2*phi)

#@torch.jit.script
def Yl92_m_minus_1(theta, phi):
    return 0.0586624966031447*(1.0 - cos(theta)**2)**0.5*(2.6760147770512e+28*cos(theta)**91 - 5.98813142733587e+29*cos(theta)**89 + 6.47776869321748e+30*cos(theta)**87 - 4.51272489410179e+31*cos(theta)**85 + 2.27548416270387e+32*cos(theta)**83 - 8.84968297792144e+32*cos(theta)**81 + 2.76232879079629e+33*cos(theta)**79 - 7.1100543061348e+33*cos(theta)**77 + 1.53875879436024e+34*cos(theta)**75 - 2.84102172611421e+34*cos(theta)**73 + 4.52497278559282e+34*cos(theta)**71 - 6.27136495939663e+34*cos(theta)**69 + 7.61522887926734e+34*cos(theta)**67 - 8.14575280699569e+34*cos(theta)**65 + 7.70844669633805e+34*cos(theta)**63 - 6.47509522492396e+34*cos(theta)**61 + 4.84045108725933e+34*cos(theta)**59 - 3.22633884312455e+34*cos(theta)**57 + 1.91992423326875e+34*cos(theta)**55 - 1.02079752467028e+34*cos(theta)**53 + 4.85054823791602e+33*cos(theta)**51 - 2.05942357753677e+33*cos(theta)**49 + 7.80748590323418e+32*cos(theta)**47 - 2.63994127663314e+32*cos(theta)**45 + 7.9487282964319e+31*cos(theta)**43 - 2.126726415312e+31*cos(theta)**41 + 5.04313377835697e+30*cos(theta)**39 - 1.05653438783221e+30*cos(theta)**37 + 1.94809496759759e+29*cos(theta)**35 - 3.14720745511965e+28*cos(theta)**33 + 4.43126809680847e+27*cos(theta)**31 - 5.40398548391276e+26*cos(theta)**29 + 5.6663690766234e+25*cos(theta)**27 - 5.0646690753624e+24*cos(theta)**25 + 3.81950910660814e+23*cos(theta)**23 - 2.40083429558226e+22*cos(theta)**21 + 1.23936873665751e+21*cos(theta)**19 - 5.16026427972813e+19*cos(theta)**17 + 1.69434075819176e+18*cos(theta)**15 - 4.26325855763562e+16*cos(theta)**13 + 791748017846615.0*cos(theta)**11 - 10311660189809.1*cos(theta)**9 + 87510553237.4181*cos(theta)**7 - 431694061.072535*cos(theta)**5 + 1011466.87224118*cos(theta)**3 - 709.801313853458*cos(theta))*sin(phi)

#@torch.jit.script
def Yl92_m0(theta, phi):
    return 3.50615801430925e+27*cos(theta)**92 - 8.02009696606477e+28*cos(theta)**90 + 8.87306307985895e+29*cos(theta)**88 - 6.32515558094973e+30*cos(theta)**86 + 3.26531689948747e+31*cos(theta)**84 - 1.30090225275581e+32*cos(theta)**82 + 4.16213524219849e+32*cos(theta)**80 - 1.09877588682934e+33*cos(theta)**78 + 2.4405502870921e+33*cos(theta)**76 - 4.6277899655439e+33*cos(theta)**74 + 7.57555193753581e+33*cos(theta)**72 - 1.07992809550148e+34*cos(theta)**70 + 1.34991011937685e+34*cos(theta)**68 - 1.48770936233211e+34*cos(theta)**66 + 1.45183647961891e+34*cos(theta)**64 - 1.25888272813407e+34*cos(theta)**62 + 9.72445767525137e+33*cos(theta)**60 - 6.70521623887609e+33*cos(theta)**58 + 4.13263327474354e+33*cos(theta)**56 - 2.27864491339243e+33*cos(theta)**54 + 1.12439340381537e+33*cos(theta)**52 - 4.96485399087305e+32*cos(theta)**50 + 1.96065317176644e+32*cos(theta)**48 - 6.91778785659225e+31*cos(theta)**46 + 2.17758833077037e+31*cos(theta)**44 - 6.10369943972969e+30*cos(theta)**42 + 1.5197470264914e+30*cos(theta)**40 - 3.35143534255949e+29*cos(theta)**38 + 6.52286557535803e+28*cos(theta)**36 - 1.1157766257061e+28*cos(theta)**34 + 1.66920183205632e+27*cos(theta)**32 - 2.17131945633343e+26*cos(theta)**30 + 2.43936974045724e+25*cos(theta)**28 - 2.34805643466472e+24*cos(theta)**26 + 1.91834676034699e+23*cos(theta)**24 - 1.31543777852365e+22*cos(theta)**22 + 7.46966880135112e+20*cos(theta)**20 - 3.45565393780549e+19*cos(theta)**18 + 1.27647284520579e+18*cos(theta)**16 - 3.67066238736389e+16*cos(theta)**14 + 795310183928843.0*cos(theta)**12 - 12429664252735.9*cos(theta)**10 + 131856410036.095*cos(theta)**8 - 867272605.358388*cos(theta)**6 + 3048052.73673285*cos(theta)**4 - 4277.96875330927*cos(theta)**2 + 0.999992695958221

#@torch.jit.script
def Yl92_m1(theta, phi):
    return 0.0586624966031447*(1.0 - cos(theta)**2)**0.5*(2.6760147770512e+28*cos(theta)**91 - 5.98813142733587e+29*cos(theta)**89 + 6.47776869321748e+30*cos(theta)**87 - 4.51272489410179e+31*cos(theta)**85 + 2.27548416270387e+32*cos(theta)**83 - 8.84968297792144e+32*cos(theta)**81 + 2.76232879079629e+33*cos(theta)**79 - 7.1100543061348e+33*cos(theta)**77 + 1.53875879436024e+34*cos(theta)**75 - 2.84102172611421e+34*cos(theta)**73 + 4.52497278559282e+34*cos(theta)**71 - 6.27136495939663e+34*cos(theta)**69 + 7.61522887926734e+34*cos(theta)**67 - 8.14575280699569e+34*cos(theta)**65 + 7.70844669633805e+34*cos(theta)**63 - 6.47509522492396e+34*cos(theta)**61 + 4.84045108725933e+34*cos(theta)**59 - 3.22633884312455e+34*cos(theta)**57 + 1.91992423326875e+34*cos(theta)**55 - 1.02079752467028e+34*cos(theta)**53 + 4.85054823791602e+33*cos(theta)**51 - 2.05942357753677e+33*cos(theta)**49 + 7.80748590323418e+32*cos(theta)**47 - 2.63994127663314e+32*cos(theta)**45 + 7.9487282964319e+31*cos(theta)**43 - 2.126726415312e+31*cos(theta)**41 + 5.04313377835697e+30*cos(theta)**39 - 1.05653438783221e+30*cos(theta)**37 + 1.94809496759759e+29*cos(theta)**35 - 3.14720745511965e+28*cos(theta)**33 + 4.43126809680847e+27*cos(theta)**31 - 5.40398548391276e+26*cos(theta)**29 + 5.6663690766234e+25*cos(theta)**27 - 5.0646690753624e+24*cos(theta)**25 + 3.81950910660814e+23*cos(theta)**23 - 2.40083429558226e+22*cos(theta)**21 + 1.23936873665751e+21*cos(theta)**19 - 5.16026427972813e+19*cos(theta)**17 + 1.69434075819176e+18*cos(theta)**15 - 4.26325855763562e+16*cos(theta)**13 + 791748017846615.0*cos(theta)**11 - 10311660189809.1*cos(theta)**9 + 87510553237.4181*cos(theta)**7 - 431694061.072535*cos(theta)**5 + 1011466.87224118*cos(theta)**3 - 709.801313853458*cos(theta))*cos(phi)

#@torch.jit.script
def Yl92_m2(theta, phi):
    return 0.000634272553902751*(1.0 - cos(theta)**2)*(2.43517344711659e+30*cos(theta)**90 - 5.32943697032893e+31*cos(theta)**88 + 5.63565876309921e+32*cos(theta)**86 - 3.83581615998652e+33*cos(theta)**84 + 1.88865185504421e+34*cos(theta)**82 - 7.16824321211636e+34*cos(theta)**80 + 2.18223974472907e+35*cos(theta)**78 - 5.4747418157238e+35*cos(theta)**76 + 1.15406909577018e+36*cos(theta)**74 - 2.07394586006338e+36*cos(theta)**72 + 3.2127306777709e+36*cos(theta)**70 - 4.32724182198368e+36*cos(theta)**68 + 5.10220334910912e+36*cos(theta)**66 - 5.2947393245472e+36*cos(theta)**64 + 4.85632141869297e+36*cos(theta)**62 - 3.94980808720362e+36*cos(theta)**60 + 2.85586614148301e+36*cos(theta)**58 - 1.83901314058099e+36*cos(theta)**56 + 1.05595832829781e+36*cos(theta)**54 - 5.41022688075248e+35*cos(theta)**52 + 2.47377960133717e+35*cos(theta)**50 - 1.00911755299302e+35*cos(theta)**48 + 3.66951837452006e+34*cos(theta)**46 - 1.18797357448491e+34*cos(theta)**44 + 3.41795316746572e+33*cos(theta)**42 - 8.7195783027792e+32*cos(theta)**40 + 1.96682217355922e+32*cos(theta)**38 - 3.90917723497917e+31*cos(theta)**36 + 6.81833238659157e+30*cos(theta)**34 - 1.03857846018948e+30*cos(theta)**32 + 1.37369311001062e+29*cos(theta)**30 - 1.5671557903347e+28*cos(theta)**28 + 1.52991965068832e+27*cos(theta)**26 - 1.2661672688406e+26*cos(theta)**24 + 8.78487094519873e+24*cos(theta)**22 - 5.04175202072275e+23*cos(theta)**20 + 2.35480059964927e+22*cos(theta)**18 - 8.77244927553782e+20*cos(theta)**16 + 2.54151113728763e+19*cos(theta)**14 - 5.54223612492631e+17*cos(theta)**12 + 8.70922819631277e+15*cos(theta)**10 - 92804941708281.9*cos(theta)**8 + 612573872661.927*cos(theta)**6 - 2158470305.36267*cos(theta)**4 + 3034400.61672353*cos(theta)**2 - 709.801313853458)*cos(2*phi)

#@torch.jit.script
def Yl92_m3(theta, phi):
    return 6.85950633855616e-6*(1.0 - cos(theta)**2)**1.5*(2.19165610240493e+32*cos(theta)**89 - 4.68990453388946e+33*cos(theta)**87 + 4.84666653626532e+34*cos(theta)**85 - 3.22208557438868e+35*cos(theta)**83 + 1.54869452113625e+36*cos(theta)**81 - 5.73459456969309e+36*cos(theta)**79 + 1.70214700088867e+37*cos(theta)**77 - 4.16080377995009e+37*cos(theta)**75 + 8.54011130869933e+37*cos(theta)**73 - 1.49324101924563e+38*cos(theta)**71 + 2.24891147443963e+38*cos(theta)**69 - 2.9425244389489e+38*cos(theta)**67 + 3.36745421041202e+38*cos(theta)**65 - 3.38863316771021e+38*cos(theta)**63 + 3.01091927958964e+38*cos(theta)**61 - 2.36988485232217e+38*cos(theta)**59 + 1.65640236206014e+38*cos(theta)**57 - 1.02984735872536e+38*cos(theta)**55 + 5.70217497280818e+37*cos(theta)**53 - 2.81331797799129e+37*cos(theta)**51 + 1.23688980066858e+37*cos(theta)**49 - 4.84376425436648e+36*cos(theta)**47 + 1.68797845227923e+36*cos(theta)**45 - 5.22708372773362e+35*cos(theta)**43 + 1.4355403303356e+35*cos(theta)**41 - 3.48783132111168e+34*cos(theta)**39 + 7.47392425952503e+33*cos(theta)**37 - 1.4073038045925e+33*cos(theta)**35 + 2.31823301144113e+32*cos(theta)**33 - 3.32345107260635e+31*cos(theta)**31 + 4.12107933003187e+30*cos(theta)**29 - 4.38803621293716e+29*cos(theta)**27 + 3.97779109178963e+28*cos(theta)**25 - 3.03880144521744e+27*cos(theta)**23 + 1.93267160794372e+26*cos(theta)**21 - 1.00835040414455e+25*cos(theta)**19 + 4.23864107936868e+23*cos(theta)**17 - 1.40359188408605e+22*cos(theta)**15 + 3.55811559220269e+20*cos(theta)**13 - 6.65068334991157e+18*cos(theta)**11 + 8.70922819631277e+16*cos(theta)**9 - 742439533666255.0*cos(theta)**7 + 3675443235971.56*cos(theta)**5 - 8633881221.4507*cos(theta)**3 + 6068801.23344707*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl92_m4(theta, phi):
    return 7.42099675879653e-8*(1.0 - cos(theta)**2)**2*(1.95057393114039e+34*cos(theta)**88 - 4.08021694448383e+35*cos(theta)**86 + 4.11966655582552e+36*cos(theta)**84 - 2.6743310267426e+37*cos(theta)**82 + 1.25444256212036e+38*cos(theta)**80 - 4.53032971005754e+38*cos(theta)**78 + 1.31065319068428e+39*cos(theta)**76 - 3.12060283496257e+39*cos(theta)**74 + 6.23428125535051e+39*cos(theta)**72 - 1.0602011236644e+40*cos(theta)**70 + 1.55174891736335e+40*cos(theta)**68 - 1.97149137409576e+40*cos(theta)**66 + 2.18884523676781e+40*cos(theta)**64 - 2.13483889565743e+40*cos(theta)**62 + 1.83666076054968e+40*cos(theta)**60 - 1.39823206287008e+40*cos(theta)**58 + 9.44149346374282e+39*cos(theta)**56 - 5.66416047298946e+39*cos(theta)**54 + 3.02215273558834e+39*cos(theta)**52 - 1.43479216877556e+39*cos(theta)**50 + 6.06076002327606e+38*cos(theta)**48 - 2.27656919955225e+38*cos(theta)**46 + 7.59590303525653e+37*cos(theta)**44 - 2.24764600292546e+37*cos(theta)**42 + 5.88571535437596e+36*cos(theta)**40 - 1.36025421523356e+36*cos(theta)**38 + 2.76535197602426e+35*cos(theta)**36 - 4.92556331607375e+34*cos(theta)**34 + 7.65016893775574e+33*cos(theta)**32 - 1.03026983250797e+33*cos(theta)**30 + 1.19511300570924e+32*cos(theta)**28 - 1.18476977749303e+31*cos(theta)**26 + 9.94447772947407e+29*cos(theta)**24 - 6.98924332400011e+28*cos(theta)**22 + 4.05861037668181e+27*cos(theta)**20 - 1.91586576787465e+26*cos(theta)**18 + 7.20568983492676e+24*cos(theta)**16 - 2.10538782612908e+23*cos(theta)**14 + 4.62555026986349e+21*cos(theta)**12 - 7.31575168490272e+19*cos(theta)**10 + 7.83830537668149e+17*cos(theta)**8 - 5.19707673566379e+15*cos(theta)**6 + 18377216179857.8*cos(theta)**4 - 25901643664.3521*cos(theta)**2 + 6068801.23344707)*cos(4*phi)

#@torch.jit.script
def Yl92_m5(theta, phi):
    return 8.0322097084169e-10*(1.0 - cos(theta)**2)**2.5*(1.71650505940354e+36*cos(theta)**87 - 3.50898657225609e+37*cos(theta)**85 + 3.46051990689344e+38*cos(theta)**83 - 2.19295144192893e+39*cos(theta)**81 + 1.00355404969629e+40*cos(theta)**79 - 3.53365717384488e+40*cos(theta)**77 + 9.96096424920051e+40*cos(theta)**75 - 2.3092460978723e+41*cos(theta)**73 + 4.48868250385237e+41*cos(theta)**71 - 7.42140786565079e+41*cos(theta)**69 + 1.05518926380708e+42*cos(theta)**67 - 1.3011843069032e+42*cos(theta)**65 + 1.4008609515314e+42*cos(theta)**63 - 1.32360011530761e+42*cos(theta)**61 + 1.10199645632981e+42*cos(theta)**59 - 8.10974596464646e+41*cos(theta)**57 + 5.28723633969598e+41*cos(theta)**55 - 3.05864665541431e+41*cos(theta)**53 + 1.57151942250593e+41*cos(theta)**51 - 7.17396084387779e+40*cos(theta)**49 + 2.90916481117251e+40*cos(theta)**47 - 1.04722183179403e+40*cos(theta)**45 + 3.34219733551287e+39*cos(theta)**43 - 9.44011321228691e+38*cos(theta)**41 + 2.35428614175039e+38*cos(theta)**39 - 5.16896601788751e+37*cos(theta)**37 + 9.95526711368734e+36*cos(theta)**35 - 1.67469152746507e+36*cos(theta)**33 + 2.44805406008184e+35*cos(theta)**31 - 3.0908094975239e+34*cos(theta)**29 + 3.34631641598588e+33*cos(theta)**27 - 3.08040142148189e+32*cos(theta)**25 + 2.38667465507378e+31*cos(theta)**23 - 1.53763353128002e+30*cos(theta)**21 + 8.11722075336363e+28*cos(theta)**19 - 3.44855838217436e+27*cos(theta)**17 + 1.15291037358828e+26*cos(theta)**15 - 2.94754295658071e+24*cos(theta)**13 + 5.55066032383619e+22*cos(theta)**11 - 7.31575168490272e+20*cos(theta)**9 + 6.27064430134519e+18*cos(theta)**7 - 3.11824604139827e+16*cos(theta)**5 + 73508864719431.2*cos(theta)**3 - 51803287328.7042*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl92_m6(theta, phi):
    return 8.69886066509475e-12*(1.0 - cos(theta)**2)**3*(1.49335940168108e+38*cos(theta)**86 - 2.98263858641768e+39*cos(theta)**84 + 2.87223152272155e+40*cos(theta)**82 - 1.77629066796244e+41*cos(theta)**80 + 7.9280769926007e+41*cos(theta)**78 - 2.72091602386056e+42*cos(theta)**76 + 7.47072318690038e+42*cos(theta)**74 - 1.68574965144678e+43*cos(theta)**72 + 3.18696457773518e+43*cos(theta)**70 - 5.12077142729904e+43*cos(theta)**68 + 7.06976806750741e+43*cos(theta)**66 - 8.45769799487082e+43*cos(theta)**64 + 8.82542399464781e+43*cos(theta)**62 - 8.0739607033764e+43*cos(theta)**60 + 6.50177909234587e+43*cos(theta)**58 - 4.62255519984848e+43*cos(theta)**56 + 2.90797998683279e+43*cos(theta)**54 - 1.62108272736958e+43*cos(theta)**52 + 8.01474905478027e+42*cos(theta)**50 - 3.51524081350012e+42*cos(theta)**48 + 1.36730746125108e+42*cos(theta)**46 - 4.71249824307315e+41*cos(theta)**44 + 1.43714485427054e+41*cos(theta)**42 - 3.87044641703763e+40*cos(theta)**40 + 9.1817159528265e+39*cos(theta)**38 - 1.91251742661838e+39*cos(theta)**36 + 3.48434348979057e+38*cos(theta)**34 - 5.52648204063475e+37*cos(theta)**32 + 7.58896758625369e+36*cos(theta)**30 - 8.96334754281932e+35*cos(theta)**28 + 9.03505432316188e+34*cos(theta)**26 - 7.70100355370472e+33*cos(theta)**24 + 5.48935170666969e+32*cos(theta)**22 - 3.22903041568805e+31*cos(theta)**20 + 1.54227194313909e+30*cos(theta)**18 - 5.86254924969642e+28*cos(theta)**16 + 1.72936556038242e+27*cos(theta)**14 - 3.83180584355492e+25*cos(theta)**12 + 6.10572635621981e+23*cos(theta)**10 - 6.58417651641245e+21*cos(theta)**8 + 4.38945101094163e+19*cos(theta)**6 - 1.55912302069914e+17*cos(theta)**4 + 220526594158294.0*cos(theta)**2 - 51803287328.7042)*cos(6*phi)

#@torch.jit.script
def Yl92_m7(theta, phi):
    return 9.42747852128868e-14*(1.0 - cos(theta)**2)**3.5*(1.28428908544573e+40*cos(theta)**85 - 2.50541641259085e+41*cos(theta)**83 + 2.35522984863167e+42*cos(theta)**81 - 1.42103253436995e+43*cos(theta)**79 + 6.18390005422855e+43*cos(theta)**77 - 2.06789617813403e+44*cos(theta)**75 + 5.52833515830628e+44*cos(theta)**73 - 1.21373974904168e+45*cos(theta)**71 + 2.23087520441463e+45*cos(theta)**69 - 3.48212457056335e+45*cos(theta)**67 + 4.66604692455489e+45*cos(theta)**65 - 5.41292671671733e+45*cos(theta)**63 + 5.47176287668164e+45*cos(theta)**61 - 4.84437642202584e+45*cos(theta)**59 + 3.77103187356061e+45*cos(theta)**57 - 2.58863091191515e+45*cos(theta)**55 + 1.57030919288971e+45*cos(theta)**53 - 8.42963018232183e+44*cos(theta)**51 + 4.00737452739013e+44*cos(theta)**49 - 1.68731559048006e+44*cos(theta)**47 + 6.28961432175497e+43*cos(theta)**45 - 2.07349922695219e+43*cos(theta)**43 + 6.03600838793625e+42*cos(theta)**41 - 1.54817856681505e+42*cos(theta)**39 + 3.48905206207407e+41*cos(theta)**37 - 6.88506273582617e+40*cos(theta)**35 + 1.18467678652879e+40*cos(theta)**33 - 1.76847425300312e+39*cos(theta)**31 + 2.27669027587611e+38*cos(theta)**29 - 2.50973731198941e+37*cos(theta)**27 + 2.34911412402209e+36*cos(theta)**25 - 1.84824085288913e+35*cos(theta)**23 + 1.20765737546733e+34*cos(theta)**21 - 6.4580608313761e+32*cos(theta)**19 + 2.77608949765036e+31*cos(theta)**17 - 9.38007879951426e+29*cos(theta)**15 + 2.42111178453539e+28*cos(theta)**13 - 4.5981670122659e+26*cos(theta)**11 + 6.10572635621981e+24*cos(theta)**9 - 5.26734121312996e+22*cos(theta)**7 + 2.63367060656498e+20*cos(theta)**5 - 6.23649208279654e+17*cos(theta)**3 + 441053188316587.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl92_m8(theta, phi):
    return 1.02255361584935e-15*(1.0 - cos(theta)**2)**4*(1.09164572262887e+42*cos(theta)**84 - 2.0794956224504e+43*cos(theta)**82 + 1.90773617739166e+44*cos(theta)**80 - 1.12261570215226e+45*cos(theta)**78 + 4.76160304175598e+45*cos(theta)**76 - 1.55092213360052e+46*cos(theta)**74 + 4.03568466556359e+46*cos(theta)**72 - 8.61755221819593e+46*cos(theta)**70 + 1.53930389104609e+47*cos(theta)**68 - 2.33302346227744e+47*cos(theta)**66 + 3.03293050096068e+47*cos(theta)**64 - 3.41014383153192e+47*cos(theta)**62 + 3.3377753547758e+47*cos(theta)**60 - 2.85818208899525e+47*cos(theta)**58 + 2.14948816792955e+47*cos(theta)**56 - 1.42374700155333e+47*cos(theta)**54 + 8.32263872231544e+46*cos(theta)**52 - 4.29911139298413e+46*cos(theta)**50 + 1.96361351842117e+46*cos(theta)**48 - 7.93038327525626e+45*cos(theta)**46 + 2.83032644478974e+45*cos(theta)**44 - 8.91604667589441e+44*cos(theta)**42 + 2.47476343905386e+44*cos(theta)**40 - 6.03789641057871e+43*cos(theta)**38 + 1.29094926296741e+43*cos(theta)**36 - 2.40977195753916e+42*cos(theta)**34 + 3.90943339554502e+41*cos(theta)**32 - 5.48227018430967e+40*cos(theta)**30 + 6.60240180004071e+39*cos(theta)**28 - 6.77629074237141e+38*cos(theta)**26 + 5.87278531005522e+37*cos(theta)**24 - 4.25095396164501e+36*cos(theta)**22 + 2.5360804884814e+35*cos(theta)**20 - 1.22703155796146e+34*cos(theta)**18 + 4.71935214600561e+32*cos(theta)**16 - 1.40701181992714e+31*cos(theta)**14 + 3.14744531989601e+29*cos(theta)**12 - 5.05798371349249e+27*cos(theta)**10 + 5.49515372059783e+25*cos(theta)**8 - 3.68713884919097e+23*cos(theta)**6 + 1.31683530328249e+21*cos(theta)**4 - 1.87094762483896e+18*cos(theta)**2 + 441053188316587.0)*cos(8*phi)

#@torch.jit.script
def Yl92_m9(theta, phi):
    return 1.11016046922451e-17*(1.0 - cos(theta)**2)**4.5*(9.16982407008251e+43*cos(theta)**83 - 1.70518641040933e+45*cos(theta)**81 + 1.52618894191332e+46*cos(theta)**79 - 8.75640247678762e+46*cos(theta)**77 + 3.61881831173454e+47*cos(theta)**75 - 1.14768237886438e+48*cos(theta)**73 + 2.90569295920578e+48*cos(theta)**71 - 6.03228655273715e+48*cos(theta)**69 + 1.04672664591134e+49*cos(theta)**67 - 1.53979548510311e+49*cos(theta)**65 + 1.94107552061483e+49*cos(theta)**63 - 2.11428917554979e+49*cos(theta)**61 + 2.00266521286548e+49*cos(theta)**59 - 1.65774561161724e+49*cos(theta)**57 + 1.20371337404055e+49*cos(theta)**55 - 7.688233808388e+48*cos(theta)**53 + 4.32777213560403e+48*cos(theta)**51 - 2.14955569649207e+48*cos(theta)**49 + 9.42534488842159e+47*cos(theta)**47 - 3.64797630661788e+47*cos(theta)**45 + 1.24534363570748e+47*cos(theta)**43 - 3.74473960387565e+46*cos(theta)**41 + 9.89905375621545e+45*cos(theta)**39 - 2.29440063601991e+45*cos(theta)**37 + 4.64741734668266e+44*cos(theta)**35 - 8.19322465563314e+43*cos(theta)**33 + 1.25101868657441e+43*cos(theta)**31 - 1.6446810552929e+42*cos(theta)**29 + 1.8486725040114e+41*cos(theta)**27 - 1.76183559301657e+40*cos(theta)**25 + 1.40946847441325e+39*cos(theta)**23 - 9.35209871561902e+37*cos(theta)**21 + 5.07216097696279e+36*cos(theta)**19 - 2.20865680433063e+35*cos(theta)**17 + 7.55096343360898e+33*cos(theta)**15 - 1.969816547898e+32*cos(theta)**13 + 3.77693438387521e+30*cos(theta)**11 - 5.05798371349249e+28*cos(theta)**9 + 4.39612297647827e+26*cos(theta)**7 - 2.21228330951458e+24*cos(theta)**5 + 5.26734121312996e+21*cos(theta)**3 - 3.74189524967793e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl92_m10(theta, phi):
    return 1.20655361938957e-19*(1.0 - cos(theta)**2)**5*(7.61095397816848e+45*cos(theta)**82 - 1.38120099243156e+47*cos(theta)**80 + 1.20568926411153e+48*cos(theta)**78 - 6.74242990712647e+48*cos(theta)**76 + 2.71411373380091e+49*cos(theta)**74 - 8.37808136571e+49*cos(theta)**72 + 2.06304200103611e+50*cos(theta)**70 - 4.16227772138863e+50*cos(theta)**68 + 7.013068527606e+50*cos(theta)**66 - 1.00086706531702e+51*cos(theta)**64 + 1.22287757798734e+51*cos(theta)**62 - 1.28971639708537e+51*cos(theta)**60 + 1.18157247559063e+51*cos(theta)**58 - 9.44914998621828e+50*cos(theta)**56 + 6.620423557223e+50*cos(theta)**54 - 4.07476391844564e+50*cos(theta)**52 + 2.20716378915805e+50*cos(theta)**50 - 1.05328229128111e+50*cos(theta)**48 + 4.42991209755815e+49*cos(theta)**46 - 1.64158933797805e+49*cos(theta)**44 + 5.35497763354218e+48*cos(theta)**42 - 1.53534323758902e+48*cos(theta)**40 + 3.86063096492403e+47*cos(theta)**38 - 8.48928235327366e+46*cos(theta)**36 + 1.62659607133893e+46*cos(theta)**34 - 2.70376413635894e+45*cos(theta)**32 + 3.87815792838066e+44*cos(theta)**30 - 4.76957506034941e+43*cos(theta)**28 + 4.99141576083078e+42*cos(theta)**26 - 4.40458898254142e+41*cos(theta)**24 + 3.24177749115048e+40*cos(theta)**22 - 1.96394073027999e+39*cos(theta)**20 + 9.6371058562293e+37*cos(theta)**18 - 3.75471656736207e+36*cos(theta)**16 + 1.13264451504135e+35*cos(theta)**14 - 2.56076151226739e+33*cos(theta)**12 + 4.15462782226273e+31*cos(theta)**10 - 4.55218534214324e+29*cos(theta)**8 + 3.07728608353479e+27*cos(theta)**6 - 1.10614165475729e+25*cos(theta)**4 + 1.58020236393899e+22*cos(theta)**2 - 3.74189524967793e+18)*cos(10*phi)

#@torch.jit.script
def Yl92_m11(theta, phi):
    return 1.31286807653569e-21*(1.0 - cos(theta)**2)**5.5*(6.24098226209815e+47*cos(theta)**81 - 1.10496079394525e+49*cos(theta)**79 + 9.4043762600699e+49*cos(theta)**77 - 5.12424672941612e+50*cos(theta)**75 + 2.00844416301267e+51*cos(theta)**73 - 6.0322185833112e+51*cos(theta)**71 + 1.44412940072527e+52*cos(theta)**69 - 2.83034885054427e+52*cos(theta)**67 + 4.62862522821996e+52*cos(theta)**65 - 6.40554921802895e+52*cos(theta)**63 + 7.58184098352154e+52*cos(theta)**61 - 7.73829838251222e+52*cos(theta)**59 + 6.85312035842568e+52*cos(theta)**57 - 5.29152399228224e+52*cos(theta)**55 + 3.57502872090042e+52*cos(theta)**53 - 2.11887723759173e+52*cos(theta)**51 + 1.10358189457903e+52*cos(theta)**49 - 5.05575499814934e+51*cos(theta)**47 + 2.03775956487675e+51*cos(theta)**45 - 7.2229930871034e+50*cos(theta)**43 + 2.24909060608772e+50*cos(theta)**41 - 6.14137295035607e+49*cos(theta)**39 + 1.46703976667113e+49*cos(theta)**37 - 3.05614164717852e+48*cos(theta)**35 + 5.53042664255237e+47*cos(theta)**33 - 8.65204523634859e+46*cos(theta)**31 + 1.1634473785142e+46*cos(theta)**29 - 1.33548101689784e+45*cos(theta)**27 + 1.297768097816e+44*cos(theta)**25 - 1.05710135580994e+43*cos(theta)**23 + 7.13191048053106e+41*cos(theta)**21 - 3.92788146055999e+40*cos(theta)**19 + 1.73467905412127e+39*cos(theta)**17 - 6.00754650777931e+37*cos(theta)**15 + 1.58570232105789e+36*cos(theta)**13 - 3.07291381472087e+34*cos(theta)**11 + 4.15462782226273e+32*cos(theta)**9 - 3.64174827371459e+30*cos(theta)**7 + 1.84637165012087e+28*cos(theta)**5 - 4.42456661902917e+25*cos(theta)**3 + 3.16040472787798e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl92_m12(theta, phi):
    return 1.43041451731379e-23*(1.0 - cos(theta)**2)**6*(5.0551956322995e+49*cos(theta)**80 - 8.72919027216745e+50*cos(theta)**78 + 7.24136972025383e+51*cos(theta)**76 - 3.84318504706209e+52*cos(theta)**74 + 1.46616423899925e+53*cos(theta)**72 - 4.28287519415095e+53*cos(theta)**70 + 9.96449286500439e+53*cos(theta)**68 - 1.89633372986466e+54*cos(theta)**66 + 3.00860639834297e+54*cos(theta)**64 - 4.03549600735824e+54*cos(theta)**62 + 4.62492299994814e+54*cos(theta)**60 - 4.56559604568221e+54*cos(theta)**58 + 3.90627860430264e+54*cos(theta)**56 - 2.91033819575523e+54*cos(theta)**54 + 1.89476522207722e+54*cos(theta)**52 - 1.08062739117178e+54*cos(theta)**50 + 5.40755128343723e+53*cos(theta)**48 - 2.37620484913019e+53*cos(theta)**46 + 9.16991804194537e+52*cos(theta)**44 - 3.10588702745446e+52*cos(theta)**42 + 9.22127148495963e+51*cos(theta)**40 - 2.39513545063887e+51*cos(theta)**38 + 5.42804713668318e+50*cos(theta)**36 - 1.06964957651248e+50*cos(theta)**34 + 1.82504079204228e+49*cos(theta)**32 - 2.68213402326806e+48*cos(theta)**30 + 3.37399739769117e+47*cos(theta)**28 - 3.60579874562416e+46*cos(theta)**26 + 3.24442024454001e+45*cos(theta)**24 - 2.43133311836286e+44*cos(theta)**22 + 1.49770120091152e+43*cos(theta)**20 - 7.46297477506397e+41*cos(theta)**18 + 2.94895439200617e+40*cos(theta)**16 - 9.01131976166896e+38*cos(theta)**14 + 2.06141301737525e+37*cos(theta)**12 - 3.38020519619296e+35*cos(theta)**10 + 3.73916504003646e+33*cos(theta)**8 - 2.54922379160022e+31*cos(theta)**6 + 9.23185825060436e+28*cos(theta)**4 - 1.32736998570875e+26*cos(theta)**2 + 3.16040472787798e+22)*cos(12*phi)

#@torch.jit.script
def Yl92_m13(theta, phi):
    return 1.56071019065575e-25*(1.0 - cos(theta)**2)**6.5*(4.0441565058396e+51*cos(theta)**79 - 6.80876841229061e+52*cos(theta)**77 + 5.50344098739291e+53*cos(theta)**75 - 2.84395693482594e+54*cos(theta)**73 + 1.05563825207946e+55*cos(theta)**71 - 2.99801263590567e+55*cos(theta)**69 + 6.77585514820298e+55*cos(theta)**67 - 1.25158026171068e+56*cos(theta)**65 + 1.9255080949395e+56*cos(theta)**63 - 2.50200752456211e+56*cos(theta)**61 + 2.77495379996888e+56*cos(theta)**59 - 2.64804570649568e+56*cos(theta)**57 + 2.18751601840948e+56*cos(theta)**55 - 1.57158262570782e+56*cos(theta)**53 + 9.85277915480156e+55*cos(theta)**51 - 5.40313695585892e+55*cos(theta)**49 + 2.59562461604987e+55*cos(theta)**47 - 1.09305423059989e+55*cos(theta)**45 + 4.03476393845596e+54*cos(theta)**43 - 1.30447255153087e+54*cos(theta)**41 + 3.68850859398385e+53*cos(theta)**39 - 9.10151471242769e+52*cos(theta)**37 + 1.95409696920595e+52*cos(theta)**35 - 3.63680856014244e+51*cos(theta)**33 + 5.8401305345353e+50*cos(theta)**31 - 8.04640206980419e+49*cos(theta)**29 + 9.44719271353529e+48*cos(theta)**27 - 9.3750767386228e+47*cos(theta)**25 + 7.78660858689602e+46*cos(theta)**23 - 5.3489328603983e+45*cos(theta)**21 + 2.99540240182305e+44*cos(theta)**19 - 1.34333545951152e+43*cos(theta)**17 + 4.71832702720987e+41*cos(theta)**15 - 1.26158476663365e+40*cos(theta)**13 + 2.4736956208503e+38*cos(theta)**11 - 3.38020519619296e+36*cos(theta)**9 + 2.99133203202917e+34*cos(theta)**7 - 1.52953427496013e+32*cos(theta)**5 + 3.69274330024174e+29*cos(theta)**3 - 2.6547399714175e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl92_m14(theta, phi):
    return 1.70551595998805e-27*(1.0 - cos(theta)**2)**7*(3.19488363961329e+53*cos(theta)**78 - 5.24275167746377e+54*cos(theta)**76 + 4.12758074054468e+55*cos(theta)**74 - 2.07608856242294e+56*cos(theta)**72 + 7.49503158976417e+56*cos(theta)**70 - 2.06862871877491e+57*cos(theta)**68 + 4.539822949296e+57*cos(theta)**66 - 8.1352717011194e+57*cos(theta)**64 + 1.21307009981189e+58*cos(theta)**62 - 1.52622458998289e+58*cos(theta)**60 + 1.63722274198164e+58*cos(theta)**58 - 1.50938605270254e+58*cos(theta)**56 + 1.20313381012521e+58*cos(theta)**54 - 8.32938791625147e+57*cos(theta)**52 + 5.02491736894879e+57*cos(theta)**50 - 2.64753710837087e+57*cos(theta)**48 + 1.21994356954344e+57*cos(theta)**46 - 4.9187440376995e+56*cos(theta)**44 + 1.73494849353606e+56*cos(theta)**42 - 5.34833746127659e+55*cos(theta)**40 + 1.4385183516537e+55*cos(theta)**38 - 3.36756044359825e+54*cos(theta)**36 + 6.83933939222081e+53*cos(theta)**34 - 1.200146824847e+53*cos(theta)**32 + 1.81044046570594e+52*cos(theta)**30 - 2.33345660024322e+51*cos(theta)**28 + 2.55074203265453e+50*cos(theta)**26 - 2.3437691846557e+49*cos(theta)**24 + 1.79091997498608e+48*cos(theta)**22 - 1.12327590068364e+47*cos(theta)**20 + 5.69126456346379e+45*cos(theta)**18 - 2.28367028116958e+44*cos(theta)**16 + 7.0774905408148e+42*cos(theta)**14 - 1.64006019662375e+41*cos(theta)**12 + 2.72106518293533e+39*cos(theta)**10 - 3.04218467657366e+37*cos(theta)**8 + 2.09393242242042e+35*cos(theta)**6 - 7.64767137480065e+32*cos(theta)**4 + 1.10782299007252e+30*cos(theta)**2 - 2.6547399714175e+26)*cos(14*phi)

#@torch.jit.script
def Yl92_m15(theta, phi):
    return 1.86688083625133e-29*(1.0 - cos(theta)**2)**7.5*(2.49200923889836e+55*cos(theta)**77 - 3.98449127487246e+56*cos(theta)**75 + 3.05440974800306e+57*cos(theta)**73 - 1.49478376494452e+58*cos(theta)**71 + 5.24652211283492e+58*cos(theta)**69 - 1.40666752876694e+59*cos(theta)**67 + 2.99628314653536e+59*cos(theta)**65 - 5.20657388871641e+59*cos(theta)**63 + 7.5210346188337e+59*cos(theta)**61 - 9.15734753989731e+59*cos(theta)**59 + 9.49589190349352e+59*cos(theta)**57 - 8.45256189513422e+59*cos(theta)**55 + 6.49692257467615e+59*cos(theta)**53 - 4.33128171645076e+59*cos(theta)**51 + 2.5124586844744e+59*cos(theta)**49 - 1.27081781201802e+59*cos(theta)**47 + 5.61174041989982e+58*cos(theta)**45 - 2.16424737658778e+58*cos(theta)**43 + 7.28678367285147e+57*cos(theta)**41 - 2.13933498451063e+57*cos(theta)**39 + 5.46636973628407e+56*cos(theta)**37 - 1.21232175969537e+56*cos(theta)**35 + 2.32537539335507e+55*cos(theta)**33 - 3.84046983951041e+54*cos(theta)**31 + 5.43132139711783e+53*cos(theta)**29 - 6.533678480681e+52*cos(theta)**27 + 6.63192928490177e+51*cos(theta)**25 - 5.62504604317368e+50*cos(theta)**23 + 3.94002394496938e+49*cos(theta)**21 - 2.24655180136728e+48*cos(theta)**19 + 1.02442762142348e+47*cos(theta)**17 - 3.65387244987132e+45*cos(theta)**15 + 9.90848675714072e+43*cos(theta)**13 - 1.9680722359485e+42*cos(theta)**11 + 2.72106518293533e+40*cos(theta)**9 - 2.43374774125893e+38*cos(theta)**7 + 1.25635945345225e+36*cos(theta)**5 - 3.05906854992026e+33*cos(theta)**3 + 2.21564598014505e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl92_m16(theta, phi):
    return 2.04719568416579e-31*(1.0 - cos(theta)**2)**8*(1.91884711395174e+57*cos(theta)**76 - 2.98836845615435e+58*cos(theta)**74 + 2.22971911604224e+59*cos(theta)**72 - 1.06129647311061e+60*cos(theta)**70 + 3.62010025785609e+60*cos(theta)**68 - 9.42467244273849e+60*cos(theta)**66 + 1.94758404524798e+61*cos(theta)**64 - 3.28014154989134e+61*cos(theta)**62 + 4.58783111748855e+61*cos(theta)**60 - 5.40283504853942e+61*cos(theta)**58 + 5.4126583849913e+61*cos(theta)**56 - 4.64890904232382e+61*cos(theta)**54 + 3.44336896457836e+61*cos(theta)**52 - 2.20895367538989e+61*cos(theta)**50 + 1.23110475539245e+61*cos(theta)**48 - 5.97284371648468e+60*cos(theta)**46 + 2.52528318895492e+60*cos(theta)**44 - 9.30626371932745e+59*cos(theta)**42 + 2.9875813058691e+59*cos(theta)**40 - 8.34340643959148e+58*cos(theta)**38 + 2.02255680242511e+58*cos(theta)**36 - 4.24312615893379e+57*cos(theta)**34 + 7.67373879807175e+56*cos(theta)**32 - 1.19054565024823e+56*cos(theta)**30 + 1.57508320516417e+55*cos(theta)**28 - 1.76409318978387e+54*cos(theta)**26 + 1.65798232122544e+53*cos(theta)**24 - 1.29376058992995e+52*cos(theta)**22 + 8.27405028443571e+50*cos(theta)**20 - 4.26844842259784e+49*cos(theta)**18 + 1.74152695641992e+48*cos(theta)**16 - 5.48080867480698e+46*cos(theta)**14 + 1.28810327842829e+45*cos(theta)**12 - 2.16487945954335e+43*cos(theta)**10 + 2.4489586646418e+41*cos(theta)**8 - 1.70362341888125e+39*cos(theta)**6 + 6.28179726726125e+36*cos(theta)**4 - 9.17720564976078e+33*cos(theta)**2 + 2.21564598014505e+30)*cos(16*phi)

#@torch.jit.script
def Yl92_m17(theta, phi):
    return 2.24925819878324e-33*(1.0 - cos(theta)**2)**8.5*(1.45832380660332e+59*cos(theta)**75 - 2.21139265755422e+60*cos(theta)**73 + 1.60539776355041e+61*cos(theta)**71 - 7.42907531177424e+61*cos(theta)**69 + 2.46166817534214e+62*cos(theta)**67 - 6.22028381220741e+62*cos(theta)**65 + 1.24645378895871e+63*cos(theta)**63 - 2.03368776093263e+63*cos(theta)**61 + 2.75269867049313e+63*cos(theta)**59 - 3.13364432815286e+63*cos(theta)**57 + 3.03108869559513e+63*cos(theta)**55 - 2.51041088285486e+63*cos(theta)**53 + 1.79055186158075e+63*cos(theta)**51 - 1.10447683769494e+63*cos(theta)**49 + 5.90930282588378e+62*cos(theta)**47 - 2.74750810958295e+62*cos(theta)**45 + 1.11112460314017e+62*cos(theta)**43 - 3.90863076211753e+61*cos(theta)**41 + 1.19503252234764e+61*cos(theta)**39 - 3.17049444704476e+60*cos(theta)**37 + 7.28120448873038e+59*cos(theta)**35 - 1.44266289403749e+59*cos(theta)**33 + 2.45559641538296e+58*cos(theta)**31 - 3.57163695074469e+57*cos(theta)**29 + 4.41023297445968e+56*cos(theta)**27 - 4.58664229343806e+55*cos(theta)**25 + 3.97915757094106e+54*cos(theta)**23 - 2.84627329784588e+53*cos(theta)**21 + 1.65481005688714e+52*cos(theta)**19 - 7.68320716067611e+50*cos(theta)**17 + 2.78644313027187e+49*cos(theta)**15 - 7.67313214472978e+47*cos(theta)**13 + 1.54572393411395e+46*cos(theta)**11 - 2.16487945954335e+44*cos(theta)**9 + 1.95916693171344e+42*cos(theta)**7 - 1.02217405132875e+40*cos(theta)**5 + 2.5127189069045e+37*cos(theta)**3 - 1.83544112995216e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl92_m18(theta, phi):
    return 2.47635177527373e-35*(1.0 - cos(theta)**2)**9*(1.09374285495249e+61*cos(theta)**74 - 1.61431664001458e+62*cos(theta)**72 + 1.13983241212079e+63*cos(theta)**70 - 5.12606196512423e+63*cos(theta)**68 + 1.64931767747924e+64*cos(theta)**66 - 4.04318447793481e+64*cos(theta)**64 + 7.85265887043987e+64*cos(theta)**62 - 1.24054953416891e+65*cos(theta)**60 + 1.62409221559095e+65*cos(theta)**58 - 1.78617726704713e+65*cos(theta)**56 + 1.66709878257732e+65*cos(theta)**54 - 1.33051776791308e+65*cos(theta)**52 + 9.1318144940618e+64*cos(theta)**50 - 5.41193650470523e+64*cos(theta)**48 + 2.77737232816538e+64*cos(theta)**46 - 1.23637864931233e+64*cos(theta)**44 + 4.77783579350271e+63*cos(theta)**42 - 1.60253861246819e+63*cos(theta)**40 + 4.6606268371558e+62*cos(theta)**38 - 1.17308294540656e+62*cos(theta)**36 + 2.54842157105563e+61*cos(theta)**34 - 4.76078755032371e+60*cos(theta)**32 + 7.61234888768717e+59*cos(theta)**30 - 1.03577471571596e+59*cos(theta)**28 + 1.19076290310411e+58*cos(theta)**26 - 1.14666057335952e+57*cos(theta)**24 + 9.15206241316444e+55*cos(theta)**22 - 5.97717392547635e+54*cos(theta)**20 + 3.14413910808557e+53*cos(theta)**18 - 1.30614521731494e+52*cos(theta)**16 + 4.1796646954078e+50*cos(theta)**14 - 9.97507178814871e+48*cos(theta)**12 + 1.70029632752535e+47*cos(theta)**10 - 1.94839151358902e+45*cos(theta)**8 + 1.37141685219941e+43*cos(theta)**6 - 5.11087025664376e+40*cos(theta)**4 + 7.5381567207135e+37*cos(theta)**2 - 1.83544112995216e+34)*cos(18*phi)

#@torch.jit.script
def Yl92_m19(theta, phi):
    return 2.7323415644396e-37*(1.0 - cos(theta)**2)**9.5*(8.09369712664844e+62*cos(theta)**73 - 1.1623079808105e+64*cos(theta)**71 + 7.97882688484554e+64*cos(theta)**69 - 3.48572213628448e+65*cos(theta)**67 + 1.0885496671363e+66*cos(theta)**65 - 2.58763806587828e+66*cos(theta)**63 + 4.86864849967272e+66*cos(theta)**61 - 7.44329720501343e+66*cos(theta)**59 + 9.4197348504275e+66*cos(theta)**57 - 1.00025926954639e+67*cos(theta)**55 + 9.00233342591754e+66*cos(theta)**53 - 6.918692393148e+66*cos(theta)**51 + 4.5659072470309e+66*cos(theta)**49 - 2.59772952225851e+66*cos(theta)**47 + 1.27759127095607e+66*cos(theta)**45 - 5.44006605697425e+65*cos(theta)**43 + 2.00669103327114e+65*cos(theta)**41 - 6.41015444987274e+64*cos(theta)**39 + 1.7710381981192e+64*cos(theta)**37 - 4.22309860346362e+63*cos(theta)**35 + 8.66463334158915e+62*cos(theta)**33 - 1.52345201610359e+62*cos(theta)**31 + 2.28370466630615e+61*cos(theta)**29 - 2.90016920400468e+60*cos(theta)**27 + 3.09598354807069e+59*cos(theta)**25 - 2.75198537606284e+58*cos(theta)**23 + 2.01345373089618e+57*cos(theta)**21 - 1.19543478509527e+56*cos(theta)**19 + 5.65945039455402e+54*cos(theta)**17 - 2.0898323477039e+53*cos(theta)**15 + 5.85153057357093e+51*cos(theta)**13 - 1.19700861457784e+50*cos(theta)**11 + 1.70029632752535e+48*cos(theta)**9 - 1.55871321087121e+46*cos(theta)**7 + 8.22850111319645e+43*cos(theta)**5 - 2.0443481026575e+41*cos(theta)**3 + 1.5076313441427e+38*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl92_m20(theta, phi):
    return 3.02179186207228e-39*(1.0 - cos(theta)**2)**10*(5.90839890245336e+64*cos(theta)**72 - 8.25238666375453e+65*cos(theta)**70 + 5.50539055054342e+66*cos(theta)**68 - 2.3354338313106e+67*cos(theta)**66 + 7.07557283638592e+67*cos(theta)**64 - 1.63021198150332e+68*cos(theta)**62 + 2.96987558480036e+68*cos(theta)**60 - 4.39154535095792e+68*cos(theta)**58 + 5.36924886474367e+68*cos(theta)**56 - 5.50142598250516e+68*cos(theta)**54 + 4.7712367157363e+68*cos(theta)**52 - 3.52853312050548e+68*cos(theta)**50 + 2.23729455104514e+68*cos(theta)**48 - 1.2209328754615e+68*cos(theta)**46 + 5.74916071930233e+67*cos(theta)**44 - 2.33922840449893e+67*cos(theta)**42 + 8.22743323641167e+66*cos(theta)**40 - 2.49996023545037e+66*cos(theta)**38 + 6.55284133304105e+65*cos(theta)**36 - 1.47808451121227e+65*cos(theta)**34 + 2.85932900272442e+64*cos(theta)**32 - 4.72270124992112e+63*cos(theta)**30 + 6.62274353228784e+62*cos(theta)**28 - 7.83045685081265e+61*cos(theta)**26 + 7.73995887017673e+60*cos(theta)**24 - 6.32956636494453e+59*cos(theta)**22 + 4.22825283488197e+58*cos(theta)**20 - 2.27132609168101e+57*cos(theta)**18 + 9.62106567074184e+55*cos(theta)**16 - 3.13474852155585e+54*cos(theta)**14 + 7.6069897456422e+52*cos(theta)**12 - 1.31670947603563e+51*cos(theta)**10 + 1.53026669477281e+49*cos(theta)**8 - 1.09109924760985e+47*cos(theta)**6 + 4.11425055659822e+44*cos(theta)**4 - 6.13304430797251e+41*cos(theta)**2 + 1.5076313441427e+38)*cos(20*phi)

#@torch.jit.script
def Yl92_m21(theta, phi):
    return 3.35011007789734e-41*(1.0 - cos(theta)**2)**10.5*(4.25404720976642e+66*cos(theta)**71 - 5.77667066462817e+67*cos(theta)**69 + 3.74366557436953e+68*cos(theta)**67 - 1.541386328665e+69*cos(theta)**65 + 4.52836661528699e+69*cos(theta)**63 - 1.01073142853206e+70*cos(theta)**61 + 1.78192535088022e+70*cos(theta)**59 - 2.5470963035556e+70*cos(theta)**57 + 3.00677936425646e+70*cos(theta)**55 - 2.97077003055279e+70*cos(theta)**53 + 2.48104309218287e+70*cos(theta)**51 - 1.76426656025274e+70*cos(theta)**49 + 1.07390138450167e+70*cos(theta)**47 - 5.6162912271229e+69*cos(theta)**45 + 2.52963071649303e+69*cos(theta)**43 - 9.82475929889549e+68*cos(theta)**41 + 3.29097329456467e+68*cos(theta)**39 - 9.49984889471141e+67*cos(theta)**37 + 2.35902287989478e+67*cos(theta)**35 - 5.02548733812171e+66*cos(theta)**33 + 9.14985280871815e+65*cos(theta)**31 - 1.41681037497634e+65*cos(theta)**29 + 1.8543681890406e+64*cos(theta)**27 - 2.03591878121129e+63*cos(theta)**25 + 1.85759012884242e+62*cos(theta)**23 - 1.3925046002878e+61*cos(theta)**21 + 8.45650566976395e+59*cos(theta)**19 - 4.08838696502583e+58*cos(theta)**17 + 1.53937050731869e+57*cos(theta)**15 - 4.38864793017819e+55*cos(theta)**13 + 9.12838769477065e+53*cos(theta)**11 - 1.31670947603563e+52*cos(theta)**9 + 1.22421335581825e+50*cos(theta)**7 - 6.54659548565909e+47*cos(theta)**5 + 1.64570022263929e+45*cos(theta)**3 - 1.2266088615945e+42*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl92_m22(theta, phi):
    return 3.72372394350724e-43*(1.0 - cos(theta)**2)**11*(3.02037351893416e+68*cos(theta)**70 - 3.98590275859344e+69*cos(theta)**68 + 2.50825593482758e+70*cos(theta)**66 - 1.00190111363225e+71*cos(theta)**64 + 2.8528709676308e+71*cos(theta)**62 - 6.16546171404555e+71*cos(theta)**60 + 1.05133595701933e+72*cos(theta)**58 - 1.45184489302669e+72*cos(theta)**56 + 1.65372865034105e+72*cos(theta)**54 - 1.57450811619298e+72*cos(theta)**52 + 1.26533197701327e+72*cos(theta)**50 - 8.64490614523843e+71*cos(theta)**48 + 5.04733650715784e+71*cos(theta)**46 - 2.5273310522053e+71*cos(theta)**44 + 1.087741208092e+71*cos(theta)**42 - 4.02815131254715e+70*cos(theta)**40 + 1.28347958488022e+70*cos(theta)**38 - 3.51494409104322e+69*cos(theta)**36 + 8.25658007963173e+68*cos(theta)**34 - 1.65841082158016e+68*cos(theta)**32 + 2.83645437070263e+67*cos(theta)**30 - 4.10875008743138e+66*cos(theta)**28 + 5.00679411040961e+65*cos(theta)**26 - 5.08979695302822e+64*cos(theta)**24 + 4.27245729633756e+63*cos(theta)**22 - 2.92425966060437e+62*cos(theta)**20 + 1.60673607725515e+61*cos(theta)**18 - 6.95025784054391e+59*cos(theta)**16 + 2.30905576097804e+58*cos(theta)**14 - 5.70524230923165e+56*cos(theta)**12 + 1.00412264642477e+55*cos(theta)**10 - 1.18503852843207e+53*cos(theta)**8 + 8.56949349072775e+50*cos(theta)**6 - 3.27329774282955e+48*cos(theta)**4 + 4.93710066791787e+45*cos(theta)**2 - 1.2266088615945e+42)*cos(22*phi)

#@torch.jit.script
def Yl92_m23(theta, phi):
    return 4.15030044672352e-45*(1.0 - cos(theta)**2)**11.5*(2.11426146325391e+70*cos(theta)**69 - 2.71041387584354e+71*cos(theta)**67 + 1.6554489169862e+72*cos(theta)**65 - 6.41216712724638e+72*cos(theta)**63 + 1.7687799999311e+73*cos(theta)**61 - 3.69927702842733e+73*cos(theta)**59 + 6.0977485507121e+73*cos(theta)**57 - 8.13033140094946e+73*cos(theta)**55 + 8.93013471184168e+73*cos(theta)**53 - 8.18744220420348e+73*cos(theta)**51 + 6.32665988506633e+73*cos(theta)**49 - 4.14955494971445e+73*cos(theta)**47 + 2.32177479329261e+73*cos(theta)**45 - 1.11202566297033e+73*cos(theta)**43 + 4.5685130739864e+72*cos(theta)**41 - 1.61126052501886e+72*cos(theta)**39 + 4.87722242254484e+71*cos(theta)**37 - 1.26537987277556e+71*cos(theta)**35 + 2.80723722707479e+70*cos(theta)**33 - 5.30691462905653e+69*cos(theta)**31 + 8.50936311210788e+68*cos(theta)**29 - 1.15045002448079e+68*cos(theta)**27 + 1.3017664687065e+67*cos(theta)**25 - 1.22155126872677e+66*cos(theta)**23 + 9.39940605194263e+64*cos(theta)**21 - 5.84851932120875e+63*cos(theta)**19 + 2.89212493905927e+62*cos(theta)**17 - 1.11204125448702e+61*cos(theta)**15 + 3.23267806536926e+59*cos(theta)**13 - 6.84629077107798e+57*cos(theta)**11 + 1.00412264642477e+56*cos(theta)**9 - 9.48030822745653e+53*cos(theta)**7 + 5.14169609443665e+51*cos(theta)**5 - 1.30931909713182e+49*cos(theta)**3 + 9.87420133583574e+45*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl92_m24(theta, phi):
    return 4.63901735355543e-47*(1.0 - cos(theta)**2)**12*(1.4588404096452e+72*cos(theta)**68 - 1.81597729681517e+73*cos(theta)**66 + 1.07604179604103e+74*cos(theta)**64 - 4.03966529016522e+74*cos(theta)**62 + 1.07895579995797e+75*cos(theta)**60 - 2.18257344677212e+75*cos(theta)**58 + 3.4757166739059e+75*cos(theta)**56 - 4.4716822705222e+75*cos(theta)**54 + 4.73297139727609e+75*cos(theta)**52 - 4.17559552414378e+75*cos(theta)**50 + 3.1000633436825e+75*cos(theta)**48 - 1.95029082636579e+75*cos(theta)**46 + 1.04479865698167e+75*cos(theta)**44 - 4.78171035077244e+74*cos(theta)**42 + 1.87309036033443e+74*cos(theta)**40 - 6.28391604757356e+73*cos(theta)**38 + 1.80457229634159e+73*cos(theta)**36 - 4.42882955471446e+72*cos(theta)**34 + 9.2638828493468e+71*cos(theta)**32 - 1.64514353500752e+71*cos(theta)**30 + 2.46771530251128e+70*cos(theta)**28 - 3.10621506609812e+69*cos(theta)**26 + 3.25441617176624e+68*cos(theta)**24 - 2.80956791807158e+67*cos(theta)**22 + 1.97387527090795e+66*cos(theta)**20 - 1.11121867102966e+65*cos(theta)**18 + 4.91661239640076e+63*cos(theta)**16 - 1.66806188173054e+62*cos(theta)**14 + 4.20248148498004e+60*cos(theta)**12 - 7.53091984818578e+58*cos(theta)**10 + 9.03710381782294e+56*cos(theta)**8 - 6.63621575921957e+54*cos(theta)**6 + 2.57084804721833e+52*cos(theta)**4 - 3.92795729139546e+49*cos(theta)**2 + 9.87420133583574e+45)*cos(24*phi)

#@torch.jit.script
def Yl92_m25(theta, phi):
    return 5.20090127435586e-49*(1.0 - cos(theta)**2)**12.5*(9.92011478558735e+73*cos(theta)**67 - 1.19854501589801e+75*cos(theta)**65 + 6.88666749466261e+75*cos(theta)**63 - 2.50459247990244e+76*cos(theta)**61 + 6.47373479974782e+76*cos(theta)**59 - 1.26589259912783e+77*cos(theta)**57 + 1.9464013373873e+77*cos(theta)**55 - 2.41470842608199e+77*cos(theta)**53 + 2.46114512658357e+77*cos(theta)**51 - 2.08779776207189e+77*cos(theta)**49 + 1.4880304049676e+77*cos(theta)**47 - 8.97133780128263e+76*cos(theta)**45 + 4.59711409071936e+76*cos(theta)**43 - 2.00831834732442e+76*cos(theta)**41 + 7.4923614413377e+75*cos(theta)**39 - 2.38788809807795e+75*cos(theta)**37 + 6.49646026682972e+74*cos(theta)**35 - 1.50580204860292e+74*cos(theta)**33 + 2.96444251179098e+73*cos(theta)**31 - 4.93543060502257e+72*cos(theta)**29 + 6.9096028470316e+71*cos(theta)**27 - 8.07615917185511e+70*cos(theta)**25 + 7.81059881223899e+69*cos(theta)**23 - 6.18104941975747e+68*cos(theta)**21 + 3.9477505418159e+67*cos(theta)**19 - 2.00019360785339e+66*cos(theta)**17 + 7.86657983424121e+64*cos(theta)**15 - 2.33528663442275e+63*cos(theta)**13 + 5.04297778197604e+61*cos(theta)**11 - 7.53091984818578e+59*cos(theta)**9 + 7.22968305425835e+57*cos(theta)**7 - 3.98172945553174e+55*cos(theta)**5 + 1.02833921888733e+53*cos(theta)**3 - 7.85591458279091e+49*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl92_m26(theta, phi):
    return 5.84925028499633e-51*(1.0 - cos(theta)**2)**13*(6.64647690634352e+75*cos(theta)**66 - 7.79054260333708e+76*cos(theta)**64 + 4.33860052163745e+77*cos(theta)**62 - 1.52780141274049e+78*cos(theta)**60 + 3.81950353185121e+78*cos(theta)**58 - 7.21558781502864e+78*cos(theta)**56 + 1.07052073556302e+79*cos(theta)**54 - 1.27979546582345e+79*cos(theta)**52 + 1.25518401455762e+79*cos(theta)**50 - 1.02302090341523e+79*cos(theta)**48 + 6.99374290334772e+78*cos(theta)**46 - 4.03710201057718e+78*cos(theta)**44 + 1.97675905900933e+78*cos(theta)**42 - 8.23410522403014e+77*cos(theta)**40 + 2.9220209621217e+77*cos(theta)**38 - 8.83518596288842e+76*cos(theta)**36 + 2.2737610933904e+76*cos(theta)**34 - 4.96914676038962e+75*cos(theta)**32 + 9.18977178655202e+74*cos(theta)**30 - 1.43127487545654e+74*cos(theta)**28 + 1.86559276869853e+73*cos(theta)**26 - 2.01903979296378e+72*cos(theta)**24 + 1.79643772681497e+71*cos(theta)**22 - 1.29802037814907e+70*cos(theta)**20 + 7.50072602945022e+68*cos(theta)**18 - 3.40032913335076e+67*cos(theta)**16 + 1.17998697513618e+66*cos(theta)**14 - 3.03587262474958e+64*cos(theta)**12 + 5.54727556017365e+62*cos(theta)**10 - 6.7778278633672e+60*cos(theta)**8 + 5.06077813798085e+58*cos(theta)**6 - 1.99086472776587e+56*cos(theta)**4 + 3.08501765666199e+53*cos(theta)**2 - 7.85591458279091e+49)*cos(26*phi)

#@torch.jit.script
def Yl92_m27(theta, phi):
    return 6.6001644476941e-53*(1.0 - cos(theta)**2)**13.5*(4.38667475818673e+77*cos(theta)**65 - 4.98594726613573e+78*cos(theta)**63 + 2.68993232341522e+79*cos(theta)**61 - 9.16680847644292e+79*cos(theta)**59 + 2.2153120484737e+80*cos(theta)**57 - 4.04072917641604e+80*cos(theta)**55 + 5.78081197204028e+80*cos(theta)**53 - 6.65493642228197e+80*cos(theta)**51 + 6.2759200727881e+80*cos(theta)**49 - 4.91050033639308e+80*cos(theta)**47 + 3.21712173553995e+80*cos(theta)**45 - 1.77632488465396e+80*cos(theta)**43 + 8.30238804783917e+79*cos(theta)**41 - 3.29364208961205e+79*cos(theta)**39 + 1.11036796560625e+79*cos(theta)**37 - 3.18066694663983e+78*cos(theta)**35 + 7.73078771752737e+77*cos(theta)**33 - 1.59012696332468e+77*cos(theta)**31 + 2.75693153596561e+76*cos(theta)**29 - 4.00756965127833e+75*cos(theta)**27 + 4.85054119861618e+74*cos(theta)**25 - 4.84569550311307e+73*cos(theta)**23 + 3.95216299899293e+72*cos(theta)**21 - 2.59604075629814e+71*cos(theta)**19 + 1.35013068530104e+70*cos(theta)**17 - 5.44052661336122e+68*cos(theta)**15 + 1.65198176519065e+67*cos(theta)**13 - 3.64304714969949e+65*cos(theta)**11 + 5.54727556017365e+63*cos(theta)**9 - 5.42226229069376e+61*cos(theta)**7 + 3.03646688278851e+59*cos(theta)**5 - 7.96345891106349e+56*cos(theta)**3 + 6.17003531332398e+53*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl92_m28(theta, phi):
    return 7.47321462570168e-55*(1.0 - cos(theta)**2)**14*(2.85133859282137e+79*cos(theta)**64 - 3.14114677766551e+80*cos(theta)**62 + 1.64085871728328e+81*cos(theta)**60 - 5.40841700110132e+81*cos(theta)**58 + 1.26272786763001e+82*cos(theta)**56 - 2.22240104702882e+82*cos(theta)**54 + 3.06383034518135e+82*cos(theta)**52 - 3.3940175753638e+82*cos(theta)**50 + 3.07520083566617e+82*cos(theta)**48 - 2.30793515810475e+82*cos(theta)**46 + 1.44770478099298e+82*cos(theta)**44 - 7.63819700401203e+81*cos(theta)**42 + 3.40397909961406e+81*cos(theta)**40 - 1.2845204149487e+81*cos(theta)**38 + 4.10836147274312e+80*cos(theta)**36 - 1.11323343132394e+80*cos(theta)**34 + 2.55115994678403e+79*cos(theta)**32 - 4.9293935863065e+78*cos(theta)**30 + 7.99510145430026e+77*cos(theta)**28 - 1.08204380584515e+77*cos(theta)**26 + 1.21263529965405e+76*cos(theta)**24 - 1.11450996571601e+75*cos(theta)**22 + 8.29954229788515e+73*cos(theta)**20 - 4.93247743696646e+72*cos(theta)**18 + 2.29522216501177e+71*cos(theta)**16 - 8.16078992004184e+69*cos(theta)**14 + 2.14757629474785e+68*cos(theta)**12 - 4.00735186466944e+66*cos(theta)**10 + 4.99254800415628e+64*cos(theta)**8 - 3.79558360348563e+62*cos(theta)**6 + 1.51823344139425e+60*cos(theta)**4 - 2.38903767331905e+57*cos(theta)**2 + 6.17003531332398e+53)*cos(28*phi)

#@torch.jit.script
def Yl92_m29(theta, phi):
    return 8.49228934738827e-57*(1.0 - cos(theta)**2)**14.5*(1.82485669940568e+81*cos(theta)**63 - 1.94751100215262e+82*cos(theta)**61 + 9.84515230369969e+82*cos(theta)**59 - 3.13688186063877e+83*cos(theta)**57 + 7.07127605872807e+83*cos(theta)**55 - 1.20009656539556e+84*cos(theta)**53 + 1.5931917794943e+84*cos(theta)**51 - 1.6970087876819e+84*cos(theta)**49 + 1.47609640111976e+84*cos(theta)**47 - 1.06165017272818e+84*cos(theta)**45 + 6.3699010363691e+83*cos(theta)**43 - 3.20804274168505e+83*cos(theta)**41 + 1.36159163984562e+83*cos(theta)**39 - 4.88117757680506e+82*cos(theta)**37 + 1.47901013018752e+82*cos(theta)**35 - 3.7849936665014e+81*cos(theta)**33 + 8.1637118297089e+80*cos(theta)**31 - 1.47881807589195e+80*cos(theta)**29 + 2.23862840720407e+79*cos(theta)**27 - 2.81331389519738e+78*cos(theta)**25 + 2.91032471916971e+77*cos(theta)**23 - 2.45192192457521e+76*cos(theta)**21 + 1.65990845957703e+75*cos(theta)**19 - 8.87845938653963e+73*cos(theta)**17 + 3.67235546401883e+72*cos(theta)**15 - 1.14251058880586e+71*cos(theta)**13 + 2.57709155369742e+69*cos(theta)**11 - 4.00735186466944e+67*cos(theta)**9 + 3.99403840332503e+65*cos(theta)**7 - 2.27735016209138e+63*cos(theta)**5 + 6.07293376557701e+60*cos(theta)**3 - 4.77807534663809e+57*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl92_m30(theta, phi):
    return 9.68667196672842e-59*(1.0 - cos(theta)**2)**15*(1.14965972062558e+83*cos(theta)**62 - 1.1879817113131e+84*cos(theta)**60 + 5.80863985918282e+84*cos(theta)**58 - 1.7880226605641e+85*cos(theta)**56 + 3.88920183230044e+85*cos(theta)**54 - 6.36051179659648e+85*cos(theta)**52 + 8.12527807542094e+85*cos(theta)**50 - 8.31534305964132e+85*cos(theta)**48 + 6.93765308526287e+85*cos(theta)**46 - 4.77742577727683e+85*cos(theta)**44 + 2.73905744563872e+85*cos(theta)**42 - 1.31529752409087e+85*cos(theta)**40 + 5.31020739539793e+84*cos(theta)**38 - 1.80603570341787e+84*cos(theta)**36 + 5.17653545565633e+83*cos(theta)**34 - 1.24904790994546e+83*cos(theta)**32 + 2.53075066720976e+82*cos(theta)**30 - 4.28857242008666e+81*cos(theta)**28 + 6.044296699451e+80*cos(theta)**26 - 7.03328473799346e+79*cos(theta)**24 + 6.69374685409033e+78*cos(theta)**22 - 5.14903604160794e+77*cos(theta)**20 + 3.15382607319636e+76*cos(theta)**18 - 1.50933809571174e+75*cos(theta)**16 + 5.50853319602824e+73*cos(theta)**14 - 1.48526376544761e+72*cos(theta)**12 + 2.83480070906716e+70*cos(theta)**10 - 3.6066166782025e+68*cos(theta)**8 + 2.79582688232752e+66*cos(theta)**6 - 1.13867508104569e+64*cos(theta)**4 + 1.8218801296731e+61*cos(theta)**2 - 4.77807534663809e+57)*cos(30*phi)

#@torch.jit.script
def Yl92_m31(theta, phi):
    return 1.10924171186194e-60*(1.0 - cos(theta)**2)**15.5*(7.12789026787858e+84*cos(theta)**61 - 7.12789026787858e+85*cos(theta)**59 + 3.36901111832603e+86*cos(theta)**57 - 1.00129268991589e+87*cos(theta)**55 + 2.10016898944224e+87*cos(theta)**53 - 3.30746613423017e+87*cos(theta)**51 + 4.06263903771047e+87*cos(theta)**49 - 3.99136466862783e+87*cos(theta)**47 + 3.19132041922092e+87*cos(theta)**45 - 2.1020673420018e+87*cos(theta)**43 + 1.15040412716826e+87*cos(theta)**41 - 5.26119009636349e+86*cos(theta)**39 + 2.01787881025121e+86*cos(theta)**37 - 6.50172853230435e+85*cos(theta)**35 + 1.76002205492315e+85*cos(theta)**33 - 3.99695331182548e+84*cos(theta)**31 + 7.59225200162928e+83*cos(theta)**29 - 1.20080027762426e+83*cos(theta)**27 + 1.57151714185726e+82*cos(theta)**25 - 1.68798833711843e+81*cos(theta)**23 + 1.47262430789987e+80*cos(theta)**21 - 1.02980720832159e+79*cos(theta)**19 + 5.67688693175344e+77*cos(theta)**17 - 2.41494095313878e+76*cos(theta)**15 + 7.71194647443953e+74*cos(theta)**13 - 1.78231651853714e+73*cos(theta)**11 + 2.83480070906716e+71*cos(theta)**9 - 2.885293342562e+69*cos(theta)**7 + 1.67749612939651e+67*cos(theta)**5 - 4.55470032418276e+64*cos(theta)**3 + 3.64376025934621e+61*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl92_m32(theta, phi):
    return 1.27541180465869e-62*(1.0 - cos(theta)**2)**16*(4.34801306340593e+86*cos(theta)**60 - 4.20545525804836e+87*cos(theta)**58 + 1.92033633744584e+88*cos(theta)**56 - 5.50710979453742e+88*cos(theta)**54 + 1.11308956440438e+89*cos(theta)**52 - 1.68680772845739e+89*cos(theta)**50 + 1.99069312847813e+89*cos(theta)**48 - 1.87594139425508e+89*cos(theta)**46 + 1.43609418864941e+89*cos(theta)**44 - 9.03888957060776e+88*cos(theta)**42 + 4.71665692138987e+88*cos(theta)**40 - 2.05186413758176e+88*cos(theta)**38 + 7.46615159792949e+87*cos(theta)**36 - 2.27560498630652e+87*cos(theta)**34 + 5.8080727812464e+86*cos(theta)**32 - 1.2390555266659e+86*cos(theta)**30 + 2.20175308047249e+85*cos(theta)**28 - 3.24216074958551e+84*cos(theta)**26 + 3.92879285464315e+83*cos(theta)**24 - 3.88237317537239e+82*cos(theta)**22 + 3.09251104658973e+81*cos(theta)**20 - 1.95663369581102e+80*cos(theta)**18 + 9.65070778398085e+78*cos(theta)**16 - 3.62241142970817e+77*cos(theta)**14 + 1.00255304167714e+76*cos(theta)**12 - 1.96054817039085e+74*cos(theta)**10 + 2.55132063816045e+72*cos(theta)**8 - 2.0197053397934e+70*cos(theta)**6 + 8.38748064698256e+67*cos(theta)**4 - 1.36641009725483e+65*cos(theta)**2 + 3.64376025934621e+61)*cos(32*phi)

#@torch.jit.script
def Yl92_m33(theta, phi):
    return 1.47271869749464e-64*(1.0 - cos(theta)**2)**16.5*(2.60880783804356e+88*cos(theta)**59 - 2.43916404966805e+89*cos(theta)**57 + 1.07538834896967e+90*cos(theta)**55 - 2.97383928905021e+90*cos(theta)**53 + 5.7880657349028e+90*cos(theta)**51 - 8.43403864228694e+90*cos(theta)**49 + 9.55532701669503e+90*cos(theta)**47 - 8.62933041357337e+90*cos(theta)**45 + 6.31881443005742e+90*cos(theta)**43 - 3.79633361965526e+90*cos(theta)**41 + 1.88666276855595e+90*cos(theta)**39 - 7.79708372281069e+89*cos(theta)**37 + 2.68781457525462e+89*cos(theta)**35 - 7.73705695344217e+88*cos(theta)**33 + 1.85858328999885e+88*cos(theta)**31 - 3.7171665799977e+87*cos(theta)**29 + 6.16490862532297e+86*cos(theta)**27 - 8.42961794892234e+85*cos(theta)**25 + 9.42910285114355e+84*cos(theta)**23 - 8.54122098581926e+83*cos(theta)**21 + 6.18502209317946e+82*cos(theta)**19 - 3.52194065245983e+81*cos(theta)**17 + 1.54411324543694e+80*cos(theta)**15 - 5.07137600159144e+78*cos(theta)**13 + 1.20306365001257e+77*cos(theta)**11 - 1.96054817039085e+75*cos(theta)**9 + 2.04105651052836e+73*cos(theta)**7 - 1.21182320387604e+71*cos(theta)**5 + 3.35499225879302e+68*cos(theta)**3 - 2.73282019450966e+65*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl92_m34(theta, phi):
    return 1.70808123770373e-66*(1.0 - cos(theta)**2)**17*(1.5391966244457e+90*cos(theta)**58 - 1.39032350831079e+91*cos(theta)**56 + 5.91463591933319e+91*cos(theta)**54 - 1.57613482319661e+92*cos(theta)**52 + 2.95191352480043e+92*cos(theta)**50 - 4.1326789347206e+92*cos(theta)**48 + 4.49100369784666e+92*cos(theta)**46 - 3.88319868610802e+92*cos(theta)**44 + 2.71709020492469e+92*cos(theta)**42 - 1.55649678405866e+92*cos(theta)**40 + 7.35798479736819e+91*cos(theta)**38 - 2.88492097743996e+91*cos(theta)**36 + 9.40735101339116e+90*cos(theta)**34 - 2.55322879463592e+90*cos(theta)**32 + 5.76160819899643e+89*cos(theta)**30 - 1.07797830819933e+89*cos(theta)**28 + 1.6645253288372e+88*cos(theta)**26 - 2.10740448723058e+87*cos(theta)**24 + 2.16869365576302e+86*cos(theta)**22 - 1.79365640702204e+85*cos(theta)**20 + 1.1751541977041e+84*cos(theta)**18 - 5.98729910918172e+82*cos(theta)**16 + 2.3161698681554e+81*cos(theta)**14 - 6.59278880206887e+79*cos(theta)**12 + 1.32337001501382e+78*cos(theta)**10 - 1.76449335335177e+76*cos(theta)**8 + 1.42873955736985e+74*cos(theta)**6 - 6.0591160193802e+71*cos(theta)**4 + 1.00649767763791e+69*cos(theta)**2 - 2.73282019450966e+65)*cos(34*phi)

#@torch.jit.script
def Yl92_m35(theta, phi):
    return 1.99018140879344e-68*(1.0 - cos(theta)**2)**17.5*(8.92734042178506e+91*cos(theta)**57 - 7.78581164654041e+92*cos(theta)**55 + 3.19390339643992e+93*cos(theta)**53 - 8.19590108062237e+93*cos(theta)**51 + 1.47595676240021e+94*cos(theta)**49 - 1.98368588866589e+94*cos(theta)**47 + 2.06586170100947e+94*cos(theta)**45 - 1.70860742188753e+94*cos(theta)**43 + 1.14117788606837e+94*cos(theta)**41 - 6.22598713623462e+93*cos(theta)**39 + 2.79603422299991e+93*cos(theta)**37 - 1.03857155187838e+93*cos(theta)**35 + 3.19849934455299e+92*cos(theta)**33 - 8.17033214283493e+91*cos(theta)**31 + 1.72848245969893e+91*cos(theta)**29 - 3.01833926295813e+90*cos(theta)**27 + 4.32776585497673e+89*cos(theta)**25 - 5.0577707693534e+88*cos(theta)**23 + 4.77112604267864e+87*cos(theta)**21 - 3.58731281404409e+86*cos(theta)**19 + 2.11527755586738e+85*cos(theta)**17 - 9.57967857469075e+83*cos(theta)**15 + 3.24263781541757e+82*cos(theta)**13 - 7.91134656248264e+80*cos(theta)**11 + 1.32337001501382e+79*cos(theta)**9 - 1.41159468268141e+77*cos(theta)**7 + 8.5724373442191e+74*cos(theta)**5 - 2.42364640775208e+72*cos(theta)**3 + 2.01299535527581e+69*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl92_m36(theta, phi):
    return 2.329969587437e-70*(1.0 - cos(theta)**2)**18*(5.08858404041748e+93*cos(theta)**56 - 4.28219640559723e+94*cos(theta)**54 + 1.69276880011316e+95*cos(theta)**52 - 4.17990955111741e+95*cos(theta)**50 + 7.23218813576105e+95*cos(theta)**48 - 9.32332367672967e+95*cos(theta)**46 + 9.29637765454259e+95*cos(theta)**44 - 7.34701191411637e+95*cos(theta)**42 + 4.67882933288032e+95*cos(theta)**40 - 2.4281349831315e+95*cos(theta)**38 + 1.03453266250997e+95*cos(theta)**36 - 3.63500043157434e+94*cos(theta)**34 + 1.05550478370249e+94*cos(theta)**32 - 2.53280296427883e+93*cos(theta)**30 + 5.01259913312689e+92*cos(theta)**28 - 8.14951600998695e+91*cos(theta)**26 + 1.08194146374418e+91*cos(theta)**24 - 1.16328727695128e+90*cos(theta)**22 + 1.00193646896251e+89*cos(theta)**20 - 6.81589434668377e+87*cos(theta)**18 + 3.59597184497454e+86*cos(theta)**16 - 1.43695178620361e+85*cos(theta)**14 + 4.21542916004283e+83*cos(theta)**12 - 8.70248121873091e+81*cos(theta)**10 + 1.19103301351244e+80*cos(theta)**8 - 9.88116277876989e+77*cos(theta)**6 + 4.28621867210955e+75*cos(theta)**4 - 7.27093922325624e+72*cos(theta)**2 + 2.01299535527581e+69)*cos(36*phi)

#@torch.jit.script
def Yl92_m37(theta, phi):
    return 2.74133040911422e-72*(1.0 - cos(theta)**2)**18.5*(2.84960706263379e+95*cos(theta)**55 - 2.3123860590225e+96*cos(theta)**53 + 8.80239776058842e+96*cos(theta)**51 - 2.0899547755587e+97*cos(theta)**49 + 3.4714503051653e+97*cos(theta)**47 - 4.28872889129565e+97*cos(theta)**45 + 4.09040616799874e+97*cos(theta)**43 - 3.08574500392887e+97*cos(theta)**41 + 1.87153173315213e+97*cos(theta)**39 - 9.22691293589971e+96*cos(theta)**37 + 3.72431758503588e+96*cos(theta)**35 - 1.23590014673528e+96*cos(theta)**33 + 3.37761530784796e+95*cos(theta)**31 - 7.59840889283649e+94*cos(theta)**29 + 1.40352775727553e+94*cos(theta)**27 - 2.11887416259661e+93*cos(theta)**25 + 2.59665951298604e+92*cos(theta)**23 - 2.55923200929282e+91*cos(theta)**21 + 2.00387293792503e+90*cos(theta)**19 - 1.22686098240308e+89*cos(theta)**17 + 5.75355495195926e+87*cos(theta)**15 - 2.01173250068506e+86*cos(theta)**13 + 5.0585149920514e+84*cos(theta)**11 - 8.70248121873091e+82*cos(theta)**9 + 9.52826410809953e+80*cos(theta)**7 - 5.92869766726193e+78*cos(theta)**5 + 1.71448746884382e+76*cos(theta)**3 - 1.45418784465125e+73*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl92_m38(theta, phi):
    return 3.24196530482212e-74*(1.0 - cos(theta)**2)**19*(1.56728388444859e+97*cos(theta)**54 - 1.22556461128193e+98*cos(theta)**52 + 4.48922285790009e+98*cos(theta)**50 - 1.02407784002376e+99*cos(theta)**48 + 1.63158164342769e+99*cos(theta)**46 - 1.92992800108304e+99*cos(theta)**44 + 1.75887465223946e+99*cos(theta)**42 - 1.26515545161084e+99*cos(theta)**40 + 7.2989737592933e+98*cos(theta)**38 - 3.41395778628289e+98*cos(theta)**36 + 1.30351115476256e+98*cos(theta)**34 - 4.07847048422641e+97*cos(theta)**32 + 1.04706074543287e+97*cos(theta)**30 - 2.20353857892258e+96*cos(theta)**28 + 3.78952494464393e+95*cos(theta)**26 - 5.29718540649152e+94*cos(theta)**24 + 5.97231687986788e+93*cos(theta)**22 - 5.37438721951493e+92*cos(theta)**20 + 3.80735858205755e+91*cos(theta)**18 - 2.08566367008523e+90*cos(theta)**16 + 8.6303324279389e+88*cos(theta)**14 - 2.61525225089057e+87*cos(theta)**12 + 5.56436649125654e+85*cos(theta)**10 - 7.83223309685782e+83*cos(theta)**8 + 6.66978487566967e+81*cos(theta)**6 - 2.96434883363097e+79*cos(theta)**4 + 5.14346240653146e+76*cos(theta)**2 - 1.45418784465125e+73)*cos(38*phi)

#@torch.jit.script
def Yl92_m39(theta, phi):
    return 3.85456909508432e-76*(1.0 - cos(theta)**2)**19.5*(8.46333297602236e+98*cos(theta)**53 - 6.37293597866602e+99*cos(theta)**51 + 2.24461142895005e+100*cos(theta)**49 - 4.91557363211407e+100*cos(theta)**47 + 7.50527555976739e+100*cos(theta)**45 - 8.49168320476539e+100*cos(theta)**43 + 7.38727353940573e+100*cos(theta)**41 - 5.06062180644335e+100*cos(theta)**39 + 2.77361002853145e+100*cos(theta)**37 - 1.22902480306184e+100*cos(theta)**35 + 4.4319379261927e+99*cos(theta)**33 - 1.30511055495245e+99*cos(theta)**31 + 3.1411822362986e+98*cos(theta)**29 - 6.16990802098323e+97*cos(theta)**27 + 9.85276485607422e+96*cos(theta)**25 - 1.27132449755796e+96*cos(theta)**23 + 1.31390971357093e+95*cos(theta)**21 - 1.07487744390299e+94*cos(theta)**19 + 6.8532454477036e+92*cos(theta)**17 - 3.33706187213637e+91*cos(theta)**15 + 1.20824653991145e+90*cos(theta)**13 - 3.13830270106869e+88*cos(theta)**11 + 5.56436649125654e+86*cos(theta)**9 - 6.26578647748625e+84*cos(theta)**7 + 4.0018709254018e+82*cos(theta)**5 - 1.18573953345239e+80*cos(theta)**3 + 1.02869248130629e+77*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl92_m40(theta, phi):
    return 4.60840813529167e-78*(1.0 - cos(theta)**2)**20*(4.48556647729185e+100*cos(theta)**52 - 3.25019734911967e+101*cos(theta)**50 + 1.09985960018552e+102*cos(theta)**48 - 2.31031960709361e+102*cos(theta)**46 + 3.37737400189532e+102*cos(theta)**44 - 3.65142377804912e+102*cos(theta)**42 + 3.02878215115635e+102*cos(theta)**40 - 1.97364250451291e+102*cos(theta)**38 + 1.02623571055664e+102*cos(theta)**36 - 4.30158681071645e+101*cos(theta)**34 + 1.46253951564359e+101*cos(theta)**32 - 4.0458427203526e+100*cos(theta)**30 + 9.10942848526595e+99*cos(theta)**28 - 1.66587516566547e+99*cos(theta)**26 + 2.46319121401855e+98*cos(theta)**24 - 2.92404634438332e+97*cos(theta)**22 + 2.75921039849896e+96*cos(theta)**20 - 2.04226714341567e+95*cos(theta)**18 + 1.16505172610961e+94*cos(theta)**16 - 5.00559280820456e+92*cos(theta)**14 + 1.57072050188488e+91*cos(theta)**12 - 3.45213297117556e+89*cos(theta)**10 + 5.00792984213089e+87*cos(theta)**8 - 4.38605053424038e+85*cos(theta)**6 + 2.0009354627009e+83*cos(theta)**4 - 3.55721860035716e+80*cos(theta)**2 + 1.02869248130629e+77)*cos(40*phi)

#@torch.jit.script
def Yl92_m41(theta, phi):
    return 5.54145029768469e-80*(1.0 - cos(theta)**2)**20.5*(2.33249456819176e+102*cos(theta)**51 - 1.62509867455983e+103*cos(theta)**49 + 5.27932608089051e+103*cos(theta)**47 - 1.06274701926306e+104*cos(theta)**45 + 1.48604456083394e+104*cos(theta)**43 - 1.53359798678063e+104*cos(theta)**41 + 1.21151286046254e+104*cos(theta)**39 - 7.49984151714905e+103*cos(theta)**37 + 3.6944485580039e+103*cos(theta)**35 - 1.46253951564359e+103*cos(theta)**33 + 4.68012645005949e+102*cos(theta)**31 - 1.21375281610578e+102*cos(theta)**29 + 2.55063997587447e+101*cos(theta)**27 - 4.33127543073023e+100*cos(theta)**25 + 5.91165891364453e+99*cos(theta)**23 - 6.4329019576433e+98*cos(theta)**21 + 5.51842079699793e+97*cos(theta)**19 - 3.67608085814821e+96*cos(theta)**17 + 1.86408276177538e+95*cos(theta)**15 - 7.00782993148638e+93*cos(theta)**13 + 1.88486460226186e+92*cos(theta)**11 - 3.45213297117556e+90*cos(theta)**9 + 4.00634387370471e+88*cos(theta)**7 - 2.63163032054423e+86*cos(theta)**5 + 8.00374185080361e+83*cos(theta)**3 - 7.11443720071432e+80*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl92_m42(theta, phi):
    return 6.70325830749101e-82*(1.0 - cos(theta)**2)**21*(1.1895722297778e+104*cos(theta)**50 - 7.96298350534319e+104*cos(theta)**48 + 2.48128325801854e+105*cos(theta)**46 - 4.78236158668378e+105*cos(theta)**44 + 6.38999161158595e+105*cos(theta)**42 - 6.28775174580058e+105*cos(theta)**40 + 4.7249001558039e+105*cos(theta)**38 - 2.77494136134515e+105*cos(theta)**36 + 1.29305699530136e+105*cos(theta)**34 - 4.82638040162385e+104*cos(theta)**32 + 1.45083919951844e+104*cos(theta)**30 - 3.51988316670676e+103*cos(theta)**28 + 6.88672793486106e+102*cos(theta)**26 - 1.08281885768256e+102*cos(theta)**24 + 1.35968155013824e+101*cos(theta)**22 - 1.35090941110509e+100*cos(theta)**20 + 1.04849995142961e+99*cos(theta)**18 - 6.24933745885195e+97*cos(theta)**16 + 2.79612414266307e+96*cos(theta)**14 - 9.1101789109323e+94*cos(theta)**12 + 2.07335106248804e+93*cos(theta)**10 - 3.106919674058e+91*cos(theta)**8 + 2.8044407115933e+89*cos(theta)**6 - 1.31581516027211e+87*cos(theta)**4 + 2.40112255524108e+84*cos(theta)**2 - 7.11443720071432e+80)*cos(42*phi)

#@torch.jit.script
def Yl92_m43(theta, phi):
    return 8.15894618621495e-84*(1.0 - cos(theta)**2)**21.5*(5.94786114888899e+105*cos(theta)**49 - 3.82223208256473e+106*cos(theta)**47 + 1.14139029868853e+107*cos(theta)**45 - 2.10423909814086e+107*cos(theta)**43 + 2.6837964768661e+107*cos(theta)**41 - 2.51510069832023e+107*cos(theta)**39 + 1.79546205920548e+107*cos(theta)**37 - 9.98978890084254e+106*cos(theta)**35 + 4.39639378402464e+106*cos(theta)**33 - 1.54444172851963e+106*cos(theta)**31 + 4.35251759855533e+105*cos(theta)**29 - 9.85567286677894e+104*cos(theta)**27 + 1.79054926306388e+104*cos(theta)**25 - 2.59876525843814e+103*cos(theta)**23 + 2.99129941030413e+102*cos(theta)**21 - 2.70181882221018e+101*cos(theta)**19 + 1.88729991257329e+100*cos(theta)**17 - 9.99893993416313e+98*cos(theta)**15 + 3.91457379972829e+97*cos(theta)**13 - 1.09322146931188e+96*cos(theta)**11 + 2.07335106248804e+94*cos(theta)**9 - 2.4855357392464e+92*cos(theta)**7 + 1.68266442695598e+90*cos(theta)**5 - 5.26326064108845e+87*cos(theta)**3 + 4.80224511048216e+84*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl92_m44(theta, phi):
    return 9.9946266227838e-86*(1.0 - cos(theta)**2)**22*(2.91445196295561e+107*cos(theta)**48 - 1.79644907880542e+108*cos(theta)**46 + 5.13625634409838e+108*cos(theta)**44 - 9.04822812200571e+108*cos(theta)**42 + 1.1003565555151e+109*cos(theta)**40 - 9.8088927234489e+108*cos(theta)**38 + 6.64320961906029e+108*cos(theta)**36 - 3.49642611529489e+108*cos(theta)**34 + 1.45080994872813e+108*cos(theta)**32 - 4.78776935841086e+107*cos(theta)**30 + 1.26223010358105e+107*cos(theta)**28 - 2.66103167403031e+106*cos(theta)**26 + 4.47637315765969e+105*cos(theta)**24 - 5.97716009440771e+104*cos(theta)**22 + 6.28172876163868e+103*cos(theta)**20 - 5.13345576219935e+102*cos(theta)**18 + 3.20840985137459e+101*cos(theta)**16 - 1.49984099012447e+100*cos(theta)**14 + 5.08894593964678e+98*cos(theta)**12 - 1.20254361624306e+97*cos(theta)**10 + 1.86601595623924e+95*cos(theta)**8 - 1.73987501747248e+93*cos(theta)**6 + 8.41332213477989e+90*cos(theta)**4 - 1.57897819232654e+88*cos(theta)**2 + 4.80224511048216e+84)*cos(44*phi)

#@torch.jit.script
def Yl92_m45(theta, phi):
    return 1.23249643628823e-87*(1.0 - cos(theta)**2)**22.5*(1.39893694221869e+109*cos(theta)**47 - 8.26366576250495e+109*cos(theta)**45 + 2.25995279140329e+110*cos(theta)**43 - 3.8002558112424e+110*cos(theta)**41 + 4.4014262220604e+110*cos(theta)**39 - 3.72737923491058e+110*cos(theta)**37 + 2.3915554628617e+110*cos(theta)**35 - 1.18878487920026e+110*cos(theta)**33 + 4.64259183593002e+109*cos(theta)**31 - 1.43633080752326e+109*cos(theta)**29 + 3.53424429002693e+108*cos(theta)**27 - 6.91868235247882e+107*cos(theta)**25 + 1.07432955783833e+107*cos(theta)**23 - 1.3149752207697e+106*cos(theta)**21 + 1.25634575232774e+105*cos(theta)**19 - 9.24022037195883e+103*cos(theta)**17 + 5.13345576219935e+102*cos(theta)**15 - 2.09977738617426e+101*cos(theta)**13 + 6.10673512757614e+99*cos(theta)**11 - 1.20254361624306e+98*cos(theta)**9 + 1.49281276499139e+96*cos(theta)**7 - 1.04392501048349e+94*cos(theta)**5 + 3.36532885391196e+91*cos(theta)**3 - 3.15795638465307e+88*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl92_m46(theta, phi):
    return 1.53037266560346e-89*(1.0 - cos(theta)**2)**23*(6.57500362842785e+110*cos(theta)**46 - 3.71864959312723e+111*cos(theta)**44 + 9.71779700303413e+111*cos(theta)**42 - 1.55810488260938e+112*cos(theta)**40 + 1.71655622660356e+112*cos(theta)**38 - 1.37913031691692e+112*cos(theta)**36 + 8.37044412001596e+111*cos(theta)**34 - 3.92299010136086e+111*cos(theta)**32 + 1.43920346913831e+111*cos(theta)**30 - 4.16535934181745e+110*cos(theta)**28 + 9.5424595830727e+109*cos(theta)**26 - 1.7296705881197e+109*cos(theta)**24 + 2.47095798302815e+108*cos(theta)**22 - 2.76144796361636e+107*cos(theta)**20 + 2.3870569294227e+106*cos(theta)**18 - 1.570837463233e+105*cos(theta)**16 + 7.70018364329903e+103*cos(theta)**14 - 2.72971060202653e+102*cos(theta)**12 + 6.71740864033375e+100*cos(theta)**10 - 1.08228925461876e+99*cos(theta)**8 + 1.04496893549397e+97*cos(theta)**6 - 5.21962505241744e+94*cos(theta)**4 + 1.00959865617359e+92*cos(theta)**2 - 3.15795638465307e+88)*cos(46*phi)

#@torch.jit.script
def Yl92_m47(theta, phi):
    return 1.91386316572517e-91*(1.0 - cos(theta)**2)**23.5*(3.02450166907681e+112*cos(theta)**45 - 1.63620582097598e+113*cos(theta)**43 + 4.08147474127434e+113*cos(theta)**41 - 6.23241953043753e+113*cos(theta)**39 + 6.52291366109352e+113*cos(theta)**37 - 4.9648691409009e+113*cos(theta)**35 + 2.84595100080543e+113*cos(theta)**33 - 1.25535683243548e+113*cos(theta)**31 + 4.31761040741492e+112*cos(theta)**29 - 1.16630061570889e+112*cos(theta)**27 + 2.4810394915989e+111*cos(theta)**25 - 4.15120941148729e+110*cos(theta)**23 + 5.43610756266193e+109*cos(theta)**21 - 5.52289592723273e+108*cos(theta)**19 + 4.29670247296086e+107*cos(theta)**17 - 2.5133399411728e+106*cos(theta)**15 + 1.07802571006186e+105*cos(theta)**13 - 3.27565272243184e+103*cos(theta)**11 + 6.71740864033375e+101*cos(theta)**9 - 8.65831403695006e+99*cos(theta)**7 + 6.26981361296383e+97*cos(theta)**5 - 2.08785002096698e+95*cos(theta)**3 + 2.01919731234717e+92*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl92_m48(theta, phi):
    return 2.41124094281695e-93*(1.0 - cos(theta)**2)**24*(1.36102575108456e+114*cos(theta)**44 - 7.03568503019671e+114*cos(theta)**42 + 1.67340464392248e+115*cos(theta)**40 - 2.43064361687064e+115*cos(theta)**38 + 2.4134780546046e+115*cos(theta)**36 - 1.73770419931531e+115*cos(theta)**34 + 9.39163830265791e+114*cos(theta)**32 - 3.89160618054998e+114*cos(theta)**30 + 1.25210701815033e+114*cos(theta)**28 - 3.14901166241399e+113*cos(theta)**26 + 6.20259872899726e+112*cos(theta)**24 - 9.54778164642076e+111*cos(theta)**22 + 1.141582588159e+111*cos(theta)**20 - 1.04935022617422e+110*cos(theta)**18 + 7.30439420403346e+108*cos(theta)**16 - 3.7700099117592e+107*cos(theta)**14 + 1.40143342308042e+106*cos(theta)**12 - 3.60321799467503e+104*cos(theta)**10 + 6.04566777630038e+102*cos(theta)**8 - 6.06081982586504e+100*cos(theta)**6 + 3.13490680648192e+98*cos(theta)**4 - 6.26355006290093e+95*cos(theta)**2 + 2.01919731234717e+92)*cos(48*phi)

#@torch.jit.script
def Yl92_m49(theta, phi):
    return 3.06129170542975e-95*(1.0 - cos(theta)**2)**24.5*(5.98851330477209e+115*cos(theta)**43 - 2.95498771268262e+116*cos(theta)**41 + 6.69361857568991e+116*cos(theta)**39 - 9.23644574410842e+116*cos(theta)**37 + 8.68852099657657e+116*cos(theta)**35 - 5.90819427767207e+116*cos(theta)**33 + 3.00532425685053e+116*cos(theta)**31 - 1.16748185416499e+116*cos(theta)**29 + 3.50589965082091e+115*cos(theta)**27 - 8.18743032227638e+114*cos(theta)**25 + 1.48862369495934e+114*cos(theta)**23 - 2.10051196221257e+113*cos(theta)**21 + 2.28316517631801e+112*cos(theta)**19 - 1.88883040711359e+111*cos(theta)**17 + 1.16870307264535e+110*cos(theta)**15 - 5.27801387646288e+108*cos(theta)**13 + 1.68172010769651e+107*cos(theta)**11 - 3.60321799467502e+105*cos(theta)**9 + 4.8365342210403e+103*cos(theta)**7 - 3.63649189551902e+101*cos(theta)**5 + 1.25396272259277e+99*cos(theta)**3 - 1.25271001258019e+96*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl92_m50(theta, phi):
    return 3.91765614269084e-97*(1.0 - cos(theta)**2)**25*(2.575060721052e+117*cos(theta)**42 - 1.21154496219987e+118*cos(theta)**40 + 2.61051124451906e+118*cos(theta)**38 - 3.41748492532012e+118*cos(theta)**36 + 3.0409823488018e+118*cos(theta)**34 - 1.94970411163178e+118*cos(theta)**32 + 9.31650519623665e+117*cos(theta)**30 - 3.38569737707848e+117*cos(theta)**28 + 9.46592905721646e+116*cos(theta)**26 - 2.04685758056909e+116*cos(theta)**24 + 3.42383449840649e+115*cos(theta)**22 - 4.41107512064639e+114*cos(theta)**20 + 4.33801383500422e+113*cos(theta)**18 - 3.21101169209311e+112*cos(theta)**16 + 1.75305460896803e+111*cos(theta)**14 - 6.86141803940175e+109*cos(theta)**12 + 1.84989211846616e+108*cos(theta)**10 - 3.24289619520752e+106*cos(theta)**8 + 3.38557395472821e+104*cos(theta)**6 - 1.81824594775951e+102*cos(theta)**4 + 3.7618881677783e+99*cos(theta)**2 - 1.25271001258019e+96)*cos(50*phi)

#@torch.jit.script
def Yl92_m51(theta, phi):
    return 5.05514539115145e-99*(1.0 - cos(theta)**2)**25.5*(1.08152550284184e+119*cos(theta)**41 - 4.8461798487995e+119*cos(theta)**39 + 9.91994272917245e+119*cos(theta)**37 - 1.23029457311524e+120*cos(theta)**35 + 1.03393399859261e+120*cos(theta)**33 - 6.2390531572217e+119*cos(theta)**31 + 2.79495155887099e+119*cos(theta)**29 - 9.47995265581974e+118*cos(theta)**27 + 2.46114155487628e+118*cos(theta)**25 - 4.91245819336583e+117*cos(theta)**23 + 7.53243589649427e+116*cos(theta)**21 - 8.82215024129279e+115*cos(theta)**19 + 7.80842490300759e+114*cos(theta)**17 - 5.13761870734897e+113*cos(theta)**15 + 2.45427645255524e+112*cos(theta)**13 - 8.2337016472821e+110*cos(theta)**11 + 1.84989211846616e+109*cos(theta)**9 - 2.59431695616602e+107*cos(theta)**7 + 2.03134437283693e+105*cos(theta)**5 - 7.27298379103805e+102*cos(theta)**3 + 7.5237763355566e+99*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl92_m52(theta, phi):
    return 6.57900893858309e-101*(1.0 - cos(theta)**2)**26*(4.43425456165154e+120*cos(theta)**40 - 1.8900101410318e+121*cos(theta)**38 + 3.67037880979381e+121*cos(theta)**36 - 4.30603100590335e+121*cos(theta)**34 + 3.41198219535562e+121*cos(theta)**32 - 1.93410647873873e+121*cos(theta)**30 + 8.10535952072588e+120*cos(theta)**28 - 2.55958721707133e+120*cos(theta)**26 + 6.1528538871907e+119*cos(theta)**24 - 1.12986538447414e+119*cos(theta)**22 + 1.5818115382638e+118*cos(theta)**20 - 1.67620854584563e+117*cos(theta)**18 + 1.32743223351129e+116*cos(theta)**16 - 7.70642806102346e+114*cos(theta)**14 + 3.19055938832181e+113*cos(theta)**12 - 9.05707181201031e+111*cos(theta)**10 + 1.66490290661954e+110*cos(theta)**8 - 1.81602186931621e+108*cos(theta)**6 + 1.01567218641846e+106*cos(theta)**4 - 2.18189513731141e+103*cos(theta)**2 + 7.5237763355566e+99)*cos(52*phi)

#@torch.jit.script
def Yl92_m53(theta, phi):
    return 8.63866195477575e-103*(1.0 - cos(theta)**2)**26.5*(1.77370182466062e+122*cos(theta)**39 - 7.18203853592085e+122*cos(theta)**37 + 1.32133637152577e+123*cos(theta)**35 - 1.46405054200714e+123*cos(theta)**33 + 1.0918343025138e+123*cos(theta)**31 - 5.80231943621618e+122*cos(theta)**29 + 2.26950066580325e+122*cos(theta)**27 - 6.65492676438546e+121*cos(theta)**25 + 1.47668493292577e+121*cos(theta)**23 - 2.48570384584311e+120*cos(theta)**21 + 3.16362307652759e+119*cos(theta)**19 - 3.01717538252213e+118*cos(theta)**17 + 2.12389157361806e+117*cos(theta)**15 - 1.07889992854328e+116*cos(theta)**13 + 3.82867126598618e+114*cos(theta)**11 - 9.05707181201031e+112*cos(theta)**9 + 1.33192232529563e+111*cos(theta)**7 - 1.08961312158973e+109*cos(theta)**5 + 4.06268874567385e+106*cos(theta)**3 - 4.36379027462283e+103*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl92_m54(theta, phi):
    return 1.14482142432251e-104*(1.0 - cos(theta)**2)**27*(6.9174371161764e+123*cos(theta)**38 - 2.65735425829072e+124*cos(theta)**36 + 4.6246773003402e+124*cos(theta)**34 - 4.83136678862356e+124*cos(theta)**32 + 3.38468633779277e+124*cos(theta)**30 - 1.68267263650269e+124*cos(theta)**28 + 6.12765179766877e+123*cos(theta)**26 - 1.66373169109637e+123*cos(theta)**24 + 3.39637534572927e+122*cos(theta)**22 - 5.21997807627053e+121*cos(theta)**20 + 6.01088384540243e+120*cos(theta)**18 - 5.12919815028763e+119*cos(theta)**16 + 3.1858373604271e+118*cos(theta)**14 - 1.40256990710627e+117*cos(theta)**12 + 4.21153839258479e+115*cos(theta)**10 - 8.15136463080928e+113*cos(theta)**8 + 9.32345627706944e+111*cos(theta)**6 - 5.44806560794864e+109*cos(theta)**4 + 1.21880662370216e+107*cos(theta)**2 - 4.36379027462283e+103)*cos(54*phi)

#@torch.jit.script
def Yl92_m55(theta, phi):
    return 1.53174786116458e-106*(1.0 - cos(theta)**2)**27.5*(2.62862610414703e+125*cos(theta)**37 - 9.56647532984657e+125*cos(theta)**35 + 1.57239028211567e+126*cos(theta)**33 - 1.54603737235954e+126*cos(theta)**31 + 1.01540590133783e+126*cos(theta)**29 - 4.71148338220754e+125*cos(theta)**27 + 1.59318946739388e+125*cos(theta)**25 - 3.99295605863128e+124*cos(theta)**23 + 7.47202576060439e+123*cos(theta)**21 - 1.04399561525411e+123*cos(theta)**19 + 1.08195909217244e+122*cos(theta)**17 - 8.2067170404602e+120*cos(theta)**15 + 4.46017230459794e+119*cos(theta)**13 - 1.68308388852752e+118*cos(theta)**11 + 4.21153839258479e+116*cos(theta)**9 - 6.52109170464742e+114*cos(theta)**7 + 5.59407376624166e+112*cos(theta)**5 - 2.17922624317946e+110*cos(theta)**3 + 2.43761324740431e+107*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl92_m56(theta, phi):
    return 2.0699295421143e-108*(1.0 - cos(theta)**2)**28*(9.72591658534402e+126*cos(theta)**36 - 3.3482663654463e+127*cos(theta)**34 + 5.1888879309817e+127*cos(theta)**32 - 4.79271585431457e+127*cos(theta)**30 + 2.94467711387971e+127*cos(theta)**28 - 1.27210051319604e+127*cos(theta)**26 + 3.9829736684847e+126*cos(theta)**24 - 9.18379893485194e+125*cos(theta)**22 + 1.56912540972692e+125*cos(theta)**20 - 1.9835916689828e+124*cos(theta)**18 + 1.83933045669314e+123*cos(theta)**16 - 1.23100755606903e+122*cos(theta)**14 + 5.79822399597732e+120*cos(theta)**12 - 1.85139227738028e+119*cos(theta)**10 + 3.79038455332631e+117*cos(theta)**8 - 4.5647641932532e+115*cos(theta)**6 + 2.79703688312083e+113*cos(theta)**4 - 6.53767872953836e+110*cos(theta)**2 + 2.43761324740431e+107)*cos(56*phi)

#@torch.jit.script
def Yl92_m57(theta, phi):
    return 2.82625392354232e-110*(1.0 - cos(theta)**2)**28.5*(3.50132997072385e+128*cos(theta)**35 - 1.13841056425174e+129*cos(theta)**33 + 1.66044413791414e+129*cos(theta)**31 - 1.43781475629437e+129*cos(theta)**29 + 8.2450959188632e+128*cos(theta)**27 - 3.30746133430969e+128*cos(theta)**25 + 9.55913680436328e+127*cos(theta)**23 - 2.02043576566743e+127*cos(theta)**21 + 3.13825081945384e+126*cos(theta)**19 - 3.57046500416904e+125*cos(theta)**17 + 2.94292873070903e+124*cos(theta)**15 - 1.72341057849664e+123*cos(theta)**13 + 6.95786879517278e+121*cos(theta)**11 - 1.85139227738028e+120*cos(theta)**9 + 3.03230764266105e+118*cos(theta)**7 - 2.73885851595192e+116*cos(theta)**5 + 1.11881475324833e+114*cos(theta)**3 - 1.30753574590767e+111*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl92_m58(theta, phi):
    return 3.90060098918551e-112*(1.0 - cos(theta)**2)**29*(1.22546548975335e+130*cos(theta)**34 - 3.75675486203075e+130*cos(theta)**32 + 5.14737682753385e+130*cos(theta)**30 - 4.16966279325367e+130*cos(theta)**28 + 2.22617589809306e+130*cos(theta)**26 - 8.26865333577423e+129*cos(theta)**24 + 2.19860146500355e+129*cos(theta)**22 - 4.24291510790159e+128*cos(theta)**20 + 5.9626765569623e+127*cos(theta)**18 - 6.06979050708737e+126*cos(theta)**16 + 4.41439309606354e+125*cos(theta)**14 - 2.24043375204564e+124*cos(theta)**12 + 7.65365567469006e+122*cos(theta)**10 - 1.66625304964225e+121*cos(theta)**8 + 2.12261534986274e+119*cos(theta)**6 - 1.36942925797596e+117*cos(theta)**4 + 3.356444259745e+114*cos(theta)**2 - 1.30753574590767e+111)*cos(58*phi)

#@torch.jit.script
def Yl92_m59(theta, phi):
    return 5.44381796405602e-114*(1.0 - cos(theta)**2)**29.5*(4.16658266516138e+131*cos(theta)**33 - 1.20216155584984e+132*cos(theta)**31 + 1.54421304826015e+132*cos(theta)**29 - 1.16750558211103e+132*cos(theta)**27 + 5.78805733504196e+131*cos(theta)**25 - 1.98447680058582e+131*cos(theta)**23 + 4.83692322300782e+130*cos(theta)**21 - 8.48583021580319e+129*cos(theta)**19 + 1.07328178025321e+129*cos(theta)**17 - 9.71166481133979e+127*cos(theta)**15 + 6.18015033448896e+126*cos(theta)**13 - 2.68852050245476e+125*cos(theta)**11 + 7.65365567469006e+123*cos(theta)**9 - 1.3330024397138e+122*cos(theta)**7 + 1.27356920991764e+120*cos(theta)**5 - 5.47771703190383e+117*cos(theta)**3 + 6.71288851948999e+114*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl92_m60(theta, phi):
    return 7.68643272641954e-116*(1.0 - cos(theta)**2)**30*(1.37497227950325e+133*cos(theta)**32 - 3.7267008231345e+133*cos(theta)**30 + 4.47821783995445e+133*cos(theta)**28 - 3.15226507169978e+133*cos(theta)**26 + 1.44701433376049e+133*cos(theta)**24 - 4.56429664134738e+132*cos(theta)**22 + 1.01575387683164e+132*cos(theta)**20 - 1.61230774100261e+131*cos(theta)**18 + 1.82457902643046e+130*cos(theta)**16 - 1.45674972170097e+129*cos(theta)**14 + 8.03419543483565e+127*cos(theta)**12 - 2.95737255270024e+126*cos(theta)**10 + 6.88829010722105e+124*cos(theta)**8 - 9.33101707799659e+122*cos(theta)**6 + 6.36784604958821e+120*cos(theta)**4 - 1.64331510957115e+118*cos(theta)**2 + 6.71288851948999e+114)*cos(60*phi)

#@torch.jit.script
def Yl92_m61(theta, phi):
    return 1.09851028114502e-117*(1.0 - cos(theta)**2)**30.5*(4.39991129441041e+134*cos(theta)**31 - 1.11801024694035e+135*cos(theta)**29 + 1.25390099518724e+135*cos(theta)**27 - 8.19588918641942e+134*cos(theta)**25 + 3.47283440102518e+134*cos(theta)**23 - 1.00414526109642e+134*cos(theta)**21 + 2.03150775366328e+133*cos(theta)**19 - 2.90215393380469e+132*cos(theta)**17 + 2.91932644228874e+131*cos(theta)**15 - 2.03944961038136e+130*cos(theta)**13 + 9.64103452180278e+128*cos(theta)**11 - 2.95737255270024e+127*cos(theta)**9 + 5.51063208577684e+125*cos(theta)**7 - 5.59861024679795e+123*cos(theta)**5 + 2.54713841983528e+121*cos(theta)**3 - 3.2866302191423e+118*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl92_m62(theta, phi):
    return 1.58987477392937e-119*(1.0 - cos(theta)**2)**31*(1.36397250126723e+136*cos(theta)**30 - 3.24222971612702e+136*cos(theta)**28 + 3.38553268700556e+136*cos(theta)**26 - 2.04897229660486e+136*cos(theta)**24 + 7.98751912235791e+135*cos(theta)**22 - 2.10870504830249e+135*cos(theta)**20 + 3.85986473196024e+134*cos(theta)**18 - 4.93366168746797e+133*cos(theta)**16 + 4.37898966343311e+132*cos(theta)**14 - 2.65128449349576e+131*cos(theta)**12 + 1.06051379739831e+130*cos(theta)**10 - 2.66163529743021e+128*cos(theta)**8 + 3.85744246004379e+126*cos(theta)**6 - 2.79930512339898e+124*cos(theta)**4 + 7.64141525950585e+121*cos(theta)**2 - 3.2866302191423e+118)*cos(62*phi)

#@torch.jit.script
def Yl92_m63(theta, phi):
    return 2.33150548841968e-121*(1.0 - cos(theta)**2)**31.5*(4.09191750380168e+137*cos(theta)**29 - 9.07824320515565e+137*cos(theta)**27 + 8.80238498621446e+137*cos(theta)**25 - 4.91753351185165e+137*cos(theta)**23 + 1.75725420691874e+137*cos(theta)**21 - 4.21741009660498e+136*cos(theta)**19 + 6.94775651752843e+135*cos(theta)**17 - 7.89385869994876e+134*cos(theta)**15 + 6.13058552880636e+133*cos(theta)**13 - 3.18154139219492e+132*cos(theta)**11 + 1.06051379739831e+131*cos(theta)**9 - 2.12930823794417e+129*cos(theta)**7 + 2.31446547602627e+127*cos(theta)**5 - 1.11972204935959e+125*cos(theta)**3 + 1.52828305190117e+122*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl92_m64(theta, phi):
    return 3.46637180864413e-123*(1.0 - cos(theta)**2)**32*(1.18665607610249e+139*cos(theta)**28 - 2.45112566539203e+139*cos(theta)**26 + 2.20059624655361e+139*cos(theta)**24 - 1.13103270772588e+139*cos(theta)**22 + 3.69023383452935e+138*cos(theta)**20 - 8.01307918354946e+137*cos(theta)**18 + 1.18111860797983e+137*cos(theta)**16 - 1.18407880499231e+136*cos(theta)**14 + 7.96976118744827e+134*cos(theta)**12 - 3.49969553141441e+133*cos(theta)**10 + 9.54462417658475e+131*cos(theta)**8 - 1.49051576656092e+130*cos(theta)**6 + 1.15723273801314e+128*cos(theta)**4 - 3.35916614807877e+125*cos(theta)**2 + 1.52828305190117e+122)*cos(64*phi)

#@torch.jit.script
def Yl92_m65(theta, phi):
    return 5.22812908680753e-125*(1.0 - cos(theta)**2)**32.5*(3.32263701308697e+140*cos(theta)**27 - 6.37292673001927e+140*cos(theta)**25 + 5.28143099172867e+140*cos(theta)**23 - 2.48827195699694e+140*cos(theta)**21 + 7.38046766905871e+139*cos(theta)**19 - 1.4423542530389e+139*cos(theta)**17 + 1.88978977276773e+138*cos(theta)**15 - 1.65771032698924e+137*cos(theta)**13 + 9.56371342493792e+135*cos(theta)**11 - 3.49969553141441e+134*cos(theta)**9 + 7.6356993412678e+132*cos(theta)**7 - 8.94309459936552e+130*cos(theta)**5 + 4.62893095205255e+128*cos(theta)**3 - 6.71833229615754e+125*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl92_m66(theta, phi):
    return 8.00453073594444e-127*(1.0 - cos(theta)**2)**33*(8.97111993533482e+141*cos(theta)**26 - 1.59323168250482e+142*cos(theta)**24 + 1.2147291280976e+142*cos(theta)**22 - 5.22537110969357e+141*cos(theta)**20 + 1.40228885712115e+141*cos(theta)**18 - 2.45200223016613e+140*cos(theta)**16 + 2.8346846591516e+139*cos(theta)**14 - 2.15502342508601e+138*cos(theta)**12 + 1.05200847674317e+137*cos(theta)**10 - 3.14972597827297e+135*cos(theta)**8 + 5.34498953888746e+133*cos(theta)**6 - 4.47154729968276e+131*cos(theta)**4 + 1.38867928561576e+129*cos(theta)**2 - 6.71833229615754e+125)*cos(66*phi)

#@torch.jit.script
def Yl92_m67(theta, phi):
    return 1.24494636197176e-128*(1.0 - cos(theta)**2)**33.5*(2.33249118318705e+143*cos(theta)**25 - 3.82375603801156e+143*cos(theta)**23 + 2.67240408181471e+143*cos(theta)**21 - 1.04507422193871e+143*cos(theta)**19 + 2.52411994281808e+142*cos(theta)**17 - 3.92320356826581e+141*cos(theta)**15 + 3.96855852281224e+140*cos(theta)**13 - 2.58602811010321e+139*cos(theta)**11 + 1.05200847674317e+138*cos(theta)**9 - 2.51978078261837e+136*cos(theta)**7 + 3.20699372333248e+134*cos(theta)**5 - 1.7886189198731e+132*cos(theta)**3 + 2.77735857123153e+129*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl92_m68(theta, phi):
    return 1.9684330342856e-130*(1.0 - cos(theta)**2)**34*(5.83122795796763e+144*cos(theta)**24 - 8.79463888742659e+144*cos(theta)**22 + 5.61204857181089e+144*cos(theta)**20 - 1.98564102168356e+144*cos(theta)**18 + 4.29100390279073e+143*cos(theta)**16 - 5.88480535239872e+142*cos(theta)**14 + 5.15912607965591e+141*cos(theta)**12 - 2.84463092111353e+140*cos(theta)**10 + 9.46807629068854e+138*cos(theta)**8 - 1.76384654783286e+137*cos(theta)**6 + 1.60349686166624e+135*cos(theta)**4 - 5.36585675961931e+132*cos(theta)**2 + 2.77735857123153e+129)*cos(68*phi)

#@torch.jit.script
def Yl92_m69(theta, phi):
    return 3.16666473675985e-132*(1.0 - cos(theta)**2)**34.5*(1.39949470991223e+146*cos(theta)**23 - 1.93482055523385e+146*cos(theta)**21 + 1.12240971436218e+146*cos(theta)**19 - 3.5741538390304e+145*cos(theta)**17 + 6.86560624446517e+144*cos(theta)**15 - 8.23872749335821e+143*cos(theta)**13 + 6.19095129558709e+142*cos(theta)**11 - 2.84463092111353e+141*cos(theta)**9 + 7.57446103255083e+139*cos(theta)**7 - 1.05830792869972e+138*cos(theta)**5 + 6.41398744666495e+135*cos(theta)**3 - 1.07317135192386e+133*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl92_m70(theta, phi):
    return 5.18776936971783e-134*(1.0 - cos(theta)**2)**35*(3.21883783279813e+147*cos(theta)**22 - 4.06312316599108e+147*cos(theta)**20 + 2.13257845728814e+147*cos(theta)**18 - 6.07606152635168e+146*cos(theta)**16 + 1.02984093666978e+146*cos(theta)**14 - 1.07103457413657e+145*cos(theta)**12 + 6.8100464251458e+143*cos(theta)**10 - 2.56016782900218e+142*cos(theta)**8 + 5.30212272278558e+140*cos(theta)**6 - 5.29153964349858e+138*cos(theta)**4 + 1.92419623399949e+136*cos(theta)**2 - 1.07317135192386e+133)*cos(70*phi)

#@torch.jit.script
def Yl92_m71(theta, phi):
    return 8.66314369349615e-136*(1.0 - cos(theta)**2)**35.5*(7.08144323215589e+148*cos(theta)**21 - 8.12624633198217e+148*cos(theta)**19 + 3.83864122311865e+148*cos(theta)**17 - 9.72169844216269e+147*cos(theta)**15 + 1.44177731133769e+147*cos(theta)**13 - 1.28524148896388e+146*cos(theta)**11 + 6.8100464251458e+144*cos(theta)**9 - 2.04813426320174e+143*cos(theta)**7 + 3.18127363367135e+141*cos(theta)**5 - 2.11661585739943e+139*cos(theta)**3 + 3.84839246799897e+136*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl92_m72(theta, phi):
    return 1.47619573625819e-137*(1.0 - cos(theta)**2)**36*(1.48710307875274e+150*cos(theta)**20 - 1.54398680307661e+150*cos(theta)**18 + 6.5256900793017e+149*cos(theta)**16 - 1.4582547663244e+149*cos(theta)**14 + 1.87431050473899e+148*cos(theta)**12 - 1.41376563786027e+147*cos(theta)**10 + 6.12904178263122e+145*cos(theta)**8 - 1.43369398424122e+144*cos(theta)**6 + 1.59063681683567e+142*cos(theta)**4 - 6.3498475721983e+139*cos(theta)**2 + 3.84839246799897e+136)*cos(72*phi)

#@torch.jit.script
def Yl92_m73(theta, phi):
    return 2.56972693499622e-139*(1.0 - cos(theta)**2)**36.5*(2.97420615750547e+151*cos(theta)**19 - 2.7791762455379e+151*cos(theta)**17 + 1.04411041268827e+151*cos(theta)**15 - 2.04155667285416e+150*cos(theta)**13 + 2.24917260568679e+149*cos(theta)**11 - 1.41376563786027e+148*cos(theta)**9 + 4.90323342610498e+146*cos(theta)**7 - 8.60216390544733e+144*cos(theta)**5 + 6.3625472673427e+142*cos(theta)**3 - 1.26996951443966e+140*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl92_m74(theta, phi):
    return 4.57568513827241e-141*(1.0 - cos(theta)**2)**37*(5.6509916992604e+152*cos(theta)**18 - 4.72459961741443e+152*cos(theta)**16 + 1.56616561903241e+152*cos(theta)**14 - 2.65402367471041e+151*cos(theta)**12 + 2.47408986625547e+150*cos(theta)**10 - 1.27238907407424e+149*cos(theta)**8 + 3.43226339827348e+147*cos(theta)**6 - 4.30108195272366e+145*cos(theta)**4 + 1.90876418020281e+143*cos(theta)**2 - 1.26996951443966e+140)*cos(74*phi)

#@torch.jit.script
def Yl92_m75(theta, phi):
    return 8.34567837787017e-143*(1.0 - cos(theta)**2)**37.5*(1.01717850586687e+154*cos(theta)**17 - 7.55935938786309e+153*cos(theta)**15 + 2.19263186664537e+153*cos(theta)**13 - 3.1848284096525e+152*cos(theta)**11 + 2.47408986625547e+151*cos(theta)**9 - 1.01791125925939e+150*cos(theta)**7 + 2.05935803896409e+148*cos(theta)**5 - 1.72043278108947e+146*cos(theta)**3 + 3.81752836040562e+143*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl92_m76(theta, phi):
    return 1.56164581791262e-144*(1.0 - cos(theta)**2)**38*(1.72920345997368e+155*cos(theta)**16 - 1.13390390817946e+155*cos(theta)**14 + 2.85042142663898e+154*cos(theta)**12 - 3.50331125061775e+153*cos(theta)**10 + 2.22668087962992e+152*cos(theta)**8 - 7.12537881481575e+150*cos(theta)**6 + 1.02967901948205e+149*cos(theta)**4 - 5.1612983432684e+146*cos(theta)**2 + 3.81752836040562e+143)*cos(76*phi)

#@torch.jit.script
def Yl92_m77(theta, phi):
    return 3.00316503444735e-146*(1.0 - cos(theta)**2)**38.5*(2.76672553595789e+156*cos(theta)**15 - 1.58746547145125e+156*cos(theta)**13 + 3.42050571196678e+155*cos(theta)**11 - 3.50331125061775e+154*cos(theta)**9 + 1.78134470370394e+153*cos(theta)**7 - 4.27522728888945e+151*cos(theta)**5 + 4.11871607792818e+149*cos(theta)**3 - 1.03225966865368e+147*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl92_m78(theta, phi):
    return 5.94715296002301e-148*(1.0 - cos(theta)**2)**39*(4.15008830393684e+157*cos(theta)**14 - 2.06370511288662e+157*cos(theta)**12 + 3.76255628316346e+156*cos(theta)**10 - 3.15298012555597e+155*cos(theta)**8 + 1.24694129259276e+154*cos(theta)**6 - 2.13761364444473e+152*cos(theta)**4 + 1.23561482337845e+150*cos(theta)**2 - 1.03225966865368e+147)*cos(78*phi)

#@torch.jit.script
def Yl92_m79(theta, phi):
    return 1.21547781257485e-149*(1.0 - cos(theta)**2)**39.5*(5.81012362551157e+158*cos(theta)**13 - 2.47644613546395e+158*cos(theta)**11 + 3.76255628316346e+157*cos(theta)**9 - 2.52238410044478e+156*cos(theta)**7 + 7.48164775555654e+154*cos(theta)**5 - 8.5504545777789e+152*cos(theta)**3 + 2.47122964675691e+150*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl92_m80(theta, phi):
    return 2.57046169264107e-151*(1.0 - cos(theta)**2)**40*(7.55316071316504e+159*cos(theta)**12 - 2.72409074901034e+159*cos(theta)**10 + 3.38630065484711e+158*cos(theta)**8 - 1.76566887031134e+157*cos(theta)**6 + 3.74082387777827e+155*cos(theta)**4 - 2.56513637333367e+153*cos(theta)**2 + 2.47122964675691e+150)*cos(80*phi)

#@torch.jit.script
def Yl92_m81(theta, phi):
    return 5.64153726766583e-153*(1.0 - cos(theta)**2)**40.5*(9.06379285579805e+160*cos(theta)**11 - 2.72409074901034e+160*cos(theta)**9 + 2.70904052387769e+159*cos(theta)**7 - 1.05940132218681e+158*cos(theta)**5 + 1.49632955111131e+156*cos(theta)**3 - 5.13027274666734e+153*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl92_m82(theta, phi):
    return 1.28951528609199e-154*(1.0 - cos(theta)**2)**41*(9.97017214137786e+161*cos(theta)**10 - 2.45168167410931e+161*cos(theta)**8 + 1.89632836671438e+160*cos(theta)**6 - 5.29700661093403e+158*cos(theta)**4 + 4.48898865333392e+156*cos(theta)**2 - 5.13027274666734e+153)*cos(82*phi)

#@torch.jit.script
def Yl92_m83(theta, phi):
    return 3.08253112422235e-156*(1.0 - cos(theta)**2)**41.5*(9.97017214137786e+162*cos(theta)**9 - 1.96134533928745e+162*cos(theta)**7 + 1.13779702002863e+161*cos(theta)**5 - 2.11880264437361e+159*cos(theta)**3 + 8.97797730666785e+156*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl92_m84(theta, phi):
    return 7.74515086639239e-158*(1.0 - cos(theta)**2)**42*(8.97315492724007e+163*cos(theta)**8 - 1.37294173750121e+163*cos(theta)**6 + 5.68898510014315e+161*cos(theta)**4 - 6.35640793312084e+159*cos(theta)**2 + 8.97797730666785e+156)*cos(84*phi)

#@torch.jit.script
def Yl92_m85(theta, phi):
    return 2.05825062066215e-159*(1.0 - cos(theta)**2)**42.5*(7.17852394179206e+164*cos(theta)**7 - 8.23765042500728e+163*cos(theta)**5 + 2.27559404005726e+162*cos(theta)**3 - 1.27128158662417e+160*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl92_m86(theta, phi):
    return 5.83094887879286e-161*(1.0 - cos(theta)**2)**43*(5.02496675925444e+165*cos(theta)**6 - 4.11882521250364e+164*cos(theta)**4 + 6.82678212017178e+162*cos(theta)**2 - 1.27128158662417e+160)*cos(86*phi)

#@torch.jit.script
def Yl92_m87(theta, phi):
    return 1.77925048630756e-162*(1.0 - cos(theta)**2)**43.5*(3.01498005555266e+166*cos(theta)**5 - 1.64753008500146e+165*cos(theta)**3 + 1.36535642403436e+163*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl92_m88(theta, phi):
    return 5.93083495435852e-164*(1.0 - cos(theta)**2)**44*(1.50749002777633e+167*cos(theta)**4 - 4.94259025500437e+165*cos(theta)**2 + 1.36535642403436e+163)*cos(88*phi)

#@torch.jit.script
def Yl92_m89(theta, phi):
    return 2.20417745196638e-165*(1.0 - cos(theta)**2)**44.5*(6.02996011110533e+167*cos(theta)**3 - 9.88518051000874e+165*cos(theta))*cos(89*phi)

#@torch.jit.script
def Yl92_m90(theta, phi):
    return 9.43300867924983e-167*(1.0 - cos(theta)**2)**45*(1.8089880333316e+168*cos(theta)**2 - 9.88518051000874e+165)*cos(90*phi)

#@torch.jit.script
def Yl92_m91(theta, phi):
    return 17.8392002646519*(1.0 - cos(theta)**2)**45.5*cos(91*phi)*cos(theta)

#@torch.jit.script
def Yl92_m92(theta, phi):
    return 1.31512329162961*(1.0 - cos(theta)**2)**46*cos(92*phi)

#@torch.jit.script
def Yl93_m_minus_93(theta, phi):
    return 1.31865383030867*(1.0 - cos(theta)**2)**46.5*sin(93*phi)

#@torch.jit.script
def Yl93_m_minus_92(theta, phi):
    return 17.9840405331759*(1.0 - cos(theta)**2)**46*sin(92*phi)*cos(theta)

#@torch.jit.script
def Yl93_m_minus_91(theta, phi):
    return 5.16833572383453e-169*(1.0 - cos(theta)**2)**45.5*(3.34662786166346e+170*cos(theta)**2 - 1.8089880333316e+168)*sin(91*phi)

#@torch.jit.script
def Yl93_m_minus_90(theta, phi):
    return 1.21428395250674e-167*(1.0 - cos(theta)**2)**45*(1.11554262055449e+170*cos(theta)**3 - 1.8089880333316e+168*cos(theta))*sin(90*phi)

#@torch.jit.script
def Yl93_m_minus_89(theta, phi):
    return 3.28530576761869e-166*(1.0 - cos(theta)**2)**44.5*(2.78885655138621e+169*cos(theta)**4 - 9.04494016665799e+167*cos(theta)**2 + 2.47129512750218e+165)*sin(89*phi)

#@torch.jit.script
def Yl93_m_minus_88(theta, phi):
    return 9.91052114065714e-165*(1.0 - cos(theta)**2)**44*(5.57771310277243e+168*cos(theta)**5 - 3.01498005555266e+167*cos(theta)**3 + 2.47129512750218e+165*cos(theta))*sin(88*phi)

#@torch.jit.script
def Yl93_m_minus_87(theta, phi):
    return 3.26596408733228e-163*(1.0 - cos(theta)**2)**43.5*(9.29618850462072e+167*cos(theta)**6 - 7.53745013888166e+166*cos(theta)**4 + 1.23564756375109e+165*cos(theta)**2 - 2.27559404005726e+162)*sin(87*phi)

#@torch.jit.script
def Yl93_m_minus_86(theta, phi):
    return 1.15930224656375e-161*(1.0 - cos(theta)**2)**43*(1.32802692923153e+167*cos(theta)**7 - 1.50749002777633e+166*cos(theta)**5 + 4.11882521250364e+164*cos(theta)**3 - 2.27559404005726e+162*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl93_m_minus_85(theta, phi):
    return 4.3870055764807e-160*(1.0 - cos(theta)**2)**42.5*(1.66003366153941e+166*cos(theta)**8 - 2.51248337962722e+165*cos(theta)**6 + 1.02970630312591e+164*cos(theta)**4 - 1.13779702002863e+162*cos(theta)**2 + 1.58910198328021e+159)*sin(85*phi)

#@torch.jit.script
def Yl93_m_minus_84(theta, phi):
    return 1.75589863946563e-158*(1.0 - cos(theta)**2)**42*(1.8444818461549e+165*cos(theta)**9 - 3.58926197089603e+164*cos(theta)**7 + 2.05941260625182e+163*cos(theta)**5 - 3.79265673342877e+161*cos(theta)**3 + 1.58910198328021e+159*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl93_m_minus_83(theta, phi):
    return 7.38730577191492e-157*(1.0 - cos(theta)**2)**41.5*(1.8444818461549e+164*cos(theta)**10 - 4.48657746362004e+163*cos(theta)**8 + 3.43235434375303e+162*cos(theta)**6 - 9.48164183357192e+160*cos(theta)**4 + 7.94550991640105e+158*cos(theta)**2 - 8.97797730666785e+155)*sin(83*phi)

#@torch.jit.script
def Yl93_m_minus_82(theta, phi):
    return 3.25041453964257e-155*(1.0 - cos(theta)**2)**41*(1.67680167832264e+163*cos(theta)**11 - 4.98508607068893e+162*cos(theta)**9 + 4.90336334821862e+161*cos(theta)**7 - 1.89632836671438e+160*cos(theta)**5 + 2.64850330546702e+158*cos(theta)**3 - 8.97797730666785e+155*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl93_m_minus_81(theta, phi):
    return 1.48952706678971e-153*(1.0 - cos(theta)**2)**40.5*(1.39733473193553e+162*cos(theta)**12 - 4.98508607068893e+161*cos(theta)**10 + 6.12920418527327e+160*cos(theta)**8 - 3.16054727785731e+159*cos(theta)**6 + 6.62125826366754e+157*cos(theta)**4 - 4.48898865333392e+155*cos(theta)**2 + 4.27522728888945e+152)*sin(81*phi)

#@torch.jit.script
def Yl93_m_minus_80(theta, phi):
    return 7.08426338913616e-152*(1.0 - cos(theta)**2)**40*(1.07487287071964e+161*cos(theta)**13 - 4.53189642789903e+160*cos(theta)**11 + 6.81022687252586e+159*cos(theta)**9 - 4.51506753979615e+158*cos(theta)**7 + 1.32425165273351e+157*cos(theta)**5 - 1.49632955111131e+155*cos(theta)**3 + 4.27522728888945e+152*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl93_m_minus_79(theta, phi):
    return 3.48643657580112e-150*(1.0 - cos(theta)**2)**39.5*(7.67766336228315e+159*cos(theta)**14 - 3.77658035658252e+159*cos(theta)**12 + 6.81022687252586e+158*cos(theta)**10 - 5.64383442474519e+157*cos(theta)**8 + 2.20708608788918e+156*cos(theta)**6 - 3.74082387777827e+154*cos(theta)**4 + 2.13761364444473e+152*cos(theta)**2 - 1.76516403339779e+149)*sin(79*phi)

#@torch.jit.script
def Yl93_m_minus_78(theta, phi):
    return 1.77089014883691e-148*(1.0 - cos(theta)**2)**39*(5.1184422415221e+158*cos(theta)**15 - 2.90506181275579e+158*cos(theta)**13 + 6.19111533865987e+157*cos(theta)**11 - 6.27092713860576e+156*cos(theta)**9 + 3.15298012555597e+155*cos(theta)**7 - 7.48164775555654e+153*cos(theta)**5 + 7.12537881481575e+151*cos(theta)**3 - 1.76516403339779e+149*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl93_m_minus_77(theta, phi):
    return 9.26295743867017e-147*(1.0 - cos(theta)**2)**38.5*(3.19902640095131e+157*cos(theta)**16 - 2.07504415196842e+157*cos(theta)**14 + 5.15926278221656e+156*cos(theta)**12 - 6.27092713860576e+155*cos(theta)**10 + 3.94122515694496e+154*cos(theta)**8 - 1.24694129259276e+153*cos(theta)**6 + 1.78134470370394e+151*cos(theta)**4 - 8.82582016698896e+148*cos(theta)**2 + 6.4516229290855e+145)*sin(77*phi)

#@torch.jit.script
def Yl93_m_minus_76(theta, phi):
    return 4.97964737381752e-145*(1.0 - cos(theta)**2)**38*(1.88178023585371e+156*cos(theta)**17 - 1.38336276797895e+156*cos(theta)**15 + 3.96866367862812e+155*cos(theta)**13 - 5.70084285327797e+154*cos(theta)**11 + 4.37913906327218e+153*cos(theta)**9 - 1.78134470370394e+152*cos(theta)**7 + 3.56268940740788e+150*cos(theta)**5 - 2.94194005566299e+148*cos(theta)**3 + 6.4516229290855e+145*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl93_m_minus_75(theta, phi):
    return 2.74649109223644e-143*(1.0 - cos(theta)**2)**37.5*(1.04543346436317e+155*cos(theta)**18 - 8.64601729986841e+154*cos(theta)**16 + 2.83475977044866e+154*cos(theta)**14 - 4.75070237773164e+153*cos(theta)**12 + 4.37913906327218e+152*cos(theta)**10 - 2.22668087962992e+151*cos(theta)**8 + 5.93781567901313e+149*cos(theta)**6 - 7.35485013915747e+147*cos(theta)**4 + 3.22581146454275e+145*cos(theta)**2 - 2.12084908911423e+142)*sin(75*phi)

#@torch.jit.script
def Yl93_m_minus_74(theta, phi):
    return 1.55170670284662e-141*(1.0 - cos(theta)**2)**37*(5.50228139138513e+153*cos(theta)**19 - 5.08589252933436e+153*cos(theta)**17 + 1.88983984696577e+153*cos(theta)**15 - 3.65438644440895e+152*cos(theta)**13 + 3.98103551206562e+151*cos(theta)**11 - 2.47408986625547e+150*cos(theta)**9 + 8.48259382716161e+148*cos(theta)**7 - 1.47097002783149e+147*cos(theta)**5 + 1.07527048818092e+145*cos(theta)**3 - 2.12084908911423e+142*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl93_m_minus_73(theta, phi):
    return 8.96773713382673e-140*(1.0 - cos(theta)**2)**36.5*(2.75114069569256e+152*cos(theta)**20 - 2.8254958496302e+152*cos(theta)**18 + 1.18114990435361e+152*cos(theta)**16 - 2.61027603172068e+151*cos(theta)**14 + 3.31752959338802e+150*cos(theta)**12 - 2.47408986625547e+149*cos(theta)**10 + 1.0603242283952e+148*cos(theta)**8 - 2.45161671305249e+146*cos(theta)**6 + 2.68817622045229e+144*cos(theta)**4 - 1.06042454455712e+142*cos(theta)**2 + 6.3498475721983e+138)*sin(73*phi)

#@torch.jit.script
def Yl93_m_minus_72(theta, phi):
    return 5.29476343404247e-138*(1.0 - cos(theta)**2)**36*(1.31006699794884e+151*cos(theta)**21 - 1.48710307875274e+151*cos(theta)**19 + 6.94794061384475e+150*cos(theta)**17 - 1.74018402114712e+150*cos(theta)**15 + 2.5519458410677e+149*cos(theta)**13 - 2.24917260568679e+148*cos(theta)**11 + 1.17813803155022e+147*cos(theta)**9 - 3.50230959007498e+145*cos(theta)**7 + 5.37635244090458e+143*cos(theta)**5 - 3.53474848185705e+141*cos(theta)**3 + 6.3498475721983e+138*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl93_m_minus_71(theta, phi):
    return 3.19006750642644e-136*(1.0 - cos(theta)**2)**35.5*(5.95484999067654e+149*cos(theta)**22 - 7.43551539376368e+149*cos(theta)**20 + 3.85996700769153e+149*cos(theta)**18 - 1.08761501321695e+149*cos(theta)**16 + 1.8228184579055e+148*cos(theta)**14 - 1.87431050473899e+147*cos(theta)**12 + 1.17813803155022e+146*cos(theta)**10 - 4.37788698759373e+144*cos(theta)**8 + 8.96058740150763e+142*cos(theta)**6 - 8.83687120464264e+140*cos(theta)**4 + 3.17492378609915e+138*cos(theta)**2 - 1.7492693036359e+135)*sin(71*phi)

#@torch.jit.script
def Yl93_m_minus_70(theta, phi):
    return 1.95923132334199e-134*(1.0 - cos(theta)**2)**35*(2.58906521333763e+148*cos(theta)**23 - 3.54072161607794e+148*cos(theta)**21 + 2.03156158299554e+148*cos(theta)**19 - 6.39773537186441e+147*cos(theta)**17 + 1.21521230527034e+147*cos(theta)**15 - 1.44177731133769e+146*cos(theta)**13 + 1.07103457413657e+145*cos(theta)**11 - 4.86431887510414e+143*cos(theta)**9 + 1.28008391450109e+142*cos(theta)**7 - 1.76737424092853e+140*cos(theta)**5 + 1.05830792869972e+138*cos(theta)**3 - 1.7492693036359e+135*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl93_m_minus_69(theta, phi):
    return 1.22542049208268e-132*(1.0 - cos(theta)**2)**34.5*(1.07877717222401e+147*cos(theta)**24 - 1.60941891639907e+147*cos(theta)**22 + 1.01578079149777e+147*cos(theta)**20 - 3.55429742881356e+146*cos(theta)**18 + 7.5950769079396e+145*cos(theta)**16 - 1.02984093666978e+145*cos(theta)**14 + 8.92528811780473e+143*cos(theta)**12 - 4.86431887510414e+142*cos(theta)**10 + 1.60010489312636e+141*cos(theta)**8 - 2.94562373488088e+139*cos(theta)**6 + 2.64576982174929e+137*cos(theta)**4 - 8.74634651817948e+134*cos(theta)**2 + 4.47154729968276e+131)*sin(69*phi)

#@torch.jit.script
def Yl93_m_minus_68(theta, phi):
    return 7.79852825780955e-131*(1.0 - cos(theta)**2)**34*(4.31510868889605e+145*cos(theta)**25 - 6.99747354956116e+145*cos(theta)**23 + 4.83705138808462e+145*cos(theta)**21 - 1.8706828572703e+145*cos(theta)**19 + 4.467692298788e+144*cos(theta)**17 - 6.86560624446517e+143*cos(theta)**15 + 6.86560624446517e+142*cos(theta)**13 - 4.42210806827649e+141*cos(theta)**11 + 1.77789432569596e+140*cos(theta)**9 - 4.20803390697268e+138*cos(theta)**7 + 5.29153964349858e+136*cos(theta)**5 - 2.91544883939316e+134*cos(theta)**3 + 4.47154729968276e+131*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl93_m_minus_67(theta, phi):
    return 5.04559354236107e-129*(1.0 - cos(theta)**2)**33.5*(1.65965718803694e+144*cos(theta)**26 - 2.91561397898381e+144*cos(theta)**24 + 2.19865972185665e+144*cos(theta)**22 - 9.35341428635148e+143*cos(theta)**20 + 2.48205127710444e+143*cos(theta)**18 - 4.29100390279073e+142*cos(theta)**16 + 4.90400446033227e+141*cos(theta)**14 - 3.68509005689708e+140*cos(theta)**12 + 1.77789432569596e+139*cos(theta)**10 - 5.26004238371585e+137*cos(theta)**8 + 8.81923273916431e+135*cos(theta)**6 - 7.2886220984829e+133*cos(theta)**4 + 2.23577364984138e+131*cos(theta)**2 - 1.06821483508905e+128)*sin(67*phi)

#@torch.jit.script
def Yl93_m_minus_66(theta, phi):
    return 3.31630247898427e-127*(1.0 - cos(theta)**2)**33*(6.14687847421089e+142*cos(theta)**27 - 1.16624559159353e+143*cos(theta)**25 + 9.5593900950289e+142*cos(theta)**23 - 4.45400680302452e+142*cos(theta)**21 + 1.30634277742339e+142*cos(theta)**19 - 2.52411994281808e+141*cos(theta)**17 + 3.26933630688818e+140*cos(theta)**15 - 2.8346846591516e+139*cos(theta)**13 + 1.61626756881451e+138*cos(theta)**11 - 5.84449153746206e+136*cos(theta)**9 + 1.25989039130919e+135*cos(theta)**7 - 1.45772441969658e+133*cos(theta)**5 + 7.4525788328046e+130*cos(theta)**3 - 1.06821483508905e+128*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl93_m_minus_65(theta, phi):
    return 2.21274675939624e-125*(1.0 - cos(theta)**2)**32.5*(2.1953137407896e+141*cos(theta)**28 - 4.48555996766741e+141*cos(theta)**26 + 3.98307920626204e+141*cos(theta)**24 - 2.02454854682933e+141*cos(theta)**22 + 6.53171388711696e+140*cos(theta)**20 - 1.40228885712115e+140*cos(theta)**18 + 2.04333519180511e+139*cos(theta)**16 - 2.02477475653686e+138*cos(theta)**14 + 1.34688964067876e+137*cos(theta)**12 - 5.84449153746206e+135*cos(theta)**10 + 1.57486298913648e+134*cos(theta)**8 - 2.4295406994943e+132*cos(theta)**6 + 1.86314470820115e+130*cos(theta)**4 - 5.34107417544525e+127*cos(theta)**2 + 2.39940439148484e+124)*sin(65*phi)

#@torch.jit.script
def Yl93_m_minus_64(theta, phi):
    return 1.49781872566821e-123*(1.0 - cos(theta)**2)**32*(7.57004738203312e+139*cos(theta)**29 - 1.66131850654348e+140*cos(theta)**27 + 1.59323168250482e+140*cos(theta)**25 - 8.80238498621446e+139*cos(theta)**23 + 3.11033994624617e+139*cos(theta)**21 - 7.38046766905871e+138*cos(theta)**19 + 1.20196187753242e+138*cos(theta)**17 - 1.34984983769124e+137*cos(theta)**15 + 1.03606895436827e+136*cos(theta)**13 - 5.31317412496551e+134*cos(theta)**11 + 1.7498477657072e+133*cos(theta)**9 - 3.470772427849e+131*cos(theta)**7 + 3.7262894164023e+129*cos(theta)**5 - 1.78035805848175e+127*cos(theta)**3 + 2.39940439148484e+124*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl93_m_minus_63(theta, phi):
    return 1.02794459985316e-121*(1.0 - cos(theta)**2)**31.5*(2.52334912734437e+138*cos(theta)**30 - 5.93328038051244e+138*cos(theta)**28 + 6.12781416348007e+138*cos(theta)**26 - 3.66766041092269e+138*cos(theta)**24 + 1.41379088465735e+138*cos(theta)**22 - 3.69023383452935e+137*cos(theta)**20 + 6.67756598629121e+136*cos(theta)**18 - 8.43656148557024e+135*cos(theta)**16 + 7.40049253120196e+134*cos(theta)**14 - 4.42764510413793e+133*cos(theta)**12 + 1.7498477657072e+132*cos(theta)**10 - 4.33846553481125e+130*cos(theta)**8 + 6.2104823606705e+128*cos(theta)**6 - 4.45089514620437e+126*cos(theta)**4 + 1.19970219574242e+124*cos(theta)**2 - 5.09427683967057e+120)*sin(63*phi)

#@torch.jit.script
def Yl93_m_minus_62(theta, phi):
    return 7.14846599304781e-120*(1.0 - cos(theta)**2)**31*(8.13983589465927e+136*cos(theta)**31 - 2.04595875190084e+137*cos(theta)**29 + 2.26956080128891e+137*cos(theta)**27 - 1.46706416436908e+137*cos(theta)**25 + 6.14691688981457e+136*cos(theta)**23 - 1.75725420691874e+136*cos(theta)**21 + 3.51450841383748e+135*cos(theta)**19 - 4.96268322680602e+134*cos(theta)**17 + 4.93366168746797e+133*cos(theta)**15 - 3.40588084933687e+132*cos(theta)**13 + 1.59077069609746e+131*cos(theta)**11 - 4.82051726090139e+129*cos(theta)**9 + 8.87211765810071e+127*cos(theta)**7 - 8.90179029240874e+125*cos(theta)**5 + 3.99900731914139e+123*cos(theta)**3 - 5.09427683967057e+120*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl93_m_minus_61(theta, phi):
    return 5.03446926325561e-118*(1.0 - cos(theta)**2)**30.5*(2.54369871708102e+135*cos(theta)**32 - 6.81986250633614e+135*cos(theta)**30 + 8.10557429031755e+135*cos(theta)**28 - 5.6425544783426e+135*cos(theta)**26 + 2.56121537075607e+135*cos(theta)**24 - 7.98751912235791e+134*cos(theta)**22 + 1.75725420691874e+134*cos(theta)**20 - 2.75704623711446e+133*cos(theta)**18 + 3.08353855466748e+132*cos(theta)**16 - 2.43277203524062e+131*cos(theta)**14 + 1.32564224674788e+130*cos(theta)**12 - 4.82051726090139e+128*cos(theta)**10 + 1.10901470726259e+127*cos(theta)**8 - 1.48363171540146e+125*cos(theta)**6 + 9.99751829785349e+122*cos(theta)**4 - 2.54713841983528e+120*cos(theta)**2 + 1.02707194348197e+117)*sin(61*phi)

#@torch.jit.script
def Yl93_m_minus_60(theta, phi):
    return 3.58897988341905e-116*(1.0 - cos(theta)**2)**30*(7.70817793054855e+133*cos(theta)**33 - 2.19995564720521e+134*cos(theta)**31 + 2.79502561735088e+134*cos(theta)**29 - 2.08983499197874e+134*cos(theta)**27 + 1.02448614830243e+134*cos(theta)**25 - 3.47283440102518e+133*cos(theta)**23 + 8.36787717580352e+132*cos(theta)**21 - 1.45107696690235e+132*cos(theta)**19 + 1.81384620862793e+131*cos(theta)**17 - 1.62184802349375e+130*cos(theta)**15 + 1.01972480519068e+129*cos(theta)**13 - 4.38228841900126e+127*cos(theta)**11 + 1.2322385636251e+126*cos(theta)**9 - 2.11947387914494e+124*cos(theta)**7 + 1.9995036595707e+122*cos(theta)**5 - 8.49046139945094e+119*cos(theta)**3 + 1.02707194348197e+117*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl93_m_minus_59(theta, phi):
    return 2.58854785336987e-114*(1.0 - cos(theta)**2)**29.5*(2.26711115604369e+132*cos(theta)**34 - 6.87486139751627e+132*cos(theta)**32 + 9.31675205783626e+132*cos(theta)**30 - 7.46369639992408e+132*cos(theta)**28 + 3.94033133962472e+132*cos(theta)**26 - 1.44701433376049e+132*cos(theta)**24 + 3.80358053445615e+131*cos(theta)**22 - 7.25538483451173e+130*cos(theta)**20 + 1.00769233812663e+130*cos(theta)**18 - 1.01365501468359e+129*cos(theta)**16 + 7.28374860850484e+127*cos(theta)**14 - 3.65190701583439e+126*cos(theta)**12 + 1.2322385636251e+125*cos(theta)**10 - 2.64934234893117e+123*cos(theta)**8 + 3.3325060992845e+121*cos(theta)**6 - 2.12261534986274e+119*cos(theta)**4 + 5.13535971740985e+116*cos(theta)**2 - 1.97437897632059e+113)*sin(59*phi)

#@torch.jit.script
def Yl93_m_minus_58(theta, phi):
    return 1.88804357848192e-112*(1.0 - cos(theta)**2)**29*(6.47746044583912e+130*cos(theta)**35 - 2.08329133258069e+131*cos(theta)**33 + 3.0054038896246e+131*cos(theta)**31 - 2.57368841376692e+131*cos(theta)**29 + 1.45938197763879e+131*cos(theta)**27 - 5.78805733504196e+130*cos(theta)**25 + 1.65373066715485e+130*cos(theta)**23 - 3.4549451592913e+129*cos(theta)**21 + 5.30364388487699e+128*cos(theta)**19 - 5.9626765569623e+127*cos(theta)**17 + 4.8558324056699e+126*cos(theta)**15 - 2.80915924294953e+125*cos(theta)**13 + 1.12021687602282e+124*cos(theta)**11 - 2.94371372103464e+122*cos(theta)**9 + 4.76072299897785e+120*cos(theta)**7 - 4.24523069972547e+118*cos(theta)**5 + 1.71178657246995e+116*cos(theta)**3 - 1.97437897632059e+113*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl93_m_minus_57(theta, phi):
    return 1.39204007488598e-110*(1.0 - cos(theta)**2)**28.5*(1.79929456828864e+129*cos(theta)**36 - 6.12732744876673e+129*cos(theta)**34 + 9.39188715507688e+129*cos(theta)**32 - 8.57896137922307e+129*cos(theta)**30 + 5.21207849156709e+129*cos(theta)**28 - 2.22617589809306e+129*cos(theta)**26 + 6.89054444647853e+128*cos(theta)**24 - 1.57042961785968e+128*cos(theta)**22 + 2.6518219424385e+127*cos(theta)**20 - 3.31259808720128e+126*cos(theta)**18 + 3.03489525354369e+125*cos(theta)**16 - 2.00654231639252e+124*cos(theta)**14 + 9.33514063352348e+122*cos(theta)**12 - 2.94371372103464e+121*cos(theta)**10 + 5.95090374872231e+119*cos(theta)**8 - 7.07538449954245e+117*cos(theta)**6 + 4.27946643117487e+115*cos(theta)**4 - 9.87189488160293e+112*cos(theta)**2 + 3.63204373863243e+109)*sin(57*phi)

#@torch.jit.script
def Yl93_m_minus_56(theta, phi):
    return 1.03704649914995e-108*(1.0 - cos(theta)**2)**28*(4.86295829267201e+127*cos(theta)**37 - 1.75066498536192e+128*cos(theta)**35 + 2.84602641062936e+128*cos(theta)**33 - 2.76740689652357e+128*cos(theta)**31 + 1.79726844536796e+128*cos(theta)**29 - 8.2450959188632e+127*cos(theta)**27 + 2.75621777859141e+127*cos(theta)**25 - 6.82795486025948e+126*cos(theta)**23 + 1.26277235354214e+126*cos(theta)**21 - 1.74347267747436e+125*cos(theta)**19 + 1.78523250208452e+124*cos(theta)**17 - 1.33769487759501e+123*cos(theta)**15 + 7.18087741040268e+121*cos(theta)**13 - 2.67610338275876e+120*cos(theta)**11 + 6.61211527635813e+118*cos(theta)**9 - 1.01076921422035e+117*cos(theta)**7 + 8.55893286234974e+114*cos(theta)**5 - 3.29063162720098e+112*cos(theta)**3 + 3.63204373863243e+109*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl93_m_minus_55(theta, phi):
    return 7.8033872960414e-107*(1.0 - cos(theta)**2)**27.5*(1.27972586649263e+126*cos(theta)**38 - 4.86295829267201e+126*cos(theta)**36 + 8.37066591361575e+126*cos(theta)**34 - 8.64814655163617e+126*cos(theta)**32 + 5.99089481789321e+126*cos(theta)**30 - 2.94467711387971e+126*cos(theta)**28 + 1.0600837609967e+126*cos(theta)**26 - 2.84498119177478e+125*cos(theta)**24 + 5.73987433428246e+124*cos(theta)**22 - 8.71736338737178e+123*cos(theta)**20 + 9.917958344914e+122*cos(theta)**18 - 8.36059298496883e+121*cos(theta)**16 + 5.12919815028763e+120*cos(theta)**14 - 2.23008615229897e+119*cos(theta)**12 + 6.61211527635813e+117*cos(theta)**10 - 1.26346151777544e+116*cos(theta)**8 + 1.42648881039162e+114*cos(theta)**6 - 8.22657906800244e+111*cos(theta)**4 + 1.81602186931621e+109*cos(theta)**2 - 6.41477170369556e+105)*sin(55*phi)

#@torch.jit.script
def Yl93_m_minus_54(theta, phi):
    return 5.92852046636883e-105*(1.0 - cos(theta)**2)**27*(3.28134837562214e+124*cos(theta)**39 - 1.31431305207352e+125*cos(theta)**37 + 2.39161883246164e+125*cos(theta)**35 - 2.62065047019278e+125*cos(theta)**33 + 1.93254671544942e+125*cos(theta)**31 - 1.01540590133783e+125*cos(theta)**29 + 3.92623615183962e+124*cos(theta)**27 - 1.13799247670991e+124*cos(theta)**25 + 2.49559753664455e+123*cos(theta)**23 - 4.15112542255799e+122*cos(theta)**21 + 5.21997807627053e+121*cos(theta)**19 - 4.91799587351108e+120*cos(theta)**17 + 3.41946543352508e+119*cos(theta)**15 - 1.71545088638382e+118*cos(theta)**13 + 6.0110138875983e+116*cos(theta)**11 - 1.4038461308616e+115*cos(theta)**9 + 2.03784115770232e+113*cos(theta)**7 - 1.64531581360049e+111*cos(theta)**5 + 6.05340623105404e+108*cos(theta)**3 - 6.41477170369556e+105*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl93_m_minus_53(theta, phi):
    return 4.54605814888576e-103*(1.0 - cos(theta)**2)**26.5*(8.20337093905535e+122*cos(theta)**40 - 3.4587185580882e+123*cos(theta)**38 + 6.64338564572679e+123*cos(theta)**36 - 7.70779550056699e+123*cos(theta)**34 + 6.03920848577944e+123*cos(theta)**32 - 3.38468633779277e+123*cos(theta)**30 + 1.40222719708558e+123*cos(theta)**28 - 4.37689414119198e+122*cos(theta)**26 + 1.03983230693523e+122*cos(theta)**24 - 1.88687519207181e+121*cos(theta)**22 + 2.60998903813526e+120*cos(theta)**20 - 2.73221992972838e+119*cos(theta)**18 + 2.13716589595318e+118*cos(theta)**16 - 1.22532206170273e+117*cos(theta)**14 + 5.00917823966525e+115*cos(theta)**12 - 1.4038461308616e+114*cos(theta)**10 + 2.5473014471279e+112*cos(theta)**8 - 2.74219302266748e+110*cos(theta)**6 + 1.51335155776351e+108*cos(theta)**4 - 3.20738585184778e+105*cos(theta)**2 + 1.09094756865571e+102)*sin(53*phi)

#@torch.jit.script
def Yl93_m_minus_52(theta, phi):
    return 3.51725084593921e-101*(1.0 - cos(theta)**2)**26*(2.0008221802574e+121*cos(theta)**41 - 8.86850912330308e+121*cos(theta)**39 + 1.79550963398021e+122*cos(theta)**37 - 2.20222728587628e+122*cos(theta)**35 + 1.83006317750892e+122*cos(theta)**33 - 1.0918343025138e+122*cos(theta)**31 + 4.83526619684682e+121*cos(theta)**29 - 1.62107190414518e+121*cos(theta)**27 + 4.15932922774091e+120*cos(theta)**25 - 8.20380518292093e+119*cos(theta)**23 + 1.24285192292155e+119*cos(theta)**21 - 1.43801048933072e+118*cos(theta)**19 + 1.25715640938422e+117*cos(theta)**17 - 8.16881374468486e+115*cos(theta)**15 + 3.85321403051173e+114*cos(theta)**13 - 1.27622375532873e+113*cos(theta)**11 + 2.83033494125322e+111*cos(theta)**9 - 3.91741860381069e+109*cos(theta)**7 + 3.02670311552702e+107*cos(theta)**5 - 1.06912861728259e+105*cos(theta)**3 + 1.09094756865571e+102*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl93_m_minus_51(theta, phi):
    return 2.74480811525604e-99*(1.0 - cos(theta)**2)**25.5*(4.76386233394619e+119*cos(theta)**42 - 2.21712728082577e+120*cos(theta)**40 + 4.72502535257951e+120*cos(theta)**38 - 6.11729801632301e+120*cos(theta)**36 + 5.38253875737918e+120*cos(theta)**34 - 3.41198219535562e+120*cos(theta)**32 + 1.61175539894894e+120*cos(theta)**30 - 5.7895425148042e+119*cos(theta)**28 + 1.59974201066958e+119*cos(theta)**26 - 3.41825215955039e+118*cos(theta)**24 + 5.6493269223707e+117*cos(theta)**22 - 7.19005244665362e+116*cos(theta)**20 + 6.98420227435679e+115*cos(theta)**18 - 5.10550859042804e+114*cos(theta)**16 + 2.75229573607981e+113*cos(theta)**14 - 1.06351979610727e+112*cos(theta)**12 + 2.83033494125322e+110*cos(theta)**10 - 4.89677325476336e+108*cos(theta)**8 + 5.04450519254503e+106*cos(theta)**6 - 2.67282154320648e+104*cos(theta)**4 + 5.45473784327854e+101*cos(theta)**2 - 1.79137531798967e+98)*sin(51*phi)

#@torch.jit.script
def Yl93_m_minus_50(theta, phi):
    return 2.1598692572156e-97*(1.0 - cos(theta)**2)**25*(1.10787496138284e+118*cos(theta)**43 - 5.40762751420919e+118*cos(theta)**41 + 1.21154496219987e+119*cos(theta)**39 - 1.65332378819541e+119*cos(theta)**37 + 1.53786821639405e+119*cos(theta)**35 - 1.03393399859261e+119*cos(theta)**33 + 5.19921096435142e+118*cos(theta)**31 - 1.99639397062214e+118*cos(theta)**29 + 5.92497040988734e+117*cos(theta)**27 - 1.36730086382016e+117*cos(theta)**25 + 2.45622909668291e+116*cos(theta)**23 - 3.42383449840649e+115*cos(theta)**21 + 3.67589593387199e+114*cos(theta)**19 - 3.00324034731061e+113*cos(theta)**17 + 1.8348638240532e+112*cos(theta)**15 - 8.18092150851747e+110*cos(theta)**13 + 2.57303176477566e+109*cos(theta)**11 - 5.44085917195929e+107*cos(theta)**9 + 7.20643598935005e+105*cos(theta)**7 - 5.34564308641297e+103*cos(theta)**5 + 1.81824594775951e+101*cos(theta)**3 - 1.79137531798967e+98*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl93_m_minus_49(theta, phi):
    return 1.71325425814162e-95*(1.0 - cos(theta)**2)**24.5*(2.51789763950644e+116*cos(theta)**44 - 1.287530360526e+117*cos(theta)**42 + 3.02886240549968e+117*cos(theta)**40 - 4.35085207419844e+117*cos(theta)**38 + 4.27185615665015e+117*cos(theta)**36 - 3.0409823488018e+117*cos(theta)**34 + 1.62475342635982e+117*cos(theta)**32 - 6.65464656874046e+116*cos(theta)**30 + 2.11606086067405e+116*cos(theta)**28 - 5.25884947623137e+115*cos(theta)**26 + 1.02342879028455e+115*cos(theta)**24 - 1.55628840836658e+114*cos(theta)**22 + 1.837947966936e+113*cos(theta)**20 - 1.66846685961701e+112*cos(theta)**18 + 1.14678989003325e+111*cos(theta)**16 - 5.84351536322676e+109*cos(theta)**14 + 2.14419313731305e+108*cos(theta)**12 - 5.44085917195929e+106*cos(theta)**10 + 9.00804498668756e+104*cos(theta)**8 - 8.90940514402161e+102*cos(theta)**6 + 4.54561486939878e+100*cos(theta)**4 - 8.95687658994834e+97*cos(theta)**2 + 2.84706821040952e+94)*sin(49*phi)

#@torch.jit.script
def Yl93_m_minus_48(theta, phi):
    return 1.3695322039999e-93*(1.0 - cos(theta)**2)**24*(5.5953280877921e+114*cos(theta)**45 - 2.99425665238604e+115*cos(theta)**43 + 7.38746928170655e+115*cos(theta)**41 - 1.11560309594832e+116*cos(theta)**39 + 1.15455571801355e+116*cos(theta)**37 - 8.68852099657657e+115*cos(theta)**35 + 4.92349523139339e+115*cos(theta)**33 - 2.14666018346466e+115*cos(theta)**31 + 7.29676158853121e+114*cos(theta)**29 - 1.94772202823384e+114*cos(theta)**27 + 4.09371516113819e+113*cos(theta)**25 - 6.76647134072428e+112*cos(theta)**23 + 8.7521331758857e+111*cos(theta)**21 - 8.78140452430003e+110*cos(theta)**19 + 6.74582288254854e+109*cos(theta)**17 - 3.89567690881784e+108*cos(theta)**15 + 1.64937933639465e+107*cos(theta)**13 - 4.94623561087208e+105*cos(theta)**11 + 1.00089388740973e+104*cos(theta)**9 - 1.27277216343166e+102*cos(theta)**7 + 9.09122973879756e+99*cos(theta)**5 - 2.98562552998278e+97*cos(theta)**3 + 2.84706821040952e+94*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl93_m_minus_47(theta, phi):
    return 1.10296243441217e-91*(1.0 - cos(theta)**2)**23.5*(1.21637567125915e+113*cos(theta)**46 - 6.80512875542282e+113*cos(theta)**44 + 1.75892125754918e+114*cos(theta)**42 - 2.7890077398708e+114*cos(theta)**40 + 3.0383045210883e+114*cos(theta)**38 - 2.4134780546046e+114*cos(theta)**36 + 1.44808683276276e+114*cos(theta)**34 - 6.70831307332708e+113*cos(theta)**32 + 2.43225386284374e+113*cos(theta)**30 - 6.95615010083514e+112*cos(theta)**28 + 1.574505831207e+112*cos(theta)**26 - 2.81936305863512e+111*cos(theta)**24 + 3.97824235267532e+110*cos(theta)**22 - 4.39070226215002e+109*cos(theta)**20 + 3.74767937919364e+108*cos(theta)**18 - 2.43479806801115e+107*cos(theta)**16 + 1.17812809742475e+106*cos(theta)**14 - 4.12186300906007e+104*cos(theta)**12 + 1.00089388740973e+103*cos(theta)**10 - 1.59096520428957e+101*cos(theta)**8 + 1.51520495646626e+99*cos(theta)**6 - 7.46406382495695e+96*cos(theta)**4 + 1.42353410520476e+94*cos(theta)**2 - 4.38955937466777e+90)*sin(47*phi)

#@torch.jit.script
def Yl93_m_minus_46(theta, phi):
    return 8.94692234611806e-90*(1.0 - cos(theta)**2)**23*(2.58803334310458e+111*cos(theta)**47 - 1.51225083453841e+112*cos(theta)**45 + 4.09051455243995e+112*cos(theta)**43 - 6.80245790212389e+112*cos(theta)**41 + 7.79052441304692e+112*cos(theta)**39 - 6.52291366109352e+112*cos(theta)**37 + 4.13739095075075e+112*cos(theta)**35 - 2.03282214343245e+112*cos(theta)**33 + 7.84598020272173e+111*cos(theta)**31 - 2.39867244856384e+111*cos(theta)**29 + 5.83150307854443e+110*cos(theta)**27 - 1.12774522345405e+110*cos(theta)**25 + 1.7296705881197e+109*cos(theta)**23 - 2.09081060102382e+108*cos(theta)**21 + 1.97246283115455e+107*cos(theta)**19 - 1.43223415765362e+106*cos(theta)**17 + 7.85418731616501e+104*cos(theta)**15 - 3.17066385312313e+103*cos(theta)**13 + 9.09903534008845e+101*cos(theta)**11 - 1.7677391158773e+100*cos(theta)**9 + 2.16457850923751e+98*cos(theta)**7 - 1.49281276499139e+96*cos(theta)**5 + 4.74511368401586e+93*cos(theta)**3 - 4.38955937466777e+90*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl93_m_minus_45(theta, phi):
    return 7.30805297385656e-88*(1.0 - cos(theta)**2)**22.5*(5.39173613146787e+109*cos(theta)**48 - 3.28750181421392e+110*cos(theta)**46 + 9.29662398281806e+110*cos(theta)**44 - 1.61963283383902e+111*cos(theta)**42 + 1.94763110326173e+111*cos(theta)**40 - 1.71655622660356e+111*cos(theta)**38 + 1.14927526409743e+111*cos(theta)**36 - 5.97888865715426e+110*cos(theta)**34 + 2.45186881335054e+110*cos(theta)**32 - 7.99557482854614e+109*cos(theta)**30 + 2.08267967090873e+109*cos(theta)**28 - 4.33748162866941e+108*cos(theta)**26 + 7.2069607838321e+107*cos(theta)**24 - 9.50368455010826e+106*cos(theta)**22 + 9.86231415577273e+105*cos(theta)**20 - 7.95685643140899e+104*cos(theta)**18 + 4.90886707260313e+103*cos(theta)**16 - 2.26475989508795e+102*cos(theta)**14 + 7.58252945007371e+100*cos(theta)**12 - 1.7677391158773e+99*cos(theta)**10 + 2.70572313654689e+97*cos(theta)**8 - 2.48802127498565e+95*cos(theta)**6 + 1.18627842100396e+93*cos(theta)**4 - 2.19477968733388e+90*cos(theta)**2 + 6.57907580136057e+86)*sin(45*phi)

#@torch.jit.script
def Yl93_m_minus_44(theta, phi):
    return 6.009512875208e-86*(1.0 - cos(theta)**2)**22*(1.10035431254446e+108*cos(theta)**49 - 6.99468471109346e+108*cos(theta)**47 + 2.06591644062624e+109*cos(theta)**45 - 3.76658798567214e+109*cos(theta)**43 + 4.750319764053e+109*cos(theta)**41 - 4.4014262220604e+109*cos(theta)**39 + 3.10614936242549e+109*cos(theta)**37 - 1.70825390204407e+109*cos(theta)**35 + 7.42990549500164e+108*cos(theta)**33 - 2.57921768662779e+108*cos(theta)**31 + 7.18165403761629e+107*cos(theta)**29 - 1.60647467728497e+107*cos(theta)**27 + 2.88278431353284e+106*cos(theta)**25 - 4.13203676091664e+105*cos(theta)**23 + 4.69634007417749e+104*cos(theta)**21 - 4.18781917442579e+103*cos(theta)**19 + 2.88756886623713e+102*cos(theta)**17 - 1.50983993005863e+101*cos(theta)**15 + 5.83271496159516e+99*cos(theta)**13 - 1.60703555988846e+98*cos(theta)**11 + 3.00635904060766e+96*cos(theta)**9 - 3.55431610712236e+94*cos(theta)**7 + 2.37255684200793e+92*cos(theta)**5 - 7.31593229111295e+89*cos(theta)**3 + 6.57907580136057e+86*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl93_m_minus_43(theta, phi):
    return 4.97375691234947e-84*(1.0 - cos(theta)**2)**21.5*(2.20070862508893e+106*cos(theta)**50 - 1.4572259814778e+107*cos(theta)**48 + 4.49112269701356e+107*cos(theta)**46 - 8.56042724016396e+107*cos(theta)**44 + 1.13102851525071e+108*cos(theta)**42 - 1.1003565555151e+108*cos(theta)**40 + 8.17407726954075e+107*cos(theta)**38 - 4.74514972790021e+107*cos(theta)**36 + 2.1852663220593e+107*cos(theta)**34 - 8.06005527071184e+106*cos(theta)**32 + 2.39388467920543e+106*cos(theta)**30 - 5.73740956173203e+105*cos(theta)**28 + 1.10876319751263e+105*cos(theta)**26 - 1.72168198371527e+104*cos(theta)**24 + 2.13470003371704e+103*cos(theta)**22 - 2.09390958721289e+102*cos(theta)**20 + 1.6042049256873e+101*cos(theta)**18 - 9.43649956286645e+99*cos(theta)**16 + 4.16622497256797e+98*cos(theta)**14 - 1.33919629990705e+97*cos(theta)**12 + 3.00635904060766e+95*cos(theta)**10 - 4.44289513390294e+93*cos(theta)**8 + 3.95426140334655e+91*cos(theta)**6 - 1.82898307277824e+89*cos(theta)**4 + 3.28953790068028e+86*cos(theta)**2 - 9.60449022096433e+82)*sin(43*phi)

#@torch.jit.script
def Yl93_m_minus_42(theta, phi):
    return 4.14227662356497e-82*(1.0 - cos(theta)**2)**21*(4.31511495115476e+104*cos(theta)**51 - 2.9739305744445e+105*cos(theta)**49 + 9.55558020641183e+105*cos(theta)**47 - 1.90231716448088e+106*cos(theta)**45 + 2.63029887267608e+106*cos(theta)**43 - 2.6837964768661e+106*cos(theta)**41 + 2.09591724860019e+106*cos(theta)**39 - 1.28247289943249e+106*cos(theta)**37 + 6.24361806302659e+105*cos(theta)**35 - 2.4424409911248e+105*cos(theta)**33 + 7.72220864259817e+104*cos(theta)**31 - 1.97841709025242e+104*cos(theta)**29 + 4.10653036115789e+103*cos(theta)**27 - 6.88672793486106e+102*cos(theta)**25 + 9.28130449442191e+101*cos(theta)**23 - 9.97099803434711e+100*cos(theta)**21 + 8.44318381940683e+99*cos(theta)**19 - 5.5508820958038e+98*cos(theta)**17 + 2.77748331504531e+97*cos(theta)**15 - 1.0301509999285e+96*cos(theta)**13 + 2.73305367327969e+94*cos(theta)**11 - 4.93655014878105e+92*cos(theta)**9 + 5.64894486192364e+90*cos(theta)**7 - 3.65796614555647e+88*cos(theta)**5 + 1.09651263356009e+86*cos(theta)**3 - 9.60449022096433e+82*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl93_m_minus_41(theta, phi):
    return 3.47062470594923e-80*(1.0 - cos(theta)**2)**20.5*(8.29829798298992e+102*cos(theta)**52 - 5.94786114888899e+103*cos(theta)**50 + 1.9907458763358e+104*cos(theta)**48 - 4.13547209669757e+104*cos(theta)**46 + 5.97795198335472e+104*cos(theta)**44 - 6.38999161158595e+104*cos(theta)**42 + 5.23979312150048e+104*cos(theta)**40 - 3.37492868271707e+104*cos(theta)**38 + 1.73433835084072e+104*cos(theta)**36 - 7.18364997389647e+103*cos(theta)**34 + 2.41319020081193e+103*cos(theta)**32 - 6.59472363417474e+102*cos(theta)**30 + 1.46661798612782e+102*cos(theta)**28 - 2.6487415134081e+101*cos(theta)**26 + 3.86721020600913e+100*cos(theta)**24 - 4.53227183379414e+99*cos(theta)**22 + 4.22159190970341e+98*cos(theta)**20 - 3.08382338655766e+97*cos(theta)**18 + 1.73592707190332e+96*cos(theta)**16 - 7.3582214280607e+94*cos(theta)**14 + 2.27754472773307e+93*cos(theta)**12 - 4.93655014878105e+91*cos(theta)**10 + 7.06118107740455e+89*cos(theta)**8 - 6.09661024259412e+87*cos(theta)**6 + 2.74128158390024e+85*cos(theta)**4 - 4.80224511048216e+82*cos(theta)**2 + 1.36816100013737e+79)*sin(41*phi)

#@torch.jit.script
def Yl93_m_minus_40(theta, phi):
    return 2.92481221625372e-78*(1.0 - cos(theta)**2)**20*(1.56571660056414e+101*cos(theta)**53 - 1.16624728409588e+102*cos(theta)**51 + 4.06274668639959e+102*cos(theta)**49 - 8.79887680148419e+102*cos(theta)**47 + 1.32843377407883e+103*cos(theta)**45 - 1.48604456083394e+103*cos(theta)**43 + 1.27799832231719e+103*cos(theta)**41 - 8.65366328901814e+102*cos(theta)**39 + 4.68740094821816e+102*cos(theta)**37 - 2.05247142111328e+102*cos(theta)**35 + 7.31269757821796e+101*cos(theta)**33 - 2.1273302045725e+101*cos(theta)**31 + 5.05730340044075e+100*cos(theta)**29 - 9.81015375336333e+99*cos(theta)**27 + 1.54688408240365e+99*cos(theta)**25 - 1.97055297121484e+98*cos(theta)**23 + 2.01028186176353e+97*cos(theta)**21 - 1.62306494029351e+96*cos(theta)**19 + 1.02113357170784e+95*cos(theta)**17 - 4.90548095204047e+93*cos(theta)**15 + 1.7519574828716e+92*cos(theta)**13 - 4.48777286252823e+90*cos(theta)**11 + 7.84575675267172e+88*cos(theta)**9 - 8.70944320370589e+86*cos(theta)**7 + 5.48256316780047e+84*cos(theta)**5 - 1.60074837016072e+82*cos(theta)**3 + 1.36816100013737e+79*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl93_m_minus_39(theta, phi):
    return 2.47868128902229e-76*(1.0 - cos(theta)**2)**19.5*(2.89947518622988e+99*cos(theta)**54 - 2.24278323864593e+100*cos(theta)**52 + 8.12549337279917e+100*cos(theta)**50 - 1.83309933364254e+101*cos(theta)**48 + 2.88789950886702e+101*cos(theta)**46 - 3.37737400189532e+101*cos(theta)**44 + 3.04285314837426e+101*cos(theta)**42 - 2.16341582225453e+101*cos(theta)**40 + 1.23352656532057e+101*cos(theta)**38 - 5.70130950309243e+100*cos(theta)**36 + 2.15079340535822e+100*cos(theta)**34 - 6.64790688928905e+99*cos(theta)**32 + 1.68576780014692e+99*cos(theta)**30 - 3.5036263404869e+98*cos(theta)**28 + 5.94955416309097e+97*cos(theta)**26 - 8.21063738006185e+96*cos(theta)**24 + 9.13764482619786e+95*cos(theta)**22 - 8.11532470146754e+94*cos(theta)**20 + 5.67296428726575e+93*cos(theta)**18 - 3.06592559502529e+92*cos(theta)**16 + 1.25139820205114e+91*cos(theta)**14 - 3.73981071877352e+89*cos(theta)**12 + 7.84575675267172e+87*cos(theta)**10 - 1.08868040046324e+86*cos(theta)**8 + 9.13760527966745e+83*cos(theta)**6 - 4.0018709254018e+81*cos(theta)**4 + 6.84080500068684e+78*cos(theta)**2 - 1.90498607649313e+75)*sin(39*phi)

#@torch.jit.script
def Yl93_m_minus_38(theta, phi):
    return 2.11197609764664e-74*(1.0 - cos(theta)**2)**19*(5.27177306587251e+97*cos(theta)**55 - 4.23166648801118e+98*cos(theta)**53 + 1.5932339946665e+99*cos(theta)**51 - 3.74101904825008e+99*cos(theta)**49 + 6.14446704014259e+99*cos(theta)**47 - 7.50527555976739e+99*cos(theta)**45 + 7.07640267063782e+99*cos(theta)**43 - 5.27662395671838e+99*cos(theta)**41 + 3.1628886290271e+99*cos(theta)**39 - 1.54089446029525e+99*cos(theta)**37 + 6.14512401530921e+98*cos(theta)**35 - 2.0145172391785e+98*cos(theta)**33 + 5.43796064563522e+97*cos(theta)**31 - 1.208147013961e+97*cos(theta)**29 + 2.20353857892258e+96*cos(theta)**27 - 3.28425495202474e+95*cos(theta)**25 + 3.97288905486864e+94*cos(theta)**23 - 3.86444033403216e+93*cos(theta)**21 + 2.98577067750829e+92*cos(theta)**19 - 1.80348564413253e+91*cos(theta)**17 + 8.34265468034093e+89*cos(theta)**15 - 2.87677747597963e+88*cos(theta)**13 + 7.13250613879248e+86*cos(theta)**11 - 1.2096448894036e+85*cos(theta)**9 + 1.30537218280964e+83*cos(theta)**7 - 8.00374185080361e+80*cos(theta)**5 + 2.28026833356228e+78*cos(theta)**3 - 1.90498607649313e+75*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl93_m_minus_37(theta, phi):
    return 1.80891708266735e-72*(1.0 - cos(theta)**2)**18.5*(9.41388047477235e+95*cos(theta)**56 - 7.83641942224293e+96*cos(theta)**54 + 3.06391152820482e+97*cos(theta)**52 - 7.48203809650016e+97*cos(theta)**50 + 1.28009730002971e+98*cos(theta)**48 - 1.63158164342769e+98*cos(theta)**46 + 1.60827333423587e+98*cos(theta)**44 - 1.2563390373139e+98*cos(theta)**42 + 7.90722157256774e+97*cos(theta)**40 - 4.05498542182961e+97*cos(theta)**38 + 1.70697889314145e+97*cos(theta)**36 - 5.92505070346618e+96*cos(theta)**34 + 1.69936270176101e+96*cos(theta)**32 - 4.02715671320334e+95*cos(theta)**30 + 7.86978063900922e+94*cos(theta)**28 - 1.26317498154798e+94*cos(theta)**26 + 1.6553704395286e+93*cos(theta)**24 - 1.75656378819644e+92*cos(theta)**22 + 1.49288533875415e+91*cos(theta)**20 - 1.00193646896251e+90*cos(theta)**18 + 5.21415917521308e+88*cos(theta)**16 - 2.05484105427117e+87*cos(theta)**14 + 5.9437551156604e+85*cos(theta)**12 - 1.2096448894036e+84*cos(theta)**10 + 1.63171522851205e+82*cos(theta)**8 - 1.33395697513393e+80*cos(theta)**6 + 5.7006708339057e+77*cos(theta)**4 - 9.52493038246567e+74*cos(theta)**2 + 2.5967640083058e+71)*sin(37*phi)

#@torch.jit.script
def Yl93_m_minus_36(theta, phi):
    return 1.5571403693523e-70*(1.0 - cos(theta)**2)**18*(1.65155797803024e+94*cos(theta)**57 - 1.4248035313169e+95*cos(theta)**55 + 5.78096514755626e+95*cos(theta)**53 - 1.4670662934314e+96*cos(theta)**51 + 2.61244346944838e+96*cos(theta)**49 - 3.4714503051653e+96*cos(theta)**47 + 3.57394074274637e+96*cos(theta)**45 - 2.92171869142767e+96*cos(theta)**43 + 1.92859062745555e+96*cos(theta)**41 - 1.03973985175118e+96*cos(theta)**39 + 4.61345646794986e+95*cos(theta)**37 - 1.69287162956177e+95*cos(theta)**35 + 5.14958394473032e+94*cos(theta)**33 - 1.29908281071075e+94*cos(theta)**31 + 2.71371746172732e+93*cos(theta)**29 - 4.6784258575851e+92*cos(theta)**27 + 6.62148175811439e+91*cos(theta)**25 - 7.63723386172364e+90*cos(theta)**23 + 7.10897780359117e+89*cos(theta)**21 - 5.27334983664481e+88*cos(theta)**19 + 3.0671524560077e+87*cos(theta)**17 - 1.36989403618078e+86*cos(theta)**15 + 4.57211931973877e+84*cos(theta)**13 - 1.09967717218509e+83*cos(theta)**11 + 1.81301692056894e+81*cos(theta)**9 - 1.90565282161991e+79*cos(theta)**7 + 1.14013416678114e+77*cos(theta)**5 - 3.17497679415522e+74*cos(theta)**3 + 2.5967640083058e+71*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl93_m_minus_35(theta, phi):
    return 1.34690391727332e-68*(1.0 - cos(theta)**2)**17.5*(2.84751375522455e+92*cos(theta)**58 - 2.54429202020874e+93*cos(theta)**56 + 1.07054910139931e+94*cos(theta)**54 - 2.82128133352193e+94*cos(theta)**52 + 5.22488693889676e+94*cos(theta)**50 - 7.23218813576105e+94*cos(theta)**48 + 7.76943639727473e+94*cos(theta)**46 - 6.64026975324471e+94*cos(theta)**44 + 4.59188244632273e+94*cos(theta)**42 - 2.59934962937796e+94*cos(theta)**40 + 1.21406749156575e+94*cos(theta)**38 - 4.70242119322713e+93*cos(theta)**36 + 1.51458351315598e+93*cos(theta)**34 - 4.05963378347111e+92*cos(theta)**32 + 9.04572487242439e+91*cos(theta)**30 - 1.67086637770896e+91*cos(theta)**28 + 2.54672375312092e+90*cos(theta)**26 - 3.18218077571818e+89*cos(theta)**24 + 3.2313535470869e+88*cos(theta)**22 - 2.63667491832241e+87*cos(theta)**20 + 1.70397358667094e+86*cos(theta)**18 - 8.56183772612986e+84*cos(theta)**16 + 3.26579951409912e+83*cos(theta)**14 - 9.16397643487573e+81*cos(theta)**12 + 1.81301692056894e+80*cos(theta)**10 - 2.38206602702488e+78*cos(theta)**8 + 1.9002236113019e+76*cos(theta)**6 - 7.93744198538806e+73*cos(theta)**4 + 1.2983820041529e+71*cos(theta)**2 - 3.47068164702726e+67)*sin(35*phi)

#@torch.jit.script
def Yl93_m_minus_34(theta, phi):
    return 1.17048972768622e-66*(1.0 - cos(theta)**2)**17*(4.82629450038058e+90*cos(theta)**59 - 4.46367021089253e+91*cos(theta)**57 + 1.9464529116351e+92*cos(theta)**55 - 5.32317232739987e+92*cos(theta)**53 + 1.0244876350778e+93*cos(theta)**51 - 1.47595676240021e+93*cos(theta)**49 + 1.65307157388824e+93*cos(theta)**47 - 1.47561550072105e+93*cos(theta)**45 + 1.0678796386797e+93*cos(theta)**43 - 6.33987714482428e+92*cos(theta)**41 + 3.11299356811731e+92*cos(theta)**39 - 1.27092464681814e+92*cos(theta)**37 + 4.32738146615993e+91*cos(theta)**35 - 1.23019205559731e+91*cos(theta)**33 + 2.91797576529819e+90*cos(theta)**31 - 5.76160819899643e+89*cos(theta)**29 + 9.43231019674415e+88*cos(theta)**27 - 1.27287231028727e+88*cos(theta)**25 + 1.40493632482039e+87*cos(theta)**23 - 1.25555948491543e+86*cos(theta)**21 + 8.96828203511022e+84*cos(theta)**19 - 5.03637513301756e+83*cos(theta)**17 + 2.17719967606608e+82*cos(theta)**15 - 7.0492126422121e+80*cos(theta)**13 + 1.64819720051722e+79*cos(theta)**11 - 2.64674003002765e+77*cos(theta)**9 + 2.71460515900272e+75*cos(theta)**7 - 1.58748839707761e+73*cos(theta)**5 + 4.327940013843e+70*cos(theta)**3 - 3.47068164702726e+67*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl93_m_minus_33(theta, phi):
    return 1.02175104912872e-64*(1.0 - cos(theta)**2)**16.5*(8.04382416730097e+88*cos(theta)**60 - 7.6959831222285e+89*cos(theta)**58 + 3.47580877077697e+90*cos(theta)**56 - 9.85772653222198e+90*cos(theta)**54 + 1.97016852899576e+91*cos(theta)**52 - 2.95191352480043e+91*cos(theta)**50 + 3.44389911226717e+91*cos(theta)**48 - 3.20785978417619e+91*cos(theta)**46 + 2.42699917881751e+91*cos(theta)**44 - 1.5094945582915e+91*cos(theta)**42 + 7.78248392029328e+90*cos(theta)**40 - 3.34453854425827e+90*cos(theta)**38 + 1.20205040726665e+90*cos(theta)**36 - 3.61821192822737e+89*cos(theta)**34 + 9.11867426655684e+88*cos(theta)**32 - 1.92053606633214e+88*cos(theta)**30 + 3.36868221312291e+87*cos(theta)**28 - 4.89566273187413e+86*cos(theta)**26 + 5.85390135341829e+85*cos(theta)**24 - 5.70708856779741e+84*cos(theta)**22 + 4.48414101755511e+83*cos(theta)**20 - 2.79798618500976e+82*cos(theta)**18 + 1.3607497975413e+81*cos(theta)**16 - 5.03515188729436e+79*cos(theta)**14 + 1.37349766709768e+78*cos(theta)**12 - 2.64674003002765e+76*cos(theta)**10 + 3.39325644875339e+74*cos(theta)**8 - 2.64581399512935e+72*cos(theta)**6 + 1.08198500346075e+70*cos(theta)**4 - 1.73534082351363e+67*cos(theta)**2 + 4.55470032418276e+63)*sin(33*phi)

#@torch.jit.script
def Yl93_m_minus_32(theta, phi):
    return 8.95767460692613e-63*(1.0 - cos(theta)**2)**16*(1.31865969955754e+87*cos(theta)**61 - 1.30440391902178e+88*cos(theta)**59 + 6.09791012417012e+88*cos(theta)**57 - 1.79231391494945e+89*cos(theta)**55 + 3.71729911131276e+89*cos(theta)**53 - 5.7880657349028e+89*cos(theta)**51 + 7.02836553523912e+89*cos(theta)**49 - 6.82523358335359e+89*cos(theta)**47 + 5.39333150848336e+89*cos(theta)**45 - 3.51045246114301e+89*cos(theta)**43 + 1.89816680982763e+89*cos(theta)**41 - 8.57573985707249e+88*cos(theta)**39 + 3.24878488450445e+88*cos(theta)**37 - 1.03377483663639e+88*cos(theta)**35 + 2.76323462622935e+87*cos(theta)**33 - 6.19527763332949e+86*cos(theta)**31 + 1.16161455624928e+86*cos(theta)**29 - 1.81320841921264e+85*cos(theta)**27 + 2.34156054136732e+84*cos(theta)**25 - 2.48134285556409e+83*cos(theta)**23 + 2.13530524645482e+82*cos(theta)**21 - 1.47262430789987e+81*cos(theta)**19 + 8.00441057377235e+79*cos(theta)**17 - 3.3567679248629e+78*cos(theta)**15 + 1.05653666699822e+77*cos(theta)**13 - 2.40612730002513e+75*cos(theta)**11 + 3.77028494305933e+73*cos(theta)**9 - 3.77973427875622e+71*cos(theta)**7 + 2.1639700069215e+69*cos(theta)**5 - 5.78446941171211e+66*cos(theta)**3 + 4.55470032418276e+63*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl93_m_minus_31(theta, phi):
    return 7.88580681552409e-61*(1.0 - cos(theta)**2)**15.5*(2.12687048315732e+85*cos(theta)**62 - 2.17400653170297e+86*cos(theta)**60 + 1.05136381451209e+87*cos(theta)**58 - 3.20056056240973e+87*cos(theta)**56 + 6.88388724317177e+87*cos(theta)**54 - 1.11308956440438e+88*cos(theta)**52 + 1.40567310704782e+88*cos(theta)**50 - 1.42192366319866e+88*cos(theta)**48 + 1.17246337140943e+88*cos(theta)**46 - 7.9783010480523e+87*cos(theta)**44 + 4.51944478530388e+87*cos(theta)**42 - 2.14393496426812e+87*cos(theta)**40 + 8.54943390659067e+86*cos(theta)**38 - 2.87159676843442e+86*cos(theta)**36 + 8.12716066538043e+85*cos(theta)**34 - 1.93602426041547e+85*cos(theta)**32 + 3.87204852083093e+84*cos(theta)**30 - 6.47574435433086e+83*cos(theta)**28 + 9.00600208218198e+82*cos(theta)**26 - 1.03389285648504e+82*cos(theta)**24 + 9.70593293843098e+80*cos(theta)**22 - 7.36312153949936e+79*cos(theta)**20 + 4.44689476320686e+78*cos(theta)**18 - 2.09797995303931e+77*cos(theta)**16 + 7.54669047855869e+75*cos(theta)**14 - 2.00510608335428e+74*cos(theta)**12 + 3.77028494305933e+72*cos(theta)**10 - 4.72466784844527e+70*cos(theta)**8 + 3.6066166782025e+68*cos(theta)**6 - 1.44611735292803e+66*cos(theta)**4 + 2.27735016209138e+63*cos(theta)**2 - 5.87703267636485e+59)*sin(31*phi)

#@torch.jit.script
def Yl93_m_minus_30(theta, phi):
    return 6.96991129511242e-59*(1.0 - cos(theta)**2)**15*(3.3759848939005e+83*cos(theta)**63 - 3.56394513393929e+84*cos(theta)**61 + 1.78197256696964e+85*cos(theta)**59 - 5.61501853054339e+85*cos(theta)**57 + 1.25161586239487e+86*cos(theta)**55 - 2.10016898944224e+86*cos(theta)**53 + 2.75622177852514e+86*cos(theta)**51 - 2.90188502693605e+86*cos(theta)**49 + 2.49460291789239e+86*cos(theta)**47 - 1.77295578845607e+86*cos(theta)**45 + 1.0510336710009e+86*cos(theta)**43 - 5.22910966894664e+85*cos(theta)**41 + 2.19216254015145e+85*cos(theta)**39 - 7.76107234712005e+84*cos(theta)**37 + 2.32204590439441e+84*cos(theta)**35 - 5.86674018307717e+83*cos(theta)**33 + 1.24904790994546e+83*cos(theta)**31 - 2.23301529459685e+82*cos(theta)**29 + 3.33555632673407e+81*cos(theta)**27 - 4.13557142594016e+80*cos(theta)**25 + 4.21997084279608e+79*cos(theta)**23 - 3.50624835214255e+78*cos(theta)**21 + 2.34047092800361e+77*cos(theta)**19 - 1.23410585472901e+76*cos(theta)**17 + 5.03112698570579e+74*cos(theta)**15 - 1.54238929488791e+73*cos(theta)**13 + 3.42753176641757e+71*cos(theta)**11 - 5.24963094271697e+69*cos(theta)**9 + 5.15230954028928e+67*cos(theta)**7 - 2.89223470585605e+65*cos(theta)**5 + 7.59116720697127e+62*cos(theta)**3 - 5.87703267636485e+59*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl93_m_minus_29(theta, phi):
    return 6.18400445319037e-57*(1.0 - cos(theta)**2)**14.5*(5.27497639671954e+81*cos(theta)**64 - 5.74829860312788e+82*cos(theta)**62 + 2.96995427828274e+83*cos(theta)**60 - 9.68106643197136e+83*cos(theta)**58 + 2.23502832570512e+84*cos(theta)**56 - 3.88920183230044e+84*cos(theta)**54 + 5.30042649716374e+84*cos(theta)**52 - 5.8037700538721e+84*cos(theta)**50 + 5.19708941227582e+84*cos(theta)**48 - 3.85425171403493e+84*cos(theta)**46 + 2.38871288863841e+84*cos(theta)**44 - 1.24502611165396e+84*cos(theta)**42 + 5.48040635037863e+83*cos(theta)**40 - 2.04238745976843e+83*cos(theta)**38 + 6.45012751220669e+82*cos(theta)**36 - 1.72551181855211e+82*cos(theta)**34 + 3.90327471857957e+81*cos(theta)**32 - 7.44338431532282e+80*cos(theta)**30 + 1.19127011669074e+80*cos(theta)**28 - 1.59060439459237e+79*cos(theta)**26 + 1.75832118449837e+78*cos(theta)**24 - 1.59374925097389e+77*cos(theta)**22 + 1.17023546400181e+76*cos(theta)**20 - 6.85614363738338e+74*cos(theta)**18 + 3.14445436606612e+73*cos(theta)**16 - 1.10170663920565e+72*cos(theta)**14 + 2.85627647201464e+70*cos(theta)**12 - 5.24963094271697e+68*cos(theta)**10 + 6.4403869253616e+66*cos(theta)**8 - 4.82039117642676e+64*cos(theta)**6 + 1.89779180174282e+62*cos(theta)**4 - 2.93851633818243e+59*cos(theta)**2 + 7.46574272912202e+55)*sin(29*phi)

#@torch.jit.script
def Yl93_m_minus_28(theta, phi):
    return 5.50688981950095e-55*(1.0 - cos(theta)**2)**14*(8.11534830264544e+79*cos(theta)**65 - 9.12428349702839e+80*cos(theta)**63 + 4.86877750538154e+81*cos(theta)**61 - 1.64085871728328e+82*cos(theta)**59 + 3.92110232579846e+82*cos(theta)**57 - 7.07127605872807e+82*cos(theta)**55 + 1.00008047116297e+83*cos(theta)**53 - 1.13799412821022e+83*cos(theta)**51 + 1.06063049230119e+83*cos(theta)**49 - 8.20053556177645e+82*cos(theta)**47 + 5.30825086364092e+82*cos(theta)**45 - 2.89540956198596e+82*cos(theta)**43 + 1.33668447570211e+82*cos(theta)**41 - 5.23689092248317e+81*cos(theta)**39 + 1.74327770600181e+81*cos(theta)**37 - 4.93003376729174e+80*cos(theta)**35 + 1.18281052078169e+80*cos(theta)**33 - 2.40109171462027e+79*cos(theta)**31 + 4.10782798858875e+78*cos(theta)**29 - 5.89112738737914e+77*cos(theta)**27 + 7.03328473799346e+76*cos(theta)**25 - 6.92934456945169e+75*cos(theta)**23 + 5.57254982858003e+74*cos(theta)**21 - 3.60849665125441e+73*cos(theta)**19 + 1.84967903886242e+72*cos(theta)**17 - 7.34471092803765e+70*cos(theta)**15 + 2.19713574770357e+69*cos(theta)**13 - 4.77239176610634e+67*cos(theta)**11 + 7.15598547262401e+65*cos(theta)**9 - 6.88627310918108e+63*cos(theta)**7 + 3.79558360348563e+61*cos(theta)**5 - 9.79505446060809e+58*cos(theta)**3 + 7.46574272912202e+55*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl93_m_minus_27(theta, phi):
    return 4.92120028220969e-53*(1.0 - cos(theta)**2)**13.5*(1.22959822767355e+78*cos(theta)**66 - 1.42566929641069e+79*cos(theta)**64 + 7.85286694416378e+79*cos(theta)**62 - 2.73476452880547e+80*cos(theta)**60 + 6.76052125137665e+80*cos(theta)**58 - 1.26272786763001e+81*cos(theta)**56 + 1.85200087252402e+81*cos(theta)**54 - 2.18845024655811e+81*cos(theta)**52 + 2.12126098460238e+81*cos(theta)**50 - 1.70844490870343e+81*cos(theta)**48 + 1.15396757905237e+81*cos(theta)**46 - 6.58047627724081e+80*cos(theta)**44 + 3.18258208500501e+80*cos(theta)**42 - 1.30922273062079e+80*cos(theta)**40 + 4.58757291053108e+79*cos(theta)**38 - 1.36945382424771e+79*cos(theta)**36 + 3.47885447288732e+78*cos(theta)**34 - 7.50341160818833e+77*cos(theta)**32 + 1.36927599619625e+77*cos(theta)**30 - 2.10397406692112e+76*cos(theta)**28 + 2.70510951461287e+75*cos(theta)**26 - 2.8872269039382e+74*cos(theta)**24 + 2.5329771948091e+73*cos(theta)**22 - 1.80424832562721e+72*cos(theta)**20 + 1.02759946603468e+71*cos(theta)**18 - 4.59044433002353e+69*cos(theta)**16 + 1.56938267693112e+68*cos(theta)**14 - 3.97699313842195e+66*cos(theta)**12 + 7.15598547262401e+64*cos(theta)**10 - 8.60784138647635e+62*cos(theta)**8 + 6.32597267247606e+60*cos(theta)**6 - 2.44876361515202e+58*cos(theta)**4 + 3.73287136456101e+55*cos(theta)**2 - 9.34853835352119e+51)*sin(27*phi)

#@torch.jit.script
def Yl93_m_minus_26(theta, phi):
    return 4.41264576223461e-51*(1.0 - cos(theta)**2)**13*(1.83522123533366e+76*cos(theta)**67 - 2.19333737909336e+77*cos(theta)**65 + 1.24648681653393e+78*cos(theta)**63 - 4.48322053902536e+78*cos(theta)**61 + 1.14585105955536e+79*cos(theta)**59 - 2.2153120484737e+79*cos(theta)**57 + 3.36727431368003e+79*cos(theta)**55 - 4.1291514086002e+79*cos(theta)**53 + 4.15933526392623e+79*cos(theta)**51 - 3.48662226266005e+79*cos(theta)**49 + 2.45525016819654e+79*cos(theta)**47 - 1.46232806160907e+79*cos(theta)**45 + 7.40135368605817e+78*cos(theta)**43 - 3.19322617224583e+78*cos(theta)**41 + 1.17630074629002e+78*cos(theta)**39 - 3.70122655202083e+77*cos(theta)**37 + 9.93958420824948e+76*cos(theta)**35 - 2.2737610933904e+76*cos(theta)**33 + 4.41701934256855e+75*cos(theta)**31 - 7.25508298938318e+74*cos(theta)**29 + 1.00189241281958e+74*cos(theta)**27 - 1.15489076157528e+73*cos(theta)**25 + 1.1012944325257e+72*cos(theta)**23 - 8.59165869346288e+70*cos(theta)**21 + 5.40841824228779e+69*cos(theta)**19 - 2.70026137060208e+68*cos(theta)**17 + 1.04625511795408e+67*cos(theta)**15 - 3.05922549109381e+65*cos(theta)**13 + 6.5054413387491e+63*cos(theta)**11 - 9.56426820719594e+61*cos(theta)**9 + 9.03710381782294e+59*cos(theta)**7 - 4.89752723030404e+57*cos(theta)**5 + 1.24429045485367e+55*cos(theta)**3 - 9.34853835352119e+51*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl93_m_minus_25(theta, phi):
    return 3.96941952563658e-49*(1.0 - cos(theta)**2)**12.5*(2.69885475784362e+74*cos(theta)**68 - 3.32323845317176e+75*cos(theta)**66 + 1.94763565083427e+76*cos(theta)**64 - 7.23100086939574e+76*cos(theta)**62 + 1.90975176592561e+77*cos(theta)**60 - 3.81950353185121e+77*cos(theta)**58 + 6.0129898458572e+77*cos(theta)**56 - 7.64657668259297e+77*cos(theta)**54 + 7.99872166139659e+77*cos(theta)**52 - 6.97324452532011e+77*cos(theta)**50 + 5.11510451707613e+77*cos(theta)**48 - 3.17897404697624e+77*cos(theta)**46 + 1.68212583774049e+77*cos(theta)**44 - 7.60291945772817e+76*cos(theta)**42 + 2.94075186572505e+76*cos(theta)**40 - 9.74006987373901e+75*cos(theta)**38 + 2.76099561340263e+75*cos(theta)**36 - 6.68753262761883e+74*cos(theta)**34 + 1.38031854455267e+74*cos(theta)**32 - 2.41836099646106e+73*cos(theta)**30 + 3.57818718864136e+72*cos(theta)**28 - 4.44188754452031e+71*cos(theta)**26 + 4.5887268021904e+70*cos(theta)**24 - 3.90529940611949e+69*cos(theta)**22 + 2.70420912114389e+68*cos(theta)**20 - 1.50014520589004e+67*cos(theta)**18 + 6.53909448721301e+65*cos(theta)**16 - 2.185161065067e+64*cos(theta)**14 + 5.42120111562425e+62*cos(theta)**12 - 9.56426820719594e+60*cos(theta)**10 + 1.12963797722787e+59*cos(theta)**8 - 8.16254538384007e+56*cos(theta)**6 + 3.11072613713417e+54*cos(theta)**4 - 4.67426917676059e+51*cos(theta)**2 + 1.15528155629278e+48)*sin(25*phi)

#@torch.jit.script
def Yl93_m_minus_24(theta, phi):
    return 3.58172757672399e-47*(1.0 - cos(theta)**2)**12*(3.91138370701973e+72*cos(theta)**69 - 4.96005739279367e+73*cos(theta)**67 + 2.99636253974503e+74*cos(theta)**65 - 1.1477779157771e+75*cos(theta)**63 + 3.13074059987805e+75*cos(theta)**61 - 6.47373479974782e+75*cos(theta)**59 + 1.05491049927319e+76*cos(theta)**57 - 1.39028666956236e+76*cos(theta)**55 + 1.50919276630124e+76*cos(theta)**53 - 1.36730284810198e+76*cos(theta)**51 + 1.04389888103594e+76*cos(theta)**49 - 6.76377456803455e+75*cos(theta)**47 + 3.7380574172011e+75*cos(theta)**45 - 1.76812080412283e+75*cos(theta)**43 + 7.17256552615866e+74*cos(theta)**41 - 2.49745381377923e+74*cos(theta)**39 + 7.4621503064936e+73*cos(theta)**37 - 1.91072360789109e+73*cos(theta)**35 + 4.18278346834143e+72*cos(theta)**33 - 7.80116450471309e+71*cos(theta)**31 + 1.23385765125564e+71*cos(theta)**29 - 1.64514353500752e+70*cos(theta)**27 + 1.83549072087616e+69*cos(theta)**25 - 1.69795626353021e+68*cos(theta)**23 + 1.28771862911614e+67*cos(theta)**21 - 7.89550108363181e+65*cos(theta)**19 + 3.84652616894883e+64*cos(theta)**17 - 1.456774043378e+63*cos(theta)**15 + 4.17015470432634e+61*cos(theta)**13 - 8.69478927926904e+59*cos(theta)**11 + 1.25515330803096e+58*cos(theta)**9 - 1.16607791197715e+56*cos(theta)**7 + 6.22145227426835e+53*cos(theta)**5 - 1.55808972558686e+51*cos(theta)**3 + 1.15528155629278e+48*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl93_m_minus_23(theta, phi):
    return 3.24141398518232e-45*(1.0 - cos(theta)**2)**11.5*(5.58769101002819e+70*cos(theta)**70 - 7.29420204822599e+71*cos(theta)**68 + 4.53994324203793e+72*cos(theta)**66 - 1.79340299340172e+73*cos(theta)**64 + 5.04958161270652e+73*cos(theta)**62 - 1.07895579995797e+74*cos(theta)**60 + 1.81881120564344e+74*cos(theta)**58 - 2.48265476707564e+74*cos(theta)**56 + 2.79480141907638e+74*cos(theta)**54 - 2.62942855404227e+74*cos(theta)**52 + 2.08779776207189e+74*cos(theta)**50 - 1.40911970167386e+74*cos(theta)**48 + 8.12621177652412e+73*cos(theta)**46 - 4.01845637300643e+73*cos(theta)**44 + 1.70775369670444e+73*cos(theta)**42 - 6.24363453444809e+72*cos(theta)**40 + 1.96372376486674e+72*cos(theta)**38 - 5.30756557747526e+71*cos(theta)**36 + 1.23023043186513e+71*cos(theta)**34 - 2.43786390772284e+70*cos(theta)**32 + 4.11285883751881e+69*cos(theta)**30 - 5.87551262502687e+68*cos(theta)**28 + 7.05957969567755e+67*cos(theta)**26 - 7.07481776470923e+66*cos(theta)**24 + 5.85326649598245e+65*cos(theta)**22 - 3.9477505418159e+64*cos(theta)**20 + 2.13695898274935e+63*cos(theta)**18 - 9.10483777111252e+61*cos(theta)**16 + 2.97868193166167e+60*cos(theta)**14 - 7.2456577327242e+58*cos(theta)**12 + 1.25515330803096e+57*cos(theta)**10 - 1.45759738997144e+55*cos(theta)**8 + 1.03690871237806e+53*cos(theta)**6 - 3.89522431396716e+50*cos(theta)**4 + 5.77640778146391e+47*cos(theta)**2 - 1.41060019083368e+44)*sin(23*phi)

#@torch.jit.script
def Yl93_m_minus_22(theta, phi):
    return 2.94166132377253e-43*(1.0 - cos(theta)**2)**11*(7.86998733806788e+68*cos(theta)**71 - 1.05713073162696e+70*cos(theta)**69 + 6.77603468960884e+70*cos(theta)**67 - 2.75908152831034e+71*cos(theta)**65 + 8.01520890905798e+71*cos(theta)**63 - 1.7687799999311e+72*cos(theta)**61 + 3.08273085702277e+72*cos(theta)**59 - 4.35553467908007e+72*cos(theta)**57 + 5.08145712559341e+72*cos(theta)**55 - 4.96118595102316e+72*cos(theta)**53 + 4.09372110210174e+72*cos(theta)**51 - 2.87575449321197e+72*cos(theta)**49 + 1.72898122904769e+72*cos(theta)**47 - 8.92990305112541e+71*cos(theta)**45 + 3.97152022489405e+71*cos(theta)**43 - 1.5228376913288e+71*cos(theta)**41 + 5.03518914068394e+70*cos(theta)**39 - 1.43447718310142e+70*cos(theta)**37 + 3.51494409104322e+69*cos(theta)**35 - 7.38746638703891e+68*cos(theta)**33 + 1.32672865726413e+68*cos(theta)**31 - 2.02603883621616e+67*cos(theta)**29 + 2.61465914654724e+66*cos(theta)**27 - 2.82992710588369e+65*cos(theta)**25 + 2.54489847651411e+64*cos(theta)**23 - 1.87988121038853e+63*cos(theta)**21 + 1.1247152540786e+62*cos(theta)**19 - 5.35578692418383e+60*cos(theta)**17 + 1.98578795444112e+59*cos(theta)**15 - 5.57358287132631e+57*cos(theta)**13 + 1.14104846184633e+56*cos(theta)**11 - 1.61955265552382e+54*cos(theta)**9 + 1.48129816054008e+52*cos(theta)**7 - 7.79044862793432e+49*cos(theta)**5 + 1.92546926048797e+47*cos(theta)**3 - 1.41060019083368e+44*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl93_m_minus_21(theta, phi):
    return 2.67675017001011e-41*(1.0 - cos(theta)**2)**10.5*(1.09305379695387e+67*cos(theta)**72 - 1.51018675946708e+68*cos(theta)**70 + 9.96475689648359e+68*cos(theta)**68 - 4.18042655804597e+69*cos(theta)**66 + 1.25237639204031e+70*cos(theta)**64 - 2.8528709676308e+70*cos(theta)**62 + 5.13788476170462e+70*cos(theta)**60 - 7.50954255013805e+70*cos(theta)**58 + 9.07403058141681e+70*cos(theta)**56 - 9.18738139078362e+70*cos(theta)**54 + 7.87254058096489e+70*cos(theta)**52 - 5.75150898642393e+70*cos(theta)**50 + 3.60204422718268e+70*cos(theta)**48 - 1.94128327198378e+70*cos(theta)**46 + 9.02618232930466e+69*cos(theta)**44 - 3.62580402697334e+69*cos(theta)**42 + 1.25879728517099e+69*cos(theta)**40 - 3.77493995553006e+68*cos(theta)**38 + 9.76373358623117e+67*cos(theta)**36 - 2.17278423148203e+67*cos(theta)**34 + 4.14602705395041e+66*cos(theta)**32 - 6.7534627873872e+65*cos(theta)**30 + 9.33806838052585e+64*cos(theta)**28 - 1.08843350226296e+64*cos(theta)**26 + 1.06037436521421e+63*cos(theta)**24 - 8.54491459267511e+61*cos(theta)**22 + 5.62357627039302e+60*cos(theta)**20 - 2.97543718010213e+59*cos(theta)**18 + 1.2411174715257e+58*cos(theta)**16 - 3.98113062237593e+56*cos(theta)**14 + 9.50873718205276e+54*cos(theta)**12 - 1.61955265552382e+53*cos(theta)**10 + 1.8516227006751e+51*cos(theta)**8 - 1.29840810465572e+49*cos(theta)**6 + 4.81367315121992e+46*cos(theta)**4 - 7.05300095416838e+43*cos(theta)**2 + 1.70362341888125e+40)*sin(21*phi)

#@torch.jit.script
def Yl93_m_minus_20(theta, phi):
    return 2.44186525089707e-39*(1.0 - cos(theta)**2)**10*(1.49733396842996e+65*cos(theta)**73 - 2.12702360488321e+66*cos(theta)**71 + 1.44416766615704e+67*cos(theta)**69 - 6.23944262394921e+67*cos(theta)**67 + 1.92673291083124e+68*cos(theta)**65 - 4.52836661528699e+68*cos(theta)**63 + 8.4227619044338e+68*cos(theta)**61 - 1.2728038220573e+69*cos(theta)**59 + 1.59193518972225e+69*cos(theta)**57 - 1.67043298014248e+69*cos(theta)**55 + 1.48538501527639e+69*cos(theta)**53 - 1.12774686008312e+69*cos(theta)**51 + 7.35111066771975e+68*cos(theta)**49 - 4.13038994039103e+68*cos(theta)**47 + 2.00581829540104e+68*cos(theta)**45 - 8.43210238831009e+67*cos(theta)**43 + 3.07023728090484e+67*cos(theta)**41 - 9.67933321930784e+66*cos(theta)**39 + 2.63884691519761e+66*cos(theta)**37 - 6.20795494709152e+65*cos(theta)**35 + 1.25637183453043e+65*cos(theta)**33 - 2.17853638302813e+64*cos(theta)**31 + 3.22002357949167e+63*cos(theta)**29 - 4.03123519356651e+62*cos(theta)**27 + 4.24149746085685e+61*cos(theta)**25 - 3.71518025768483e+60*cos(theta)**23 + 2.67789346209192e+59*cos(theta)**21 - 1.56601956847481e+58*cos(theta)**19 + 7.30069100897469e+56*cos(theta)**17 - 2.65408708158396e+55*cos(theta)**15 + 7.31441321696366e+53*cos(theta)**13 - 1.47232059593075e+52*cos(theta)**11 + 2.05735855630567e+50*cos(theta)**9 - 1.85486872093674e+48*cos(theta)**7 + 9.62734630243984e+45*cos(theta)**5 - 2.35100031805613e+43*cos(theta)**3 + 1.70362341888125e+40*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl93_m_minus_19(theta, phi):
    return 2.23293857428703e-37*(1.0 - cos(theta)**2)**9.5*(2.02342428166211e+63*cos(theta)**74 - 2.95419945122668e+64*cos(theta)**72 + 2.06309666593863e+65*cos(theta)**70 - 9.17565091757237e+65*cos(theta)**68 + 2.91929228913825e+66*cos(theta)**66 - 7.07557283638592e+66*cos(theta)**64 + 1.3585099845861e+67*cos(theta)**62 - 2.12133970342883e+67*cos(theta)**60 + 2.7447158443487e+67*cos(theta)**58 - 2.98291603596871e+67*cos(theta)**56 + 2.75071299125258e+67*cos(theta)**54 - 2.16874396169832e+67*cos(theta)**52 + 1.47022213354395e+67*cos(theta)**50 - 8.60497904248132e+66*cos(theta)**48 + 4.36047455521964e+66*cos(theta)**46 - 1.91638690643411e+66*cos(theta)**44 + 7.31008876405915e+65*cos(theta)**42 - 2.41983330482696e+65*cos(theta)**40 + 6.94433398736214e+64*cos(theta)**38 - 1.72443192974765e+64*cos(theta)**36 + 3.69521127803067e+63*cos(theta)**34 - 6.80792619696291e+62*cos(theta)**32 + 1.07334119316389e+62*cos(theta)**30 - 1.43972685484518e+61*cos(theta)**28 + 1.63134517725264e+60*cos(theta)**26 - 1.54799177403535e+59*cos(theta)**24 + 1.21722430095087e+58*cos(theta)**22 - 7.83009784237402e+56*cos(theta)**20 + 4.05593944943038e+55*cos(theta)**18 - 1.65880442598997e+54*cos(theta)**16 + 5.22458086925976e+52*cos(theta)**14 - 1.22693382994229e+51*cos(theta)**12 + 2.05735855630567e+49*cos(theta)**10 - 2.31858590117093e+47*cos(theta)**8 + 1.60455771707331e+45*cos(theta)**6 - 5.87750079514032e+42*cos(theta)**4 + 8.51811709440626e+39*cos(theta)**2 - 2.03733965424689e+36)*sin(19*phi)

#@torch.jit.script
def Yl93_m_minus_18(theta, phi):
    return 2.04652200777142e-35*(1.0 - cos(theta)**2)**9*(2.69789904221615e+61*cos(theta)**75 - 4.04684856332422e+62*cos(theta)**73 + 2.90576995202624e+63*cos(theta)**71 - 1.32980448080759e+64*cos(theta)**69 + 4.35715267035559e+64*cos(theta)**67 - 1.0885496671363e+65*cos(theta)**65 + 2.15636505489857e+65*cos(theta)**63 - 3.4776060711948e+65*cos(theta)**61 + 4.65206075313339e+65*cos(theta)**59 - 5.23318602801528e+65*cos(theta)**57 + 5.00129634773197e+65*cos(theta)**55 - 4.09196973905343e+65*cos(theta)**53 + 2.882788497145e+65*cos(theta)**51 - 1.75611817193496e+65*cos(theta)**49 + 9.27760543663754e+64*cos(theta)**47 - 4.25863756985358e+64*cos(theta)**45 + 1.70002064280445e+64*cos(theta)**43 - 5.90203245079747e+63*cos(theta)**41 + 1.78059845829798e+63*cos(theta)**39 - 4.6606268371558e+62*cos(theta)**37 + 1.05577465086591e+62*cos(theta)**35 - 2.06300793847361e+61*cos(theta)**33 + 3.46239094568997e+60*cos(theta)**31 - 4.96457536153511e+59*cos(theta)**29 + 6.04201917500976e+58*cos(theta)**27 - 6.19196709614139e+57*cos(theta)**25 + 5.29227956935161e+56*cos(theta)**23 - 3.72861802017811e+55*cos(theta)**21 + 2.13470497338441e+54*cos(theta)**19 - 9.75767309405866e+52*cos(theta)**17 + 3.48305391283984e+51*cos(theta)**15 - 9.43795253801762e+49*cos(theta)**13 + 1.87032596027788e+48*cos(theta)**11 - 2.57620655685659e+46*cos(theta)**9 + 2.29222531010472e+44*cos(theta)**7 - 1.17550015902806e+42*cos(theta)**5 + 2.83937236480209e+39*cos(theta)**3 - 2.03733965424689e+36*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl93_m_minus_17(theta, phi):
    return 1.8796833946566e-33*(1.0 - cos(theta)**2)**8.5*(3.54986716081072e+59*cos(theta)**76 - 5.46871427476246e+60*cos(theta)**74 + 4.03579160003645e+61*cos(theta)**72 - 1.89972068686799e+62*cos(theta)**70 + 6.40757745640529e+62*cos(theta)**68 - 1.64931767747924e+63*cos(theta)**66 + 3.36932039827901e+63*cos(theta)**64 - 5.60904205031419e+63*cos(theta)**62 + 7.75343458855566e+63*cos(theta)**60 - 9.02273453106082e+63*cos(theta)**58 + 8.93088633523565e+63*cos(theta)**56 - 7.57772173898783e+63*cos(theta)**54 + 5.54382403297116e+63*cos(theta)**52 - 3.51223634386993e+63*cos(theta)**50 + 1.93283446596615e+63*cos(theta)**48 - 9.25790776055126e+62*cos(theta)**46 + 3.86368327910103e+62*cos(theta)**44 - 1.40524582161844e+62*cos(theta)**42 + 4.45149614574496e+61*cos(theta)**40 - 1.22648074661995e+61*cos(theta)**38 + 2.9327073635164e+60*cos(theta)**36 - 6.06767040727532e+59*cos(theta)**34 + 1.08199717052812e+59*cos(theta)**32 - 1.65485845384504e+58*cos(theta)**30 + 2.15786399107491e+57*cos(theta)**28 - 2.38152580620823e+56*cos(theta)**26 + 2.20511648722984e+55*cos(theta)**24 - 1.69482637280823e+54*cos(theta)**22 + 1.06735248669221e+53*cos(theta)**20 - 5.42092949669926e+51*cos(theta)**18 + 2.1769086955249e+50*cos(theta)**16 - 6.74139467001259e+48*cos(theta)**14 + 1.55860496689824e+47*cos(theta)**12 - 2.57620655685659e+45*cos(theta)**10 + 2.86528163763091e+43*cos(theta)**8 - 1.95916693171344e+41*cos(theta)**6 + 7.09843091200522e+38*cos(theta)**4 - 1.01866982712345e+36*cos(theta)**2 + 2.4150541183581e+32)*sin(17*phi)

#@torch.jit.script
def Yl93_m_minus_16(theta, phi):
    return 1.72992155473396e-31*(1.0 - cos(theta)**2)**8*(4.61021709196197e+57*cos(theta)**77 - 7.29161903301661e+58*cos(theta)**75 + 5.52848164388555e+59*cos(theta)**73 - 2.67566293925068e+60*cos(theta)**71 + 9.28634413971781e+60*cos(theta)**69 - 2.46166817534214e+61*cos(theta)**67 + 5.18356984350617e+61*cos(theta)**65 - 8.90324134970507e+61*cos(theta)**63 + 1.27105485058289e+62*cos(theta)**61 - 1.52927703916285e+62*cos(theta)**59 + 1.56682216407643e+62*cos(theta)**57 - 1.37776758890688e+62*cos(theta)**55 + 1.04600453452286e+62*cos(theta)**53 - 6.88673792915672e+61*cos(theta)**51 + 3.9445601346248e+61*cos(theta)**49 - 1.96976760862793e+61*cos(theta)**47 + 8.58596284244673e+60*cos(theta)**45 - 3.26801353864754e+60*cos(theta)**43 + 1.08573076725487e+60*cos(theta)**41 - 3.14482242723063e+59*cos(theta)**39 + 7.9262361176119e+58*cos(theta)**37 - 1.73362011636438e+58*cos(theta)**35 + 3.27877930463066e+57*cos(theta)**33 - 5.33825307691948e+56*cos(theta)**31 + 7.44091031405143e+55*cos(theta)**29 - 8.82046594891936e+54*cos(theta)**27 + 8.82046594891936e+53*cos(theta)**25 - 7.36881031655752e+52*cos(theta)**23 + 5.08263088901051e+51*cos(theta)**21 - 2.85312078773645e+50*cos(theta)**19 + 1.28053452677935e+49*cos(theta)**17 - 4.49426311334173e+47*cos(theta)**15 + 1.19892689761403e+46*cos(theta)**13 - 2.34200596077872e+44*cos(theta)**11 + 3.18364626403434e+42*cos(theta)**9 - 2.79880990244777e+40*cos(theta)**7 + 1.41968618240104e+38*cos(theta)**5 - 3.39556609041149e+35*cos(theta)**3 + 2.4150541183581e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl93_m_minus_15(theta, phi):
    return 1.59509649345119e-29*(1.0 - cos(theta)**2)**7.5*(5.91053473328458e+55*cos(theta)**78 - 9.5942355697587e+56*cos(theta)**76 + 7.47092114038587e+57*cos(theta)**74 - 3.71619852673706e+58*cos(theta)**72 + 1.32662059138826e+59*cos(theta)**70 - 3.62010025785609e+59*cos(theta)**68 + 7.85389370228208e+59*cos(theta)**66 - 1.39113146089142e+60*cos(theta)**64 + 2.05008846868209e+60*cos(theta)**62 - 2.54879506527142e+60*cos(theta)**60 + 2.70141752426971e+60*cos(theta)**58 - 2.46029926590514e+60*cos(theta)**56 + 1.93704543430159e+60*cos(theta)**54 - 1.32437267868398e+60*cos(theta)**52 + 7.88912026924961e+59*cos(theta)**50 - 4.10368251797485e+59*cos(theta)**48 + 1.86651366140146e+59*cos(theta)**46 - 7.42730349692624e+58*cos(theta)**44 + 2.58507325536874e+58*cos(theta)**42 - 7.86205606807658e+57*cos(theta)**40 + 2.08585160989787e+57*cos(theta)**38 - 4.81561143434549e+56*cos(theta)**36 + 9.64346854303134e+55*cos(theta)**34 - 1.66820408653734e+55*cos(theta)**32 + 2.48030343801714e+54*cos(theta)**30 - 3.15016641032834e+53*cos(theta)**28 + 3.39248690343052e+52*cos(theta)**26 - 3.07033763189897e+51*cos(theta)**24 + 2.31028676773205e+50*cos(theta)**22 - 1.42656039386823e+49*cos(theta)**20 + 7.11408070432973e+47*cos(theta)**18 - 2.80891444583858e+46*cos(theta)**16 + 8.56376355438591e+44*cos(theta)**14 - 1.95167163398226e+43*cos(theta)**12 + 3.18364626403434e+41*cos(theta)**10 - 3.49851237805971e+39*cos(theta)**8 + 2.36614363733507e+37*cos(theta)**6 - 8.48891522602872e+34*cos(theta)**4 + 1.20752705917905e+32*cos(theta)**2 - 2.84057176941673e+28)*sin(15*phi)

#@torch.jit.script
def Yl93_m_minus_14(theta, phi):
    return 1.47337190313315e-27*(1.0 - cos(theta)**2)**7*(7.48168953580327e+53*cos(theta)**79 - 1.24600461944918e+55*cos(theta)**77 + 9.96122818718116e+55*cos(theta)**75 - 5.09068291333844e+56*cos(theta)**73 + 1.86847970618065e+57*cos(theta)**71 - 5.24652211283492e+57*cos(theta)**69 + 1.17222294063912e+58*cos(theta)**67 - 2.14020224752526e+58*cos(theta)**65 + 3.25410868044776e+58*cos(theta)**63 - 4.17835256601872e+58*cos(theta)**61 + 4.57867376994866e+58*cos(theta)**59 - 4.31631450158796e+58*cos(theta)**57 + 3.52190078963926e+58*cos(theta)**55 - 2.49881637487544e+58*cos(theta)**53 + 1.54688632730384e+58*cos(theta)**51 - 8.37486228158132e+57*cos(theta)**49 + 3.97130566255631e+57*cos(theta)**47 - 1.65051188820583e+57*cos(theta)**45 + 6.01179826829938e+56*cos(theta)**43 - 1.91757465075039e+56*cos(theta)**41 + 5.34833746127659e+55*cos(theta)**39 - 1.30151660387716e+55*cos(theta)**37 + 2.75527672658038e+54*cos(theta)**35 - 5.05516389859799e+53*cos(theta)**33 + 8.00097883231336e+52*cos(theta)**31 - 1.08626427942357e+52*cos(theta)**29 + 1.25647663090019e+51*cos(theta)**27 - 1.22813505275959e+50*cos(theta)**25 + 1.00447250770959e+49*cos(theta)**23 - 6.79314473270583e+47*cos(theta)**21 + 3.74425300227881e+46*cos(theta)**19 - 1.65230261519916e+45*cos(theta)**17 + 5.70917570292394e+43*cos(theta)**15 - 1.50128587229405e+42*cos(theta)**13 + 2.89422387639485e+40*cos(theta)**11 - 3.8872359756219e+38*cos(theta)**9 + 3.38020519619296e+36*cos(theta)**7 - 1.69778304520574e+34*cos(theta)**5 + 4.0250901972635e+31*cos(theta)**3 - 2.84057176941673e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl93_m_minus_13(theta, phi):
    return 1.36316763414868e-25*(1.0 - cos(theta)**2)**6.5*(9.35211191975408e+51*cos(theta)**80 - 1.59744181980664e+53*cos(theta)**78 + 1.31068791936594e+54*cos(theta)**76 - 6.87930123424113e+54*cos(theta)**74 + 2.59511070302867e+55*cos(theta)**72 - 7.49503158976417e+55*cos(theta)**70 + 1.72385726564576e+56*cos(theta)**68 - 3.24273067806857e+56*cos(theta)**66 + 5.08454481319962e+56*cos(theta)**64 - 6.73927833228826e+56*cos(theta)**62 + 7.63112294991443e+56*cos(theta)**60 - 7.441921554462e+56*cos(theta)**58 + 6.28910855292725e+56*cos(theta)**56 - 4.62743773125082e+56*cos(theta)**54 + 2.97478139866124e+56*cos(theta)**52 - 1.67497245631626e+56*cos(theta)**50 + 8.27355346365897e+55*cos(theta)**48 - 3.58806932218659e+55*cos(theta)**46 + 1.36631778824986e+55*cos(theta)**44 - 4.56565393035806e+54*cos(theta)**42 + 1.33708436531915e+54*cos(theta)**40 - 3.42504369441358e+53*cos(theta)**38 + 7.65354646272328e+52*cos(theta)**36 - 1.48681291135235e+52*cos(theta)**34 + 2.50030588509793e+51*cos(theta)**32 - 3.62088093141189e+50*cos(theta)**30 + 4.48741653892926e+49*cos(theta)**28 - 4.72359635676764e+48*cos(theta)**26 + 4.18530211545661e+47*cos(theta)**24 - 3.08779306032083e+46*cos(theta)**22 + 1.8721265011394e+45*cos(theta)**20 - 9.17945897332869e+43*cos(theta)**18 + 3.56823481432746e+42*cos(theta)**16 - 1.07234705163861e+41*cos(theta)**14 + 2.41185323032905e+39*cos(theta)**12 - 3.8872359756219e+37*cos(theta)**10 + 4.2252564952412e+35*cos(theta)**8 - 2.82963840867624e+33*cos(theta)**6 + 1.00627254931588e+31*cos(theta)**4 - 1.42028588470836e+28*cos(theta)**2 + 3.31842496427188e+24)*sin(13*phi)

#@torch.jit.script
def Yl93_m_minus_12(theta, phi):
    return 1.26312028032232e-23*(1.0 - cos(theta)**2)**6*(1.15458171848816e+50*cos(theta)**81 - 2.0220782529198e+51*cos(theta)**79 + 1.70219210307265e+52*cos(theta)**77 - 9.17240164565485e+52*cos(theta)**75 + 3.55494616853243e+53*cos(theta)**73 - 1.05563825207946e+54*cos(theta)**71 + 2.49834386325472e+54*cos(theta)**69 - 4.8398965344307e+54*cos(theta)**67 + 7.82237663569173e+54*cos(theta)**65 - 1.06972671941083e+55*cos(theta)**63 + 1.25100376228105e+55*cos(theta)**61 - 1.26134263634949e+55*cos(theta)**59 + 1.10335237770653e+55*cos(theta)**57 - 8.41352314772876e+54*cos(theta)**55 + 5.61279509181366e+54*cos(theta)**53 - 3.28425971826719e+54*cos(theta)**51 + 1.68848029870591e+54*cos(theta)**49 - 7.63419004720551e+53*cos(theta)**47 + 3.03626175166636e+53*cos(theta)**45 - 1.0617799838042e+53*cos(theta)**43 + 3.26118137882719e+52*cos(theta)**41 - 8.78216331900917e+51*cos(theta)**39 + 2.06852607100629e+51*cos(theta)**37 - 4.24803688957814e+50*cos(theta)**35 + 7.57668450029675e+49*cos(theta)**33 - 1.16802610690706e+49*cos(theta)**31 + 1.54738501342388e+48*cos(theta)**29 - 1.74948013213616e+47*cos(theta)**27 + 1.67412084618264e+46*cos(theta)**25 - 1.34251872187862e+45*cos(theta)**23 + 8.91488810066383e+43*cos(theta)**21 - 4.83129419648878e+42*cos(theta)**19 + 2.09896165548674e+41*cos(theta)**17 - 7.14898034425737e+39*cos(theta)**15 + 1.85527171563773e+38*cos(theta)**13 - 3.533850886929e+36*cos(theta)**11 + 4.69472943915689e+34*cos(theta)**9 - 4.0423405838232e+32*cos(theta)**7 + 2.01254509863175e+30*cos(theta)**5 - 4.73428628236121e+27*cos(theta)**3 + 3.31842496427188e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl93_m_minus_11(theta, phi):
    return 1.17205039031839e-21*(1.0 - cos(theta)**2)**5.5*(1.40802648596117e+48*cos(theta)**82 - 2.52759781614975e+49*cos(theta)**80 + 2.18229756804186e+50*cos(theta)**78 - 1.20689495337564e+51*cos(theta)**76 + 4.80398130882761e+51*cos(theta)**74 - 1.46616423899925e+52*cos(theta)**72 + 3.56906266179246e+52*cos(theta)**70 - 7.11749490357456e+52*cos(theta)**68 + 1.18520858116541e+53*cos(theta)**66 - 1.67144799907943e+53*cos(theta)**64 + 2.01774800367912e+53*cos(theta)**62 - 2.10223772724915e+53*cos(theta)**60 + 1.90233168570092e+53*cos(theta)**58 - 1.50241484780871e+53*cos(theta)**56 + 1.03940649848401e+53*cos(theta)**54 - 6.31588407359074e+52*cos(theta)**52 + 3.37696059741182e+52*cos(theta)**50 - 1.59045625983448e+52*cos(theta)**48 + 6.60056902536164e+51*cos(theta)**46 - 2.41313632682773e+51*cos(theta)**44 + 7.76471756863616e+50*cos(theta)**42 - 2.19554082975229e+50*cos(theta)**40 + 5.44348966054288e+49*cos(theta)**38 - 1.18001024710504e+49*cos(theta)**36 + 2.22843661773434e+48*cos(theta)**34 - 3.65008158408456e+47*cos(theta)**32 + 5.15795004474628e+46*cos(theta)**30 - 6.24814332905773e+45*cos(theta)**28 + 6.43892633147171e+44*cos(theta)**26 - 5.5938280078276e+43*cos(theta)**24 + 4.0522218639381e+42*cos(theta)**22 - 2.41564709824439e+41*cos(theta)**20 + 1.16608980860375e+40*cos(theta)**18 - 4.46811271516086e+38*cos(theta)**16 + 1.32519408259838e+37*cos(theta)**14 - 2.9448757391075e+35*cos(theta)**12 + 4.69472943915689e+33*cos(theta)**10 - 5.052925729779e+31*cos(theta)**8 + 3.35424183105292e+29*cos(theta)**6 - 1.1835715705903e+27*cos(theta)**4 + 1.65921248213594e+24*cos(theta)**2 - 3.85415210716826e+20)*sin(11*phi)

#@torch.jit.script
def Yl93_m_minus_10(theta, phi):
    return 1.08893510723961e-19*(1.0 - cos(theta)**2)**5*(1.69641745296526e+46*cos(theta)**83 - 3.12049113104908e+47*cos(theta)**81 + 2.76240198486312e+48*cos(theta)**79 - 1.56739604334498e+49*cos(theta)**77 + 6.40530841177014e+49*cos(theta)**75 - 2.00844416301267e+50*cos(theta)**73 + 5.026848819426e+50*cos(theta)**71 - 1.03152100051805e+51*cos(theta)**69 + 1.76896803159017e+51*cos(theta)**67 - 2.5714584601222e+51*cos(theta)**65 + 3.20277460901447e+51*cos(theta)**63 - 3.44629135614615e+51*cos(theta)**61 + 3.22429099271343e+51*cos(theta)**59 - 2.63581552247142e+51*cos(theta)**57 + 1.88982999724366e+51*cos(theta)**55 - 1.19167624030014e+51*cos(theta)**53 + 6.62149136747416e+50*cos(theta)**51 - 3.24582910170302e+50*cos(theta)**49 + 1.40437638837482e+50*cos(theta)**47 - 5.36252517072829e+49*cos(theta)**45 + 1.80574827177585e+49*cos(theta)**43 - 5.35497763354218e+48*cos(theta)**41 + 1.39576657962638e+48*cos(theta)**39 - 3.18921688406767e+47*cos(theta)**37 + 6.36696176495525e+46*cos(theta)**35 - 1.10608532851047e+46*cos(theta)**33 + 1.66385485314396e+45*cos(theta)**31 - 2.1545321824337e+44*cos(theta)**29 + 2.38478753017471e+43*cos(theta)**27 - 2.23753120313104e+42*cos(theta)**25 + 1.76183559301657e+41*cos(theta)**23 - 1.15030814202114e+40*cos(theta)**21 + 6.13731478212498e+38*cos(theta)**19 - 2.62830159715345e+37*cos(theta)**17 + 8.83462721732251e+35*cos(theta)**15 - 2.26528903008269e+34*cos(theta)**13 + 4.26793585377899e+32*cos(theta)**11 - 5.61436192197667e+30*cos(theta)**9 + 4.79177404436131e+28*cos(theta)**7 - 2.3671431411806e+26*cos(theta)**5 + 5.53070827378646e+23*cos(theta)**3 - 3.85415210716826e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl93_m_minus_9(theta, phi):
    return 1.01288526919999e-17*(1.0 - cos(theta)**2)**4.5*(2.01954458686341e+44*cos(theta)**84 - 3.80547698908424e+45*cos(theta)**82 + 3.4530024810789e+46*cos(theta)**80 - 2.00948210685254e+47*cos(theta)**78 + 8.42803738390808e+47*cos(theta)**76 - 2.71411373380091e+48*cos(theta)**74 + 6.981734471425e+48*cos(theta)**72 - 1.4736014293115e+49*cos(theta)**70 + 2.6014235758679e+49*cos(theta)**68 - 3.89614918200333e+49*cos(theta)**66 + 5.00433532658512e+49*cos(theta)**64 - 5.55853444539702e+49*cos(theta)**62 + 5.37381832118904e+49*cos(theta)**60 - 4.54450952150244e+49*cos(theta)**58 + 3.37469642364939e+49*cos(theta)**56 - 2.20680785240767e+49*cos(theta)**54 + 1.27336372451426e+49*cos(theta)**52 - 6.49165820340604e+48*cos(theta)**50 + 2.92578414244754e+48*cos(theta)**48 - 1.16576634146267e+48*cos(theta)**46 + 4.10397334494512e+47*cos(theta)**44 - 1.2749946746529e+47*cos(theta)**42 + 3.48941644906595e+46*cos(theta)**40 - 8.3926760107044e+45*cos(theta)**38 + 1.76860049026535e+45*cos(theta)**36 - 3.25319214267786e+44*cos(theta)**34 + 5.19954641607488e+43*cos(theta)**32 - 7.18177394144567e+42*cos(theta)**30 + 8.51709832205252e+41*cos(theta)**28 - 8.60588924281169e+40*cos(theta)**26 + 7.34098163756903e+39*cos(theta)**24 - 5.22867337282336e+38*cos(theta)**22 + 3.06865739106249e+37*cos(theta)**20 - 1.46016755397414e+36*cos(theta)**18 + 5.52164201082657e+34*cos(theta)**16 - 1.61806359291621e+33*cos(theta)**14 + 3.55661321148249e+31*cos(theta)**12 - 5.61436192197667e+29*cos(theta)**10 + 5.98971755545164e+27*cos(theta)**8 - 3.94523856863434e+25*cos(theta)**6 + 1.38267706844661e+23*cos(theta)**4 - 1.92707605358413e+20*cos(theta)**2 + 4.45463720199753e+16)*sin(9*phi)

#@torch.jit.script
def Yl93_m_minus_8(theta, phi):
    return 9.43126187179398e-16*(1.0 - cos(theta)**2)**4*(2.3759348080746e+42*cos(theta)**85 - 4.58491203504125e+43*cos(theta)**83 + 4.26296602602333e+44*cos(theta)**81 - 2.54364823652221e+45*cos(theta)**79 + 1.09455030959845e+46*cos(theta)**77 - 3.61881831173454e+46*cos(theta)**75 + 9.56401982386987e+46*cos(theta)**73 - 2.07549497086127e+47*cos(theta)**71 + 3.77017909546072e+47*cos(theta)**69 - 5.81514803284079e+47*cos(theta)**67 + 7.69897742551556e+47*cos(theta)**65 - 8.82307054824924e+47*cos(theta)**63 + 8.80953823145745e+47*cos(theta)**61 - 7.70255851102109e+47*cos(theta)**59 + 5.92052004149015e+47*cos(theta)**57 - 4.01237791346848e+47*cos(theta)**55 + 2.40257306512125e+47*cos(theta)**53 - 1.2728741575306e+47*cos(theta)**51 + 5.9709880458113e+46*cos(theta)**49 - 2.48035391800568e+46*cos(theta)**47 + 9.1199407665447e+45*cos(theta)**45 - 2.96510389454163e+45*cos(theta)**43 + 8.51077182699011e+44*cos(theta)**41 - 2.15196820787292e+44*cos(theta)**39 + 4.78000132504148e+43*cos(theta)**37 - 9.29483469336532e+42*cos(theta)**35 + 1.5756201260833e+42*cos(theta)**33 - 2.31670127143409e+41*cos(theta)**31 + 2.93693045588018e+40*cos(theta)**29 - 3.18736638622655e+39*cos(theta)**27 + 2.93639265502761e+38*cos(theta)**25 - 2.27333624905363e+37*cos(theta)**23 + 1.46126542431547e+36*cos(theta)**21 - 7.68509238933756e+34*cos(theta)**19 + 3.24802471225092e+33*cos(theta)**17 - 1.07870906194414e+32*cos(theta)**15 + 2.73585631652499e+30*cos(theta)**13 - 5.10396538361515e+28*cos(theta)**11 + 6.6552417282796e+26*cos(theta)**9 - 5.63605509804906e+24*cos(theta)**7 + 2.76535413689323e+22*cos(theta)**5 - 6.42358684528044e+19*cos(theta)**3 + 4.45463720199753e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl93_m_minus_7(theta, phi):
    return 8.7898146311169e-14*(1.0 - cos(theta)**2)**3.5*(2.76271489311e+40*cos(theta)**86 - 5.45822861314435e+41*cos(theta)**84 + 5.19873905612601e+42*cos(theta)**82 - 3.17956029565276e+43*cos(theta)**80 + 1.40326962769032e+44*cos(theta)**78 - 4.76160304175598e+44*cos(theta)**76 + 1.29243511133377e+45*cos(theta)**74 - 2.88263190397399e+45*cos(theta)**72 + 5.38597013637245e+45*cos(theta)**70 - 8.5516882835894e+45*cos(theta)**68 + 1.16651173113872e+46*cos(theta)**66 - 1.37860477316394e+46*cos(theta)**64 + 1.4208932631383e+46*cos(theta)**62 - 1.28375975183685e+46*cos(theta)**60 + 1.0207793174983e+46*cos(theta)**58 - 7.16496055976515e+45*cos(theta)**56 + 4.44920937985417e+45*cos(theta)**54 - 2.44783491832807e+45*cos(theta)**52 + 1.19419760916226e+45*cos(theta)**50 - 5.16740399584517e+44*cos(theta)**48 + 1.98259581881407e+44*cos(theta)**46 - 6.73887248759461e+43*cos(theta)**44 + 2.02637424452146e+43*cos(theta)**42 - 5.37992051968231e+42*cos(theta)**40 + 1.25789508553723e+42*cos(theta)**38 - 2.58189852593481e+41*cos(theta)**36 + 4.63417684142146e+40*cos(theta)**34 - 7.23969147323152e+39*cos(theta)**32 + 9.78976818626727e+38*cos(theta)**30 - 1.13834513793805e+38*cos(theta)**28 + 1.12938179039523e+37*cos(theta)**26 - 9.47223437105681e+35*cos(theta)**24 + 6.64211556507032e+34*cos(theta)**22 - 3.84254619466878e+33*cos(theta)**20 + 1.80445817347273e+32*cos(theta)**18 - 6.74193163715088e+30*cos(theta)**16 + 1.95418308323214e+29*cos(theta)**14 - 4.25330448634596e+27*cos(theta)**12 + 6.6552417282796e+25*cos(theta)**10 - 7.04506887256132e+23*cos(theta)**8 + 4.60892356148872e+21*cos(theta)**6 - 1.60589671132011e+19*cos(theta)**4 + 2.22731860099877e+16*cos(theta)**2 - 5128525445541.71)*sin(7*phi)

#@torch.jit.script
def Yl93_m_minus_6(theta, phi):
    return 8.19859328708133e-12*(1.0 - cos(theta)**2)**3*(3.17553435989655e+38*cos(theta)**87 - 6.42144542722864e+39*cos(theta)**85 + 6.26354103147712e+40*cos(theta)**83 - 3.92538308105279e+41*cos(theta)**81 + 1.77629066796243e+42*cos(theta)**79 - 6.18390005422855e+42*cos(theta)**77 + 1.72324681511169e+43*cos(theta)**75 - 3.94881082736163e+43*cos(theta)**73 + 7.5858734315105e+43*cos(theta)**71 - 1.23937511356368e+44*cos(theta)**69 + 1.74106228528167e+44*cos(theta)**67 - 2.12093042025222e+44*cos(theta)**65 + 2.25538613196555e+44*cos(theta)**63 - 2.10452418333909e+44*cos(theta)**61 + 1.7301344364378e+44*cos(theta)**59 - 1.2570106245202e+44*cos(theta)**57 + 8.08947159973485e+43*cos(theta)**55 - 4.61855644967561e+43*cos(theta)**53 + 2.34156393953384e+43*cos(theta)**51 - 1.05457224405004e+43*cos(theta)**49 + 4.21828897620014e+42*cos(theta)**47 - 1.49752721946547e+42*cos(theta)**45 + 4.71249824307315e+41*cos(theta)**43 - 1.31217573650788e+41*cos(theta)**41 + 3.22537201419803e+40*cos(theta)**39 - 6.97810412414814e+39*cos(theta)**37 + 1.32405052612042e+39*cos(theta)**35 - 2.19384590097925e+38*cos(theta)**33 + 3.15798973750557e+37*cos(theta)**31 - 3.92532806185536e+36*cos(theta)**29 + 4.18289551998235e+35*cos(theta)**27 - 3.78889374842272e+34*cos(theta)**25 + 2.88787633263927e+33*cos(theta)**23 - 1.82978390222323e+32*cos(theta)**21 + 9.49714828143545e+30*cos(theta)**19 - 3.96584213950052e+29*cos(theta)**17 + 1.30278872215476e+28*cos(theta)**15 - 3.27177268180458e+26*cos(theta)**13 + 6.05021975298145e+24*cos(theta)**11 - 7.82785430284591e+22*cos(theta)**9 + 6.58417651641245e+20*cos(theta)**7 - 3.21179342264022e+18*cos(theta)**5 + 7.42439533666255e+15*cos(theta)**3 - 5128525445541.71*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl93_m_minus_5(theta, phi):
    return 7.65241080052115e-10*(1.0 - cos(theta)**2)**2.5*(3.60856177260972e+36*cos(theta)**88 - 7.4667970084054e+37*cos(theta)**86 + 7.45659646604419e+38*cos(theta)**84 - 4.78705253786925e+39*cos(theta)**82 + 2.22036333495304e+40*cos(theta)**80 - 7.9280769926007e+40*cos(theta)**78 + 2.2674300198838e+41*cos(theta)**76 - 5.33623084778599e+41*cos(theta)**74 + 1.05359353215424e+42*cos(theta)**72 - 1.77053587651954e+42*cos(theta)**70 + 2.56038571364952e+42*cos(theta)**68 - 3.21353093977609e+42*cos(theta)**66 + 3.52404083119618e+42*cos(theta)**64 - 3.39439384409531e+42*cos(theta)**62 + 2.883557394063e+42*cos(theta)**60 - 2.16725969744862e+42*cos(theta)**58 + 1.44454849995265e+42*cos(theta)**56 - 8.55288231421408e+41*cos(theta)**54 + 4.50300757602662e+41*cos(theta)**52 - 2.10914448810007e+41*cos(theta)**50 + 8.78810203375029e+40*cos(theta)**48 - 3.25549395535971e+40*cos(theta)**46 + 1.07102232797117e+40*cos(theta)**44 - 3.12422794406638e+39*cos(theta)**42 + 8.06343003549507e+38*cos(theta)**40 - 1.8363431905653e+38*cos(theta)**38 + 3.67791812811227e+37*cos(theta)**36 - 6.45248794405661e+36*cos(theta)**34 + 9.8687179297049e+35*cos(theta)**32 - 1.30844268728512e+35*cos(theta)**30 + 1.49389125713655e+34*cos(theta)**28 - 1.45726682631643e+33*cos(theta)**26 + 1.20328180526636e+32*cos(theta)**24 - 8.31719955556013e+30*cos(theta)**22 + 4.74857414071772e+29*cos(theta)**20 - 2.20324563305584e+28*cos(theta)**18 + 8.14242951346724e+26*cos(theta)**16 - 2.33698048700327e+25*cos(theta)**14 + 5.04184979415121e+23*cos(theta)**12 - 7.82785430284591e+21*cos(theta)**10 + 8.23022064551556e+19*cos(theta)**8 - 5.3529890377337e+17*cos(theta)**6 + 1.85609883416564e+15*cos(theta)**4 - 2564262722770.86*cos(theta)**2 + 588673719.644366)*sin(5*phi)

#@torch.jit.script
def Yl93_m_minus_4(theta, phi):
    return 7.14671259268717e-8*(1.0 - cos(theta)**2)**2*(4.05456378944912e+34*cos(theta)**89 - 8.5825252970177e+35*cos(theta)**87 + 8.77246643064022e+36*cos(theta)**85 - 5.76753317815573e+37*cos(theta)**83 + 2.74118930241117e+38*cos(theta)**81 - 1.00355404969629e+39*cos(theta)**79 + 2.9447143115374e+39*cos(theta)**77 - 7.11497446371465e+39*cos(theta)**75 + 1.44327881117019e+40*cos(theta)**73 - 2.4937125021402e+40*cos(theta)**71 + 3.71070393282539e+40*cos(theta)**69 - 4.79631483548671e+40*cos(theta)**67 + 5.42160127876335e+40*cos(theta)**65 - 5.38792673665923e+40*cos(theta)**63 + 4.72714326895574e+40*cos(theta)**61 - 3.67332152109936e+40*cos(theta)**59 + 2.53429561395202e+40*cos(theta)**57 - 1.55506951167529e+40*cos(theta)**55 + 8.49624070948419e+39*cos(theta)**53 - 4.1355774276472e+39*cos(theta)**51 + 1.79349021096945e+39*cos(theta)**49 - 6.92658288374407e+38*cos(theta)**47 + 2.38004961771371e+38*cos(theta)**45 - 7.26564638154973e+37*cos(theta)**43 + 1.96669025255977e+37*cos(theta)**41 - 4.70857228350077e+36*cos(theta)**39 + 9.94031926516829e+35*cos(theta)**37 - 1.84356798401617e+35*cos(theta)**35 + 2.99052058475906e+34*cos(theta)**33 - 4.22078286221006e+33*cos(theta)**31 + 5.15134916253984e+32*cos(theta)**29 - 5.39728454191271e+31*cos(theta)**27 + 4.81312722106545e+30*cos(theta)**25 - 3.61617371980875e+29*cos(theta)**23 + 2.26122578129415e+28*cos(theta)**21 - 1.15960296476623e+27*cos(theta)**19 + 4.78966441968661e+25*cos(theta)**17 - 1.55798699133552e+24*cos(theta)**15 + 3.87834599550093e+22*cos(theta)**13 - 7.11623118440538e+20*cos(theta)**11 + 9.1446896061284e+18*cos(theta)**9 - 7.64712719676243e+16*cos(theta)**7 + 371219766833128.0*cos(theta)**5 - 854754240923.619*cos(theta)**3 + 588673719.644366*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl93_m_minus_3(theta, phi):
    return 6.67749296296141e-6*(1.0 - cos(theta)**2)**1.5*(4.50507087716569e+32*cos(theta)**90 - 9.75286965570193e+33*cos(theta)**88 + 1.02005423612096e+35*cos(theta)**86 - 6.86611092637587e+35*cos(theta)**84 + 3.34291378342825e+36*cos(theta)**82 - 1.25444256212036e+37*cos(theta)**80 + 3.77527475838129e+37*cos(theta)**78 - 9.3618085048877e+37*cos(theta)**76 + 1.9503767718516e+38*cos(theta)**74 - 3.46348958630584e+38*cos(theta)**72 + 5.30100561832199e+38*cos(theta)**70 - 7.05340416983339e+38*cos(theta)**68 + 8.21454739206568e+38*cos(theta)**66 - 8.41863552603004e+38*cos(theta)**64 + 7.62442462734796e+38*cos(theta)**62 - 6.1222025351656e+38*cos(theta)**60 + 4.369475196469e+38*cos(theta)**58 - 2.7769098422773e+38*cos(theta)**56 + 1.57337790916374e+38*cos(theta)**54 - 7.95303351470615e+37*cos(theta)**52 + 3.58698042193889e+37*cos(theta)**50 - 1.44303810078002e+37*cos(theta)**48 + 5.17402090807329e+36*cos(theta)**46 - 1.65128326853403e+36*cos(theta)**44 + 4.68259583942803e+35*cos(theta)**42 - 1.17714307087519e+35*cos(theta)**40 + 2.61587349083376e+34*cos(theta)**38 - 5.12102217782271e+33*cos(theta)**36 + 8.79564877870312e+32*cos(theta)**34 - 1.31899464444064e+32*cos(theta)**32 + 1.71711638751328e+31*cos(theta)**30 - 1.92760162211168e+30*cos(theta)**28 + 1.85120277733287e+29*cos(theta)**26 - 1.50673904992031e+28*cos(theta)**24 + 1.02782990058825e+27*cos(theta)**22 - 5.79801482383116e+25*cos(theta)**20 + 2.66092467760367e+24*cos(theta)**18 - 9.73741869584698e+22*cos(theta)**16 + 2.77024713964352e+21*cos(theta)**14 - 5.93019265367115e+19*cos(theta)**12 + 9.1446896061284e+17*cos(theta)**10 - 9.55890899595304e+15*cos(theta)**8 + 61869961138854.6*cos(theta)**6 - 213688560230.905*cos(theta)**4 + 294336859.822183*cos(theta)**2 - 67431.1248160785)*sin(3*phi)

#@torch.jit.script
def Yl93_m_minus_2(theta, phi):
    return 0.000624122373893299*(1.0 - cos(theta)**2)*(4.95062733754471e+30*cos(theta)**91 - 1.09582805120246e+32*cos(theta)**89 + 1.17247613347236e+33*cos(theta)**87 - 8.0777775604422e+33*cos(theta)**85 + 4.02760696798584e+34*cos(theta)**83 - 1.54869452113625e+35*cos(theta)**81 + 4.77882880807758e+35*cos(theta)**79 - 1.21581928634905e+36*cos(theta)**77 + 2.6005023624688e+36*cos(theta)**75 - 4.74450628261074e+36*cos(theta)**73 + 7.46620509622815e+36*cos(theta)**71 - 1.02223248838165e+37*cos(theta)**69 + 1.22605184956204e+37*cos(theta)**67 - 1.29517469631231e+37*cos(theta)**65 + 1.21022613132507e+37*cos(theta)**63 - 1.00363975986321e+37*cos(theta)**61 + 7.40589016350678e+36*cos(theta)**59 - 4.87177165311807e+36*cos(theta)**57 + 2.86068710757043e+36*cos(theta)**55 - 1.50057236126531e+36*cos(theta)**53 + 7.03329494497822e+35*cos(theta)**51 - 2.94497571587758e+35*cos(theta)**49 + 1.10085551235602e+35*cos(theta)**47 - 3.66951837452006e+34*cos(theta)**45 + 1.08897577661117e+34*cos(theta)**43 - 2.8710806606712e+33*cos(theta)**41 + 6.70736792521477e+32*cos(theta)**39 - 1.38406004806019e+32*cos(theta)**37 + 2.51304250820089e+31*cos(theta)**35 - 3.99695346800195e+30*cos(theta)**33 + 5.53908512101058e+29*cos(theta)**31 - 6.6469021452127e+28*cos(theta)**29 + 6.85630658271432e+27*cos(theta)**27 - 6.02695619968126e+26*cos(theta)**25 + 4.46882565473153e+25*cos(theta)**23 - 2.7609594399196e+24*cos(theta)**21 + 1.40048667242299e+23*cos(theta)**19 - 5.72789335049822e+21*cos(theta)**17 + 1.84683142642901e+20*cos(theta)**15 - 4.56168665667011e+18*cos(theta)**13 + 8.31335418738946e+16*cos(theta)**11 - 1.06210099955034e+15*cos(theta)**9 + 8838565876979.23*cos(theta)**7 - 42737712046.1809*cos(theta)**5 + 98112286.6073942*cos(theta)**3 - 67431.1248160785*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl93_m_minus_1(theta, phi):
    return 0.0583479319819766*(1.0 - cos(theta)**2)**0.5*(5.38111667124425e+28*cos(theta)**92 - 1.21758672355829e+30*cos(theta)**90 + 1.33235924258223e+31*cos(theta)**88 - 9.39276460516535e+31*cos(theta)**86 + 4.79477019998315e+32*cos(theta)**84 - 1.88865185504421e+33*cos(theta)**82 + 5.97353601009697e+33*cos(theta)**80 - 1.55874267480648e+34*cos(theta)**78 + 3.42171363482737e+34*cos(theta)**76 - 6.411494976501e+34*cos(theta)**74 + 1.03697293003169e+35*cos(theta)**72 - 1.4603321262595e+35*cos(theta)**70 + 1.80301742582653e+35*cos(theta)**68 - 1.96238590350351e+35*cos(theta)**66 + 1.89097833019543e+35*cos(theta)**64 - 1.61877380623099e+35*cos(theta)**62 + 1.23431502725113e+35*cos(theta)**60 - 8.39960629847943e+34*cos(theta)**58 + 5.1083698349472e+34*cos(theta)**56 - 2.77883770604687e+34*cos(theta)**54 + 1.35255672018812e+34*cos(theta)**52 - 5.88995143175516e+33*cos(theta)**50 + 2.29344898407504e+33*cos(theta)**48 - 7.97721385765231e+32*cos(theta)**46 + 2.47494494684357e+32*cos(theta)**44 - 6.83590633493143e+31*cos(theta)**42 + 1.67684198130369e+31*cos(theta)**40 - 3.64226328436892e+30*cos(theta)**38 + 6.98067363389137e+29*cos(theta)**36 - 1.17557454941234e+29*cos(theta)**34 + 1.73096410031581e+28*cos(theta)**32 - 2.21563404840423e+27*cos(theta)**30 + 2.44868092239797e+26*cos(theta)**28 - 2.31806007680048e+25*cos(theta)**26 + 1.86201068947147e+24*cos(theta)**24 - 1.25498156359982e+23*cos(theta)**22 + 7.00243336211493e+21*cos(theta)**20 - 3.18216297249901e+20*cos(theta)**18 + 1.15426964151813e+19*cos(theta)**16 - 3.25834761190722e+17*cos(theta)**14 + 6.92779515615788e+15*cos(theta)**12 - 106210099955034.0*cos(theta)**10 + 1104820734622.4*cos(theta)**8 - 7122952007.69682*cos(theta)**6 + 24528071.6518486*cos(theta)**4 - 33715.5624080393*cos(theta)**2 + 7.7152316723202)*sin(phi)

#@torch.jit.script
def Yl93_m0(theta, phi):
    return 7.01221468212321e+27*cos(theta)**93 - 1.62152726541206e+29*cos(theta)**91 + 1.81424976826841e+30*cos(theta)**89 - 1.30839817542157e+31*cos(theta)**87 + 6.83619772940234e+31*cos(theta)**85 - 2.75765264338603e+32*cos(theta)**83 + 8.93742090042158e+32*cos(theta)**81 - 2.39118445230107e+33*cos(theta)**79 + 5.38540884323069e+33*cos(theta)**77 - 1.03600961704753e+34*cos(theta)**75 + 1.72151298641132e+34*cos(theta)**73 - 2.49263698528317e+34*cos(theta)**71 + 3.16677040308215e+34*cos(theta)**69 - 3.54956682543274e+34*cos(theta)**67 + 3.52564791151473e+34*cos(theta)**65 - 3.11394804923594e+34*cos(theta)**63 + 2.4522340887733e+34*cos(theta)**61 - 1.72533194250486e+34*cos(theta)**59 + 1.08610851862613e+34*cos(theta)**57 - 6.12302789024126e+33*cos(theta)**55 + 3.09275388333614e+33*cos(theta)**53 - 1.39961078858365e+33*cos(theta)**51 + 5.67229420039463e+32*cos(theta)**49 - 2.05692814667409e+32*cos(theta)**47 + 6.66528575106323e+31*cos(theta)**45 - 1.92660814410295e+31*cos(theta)**43 + 4.95648761858964e+30*cos(theta)**41 - 1.13180725347912e+30*cos(theta)**39 + 2.28644813202842e+29*cos(theta)**37 - 4.07050108508668e+28*cos(theta)**35 + 6.35681927985978e+27*cos(theta)**33 - 8.66167891552507e+26*cos(theta)**31 + 1.02329285968475e+26*cos(theta)**29 - 1.04046306294016e+25*cos(theta)**27 + 9.02626137152735e+23*cos(theta)**25 - 6.61264569342663e+22*cos(theta)**23 + 4.04106125709405e+21*cos(theta)**21 - 2.02971266201806e+20*cos(theta)**19 + 8.22856484601916e+18*cos(theta)**17 - 2.63252133394168e+17*cos(theta)**15 + 6.45828831924944e+15*cos(theta)**13 - 117014283136227.0*cos(theta)**11 + 1487698930303.39*cos(theta)**9 - 12331835480.2952*cos(theta)**7 + 59450997.4945361*cos(theta)**5 - 136199.306974882*cos(theta)**3 + 93.5006684038094*cos(theta)

#@torch.jit.script
def Yl93_m1(theta, phi):
    return 0.0583479319819766*(1.0 - cos(theta)**2)**0.5*(5.38111667124425e+28*cos(theta)**92 - 1.21758672355829e+30*cos(theta)**90 + 1.33235924258223e+31*cos(theta)**88 - 9.39276460516535e+31*cos(theta)**86 + 4.79477019998315e+32*cos(theta)**84 - 1.88865185504421e+33*cos(theta)**82 + 5.97353601009697e+33*cos(theta)**80 - 1.55874267480648e+34*cos(theta)**78 + 3.42171363482737e+34*cos(theta)**76 - 6.411494976501e+34*cos(theta)**74 + 1.03697293003169e+35*cos(theta)**72 - 1.4603321262595e+35*cos(theta)**70 + 1.80301742582653e+35*cos(theta)**68 - 1.96238590350351e+35*cos(theta)**66 + 1.89097833019543e+35*cos(theta)**64 - 1.61877380623099e+35*cos(theta)**62 + 1.23431502725113e+35*cos(theta)**60 - 8.39960629847943e+34*cos(theta)**58 + 5.1083698349472e+34*cos(theta)**56 - 2.77883770604687e+34*cos(theta)**54 + 1.35255672018812e+34*cos(theta)**52 - 5.88995143175516e+33*cos(theta)**50 + 2.29344898407504e+33*cos(theta)**48 - 7.97721385765231e+32*cos(theta)**46 + 2.47494494684357e+32*cos(theta)**44 - 6.83590633493143e+31*cos(theta)**42 + 1.67684198130369e+31*cos(theta)**40 - 3.64226328436892e+30*cos(theta)**38 + 6.98067363389137e+29*cos(theta)**36 - 1.17557454941234e+29*cos(theta)**34 + 1.73096410031581e+28*cos(theta)**32 - 2.21563404840423e+27*cos(theta)**30 + 2.44868092239797e+26*cos(theta)**28 - 2.31806007680048e+25*cos(theta)**26 + 1.86201068947147e+24*cos(theta)**24 - 1.25498156359982e+23*cos(theta)**22 + 7.00243336211493e+21*cos(theta)**20 - 3.18216297249901e+20*cos(theta)**18 + 1.15426964151813e+19*cos(theta)**16 - 3.25834761190722e+17*cos(theta)**14 + 6.92779515615788e+15*cos(theta)**12 - 106210099955034.0*cos(theta)**10 + 1104820734622.4*cos(theta)**8 - 7122952007.69682*cos(theta)**6 + 24528071.6518486*cos(theta)**4 - 33715.5624080393*cos(theta)**2 + 7.7152316723202)*cos(phi)

#@torch.jit.script
def Yl93_m2(theta, phi):
    return 0.000624122373893299*(1.0 - cos(theta)**2)*(4.95062733754471e+30*cos(theta)**91 - 1.09582805120246e+32*cos(theta)**89 + 1.17247613347236e+33*cos(theta)**87 - 8.0777775604422e+33*cos(theta)**85 + 4.02760696798584e+34*cos(theta)**83 - 1.54869452113625e+35*cos(theta)**81 + 4.77882880807758e+35*cos(theta)**79 - 1.21581928634905e+36*cos(theta)**77 + 2.6005023624688e+36*cos(theta)**75 - 4.74450628261074e+36*cos(theta)**73 + 7.46620509622815e+36*cos(theta)**71 - 1.02223248838165e+37*cos(theta)**69 + 1.22605184956204e+37*cos(theta)**67 - 1.29517469631231e+37*cos(theta)**65 + 1.21022613132507e+37*cos(theta)**63 - 1.00363975986321e+37*cos(theta)**61 + 7.40589016350678e+36*cos(theta)**59 - 4.87177165311807e+36*cos(theta)**57 + 2.86068710757043e+36*cos(theta)**55 - 1.50057236126531e+36*cos(theta)**53 + 7.03329494497822e+35*cos(theta)**51 - 2.94497571587758e+35*cos(theta)**49 + 1.10085551235602e+35*cos(theta)**47 - 3.66951837452006e+34*cos(theta)**45 + 1.08897577661117e+34*cos(theta)**43 - 2.8710806606712e+33*cos(theta)**41 + 6.70736792521477e+32*cos(theta)**39 - 1.38406004806019e+32*cos(theta)**37 + 2.51304250820089e+31*cos(theta)**35 - 3.99695346800195e+30*cos(theta)**33 + 5.53908512101058e+29*cos(theta)**31 - 6.6469021452127e+28*cos(theta)**29 + 6.85630658271432e+27*cos(theta)**27 - 6.02695619968126e+26*cos(theta)**25 + 4.46882565473153e+25*cos(theta)**23 - 2.7609594399196e+24*cos(theta)**21 + 1.40048667242299e+23*cos(theta)**19 - 5.72789335049822e+21*cos(theta)**17 + 1.84683142642901e+20*cos(theta)**15 - 4.56168665667011e+18*cos(theta)**13 + 8.31335418738946e+16*cos(theta)**11 - 1.06210099955034e+15*cos(theta)**9 + 8838565876979.23*cos(theta)**7 - 42737712046.1809*cos(theta)**5 + 98112286.6073942*cos(theta)**3 - 67431.1248160785*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl93_m3(theta, phi):
    return 6.67749296296141e-6*(1.0 - cos(theta)**2)**1.5*(4.50507087716569e+32*cos(theta)**90 - 9.75286965570193e+33*cos(theta)**88 + 1.02005423612096e+35*cos(theta)**86 - 6.86611092637587e+35*cos(theta)**84 + 3.34291378342825e+36*cos(theta)**82 - 1.25444256212036e+37*cos(theta)**80 + 3.77527475838129e+37*cos(theta)**78 - 9.3618085048877e+37*cos(theta)**76 + 1.9503767718516e+38*cos(theta)**74 - 3.46348958630584e+38*cos(theta)**72 + 5.30100561832199e+38*cos(theta)**70 - 7.05340416983339e+38*cos(theta)**68 + 8.21454739206568e+38*cos(theta)**66 - 8.41863552603004e+38*cos(theta)**64 + 7.62442462734796e+38*cos(theta)**62 - 6.1222025351656e+38*cos(theta)**60 + 4.369475196469e+38*cos(theta)**58 - 2.7769098422773e+38*cos(theta)**56 + 1.57337790916374e+38*cos(theta)**54 - 7.95303351470615e+37*cos(theta)**52 + 3.58698042193889e+37*cos(theta)**50 - 1.44303810078002e+37*cos(theta)**48 + 5.17402090807329e+36*cos(theta)**46 - 1.65128326853403e+36*cos(theta)**44 + 4.68259583942803e+35*cos(theta)**42 - 1.17714307087519e+35*cos(theta)**40 + 2.61587349083376e+34*cos(theta)**38 - 5.12102217782271e+33*cos(theta)**36 + 8.79564877870312e+32*cos(theta)**34 - 1.31899464444064e+32*cos(theta)**32 + 1.71711638751328e+31*cos(theta)**30 - 1.92760162211168e+30*cos(theta)**28 + 1.85120277733287e+29*cos(theta)**26 - 1.50673904992031e+28*cos(theta)**24 + 1.02782990058825e+27*cos(theta)**22 - 5.79801482383116e+25*cos(theta)**20 + 2.66092467760367e+24*cos(theta)**18 - 9.73741869584698e+22*cos(theta)**16 + 2.77024713964352e+21*cos(theta)**14 - 5.93019265367115e+19*cos(theta)**12 + 9.1446896061284e+17*cos(theta)**10 - 9.55890899595304e+15*cos(theta)**8 + 61869961138854.6*cos(theta)**6 - 213688560230.905*cos(theta)**4 + 294336859.822183*cos(theta)**2 - 67431.1248160785)*cos(3*phi)

#@torch.jit.script
def Yl93_m4(theta, phi):
    return 7.14671259268717e-8*(1.0 - cos(theta)**2)**2*(4.05456378944912e+34*cos(theta)**89 - 8.5825252970177e+35*cos(theta)**87 + 8.77246643064022e+36*cos(theta)**85 - 5.76753317815573e+37*cos(theta)**83 + 2.74118930241117e+38*cos(theta)**81 - 1.00355404969629e+39*cos(theta)**79 + 2.9447143115374e+39*cos(theta)**77 - 7.11497446371465e+39*cos(theta)**75 + 1.44327881117019e+40*cos(theta)**73 - 2.4937125021402e+40*cos(theta)**71 + 3.71070393282539e+40*cos(theta)**69 - 4.79631483548671e+40*cos(theta)**67 + 5.42160127876335e+40*cos(theta)**65 - 5.38792673665923e+40*cos(theta)**63 + 4.72714326895574e+40*cos(theta)**61 - 3.67332152109936e+40*cos(theta)**59 + 2.53429561395202e+40*cos(theta)**57 - 1.55506951167529e+40*cos(theta)**55 + 8.49624070948419e+39*cos(theta)**53 - 4.1355774276472e+39*cos(theta)**51 + 1.79349021096945e+39*cos(theta)**49 - 6.92658288374407e+38*cos(theta)**47 + 2.38004961771371e+38*cos(theta)**45 - 7.26564638154973e+37*cos(theta)**43 + 1.96669025255977e+37*cos(theta)**41 - 4.70857228350077e+36*cos(theta)**39 + 9.94031926516829e+35*cos(theta)**37 - 1.84356798401617e+35*cos(theta)**35 + 2.99052058475906e+34*cos(theta)**33 - 4.22078286221006e+33*cos(theta)**31 + 5.15134916253984e+32*cos(theta)**29 - 5.39728454191271e+31*cos(theta)**27 + 4.81312722106545e+30*cos(theta)**25 - 3.61617371980875e+29*cos(theta)**23 + 2.26122578129415e+28*cos(theta)**21 - 1.15960296476623e+27*cos(theta)**19 + 4.78966441968661e+25*cos(theta)**17 - 1.55798699133552e+24*cos(theta)**15 + 3.87834599550093e+22*cos(theta)**13 - 7.11623118440538e+20*cos(theta)**11 + 9.1446896061284e+18*cos(theta)**9 - 7.64712719676243e+16*cos(theta)**7 + 371219766833128.0*cos(theta)**5 - 854754240923.619*cos(theta)**3 + 588673719.644366*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl93_m5(theta, phi):
    return 7.65241080052115e-10*(1.0 - cos(theta)**2)**2.5*(3.60856177260972e+36*cos(theta)**88 - 7.4667970084054e+37*cos(theta)**86 + 7.45659646604419e+38*cos(theta)**84 - 4.78705253786925e+39*cos(theta)**82 + 2.22036333495304e+40*cos(theta)**80 - 7.9280769926007e+40*cos(theta)**78 + 2.2674300198838e+41*cos(theta)**76 - 5.33623084778599e+41*cos(theta)**74 + 1.05359353215424e+42*cos(theta)**72 - 1.77053587651954e+42*cos(theta)**70 + 2.56038571364952e+42*cos(theta)**68 - 3.21353093977609e+42*cos(theta)**66 + 3.52404083119618e+42*cos(theta)**64 - 3.39439384409531e+42*cos(theta)**62 + 2.883557394063e+42*cos(theta)**60 - 2.16725969744862e+42*cos(theta)**58 + 1.44454849995265e+42*cos(theta)**56 - 8.55288231421408e+41*cos(theta)**54 + 4.50300757602662e+41*cos(theta)**52 - 2.10914448810007e+41*cos(theta)**50 + 8.78810203375029e+40*cos(theta)**48 - 3.25549395535971e+40*cos(theta)**46 + 1.07102232797117e+40*cos(theta)**44 - 3.12422794406638e+39*cos(theta)**42 + 8.06343003549507e+38*cos(theta)**40 - 1.8363431905653e+38*cos(theta)**38 + 3.67791812811227e+37*cos(theta)**36 - 6.45248794405661e+36*cos(theta)**34 + 9.8687179297049e+35*cos(theta)**32 - 1.30844268728512e+35*cos(theta)**30 + 1.49389125713655e+34*cos(theta)**28 - 1.45726682631643e+33*cos(theta)**26 + 1.20328180526636e+32*cos(theta)**24 - 8.31719955556013e+30*cos(theta)**22 + 4.74857414071772e+29*cos(theta)**20 - 2.20324563305584e+28*cos(theta)**18 + 8.14242951346724e+26*cos(theta)**16 - 2.33698048700327e+25*cos(theta)**14 + 5.04184979415121e+23*cos(theta)**12 - 7.82785430284591e+21*cos(theta)**10 + 8.23022064551556e+19*cos(theta)**8 - 5.3529890377337e+17*cos(theta)**6 + 1.85609883416564e+15*cos(theta)**4 - 2564262722770.86*cos(theta)**2 + 588673719.644366)*cos(5*phi)

#@torch.jit.script
def Yl93_m6(theta, phi):
    return 8.19859328708133e-12*(1.0 - cos(theta)**2)**3*(3.17553435989655e+38*cos(theta)**87 - 6.42144542722864e+39*cos(theta)**85 + 6.26354103147712e+40*cos(theta)**83 - 3.92538308105279e+41*cos(theta)**81 + 1.77629066796243e+42*cos(theta)**79 - 6.18390005422855e+42*cos(theta)**77 + 1.72324681511169e+43*cos(theta)**75 - 3.94881082736163e+43*cos(theta)**73 + 7.5858734315105e+43*cos(theta)**71 - 1.23937511356368e+44*cos(theta)**69 + 1.74106228528167e+44*cos(theta)**67 - 2.12093042025222e+44*cos(theta)**65 + 2.25538613196555e+44*cos(theta)**63 - 2.10452418333909e+44*cos(theta)**61 + 1.7301344364378e+44*cos(theta)**59 - 1.2570106245202e+44*cos(theta)**57 + 8.08947159973485e+43*cos(theta)**55 - 4.61855644967561e+43*cos(theta)**53 + 2.34156393953384e+43*cos(theta)**51 - 1.05457224405004e+43*cos(theta)**49 + 4.21828897620014e+42*cos(theta)**47 - 1.49752721946547e+42*cos(theta)**45 + 4.71249824307315e+41*cos(theta)**43 - 1.31217573650788e+41*cos(theta)**41 + 3.22537201419803e+40*cos(theta)**39 - 6.97810412414814e+39*cos(theta)**37 + 1.32405052612042e+39*cos(theta)**35 - 2.19384590097925e+38*cos(theta)**33 + 3.15798973750557e+37*cos(theta)**31 - 3.92532806185536e+36*cos(theta)**29 + 4.18289551998235e+35*cos(theta)**27 - 3.78889374842272e+34*cos(theta)**25 + 2.88787633263927e+33*cos(theta)**23 - 1.82978390222323e+32*cos(theta)**21 + 9.49714828143545e+30*cos(theta)**19 - 3.96584213950052e+29*cos(theta)**17 + 1.30278872215476e+28*cos(theta)**15 - 3.27177268180458e+26*cos(theta)**13 + 6.05021975298145e+24*cos(theta)**11 - 7.82785430284591e+22*cos(theta)**9 + 6.58417651641245e+20*cos(theta)**7 - 3.21179342264022e+18*cos(theta)**5 + 7.42439533666255e+15*cos(theta)**3 - 5128525445541.71*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl93_m7(theta, phi):
    return 8.7898146311169e-14*(1.0 - cos(theta)**2)**3.5*(2.76271489311e+40*cos(theta)**86 - 5.45822861314435e+41*cos(theta)**84 + 5.19873905612601e+42*cos(theta)**82 - 3.17956029565276e+43*cos(theta)**80 + 1.40326962769032e+44*cos(theta)**78 - 4.76160304175598e+44*cos(theta)**76 + 1.29243511133377e+45*cos(theta)**74 - 2.88263190397399e+45*cos(theta)**72 + 5.38597013637245e+45*cos(theta)**70 - 8.5516882835894e+45*cos(theta)**68 + 1.16651173113872e+46*cos(theta)**66 - 1.37860477316394e+46*cos(theta)**64 + 1.4208932631383e+46*cos(theta)**62 - 1.28375975183685e+46*cos(theta)**60 + 1.0207793174983e+46*cos(theta)**58 - 7.16496055976515e+45*cos(theta)**56 + 4.44920937985417e+45*cos(theta)**54 - 2.44783491832807e+45*cos(theta)**52 + 1.19419760916226e+45*cos(theta)**50 - 5.16740399584517e+44*cos(theta)**48 + 1.98259581881407e+44*cos(theta)**46 - 6.73887248759461e+43*cos(theta)**44 + 2.02637424452146e+43*cos(theta)**42 - 5.37992051968231e+42*cos(theta)**40 + 1.25789508553723e+42*cos(theta)**38 - 2.58189852593481e+41*cos(theta)**36 + 4.63417684142146e+40*cos(theta)**34 - 7.23969147323152e+39*cos(theta)**32 + 9.78976818626727e+38*cos(theta)**30 - 1.13834513793805e+38*cos(theta)**28 + 1.12938179039523e+37*cos(theta)**26 - 9.47223437105681e+35*cos(theta)**24 + 6.64211556507032e+34*cos(theta)**22 - 3.84254619466878e+33*cos(theta)**20 + 1.80445817347273e+32*cos(theta)**18 - 6.74193163715088e+30*cos(theta)**16 + 1.95418308323214e+29*cos(theta)**14 - 4.25330448634596e+27*cos(theta)**12 + 6.6552417282796e+25*cos(theta)**10 - 7.04506887256132e+23*cos(theta)**8 + 4.60892356148872e+21*cos(theta)**6 - 1.60589671132011e+19*cos(theta)**4 + 2.22731860099877e+16*cos(theta)**2 - 5128525445541.71)*cos(7*phi)

#@torch.jit.script
def Yl93_m8(theta, phi):
    return 9.43126187179398e-16*(1.0 - cos(theta)**2)**4*(2.3759348080746e+42*cos(theta)**85 - 4.58491203504125e+43*cos(theta)**83 + 4.26296602602333e+44*cos(theta)**81 - 2.54364823652221e+45*cos(theta)**79 + 1.09455030959845e+46*cos(theta)**77 - 3.61881831173454e+46*cos(theta)**75 + 9.56401982386987e+46*cos(theta)**73 - 2.07549497086127e+47*cos(theta)**71 + 3.77017909546072e+47*cos(theta)**69 - 5.81514803284079e+47*cos(theta)**67 + 7.69897742551556e+47*cos(theta)**65 - 8.82307054824924e+47*cos(theta)**63 + 8.80953823145745e+47*cos(theta)**61 - 7.70255851102109e+47*cos(theta)**59 + 5.92052004149015e+47*cos(theta)**57 - 4.01237791346848e+47*cos(theta)**55 + 2.40257306512125e+47*cos(theta)**53 - 1.2728741575306e+47*cos(theta)**51 + 5.9709880458113e+46*cos(theta)**49 - 2.48035391800568e+46*cos(theta)**47 + 9.1199407665447e+45*cos(theta)**45 - 2.96510389454163e+45*cos(theta)**43 + 8.51077182699011e+44*cos(theta)**41 - 2.15196820787292e+44*cos(theta)**39 + 4.78000132504148e+43*cos(theta)**37 - 9.29483469336532e+42*cos(theta)**35 + 1.5756201260833e+42*cos(theta)**33 - 2.31670127143409e+41*cos(theta)**31 + 2.93693045588018e+40*cos(theta)**29 - 3.18736638622655e+39*cos(theta)**27 + 2.93639265502761e+38*cos(theta)**25 - 2.27333624905363e+37*cos(theta)**23 + 1.46126542431547e+36*cos(theta)**21 - 7.68509238933756e+34*cos(theta)**19 + 3.24802471225092e+33*cos(theta)**17 - 1.07870906194414e+32*cos(theta)**15 + 2.73585631652499e+30*cos(theta)**13 - 5.10396538361515e+28*cos(theta)**11 + 6.6552417282796e+26*cos(theta)**9 - 5.63605509804906e+24*cos(theta)**7 + 2.76535413689323e+22*cos(theta)**5 - 6.42358684528044e+19*cos(theta)**3 + 4.45463720199753e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl93_m9(theta, phi):
    return 1.01288526919999e-17*(1.0 - cos(theta)**2)**4.5*(2.01954458686341e+44*cos(theta)**84 - 3.80547698908424e+45*cos(theta)**82 + 3.4530024810789e+46*cos(theta)**80 - 2.00948210685254e+47*cos(theta)**78 + 8.42803738390808e+47*cos(theta)**76 - 2.71411373380091e+48*cos(theta)**74 + 6.981734471425e+48*cos(theta)**72 - 1.4736014293115e+49*cos(theta)**70 + 2.6014235758679e+49*cos(theta)**68 - 3.89614918200333e+49*cos(theta)**66 + 5.00433532658512e+49*cos(theta)**64 - 5.55853444539702e+49*cos(theta)**62 + 5.37381832118904e+49*cos(theta)**60 - 4.54450952150244e+49*cos(theta)**58 + 3.37469642364939e+49*cos(theta)**56 - 2.20680785240767e+49*cos(theta)**54 + 1.27336372451426e+49*cos(theta)**52 - 6.49165820340604e+48*cos(theta)**50 + 2.92578414244754e+48*cos(theta)**48 - 1.16576634146267e+48*cos(theta)**46 + 4.10397334494512e+47*cos(theta)**44 - 1.2749946746529e+47*cos(theta)**42 + 3.48941644906595e+46*cos(theta)**40 - 8.3926760107044e+45*cos(theta)**38 + 1.76860049026535e+45*cos(theta)**36 - 3.25319214267786e+44*cos(theta)**34 + 5.19954641607488e+43*cos(theta)**32 - 7.18177394144567e+42*cos(theta)**30 + 8.51709832205252e+41*cos(theta)**28 - 8.60588924281169e+40*cos(theta)**26 + 7.34098163756903e+39*cos(theta)**24 - 5.22867337282336e+38*cos(theta)**22 + 3.06865739106249e+37*cos(theta)**20 - 1.46016755397414e+36*cos(theta)**18 + 5.52164201082657e+34*cos(theta)**16 - 1.61806359291621e+33*cos(theta)**14 + 3.55661321148249e+31*cos(theta)**12 - 5.61436192197667e+29*cos(theta)**10 + 5.98971755545164e+27*cos(theta)**8 - 3.94523856863434e+25*cos(theta)**6 + 1.38267706844661e+23*cos(theta)**4 - 1.92707605358413e+20*cos(theta)**2 + 4.45463720199753e+16)*cos(9*phi)

#@torch.jit.script
def Yl93_m10(theta, phi):
    return 1.08893510723961e-19*(1.0 - cos(theta)**2)**5*(1.69641745296526e+46*cos(theta)**83 - 3.12049113104908e+47*cos(theta)**81 + 2.76240198486312e+48*cos(theta)**79 - 1.56739604334498e+49*cos(theta)**77 + 6.40530841177014e+49*cos(theta)**75 - 2.00844416301267e+50*cos(theta)**73 + 5.026848819426e+50*cos(theta)**71 - 1.03152100051805e+51*cos(theta)**69 + 1.76896803159017e+51*cos(theta)**67 - 2.5714584601222e+51*cos(theta)**65 + 3.20277460901447e+51*cos(theta)**63 - 3.44629135614615e+51*cos(theta)**61 + 3.22429099271343e+51*cos(theta)**59 - 2.63581552247142e+51*cos(theta)**57 + 1.88982999724366e+51*cos(theta)**55 - 1.19167624030014e+51*cos(theta)**53 + 6.62149136747416e+50*cos(theta)**51 - 3.24582910170302e+50*cos(theta)**49 + 1.40437638837482e+50*cos(theta)**47 - 5.36252517072829e+49*cos(theta)**45 + 1.80574827177585e+49*cos(theta)**43 - 5.35497763354218e+48*cos(theta)**41 + 1.39576657962638e+48*cos(theta)**39 - 3.18921688406767e+47*cos(theta)**37 + 6.36696176495525e+46*cos(theta)**35 - 1.10608532851047e+46*cos(theta)**33 + 1.66385485314396e+45*cos(theta)**31 - 2.1545321824337e+44*cos(theta)**29 + 2.38478753017471e+43*cos(theta)**27 - 2.23753120313104e+42*cos(theta)**25 + 1.76183559301657e+41*cos(theta)**23 - 1.15030814202114e+40*cos(theta)**21 + 6.13731478212498e+38*cos(theta)**19 - 2.62830159715345e+37*cos(theta)**17 + 8.83462721732251e+35*cos(theta)**15 - 2.26528903008269e+34*cos(theta)**13 + 4.26793585377899e+32*cos(theta)**11 - 5.61436192197667e+30*cos(theta)**9 + 4.79177404436131e+28*cos(theta)**7 - 2.3671431411806e+26*cos(theta)**5 + 5.53070827378646e+23*cos(theta)**3 - 3.85415210716826e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl93_m11(theta, phi):
    return 1.17205039031839e-21*(1.0 - cos(theta)**2)**5.5*(1.40802648596117e+48*cos(theta)**82 - 2.52759781614975e+49*cos(theta)**80 + 2.18229756804186e+50*cos(theta)**78 - 1.20689495337564e+51*cos(theta)**76 + 4.80398130882761e+51*cos(theta)**74 - 1.46616423899925e+52*cos(theta)**72 + 3.56906266179246e+52*cos(theta)**70 - 7.11749490357456e+52*cos(theta)**68 + 1.18520858116541e+53*cos(theta)**66 - 1.67144799907943e+53*cos(theta)**64 + 2.01774800367912e+53*cos(theta)**62 - 2.10223772724915e+53*cos(theta)**60 + 1.90233168570092e+53*cos(theta)**58 - 1.50241484780871e+53*cos(theta)**56 + 1.03940649848401e+53*cos(theta)**54 - 6.31588407359074e+52*cos(theta)**52 + 3.37696059741182e+52*cos(theta)**50 - 1.59045625983448e+52*cos(theta)**48 + 6.60056902536164e+51*cos(theta)**46 - 2.41313632682773e+51*cos(theta)**44 + 7.76471756863616e+50*cos(theta)**42 - 2.19554082975229e+50*cos(theta)**40 + 5.44348966054288e+49*cos(theta)**38 - 1.18001024710504e+49*cos(theta)**36 + 2.22843661773434e+48*cos(theta)**34 - 3.65008158408456e+47*cos(theta)**32 + 5.15795004474628e+46*cos(theta)**30 - 6.24814332905773e+45*cos(theta)**28 + 6.43892633147171e+44*cos(theta)**26 - 5.5938280078276e+43*cos(theta)**24 + 4.0522218639381e+42*cos(theta)**22 - 2.41564709824439e+41*cos(theta)**20 + 1.16608980860375e+40*cos(theta)**18 - 4.46811271516086e+38*cos(theta)**16 + 1.32519408259838e+37*cos(theta)**14 - 2.9448757391075e+35*cos(theta)**12 + 4.69472943915689e+33*cos(theta)**10 - 5.052925729779e+31*cos(theta)**8 + 3.35424183105292e+29*cos(theta)**6 - 1.1835715705903e+27*cos(theta)**4 + 1.65921248213594e+24*cos(theta)**2 - 3.85415210716826e+20)*cos(11*phi)

#@torch.jit.script
def Yl93_m12(theta, phi):
    return 1.26312028032232e-23*(1.0 - cos(theta)**2)**6*(1.15458171848816e+50*cos(theta)**81 - 2.0220782529198e+51*cos(theta)**79 + 1.70219210307265e+52*cos(theta)**77 - 9.17240164565485e+52*cos(theta)**75 + 3.55494616853243e+53*cos(theta)**73 - 1.05563825207946e+54*cos(theta)**71 + 2.49834386325472e+54*cos(theta)**69 - 4.8398965344307e+54*cos(theta)**67 + 7.82237663569173e+54*cos(theta)**65 - 1.06972671941083e+55*cos(theta)**63 + 1.25100376228105e+55*cos(theta)**61 - 1.26134263634949e+55*cos(theta)**59 + 1.10335237770653e+55*cos(theta)**57 - 8.41352314772876e+54*cos(theta)**55 + 5.61279509181366e+54*cos(theta)**53 - 3.28425971826719e+54*cos(theta)**51 + 1.68848029870591e+54*cos(theta)**49 - 7.63419004720551e+53*cos(theta)**47 + 3.03626175166636e+53*cos(theta)**45 - 1.0617799838042e+53*cos(theta)**43 + 3.26118137882719e+52*cos(theta)**41 - 8.78216331900917e+51*cos(theta)**39 + 2.06852607100629e+51*cos(theta)**37 - 4.24803688957814e+50*cos(theta)**35 + 7.57668450029675e+49*cos(theta)**33 - 1.16802610690706e+49*cos(theta)**31 + 1.54738501342388e+48*cos(theta)**29 - 1.74948013213616e+47*cos(theta)**27 + 1.67412084618264e+46*cos(theta)**25 - 1.34251872187862e+45*cos(theta)**23 + 8.91488810066383e+43*cos(theta)**21 - 4.83129419648878e+42*cos(theta)**19 + 2.09896165548674e+41*cos(theta)**17 - 7.14898034425737e+39*cos(theta)**15 + 1.85527171563773e+38*cos(theta)**13 - 3.533850886929e+36*cos(theta)**11 + 4.69472943915689e+34*cos(theta)**9 - 4.0423405838232e+32*cos(theta)**7 + 2.01254509863175e+30*cos(theta)**5 - 4.73428628236121e+27*cos(theta)**3 + 3.31842496427188e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl93_m13(theta, phi):
    return 1.36316763414868e-25*(1.0 - cos(theta)**2)**6.5*(9.35211191975408e+51*cos(theta)**80 - 1.59744181980664e+53*cos(theta)**78 + 1.31068791936594e+54*cos(theta)**76 - 6.87930123424113e+54*cos(theta)**74 + 2.59511070302867e+55*cos(theta)**72 - 7.49503158976417e+55*cos(theta)**70 + 1.72385726564576e+56*cos(theta)**68 - 3.24273067806857e+56*cos(theta)**66 + 5.08454481319962e+56*cos(theta)**64 - 6.73927833228826e+56*cos(theta)**62 + 7.63112294991443e+56*cos(theta)**60 - 7.441921554462e+56*cos(theta)**58 + 6.28910855292725e+56*cos(theta)**56 - 4.62743773125082e+56*cos(theta)**54 + 2.97478139866124e+56*cos(theta)**52 - 1.67497245631626e+56*cos(theta)**50 + 8.27355346365897e+55*cos(theta)**48 - 3.58806932218659e+55*cos(theta)**46 + 1.36631778824986e+55*cos(theta)**44 - 4.56565393035806e+54*cos(theta)**42 + 1.33708436531915e+54*cos(theta)**40 - 3.42504369441358e+53*cos(theta)**38 + 7.65354646272328e+52*cos(theta)**36 - 1.48681291135235e+52*cos(theta)**34 + 2.50030588509793e+51*cos(theta)**32 - 3.62088093141189e+50*cos(theta)**30 + 4.48741653892926e+49*cos(theta)**28 - 4.72359635676764e+48*cos(theta)**26 + 4.18530211545661e+47*cos(theta)**24 - 3.08779306032083e+46*cos(theta)**22 + 1.8721265011394e+45*cos(theta)**20 - 9.17945897332869e+43*cos(theta)**18 + 3.56823481432746e+42*cos(theta)**16 - 1.07234705163861e+41*cos(theta)**14 + 2.41185323032905e+39*cos(theta)**12 - 3.8872359756219e+37*cos(theta)**10 + 4.2252564952412e+35*cos(theta)**8 - 2.82963840867624e+33*cos(theta)**6 + 1.00627254931588e+31*cos(theta)**4 - 1.42028588470836e+28*cos(theta)**2 + 3.31842496427188e+24)*cos(13*phi)

#@torch.jit.script
def Yl93_m14(theta, phi):
    return 1.47337190313315e-27*(1.0 - cos(theta)**2)**7*(7.48168953580327e+53*cos(theta)**79 - 1.24600461944918e+55*cos(theta)**77 + 9.96122818718116e+55*cos(theta)**75 - 5.09068291333844e+56*cos(theta)**73 + 1.86847970618065e+57*cos(theta)**71 - 5.24652211283492e+57*cos(theta)**69 + 1.17222294063912e+58*cos(theta)**67 - 2.14020224752526e+58*cos(theta)**65 + 3.25410868044776e+58*cos(theta)**63 - 4.17835256601872e+58*cos(theta)**61 + 4.57867376994866e+58*cos(theta)**59 - 4.31631450158796e+58*cos(theta)**57 + 3.52190078963926e+58*cos(theta)**55 - 2.49881637487544e+58*cos(theta)**53 + 1.54688632730384e+58*cos(theta)**51 - 8.37486228158132e+57*cos(theta)**49 + 3.97130566255631e+57*cos(theta)**47 - 1.65051188820583e+57*cos(theta)**45 + 6.01179826829938e+56*cos(theta)**43 - 1.91757465075039e+56*cos(theta)**41 + 5.34833746127659e+55*cos(theta)**39 - 1.30151660387716e+55*cos(theta)**37 + 2.75527672658038e+54*cos(theta)**35 - 5.05516389859799e+53*cos(theta)**33 + 8.00097883231336e+52*cos(theta)**31 - 1.08626427942357e+52*cos(theta)**29 + 1.25647663090019e+51*cos(theta)**27 - 1.22813505275959e+50*cos(theta)**25 + 1.00447250770959e+49*cos(theta)**23 - 6.79314473270583e+47*cos(theta)**21 + 3.74425300227881e+46*cos(theta)**19 - 1.65230261519916e+45*cos(theta)**17 + 5.70917570292394e+43*cos(theta)**15 - 1.50128587229405e+42*cos(theta)**13 + 2.89422387639485e+40*cos(theta)**11 - 3.8872359756219e+38*cos(theta)**9 + 3.38020519619296e+36*cos(theta)**7 - 1.69778304520574e+34*cos(theta)**5 + 4.0250901972635e+31*cos(theta)**3 - 2.84057176941673e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl93_m15(theta, phi):
    return 1.59509649345119e-29*(1.0 - cos(theta)**2)**7.5*(5.91053473328458e+55*cos(theta)**78 - 9.5942355697587e+56*cos(theta)**76 + 7.47092114038587e+57*cos(theta)**74 - 3.71619852673706e+58*cos(theta)**72 + 1.32662059138826e+59*cos(theta)**70 - 3.62010025785609e+59*cos(theta)**68 + 7.85389370228208e+59*cos(theta)**66 - 1.39113146089142e+60*cos(theta)**64 + 2.05008846868209e+60*cos(theta)**62 - 2.54879506527142e+60*cos(theta)**60 + 2.70141752426971e+60*cos(theta)**58 - 2.46029926590514e+60*cos(theta)**56 + 1.93704543430159e+60*cos(theta)**54 - 1.32437267868398e+60*cos(theta)**52 + 7.88912026924961e+59*cos(theta)**50 - 4.10368251797485e+59*cos(theta)**48 + 1.86651366140146e+59*cos(theta)**46 - 7.42730349692624e+58*cos(theta)**44 + 2.58507325536874e+58*cos(theta)**42 - 7.86205606807658e+57*cos(theta)**40 + 2.08585160989787e+57*cos(theta)**38 - 4.81561143434549e+56*cos(theta)**36 + 9.64346854303134e+55*cos(theta)**34 - 1.66820408653734e+55*cos(theta)**32 + 2.48030343801714e+54*cos(theta)**30 - 3.15016641032834e+53*cos(theta)**28 + 3.39248690343052e+52*cos(theta)**26 - 3.07033763189897e+51*cos(theta)**24 + 2.31028676773205e+50*cos(theta)**22 - 1.42656039386823e+49*cos(theta)**20 + 7.11408070432973e+47*cos(theta)**18 - 2.80891444583858e+46*cos(theta)**16 + 8.56376355438591e+44*cos(theta)**14 - 1.95167163398226e+43*cos(theta)**12 + 3.18364626403434e+41*cos(theta)**10 - 3.49851237805971e+39*cos(theta)**8 + 2.36614363733507e+37*cos(theta)**6 - 8.48891522602872e+34*cos(theta)**4 + 1.20752705917905e+32*cos(theta)**2 - 2.84057176941673e+28)*cos(15*phi)

#@torch.jit.script
def Yl93_m16(theta, phi):
    return 1.72992155473396e-31*(1.0 - cos(theta)**2)**8*(4.61021709196197e+57*cos(theta)**77 - 7.29161903301661e+58*cos(theta)**75 + 5.52848164388555e+59*cos(theta)**73 - 2.67566293925068e+60*cos(theta)**71 + 9.28634413971781e+60*cos(theta)**69 - 2.46166817534214e+61*cos(theta)**67 + 5.18356984350617e+61*cos(theta)**65 - 8.90324134970507e+61*cos(theta)**63 + 1.27105485058289e+62*cos(theta)**61 - 1.52927703916285e+62*cos(theta)**59 + 1.56682216407643e+62*cos(theta)**57 - 1.37776758890688e+62*cos(theta)**55 + 1.04600453452286e+62*cos(theta)**53 - 6.88673792915672e+61*cos(theta)**51 + 3.9445601346248e+61*cos(theta)**49 - 1.96976760862793e+61*cos(theta)**47 + 8.58596284244673e+60*cos(theta)**45 - 3.26801353864754e+60*cos(theta)**43 + 1.08573076725487e+60*cos(theta)**41 - 3.14482242723063e+59*cos(theta)**39 + 7.9262361176119e+58*cos(theta)**37 - 1.73362011636438e+58*cos(theta)**35 + 3.27877930463066e+57*cos(theta)**33 - 5.33825307691948e+56*cos(theta)**31 + 7.44091031405143e+55*cos(theta)**29 - 8.82046594891936e+54*cos(theta)**27 + 8.82046594891936e+53*cos(theta)**25 - 7.36881031655752e+52*cos(theta)**23 + 5.08263088901051e+51*cos(theta)**21 - 2.85312078773645e+50*cos(theta)**19 + 1.28053452677935e+49*cos(theta)**17 - 4.49426311334173e+47*cos(theta)**15 + 1.19892689761403e+46*cos(theta)**13 - 2.34200596077872e+44*cos(theta)**11 + 3.18364626403434e+42*cos(theta)**9 - 2.79880990244777e+40*cos(theta)**7 + 1.41968618240104e+38*cos(theta)**5 - 3.39556609041149e+35*cos(theta)**3 + 2.4150541183581e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl93_m17(theta, phi):
    return 1.8796833946566e-33*(1.0 - cos(theta)**2)**8.5*(3.54986716081072e+59*cos(theta)**76 - 5.46871427476246e+60*cos(theta)**74 + 4.03579160003645e+61*cos(theta)**72 - 1.89972068686799e+62*cos(theta)**70 + 6.40757745640529e+62*cos(theta)**68 - 1.64931767747924e+63*cos(theta)**66 + 3.36932039827901e+63*cos(theta)**64 - 5.60904205031419e+63*cos(theta)**62 + 7.75343458855566e+63*cos(theta)**60 - 9.02273453106082e+63*cos(theta)**58 + 8.93088633523565e+63*cos(theta)**56 - 7.57772173898783e+63*cos(theta)**54 + 5.54382403297116e+63*cos(theta)**52 - 3.51223634386993e+63*cos(theta)**50 + 1.93283446596615e+63*cos(theta)**48 - 9.25790776055126e+62*cos(theta)**46 + 3.86368327910103e+62*cos(theta)**44 - 1.40524582161844e+62*cos(theta)**42 + 4.45149614574496e+61*cos(theta)**40 - 1.22648074661995e+61*cos(theta)**38 + 2.9327073635164e+60*cos(theta)**36 - 6.06767040727532e+59*cos(theta)**34 + 1.08199717052812e+59*cos(theta)**32 - 1.65485845384504e+58*cos(theta)**30 + 2.15786399107491e+57*cos(theta)**28 - 2.38152580620823e+56*cos(theta)**26 + 2.20511648722984e+55*cos(theta)**24 - 1.69482637280823e+54*cos(theta)**22 + 1.06735248669221e+53*cos(theta)**20 - 5.42092949669926e+51*cos(theta)**18 + 2.1769086955249e+50*cos(theta)**16 - 6.74139467001259e+48*cos(theta)**14 + 1.55860496689824e+47*cos(theta)**12 - 2.57620655685659e+45*cos(theta)**10 + 2.86528163763091e+43*cos(theta)**8 - 1.95916693171344e+41*cos(theta)**6 + 7.09843091200522e+38*cos(theta)**4 - 1.01866982712345e+36*cos(theta)**2 + 2.4150541183581e+32)*cos(17*phi)

#@torch.jit.script
def Yl93_m18(theta, phi):
    return 2.04652200777142e-35*(1.0 - cos(theta)**2)**9*(2.69789904221615e+61*cos(theta)**75 - 4.04684856332422e+62*cos(theta)**73 + 2.90576995202624e+63*cos(theta)**71 - 1.32980448080759e+64*cos(theta)**69 + 4.35715267035559e+64*cos(theta)**67 - 1.0885496671363e+65*cos(theta)**65 + 2.15636505489857e+65*cos(theta)**63 - 3.4776060711948e+65*cos(theta)**61 + 4.65206075313339e+65*cos(theta)**59 - 5.23318602801528e+65*cos(theta)**57 + 5.00129634773197e+65*cos(theta)**55 - 4.09196973905343e+65*cos(theta)**53 + 2.882788497145e+65*cos(theta)**51 - 1.75611817193496e+65*cos(theta)**49 + 9.27760543663754e+64*cos(theta)**47 - 4.25863756985358e+64*cos(theta)**45 + 1.70002064280445e+64*cos(theta)**43 - 5.90203245079747e+63*cos(theta)**41 + 1.78059845829798e+63*cos(theta)**39 - 4.6606268371558e+62*cos(theta)**37 + 1.05577465086591e+62*cos(theta)**35 - 2.06300793847361e+61*cos(theta)**33 + 3.46239094568997e+60*cos(theta)**31 - 4.96457536153511e+59*cos(theta)**29 + 6.04201917500976e+58*cos(theta)**27 - 6.19196709614139e+57*cos(theta)**25 + 5.29227956935161e+56*cos(theta)**23 - 3.72861802017811e+55*cos(theta)**21 + 2.13470497338441e+54*cos(theta)**19 - 9.75767309405866e+52*cos(theta)**17 + 3.48305391283984e+51*cos(theta)**15 - 9.43795253801762e+49*cos(theta)**13 + 1.87032596027788e+48*cos(theta)**11 - 2.57620655685659e+46*cos(theta)**9 + 2.29222531010472e+44*cos(theta)**7 - 1.17550015902806e+42*cos(theta)**5 + 2.83937236480209e+39*cos(theta)**3 - 2.03733965424689e+36*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl93_m19(theta, phi):
    return 2.23293857428703e-37*(1.0 - cos(theta)**2)**9.5*(2.02342428166211e+63*cos(theta)**74 - 2.95419945122668e+64*cos(theta)**72 + 2.06309666593863e+65*cos(theta)**70 - 9.17565091757237e+65*cos(theta)**68 + 2.91929228913825e+66*cos(theta)**66 - 7.07557283638592e+66*cos(theta)**64 + 1.3585099845861e+67*cos(theta)**62 - 2.12133970342883e+67*cos(theta)**60 + 2.7447158443487e+67*cos(theta)**58 - 2.98291603596871e+67*cos(theta)**56 + 2.75071299125258e+67*cos(theta)**54 - 2.16874396169832e+67*cos(theta)**52 + 1.47022213354395e+67*cos(theta)**50 - 8.60497904248132e+66*cos(theta)**48 + 4.36047455521964e+66*cos(theta)**46 - 1.91638690643411e+66*cos(theta)**44 + 7.31008876405915e+65*cos(theta)**42 - 2.41983330482696e+65*cos(theta)**40 + 6.94433398736214e+64*cos(theta)**38 - 1.72443192974765e+64*cos(theta)**36 + 3.69521127803067e+63*cos(theta)**34 - 6.80792619696291e+62*cos(theta)**32 + 1.07334119316389e+62*cos(theta)**30 - 1.43972685484518e+61*cos(theta)**28 + 1.63134517725264e+60*cos(theta)**26 - 1.54799177403535e+59*cos(theta)**24 + 1.21722430095087e+58*cos(theta)**22 - 7.83009784237402e+56*cos(theta)**20 + 4.05593944943038e+55*cos(theta)**18 - 1.65880442598997e+54*cos(theta)**16 + 5.22458086925976e+52*cos(theta)**14 - 1.22693382994229e+51*cos(theta)**12 + 2.05735855630567e+49*cos(theta)**10 - 2.31858590117093e+47*cos(theta)**8 + 1.60455771707331e+45*cos(theta)**6 - 5.87750079514032e+42*cos(theta)**4 + 8.51811709440626e+39*cos(theta)**2 - 2.03733965424689e+36)*cos(19*phi)

#@torch.jit.script
def Yl93_m20(theta, phi):
    return 2.44186525089707e-39*(1.0 - cos(theta)**2)**10*(1.49733396842996e+65*cos(theta)**73 - 2.12702360488321e+66*cos(theta)**71 + 1.44416766615704e+67*cos(theta)**69 - 6.23944262394921e+67*cos(theta)**67 + 1.92673291083124e+68*cos(theta)**65 - 4.52836661528699e+68*cos(theta)**63 + 8.4227619044338e+68*cos(theta)**61 - 1.2728038220573e+69*cos(theta)**59 + 1.59193518972225e+69*cos(theta)**57 - 1.67043298014248e+69*cos(theta)**55 + 1.48538501527639e+69*cos(theta)**53 - 1.12774686008312e+69*cos(theta)**51 + 7.35111066771975e+68*cos(theta)**49 - 4.13038994039103e+68*cos(theta)**47 + 2.00581829540104e+68*cos(theta)**45 - 8.43210238831009e+67*cos(theta)**43 + 3.07023728090484e+67*cos(theta)**41 - 9.67933321930784e+66*cos(theta)**39 + 2.63884691519761e+66*cos(theta)**37 - 6.20795494709152e+65*cos(theta)**35 + 1.25637183453043e+65*cos(theta)**33 - 2.17853638302813e+64*cos(theta)**31 + 3.22002357949167e+63*cos(theta)**29 - 4.03123519356651e+62*cos(theta)**27 + 4.24149746085685e+61*cos(theta)**25 - 3.71518025768483e+60*cos(theta)**23 + 2.67789346209192e+59*cos(theta)**21 - 1.56601956847481e+58*cos(theta)**19 + 7.30069100897469e+56*cos(theta)**17 - 2.65408708158396e+55*cos(theta)**15 + 7.31441321696366e+53*cos(theta)**13 - 1.47232059593075e+52*cos(theta)**11 + 2.05735855630567e+50*cos(theta)**9 - 1.85486872093674e+48*cos(theta)**7 + 9.62734630243984e+45*cos(theta)**5 - 2.35100031805613e+43*cos(theta)**3 + 1.70362341888125e+40*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl93_m21(theta, phi):
    return 2.67675017001011e-41*(1.0 - cos(theta)**2)**10.5*(1.09305379695387e+67*cos(theta)**72 - 1.51018675946708e+68*cos(theta)**70 + 9.96475689648359e+68*cos(theta)**68 - 4.18042655804597e+69*cos(theta)**66 + 1.25237639204031e+70*cos(theta)**64 - 2.8528709676308e+70*cos(theta)**62 + 5.13788476170462e+70*cos(theta)**60 - 7.50954255013805e+70*cos(theta)**58 + 9.07403058141681e+70*cos(theta)**56 - 9.18738139078362e+70*cos(theta)**54 + 7.87254058096489e+70*cos(theta)**52 - 5.75150898642393e+70*cos(theta)**50 + 3.60204422718268e+70*cos(theta)**48 - 1.94128327198378e+70*cos(theta)**46 + 9.02618232930466e+69*cos(theta)**44 - 3.62580402697334e+69*cos(theta)**42 + 1.25879728517099e+69*cos(theta)**40 - 3.77493995553006e+68*cos(theta)**38 + 9.76373358623117e+67*cos(theta)**36 - 2.17278423148203e+67*cos(theta)**34 + 4.14602705395041e+66*cos(theta)**32 - 6.7534627873872e+65*cos(theta)**30 + 9.33806838052585e+64*cos(theta)**28 - 1.08843350226296e+64*cos(theta)**26 + 1.06037436521421e+63*cos(theta)**24 - 8.54491459267511e+61*cos(theta)**22 + 5.62357627039302e+60*cos(theta)**20 - 2.97543718010213e+59*cos(theta)**18 + 1.2411174715257e+58*cos(theta)**16 - 3.98113062237593e+56*cos(theta)**14 + 9.50873718205276e+54*cos(theta)**12 - 1.61955265552382e+53*cos(theta)**10 + 1.8516227006751e+51*cos(theta)**8 - 1.29840810465572e+49*cos(theta)**6 + 4.81367315121992e+46*cos(theta)**4 - 7.05300095416838e+43*cos(theta)**2 + 1.70362341888125e+40)*cos(21*phi)

#@torch.jit.script
def Yl93_m22(theta, phi):
    return 2.94166132377253e-43*(1.0 - cos(theta)**2)**11*(7.86998733806788e+68*cos(theta)**71 - 1.05713073162696e+70*cos(theta)**69 + 6.77603468960884e+70*cos(theta)**67 - 2.75908152831034e+71*cos(theta)**65 + 8.01520890905798e+71*cos(theta)**63 - 1.7687799999311e+72*cos(theta)**61 + 3.08273085702277e+72*cos(theta)**59 - 4.35553467908007e+72*cos(theta)**57 + 5.08145712559341e+72*cos(theta)**55 - 4.96118595102316e+72*cos(theta)**53 + 4.09372110210174e+72*cos(theta)**51 - 2.87575449321197e+72*cos(theta)**49 + 1.72898122904769e+72*cos(theta)**47 - 8.92990305112541e+71*cos(theta)**45 + 3.97152022489405e+71*cos(theta)**43 - 1.5228376913288e+71*cos(theta)**41 + 5.03518914068394e+70*cos(theta)**39 - 1.43447718310142e+70*cos(theta)**37 + 3.51494409104322e+69*cos(theta)**35 - 7.38746638703891e+68*cos(theta)**33 + 1.32672865726413e+68*cos(theta)**31 - 2.02603883621616e+67*cos(theta)**29 + 2.61465914654724e+66*cos(theta)**27 - 2.82992710588369e+65*cos(theta)**25 + 2.54489847651411e+64*cos(theta)**23 - 1.87988121038853e+63*cos(theta)**21 + 1.1247152540786e+62*cos(theta)**19 - 5.35578692418383e+60*cos(theta)**17 + 1.98578795444112e+59*cos(theta)**15 - 5.57358287132631e+57*cos(theta)**13 + 1.14104846184633e+56*cos(theta)**11 - 1.61955265552382e+54*cos(theta)**9 + 1.48129816054008e+52*cos(theta)**7 - 7.79044862793432e+49*cos(theta)**5 + 1.92546926048797e+47*cos(theta)**3 - 1.41060019083368e+44*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl93_m23(theta, phi):
    return 3.24141398518232e-45*(1.0 - cos(theta)**2)**11.5*(5.58769101002819e+70*cos(theta)**70 - 7.29420204822599e+71*cos(theta)**68 + 4.53994324203793e+72*cos(theta)**66 - 1.79340299340172e+73*cos(theta)**64 + 5.04958161270652e+73*cos(theta)**62 - 1.07895579995797e+74*cos(theta)**60 + 1.81881120564344e+74*cos(theta)**58 - 2.48265476707564e+74*cos(theta)**56 + 2.79480141907638e+74*cos(theta)**54 - 2.62942855404227e+74*cos(theta)**52 + 2.08779776207189e+74*cos(theta)**50 - 1.40911970167386e+74*cos(theta)**48 + 8.12621177652412e+73*cos(theta)**46 - 4.01845637300643e+73*cos(theta)**44 + 1.70775369670444e+73*cos(theta)**42 - 6.24363453444809e+72*cos(theta)**40 + 1.96372376486674e+72*cos(theta)**38 - 5.30756557747526e+71*cos(theta)**36 + 1.23023043186513e+71*cos(theta)**34 - 2.43786390772284e+70*cos(theta)**32 + 4.11285883751881e+69*cos(theta)**30 - 5.87551262502687e+68*cos(theta)**28 + 7.05957969567755e+67*cos(theta)**26 - 7.07481776470923e+66*cos(theta)**24 + 5.85326649598245e+65*cos(theta)**22 - 3.9477505418159e+64*cos(theta)**20 + 2.13695898274935e+63*cos(theta)**18 - 9.10483777111252e+61*cos(theta)**16 + 2.97868193166167e+60*cos(theta)**14 - 7.2456577327242e+58*cos(theta)**12 + 1.25515330803096e+57*cos(theta)**10 - 1.45759738997144e+55*cos(theta)**8 + 1.03690871237806e+53*cos(theta)**6 - 3.89522431396716e+50*cos(theta)**4 + 5.77640778146391e+47*cos(theta)**2 - 1.41060019083368e+44)*cos(23*phi)

#@torch.jit.script
def Yl93_m24(theta, phi):
    return 3.58172757672399e-47*(1.0 - cos(theta)**2)**12*(3.91138370701973e+72*cos(theta)**69 - 4.96005739279367e+73*cos(theta)**67 + 2.99636253974503e+74*cos(theta)**65 - 1.1477779157771e+75*cos(theta)**63 + 3.13074059987805e+75*cos(theta)**61 - 6.47373479974782e+75*cos(theta)**59 + 1.05491049927319e+76*cos(theta)**57 - 1.39028666956236e+76*cos(theta)**55 + 1.50919276630124e+76*cos(theta)**53 - 1.36730284810198e+76*cos(theta)**51 + 1.04389888103594e+76*cos(theta)**49 - 6.76377456803455e+75*cos(theta)**47 + 3.7380574172011e+75*cos(theta)**45 - 1.76812080412283e+75*cos(theta)**43 + 7.17256552615866e+74*cos(theta)**41 - 2.49745381377923e+74*cos(theta)**39 + 7.4621503064936e+73*cos(theta)**37 - 1.91072360789109e+73*cos(theta)**35 + 4.18278346834143e+72*cos(theta)**33 - 7.80116450471309e+71*cos(theta)**31 + 1.23385765125564e+71*cos(theta)**29 - 1.64514353500752e+70*cos(theta)**27 + 1.83549072087616e+69*cos(theta)**25 - 1.69795626353021e+68*cos(theta)**23 + 1.28771862911614e+67*cos(theta)**21 - 7.89550108363181e+65*cos(theta)**19 + 3.84652616894883e+64*cos(theta)**17 - 1.456774043378e+63*cos(theta)**15 + 4.17015470432634e+61*cos(theta)**13 - 8.69478927926904e+59*cos(theta)**11 + 1.25515330803096e+58*cos(theta)**9 - 1.16607791197715e+56*cos(theta)**7 + 6.22145227426835e+53*cos(theta)**5 - 1.55808972558686e+51*cos(theta)**3 + 1.15528155629278e+48*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl93_m25(theta, phi):
    return 3.96941952563658e-49*(1.0 - cos(theta)**2)**12.5*(2.69885475784362e+74*cos(theta)**68 - 3.32323845317176e+75*cos(theta)**66 + 1.94763565083427e+76*cos(theta)**64 - 7.23100086939574e+76*cos(theta)**62 + 1.90975176592561e+77*cos(theta)**60 - 3.81950353185121e+77*cos(theta)**58 + 6.0129898458572e+77*cos(theta)**56 - 7.64657668259297e+77*cos(theta)**54 + 7.99872166139659e+77*cos(theta)**52 - 6.97324452532011e+77*cos(theta)**50 + 5.11510451707613e+77*cos(theta)**48 - 3.17897404697624e+77*cos(theta)**46 + 1.68212583774049e+77*cos(theta)**44 - 7.60291945772817e+76*cos(theta)**42 + 2.94075186572505e+76*cos(theta)**40 - 9.74006987373901e+75*cos(theta)**38 + 2.76099561340263e+75*cos(theta)**36 - 6.68753262761883e+74*cos(theta)**34 + 1.38031854455267e+74*cos(theta)**32 - 2.41836099646106e+73*cos(theta)**30 + 3.57818718864136e+72*cos(theta)**28 - 4.44188754452031e+71*cos(theta)**26 + 4.5887268021904e+70*cos(theta)**24 - 3.90529940611949e+69*cos(theta)**22 + 2.70420912114389e+68*cos(theta)**20 - 1.50014520589004e+67*cos(theta)**18 + 6.53909448721301e+65*cos(theta)**16 - 2.185161065067e+64*cos(theta)**14 + 5.42120111562425e+62*cos(theta)**12 - 9.56426820719594e+60*cos(theta)**10 + 1.12963797722787e+59*cos(theta)**8 - 8.16254538384007e+56*cos(theta)**6 + 3.11072613713417e+54*cos(theta)**4 - 4.67426917676059e+51*cos(theta)**2 + 1.15528155629278e+48)*cos(25*phi)

#@torch.jit.script
def Yl93_m26(theta, phi):
    return 4.41264576223461e-51*(1.0 - cos(theta)**2)**13*(1.83522123533366e+76*cos(theta)**67 - 2.19333737909336e+77*cos(theta)**65 + 1.24648681653393e+78*cos(theta)**63 - 4.48322053902536e+78*cos(theta)**61 + 1.14585105955536e+79*cos(theta)**59 - 2.2153120484737e+79*cos(theta)**57 + 3.36727431368003e+79*cos(theta)**55 - 4.1291514086002e+79*cos(theta)**53 + 4.15933526392623e+79*cos(theta)**51 - 3.48662226266005e+79*cos(theta)**49 + 2.45525016819654e+79*cos(theta)**47 - 1.46232806160907e+79*cos(theta)**45 + 7.40135368605817e+78*cos(theta)**43 - 3.19322617224583e+78*cos(theta)**41 + 1.17630074629002e+78*cos(theta)**39 - 3.70122655202083e+77*cos(theta)**37 + 9.93958420824948e+76*cos(theta)**35 - 2.2737610933904e+76*cos(theta)**33 + 4.41701934256855e+75*cos(theta)**31 - 7.25508298938318e+74*cos(theta)**29 + 1.00189241281958e+74*cos(theta)**27 - 1.15489076157528e+73*cos(theta)**25 + 1.1012944325257e+72*cos(theta)**23 - 8.59165869346288e+70*cos(theta)**21 + 5.40841824228779e+69*cos(theta)**19 - 2.70026137060208e+68*cos(theta)**17 + 1.04625511795408e+67*cos(theta)**15 - 3.05922549109381e+65*cos(theta)**13 + 6.5054413387491e+63*cos(theta)**11 - 9.56426820719594e+61*cos(theta)**9 + 9.03710381782294e+59*cos(theta)**7 - 4.89752723030404e+57*cos(theta)**5 + 1.24429045485367e+55*cos(theta)**3 - 9.34853835352119e+51*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl93_m27(theta, phi):
    return 4.92120028220969e-53*(1.0 - cos(theta)**2)**13.5*(1.22959822767355e+78*cos(theta)**66 - 1.42566929641069e+79*cos(theta)**64 + 7.85286694416378e+79*cos(theta)**62 - 2.73476452880547e+80*cos(theta)**60 + 6.76052125137665e+80*cos(theta)**58 - 1.26272786763001e+81*cos(theta)**56 + 1.85200087252402e+81*cos(theta)**54 - 2.18845024655811e+81*cos(theta)**52 + 2.12126098460238e+81*cos(theta)**50 - 1.70844490870343e+81*cos(theta)**48 + 1.15396757905237e+81*cos(theta)**46 - 6.58047627724081e+80*cos(theta)**44 + 3.18258208500501e+80*cos(theta)**42 - 1.30922273062079e+80*cos(theta)**40 + 4.58757291053108e+79*cos(theta)**38 - 1.36945382424771e+79*cos(theta)**36 + 3.47885447288732e+78*cos(theta)**34 - 7.50341160818833e+77*cos(theta)**32 + 1.36927599619625e+77*cos(theta)**30 - 2.10397406692112e+76*cos(theta)**28 + 2.70510951461287e+75*cos(theta)**26 - 2.8872269039382e+74*cos(theta)**24 + 2.5329771948091e+73*cos(theta)**22 - 1.80424832562721e+72*cos(theta)**20 + 1.02759946603468e+71*cos(theta)**18 - 4.59044433002353e+69*cos(theta)**16 + 1.56938267693112e+68*cos(theta)**14 - 3.97699313842195e+66*cos(theta)**12 + 7.15598547262401e+64*cos(theta)**10 - 8.60784138647635e+62*cos(theta)**8 + 6.32597267247606e+60*cos(theta)**6 - 2.44876361515202e+58*cos(theta)**4 + 3.73287136456101e+55*cos(theta)**2 - 9.34853835352119e+51)*cos(27*phi)

#@torch.jit.script
def Yl93_m28(theta, phi):
    return 5.50688981950095e-55*(1.0 - cos(theta)**2)**14*(8.11534830264544e+79*cos(theta)**65 - 9.12428349702839e+80*cos(theta)**63 + 4.86877750538154e+81*cos(theta)**61 - 1.64085871728328e+82*cos(theta)**59 + 3.92110232579846e+82*cos(theta)**57 - 7.07127605872807e+82*cos(theta)**55 + 1.00008047116297e+83*cos(theta)**53 - 1.13799412821022e+83*cos(theta)**51 + 1.06063049230119e+83*cos(theta)**49 - 8.20053556177645e+82*cos(theta)**47 + 5.30825086364092e+82*cos(theta)**45 - 2.89540956198596e+82*cos(theta)**43 + 1.33668447570211e+82*cos(theta)**41 - 5.23689092248317e+81*cos(theta)**39 + 1.74327770600181e+81*cos(theta)**37 - 4.93003376729174e+80*cos(theta)**35 + 1.18281052078169e+80*cos(theta)**33 - 2.40109171462027e+79*cos(theta)**31 + 4.10782798858875e+78*cos(theta)**29 - 5.89112738737914e+77*cos(theta)**27 + 7.03328473799346e+76*cos(theta)**25 - 6.92934456945169e+75*cos(theta)**23 + 5.57254982858003e+74*cos(theta)**21 - 3.60849665125441e+73*cos(theta)**19 + 1.84967903886242e+72*cos(theta)**17 - 7.34471092803765e+70*cos(theta)**15 + 2.19713574770357e+69*cos(theta)**13 - 4.77239176610634e+67*cos(theta)**11 + 7.15598547262401e+65*cos(theta)**9 - 6.88627310918108e+63*cos(theta)**7 + 3.79558360348563e+61*cos(theta)**5 - 9.79505446060809e+58*cos(theta)**3 + 7.46574272912202e+55*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl93_m29(theta, phi):
    return 6.18400445319037e-57*(1.0 - cos(theta)**2)**14.5*(5.27497639671954e+81*cos(theta)**64 - 5.74829860312788e+82*cos(theta)**62 + 2.96995427828274e+83*cos(theta)**60 - 9.68106643197136e+83*cos(theta)**58 + 2.23502832570512e+84*cos(theta)**56 - 3.88920183230044e+84*cos(theta)**54 + 5.30042649716374e+84*cos(theta)**52 - 5.8037700538721e+84*cos(theta)**50 + 5.19708941227582e+84*cos(theta)**48 - 3.85425171403493e+84*cos(theta)**46 + 2.38871288863841e+84*cos(theta)**44 - 1.24502611165396e+84*cos(theta)**42 + 5.48040635037863e+83*cos(theta)**40 - 2.04238745976843e+83*cos(theta)**38 + 6.45012751220669e+82*cos(theta)**36 - 1.72551181855211e+82*cos(theta)**34 + 3.90327471857957e+81*cos(theta)**32 - 7.44338431532282e+80*cos(theta)**30 + 1.19127011669074e+80*cos(theta)**28 - 1.59060439459237e+79*cos(theta)**26 + 1.75832118449837e+78*cos(theta)**24 - 1.59374925097389e+77*cos(theta)**22 + 1.17023546400181e+76*cos(theta)**20 - 6.85614363738338e+74*cos(theta)**18 + 3.14445436606612e+73*cos(theta)**16 - 1.10170663920565e+72*cos(theta)**14 + 2.85627647201464e+70*cos(theta)**12 - 5.24963094271697e+68*cos(theta)**10 + 6.4403869253616e+66*cos(theta)**8 - 4.82039117642676e+64*cos(theta)**6 + 1.89779180174282e+62*cos(theta)**4 - 2.93851633818243e+59*cos(theta)**2 + 7.46574272912202e+55)*cos(29*phi)

#@torch.jit.script
def Yl93_m30(theta, phi):
    return 6.96991129511242e-59*(1.0 - cos(theta)**2)**15*(3.3759848939005e+83*cos(theta)**63 - 3.56394513393929e+84*cos(theta)**61 + 1.78197256696964e+85*cos(theta)**59 - 5.61501853054339e+85*cos(theta)**57 + 1.25161586239487e+86*cos(theta)**55 - 2.10016898944224e+86*cos(theta)**53 + 2.75622177852514e+86*cos(theta)**51 - 2.90188502693605e+86*cos(theta)**49 + 2.49460291789239e+86*cos(theta)**47 - 1.77295578845607e+86*cos(theta)**45 + 1.0510336710009e+86*cos(theta)**43 - 5.22910966894664e+85*cos(theta)**41 + 2.19216254015145e+85*cos(theta)**39 - 7.76107234712005e+84*cos(theta)**37 + 2.32204590439441e+84*cos(theta)**35 - 5.86674018307717e+83*cos(theta)**33 + 1.24904790994546e+83*cos(theta)**31 - 2.23301529459685e+82*cos(theta)**29 + 3.33555632673407e+81*cos(theta)**27 - 4.13557142594016e+80*cos(theta)**25 + 4.21997084279608e+79*cos(theta)**23 - 3.50624835214255e+78*cos(theta)**21 + 2.34047092800361e+77*cos(theta)**19 - 1.23410585472901e+76*cos(theta)**17 + 5.03112698570579e+74*cos(theta)**15 - 1.54238929488791e+73*cos(theta)**13 + 3.42753176641757e+71*cos(theta)**11 - 5.24963094271697e+69*cos(theta)**9 + 5.15230954028928e+67*cos(theta)**7 - 2.89223470585605e+65*cos(theta)**5 + 7.59116720697127e+62*cos(theta)**3 - 5.87703267636485e+59*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl93_m31(theta, phi):
    return 7.88580681552409e-61*(1.0 - cos(theta)**2)**15.5*(2.12687048315732e+85*cos(theta)**62 - 2.17400653170297e+86*cos(theta)**60 + 1.05136381451209e+87*cos(theta)**58 - 3.20056056240973e+87*cos(theta)**56 + 6.88388724317177e+87*cos(theta)**54 - 1.11308956440438e+88*cos(theta)**52 + 1.40567310704782e+88*cos(theta)**50 - 1.42192366319866e+88*cos(theta)**48 + 1.17246337140943e+88*cos(theta)**46 - 7.9783010480523e+87*cos(theta)**44 + 4.51944478530388e+87*cos(theta)**42 - 2.14393496426812e+87*cos(theta)**40 + 8.54943390659067e+86*cos(theta)**38 - 2.87159676843442e+86*cos(theta)**36 + 8.12716066538043e+85*cos(theta)**34 - 1.93602426041547e+85*cos(theta)**32 + 3.87204852083093e+84*cos(theta)**30 - 6.47574435433086e+83*cos(theta)**28 + 9.00600208218198e+82*cos(theta)**26 - 1.03389285648504e+82*cos(theta)**24 + 9.70593293843098e+80*cos(theta)**22 - 7.36312153949936e+79*cos(theta)**20 + 4.44689476320686e+78*cos(theta)**18 - 2.09797995303931e+77*cos(theta)**16 + 7.54669047855869e+75*cos(theta)**14 - 2.00510608335428e+74*cos(theta)**12 + 3.77028494305933e+72*cos(theta)**10 - 4.72466784844527e+70*cos(theta)**8 + 3.6066166782025e+68*cos(theta)**6 - 1.44611735292803e+66*cos(theta)**4 + 2.27735016209138e+63*cos(theta)**2 - 5.87703267636485e+59)*cos(31*phi)

#@torch.jit.script
def Yl93_m32(theta, phi):
    return 8.95767460692613e-63*(1.0 - cos(theta)**2)**16*(1.31865969955754e+87*cos(theta)**61 - 1.30440391902178e+88*cos(theta)**59 + 6.09791012417012e+88*cos(theta)**57 - 1.79231391494945e+89*cos(theta)**55 + 3.71729911131276e+89*cos(theta)**53 - 5.7880657349028e+89*cos(theta)**51 + 7.02836553523912e+89*cos(theta)**49 - 6.82523358335359e+89*cos(theta)**47 + 5.39333150848336e+89*cos(theta)**45 - 3.51045246114301e+89*cos(theta)**43 + 1.89816680982763e+89*cos(theta)**41 - 8.57573985707249e+88*cos(theta)**39 + 3.24878488450445e+88*cos(theta)**37 - 1.03377483663639e+88*cos(theta)**35 + 2.76323462622935e+87*cos(theta)**33 - 6.19527763332949e+86*cos(theta)**31 + 1.16161455624928e+86*cos(theta)**29 - 1.81320841921264e+85*cos(theta)**27 + 2.34156054136732e+84*cos(theta)**25 - 2.48134285556409e+83*cos(theta)**23 + 2.13530524645482e+82*cos(theta)**21 - 1.47262430789987e+81*cos(theta)**19 + 8.00441057377235e+79*cos(theta)**17 - 3.3567679248629e+78*cos(theta)**15 + 1.05653666699822e+77*cos(theta)**13 - 2.40612730002513e+75*cos(theta)**11 + 3.77028494305933e+73*cos(theta)**9 - 3.77973427875622e+71*cos(theta)**7 + 2.1639700069215e+69*cos(theta)**5 - 5.78446941171211e+66*cos(theta)**3 + 4.55470032418276e+63*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl93_m33(theta, phi):
    return 1.02175104912872e-64*(1.0 - cos(theta)**2)**16.5*(8.04382416730097e+88*cos(theta)**60 - 7.6959831222285e+89*cos(theta)**58 + 3.47580877077697e+90*cos(theta)**56 - 9.85772653222198e+90*cos(theta)**54 + 1.97016852899576e+91*cos(theta)**52 - 2.95191352480043e+91*cos(theta)**50 + 3.44389911226717e+91*cos(theta)**48 - 3.20785978417619e+91*cos(theta)**46 + 2.42699917881751e+91*cos(theta)**44 - 1.5094945582915e+91*cos(theta)**42 + 7.78248392029328e+90*cos(theta)**40 - 3.34453854425827e+90*cos(theta)**38 + 1.20205040726665e+90*cos(theta)**36 - 3.61821192822737e+89*cos(theta)**34 + 9.11867426655684e+88*cos(theta)**32 - 1.92053606633214e+88*cos(theta)**30 + 3.36868221312291e+87*cos(theta)**28 - 4.89566273187413e+86*cos(theta)**26 + 5.85390135341829e+85*cos(theta)**24 - 5.70708856779741e+84*cos(theta)**22 + 4.48414101755511e+83*cos(theta)**20 - 2.79798618500976e+82*cos(theta)**18 + 1.3607497975413e+81*cos(theta)**16 - 5.03515188729436e+79*cos(theta)**14 + 1.37349766709768e+78*cos(theta)**12 - 2.64674003002765e+76*cos(theta)**10 + 3.39325644875339e+74*cos(theta)**8 - 2.64581399512935e+72*cos(theta)**6 + 1.08198500346075e+70*cos(theta)**4 - 1.73534082351363e+67*cos(theta)**2 + 4.55470032418276e+63)*cos(33*phi)

#@torch.jit.script
def Yl93_m34(theta, phi):
    return 1.17048972768622e-66*(1.0 - cos(theta)**2)**17*(4.82629450038058e+90*cos(theta)**59 - 4.46367021089253e+91*cos(theta)**57 + 1.9464529116351e+92*cos(theta)**55 - 5.32317232739987e+92*cos(theta)**53 + 1.0244876350778e+93*cos(theta)**51 - 1.47595676240021e+93*cos(theta)**49 + 1.65307157388824e+93*cos(theta)**47 - 1.47561550072105e+93*cos(theta)**45 + 1.0678796386797e+93*cos(theta)**43 - 6.33987714482428e+92*cos(theta)**41 + 3.11299356811731e+92*cos(theta)**39 - 1.27092464681814e+92*cos(theta)**37 + 4.32738146615993e+91*cos(theta)**35 - 1.23019205559731e+91*cos(theta)**33 + 2.91797576529819e+90*cos(theta)**31 - 5.76160819899643e+89*cos(theta)**29 + 9.43231019674415e+88*cos(theta)**27 - 1.27287231028727e+88*cos(theta)**25 + 1.40493632482039e+87*cos(theta)**23 - 1.25555948491543e+86*cos(theta)**21 + 8.96828203511022e+84*cos(theta)**19 - 5.03637513301756e+83*cos(theta)**17 + 2.17719967606608e+82*cos(theta)**15 - 7.0492126422121e+80*cos(theta)**13 + 1.64819720051722e+79*cos(theta)**11 - 2.64674003002765e+77*cos(theta)**9 + 2.71460515900272e+75*cos(theta)**7 - 1.58748839707761e+73*cos(theta)**5 + 4.327940013843e+70*cos(theta)**3 - 3.47068164702726e+67*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl93_m35(theta, phi):
    return 1.34690391727332e-68*(1.0 - cos(theta)**2)**17.5*(2.84751375522455e+92*cos(theta)**58 - 2.54429202020874e+93*cos(theta)**56 + 1.07054910139931e+94*cos(theta)**54 - 2.82128133352193e+94*cos(theta)**52 + 5.22488693889676e+94*cos(theta)**50 - 7.23218813576105e+94*cos(theta)**48 + 7.76943639727473e+94*cos(theta)**46 - 6.64026975324471e+94*cos(theta)**44 + 4.59188244632273e+94*cos(theta)**42 - 2.59934962937796e+94*cos(theta)**40 + 1.21406749156575e+94*cos(theta)**38 - 4.70242119322713e+93*cos(theta)**36 + 1.51458351315598e+93*cos(theta)**34 - 4.05963378347111e+92*cos(theta)**32 + 9.04572487242439e+91*cos(theta)**30 - 1.67086637770896e+91*cos(theta)**28 + 2.54672375312092e+90*cos(theta)**26 - 3.18218077571818e+89*cos(theta)**24 + 3.2313535470869e+88*cos(theta)**22 - 2.63667491832241e+87*cos(theta)**20 + 1.70397358667094e+86*cos(theta)**18 - 8.56183772612986e+84*cos(theta)**16 + 3.26579951409912e+83*cos(theta)**14 - 9.16397643487573e+81*cos(theta)**12 + 1.81301692056894e+80*cos(theta)**10 - 2.38206602702488e+78*cos(theta)**8 + 1.9002236113019e+76*cos(theta)**6 - 7.93744198538806e+73*cos(theta)**4 + 1.2983820041529e+71*cos(theta)**2 - 3.47068164702726e+67)*cos(35*phi)

#@torch.jit.script
def Yl93_m36(theta, phi):
    return 1.5571403693523e-70*(1.0 - cos(theta)**2)**18*(1.65155797803024e+94*cos(theta)**57 - 1.4248035313169e+95*cos(theta)**55 + 5.78096514755626e+95*cos(theta)**53 - 1.4670662934314e+96*cos(theta)**51 + 2.61244346944838e+96*cos(theta)**49 - 3.4714503051653e+96*cos(theta)**47 + 3.57394074274637e+96*cos(theta)**45 - 2.92171869142767e+96*cos(theta)**43 + 1.92859062745555e+96*cos(theta)**41 - 1.03973985175118e+96*cos(theta)**39 + 4.61345646794986e+95*cos(theta)**37 - 1.69287162956177e+95*cos(theta)**35 + 5.14958394473032e+94*cos(theta)**33 - 1.29908281071075e+94*cos(theta)**31 + 2.71371746172732e+93*cos(theta)**29 - 4.6784258575851e+92*cos(theta)**27 + 6.62148175811439e+91*cos(theta)**25 - 7.63723386172364e+90*cos(theta)**23 + 7.10897780359117e+89*cos(theta)**21 - 5.27334983664481e+88*cos(theta)**19 + 3.0671524560077e+87*cos(theta)**17 - 1.36989403618078e+86*cos(theta)**15 + 4.57211931973877e+84*cos(theta)**13 - 1.09967717218509e+83*cos(theta)**11 + 1.81301692056894e+81*cos(theta)**9 - 1.90565282161991e+79*cos(theta)**7 + 1.14013416678114e+77*cos(theta)**5 - 3.17497679415522e+74*cos(theta)**3 + 2.5967640083058e+71*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl93_m37(theta, phi):
    return 1.80891708266735e-72*(1.0 - cos(theta)**2)**18.5*(9.41388047477235e+95*cos(theta)**56 - 7.83641942224293e+96*cos(theta)**54 + 3.06391152820482e+97*cos(theta)**52 - 7.48203809650016e+97*cos(theta)**50 + 1.28009730002971e+98*cos(theta)**48 - 1.63158164342769e+98*cos(theta)**46 + 1.60827333423587e+98*cos(theta)**44 - 1.2563390373139e+98*cos(theta)**42 + 7.90722157256774e+97*cos(theta)**40 - 4.05498542182961e+97*cos(theta)**38 + 1.70697889314145e+97*cos(theta)**36 - 5.92505070346618e+96*cos(theta)**34 + 1.69936270176101e+96*cos(theta)**32 - 4.02715671320334e+95*cos(theta)**30 + 7.86978063900922e+94*cos(theta)**28 - 1.26317498154798e+94*cos(theta)**26 + 1.6553704395286e+93*cos(theta)**24 - 1.75656378819644e+92*cos(theta)**22 + 1.49288533875415e+91*cos(theta)**20 - 1.00193646896251e+90*cos(theta)**18 + 5.21415917521308e+88*cos(theta)**16 - 2.05484105427117e+87*cos(theta)**14 + 5.9437551156604e+85*cos(theta)**12 - 1.2096448894036e+84*cos(theta)**10 + 1.63171522851205e+82*cos(theta)**8 - 1.33395697513393e+80*cos(theta)**6 + 5.7006708339057e+77*cos(theta)**4 - 9.52493038246567e+74*cos(theta)**2 + 2.5967640083058e+71)*cos(37*phi)

#@torch.jit.script
def Yl93_m38(theta, phi):
    return 2.11197609764664e-74*(1.0 - cos(theta)**2)**19*(5.27177306587251e+97*cos(theta)**55 - 4.23166648801118e+98*cos(theta)**53 + 1.5932339946665e+99*cos(theta)**51 - 3.74101904825008e+99*cos(theta)**49 + 6.14446704014259e+99*cos(theta)**47 - 7.50527555976739e+99*cos(theta)**45 + 7.07640267063782e+99*cos(theta)**43 - 5.27662395671838e+99*cos(theta)**41 + 3.1628886290271e+99*cos(theta)**39 - 1.54089446029525e+99*cos(theta)**37 + 6.14512401530921e+98*cos(theta)**35 - 2.0145172391785e+98*cos(theta)**33 + 5.43796064563522e+97*cos(theta)**31 - 1.208147013961e+97*cos(theta)**29 + 2.20353857892258e+96*cos(theta)**27 - 3.28425495202474e+95*cos(theta)**25 + 3.97288905486864e+94*cos(theta)**23 - 3.86444033403216e+93*cos(theta)**21 + 2.98577067750829e+92*cos(theta)**19 - 1.80348564413253e+91*cos(theta)**17 + 8.34265468034093e+89*cos(theta)**15 - 2.87677747597963e+88*cos(theta)**13 + 7.13250613879248e+86*cos(theta)**11 - 1.2096448894036e+85*cos(theta)**9 + 1.30537218280964e+83*cos(theta)**7 - 8.00374185080361e+80*cos(theta)**5 + 2.28026833356228e+78*cos(theta)**3 - 1.90498607649313e+75*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl93_m39(theta, phi):
    return 2.47868128902229e-76*(1.0 - cos(theta)**2)**19.5*(2.89947518622988e+99*cos(theta)**54 - 2.24278323864593e+100*cos(theta)**52 + 8.12549337279917e+100*cos(theta)**50 - 1.83309933364254e+101*cos(theta)**48 + 2.88789950886702e+101*cos(theta)**46 - 3.37737400189532e+101*cos(theta)**44 + 3.04285314837426e+101*cos(theta)**42 - 2.16341582225453e+101*cos(theta)**40 + 1.23352656532057e+101*cos(theta)**38 - 5.70130950309243e+100*cos(theta)**36 + 2.15079340535822e+100*cos(theta)**34 - 6.64790688928905e+99*cos(theta)**32 + 1.68576780014692e+99*cos(theta)**30 - 3.5036263404869e+98*cos(theta)**28 + 5.94955416309097e+97*cos(theta)**26 - 8.21063738006185e+96*cos(theta)**24 + 9.13764482619786e+95*cos(theta)**22 - 8.11532470146754e+94*cos(theta)**20 + 5.67296428726575e+93*cos(theta)**18 - 3.06592559502529e+92*cos(theta)**16 + 1.25139820205114e+91*cos(theta)**14 - 3.73981071877352e+89*cos(theta)**12 + 7.84575675267172e+87*cos(theta)**10 - 1.08868040046324e+86*cos(theta)**8 + 9.13760527966745e+83*cos(theta)**6 - 4.0018709254018e+81*cos(theta)**4 + 6.84080500068684e+78*cos(theta)**2 - 1.90498607649313e+75)*cos(39*phi)

#@torch.jit.script
def Yl93_m40(theta, phi):
    return 2.92481221625372e-78*(1.0 - cos(theta)**2)**20*(1.56571660056414e+101*cos(theta)**53 - 1.16624728409588e+102*cos(theta)**51 + 4.06274668639959e+102*cos(theta)**49 - 8.79887680148419e+102*cos(theta)**47 + 1.32843377407883e+103*cos(theta)**45 - 1.48604456083394e+103*cos(theta)**43 + 1.27799832231719e+103*cos(theta)**41 - 8.65366328901814e+102*cos(theta)**39 + 4.68740094821816e+102*cos(theta)**37 - 2.05247142111328e+102*cos(theta)**35 + 7.31269757821796e+101*cos(theta)**33 - 2.1273302045725e+101*cos(theta)**31 + 5.05730340044075e+100*cos(theta)**29 - 9.81015375336333e+99*cos(theta)**27 + 1.54688408240365e+99*cos(theta)**25 - 1.97055297121484e+98*cos(theta)**23 + 2.01028186176353e+97*cos(theta)**21 - 1.62306494029351e+96*cos(theta)**19 + 1.02113357170784e+95*cos(theta)**17 - 4.90548095204047e+93*cos(theta)**15 + 1.7519574828716e+92*cos(theta)**13 - 4.48777286252823e+90*cos(theta)**11 + 7.84575675267172e+88*cos(theta)**9 - 8.70944320370589e+86*cos(theta)**7 + 5.48256316780047e+84*cos(theta)**5 - 1.60074837016072e+82*cos(theta)**3 + 1.36816100013737e+79*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl93_m41(theta, phi):
    return 3.47062470594923e-80*(1.0 - cos(theta)**2)**20.5*(8.29829798298992e+102*cos(theta)**52 - 5.94786114888899e+103*cos(theta)**50 + 1.9907458763358e+104*cos(theta)**48 - 4.13547209669757e+104*cos(theta)**46 + 5.97795198335472e+104*cos(theta)**44 - 6.38999161158595e+104*cos(theta)**42 + 5.23979312150048e+104*cos(theta)**40 - 3.37492868271707e+104*cos(theta)**38 + 1.73433835084072e+104*cos(theta)**36 - 7.18364997389647e+103*cos(theta)**34 + 2.41319020081193e+103*cos(theta)**32 - 6.59472363417474e+102*cos(theta)**30 + 1.46661798612782e+102*cos(theta)**28 - 2.6487415134081e+101*cos(theta)**26 + 3.86721020600913e+100*cos(theta)**24 - 4.53227183379414e+99*cos(theta)**22 + 4.22159190970341e+98*cos(theta)**20 - 3.08382338655766e+97*cos(theta)**18 + 1.73592707190332e+96*cos(theta)**16 - 7.3582214280607e+94*cos(theta)**14 + 2.27754472773307e+93*cos(theta)**12 - 4.93655014878105e+91*cos(theta)**10 + 7.06118107740455e+89*cos(theta)**8 - 6.09661024259412e+87*cos(theta)**6 + 2.74128158390024e+85*cos(theta)**4 - 4.80224511048216e+82*cos(theta)**2 + 1.36816100013737e+79)*cos(41*phi)

#@torch.jit.script
def Yl93_m42(theta, phi):
    return 4.14227662356497e-82*(1.0 - cos(theta)**2)**21*(4.31511495115476e+104*cos(theta)**51 - 2.9739305744445e+105*cos(theta)**49 + 9.55558020641183e+105*cos(theta)**47 - 1.90231716448088e+106*cos(theta)**45 + 2.63029887267608e+106*cos(theta)**43 - 2.6837964768661e+106*cos(theta)**41 + 2.09591724860019e+106*cos(theta)**39 - 1.28247289943249e+106*cos(theta)**37 + 6.24361806302659e+105*cos(theta)**35 - 2.4424409911248e+105*cos(theta)**33 + 7.72220864259817e+104*cos(theta)**31 - 1.97841709025242e+104*cos(theta)**29 + 4.10653036115789e+103*cos(theta)**27 - 6.88672793486106e+102*cos(theta)**25 + 9.28130449442191e+101*cos(theta)**23 - 9.97099803434711e+100*cos(theta)**21 + 8.44318381940683e+99*cos(theta)**19 - 5.5508820958038e+98*cos(theta)**17 + 2.77748331504531e+97*cos(theta)**15 - 1.0301509999285e+96*cos(theta)**13 + 2.73305367327969e+94*cos(theta)**11 - 4.93655014878105e+92*cos(theta)**9 + 5.64894486192364e+90*cos(theta)**7 - 3.65796614555647e+88*cos(theta)**5 + 1.09651263356009e+86*cos(theta)**3 - 9.60449022096433e+82*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl93_m43(theta, phi):
    return 4.97375691234947e-84*(1.0 - cos(theta)**2)**21.5*(2.20070862508893e+106*cos(theta)**50 - 1.4572259814778e+107*cos(theta)**48 + 4.49112269701356e+107*cos(theta)**46 - 8.56042724016396e+107*cos(theta)**44 + 1.13102851525071e+108*cos(theta)**42 - 1.1003565555151e+108*cos(theta)**40 + 8.17407726954075e+107*cos(theta)**38 - 4.74514972790021e+107*cos(theta)**36 + 2.1852663220593e+107*cos(theta)**34 - 8.06005527071184e+106*cos(theta)**32 + 2.39388467920543e+106*cos(theta)**30 - 5.73740956173203e+105*cos(theta)**28 + 1.10876319751263e+105*cos(theta)**26 - 1.72168198371527e+104*cos(theta)**24 + 2.13470003371704e+103*cos(theta)**22 - 2.09390958721289e+102*cos(theta)**20 + 1.6042049256873e+101*cos(theta)**18 - 9.43649956286645e+99*cos(theta)**16 + 4.16622497256797e+98*cos(theta)**14 - 1.33919629990705e+97*cos(theta)**12 + 3.00635904060766e+95*cos(theta)**10 - 4.44289513390294e+93*cos(theta)**8 + 3.95426140334655e+91*cos(theta)**6 - 1.82898307277824e+89*cos(theta)**4 + 3.28953790068028e+86*cos(theta)**2 - 9.60449022096433e+82)*cos(43*phi)

#@torch.jit.script
def Yl93_m44(theta, phi):
    return 6.009512875208e-86*(1.0 - cos(theta)**2)**22*(1.10035431254446e+108*cos(theta)**49 - 6.99468471109346e+108*cos(theta)**47 + 2.06591644062624e+109*cos(theta)**45 - 3.76658798567214e+109*cos(theta)**43 + 4.750319764053e+109*cos(theta)**41 - 4.4014262220604e+109*cos(theta)**39 + 3.10614936242549e+109*cos(theta)**37 - 1.70825390204407e+109*cos(theta)**35 + 7.42990549500164e+108*cos(theta)**33 - 2.57921768662779e+108*cos(theta)**31 + 7.18165403761629e+107*cos(theta)**29 - 1.60647467728497e+107*cos(theta)**27 + 2.88278431353284e+106*cos(theta)**25 - 4.13203676091664e+105*cos(theta)**23 + 4.69634007417749e+104*cos(theta)**21 - 4.18781917442579e+103*cos(theta)**19 + 2.88756886623713e+102*cos(theta)**17 - 1.50983993005863e+101*cos(theta)**15 + 5.83271496159516e+99*cos(theta)**13 - 1.60703555988846e+98*cos(theta)**11 + 3.00635904060766e+96*cos(theta)**9 - 3.55431610712236e+94*cos(theta)**7 + 2.37255684200793e+92*cos(theta)**5 - 7.31593229111295e+89*cos(theta)**3 + 6.57907580136057e+86*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl93_m45(theta, phi):
    return 7.30805297385656e-88*(1.0 - cos(theta)**2)**22.5*(5.39173613146787e+109*cos(theta)**48 - 3.28750181421392e+110*cos(theta)**46 + 9.29662398281806e+110*cos(theta)**44 - 1.61963283383902e+111*cos(theta)**42 + 1.94763110326173e+111*cos(theta)**40 - 1.71655622660356e+111*cos(theta)**38 + 1.14927526409743e+111*cos(theta)**36 - 5.97888865715426e+110*cos(theta)**34 + 2.45186881335054e+110*cos(theta)**32 - 7.99557482854614e+109*cos(theta)**30 + 2.08267967090873e+109*cos(theta)**28 - 4.33748162866941e+108*cos(theta)**26 + 7.2069607838321e+107*cos(theta)**24 - 9.50368455010826e+106*cos(theta)**22 + 9.86231415577273e+105*cos(theta)**20 - 7.95685643140899e+104*cos(theta)**18 + 4.90886707260313e+103*cos(theta)**16 - 2.26475989508795e+102*cos(theta)**14 + 7.58252945007371e+100*cos(theta)**12 - 1.7677391158773e+99*cos(theta)**10 + 2.70572313654689e+97*cos(theta)**8 - 2.48802127498565e+95*cos(theta)**6 + 1.18627842100396e+93*cos(theta)**4 - 2.19477968733388e+90*cos(theta)**2 + 6.57907580136057e+86)*cos(45*phi)

#@torch.jit.script
def Yl93_m46(theta, phi):
    return 8.94692234611806e-90*(1.0 - cos(theta)**2)**23*(2.58803334310458e+111*cos(theta)**47 - 1.51225083453841e+112*cos(theta)**45 + 4.09051455243995e+112*cos(theta)**43 - 6.80245790212389e+112*cos(theta)**41 + 7.79052441304692e+112*cos(theta)**39 - 6.52291366109352e+112*cos(theta)**37 + 4.13739095075075e+112*cos(theta)**35 - 2.03282214343245e+112*cos(theta)**33 + 7.84598020272173e+111*cos(theta)**31 - 2.39867244856384e+111*cos(theta)**29 + 5.83150307854443e+110*cos(theta)**27 - 1.12774522345405e+110*cos(theta)**25 + 1.7296705881197e+109*cos(theta)**23 - 2.09081060102382e+108*cos(theta)**21 + 1.97246283115455e+107*cos(theta)**19 - 1.43223415765362e+106*cos(theta)**17 + 7.85418731616501e+104*cos(theta)**15 - 3.17066385312313e+103*cos(theta)**13 + 9.09903534008845e+101*cos(theta)**11 - 1.7677391158773e+100*cos(theta)**9 + 2.16457850923751e+98*cos(theta)**7 - 1.49281276499139e+96*cos(theta)**5 + 4.74511368401586e+93*cos(theta)**3 - 4.38955937466777e+90*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl93_m47(theta, phi):
    return 1.10296243441217e-91*(1.0 - cos(theta)**2)**23.5*(1.21637567125915e+113*cos(theta)**46 - 6.80512875542282e+113*cos(theta)**44 + 1.75892125754918e+114*cos(theta)**42 - 2.7890077398708e+114*cos(theta)**40 + 3.0383045210883e+114*cos(theta)**38 - 2.4134780546046e+114*cos(theta)**36 + 1.44808683276276e+114*cos(theta)**34 - 6.70831307332708e+113*cos(theta)**32 + 2.43225386284374e+113*cos(theta)**30 - 6.95615010083514e+112*cos(theta)**28 + 1.574505831207e+112*cos(theta)**26 - 2.81936305863512e+111*cos(theta)**24 + 3.97824235267532e+110*cos(theta)**22 - 4.39070226215002e+109*cos(theta)**20 + 3.74767937919364e+108*cos(theta)**18 - 2.43479806801115e+107*cos(theta)**16 + 1.17812809742475e+106*cos(theta)**14 - 4.12186300906007e+104*cos(theta)**12 + 1.00089388740973e+103*cos(theta)**10 - 1.59096520428957e+101*cos(theta)**8 + 1.51520495646626e+99*cos(theta)**6 - 7.46406382495695e+96*cos(theta)**4 + 1.42353410520476e+94*cos(theta)**2 - 4.38955937466777e+90)*cos(47*phi)

#@torch.jit.script
def Yl93_m48(theta, phi):
    return 1.3695322039999e-93*(1.0 - cos(theta)**2)**24*(5.5953280877921e+114*cos(theta)**45 - 2.99425665238604e+115*cos(theta)**43 + 7.38746928170655e+115*cos(theta)**41 - 1.11560309594832e+116*cos(theta)**39 + 1.15455571801355e+116*cos(theta)**37 - 8.68852099657657e+115*cos(theta)**35 + 4.92349523139339e+115*cos(theta)**33 - 2.14666018346466e+115*cos(theta)**31 + 7.29676158853121e+114*cos(theta)**29 - 1.94772202823384e+114*cos(theta)**27 + 4.09371516113819e+113*cos(theta)**25 - 6.76647134072428e+112*cos(theta)**23 + 8.7521331758857e+111*cos(theta)**21 - 8.78140452430003e+110*cos(theta)**19 + 6.74582288254854e+109*cos(theta)**17 - 3.89567690881784e+108*cos(theta)**15 + 1.64937933639465e+107*cos(theta)**13 - 4.94623561087208e+105*cos(theta)**11 + 1.00089388740973e+104*cos(theta)**9 - 1.27277216343166e+102*cos(theta)**7 + 9.09122973879756e+99*cos(theta)**5 - 2.98562552998278e+97*cos(theta)**3 + 2.84706821040952e+94*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl93_m49(theta, phi):
    return 1.71325425814162e-95*(1.0 - cos(theta)**2)**24.5*(2.51789763950644e+116*cos(theta)**44 - 1.287530360526e+117*cos(theta)**42 + 3.02886240549968e+117*cos(theta)**40 - 4.35085207419844e+117*cos(theta)**38 + 4.27185615665015e+117*cos(theta)**36 - 3.0409823488018e+117*cos(theta)**34 + 1.62475342635982e+117*cos(theta)**32 - 6.65464656874046e+116*cos(theta)**30 + 2.11606086067405e+116*cos(theta)**28 - 5.25884947623137e+115*cos(theta)**26 + 1.02342879028455e+115*cos(theta)**24 - 1.55628840836658e+114*cos(theta)**22 + 1.837947966936e+113*cos(theta)**20 - 1.66846685961701e+112*cos(theta)**18 + 1.14678989003325e+111*cos(theta)**16 - 5.84351536322676e+109*cos(theta)**14 + 2.14419313731305e+108*cos(theta)**12 - 5.44085917195929e+106*cos(theta)**10 + 9.00804498668756e+104*cos(theta)**8 - 8.90940514402161e+102*cos(theta)**6 + 4.54561486939878e+100*cos(theta)**4 - 8.95687658994834e+97*cos(theta)**2 + 2.84706821040952e+94)*cos(49*phi)

#@torch.jit.script
def Yl93_m50(theta, phi):
    return 2.1598692572156e-97*(1.0 - cos(theta)**2)**25*(1.10787496138284e+118*cos(theta)**43 - 5.40762751420919e+118*cos(theta)**41 + 1.21154496219987e+119*cos(theta)**39 - 1.65332378819541e+119*cos(theta)**37 + 1.53786821639405e+119*cos(theta)**35 - 1.03393399859261e+119*cos(theta)**33 + 5.19921096435142e+118*cos(theta)**31 - 1.99639397062214e+118*cos(theta)**29 + 5.92497040988734e+117*cos(theta)**27 - 1.36730086382016e+117*cos(theta)**25 + 2.45622909668291e+116*cos(theta)**23 - 3.42383449840649e+115*cos(theta)**21 + 3.67589593387199e+114*cos(theta)**19 - 3.00324034731061e+113*cos(theta)**17 + 1.8348638240532e+112*cos(theta)**15 - 8.18092150851747e+110*cos(theta)**13 + 2.57303176477566e+109*cos(theta)**11 - 5.44085917195929e+107*cos(theta)**9 + 7.20643598935005e+105*cos(theta)**7 - 5.34564308641297e+103*cos(theta)**5 + 1.81824594775951e+101*cos(theta)**3 - 1.79137531798967e+98*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl93_m51(theta, phi):
    return 2.74480811525604e-99*(1.0 - cos(theta)**2)**25.5*(4.76386233394619e+119*cos(theta)**42 - 2.21712728082577e+120*cos(theta)**40 + 4.72502535257951e+120*cos(theta)**38 - 6.11729801632301e+120*cos(theta)**36 + 5.38253875737918e+120*cos(theta)**34 - 3.41198219535562e+120*cos(theta)**32 + 1.61175539894894e+120*cos(theta)**30 - 5.7895425148042e+119*cos(theta)**28 + 1.59974201066958e+119*cos(theta)**26 - 3.41825215955039e+118*cos(theta)**24 + 5.6493269223707e+117*cos(theta)**22 - 7.19005244665362e+116*cos(theta)**20 + 6.98420227435679e+115*cos(theta)**18 - 5.10550859042804e+114*cos(theta)**16 + 2.75229573607981e+113*cos(theta)**14 - 1.06351979610727e+112*cos(theta)**12 + 2.83033494125322e+110*cos(theta)**10 - 4.89677325476336e+108*cos(theta)**8 + 5.04450519254503e+106*cos(theta)**6 - 2.67282154320648e+104*cos(theta)**4 + 5.45473784327854e+101*cos(theta)**2 - 1.79137531798967e+98)*cos(51*phi)

#@torch.jit.script
def Yl93_m52(theta, phi):
    return 3.51725084593921e-101*(1.0 - cos(theta)**2)**26*(2.0008221802574e+121*cos(theta)**41 - 8.86850912330308e+121*cos(theta)**39 + 1.79550963398021e+122*cos(theta)**37 - 2.20222728587628e+122*cos(theta)**35 + 1.83006317750892e+122*cos(theta)**33 - 1.0918343025138e+122*cos(theta)**31 + 4.83526619684682e+121*cos(theta)**29 - 1.62107190414518e+121*cos(theta)**27 + 4.15932922774091e+120*cos(theta)**25 - 8.20380518292093e+119*cos(theta)**23 + 1.24285192292155e+119*cos(theta)**21 - 1.43801048933072e+118*cos(theta)**19 + 1.25715640938422e+117*cos(theta)**17 - 8.16881374468486e+115*cos(theta)**15 + 3.85321403051173e+114*cos(theta)**13 - 1.27622375532873e+113*cos(theta)**11 + 2.83033494125322e+111*cos(theta)**9 - 3.91741860381069e+109*cos(theta)**7 + 3.02670311552702e+107*cos(theta)**5 - 1.06912861728259e+105*cos(theta)**3 + 1.09094756865571e+102*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl93_m53(theta, phi):
    return 4.54605814888576e-103*(1.0 - cos(theta)**2)**26.5*(8.20337093905535e+122*cos(theta)**40 - 3.4587185580882e+123*cos(theta)**38 + 6.64338564572679e+123*cos(theta)**36 - 7.70779550056699e+123*cos(theta)**34 + 6.03920848577944e+123*cos(theta)**32 - 3.38468633779277e+123*cos(theta)**30 + 1.40222719708558e+123*cos(theta)**28 - 4.37689414119198e+122*cos(theta)**26 + 1.03983230693523e+122*cos(theta)**24 - 1.88687519207181e+121*cos(theta)**22 + 2.60998903813526e+120*cos(theta)**20 - 2.73221992972838e+119*cos(theta)**18 + 2.13716589595318e+118*cos(theta)**16 - 1.22532206170273e+117*cos(theta)**14 + 5.00917823966525e+115*cos(theta)**12 - 1.4038461308616e+114*cos(theta)**10 + 2.5473014471279e+112*cos(theta)**8 - 2.74219302266748e+110*cos(theta)**6 + 1.51335155776351e+108*cos(theta)**4 - 3.20738585184778e+105*cos(theta)**2 + 1.09094756865571e+102)*cos(53*phi)

#@torch.jit.script
def Yl93_m54(theta, phi):
    return 5.92852046636883e-105*(1.0 - cos(theta)**2)**27*(3.28134837562214e+124*cos(theta)**39 - 1.31431305207352e+125*cos(theta)**37 + 2.39161883246164e+125*cos(theta)**35 - 2.62065047019278e+125*cos(theta)**33 + 1.93254671544942e+125*cos(theta)**31 - 1.01540590133783e+125*cos(theta)**29 + 3.92623615183962e+124*cos(theta)**27 - 1.13799247670991e+124*cos(theta)**25 + 2.49559753664455e+123*cos(theta)**23 - 4.15112542255799e+122*cos(theta)**21 + 5.21997807627053e+121*cos(theta)**19 - 4.91799587351108e+120*cos(theta)**17 + 3.41946543352508e+119*cos(theta)**15 - 1.71545088638382e+118*cos(theta)**13 + 6.0110138875983e+116*cos(theta)**11 - 1.4038461308616e+115*cos(theta)**9 + 2.03784115770232e+113*cos(theta)**7 - 1.64531581360049e+111*cos(theta)**5 + 6.05340623105404e+108*cos(theta)**3 - 6.41477170369556e+105*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl93_m55(theta, phi):
    return 7.8033872960414e-107*(1.0 - cos(theta)**2)**27.5*(1.27972586649263e+126*cos(theta)**38 - 4.86295829267201e+126*cos(theta)**36 + 8.37066591361575e+126*cos(theta)**34 - 8.64814655163617e+126*cos(theta)**32 + 5.99089481789321e+126*cos(theta)**30 - 2.94467711387971e+126*cos(theta)**28 + 1.0600837609967e+126*cos(theta)**26 - 2.84498119177478e+125*cos(theta)**24 + 5.73987433428246e+124*cos(theta)**22 - 8.71736338737178e+123*cos(theta)**20 + 9.917958344914e+122*cos(theta)**18 - 8.36059298496883e+121*cos(theta)**16 + 5.12919815028763e+120*cos(theta)**14 - 2.23008615229897e+119*cos(theta)**12 + 6.61211527635813e+117*cos(theta)**10 - 1.26346151777544e+116*cos(theta)**8 + 1.42648881039162e+114*cos(theta)**6 - 8.22657906800244e+111*cos(theta)**4 + 1.81602186931621e+109*cos(theta)**2 - 6.41477170369556e+105)*cos(55*phi)

#@torch.jit.script
def Yl93_m56(theta, phi):
    return 1.03704649914995e-108*(1.0 - cos(theta)**2)**28*(4.86295829267201e+127*cos(theta)**37 - 1.75066498536192e+128*cos(theta)**35 + 2.84602641062936e+128*cos(theta)**33 - 2.76740689652357e+128*cos(theta)**31 + 1.79726844536796e+128*cos(theta)**29 - 8.2450959188632e+127*cos(theta)**27 + 2.75621777859141e+127*cos(theta)**25 - 6.82795486025948e+126*cos(theta)**23 + 1.26277235354214e+126*cos(theta)**21 - 1.74347267747436e+125*cos(theta)**19 + 1.78523250208452e+124*cos(theta)**17 - 1.33769487759501e+123*cos(theta)**15 + 7.18087741040268e+121*cos(theta)**13 - 2.67610338275876e+120*cos(theta)**11 + 6.61211527635813e+118*cos(theta)**9 - 1.01076921422035e+117*cos(theta)**7 + 8.55893286234974e+114*cos(theta)**5 - 3.29063162720098e+112*cos(theta)**3 + 3.63204373863243e+109*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl93_m57(theta, phi):
    return 1.39204007488598e-110*(1.0 - cos(theta)**2)**28.5*(1.79929456828864e+129*cos(theta)**36 - 6.12732744876673e+129*cos(theta)**34 + 9.39188715507688e+129*cos(theta)**32 - 8.57896137922307e+129*cos(theta)**30 + 5.21207849156709e+129*cos(theta)**28 - 2.22617589809306e+129*cos(theta)**26 + 6.89054444647853e+128*cos(theta)**24 - 1.57042961785968e+128*cos(theta)**22 + 2.6518219424385e+127*cos(theta)**20 - 3.31259808720128e+126*cos(theta)**18 + 3.03489525354369e+125*cos(theta)**16 - 2.00654231639252e+124*cos(theta)**14 + 9.33514063352348e+122*cos(theta)**12 - 2.94371372103464e+121*cos(theta)**10 + 5.95090374872231e+119*cos(theta)**8 - 7.07538449954245e+117*cos(theta)**6 + 4.27946643117487e+115*cos(theta)**4 - 9.87189488160293e+112*cos(theta)**2 + 3.63204373863243e+109)*cos(57*phi)

#@torch.jit.script
def Yl93_m58(theta, phi):
    return 1.88804357848192e-112*(1.0 - cos(theta)**2)**29*(6.47746044583912e+130*cos(theta)**35 - 2.08329133258069e+131*cos(theta)**33 + 3.0054038896246e+131*cos(theta)**31 - 2.57368841376692e+131*cos(theta)**29 + 1.45938197763879e+131*cos(theta)**27 - 5.78805733504196e+130*cos(theta)**25 + 1.65373066715485e+130*cos(theta)**23 - 3.4549451592913e+129*cos(theta)**21 + 5.30364388487699e+128*cos(theta)**19 - 5.9626765569623e+127*cos(theta)**17 + 4.8558324056699e+126*cos(theta)**15 - 2.80915924294953e+125*cos(theta)**13 + 1.12021687602282e+124*cos(theta)**11 - 2.94371372103464e+122*cos(theta)**9 + 4.76072299897785e+120*cos(theta)**7 - 4.24523069972547e+118*cos(theta)**5 + 1.71178657246995e+116*cos(theta)**3 - 1.97437897632059e+113*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl93_m59(theta, phi):
    return 2.58854785336987e-114*(1.0 - cos(theta)**2)**29.5*(2.26711115604369e+132*cos(theta)**34 - 6.87486139751627e+132*cos(theta)**32 + 9.31675205783626e+132*cos(theta)**30 - 7.46369639992408e+132*cos(theta)**28 + 3.94033133962472e+132*cos(theta)**26 - 1.44701433376049e+132*cos(theta)**24 + 3.80358053445615e+131*cos(theta)**22 - 7.25538483451173e+130*cos(theta)**20 + 1.00769233812663e+130*cos(theta)**18 - 1.01365501468359e+129*cos(theta)**16 + 7.28374860850484e+127*cos(theta)**14 - 3.65190701583439e+126*cos(theta)**12 + 1.2322385636251e+125*cos(theta)**10 - 2.64934234893117e+123*cos(theta)**8 + 3.3325060992845e+121*cos(theta)**6 - 2.12261534986274e+119*cos(theta)**4 + 5.13535971740985e+116*cos(theta)**2 - 1.97437897632059e+113)*cos(59*phi)

#@torch.jit.script
def Yl93_m60(theta, phi):
    return 3.58897988341905e-116*(1.0 - cos(theta)**2)**30*(7.70817793054855e+133*cos(theta)**33 - 2.19995564720521e+134*cos(theta)**31 + 2.79502561735088e+134*cos(theta)**29 - 2.08983499197874e+134*cos(theta)**27 + 1.02448614830243e+134*cos(theta)**25 - 3.47283440102518e+133*cos(theta)**23 + 8.36787717580352e+132*cos(theta)**21 - 1.45107696690235e+132*cos(theta)**19 + 1.81384620862793e+131*cos(theta)**17 - 1.62184802349375e+130*cos(theta)**15 + 1.01972480519068e+129*cos(theta)**13 - 4.38228841900126e+127*cos(theta)**11 + 1.2322385636251e+126*cos(theta)**9 - 2.11947387914494e+124*cos(theta)**7 + 1.9995036595707e+122*cos(theta)**5 - 8.49046139945094e+119*cos(theta)**3 + 1.02707194348197e+117*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl93_m61(theta, phi):
    return 5.03446926325561e-118*(1.0 - cos(theta)**2)**30.5*(2.54369871708102e+135*cos(theta)**32 - 6.81986250633614e+135*cos(theta)**30 + 8.10557429031755e+135*cos(theta)**28 - 5.6425544783426e+135*cos(theta)**26 + 2.56121537075607e+135*cos(theta)**24 - 7.98751912235791e+134*cos(theta)**22 + 1.75725420691874e+134*cos(theta)**20 - 2.75704623711446e+133*cos(theta)**18 + 3.08353855466748e+132*cos(theta)**16 - 2.43277203524062e+131*cos(theta)**14 + 1.32564224674788e+130*cos(theta)**12 - 4.82051726090139e+128*cos(theta)**10 + 1.10901470726259e+127*cos(theta)**8 - 1.48363171540146e+125*cos(theta)**6 + 9.99751829785349e+122*cos(theta)**4 - 2.54713841983528e+120*cos(theta)**2 + 1.02707194348197e+117)*cos(61*phi)

#@torch.jit.script
def Yl93_m62(theta, phi):
    return 7.14846599304781e-120*(1.0 - cos(theta)**2)**31*(8.13983589465927e+136*cos(theta)**31 - 2.04595875190084e+137*cos(theta)**29 + 2.26956080128891e+137*cos(theta)**27 - 1.46706416436908e+137*cos(theta)**25 + 6.14691688981457e+136*cos(theta)**23 - 1.75725420691874e+136*cos(theta)**21 + 3.51450841383748e+135*cos(theta)**19 - 4.96268322680602e+134*cos(theta)**17 + 4.93366168746797e+133*cos(theta)**15 - 3.40588084933687e+132*cos(theta)**13 + 1.59077069609746e+131*cos(theta)**11 - 4.82051726090139e+129*cos(theta)**9 + 8.87211765810071e+127*cos(theta)**7 - 8.90179029240874e+125*cos(theta)**5 + 3.99900731914139e+123*cos(theta)**3 - 5.09427683967057e+120*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl93_m63(theta, phi):
    return 1.02794459985316e-121*(1.0 - cos(theta)**2)**31.5*(2.52334912734437e+138*cos(theta)**30 - 5.93328038051244e+138*cos(theta)**28 + 6.12781416348007e+138*cos(theta)**26 - 3.66766041092269e+138*cos(theta)**24 + 1.41379088465735e+138*cos(theta)**22 - 3.69023383452935e+137*cos(theta)**20 + 6.67756598629121e+136*cos(theta)**18 - 8.43656148557024e+135*cos(theta)**16 + 7.40049253120196e+134*cos(theta)**14 - 4.42764510413793e+133*cos(theta)**12 + 1.7498477657072e+132*cos(theta)**10 - 4.33846553481125e+130*cos(theta)**8 + 6.2104823606705e+128*cos(theta)**6 - 4.45089514620437e+126*cos(theta)**4 + 1.19970219574242e+124*cos(theta)**2 - 5.09427683967057e+120)*cos(63*phi)

#@torch.jit.script
def Yl93_m64(theta, phi):
    return 1.49781872566821e-123*(1.0 - cos(theta)**2)**32*(7.57004738203312e+139*cos(theta)**29 - 1.66131850654348e+140*cos(theta)**27 + 1.59323168250482e+140*cos(theta)**25 - 8.80238498621446e+139*cos(theta)**23 + 3.11033994624617e+139*cos(theta)**21 - 7.38046766905871e+138*cos(theta)**19 + 1.20196187753242e+138*cos(theta)**17 - 1.34984983769124e+137*cos(theta)**15 + 1.03606895436827e+136*cos(theta)**13 - 5.31317412496551e+134*cos(theta)**11 + 1.7498477657072e+133*cos(theta)**9 - 3.470772427849e+131*cos(theta)**7 + 3.7262894164023e+129*cos(theta)**5 - 1.78035805848175e+127*cos(theta)**3 + 2.39940439148484e+124*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl93_m65(theta, phi):
    return 2.21274675939624e-125*(1.0 - cos(theta)**2)**32.5*(2.1953137407896e+141*cos(theta)**28 - 4.48555996766741e+141*cos(theta)**26 + 3.98307920626204e+141*cos(theta)**24 - 2.02454854682933e+141*cos(theta)**22 + 6.53171388711696e+140*cos(theta)**20 - 1.40228885712115e+140*cos(theta)**18 + 2.04333519180511e+139*cos(theta)**16 - 2.02477475653686e+138*cos(theta)**14 + 1.34688964067876e+137*cos(theta)**12 - 5.84449153746206e+135*cos(theta)**10 + 1.57486298913648e+134*cos(theta)**8 - 2.4295406994943e+132*cos(theta)**6 + 1.86314470820115e+130*cos(theta)**4 - 5.34107417544525e+127*cos(theta)**2 + 2.39940439148484e+124)*cos(65*phi)

#@torch.jit.script
def Yl93_m66(theta, phi):
    return 3.31630247898427e-127*(1.0 - cos(theta)**2)**33*(6.14687847421089e+142*cos(theta)**27 - 1.16624559159353e+143*cos(theta)**25 + 9.5593900950289e+142*cos(theta)**23 - 4.45400680302452e+142*cos(theta)**21 + 1.30634277742339e+142*cos(theta)**19 - 2.52411994281808e+141*cos(theta)**17 + 3.26933630688818e+140*cos(theta)**15 - 2.8346846591516e+139*cos(theta)**13 + 1.61626756881451e+138*cos(theta)**11 - 5.84449153746206e+136*cos(theta)**9 + 1.25989039130919e+135*cos(theta)**7 - 1.45772441969658e+133*cos(theta)**5 + 7.4525788328046e+130*cos(theta)**3 - 1.06821483508905e+128*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl93_m67(theta, phi):
    return 5.04559354236107e-129*(1.0 - cos(theta)**2)**33.5*(1.65965718803694e+144*cos(theta)**26 - 2.91561397898381e+144*cos(theta)**24 + 2.19865972185665e+144*cos(theta)**22 - 9.35341428635148e+143*cos(theta)**20 + 2.48205127710444e+143*cos(theta)**18 - 4.29100390279073e+142*cos(theta)**16 + 4.90400446033227e+141*cos(theta)**14 - 3.68509005689708e+140*cos(theta)**12 + 1.77789432569596e+139*cos(theta)**10 - 5.26004238371585e+137*cos(theta)**8 + 8.81923273916431e+135*cos(theta)**6 - 7.2886220984829e+133*cos(theta)**4 + 2.23577364984138e+131*cos(theta)**2 - 1.06821483508905e+128)*cos(67*phi)

#@torch.jit.script
def Yl93_m68(theta, phi):
    return 7.79852825780955e-131*(1.0 - cos(theta)**2)**34*(4.31510868889605e+145*cos(theta)**25 - 6.99747354956116e+145*cos(theta)**23 + 4.83705138808462e+145*cos(theta)**21 - 1.8706828572703e+145*cos(theta)**19 + 4.467692298788e+144*cos(theta)**17 - 6.86560624446517e+143*cos(theta)**15 + 6.86560624446517e+142*cos(theta)**13 - 4.42210806827649e+141*cos(theta)**11 + 1.77789432569596e+140*cos(theta)**9 - 4.20803390697268e+138*cos(theta)**7 + 5.29153964349858e+136*cos(theta)**5 - 2.91544883939316e+134*cos(theta)**3 + 4.47154729968276e+131*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl93_m69(theta, phi):
    return 1.22542049208268e-132*(1.0 - cos(theta)**2)**34.5*(1.07877717222401e+147*cos(theta)**24 - 1.60941891639907e+147*cos(theta)**22 + 1.01578079149777e+147*cos(theta)**20 - 3.55429742881356e+146*cos(theta)**18 + 7.5950769079396e+145*cos(theta)**16 - 1.02984093666978e+145*cos(theta)**14 + 8.92528811780473e+143*cos(theta)**12 - 4.86431887510414e+142*cos(theta)**10 + 1.60010489312636e+141*cos(theta)**8 - 2.94562373488088e+139*cos(theta)**6 + 2.64576982174929e+137*cos(theta)**4 - 8.74634651817948e+134*cos(theta)**2 + 4.47154729968276e+131)*cos(69*phi)

#@torch.jit.script
def Yl93_m70(theta, phi):
    return 1.95923132334199e-134*(1.0 - cos(theta)**2)**35*(2.58906521333763e+148*cos(theta)**23 - 3.54072161607794e+148*cos(theta)**21 + 2.03156158299554e+148*cos(theta)**19 - 6.39773537186441e+147*cos(theta)**17 + 1.21521230527034e+147*cos(theta)**15 - 1.44177731133769e+146*cos(theta)**13 + 1.07103457413657e+145*cos(theta)**11 - 4.86431887510414e+143*cos(theta)**9 + 1.28008391450109e+142*cos(theta)**7 - 1.76737424092853e+140*cos(theta)**5 + 1.05830792869972e+138*cos(theta)**3 - 1.7492693036359e+135*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl93_m71(theta, phi):
    return 3.19006750642644e-136*(1.0 - cos(theta)**2)**35.5*(5.95484999067654e+149*cos(theta)**22 - 7.43551539376368e+149*cos(theta)**20 + 3.85996700769153e+149*cos(theta)**18 - 1.08761501321695e+149*cos(theta)**16 + 1.8228184579055e+148*cos(theta)**14 - 1.87431050473899e+147*cos(theta)**12 + 1.17813803155022e+146*cos(theta)**10 - 4.37788698759373e+144*cos(theta)**8 + 8.96058740150763e+142*cos(theta)**6 - 8.83687120464264e+140*cos(theta)**4 + 3.17492378609915e+138*cos(theta)**2 - 1.7492693036359e+135)*cos(71*phi)

#@torch.jit.script
def Yl93_m72(theta, phi):
    return 5.29476343404247e-138*(1.0 - cos(theta)**2)**36*(1.31006699794884e+151*cos(theta)**21 - 1.48710307875274e+151*cos(theta)**19 + 6.94794061384475e+150*cos(theta)**17 - 1.74018402114712e+150*cos(theta)**15 + 2.5519458410677e+149*cos(theta)**13 - 2.24917260568679e+148*cos(theta)**11 + 1.17813803155022e+147*cos(theta)**9 - 3.50230959007498e+145*cos(theta)**7 + 5.37635244090458e+143*cos(theta)**5 - 3.53474848185705e+141*cos(theta)**3 + 6.3498475721983e+138*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl93_m73(theta, phi):
    return 8.96773713382673e-140*(1.0 - cos(theta)**2)**36.5*(2.75114069569256e+152*cos(theta)**20 - 2.8254958496302e+152*cos(theta)**18 + 1.18114990435361e+152*cos(theta)**16 - 2.61027603172068e+151*cos(theta)**14 + 3.31752959338802e+150*cos(theta)**12 - 2.47408986625547e+149*cos(theta)**10 + 1.0603242283952e+148*cos(theta)**8 - 2.45161671305249e+146*cos(theta)**6 + 2.68817622045229e+144*cos(theta)**4 - 1.06042454455712e+142*cos(theta)**2 + 6.3498475721983e+138)*cos(73*phi)

#@torch.jit.script
def Yl93_m74(theta, phi):
    return 1.55170670284662e-141*(1.0 - cos(theta)**2)**37*(5.50228139138513e+153*cos(theta)**19 - 5.08589252933436e+153*cos(theta)**17 + 1.88983984696577e+153*cos(theta)**15 - 3.65438644440895e+152*cos(theta)**13 + 3.98103551206562e+151*cos(theta)**11 - 2.47408986625547e+150*cos(theta)**9 + 8.48259382716161e+148*cos(theta)**7 - 1.47097002783149e+147*cos(theta)**5 + 1.07527048818092e+145*cos(theta)**3 - 2.12084908911423e+142*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl93_m75(theta, phi):
    return 2.74649109223644e-143*(1.0 - cos(theta)**2)**37.5*(1.04543346436317e+155*cos(theta)**18 - 8.64601729986841e+154*cos(theta)**16 + 2.83475977044866e+154*cos(theta)**14 - 4.75070237773164e+153*cos(theta)**12 + 4.37913906327218e+152*cos(theta)**10 - 2.22668087962992e+151*cos(theta)**8 + 5.93781567901313e+149*cos(theta)**6 - 7.35485013915747e+147*cos(theta)**4 + 3.22581146454275e+145*cos(theta)**2 - 2.12084908911423e+142)*cos(75*phi)

#@torch.jit.script
def Yl93_m76(theta, phi):
    return 4.97964737381752e-145*(1.0 - cos(theta)**2)**38*(1.88178023585371e+156*cos(theta)**17 - 1.38336276797895e+156*cos(theta)**15 + 3.96866367862812e+155*cos(theta)**13 - 5.70084285327797e+154*cos(theta)**11 + 4.37913906327218e+153*cos(theta)**9 - 1.78134470370394e+152*cos(theta)**7 + 3.56268940740788e+150*cos(theta)**5 - 2.94194005566299e+148*cos(theta)**3 + 6.4516229290855e+145*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl93_m77(theta, phi):
    return 9.26295743867017e-147*(1.0 - cos(theta)**2)**38.5*(3.19902640095131e+157*cos(theta)**16 - 2.07504415196842e+157*cos(theta)**14 + 5.15926278221656e+156*cos(theta)**12 - 6.27092713860576e+155*cos(theta)**10 + 3.94122515694496e+154*cos(theta)**8 - 1.24694129259276e+153*cos(theta)**6 + 1.78134470370394e+151*cos(theta)**4 - 8.82582016698896e+148*cos(theta)**2 + 6.4516229290855e+145)*cos(77*phi)

#@torch.jit.script
def Yl93_m78(theta, phi):
    return 1.77089014883691e-148*(1.0 - cos(theta)**2)**39*(5.1184422415221e+158*cos(theta)**15 - 2.90506181275579e+158*cos(theta)**13 + 6.19111533865987e+157*cos(theta)**11 - 6.27092713860576e+156*cos(theta)**9 + 3.15298012555597e+155*cos(theta)**7 - 7.48164775555654e+153*cos(theta)**5 + 7.12537881481575e+151*cos(theta)**3 - 1.76516403339779e+149*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl93_m79(theta, phi):
    return 3.48643657580112e-150*(1.0 - cos(theta)**2)**39.5*(7.67766336228315e+159*cos(theta)**14 - 3.77658035658252e+159*cos(theta)**12 + 6.81022687252586e+158*cos(theta)**10 - 5.64383442474519e+157*cos(theta)**8 + 2.20708608788918e+156*cos(theta)**6 - 3.74082387777827e+154*cos(theta)**4 + 2.13761364444473e+152*cos(theta)**2 - 1.76516403339779e+149)*cos(79*phi)

#@torch.jit.script
def Yl93_m80(theta, phi):
    return 7.08426338913616e-152*(1.0 - cos(theta)**2)**40*(1.07487287071964e+161*cos(theta)**13 - 4.53189642789903e+160*cos(theta)**11 + 6.81022687252586e+159*cos(theta)**9 - 4.51506753979615e+158*cos(theta)**7 + 1.32425165273351e+157*cos(theta)**5 - 1.49632955111131e+155*cos(theta)**3 + 4.27522728888945e+152*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl93_m81(theta, phi):
    return 1.48952706678971e-153*(1.0 - cos(theta)**2)**40.5*(1.39733473193553e+162*cos(theta)**12 - 4.98508607068893e+161*cos(theta)**10 + 6.12920418527327e+160*cos(theta)**8 - 3.16054727785731e+159*cos(theta)**6 + 6.62125826366754e+157*cos(theta)**4 - 4.48898865333392e+155*cos(theta)**2 + 4.27522728888945e+152)*cos(81*phi)

#@torch.jit.script
def Yl93_m82(theta, phi):
    return 3.25041453964257e-155*(1.0 - cos(theta)**2)**41*(1.67680167832264e+163*cos(theta)**11 - 4.98508607068893e+162*cos(theta)**9 + 4.90336334821862e+161*cos(theta)**7 - 1.89632836671438e+160*cos(theta)**5 + 2.64850330546702e+158*cos(theta)**3 - 8.97797730666785e+155*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl93_m83(theta, phi):
    return 7.38730577191492e-157*(1.0 - cos(theta)**2)**41.5*(1.8444818461549e+164*cos(theta)**10 - 4.48657746362004e+163*cos(theta)**8 + 3.43235434375303e+162*cos(theta)**6 - 9.48164183357192e+160*cos(theta)**4 + 7.94550991640105e+158*cos(theta)**2 - 8.97797730666785e+155)*cos(83*phi)

#@torch.jit.script
def Yl93_m84(theta, phi):
    return 1.75589863946563e-158*(1.0 - cos(theta)**2)**42*(1.8444818461549e+165*cos(theta)**9 - 3.58926197089603e+164*cos(theta)**7 + 2.05941260625182e+163*cos(theta)**5 - 3.79265673342877e+161*cos(theta)**3 + 1.58910198328021e+159*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl93_m85(theta, phi):
    return 4.3870055764807e-160*(1.0 - cos(theta)**2)**42.5*(1.66003366153941e+166*cos(theta)**8 - 2.51248337962722e+165*cos(theta)**6 + 1.02970630312591e+164*cos(theta)**4 - 1.13779702002863e+162*cos(theta)**2 + 1.58910198328021e+159)*cos(85*phi)

#@torch.jit.script
def Yl93_m86(theta, phi):
    return 1.15930224656375e-161*(1.0 - cos(theta)**2)**43*(1.32802692923153e+167*cos(theta)**7 - 1.50749002777633e+166*cos(theta)**5 + 4.11882521250364e+164*cos(theta)**3 - 2.27559404005726e+162*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl93_m87(theta, phi):
    return 3.26596408733228e-163*(1.0 - cos(theta)**2)**43.5*(9.29618850462072e+167*cos(theta)**6 - 7.53745013888166e+166*cos(theta)**4 + 1.23564756375109e+165*cos(theta)**2 - 2.27559404005726e+162)*cos(87*phi)

#@torch.jit.script
def Yl93_m88(theta, phi):
    return 9.91052114065714e-165*(1.0 - cos(theta)**2)**44*(5.57771310277243e+168*cos(theta)**5 - 3.01498005555266e+167*cos(theta)**3 + 2.47129512750218e+165*cos(theta))*cos(88*phi)

#@torch.jit.script
def Yl93_m89(theta, phi):
    return 3.28530576761869e-166*(1.0 - cos(theta)**2)**44.5*(2.78885655138621e+169*cos(theta)**4 - 9.04494016665799e+167*cos(theta)**2 + 2.47129512750218e+165)*cos(89*phi)

#@torch.jit.script
def Yl93_m90(theta, phi):
    return 1.21428395250674e-167*(1.0 - cos(theta)**2)**45*(1.11554262055449e+170*cos(theta)**3 - 1.8089880333316e+168*cos(theta))*cos(90*phi)

#@torch.jit.script
def Yl93_m91(theta, phi):
    return 5.16833572383453e-169*(1.0 - cos(theta)**2)**45.5*(3.34662786166346e+170*cos(theta)**2 - 1.8089880333316e+168)*cos(91*phi)

#@torch.jit.script
def Yl93_m92(theta, phi):
    return 17.9840405331759*(1.0 - cos(theta)**2)**46*cos(92*phi)*cos(theta)

#@torch.jit.script
def Yl93_m93(theta, phi):
    return 1.31865383030867*(1.0 - cos(theta)**2)**46.5*cos(93*phi)

#@torch.jit.script
def Yl94_m_minus_94(theta, phi):
    return 1.32215623708918*(1.0 - cos(theta)**2)**47*sin(94*phi)

#@torch.jit.script
def Yl94_m_minus_93(theta, phi):
    return 18.1284929784988*(1.0 - cos(theta)**2)**46.5*sin(93*phi)*cos(theta)

#@torch.jit.script
def Yl94_m_minus_92(theta, phi):
    return 2.80103463690266e-171*(1.0 - cos(theta)**2)**46*(6.25819410131067e+172*cos(theta)**2 - 3.34662786166346e+170)*sin(92*phi)

#@torch.jit.script
def Yl94_m_minus_91(theta, phi):
    return 6.61661063590542e-170*(1.0 - cos(theta)**2)**45.5*(2.08606470043689e+172*cos(theta)**3 - 3.34662786166346e+170*cos(theta))*sin(91*phi)

#@torch.jit.script
def Yl94_m_minus_90(theta, phi):
    return 1.79991268864106e-168*(1.0 - cos(theta)**2)**45*(5.21516175109222e+171*cos(theta)**4 - 1.67331393083173e+170*cos(theta)**2 + 4.522470083329e+167)*sin(90*phi)

#@torch.jit.script
def Yl94_m_minus_89(theta, phi):
    return 5.45940549125323e-167*(1.0 - cos(theta)**2)**44.5*(1.04303235021844e+171*cos(theta)**5 - 5.57771310277243e+169*cos(theta)**3 + 4.522470083329e+167*cos(theta))*sin(89*phi)

#@torch.jit.script
def Yl94_m_minus_88(theta, phi):
    return 1.80903313770319e-165*(1.0 - cos(theta)**2)**44*(1.73838725036407e+170*cos(theta)**6 - 1.39442827569311e+169*cos(theta)**4 + 2.2612350416645e+167*cos(theta)**2 - 4.11882521250364e+164)*sin(88*phi)

#@torch.jit.script
def Yl94_m_minus_87(theta, phi):
    return 6.4570066889192e-164*(1.0 - cos(theta)**2)**43.5*(2.48341035766296e+169*cos(theta)**7 - 2.78885655138621e+168*cos(theta)**5 + 7.53745013888166e+166*cos(theta)**3 - 4.11882521250364e+164*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl94_m_minus_86(theta, phi):
    return 2.45705861613682e-162*(1.0 - cos(theta)**2)**43*(3.1042629470787e+168*cos(theta)**8 - 4.64809425231036e+167*cos(theta)**6 + 1.88436253472042e+166*cos(theta)**4 - 2.05941260625182e+164*cos(theta)**2 + 2.84449255007157e+161)*sin(86*phi)

#@torch.jit.script
def Yl94_m_minus_85(theta, phi):
    return 9.8894701626903e-161*(1.0 - cos(theta)**2)**42.5*(3.44918105230967e+167*cos(theta)**9 - 6.64013464615765e+166*cos(theta)**7 + 3.76872506944083e+165*cos(theta)**5 - 6.86470868750607e+163*cos(theta)**3 + 2.84449255007157e+161*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl94_m_minus_84(theta, phi):
    return 4.18407576385452e-159*(1.0 - cos(theta)**2)**42*(3.44918105230967e+166*cos(theta)**10 - 8.30016830769707e+165*cos(theta)**8 + 6.28120844906805e+164*cos(theta)**6 - 1.71617717187652e+163*cos(theta)**4 + 1.42224627503579e+161*cos(theta)**2 - 1.58910198328021e+158)*sin(84*phi)

#@torch.jit.script
def Yl94_m_minus_83(theta, phi):
    return 1.85142397671217e-157*(1.0 - cos(theta)**2)**41.5*(3.13561913846334e+165*cos(theta)**11 - 9.22240923077452e+164*cos(theta)**9 + 8.97315492724007e+163*cos(theta)**7 - 3.43235434375303e+162*cos(theta)**5 + 4.74082091678596e+160*cos(theta)**3 - 1.58910198328021e+158*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl94_m_minus_82(theta, phi):
    return 8.53263444373482e-156*(1.0 - cos(theta)**2)**41*(2.61301594871945e+164*cos(theta)**12 - 9.22240923077452e+163*cos(theta)**10 + 1.12164436590501e+163*cos(theta)**8 - 5.72059057292172e+161*cos(theta)**6 + 1.18520522919649e+160*cos(theta)**4 - 7.94550991640105e+157*cos(theta)**2 + 7.48164775555654e+154)*sin(82*phi)

#@torch.jit.script
def Yl94_m_minus_81(theta, phi):
    return 4.08141870014996e-154*(1.0 - cos(theta)**2)**40.5*(2.01001226824573e+163*cos(theta)**13 - 8.3840083916132e+162*cos(theta)**11 + 1.24627151767223e+162*cos(theta)**9 - 8.17227224703103e+160*cos(theta)**7 + 2.37041045839298e+159*cos(theta)**5 - 2.64850330546702e+157*cos(theta)**3 + 7.48164775555654e+154*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl94_m_minus_80(theta, phi):
    return 2.02019918781633e-152*(1.0 - cos(theta)**2)**40*(1.43572304874695e+162*cos(theta)**14 - 6.98667365967767e+161*cos(theta)**12 + 1.24627151767223e+161*cos(theta)**10 - 1.02153403087888e+160*cos(theta)**8 + 3.95068409732163e+158*cos(theta)**6 - 6.62125826366754e+156*cos(theta)**4 + 3.74082387777827e+154*cos(theta)**2 - 3.05373377777818e+151)*sin(80*phi)

#@torch.jit.script
def Yl94_m_minus_79(theta, phi):
    return 1.03208257516365e-150*(1.0 - cos(theta)**2)**39.5*(9.57148699164633e+160*cos(theta)**15 - 5.3743643535982e+160*cos(theta)**13 + 1.13297410697476e+160*cos(theta)**11 - 1.13503781208764e+159*cos(theta)**9 + 5.64383442474519e+157*cos(theta)**7 - 1.32425165273351e+156*cos(theta)**5 + 1.24694129259276e+154*cos(theta)**3 - 3.05373377777818e+151*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl94_m_minus_78(theta, phi):
    return 5.42997073227417e-149*(1.0 - cos(theta)**2)**39*(5.98217936977895e+159*cos(theta)**16 - 3.83883168114157e+159*cos(theta)**14 + 9.4414508914563e+158*cos(theta)**12 - 1.13503781208764e+158*cos(theta)**10 + 7.05479303093148e+156*cos(theta)**8 - 2.20708608788918e+155*cos(theta)**6 + 3.11735323148189e+153*cos(theta)**4 - 1.52686688888909e+151*cos(theta)**2 + 1.10322752087362e+148)*sin(78*phi)

#@torch.jit.script
def Yl94_m_minus_77(theta, phi):
    return 2.93620364103731e-147*(1.0 - cos(theta)**2)**38.5*(3.51892904104644e+158*cos(theta)**17 - 2.55922112076105e+158*cos(theta)**15 + 7.26265453188947e+157*cos(theta)**13 - 1.03185255644331e+157*cos(theta)**11 + 7.8386589232572e+155*cos(theta)**9 - 3.15298012555597e+154*cos(theta)**7 + 6.23470646296378e+152*cos(theta)**5 - 5.08955629629697e+150*cos(theta)**3 + 1.10322752087362e+148*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl94_m_minus_76(theta, phi):
    return 1.6289977356341e-145*(1.0 - cos(theta)**2)**38*(1.95496057835914e+157*cos(theta)**18 - 1.59951320047566e+157*cos(theta)**16 + 5.18761037992105e+156*cos(theta)**14 - 8.59877130369427e+155*cos(theta)**12 + 7.8386589232572e+154*cos(theta)**10 - 3.94122515694496e+153*cos(theta)**8 + 1.0391177438273e+152*cos(theta)**6 - 1.27238907407424e+150*cos(theta)**4 + 5.5161376043681e+147*cos(theta)**2 - 3.58423496060305e+144)*sin(76*phi)

#@torch.jit.script
def Yl94_m_minus_75(theta, phi):
    return 9.25809732143938e-144*(1.0 - cos(theta)**2)**37.5*(1.02892662018902e+156*cos(theta)**19 - 9.40890117926856e+155*cos(theta)**17 + 3.45840691994736e+155*cos(theta)**15 - 6.61443946438021e+154*cos(theta)**13 + 7.12605356659746e+153*cos(theta)**11 - 4.37913906327218e+152*cos(theta)**9 + 1.48445391975328e+151*cos(theta)**7 - 2.54477814814848e+149*cos(theta)**5 + 1.83871253478937e+147*cos(theta)**3 - 3.58423496060305e+144*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl94_m_minus_74(theta, phi):
    return 5.38245108779227e-142*(1.0 - cos(theta)**2)**37*(5.14463310094509e+154*cos(theta)**20 - 5.22716732181587e+154*cos(theta)**18 + 2.1615043249671e+154*cos(theta)**16 - 4.72459961741443e+153*cos(theta)**14 + 5.93837797216455e+152*cos(theta)**12 - 4.37913906327218e+151*cos(theta)**10 + 1.8555673996916e+150*cos(theta)**8 - 4.24129691358081e+148*cos(theta)**6 + 4.59678133697342e+146*cos(theta)**4 - 1.79211748030153e+144*cos(theta)**2 + 1.06042454455712e+141)*sin(74*phi)

#@torch.jit.script
def Yl94_m_minus_73(theta, phi):
    return 3.19701283740957e-140*(1.0 - cos(theta)**2)**36.5*(2.44982528616433e+153*cos(theta)**21 - 2.75114069569256e+153*cos(theta)**19 + 1.27147313233359e+153*cos(theta)**17 - 3.14973307827629e+152*cos(theta)**15 + 4.56798305551119e+151*cos(theta)**13 - 3.98103551206562e+150*cos(theta)**11 + 2.06174155521289e+149*cos(theta)**9 - 6.05899559082972e+147*cos(theta)**7 + 9.19356267394683e+145*cos(theta)**5 - 5.97372493433842e+143*cos(theta)**3 + 1.06042454455712e+141*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl94_m_minus_72(theta, phi):
    return 1.93782233028034e-138*(1.0 - cos(theta)**2)**36*(1.11355694825651e+152*cos(theta)**22 - 1.37557034784628e+152*cos(theta)**20 + 7.0637396240755e+151*cos(theta)**18 - 1.96858317392268e+151*cos(theta)**16 + 3.26284503965085e+150*cos(theta)**14 - 3.31752959338802e+149*cos(theta)**12 + 2.06174155521289e+148*cos(theta)**10 - 7.57374448853715e+146*cos(theta)**8 + 1.53226044565781e+145*cos(theta)**6 - 1.49343123358461e+143*cos(theta)**4 + 5.30212272278558e+140*cos(theta)**2 - 2.88629435099923e+137)*sin(72*phi)

#@torch.jit.script
def Yl94_m_minus_71(theta, phi):
    return 1.19737977497088e-136*(1.0 - cos(theta)**2)**35.5*(4.84155194894136e+150*cos(theta)**23 - 6.5503349897442e+150*cos(theta)**21 + 3.71775769688184e+150*cos(theta)**19 - 1.15799010230746e+150*cos(theta)**17 + 2.1752300264339e+149*cos(theta)**15 - 2.5519458410677e+148*cos(theta)**13 + 1.87431050473899e+147*cos(theta)**11 - 8.41527165393017e+145*cos(theta)**9 + 2.18894349379686e+144*cos(theta)**7 - 2.98686246716921e+142*cos(theta)**5 + 1.76737424092853e+140*cos(theta)**3 - 2.88629435099923e+137*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl94_m_minus_70(theta, phi):
    return 7.53493501565664e-135*(1.0 - cos(theta)**2)**35*(2.0173133120589e+149*cos(theta)**24 - 2.97742499533827e+149*cos(theta)**22 + 1.85887884844092e+149*cos(theta)**20 - 6.43327834615255e+148*cos(theta)**18 + 1.35951876652119e+148*cos(theta)**16 - 1.8228184579055e+147*cos(theta)**14 + 1.56192542061583e+146*cos(theta)**12 - 8.41527165393017e+144*cos(theta)**10 + 2.73617936724608e+143*cos(theta)**8 - 4.97810411194869e+141*cos(theta)**6 + 4.41843560232132e+139*cos(theta)**4 - 1.44314717549961e+137*cos(theta)**2 + 7.2886220984829e+133)*sin(70*phi)

#@torch.jit.script
def Yl94_m_minus_69(theta, phi):
    return 4.82471250262325e-133*(1.0 - cos(theta)**2)**34.5*(8.06925324823561e+147*cos(theta)**25 - 1.29453260666881e+148*cos(theta)**23 + 8.85180404019486e+147*cos(theta)**21 - 3.38593597165924e+147*cos(theta)**19 + 7.99716921483052e+146*cos(theta)**17 - 1.21521230527034e+146*cos(theta)**15 + 1.20148109278141e+145*cos(theta)**13 - 7.65024695811834e+143*cos(theta)**11 + 3.04019929694009e+142*cos(theta)**9 - 7.11157730278384e+140*cos(theta)**7 + 8.83687120464264e+138*cos(theta)**5 - 4.81049058499871e+136*cos(theta)**3 + 7.2886220984829e+133*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl94_m_minus_68(theta, phi):
    return 3.14088413358919e-131*(1.0 - cos(theta)**2)**34*(3.10355894162908e+146*cos(theta)**26 - 5.39388586112006e+146*cos(theta)**24 + 4.02354729099766e+146*cos(theta)**22 - 1.69296798582962e+146*cos(theta)**20 + 4.44287178601695e+145*cos(theta)**18 - 7.5950769079396e+144*cos(theta)**16 + 8.58200780558147e+143*cos(theta)**14 - 6.37520579843195e+142*cos(theta)**12 + 3.04019929694009e+141*cos(theta)**10 - 8.8894716284798e+139*cos(theta)**8 + 1.47281186744044e+138*cos(theta)**6 - 1.20262264624968e+136*cos(theta)**4 + 3.64431104924145e+133*cos(theta)**2 - 1.71982588449337e+130)*sin(68*phi)

#@torch.jit.script
def Yl94_m_minus_67(theta, phi):
    return 2.07726213649423e-129*(1.0 - cos(theta)**2)**33.5*(1.14946627467744e+145*cos(theta)**27 - 2.15755434444802e+145*cos(theta)**25 + 1.74936838739029e+145*cos(theta)**23 - 8.06175231347437e+144*cos(theta)**21 + 2.33835357158787e+144*cos(theta)**19 - 4.467692298788e+143*cos(theta)**17 + 5.72133853705431e+142*cos(theta)**15 - 4.90400446033227e+141*cos(theta)**13 + 2.76381754267281e+140*cos(theta)**11 - 9.87719069831088e+138*cos(theta)**9 + 2.10401695348634e+137*cos(theta)**7 - 2.40524529249936e+135*cos(theta)**5 + 1.21477034974715e+133*cos(theta)**3 - 1.71982588449337e+130*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl94_m_minus_66(theta, phi):
    return 1.39470789309361e-127*(1.0 - cos(theta)**2)**33*(4.10523669527656e+143*cos(theta)**28 - 8.2982859401847e+143*cos(theta)**26 + 7.28903494745954e+143*cos(theta)**24 - 3.66443286976108e+143*cos(theta)**22 + 1.16917678579394e+143*cos(theta)**20 - 2.48205127710444e+142*cos(theta)**18 + 3.57583658565894e+141*cos(theta)**16 - 3.50286032880876e+140*cos(theta)**14 + 2.30318128556067e+139*cos(theta)**12 - 9.87719069831088e+137*cos(theta)**10 + 2.63002119185793e+136*cos(theta)**8 - 4.00874215416559e+134*cos(theta)**6 + 3.03692587436787e+132*cos(theta)**4 - 8.59912942246685e+129*cos(theta)**2 + 3.81505298246089e+126)*sin(66*phi)

#@torch.jit.script
def Yl94_m_minus_65(theta, phi):
    return 9.50040783163933e-126*(1.0 - cos(theta)**2)**32.5*(1.41559886044019e+142*cos(theta)**29 - 3.07343923710545e+142*cos(theta)**27 + 2.91561397898381e+142*cos(theta)**25 - 1.59323168250482e+142*cos(theta)**23 + 5.56750850378064e+141*cos(theta)**21 - 1.30634277742339e+141*cos(theta)**19 + 2.10343328568173e+140*cos(theta)**17 - 2.33524021920584e+139*cos(theta)**15 + 1.77167791196975e+138*cos(theta)**13 - 8.97926427119171e+136*cos(theta)**11 + 2.92224576873103e+135*cos(theta)**9 - 5.72677450595085e+133*cos(theta)**7 + 6.07385174873575e+131*cos(theta)**5 - 2.86637647415562e+129*cos(theta)**3 + 3.81505298246089e+126*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl94_m_minus_64(theta, phi):
    return 6.56147439661888e-124*(1.0 - cos(theta)**2)**32*(4.71866286813398e+140*cos(theta)**30 - 1.0976568703948e+141*cos(theta)**28 + 1.12138999191685e+141*cos(theta)**26 - 6.63846534377007e+140*cos(theta)**24 + 2.53068568353666e+140*cos(theta)**22 - 6.53171388711696e+139*cos(theta)**20 + 1.16857404760096e+139*cos(theta)**18 - 1.45952513700365e+138*cos(theta)**16 + 1.26548422283554e+137*cos(theta)**14 - 7.48272022599309e+135*cos(theta)**12 + 2.92224576873103e+134*cos(theta)**10 - 7.15846813243856e+132*cos(theta)**8 + 1.01230862478929e+131*cos(theta)**6 - 7.16594118538904e+128*cos(theta)**4 + 1.90752649123045e+126*cos(theta)**2 - 7.99801463828279e+122)*sin(64*phi)

#@torch.jit.script
def Yl94_m_minus_63(theta, phi):
    return 4.59209462848014e-122*(1.0 - cos(theta)**2)**31.5*(1.52214931230128e+139*cos(theta)**31 - 3.78502369101656e+139*cos(theta)**29 + 4.15329626635871e+139*cos(theta)**27 - 2.65538613750803e+139*cos(theta)**25 + 1.10029812327681e+139*cos(theta)**23 - 3.11033994624617e+138*cos(theta)**21 + 6.15038972421559e+137*cos(theta)**19 - 8.58544198237442e+136*cos(theta)**17 + 8.43656148557024e+135*cos(theta)**15 - 5.7559386353793e+134*cos(theta)**13 + 2.65658706248276e+133*cos(theta)**11 - 7.95385348048729e+131*cos(theta)**9 + 1.44615517827042e+130*cos(theta)**7 - 1.43318823707781e+128*cos(theta)**5 + 6.35842163743482e+125*cos(theta)**3 - 7.99801463828279e+122*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl94_m_minus_62(theta, phi):
    return 3.25488496537784e-120*(1.0 - cos(theta)**2)**31*(4.75671660094151e+137*cos(theta)**32 - 1.26167456367219e+138*cos(theta)**30 + 1.48332009512811e+138*cos(theta)**28 - 1.02130236058001e+138*cos(theta)**26 + 4.58457551365336e+137*cos(theta)**24 - 1.41379088465735e+137*cos(theta)**22 + 3.0751948621078e+136*cos(theta)**20 - 4.76968999020801e+135*cos(theta)**18 + 5.2728509284814e+134*cos(theta)**16 - 4.11138473955665e+133*cos(theta)**14 + 2.21382255206896e+132*cos(theta)**12 - 7.95385348048729e+130*cos(theta)**10 + 1.80769397283802e+129*cos(theta)**8 - 2.38864706179635e+127*cos(theta)**6 + 1.5896054093587e+125*cos(theta)**4 - 3.99900731914139e+122*cos(theta)**2 + 1.59196151239705e+119)*sin(62*phi)

#@torch.jit.script
def Yl94_m_minus_61(theta, phi):
    return 2.33536578628732e-118*(1.0 - cos(theta)**2)**30.5*(1.44142927301258e+136*cos(theta)**33 - 4.06991794732963e+136*cos(theta)**31 + 5.11489687975211e+136*cos(theta)**29 - 3.78260133548152e+136*cos(theta)**27 + 1.83383020546135e+136*cos(theta)**25 - 6.14691688981457e+135*cos(theta)**23 + 1.46437850576562e+135*cos(theta)**21 - 2.51036315274106e+134*cos(theta)**19 + 3.10167701675376e+133*cos(theta)**17 - 2.74092315970443e+132*cos(theta)**15 + 1.70294042466843e+131*cos(theta)**13 - 7.23077589135208e+129*cos(theta)**11 + 2.00854885870891e+128*cos(theta)**9 - 3.41235294542335e+126*cos(theta)**7 + 3.17921081871741e+124*cos(theta)**5 - 1.3330024397138e+122*cos(theta)**3 + 1.59196151239705e+119*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl94_m_minus_60(theta, phi):
    return 1.6953533196612e-116*(1.0 - cos(theta)**2)**30*(4.2394978618017e+134*cos(theta)**34 - 1.27184935854051e+135*cos(theta)**32 + 1.70496562658404e+135*cos(theta)**30 - 1.35092904838626e+135*cos(theta)**28 + 7.05319309792825e+134*cos(theta)**26 - 2.56121537075607e+134*cos(theta)**24 + 6.65626593529826e+133*cos(theta)**22 - 1.25518157637053e+133*cos(theta)**20 + 1.72315389819654e+132*cos(theta)**18 - 1.71307697481527e+131*cos(theta)**16 + 1.21638601762031e+130*cos(theta)**14 - 6.02564657612674e+128*cos(theta)**12 + 2.00854885870891e+127*cos(theta)**10 - 4.26544118177919e+125*cos(theta)**8 + 5.29868469786235e+123*cos(theta)**6 - 3.3325060992845e+121*cos(theta)**4 + 7.95980756198526e+118*cos(theta)**2 - 3.0207998337705e+115)*sin(60*phi)

#@torch.jit.script
def Yl94_m_minus_59(theta, phi):
    return 1.24467109370472e-114*(1.0 - cos(theta)**2)**29.5*(1.21128510337191e+133*cos(theta)**35 - 3.85408896527427e+133*cos(theta)**33 + 5.49988911801302e+133*cos(theta)**31 - 4.65837602891813e+133*cos(theta)**29 + 2.61229373997343e+133*cos(theta)**27 - 1.02448614830243e+133*cos(theta)**25 + 2.89402866752098e+132*cos(theta)**23 - 5.97705512557395e+131*cos(theta)**21 + 9.06923104313966e+130*cos(theta)**19 - 1.00769233812663e+130*cos(theta)**17 + 8.10924011746873e+128*cos(theta)**15 - 4.63511275086672e+127*cos(theta)**13 + 1.82595350791719e+126*cos(theta)**11 - 4.73937909086577e+124*cos(theta)**9 + 7.56954956837478e+122*cos(theta)**7 - 6.66501219856899e+120*cos(theta)**5 + 2.65326918732842e+118*cos(theta)**3 - 3.0207998337705e+115*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl94_m_minus_58(theta, phi):
    return 9.23743869929569e-113*(1.0 - cos(theta)**2)**29*(3.36468084269976e+131*cos(theta)**36 - 1.13355557802185e+132*cos(theta)**34 + 1.71871534937907e+132*cos(theta)**32 - 1.55279200963938e+132*cos(theta)**30 + 9.32962049990509e+131*cos(theta)**28 - 3.94033133962472e+131*cos(theta)**26 + 1.20584527813374e+131*cos(theta)**24 - 2.71684323889725e+130*cos(theta)**22 + 4.53461552156983e+129*cos(theta)**20 - 5.59829076737016e+128*cos(theta)**18 + 5.06827507341796e+127*cos(theta)**16 - 3.31079482204766e+126*cos(theta)**14 + 1.52162792326433e+125*cos(theta)**12 - 4.73937909086577e+123*cos(theta)**10 + 9.46193696046848e+121*cos(theta)**8 - 1.11083536642817e+120*cos(theta)**6 + 6.63317296832105e+117*cos(theta)**4 - 1.51039991688525e+115*cos(theta)**2 + 5.48438604533496e+111)*sin(58*phi)

#@torch.jit.script
def Yl94_m_minus_57(theta, phi):
    return 6.92746316785253e-111*(1.0 - cos(theta)**2)**28.5*(9.09373200729666e+129*cos(theta)**37 - 3.23873022291956e+130*cos(theta)**35 + 5.20822833145172e+130*cos(theta)**33 - 5.00900648270767e+130*cos(theta)**31 + 3.21711051720865e+130*cos(theta)**29 - 1.45938197763879e+130*cos(theta)**27 + 4.82338111253497e+129*cos(theta)**25 - 1.18123619082489e+129*cos(theta)**23 + 2.15934072455706e+128*cos(theta)**21 - 2.94646882493166e+127*cos(theta)**19 + 2.98133827848115e+126*cos(theta)**17 - 2.20719654803177e+125*cos(theta)**15 + 1.17048301789564e+124*cos(theta)**13 - 4.30852644624161e+122*cos(theta)**11 + 1.05132632894094e+121*cos(theta)**9 - 1.58690766632595e+119*cos(theta)**7 + 1.32663459366421e+117*cos(theta)**5 - 5.0346663896175e+114*cos(theta)**3 + 5.48438604533496e+111*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl94_m_minus_56(theta, phi):
    return 5.24752477092704e-109*(1.0 - cos(theta)**2)**28*(2.39308737034123e+128*cos(theta)**38 - 8.99647284144322e+128*cos(theta)**36 + 1.53183186219168e+129*cos(theta)**34 - 1.56531452584615e+129*cos(theta)**32 + 1.07237017240288e+129*cos(theta)**30 - 5.21207849156709e+128*cos(theta)**28 + 1.85514658174422e+128*cos(theta)**26 - 4.92181746177038e+127*cos(theta)**24 + 9.81518511162301e+126*cos(theta)**22 - 1.47323441246583e+126*cos(theta)**20 + 1.65629904360064e+125*cos(theta)**18 - 1.37949784251986e+124*cos(theta)**16 + 8.36059298496883e+122*cos(theta)**14 - 3.59043870520134e+121*cos(theta)**12 + 1.05132632894094e+120*cos(theta)**10 - 1.98363458290744e+118*cos(theta)**8 + 2.21105765610702e+116*cos(theta)**6 - 1.25866659740437e+114*cos(theta)**4 + 2.74219302266748e+111*cos(theta)**2 - 9.55800983850638e+107)*sin(56*phi)

#@torch.jit.script
def Yl94_m_minus_55(theta, phi):
    return 4.01358468075277e-107*(1.0 - cos(theta)**2)**27.5*(6.1361214624134e+126*cos(theta)**39 - 2.431479146336e+127*cos(theta)**37 + 4.37666246340481e+127*cos(theta)**35 - 4.74337735104893e+127*cos(theta)**33 + 3.45925862065447e+127*cos(theta)**31 - 1.79726844536796e+127*cos(theta)**29 + 6.87091326571933e+126*cos(theta)**27 - 1.96872698470815e+126*cos(theta)**25 + 4.26747178766218e+125*cos(theta)**23 - 7.01540196412301e+124*cos(theta)**21 + 8.71736338737178e+123*cos(theta)**19 - 8.11469319129328e+122*cos(theta)**17 + 5.57372865664589e+121*cos(theta)**15 - 2.76187592707795e+120*cos(theta)**13 + 9.55751208128129e+118*cos(theta)**11 - 2.20403842545271e+117*cos(theta)**9 + 3.1586537944386e+115*cos(theta)**7 - 2.51733319480875e+113*cos(theta)**5 + 9.1406434088916e+110*cos(theta)**3 - 9.55800983850638e+107*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl94_m_minus_54(theta, phi):
    return 3.09852896481309e-105*(1.0 - cos(theta)**2)**27*(1.53403036560335e+125*cos(theta)**40 - 6.39862933246317e+125*cos(theta)**38 + 1.215739573168e+126*cos(theta)**36 - 1.39511098560263e+126*cos(theta)**34 + 1.08101831895452e+126*cos(theta)**32 - 5.99089481789321e+125*cos(theta)**30 + 2.45389759489976e+125*cos(theta)**28 - 7.57202686426212e+124*cos(theta)**26 + 1.77811324485924e+124*cos(theta)**24 - 3.18881907460137e+123*cos(theta)**22 + 4.35868169368589e+122*cos(theta)**20 - 4.50816288405182e+121*cos(theta)**18 + 3.48358041040368e+120*cos(theta)**16 - 1.97276851934139e+119*cos(theta)**14 + 7.96459340106774e+117*cos(theta)**12 - 2.20403842545271e+116*cos(theta)**10 + 3.94831724304824e+114*cos(theta)**8 - 4.19555532468125e+112*cos(theta)**6 + 2.2851608522229e+110*cos(theta)**4 - 4.77900491925319e+107*cos(theta)**2 + 1.60369292592389e+104)*sin(54*phi)

#@torch.jit.script
def Yl94_m_minus_53(theta, phi):
    return 2.41367252197616e-103*(1.0 - cos(theta)**2)**26.5*(3.74153747708134e+123*cos(theta)**41 - 1.64067418781107e+124*cos(theta)**39 + 3.28578263018379e+124*cos(theta)**37 - 3.98603138743607e+124*cos(theta)**35 + 3.27581308774097e+124*cos(theta)**33 - 1.93254671544942e+124*cos(theta)**31 + 8.46171584448193e+123*cos(theta)**29 - 2.80445439417116e+123*cos(theta)**27 + 7.11245297943696e+122*cos(theta)**25 - 1.38644307591364e+122*cos(theta)**23 + 2.075562711279e+121*cos(theta)**21 - 2.37271730739569e+120*cos(theta)**19 + 2.04916494729628e+119*cos(theta)**17 - 1.31517901289426e+118*cos(theta)**15 + 6.12661030851365e+116*cos(theta)**13 - 2.0036712958661e+115*cos(theta)**11 + 4.38701915894249e+113*cos(theta)**9 - 5.99365046383035e+111*cos(theta)**7 + 4.5703217044458e+109*cos(theta)**5 - 1.59300163975106e+107*cos(theta)**3 + 1.60369292592389e+104*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl94_m_minus_52(theta, phi):
    return 1.89653848043213e-101*(1.0 - cos(theta)**2)**26*(8.90842256447938e+121*cos(theta)**42 - 4.10168546952767e+122*cos(theta)**40 + 8.6467963952205e+122*cos(theta)**38 - 1.10723094095446e+123*cos(theta)**36 + 9.63474437570874e+122*cos(theta)**34 - 6.03920848577944e+122*cos(theta)**32 + 2.82057194816064e+122*cos(theta)**30 - 1.00159085506113e+122*cos(theta)**28 + 2.73555883824499e+121*cos(theta)**26 - 5.77684614964016e+120*cos(theta)**24 + 9.43437596035907e+119*cos(theta)**22 - 1.18635865369785e+119*cos(theta)**20 + 1.13842497072016e+118*cos(theta)**18 - 8.21986883058915e+116*cos(theta)**16 + 4.37615022036689e+115*cos(theta)**14 - 1.66972607988842e+114*cos(theta)**12 + 4.38701915894249e+112*cos(theta)**10 - 7.49206307978794e+110*cos(theta)**8 + 7.617202840743e+108*cos(theta)**6 - 3.98250409937766e+106*cos(theta)**4 + 8.01846462961945e+103*cos(theta)**2 - 2.59749421108502e+100)*sin(52*phi)

#@torch.jit.script
def Yl94_m_minus_51(theta, phi):
    return 1.50270009743515e-99*(1.0 - cos(theta)**2)**25.5*(2.0717261777859e+120*cos(theta)**43 - 1.0004110901287e+121*cos(theta)**41 + 2.21712728082577e+121*cos(theta)**39 - 2.99251605663369e+121*cos(theta)**37 + 2.75278410734535e+121*cos(theta)**35 - 1.83006317750892e+121*cos(theta)**33 + 9.09861918761498e+120*cos(theta)**31 - 3.4537615691763e+120*cos(theta)**29 + 1.01316994009074e+120*cos(theta)**27 - 2.31073845985606e+119*cos(theta)**25 + 4.10190259146047e+118*cos(theta)**23 - 5.6493269223707e+117*cos(theta)**21 + 5.99171037221135e+116*cos(theta)**19 - 4.83521695917009e+115*cos(theta)**17 + 2.91743348024459e+114*cos(theta)**15 - 1.28440467683724e+113*cos(theta)**13 + 3.98819923540227e+111*cos(theta)**11 - 8.32451453309771e+109*cos(theta)**9 + 1.08817183439186e+108*cos(theta)**7 - 7.96500819875532e+105*cos(theta)**5 + 2.67282154320648e+103*cos(theta)**3 - 2.59749421108502e+100*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl94_m_minus_50(theta, phi):
    return 1.20028023304834e-97*(1.0 - cos(theta)**2)**25*(4.70846858587705e+118*cos(theta)**44 - 2.3819311669731e+119*cos(theta)**42 + 5.54281820206442e+119*cos(theta)**40 - 7.87504225429918e+119*cos(theta)**38 + 7.64662252040376e+119*cos(theta)**36 - 5.38253875737918e+119*cos(theta)**34 + 2.84331849612968e+119*cos(theta)**32 - 1.1512538563921e+119*cos(theta)**30 + 3.61846407175263e+118*cos(theta)**28 - 8.88745561483101e+117*cos(theta)**26 + 1.70912607977519e+117*cos(theta)**24 - 2.56787587380486e+116*cos(theta)**22 + 2.99585518610568e+115*cos(theta)**20 - 2.68623164398338e+114*cos(theta)**18 + 1.82339592515287e+113*cos(theta)**16 - 9.17431912026602e+111*cos(theta)**14 + 3.32349936283522e+110*cos(theta)**12 - 8.32451453309771e+108*cos(theta)**10 + 1.36021479298982e+107*cos(theta)**8 - 1.32750136645922e+105*cos(theta)**6 + 6.68205385801621e+102*cos(theta)**4 - 1.29874710554251e+100*cos(theta)**2 + 4.07130754088561e+96)*sin(50*phi)

#@torch.jit.script
def Yl94_m_minus_49(theta, phi):
    return 9.66206949532334e-96*(1.0 - cos(theta)**2)**24.5*(1.04632635241712e+117*cos(theta)**45 - 5.53937480691418e+117*cos(theta)**43 + 1.3519068785523e+118*cos(theta)**41 - 2.01924160366646e+118*cos(theta)**39 + 2.06665473524426e+118*cos(theta)**37 - 1.53786821639405e+118*cos(theta)**35 + 8.61611665493843e+117*cos(theta)**33 - 3.71372211739387e+117*cos(theta)**31 + 1.24774623163884e+117*cos(theta)**29 - 3.29165022771519e+116*cos(theta)**27 + 6.83650431910078e+115*cos(theta)**25 - 1.11646777121951e+115*cos(theta)**23 + 1.42659770766937e+114*cos(theta)**21 - 1.41380612841231e+113*cos(theta)**19 + 1.07258583832522e+112*cos(theta)**17 - 6.11621274684401e+110*cos(theta)**15 + 2.55653797141171e+109*cos(theta)**13 - 7.56774048463428e+107*cos(theta)**11 + 1.51134976998869e+106*cos(theta)**9 - 1.89643052351317e+104*cos(theta)**7 + 1.33641077160324e+102*cos(theta)**5 - 4.32915701847503e+99*cos(theta)**3 + 4.07130754088561e+96*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl94_m_minus_48(theta, phi):
    return 7.83640894059076e-94*(1.0 - cos(theta)**2)**24*(2.27462250525461e+115*cos(theta)**46 - 1.25894881975322e+116*cos(theta)**44 + 3.218825901315e+116*cos(theta)**42 - 5.04810400916614e+116*cos(theta)**40 + 5.43856509274805e+116*cos(theta)**38 - 4.27185615665015e+116*cos(theta)**36 + 2.53415195733483e+116*cos(theta)**34 - 1.16053816168558e+116*cos(theta)**32 + 4.15915410546279e+115*cos(theta)**30 - 1.17558936704114e+115*cos(theta)**28 + 2.62942473811568e+114*cos(theta)**26 - 4.65194904674794e+113*cos(theta)**24 + 6.48453503486077e+112*cos(theta)**22 - 7.06903064206153e+111*cos(theta)**20 + 5.95881021291788e+110*cos(theta)**18 - 3.82263296677751e+109*cos(theta)**16 + 1.82609855100836e+108*cos(theta)**14 - 6.3064504038619e+106*cos(theta)**12 + 1.51134976998869e+105*cos(theta)**10 - 2.37053815439146e+103*cos(theta)**8 + 2.2273512860054e+101*cos(theta)**6 - 1.08228925461876e+99*cos(theta)**4 + 2.0356537704428e+96*cos(theta)**2 - 6.18927871828155e+92)*sin(48*phi)

#@torch.jit.script
def Yl94_m_minus_47(theta, phi):
    return 6.40191926012626e-92*(1.0 - cos(theta)**2)**23.5*(4.83962235160556e+113*cos(theta)**47 - 2.79766404389605e+114*cos(theta)**45 + 7.48564163096511e+114*cos(theta)**43 - 1.23124488028442e+115*cos(theta)**41 + 1.3945038699354e+115*cos(theta)**39 - 1.15455571801355e+115*cos(theta)**37 + 7.24043416381381e+114*cos(theta)**35 - 3.51678230813813e+114*cos(theta)**33 + 1.34166261466542e+114*cos(theta)**31 - 4.05375643807289e+113*cos(theta)**29 + 9.7386101411692e+112*cos(theta)**27 - 1.86077961869918e+112*cos(theta)**25 + 2.81936305863512e+111*cos(theta)**23 - 3.36620506764835e+110*cos(theta)**21 + 3.13621590153573e+109*cos(theta)**19 - 2.24860762751618e+108*cos(theta)**17 + 1.21739903400558e+107*cos(theta)**15 - 4.85111569527839e+105*cos(theta)**13 + 1.37395433635336e+104*cos(theta)**11 - 2.63393128265718e+102*cos(theta)**9 + 3.18193040857915e+100*cos(theta)**7 - 2.16457850923751e+98*cos(theta)**5 + 6.78551256814268e+95*cos(theta)**3 - 6.18927871828155e+92*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl94_m_minus_46(theta, phi):
    return 5.26672166724968e-90*(1.0 - cos(theta)**2)**23*(1.00825465658449e+112*cos(theta)**48 - 6.08187835629576e+112*cos(theta)**46 + 1.70128218885571e+113*cos(theta)**44 - 2.93153542924863e+113*cos(theta)**42 + 3.4862596748385e+113*cos(theta)**40 - 3.0383045210883e+113*cos(theta)**38 + 2.0112317121705e+113*cos(theta)**36 - 1.03434773768769e+113*cos(theta)**34 + 4.19269567082942e+112*cos(theta)**32 - 1.3512521460243e+112*cos(theta)**30 + 3.47807505041757e+111*cos(theta)**28 - 7.15684468730453e+110*cos(theta)**26 + 1.17473460776463e+110*cos(theta)**24 - 1.53009321256743e+109*cos(theta)**22 + 1.56810795076786e+108*cos(theta)**20 - 1.24922645973121e+107*cos(theta)**18 + 7.60874396253485e+105*cos(theta)**16 - 3.46508263948456e+104*cos(theta)**14 + 1.14496194696113e+103*cos(theta)**12 - 2.63393128265718e+101*cos(theta)**10 + 3.97741301072393e+99*cos(theta)**8 - 3.60763084872919e+97*cos(theta)**6 + 1.69637814203567e+95*cos(theta)**4 - 3.09463935914078e+92*cos(theta)**2 + 9.14491536389119e+88)*sin(46*phi)

#@torch.jit.script
def Yl94_m_minus_45(theta, phi):
    return 4.36216838103599e-88*(1.0 - cos(theta)**2)**22.5*(2.05766256445815e+110*cos(theta)**49 - 1.29401667155229e+111*cos(theta)**47 + 3.78062708634601e+111*cos(theta)**45 - 6.81752425406658e+111*cos(theta)**43 + 8.50307237765487e+111*cos(theta)**41 - 7.79052441304692e+111*cos(theta)**39 + 5.4357613842446e+111*cos(theta)**37 - 2.95527925053625e+111*cos(theta)**35 + 1.27051383964528e+111*cos(theta)**33 - 4.35887789040096e+110*cos(theta)**31 + 1.19933622428192e+110*cos(theta)**29 - 2.6506832175202e+109*cos(theta)**27 + 4.69893843105853e+108*cos(theta)**25 - 6.65257918507578e+107*cos(theta)**23 + 7.46718071794221e+106*cos(theta)**21 - 6.57487610384848e+105*cos(theta)**19 + 4.47573174266756e+104*cos(theta)**17 - 2.31005509298971e+103*cos(theta)**15 + 8.80739959200869e+101*cos(theta)**13 - 2.3944829842338e+100*cos(theta)**11 + 4.41934778969326e+98*cos(theta)**9 - 5.15375835532742e+96*cos(theta)**7 + 3.39275628407134e+94*cos(theta)**5 - 1.03154645304693e+92*cos(theta)**3 + 9.14491536389119e+88*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl94_m_minus_44(theta, phi):
    return 3.63659408296205e-86*(1.0 - cos(theta)**2)**22*(4.11532512891629e+108*cos(theta)**50 - 2.69586806573394e+109*cos(theta)**48 + 8.21875453553481e+109*cos(theta)**46 - 1.54943733046968e+110*cos(theta)**44 + 2.02454104229878e+110*cos(theta)**42 - 1.94763110326173e+110*cos(theta)**40 + 1.43046352216963e+110*cos(theta)**38 - 8.20910902926736e+109*cos(theta)**36 + 3.73680541072141e+109*cos(theta)**34 - 1.3621493407503e+109*cos(theta)**32 + 3.99778741427307e+108*cos(theta)**30 - 9.46672577685784e+107*cos(theta)**28 + 1.80728401194559e+107*cos(theta)**26 - 2.77190799378158e+106*cos(theta)**24 + 3.39417305361009e+105*cos(theta)**22 - 3.28743805192424e+104*cos(theta)**20 + 2.48651763481531e+103*cos(theta)**18 - 1.44378443311857e+102*cos(theta)**16 + 6.29099970857764e+100*cos(theta)**14 - 1.9954024868615e+99*cos(theta)**12 + 4.41934778969326e+97*cos(theta)**10 - 6.44219794415927e+95*cos(theta)**8 + 5.65459380678556e+93*cos(theta)**6 - 2.57886613261731e+91*cos(theta)**4 + 4.57245768194559e+88*cos(theta)**2 - 1.31581516027211e+85)*sin(44*phi)

#@torch.jit.script
def Yl94_m_minus_43(theta, phi):
    return 3.05084019079274e-84*(1.0 - cos(theta)**2)**21.5*(8.0692649586594e+106*cos(theta)**51 - 5.50177156272232e+107*cos(theta)**49 + 1.74867117777336e+108*cos(theta)**47 - 3.44319406771039e+108*cos(theta)**45 + 4.70823498209018e+108*cos(theta)**43 - 4.750319764053e+108*cos(theta)**41 + 3.66785518505034e+108*cos(theta)**39 - 2.2186781160182e+108*cos(theta)**37 + 1.06765868877755e+108*cos(theta)**35 - 4.12772527500091e+107*cos(theta)**33 + 1.28960884331389e+107*cos(theta)**31 - 3.2643881989165e+106*cos(theta)**29 + 6.69364448868736e+105*cos(theta)**27 - 1.10876319751263e+105*cos(theta)**25 + 1.47572741461308e+104*cos(theta)**23 - 1.5654466913925e+103*cos(theta)**21 + 1.30869349200806e+102*cos(theta)**19 - 8.49284960657981e+100*cos(theta)**17 + 4.19399980571842e+99*cos(theta)**15 - 1.53492498989346e+98*cos(theta)**13 + 4.01758889972114e+96*cos(theta)**11 - 7.15799771573252e+94*cos(theta)**9 + 8.07799115255081e+92*cos(theta)**7 - 5.15773226523463e+90*cos(theta)**5 + 1.52415256064853e+88*cos(theta)**3 - 1.31581516027211e+85*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl94_m_minus_42(theta, phi):
    return 2.57502479009705e-82*(1.0 - cos(theta)**2)**21*(1.55178172281912e+105*cos(theta)**52 - 1.10035431254446e+106*cos(theta)**50 + 3.64306495369451e+106*cos(theta)**48 - 7.4852044950226e+106*cos(theta)**46 + 1.0700534050205e+107*cos(theta)**44 - 1.13102851525071e+107*cos(theta)**42 + 9.16963796262584e+106*cos(theta)**40 - 5.83862662110054e+106*cos(theta)**38 + 2.96571857993763e+106*cos(theta)**36 - 1.2140368455885e+106*cos(theta)**34 + 4.03002763535592e+105*cos(theta)**32 - 1.08812939963883e+105*cos(theta)**30 + 2.39058731738834e+104*cos(theta)**28 - 4.26447383658704e+103*cos(theta)**26 + 6.14886422755452e+102*cos(theta)**24 - 7.1156667790568e+101*cos(theta)**22 + 6.54346746004029e+100*cos(theta)**20 - 4.71824978143323e+99*cos(theta)**18 + 2.62124987857401e+98*cos(theta)**16 - 1.09637499278104e+97*cos(theta)**14 + 3.34799074976762e+95*cos(theta)**12 - 7.15799771573252e+93*cos(theta)**10 + 1.00974889406885e+92*cos(theta)**8 - 8.59622044205772e+89*cos(theta)**6 + 3.81038140162133e+87*cos(theta)**4 - 6.57907580136057e+84*cos(theta)**2 + 1.84701735018545e+81)*sin(42*phi)

#@torch.jit.script
def Yl94_m_minus_41(theta, phi):
    return 2.18619453028729e-80*(1.0 - cos(theta)**2)**20.5*(2.92789004305494e+103*cos(theta)**53 - 2.15755747557738e+104*cos(theta)**51 + 7.43482643611124e+104*cos(theta)**49 - 1.59259670106864e+105*cos(theta)**47 + 2.3778964556011e+105*cos(theta)**45 - 2.63029887267608e+105*cos(theta)**43 + 2.23649706405508e+105*cos(theta)**41 - 1.49708374900014e+105*cos(theta)**39 + 8.01545562145305e+104*cos(theta)**37 - 3.46867670168144e+104*cos(theta)**35 + 1.2212204955624e+104*cos(theta)**33 - 3.51009483754462e+103*cos(theta)**31 + 8.24340454271843e+102*cos(theta)**29 - 1.5794347542915e+102*cos(theta)**27 + 2.45954569102181e+101*cos(theta)**25 - 3.0937681648073e+100*cos(theta)**23 + 3.11593688573347e+99*cos(theta)**21 - 2.48328935864907e+98*cos(theta)**19 + 1.54191169327883e+97*cos(theta)**17 - 7.3091666185403e+95*cos(theta)**15 + 2.57537749982125e+94*cos(theta)**13 - 6.50727065066593e+92*cos(theta)**11 + 1.12194321563206e+91*cos(theta)**9 - 1.22803149172253e+89*cos(theta)**7 + 7.62076280324265e+86*cos(theta)**5 - 2.19302526712019e+84*cos(theta)**3 + 1.84701735018545e+81*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl94_m_minus_40(theta, phi):
    return 1.86660561345564e-78*(1.0 - cos(theta)**2)**20*(5.42201859824988e+101*cos(theta)**54 - 4.14914899149496e+102*cos(theta)**52 + 1.48696528722225e+103*cos(theta)**50 - 3.317909793893e+103*cos(theta)**48 + 5.16934012087196e+103*cos(theta)**46 - 5.97795198335472e+103*cos(theta)**44 + 5.32499300965496e+103*cos(theta)**42 - 3.74270937250034e+103*cos(theta)**40 + 2.10933042669817e+103*cos(theta)**38 - 9.63521306022621e+102*cos(theta)**36 + 3.59182498694823e+102*cos(theta)**34 - 1.09690463673269e+102*cos(theta)**32 + 2.74780151423948e+101*cos(theta)**30 - 5.64083840818392e+100*cos(theta)**28 + 9.45979111931464e+99*cos(theta)**26 - 1.28907006866971e+99*cos(theta)**24 + 1.41633494806067e+98*cos(theta)**22 - 1.24164467932453e+97*cos(theta)**20 + 8.56617607377129e+95*cos(theta)**18 - 4.56822913658769e+94*cos(theta)**16 + 1.83955535701518e+93*cos(theta)**14 - 5.42272554222161e+91*cos(theta)**12 + 1.12194321563206e+90*cos(theta)**10 - 1.53503936465316e+88*cos(theta)**8 + 1.27012713387378e+86*cos(theta)**6 - 5.48256316780047e+83*cos(theta)**4 + 9.23508675092724e+80*cos(theta)**2 - 2.53363148173587e+77)*sin(40*phi)

#@torch.jit.script
def Yl94_m_minus_39(theta, phi):
    return 1.6024567302825e-76*(1.0 - cos(theta)**2)**19.5*(9.8582156331816e+99*cos(theta)**55 - 7.82858300282068e+100*cos(theta)**53 + 2.9156182102397e+101*cos(theta)**51 - 6.77124447733264e+101*cos(theta)**49 + 1.09985960018552e+102*cos(theta)**47 - 1.32843377407883e+102*cos(theta)**45 + 1.23837046736162e+102*cos(theta)**43 - 9.12855944512279e+101*cos(theta)**41 + 5.40853955563634e+101*cos(theta)**39 - 2.60411163789898e+101*cos(theta)**37 + 1.02623571055664e+101*cos(theta)**35 - 3.32395344464453e+100*cos(theta)**33 + 8.86387585238541e+99*cos(theta)**31 - 1.94511669247721e+99*cos(theta)**29 + 3.5036263404869e+98*cos(theta)**27 - 5.15628027467884e+97*cos(theta)**25 + 6.15797803504639e+96*cos(theta)**23 - 5.91259371106921e+95*cos(theta)**21 + 4.50851372303752e+94*cos(theta)**19 - 2.68719360975746e+93*cos(theta)**17 + 1.22637023801012e+92*cos(theta)**15 - 4.17132734017047e+90*cos(theta)**13 + 1.01994837784732e+89*cos(theta)**11 - 1.70559929405907e+87*cos(theta)**9 + 1.81446733410539e+85*cos(theta)**7 - 1.09651263356009e+83*cos(theta)**5 + 3.07836225030908e+80*cos(theta)**3 - 2.53363148173587e+77*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl94_m_minus_38(theta, phi):
    return 1.38294893902275e-74*(1.0 - cos(theta)**2)**19*(1.76039564878243e+98*cos(theta)**56 - 1.44973759311494e+99*cos(theta)**54 + 5.60695809661481e+99*cos(theta)**52 - 1.35424889546653e+100*cos(theta)**50 + 2.29137416705317e+100*cos(theta)**48 - 2.88789950886702e+100*cos(theta)**46 + 2.81447833491277e+100*cos(theta)**44 - 2.17346653455305e+100*cos(theta)**42 + 1.35213488890908e+100*cos(theta)**40 - 6.85292536289204e+99*cos(theta)**38 + 2.85065475154622e+99*cos(theta)**36 - 9.7763336607192e+98*cos(theta)**34 + 2.76996120387044e+98*cos(theta)**32 - 6.48372230825738e+97*cos(theta)**30 + 1.25129512160247e+97*cos(theta)**28 - 1.98318472103032e+96*cos(theta)**26 + 2.56582418126933e+95*cos(theta)**24 - 2.68754259594055e+94*cos(theta)**22 + 2.25425686151876e+93*cos(theta)**20 - 1.49288533875415e+92*cos(theta)**18 + 7.66481398756323e+90*cos(theta)**16 - 2.97951952869319e+89*cos(theta)**14 + 8.49956981539437e+87*cos(theta)**12 - 1.70559929405907e+86*cos(theta)**10 + 2.26808416763174e+84*cos(theta)**8 - 1.82752105593349e+82*cos(theta)**6 + 7.6959056257727e+79*cos(theta)**4 - 1.26681574086793e+77*cos(theta)**2 + 3.4017608508806e+73)*sin(38*phi)

#@torch.jit.script
def Yl94_m_minus_37(theta, phi):
    return 1.19958365302349e-72*(1.0 - cos(theta)**2)**18.5*(3.08841341891654e+96*cos(theta)**57 - 2.63588653293626e+97*cos(theta)**55 + 1.05791662200279e+98*cos(theta)**53 - 2.65538999111084e+98*cos(theta)**51 + 4.6762738103126e+98*cos(theta)**49 - 6.14446704014259e+98*cos(theta)**47 + 6.25439629980616e+98*cos(theta)**45 - 5.05457333616987e+98*cos(theta)**43 + 3.29788997294898e+98*cos(theta)**41 - 1.7571603494595e+98*cos(theta)**39 + 7.70447230147626e+97*cos(theta)**37 - 2.79323818877691e+97*cos(theta)**35 + 8.39382182991042e+96*cos(theta)**33 - 2.09152332524431e+96*cos(theta)**31 + 4.31481076414643e+95*cos(theta)**29 - 7.34512859640861e+94*cos(theta)**27 + 1.02632967250773e+94*cos(theta)**25 - 1.16849678084372e+93*cos(theta)**23 + 1.07345564834227e+92*cos(theta)**21 - 7.85729125660077e+90*cos(theta)**19 + 4.50871411033131e+89*cos(theta)**17 - 1.98634635246213e+88*cos(theta)**15 + 6.53813062722644e+86*cos(theta)**13 - 1.55054481278097e+85*cos(theta)**11 + 2.52009351959083e+83*cos(theta)**9 - 2.61074436561927e+81*cos(theta)**7 + 1.53918112515454e+79*cos(theta)**5 - 4.22271913622645e+76*cos(theta)**3 + 3.4017608508806e+73*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl94_m_minus_36(theta, phi):
    return 1.04563517283457e-70*(1.0 - cos(theta)**2)**18*(5.3248507222699e+94*cos(theta)**58 - 4.70694023738617e+95*cos(theta)**56 + 1.95910485556073e+96*cos(theta)**54 - 5.10651921367469e+96*cos(theta)**52 + 9.3525476206252e+96*cos(theta)**50 - 1.28009730002971e+97*cos(theta)**48 + 1.35965136952308e+97*cos(theta)**46 - 1.14876666731133e+97*cos(theta)**44 + 7.85211898321187e+96*cos(theta)**42 - 4.39290087364875e+96*cos(theta)**40 + 2.02749271091481e+96*cos(theta)**38 - 7.75899496882476e+95*cos(theta)**36 + 2.46877112644424e+95*cos(theta)**34 - 6.53601039138848e+94*cos(theta)**32 + 1.43827025471548e+94*cos(theta)**30 - 2.62326021300307e+93*cos(theta)**28 + 3.94742181733743e+92*cos(theta)**26 - 4.86873658684882e+91*cos(theta)**24 + 4.87934385610121e+90*cos(theta)**22 - 3.92864562830038e+89*cos(theta)**20 + 2.50484117240629e+88*cos(theta)**18 - 1.24146647028883e+87*cos(theta)**16 + 4.67009330516174e+85*cos(theta)**14 - 1.29212067731748e+84*cos(theta)**12 + 2.52009351959083e+82*cos(theta)**10 - 3.26343045702409e+80*cos(theta)**8 + 2.56530187525757e+78*cos(theta)**6 - 1.05567978405661e+76*cos(theta)**4 + 1.7008804254403e+73*cos(theta)**2 - 4.47717932466517e+69)*sin(36*phi)

#@torch.jit.script
def Yl94_m_minus_35(theta, phi):
    return 9.15751978185659e-69*(1.0 - cos(theta)**2)**17.5*(9.02517071571169e+92*cos(theta)**59 - 8.25778989015118e+93*cos(theta)**57 + 3.56200882829224e+94*cos(theta)**55 - 9.63494191259376e+94*cos(theta)**53 + 1.83383286678925e+95*cos(theta)**51 - 2.61244346944838e+95*cos(theta)**49 + 2.89287525430442e+95*cos(theta)**47 - 2.55281481624741e+95*cos(theta)**45 + 1.8260741821423e+95*cos(theta)**43 - 1.0714392374753e+95*cos(theta)**41 + 5.19869925875591e+94*cos(theta)**39 - 2.09702566724993e+94*cos(theta)**37 + 7.05363178984069e+93*cos(theta)**35 - 1.98060920951166e+93*cos(theta)**33 + 4.63958146682412e+92*cos(theta)**31 - 9.04572487242439e+91*cos(theta)**29 + 1.46200808049534e+91*cos(theta)**27 - 1.94749463473953e+90*cos(theta)**25 + 2.12145385047879e+89*cos(theta)**23 - 1.87078363252399e+88*cos(theta)**21 + 1.3183374591612e+87*cos(theta)**19 - 7.30274394287547e+85*cos(theta)**17 + 3.11339553677449e+84*cos(theta)**15 - 9.93938982551906e+82*cos(theta)**13 + 2.29099410871893e+81*cos(theta)**11 - 3.62603384113788e+79*cos(theta)**9 + 3.66471696465367e+77*cos(theta)**7 - 2.11135956811322e+75*cos(theta)**5 + 5.66960141813433e+72*cos(theta)**3 - 4.47717932466517e+69*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl94_m_minus_34(theta, phi):
    return 8.05653588471146e-67*(1.0 - cos(theta)**2)**17*(1.50419511928528e+91*cos(theta)**60 - 1.42375687761227e+92*cos(theta)**58 + 6.36073005052185e+92*cos(theta)**56 - 1.78424850233218e+93*cos(theta)**54 + 3.52660166690241e+93*cos(theta)**52 - 5.22488693889676e+93*cos(theta)**50 + 6.02682344646754e+93*cos(theta)**48 - 5.54959742662481e+93*cos(theta)**46 + 4.15016859577794e+93*cos(theta)**44 - 2.55104580351263e+93*cos(theta)**42 + 1.29967481468898e+93*cos(theta)**40 - 5.51848859802614e+92*cos(theta)**38 + 1.95934216384464e+92*cos(theta)**36 - 5.82532120444606e+91*cos(theta)**34 + 1.44986920838254e+91*cos(theta)**32 - 3.01524162414146e+90*cos(theta)**30 + 5.22145743034051e+89*cos(theta)**28 - 7.49036397976741e+88*cos(theta)**26 + 8.83939104366162e+87*cos(theta)**24 - 8.50356196601815e+86*cos(theta)**22 + 6.59168729580601e+85*cos(theta)**20 - 4.05707996826415e+84*cos(theta)**18 + 1.94587221048406e+83*cos(theta)**16 - 7.09956416108504e+81*cos(theta)**14 + 1.90916175726578e+80*cos(theta)**12 - 3.62603384113788e+78*cos(theta)**10 + 4.58089620581708e+76*cos(theta)**8 - 3.51893261352204e+74*cos(theta)**6 + 1.41740035453358e+72*cos(theta)**4 - 2.23858966233259e+69*cos(theta)**2 + 5.78446941171211e+65)*sin(34*phi)

#@torch.jit.script
def Yl94_m_minus_33(theta, phi):
    return 7.11898779156498e-65*(1.0 - cos(theta)**2)**16.5*(2.46589363817259e+89*cos(theta)**61 - 2.41314725019029e+90*cos(theta)**59 + 1.11591755272313e+91*cos(theta)**57 - 3.24408818605851e+91*cos(theta)**55 + 6.65396540924984e+91*cos(theta)**53 - 1.0244876350778e+92*cos(theta)**51 + 1.22996396866685e+92*cos(theta)**49 - 1.18076540992017e+92*cos(theta)**47 + 9.22259687950654e+91*cos(theta)**45 - 5.93266465933169e+91*cos(theta)**43 + 3.16993857241214e+91*cos(theta)**41 - 1.41499707641696e+91*cos(theta)**39 + 5.29551936174226e+90*cos(theta)**37 - 1.66437748698459e+90*cos(theta)**35 + 4.39354305570466e+89*cos(theta)**33 - 9.7265858843273e+88*cos(theta)**31 + 1.80050256218638e+88*cos(theta)**29 - 2.77420888139534e+87*cos(theta)**27 + 3.53575641746465e+86*cos(theta)**25 - 3.6972008547905e+85*cos(theta)**23 + 3.13889871228858e+84*cos(theta)**21 - 2.13530524645482e+83*cos(theta)**19 + 1.14463071204945e+82*cos(theta)**17 - 4.73304277405669e+80*cos(theta)**15 + 1.46858596712752e+79*cos(theta)**13 - 3.29639440103443e+77*cos(theta)**11 + 5.08988467313009e+75*cos(theta)**9 - 5.02704659074577e+73*cos(theta)**7 + 2.83480070906716e+71*cos(theta)**5 - 7.46196554110862e+68*cos(theta)**3 + 5.78446941171211e+65*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl94_m_minus_32(theta, phi):
    return 6.31707384021571e-63*(1.0 - cos(theta)**2)**16*(3.97724780350418e+87*cos(theta)**62 - 4.02191208365049e+88*cos(theta)**60 + 1.92399578055712e+89*cos(theta)**58 - 5.79301461796162e+89*cos(theta)**56 + 1.23221581652775e+90*cos(theta)**54 - 1.97016852899576e+90*cos(theta)**52 + 2.45992793733369e+90*cos(theta)**50 - 2.45992793733369e+90*cos(theta)**48 + 2.00491236511012e+90*cos(theta)**46 - 1.34833287712084e+90*cos(theta)**44 + 7.54747279145748e+89*cos(theta)**42 - 3.5374926910424e+89*cos(theta)**40 + 1.39355772677428e+89*cos(theta)**38 - 4.62327079717942e+88*cos(theta)**36 + 1.29221854579549e+88*cos(theta)**34 - 3.03955808885228e+87*cos(theta)**32 + 6.00167520728794e+86*cos(theta)**30 - 9.90788886212621e+85*cos(theta)**28 + 1.35990631440948e+85*cos(theta)**26 - 1.54050035616271e+84*cos(theta)**24 + 1.42677214194935e+83*cos(theta)**22 - 1.06765262322741e+82*cos(theta)**20 + 6.35905951138581e+80*cos(theta)**18 - 2.95815173378543e+79*cos(theta)**16 + 1.04898997651966e+78*cos(theta)**14 - 2.74699533419536e+76*cos(theta)**12 + 5.08988467313009e+74*cos(theta)**10 - 6.28380823843221e+72*cos(theta)**8 + 4.72466784844527e+70*cos(theta)**6 - 1.86549138527715e+68*cos(theta)**4 + 2.89223470585605e+65*cos(theta)**2 - 7.34629084545607e+61)*sin(32*phi)

#@torch.jit.script
def Yl94_m_minus_31(theta, phi):
    return 5.62822564458757e-61*(1.0 - cos(theta)**2)**15.5*(6.31309175159394e+85*cos(theta)**63 - 6.59329849778768e+86*cos(theta)**61 + 3.26100979755445e+87*cos(theta)**59 - 1.01631835402835e+88*cos(theta)**57 + 2.24039239368681e+88*cos(theta)**55 - 3.71729911131276e+88*cos(theta)**53 + 4.823388112419e+88*cos(theta)**51 - 5.02026109659937e+88*cos(theta)**49 + 4.265770989596e+88*cos(theta)**47 - 2.99629528249075e+88*cos(theta)**45 + 1.75522623057151e+88*cos(theta)**43 - 8.62803095376195e+87*cos(theta)**41 + 3.57322494044687e+87*cos(theta)**39 - 1.24953264788633e+87*cos(theta)**37 + 3.69205298798711e+86*cos(theta)**35 - 9.21078208743116e+85*cos(theta)**33 + 1.93602426041547e+85*cos(theta)**31 - 3.41651340073318e+84*cos(theta)**29 + 5.03669005336844e+83*cos(theta)**27 - 6.16200142465083e+82*cos(theta)**25 + 6.20335713891023e+81*cos(theta)**23 - 5.0840601106067e+80*cos(theta)**21 + 3.34687342704516e+79*cos(theta)**19 - 1.7400892551679e+78*cos(theta)**17 + 6.99326651013105e+76*cos(theta)**15 - 2.11307333399643e+75*cos(theta)**13 + 4.62716788466372e+73*cos(theta)**11 - 6.98200915381357e+71*cos(theta)**9 + 6.74952549777896e+69*cos(theta)**7 - 3.73098277055431e+67*cos(theta)**5 + 9.64078235285351e+64*cos(theta)**3 - 7.34629084545607e+61*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl94_m_minus_30(theta, phi):
    return 5.03403805360215e-59*(1.0 - cos(theta)**2)**15*(9.86420586186554e+83*cos(theta)**64 - 1.06343524157866e+85*cos(theta)**62 + 5.43501632925741e+85*cos(theta)**60 - 1.75227302418682e+86*cos(theta)**58 + 4.00070070301217e+86*cos(theta)**56 - 6.88388724317177e+86*cos(theta)**54 + 9.27574637003654e+86*cos(theta)**52 - 1.00405221931987e+87*cos(theta)**50 + 8.88702289499166e+86*cos(theta)**48 - 6.51368539671903e+86*cos(theta)**46 + 3.98915052402615e+86*cos(theta)**44 - 2.05429308422904e+86*cos(theta)**42 + 8.93306235111717e+85*cos(theta)**40 - 3.28824381022718e+85*cos(theta)**38 + 1.02557027444086e+85*cos(theta)**36 - 2.70905355512681e+84*cos(theta)**34 + 6.05007581379833e+83*cos(theta)**32 - 1.13883780024439e+83*cos(theta)**30 + 1.79881787620302e+82*cos(theta)**28 - 2.37000054794263e+81*cos(theta)**26 + 2.5847321412126e+80*cos(theta)**24 - 2.31093641391214e+79*cos(theta)**22 + 1.67343671352258e+78*cos(theta)**20 - 9.66716252871057e+76*cos(theta)**18 + 4.37079156883191e+75*cos(theta)**16 - 1.50933809571174e+74*cos(theta)**14 + 3.85597323721977e+72*cos(theta)**12 - 6.98200915381357e+70*cos(theta)**10 + 8.4369068722237e+68*cos(theta)**8 - 6.21830461759051e+66*cos(theta)**6 + 2.41019558821338e+64*cos(theta)**4 - 3.67314542272803e+61*cos(theta)**2 + 9.18286355682008e+57)*sin(30*phi)

#@torch.jit.script
def Yl94_m_minus_29(theta, phi):
    return 4.51943365200135e-57*(1.0 - cos(theta)**2)**14.5*(1.5175701325947e+82*cos(theta)**65 - 1.68799244695025e+83*cos(theta)**63 + 8.90986283484822e+83*cos(theta)**61 - 2.96995427828274e+84*cos(theta)**59 + 7.01877316317924e+84*cos(theta)**57 - 1.25161586239487e+85*cos(theta)**55 + 1.7501408245352e+85*cos(theta)**53 - 1.96872984180367e+85*cos(theta)**51 + 1.81367814183503e+85*cos(theta)**49 - 1.38589050994022e+85*cos(theta)**47 + 8.86477894228034e+84*cos(theta)**45 - 4.77742577727683e+84*cos(theta)**43 + 2.17879569539443e+84*cos(theta)**41 - 8.4313943851979e+83*cos(theta)**39 + 2.77181155254288e+83*cos(theta)**37 - 7.74015301464803e+82*cos(theta)**35 + 1.83335630721162e+82*cos(theta)**33 - 3.67367032336901e+81*cos(theta)**31 + 6.20282026276902e+80*cos(theta)**29 - 8.77777980719492e+79*cos(theta)**27 + 1.03389285648504e+79*cos(theta)**25 - 1.00475496257049e+78*cos(theta)**23 + 7.96874625486944e+76*cos(theta)**21 - 5.08798027826872e+75*cos(theta)**19 + 2.57105386401877e+74*cos(theta)**17 - 1.00622539714116e+73*cos(theta)**15 + 2.96613325939982e+71*cos(theta)**13 - 6.34728104892143e+69*cos(theta)**11 + 9.37434096913745e+67*cos(theta)**9 - 8.88329231084359e+65*cos(theta)**7 + 4.82039117642676e+63*cos(theta)**5 - 1.22438180757601e+61*cos(theta)**3 + 9.18286355682008e+57*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl94_m_minus_28(theta, phi):
    return 4.07200721244265e-55*(1.0 - cos(theta)**2)**14*(2.29934868574954e+80*cos(theta)**66 - 2.63748819835977e+81*cos(theta)**64 + 1.43707465078197e+82*cos(theta)**62 - 4.9499237971379e+82*cos(theta)**60 + 1.21013330399642e+83*cos(theta)**58 - 2.23502832570512e+83*cos(theta)**56 + 3.24100152691703e+83*cos(theta)**54 - 3.78601892654553e+83*cos(theta)**52 + 3.62735628367006e+83*cos(theta)**50 - 2.88727189570879e+83*cos(theta)**48 + 1.92712585701746e+83*cos(theta)**46 - 1.08577858574473e+83*cos(theta)**44 + 5.18760879855817e+82*cos(theta)**42 - 2.10784859629947e+82*cos(theta)**40 + 7.29424092774441e+81*cos(theta)**38 - 2.1500425040689e+81*cos(theta)**36 + 5.39222443297534e+80*cos(theta)**34 - 1.14802197605281e+80*cos(theta)**32 + 2.06760675425634e+79*cos(theta)**30 - 3.13492135971247e+78*cos(theta)**28 + 3.97651098648092e+77*cos(theta)**26 - 4.18647901071039e+76*cos(theta)**24 + 3.62215738857702e+75*cos(theta)**22 - 2.54399013913436e+74*cos(theta)**20 + 1.4283632577882e+73*cos(theta)**18 - 6.28890873213224e+71*cos(theta)**16 + 2.11866661385701e+70*cos(theta)**14 - 5.28940087410119e+68*cos(theta)**12 + 9.37434096913745e+66*cos(theta)**10 - 1.11041153885545e+65*cos(theta)**8 + 8.03398529404459e+62*cos(theta)**6 - 3.06095451894003e+60*cos(theta)**4 + 4.59143177841004e+57*cos(theta)**2 - 1.13117314077606e+54)*sin(28*phi)

#@torch.jit.script
def Yl94_m_minus_27(theta, phi):
    return 3.68150890453798e-53*(1.0 - cos(theta)**2)**13.5*(3.43186371007394e+78*cos(theta)**67 - 4.05767415132272e+79*cos(theta)**65 + 2.2810708742571e+80*cos(theta)**63 - 8.1146291756359e+80*cos(theta)**61 + 2.0510733966041e+81*cos(theta)**59 - 3.92110232579846e+81*cos(theta)**57 + 5.89273004894005e+81*cos(theta)**55 - 7.14343193687835e+81*cos(theta)**53 + 7.11246330131385e+81*cos(theta)**51 - 5.89239162389549e+81*cos(theta)**49 + 4.10026778088822e+81*cos(theta)**47 - 2.41284130165496e+81*cos(theta)**45 + 1.20642065082748e+81*cos(theta)**43 - 5.14109413731579e+80*cos(theta)**41 + 1.87031818660113e+80*cos(theta)**39 - 5.8109256866727e+79*cos(theta)**37 + 1.54063555227867e+79*cos(theta)**35 - 3.47885447288732e+78*cos(theta)**33 + 6.66969920727851e+77*cos(theta)**31 - 1.08100736541809e+77*cos(theta)**29 + 1.47278184684478e+76*cos(theta)**27 - 1.67459160428416e+75*cos(theta)**25 + 1.57485103851175e+74*cos(theta)**23 - 1.21142387577827e+73*cos(theta)**21 + 7.51770135678002e+71*cos(theta)**19 - 3.69935807772485e+70*cos(theta)**17 + 1.41244440923801e+69*cos(theta)**15 - 4.06876990315476e+67*cos(theta)**13 + 8.52212815376132e+65*cos(theta)**11 - 1.23379059872828e+64*cos(theta)**9 + 1.14771218486351e+62*cos(theta)**7 - 6.12190903788006e+59*cos(theta)**5 + 1.53047725947001e+57*cos(theta)**3 - 1.13117314077606e+54*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl94_m_minus_26(theta, phi):
    return 3.33943501651365e-51*(1.0 - cos(theta)**2)**13*(5.04685839716756e+76*cos(theta)**68 - 6.14799113836776e+77*cos(theta)**66 + 3.56417324102671e+78*cos(theta)**64 - 1.30881115736063e+79*cos(theta)**62 + 3.41845566100684e+79*cos(theta)**60 - 6.76052125137665e+79*cos(theta)**58 + 1.05227322302501e+80*cos(theta)**56 - 1.32285776608858e+80*cos(theta)**54 + 1.36778140409882e+80*cos(theta)**52 - 1.1784783247791e+80*cos(theta)**50 + 8.54222454351713e+79*cos(theta)**48 - 5.24530717751079e+79*cos(theta)**46 + 2.741865115517e+79*cos(theta)**44 - 1.22407003269424e+79*cos(theta)**42 + 4.67579546650283e+78*cos(theta)**40 - 1.52919097017703e+78*cos(theta)**38 + 4.27954320077408e+77*cos(theta)**36 - 1.02319249202568e+77*cos(theta)**34 + 2.08428100227454e+76*cos(theta)**32 - 3.60335788472698e+75*cos(theta)**30 + 5.2599351673028e+74*cos(theta)**28 - 6.44073693955445e+73*cos(theta)**26 + 6.56187932713228e+72*cos(theta)**24 - 5.50647216262849e+71*cos(theta)**22 + 3.75885067839001e+70*cos(theta)**20 - 2.05519893206936e+69*cos(theta)**18 + 8.82777755773756e+67*cos(theta)**16 - 2.90626421653912e+66*cos(theta)**14 + 7.10177346146776e+64*cos(theta)**12 - 1.23379059872828e+63*cos(theta)**10 + 1.43464023107939e+61*cos(theta)**8 - 1.02031817298001e+59*cos(theta)**6 + 3.82619314867503e+56*cos(theta)**4 - 5.65586570388032e+53*cos(theta)**2 + 1.37478505198841e+50)*sin(26*phi)

#@torch.jit.script
def Yl94_m_minus_25(theta, phi):
    return 3.03870237404727e-49*(1.0 - cos(theta)**2)**12.5*(7.3142875321269e+74*cos(theta)**69 - 9.1761061766683e+75*cos(theta)**67 + 5.48334344773341e+76*cos(theta)**65 - 2.07747802755655e+77*cos(theta)**63 + 5.6040256737817e+77*cos(theta)**61 - 1.14585105955536e+78*cos(theta)**59 + 1.84609337372809e+78*cos(theta)**57 - 2.40519593834288e+78*cos(theta)**55 + 2.58071963037513e+78*cos(theta)**53 - 2.31074181329235e+78*cos(theta)**51 + 1.74331113133003e+78*cos(theta)**49 - 1.1160228037257e+78*cos(theta)**47 + 6.09303359003779e+77*cos(theta)**45 - 2.84667449463776e+77*cos(theta)**43 + 1.14043791865923e+77*cos(theta)**41 - 3.9210024876334e+76*cos(theta)**39 + 1.15663329750651e+76*cos(theta)**37 - 2.92340712007337e+75*cos(theta)**35 + 6.31600303719556e+74*cos(theta)**33 - 1.16237351120225e+74*cos(theta)**31 + 1.81377074734579e+73*cos(theta)**29 - 2.38545812576091e+72*cos(theta)**27 + 2.62475173085291e+71*cos(theta)**25 - 2.3941183315776e+70*cos(theta)**23 + 1.78992889447143e+69*cos(theta)**21 - 1.08168364845756e+68*cos(theta)**19 + 5.19281032808092e+66*cos(theta)**17 - 1.93750947769274e+65*cos(theta)**15 + 5.46290266266751e+63*cos(theta)**13 - 1.12162781702571e+62*cos(theta)**11 + 1.59404470119932e+60*cos(theta)**9 - 1.45759738997144e+58*cos(theta)**7 + 7.65238629735007e+55*cos(theta)**5 - 1.88528856796011e+53*cos(theta)**3 + 1.37478505198841e+50*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl94_m_minus_24(theta, phi):
    return 2.77338821558175e-47*(1.0 - cos(theta)**2)**12*(1.04489821887527e+73*cos(theta)**70 - 1.34942737892181e+74*cos(theta)**68 + 8.3080961329294e+74*cos(theta)**66 - 3.24605941805712e+75*cos(theta)**64 + 9.03875108674468e+75*cos(theta)**62 - 1.90975176592561e+76*cos(theta)**60 + 3.18291960987601e+76*cos(theta)**58 - 4.29499274704086e+76*cos(theta)**56 + 4.77911042662061e+76*cos(theta)**54 - 4.44373425633144e+76*cos(theta)**52 + 3.48662226266005e+76*cos(theta)**50 - 2.32504750776188e+76*cos(theta)**48 + 1.32457251957343e+76*cos(theta)**46 - 6.46971476054036e+75*cos(theta)**44 + 2.71532837776006e+75*cos(theta)**42 - 9.8025062190835e+74*cos(theta)**40 + 3.04377183554344e+74*cos(theta)**38 - 8.12057533353715e+73*cos(theta)**36 + 1.85764795211634e+73*cos(theta)**34 - 3.63241722250703e+72*cos(theta)**32 + 6.04590249115265e+71*cos(theta)**30 - 8.51949330628896e+70*cos(theta)**28 + 1.00951989648189e+70*cos(theta)**26 - 9.97549304824001e+68*cos(theta)**24 + 8.13604042941561e+67*cos(theta)**22 - 5.40841824228779e+66*cos(theta)**20 + 2.88489462671162e+65*cos(theta)**18 - 1.21094342355796e+64*cos(theta)**16 + 3.90207333047679e+62*cos(theta)**14 - 9.34689847521422e+60*cos(theta)**12 + 1.59404470119932e+59*cos(theta)**10 - 1.8219967374643e+57*cos(theta)**8 + 1.27539771622501e+55*cos(theta)**6 - 4.71322141990026e+52*cos(theta)**4 + 6.87392525994205e+49*cos(theta)**2 - 1.6504022232754e+46)*sin(24*phi)

#@torch.jit.script
def Yl94_m_minus_23(theta, phi):
    return 2.53852148748199e-45*(1.0 - cos(theta)**2)**11.5*(1.47168763221869e+71*cos(theta)**71 - 1.95569185350987e+72*cos(theta)**69 + 1.24001434819842e+73*cos(theta)**67 - 4.99393756624172e+73*cos(theta)**65 + 1.43472239472138e+74*cos(theta)**63 - 3.13074059987805e+74*cos(theta)**61 + 5.39477899978985e+74*cos(theta)**59 - 7.53507499480852e+74*cos(theta)**57 + 8.68929168476474e+74*cos(theta)**55 - 8.38440425722913e+74*cos(theta)**53 + 6.83651424050991e+74*cos(theta)**51 - 4.74499491379975e+74*cos(theta)**49 + 2.81823940334773e+74*cos(theta)**47 - 1.43771439123119e+74*cos(theta)**45 + 6.31471715758154e+73*cos(theta)**43 - 2.39085517538622e+73*cos(theta)**41 + 7.80454316806011e+72*cos(theta)**39 - 2.19475009014518e+72*cos(theta)**37 + 5.30756557747526e+71*cos(theta)**35 - 1.1007324916688e+71*cos(theta)**33 + 1.95029112617827e+70*cos(theta)**31 - 2.93775631251343e+69*cos(theta)**29 + 3.73896257956255e+68*cos(theta)**27 - 3.990197219296e+67*cos(theta)**25 + 3.53740888235461e+66*cos(theta)**23 - 2.57543725823228e+65*cos(theta)**21 + 1.51836559300612e+64*cos(theta)**19 - 7.1231966091645e+62*cos(theta)**17 + 2.60138222031786e+61*cos(theta)**15 - 7.18992190401094e+59*cos(theta)**13 + 1.44913154654484e+58*cos(theta)**11 - 2.02444081940478e+56*cos(theta)**9 + 1.8219967374643e+54*cos(theta)**7 - 9.42644283980053e+51*cos(theta)**5 + 2.29130841998068e+49*cos(theta)**3 - 1.6504022232754e+46*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl94_m_minus_22(theta, phi):
    return 2.32991470806215e-43*(1.0 - cos(theta)**2)**11*(2.04401060030374e+69*cos(theta)**72 - 2.7938455050141e+70*cos(theta)**70 + 1.8235505120565e+71*cos(theta)**68 - 7.56657207006321e+71*cos(theta)**66 + 2.24175374175215e+72*cos(theta)**64 - 5.04958161270652e+72*cos(theta)**62 + 8.99129833298309e+72*cos(theta)**60 - 1.29915086117388e+73*cos(theta)**58 + 1.55165922942227e+73*cos(theta)**56 - 1.55266745504243e+73*cos(theta)**54 + 1.31471427702114e+73*cos(theta)**52 - 9.48998982759949e+72*cos(theta)**50 + 5.87133209030777e+72*cos(theta)**48 - 3.12546606789389e+72*cos(theta)**46 + 1.43516299035944e+72*cos(theta)**44 - 5.69251232234814e+71*cos(theta)**42 + 1.95113579201503e+71*cos(theta)**40 - 5.77565813196099e+70*cos(theta)**38 + 1.47432377152091e+70*cos(theta)**36 - 3.23744850490823e+69*cos(theta)**34 + 6.0946597693071e+68*cos(theta)**32 - 9.79252104171144e+67*cos(theta)**30 + 1.3353437784152e+67*cos(theta)**28 - 1.53469123819077e+66*cos(theta)**26 + 1.47392036764776e+65*cos(theta)**24 - 1.17065329919649e+64*cos(theta)**22 + 7.59182796503058e+62*cos(theta)**20 - 3.95733144953583e+61*cos(theta)**18 + 1.62586388769866e+60*cos(theta)**16 - 5.13565850286495e+58*cos(theta)**14 + 1.2076096221207e+57*cos(theta)**12 - 2.02444081940478e+55*cos(theta)**10 + 2.27749592183038e+53*cos(theta)**8 - 1.57107380663342e+51*cos(theta)**6 + 5.72827104995171e+48*cos(theta)**4 - 8.25201111637701e+45*cos(theta)**2 + 1.95916693171344e+42)*sin(22*phi)

#@torch.jit.script
def Yl94_m_minus_21(theta, phi):
    return 2.14402797478665e-41*(1.0 - cos(theta)**2)**10.5*(2.80001452096403e+67*cos(theta)**73 - 3.93499366903394e+68*cos(theta)**71 + 2.64282682906739e+69*cos(theta)**69 - 1.12933911493481e+70*cos(theta)**67 + 3.44885191038793e+70*cos(theta)**65 - 8.01520890905798e+70*cos(theta)**63 + 1.47398333327592e+71*cos(theta)**61 - 2.20195061215912e+71*cos(theta)**59 + 2.72220917442504e+71*cos(theta)**57 - 2.82303173644079e+71*cos(theta)**55 + 2.48059297551158e+71*cos(theta)**53 - 1.86078231913716e+71*cos(theta)**51 + 1.19823103883832e+71*cos(theta)**49 - 6.64992780402956e+70*cos(theta)**47 + 3.18925108968765e+70*cos(theta)**45 - 1.32384007496468e+70*cos(theta)**43 + 4.7588677854025e+69*cos(theta)**41 - 1.4809379825541e+69*cos(theta)**39 + 3.9846588419484e+68*cos(theta)**37 - 9.24985287116637e+67*cos(theta)**35 + 1.84686659675973e+67*cos(theta)**33 - 3.15887775539079e+66*cos(theta)**31 + 4.60463371867309e+65*cos(theta)**29 - 5.68404162292878e+64*cos(theta)**27 + 5.89568147059102e+63*cos(theta)**25 - 5.08979695302822e+62*cos(theta)**23 + 3.61515617382409e+61*cos(theta)**21 - 2.08280602607149e+60*cos(theta)**19 + 9.56390522175684e+58*cos(theta)**17 - 3.4237723352433e+57*cos(theta)**15 + 9.28930478554385e+55*cos(theta)**13 - 1.84040074491344e+54*cos(theta)**11 + 2.53055102425598e+52*cos(theta)**9 - 2.24439115233346e+50*cos(theta)**7 + 1.14565420999034e+48*cos(theta)**5 - 2.75067037212567e+45*cos(theta)**3 + 1.95916693171344e+42*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl94_m_minus_20(theta, phi):
    return 1.97785854375996e-39*(1.0 - cos(theta)**2)**10*(3.78380340670815e+65*cos(theta)**74 - 5.46526898476936e+66*cos(theta)**72 + 3.7754668986677e+67*cos(theta)**70 - 1.6607928160806e+68*cos(theta)**68 + 5.22553319755747e+68*cos(theta)**66 - 1.25237639204031e+69*cos(theta)**64 + 2.37739247302567e+69*cos(theta)**62 - 3.66991768693187e+69*cos(theta)**60 + 4.69346409383628e+69*cos(theta)**58 - 5.04112810078712e+69*cos(theta)**56 + 4.59369069539181e+69*cos(theta)**54 - 3.57842753680222e+69*cos(theta)**52 + 2.39646207767664e+69*cos(theta)**50 - 1.38540162583949e+69*cos(theta)**48 + 6.93315454279923e+68*cos(theta)**46 - 3.00872744310155e+68*cos(theta)**44 + 1.13306375842917e+68*cos(theta)**42 - 3.70234495638525e+67*cos(theta)**40 + 1.04859443209168e+67*cos(theta)**38 - 2.56940357532399e+66*cos(theta)**36 + 5.43196057870508e+65*cos(theta)**34 - 9.87149298559621e+64*cos(theta)**32 + 1.53487790622436e+64*cos(theta)**30 - 2.03001486533171e+63*cos(theta)**28 + 2.26756979638116e+62*cos(theta)**26 - 2.12074873042843e+61*cos(theta)**24 + 1.64325280628368e+60*cos(theta)**22 - 1.04140301303575e+59*cos(theta)**20 + 5.3132806787538e+57*cos(theta)**18 - 2.13985770952706e+56*cos(theta)**16 + 6.63521770395989e+54*cos(theta)**14 - 1.53366728742786e+53*cos(theta)**12 + 2.53055102425598e+51*cos(theta)**10 - 2.80548894041682e+49*cos(theta)**8 + 1.90942368331724e+47*cos(theta)**6 - 6.87667593031417e+44*cos(theta)**4 + 9.7958346585672e+41*cos(theta)**2 - 2.30219380929899e+38)*sin(20*phi)

#@torch.jit.script
def Yl94_m_minus_19(theta, phi):
    return 1.82885083545686e-37*(1.0 - cos(theta)**2)**9.5*(5.04507120894419e+63*cos(theta)**75 - 7.48666984214981e+64*cos(theta)**73 + 5.31755901220802e+65*cos(theta)**71 - 2.40694611026174e+66*cos(theta)**69 + 7.79930327993651e+66*cos(theta)**67 - 1.92673291083124e+67*cos(theta)**65 + 3.77363884607249e+67*cos(theta)**63 - 6.016258503167e+67*cos(theta)**61 + 7.9550238878581e+67*cos(theta)**59 - 8.84408438734582e+67*cos(theta)**57 + 8.35216490071238e+67*cos(theta)**55 - 6.75175006943815e+67*cos(theta)**53 + 4.69894525034635e+67*cos(theta)**51 - 2.82735025681529e+67*cos(theta)**49 + 1.47513926442537e+67*cos(theta)**47 - 6.68606098467012e+66*cos(theta)**45 + 2.6350319963469e+66*cos(theta)**43 - 9.03010964972012e+65*cos(theta)**41 + 2.68870367202996e+65*cos(theta)**39 - 6.94433398736214e+64*cos(theta)**37 + 1.55198873677288e+64*cos(theta)**35 - 2.99136151078673e+63*cos(theta)**33 + 4.95121905233666e+62*cos(theta)**31 - 7.00005125976451e+61*cos(theta)**29 + 8.39840665326356e+60*cos(theta)**27 - 8.4829949217137e+59*cos(theta)**25 + 7.14457741862468e+58*cos(theta)**23 - 4.95906196683688e+57*cos(theta)**21 + 2.79646351513358e+56*cos(theta)**19 - 1.25873982913357e+55*cos(theta)**17 + 4.42347846930659e+53*cos(theta)**15 - 1.1797440672522e+52*cos(theta)**13 + 2.3005009311418e+50*cos(theta)**11 - 3.11720993379647e+48*cos(theta)**9 + 2.72774811902462e+46*cos(theta)**7 - 1.37533518606283e+44*cos(theta)**5 + 3.2652782195224e+41*cos(theta)**3 - 2.30219380929899e+38*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl94_m_minus_18(theta, phi):
    return 1.69482281992191e-35*(1.0 - cos(theta)**2)**9*(6.63825159071604e+61*cos(theta)**76 - 1.01171214083105e+63*cos(theta)**74 + 7.3854986280667e+63*cos(theta)**72 - 3.43849444323105e+64*cos(theta)**70 + 1.14695636469655e+65*cos(theta)**68 - 2.91929228913825e+65*cos(theta)**66 + 5.89631069698827e+65*cos(theta)**64 - 9.70364274704355e+65*cos(theta)**62 + 1.32583731464302e+66*cos(theta)**60 - 1.52484213574928e+66*cos(theta)**58 + 1.49145801798435e+66*cos(theta)**56 - 1.25032408693299e+66*cos(theta)**54 + 9.03643317374298e+65*cos(theta)**52 - 5.65470051363058e+65*cos(theta)**50 + 3.07320680088618e+65*cos(theta)**48 - 1.45349151840655e+65*cos(theta)**46 + 5.9887090826066e+64*cos(theta)**44 - 2.15002610707622e+64*cos(theta)**42 + 6.72175918007489e+63*cos(theta)**40 - 1.82745631246372e+63*cos(theta)**38 + 4.31107982436911e+62*cos(theta)**36 - 8.79812209054921e+61*cos(theta)**34 + 1.54725595385521e+61*cos(theta)**32 - 2.3333504199215e+60*cos(theta)**30 + 2.99943094759413e+59*cos(theta)**28 - 3.26269035450527e+58*cos(theta)**26 + 2.97690725776028e+57*cos(theta)**24 - 2.25411907583495e+56*cos(theta)**22 + 1.39823175756679e+55*cos(theta)**20 - 6.99299905074204e+53*cos(theta)**18 + 2.76467404331662e+52*cos(theta)**16 - 8.42674333751574e+50*cos(theta)**14 + 1.91708410928483e+49*cos(theta)**12 - 3.11720993379647e+47*cos(theta)**10 + 3.40968514878078e+45*cos(theta)**8 - 2.29222531010472e+43*cos(theta)**6 + 8.163195548806e+40*cos(theta)**4 - 1.15109690464949e+38*cos(theta)**2 + 2.68071007137749e+34)*sin(18*phi)

#@torch.jit.script
def Yl94_m_minus_17(theta, phi):
    return 1.57390558634765e-33*(1.0 - cos(theta)**2)**8.5*(8.62110596196889e+59*cos(theta)**77 - 1.34894952110807e+61*cos(theta)**75 + 1.01171214083105e+62*cos(theta)**73 - 4.84294992004374e+62*cos(theta)**71 + 1.66225560100949e+63*cos(theta)**69 - 4.3571526703556e+63*cos(theta)**67 + 9.0712472261358e+63*cos(theta)**65 - 1.54026075349898e+64*cos(theta)**63 + 2.17350379449675e+64*cos(theta)**61 - 2.58447819618522e+64*cos(theta)**59 + 2.61659301400764e+64*cos(theta)**57 - 2.27331652169635e+64*cos(theta)**55 + 1.70498739127226e+64*cos(theta)**53 - 1.10876480659423e+64*cos(theta)**51 + 6.27185061405344e+63*cos(theta)**49 - 3.09253514554585e+63*cos(theta)**47 + 1.33082424057924e+63*cos(theta)**45 - 5.00006071413074e+62*cos(theta)**43 + 1.63945345855485e+62*cos(theta)**41 - 4.68578541657364e+61*cos(theta)**39 + 1.16515670928895e+61*cos(theta)**37 - 2.51374916872835e+60*cos(theta)**35 + 4.68865440562184e+59*cos(theta)**33 - 7.52693683845646e+58*cos(theta)**31 + 1.03428653365315e+58*cos(theta)**29 - 1.20840383500195e+57*cos(theta)**27 + 1.19076290310411e+56*cos(theta)**25 - 9.80051772102151e+54*cos(theta)**23 + 6.65824646460376e+53*cos(theta)**21 - 3.68052581618002e+52*cos(theta)**19 + 1.62627884900978e+51*cos(theta)**17 - 5.61782889167716e+49*cos(theta)**15 + 1.47468008406525e+48*cos(theta)**13 - 2.83382721254225e+46*cos(theta)**11 + 3.78853905420086e+44*cos(theta)**9 - 3.27460758586389e+42*cos(theta)**7 + 1.6326391097612e+40*cos(theta)**5 - 3.83698968216498e+37*cos(theta)**3 + 2.68071007137749e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl94_m_minus_16(theta, phi):
    return 1.46449356450711e-31*(1.0 - cos(theta)**2)**8*(1.10526999512422e+58*cos(theta)**78 - 1.77493358040536e+59*cos(theta)**76 + 1.36717856869061e+60*cos(theta)**74 - 6.72631933339408e+60*cos(theta)**72 + 2.37465085858498e+61*cos(theta)**70 - 6.40757745640529e+61*cos(theta)**68 + 1.37443139789936e+62*cos(theta)**66 - 2.40665742734215e+62*cos(theta)**64 + 3.50565128144637e+62*cos(theta)**62 - 4.3074636603087e+62*cos(theta)**60 + 4.51136726553041e+62*cos(theta)**58 - 4.05949378874348e+62*cos(theta)**56 + 3.15738405791159e+62*cos(theta)**54 - 2.13224001268121e+62*cos(theta)**52 + 1.25437012281069e+62*cos(theta)**50 - 6.44278155322051e+61*cos(theta)**48 + 2.89309617517227e+61*cos(theta)**46 - 1.13637743502971e+61*cos(theta)**44 + 3.90346061560679e+60*cos(theta)**42 - 1.17144635414341e+60*cos(theta)**40 + 3.06620186654987e+59*cos(theta)**38 - 6.98263657980096e+58*cos(theta)**36 + 1.37901600165348e+58*cos(theta)**34 - 2.35216776201764e+57*cos(theta)**32 + 3.44762177884383e+56*cos(theta)**30 - 4.31572798214983e+55*cos(theta)**28 + 4.5798573196312e+54*cos(theta)**26 - 4.08354905042563e+53*cos(theta)**24 + 3.02647566572898e+52*cos(theta)**22 - 1.84026290809001e+51*cos(theta)**20 + 9.03488249449876e+49*cos(theta)**18 - 3.51114305729822e+48*cos(theta)**16 + 1.05334291718947e+47*cos(theta)**14 - 2.36152267711854e+45*cos(theta)**12 + 3.78853905420086e+43*cos(theta)**10 - 4.09325948232987e+41*cos(theta)**8 + 2.72106518293533e+39*cos(theta)**6 - 9.59247420541246e+36*cos(theta)**4 + 1.34035503568875e+34*cos(theta)**2 - 3.09622322866423e+30)*sin(16*phi)

#@torch.jit.script
def Yl94_m_minus_15(theta, phi):
    return 1.36520338302375e-29*(1.0 - cos(theta)**2)**7.5*(1.39907594319521e+56*cos(theta)**79 - 2.30510854598099e+57*cos(theta)**77 + 1.82290475825415e+58*cos(theta)**75 - 9.21413607314258e+58*cos(theta)**73 + 3.34457867406335e+59*cos(theta)**71 - 9.28634413971781e+59*cos(theta)**69 + 2.05139014611845e+60*cos(theta)**67 - 3.70254988821869e+60*cos(theta)**65 + 5.56452584356567e+60*cos(theta)**63 - 7.06141583657164e+60*cos(theta)**61 + 7.64638519581426e+60*cos(theta)**59 - 7.12191892762014e+60*cos(theta)**57 + 5.74069828711199e+60*cos(theta)**55 - 4.02309436354946e+60*cos(theta)**53 + 2.45954926041311e+60*cos(theta)**51 - 1.31485337820827e+60*cos(theta)**49 + 6.15552377696227e+59*cos(theta)**47 - 2.52528318895492e+59*cos(theta)**45 + 9.07781538513207e+58*cos(theta)**43 - 2.85718622961808e+58*cos(theta)**41 + 7.86205606807658e+57*cos(theta)**39 - 1.88719907562188e+57*cos(theta)**37 + 3.94004571900995e+56*cos(theta)**35 - 7.12778109702316e+55*cos(theta)**33 + 1.11213605769156e+55*cos(theta)**31 - 1.48818206281029e+54*cos(theta)**29 + 1.69624345171526e+53*cos(theta)**27 - 1.63341962017025e+52*cos(theta)**25 + 1.31585898509956e+51*cos(theta)**23 - 8.76315670519053e+49*cos(theta)**21 + 4.75520131289408e+48*cos(theta)**19 - 2.06537826899895e+47*cos(theta)**17 + 7.02228611459645e+45*cos(theta)**15 - 1.8165559054758e+44*cos(theta)**13 + 3.44412641290988e+42*cos(theta)**11 - 4.54806609147763e+40*cos(theta)**9 + 3.8872359756219e+38*cos(theta)**7 - 1.91849484108249e+36*cos(theta)**5 + 4.46785011896248e+33*cos(theta)**3 - 3.09622322866423e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl94_m_minus_14(theta, phi):
    return 1.27483975524809e-27*(1.0 - cos(theta)**2)**7*(1.74884492899401e+54*cos(theta)**80 - 2.95526736664229e+55*cos(theta)**78 + 2.39855889243967e+56*cos(theta)**76 - 1.24515352339765e+57*cos(theta)**74 + 4.64524815842133e+57*cos(theta)**72 - 1.32662059138826e+58*cos(theta)**70 + 3.01675021488008e+58*cos(theta)**68 - 5.60992407305863e+58*cos(theta)**66 + 8.69457163057136e+58*cos(theta)**64 - 1.13893803815672e+59*cos(theta)**62 + 1.27439753263571e+59*cos(theta)**60 - 1.22791705648623e+59*cos(theta)**58 + 1.02512469412714e+59*cos(theta)**56 - 7.45017474731382e+58*cos(theta)**54 + 4.72990242387137e+58*cos(theta)**52 - 2.62970675641654e+58*cos(theta)**50 + 1.28240078686714e+58*cos(theta)**48 - 5.48974606294548e+57*cos(theta)**46 + 2.06313986025729e+57*cos(theta)**44 - 6.80282435623351e+56*cos(theta)**42 + 1.96551401701915e+56*cos(theta)**40 - 4.96631335689969e+55*cos(theta)**38 + 1.09445714416943e+55*cos(theta)**36 - 2.09640620500681e+54*cos(theta)**34 + 3.47542518028612e+53*cos(theta)**32 - 4.96060687603429e+52*cos(theta)**30 + 6.0580123275545e+51*cos(theta)**28 - 6.28238315450097e+50*cos(theta)**26 + 5.48274577124816e+49*cos(theta)**24 - 3.98325304781388e+48*cos(theta)**22 + 2.37760065644704e+47*cos(theta)**20 - 1.14743237166609e+46*cos(theta)**18 + 4.38892882162278e+44*cos(theta)**16 - 1.29753993248271e+43*cos(theta)**14 + 2.87010534409156e+41*cos(theta)**12 - 4.54806609147763e+39*cos(theta)**10 + 4.85904496952738e+37*cos(theta)**8 - 3.19749140180415e+35*cos(theta)**6 + 1.11696252974062e+33*cos(theta)**4 - 1.54811161433212e+30*cos(theta)**2 + 3.55071471177091e+26)*sin(14*phi)

#@torch.jit.script
def Yl94_m_minus_13(theta, phi):
    return 1.19236710290311e-25*(1.0 - cos(theta)**2)**6.5*(2.15906781357286e+52*cos(theta)**81 - 3.74084476790163e+53*cos(theta)**79 + 3.11501154862295e+54*cos(theta)**77 - 1.66020469786353e+55*cos(theta)**75 + 6.36335364167305e+55*cos(theta)**73 - 1.86847970618065e+56*cos(theta)**71 + 4.37210176069577e+56*cos(theta)**69 - 8.37302100456512e+56*cos(theta)**67 + 1.33762640470329e+57*cos(theta)**65 - 1.80783815580431e+57*cos(theta)**63 + 2.08917628300936e+57*cos(theta)**61 - 2.08121534997666e+57*cos(theta)**59 + 1.79846437566165e+57*cos(theta)**57 - 1.35457722678433e+57*cos(theta)**55 + 8.92434419598372e+56*cos(theta)**53 - 5.15628775767948e+56*cos(theta)**51 + 2.61714446299416e+56*cos(theta)**49 - 1.16803107722244e+56*cos(theta)**47 + 4.5847552450162e+55*cos(theta)**45 - 1.58205217586826e+55*cos(theta)**43 + 4.79393662687597e+54*cos(theta)**41 - 1.27341368125633e+54*cos(theta)**39 + 2.957992281539e+53*cos(theta)**37 - 5.98973201430518e+52*cos(theta)**35 + 1.05315914554125e+52*cos(theta)**33 - 1.60019576646267e+51*cos(theta)**31 + 2.08896976812224e+50*cos(theta)**29 - 2.3268085757411e+49*cos(theta)**27 + 2.19309830849926e+48*cos(theta)**25 - 1.73184915122342e+47*cos(theta)**23 + 1.13219078878431e+46*cos(theta)**21 - 6.03911774561098e+44*cos(theta)**19 + 2.58172283624869e+43*cos(theta)**17 - 8.65026621655142e+41*cos(theta)**15 + 2.2077733416089e+40*cos(theta)**13 - 4.13460553770693e+38*cos(theta)**11 + 5.39893885503042e+36*cos(theta)**9 - 4.56784485972022e+34*cos(theta)**7 + 2.23392505948124e+32*cos(theta)**5 - 5.16037204777372e+29*cos(theta)**3 + 3.55071471177091e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl94_m_minus_12(theta, phi):
    return 1.11688587998697e-23*(1.0 - cos(theta)**2)**6*(2.63300952874739e+50*cos(theta)**82 - 4.67605595987704e+51*cos(theta)**80 + 3.99360454951661e+52*cos(theta)**78 - 2.1844798656099e+53*cos(theta)**76 + 8.59912654280142e+53*cos(theta)**74 - 2.59511070302867e+54*cos(theta)**72 + 6.24585965813681e+54*cos(theta)**70 - 1.2313266183184e+55*cos(theta)**68 + 2.02670667379286e+55*cos(theta)**66 - 2.82474711844424e+55*cos(theta)**64 + 3.36963916614413e+55*cos(theta)**62 - 3.4686922499611e+55*cos(theta)**60 + 3.1008006476925e+55*cos(theta)**58 - 2.41888790497202e+55*cos(theta)**56 + 1.65265633258958e+55*cos(theta)**54 - 9.91593799553746e+54*cos(theta)**52 + 5.23428892598833e+54*cos(theta)**50 - 2.43339807754676e+54*cos(theta)**48 + 9.96685922829608e+53*cos(theta)**46 - 3.59557312697332e+53*cos(theta)**44 + 1.14141348258952e+53*cos(theta)**42 - 3.18353420314083e+52*cos(theta)**40 + 7.78419021457631e+51*cos(theta)**38 - 1.66381444841811e+51*cos(theta)**36 + 3.09752689865073e+50*cos(theta)**34 - 5.00061177019585e+49*cos(theta)**32 + 6.96323256040747e+48*cos(theta)**30 - 8.31003062764678e+47*cos(theta)**28 + 8.43499349422793e+46*cos(theta)**26 - 7.2160381300976e+45*cos(theta)**24 + 5.14632176720139e+44*cos(theta)**22 - 3.01955887280549e+43*cos(theta)**20 + 1.43429046458261e+42*cos(theta)**18 - 5.40641638534464e+40*cos(theta)**16 + 1.57698095829207e+39*cos(theta)**14 - 3.44550461475578e+37*cos(theta)**12 + 5.39893885503042e+35*cos(theta)**10 - 5.70980607465027e+33*cos(theta)**8 + 3.72320843246874e+31*cos(theta)**6 - 1.29009301194343e+29*cos(theta)**4 + 1.77535735588545e+26*cos(theta)**2 - 4.04685971252668e+22)*sin(12*phi)

#@torch.jit.script
def Yl94_m_minus_11(theta, phi):
    return 1.04761275948261e-21*(1.0 - cos(theta)**2)**5.5*(3.17230063704504e+48*cos(theta)**83 - 5.77290859244079e+49*cos(theta)**81 + 5.0551956322995e+50*cos(theta)**79 - 2.83698683845442e+51*cos(theta)**77 + 1.14655020570686e+52*cos(theta)**75 - 3.55494616853243e+52*cos(theta)**73 + 8.7969854339955e+52*cos(theta)**71 - 1.78453133089623e+53*cos(theta)**69 + 3.02493533401919e+53*cos(theta)**67 - 4.34576479760652e+53*cos(theta)**65 + 5.34863359705417e+53*cos(theta)**63 - 5.68638073764115e+53*cos(theta)**61 + 5.25559431812288e+53*cos(theta)**59 - 4.24366299117898e+53*cos(theta)**57 + 3.00482969561741e+53*cos(theta)**55 - 1.87093169727122e+53*cos(theta)**53 + 1.0263311619585e+53*cos(theta)**51 - 4.96611852560562e+52*cos(theta)**49 + 2.12060834644597e+52*cos(theta)**47 - 7.99016250438515e+51*cos(theta)**45 + 2.6544499595105e+51*cos(theta)**43 - 7.76471756863616e+50*cos(theta)**41 + 1.99594620886572e+50*cos(theta)**39 - 4.49679580653542e+49*cos(theta)**37 + 8.85007685328779e+48*cos(theta)**35 - 1.51533690005935e+48*cos(theta)**33 + 2.24620405174435e+47*cos(theta)**31 - 2.86552780263682e+46*cos(theta)**29 + 3.12407166452886e+45*cos(theta)**27 - 2.88641525203904e+44*cos(theta)**25 + 2.23753120313104e+43*cos(theta)**23 - 1.43788517752642e+42*cos(theta)**21 + 7.54889718201372e+40*cos(theta)**19 - 3.18024493255567e+39*cos(theta)**17 + 1.05132063886138e+38*cos(theta)**15 - 2.65038816519675e+36*cos(theta)**13 + 4.90812623184584e+34*cos(theta)**11 - 6.34422897183363e+32*cos(theta)**9 + 5.31886918924105e+30*cos(theta)**7 - 2.58018602388686e+28*cos(theta)**5 + 5.91785785295151e+25*cos(theta)**3 - 4.04685971252668e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl94_m_minus_10(theta, phi):
    return 9.8386400460569e-20*(1.0 - cos(theta)**2)**5*(3.77654837743457e+46*cos(theta)**84 - 7.04013242980584e+47*cos(theta)**82 + 6.31899454037438e+48*cos(theta)**80 - 3.6371626134031e+49*cos(theta)**78 + 1.50861869171955e+50*cos(theta)**76 - 4.80398130882761e+50*cos(theta)**74 + 1.22180353249938e+51*cos(theta)**72 - 2.5493304727089e+51*cos(theta)**70 + 4.4484343147341e+51*cos(theta)**68 - 6.58449211758563e+51*cos(theta)**66 + 8.35723999539714e+51*cos(theta)**64 - 9.17158183490509e+51*cos(theta)**62 + 8.75932386353814e+51*cos(theta)**60 - 7.31666032961893e+51*cos(theta)**58 + 5.36576731360252e+51*cos(theta)**56 - 3.46468832828004e+51*cos(theta)**54 + 1.97371377299711e+51*cos(theta)**52 - 9.93223705121125e+50*cos(theta)**50 + 4.41793405509578e+50*cos(theta)**48 - 1.73699184877938e+50*cos(theta)**46 + 6.03284081706932e+49*cos(theta)**44 - 1.8487422782467e+49*cos(theta)**42 + 4.9898655221643e+48*cos(theta)**40 - 1.18336731750932e+48*cos(theta)**38 + 2.45835468146883e+47*cos(theta)**36 - 4.45687323546867e+46*cos(theta)**34 + 7.01938766170108e+45*cos(theta)**32 - 9.55175934212274e+44*cos(theta)**30 + 1.11573988018888e+44*cos(theta)**28 - 1.11015971232271e+43*cos(theta)**26 + 9.32304667971266e+41*cos(theta)**24 - 6.5358417160292e+40*cos(theta)**22 + 3.77444859100686e+39*cos(theta)**20 - 1.76680274030871e+38*cos(theta)**18 + 6.57075399288362e+36*cos(theta)**16 - 1.89313440371197e+35*cos(theta)**14 + 4.09010519320487e+33*cos(theta)**12 - 6.34422897183363e+31*cos(theta)**10 + 6.64858648655132e+29*cos(theta)**8 - 4.30031003981143e+27*cos(theta)**6 + 1.47946446323788e+25*cos(theta)**4 - 2.02342985626334e+22*cos(theta)**2 + 4.58827631805746e+18)*sin(10*phi)

#@torch.jit.script
def Yl94_m_minus_9(theta, phi):
    return 9.2504147341075e-18*(1.0 - cos(theta)**2)**4.5*(4.4429980910995e+44*cos(theta)**85 - 8.48208726482632e+45*cos(theta)**83 + 7.80122782762269e+46*cos(theta)**81 - 4.60400330810519e+47*cos(theta)**79 + 1.95924505418123e+48*cos(theta)**77 - 6.40530841177014e+48*cos(theta)**75 + 1.67370346917723e+49*cos(theta)**73 - 3.59060629959e+49*cos(theta)**71 + 6.44700625323783e+49*cos(theta)**69 - 9.82760017550094e+49*cos(theta)**67 + 1.2857292300611e+50*cos(theta)**65 - 1.45580664046112e+50*cos(theta)**63 + 1.43595473172756e+50*cos(theta)**61 - 1.24011192027439e+50*cos(theta)**59 + 9.41362686596934e+49*cos(theta)**57 - 6.29943332414552e+49*cos(theta)**55 + 3.72398825093794e+49*cos(theta)**53 - 1.94749746102181e+49*cos(theta)**51 + 9.01619194917506e+48*cos(theta)**49 - 3.69572733782847e+48*cos(theta)**47 + 1.34063129268207e+48*cos(theta)**45 - 4.29940064708536e+47*cos(theta)**43 + 1.21704037125959e+47*cos(theta)**41 - 3.03427517310082e+46*cos(theta)**39 + 6.64420184180765e+45*cos(theta)**37 - 1.27339235299105e+45*cos(theta)**35 + 2.12708717021245e+44*cos(theta)**33 - 3.08121269100733e+43*cos(theta)**31 + 3.84737889720304e+42*cos(theta)**29 - 4.11170263823225e+41*cos(theta)**27 + 3.72921867188507e+40*cos(theta)**25 - 2.84167031131704e+39*cos(theta)**23 + 1.79735647190803e+38*cos(theta)**21 - 9.29896179109845e+36*cos(theta)**19 + 3.8651494075786e+35*cos(theta)**17 - 1.26208960247464e+34*cos(theta)**15 + 3.14623476400374e+32*cos(theta)**13 - 5.76748088348512e+30*cos(theta)**11 + 7.38731831839035e+28*cos(theta)**9 - 6.14330005687347e+26*cos(theta)**7 + 2.95892892647576e+24*cos(theta)**5 - 6.74476618754446e+21*cos(theta)**3 + 4.58827631805746e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl94_m_minus_8(theta, phi):
    return 8.70620807381728e-16*(1.0 - cos(theta)**2)**4*(5.1662768501157e+42*cos(theta)**86 - 1.0097722934317e+44*cos(theta)**84 + 9.5136924727106e+44*cos(theta)**82 - 5.75500413513149e+45*cos(theta)**80 + 2.51185263356568e+46*cos(theta)**78 - 8.42803738390808e+46*cos(theta)**76 + 2.26176144483409e+47*cos(theta)**74 - 4.986953193875e+47*cos(theta)**72 + 9.2100089331969e+47*cos(theta)**70 - 1.44523531992661e+48*cos(theta)**68 + 1.94807459100167e+48*cos(theta)**66 - 2.27469787572051e+48*cos(theta)**64 + 2.31605601891543e+48*cos(theta)**62 - 2.06685320045732e+48*cos(theta)**60 + 1.6230391148223e+48*cos(theta)**58 - 1.12489880788313e+48*cos(theta)**56 + 6.89627453877396e+47*cos(theta)**54 - 3.74518742504195e+47*cos(theta)**52 + 1.80323838983501e+47*cos(theta)**50 - 7.69943195380931e+46*cos(theta)**48 + 2.91441585365668e+46*cos(theta)**46 - 9.77136510701218e+45*cos(theta)**44 + 2.89771516966568e+45*cos(theta)**42 - 7.58568793275206e+44*cos(theta)**40 + 1.74847416889675e+44*cos(theta)**38 - 3.53720098053069e+43*cos(theta)**36 + 6.25613873591897e+42*cos(theta)**34 - 9.62878965939792e+41*cos(theta)**32 + 1.28245963240101e+41*cos(theta)**30 - 1.46846522794009e+40*cos(theta)**28 + 1.43431487380195e+39*cos(theta)**26 - 1.1840292963821e+38*cos(theta)**24 + 8.1698021450365e+36*cos(theta)**22 - 4.64948089554923e+35*cos(theta)**20 + 2.14730522643255e+34*cos(theta)**18 - 7.88806001546653e+32*cos(theta)**16 + 2.24731054571696e+31*cos(theta)**14 - 4.80623406957094e+29*cos(theta)**12 + 7.38731831839035e+27*cos(theta)**10 - 7.67912507109184e+25*cos(theta)**8 + 4.93154821079293e+23*cos(theta)**6 - 1.68619154688612e+21*cos(theta)**4 + 2.29413815902873e+18*cos(theta)**2 - 517981069999713.0)*sin(8*phi)

#@torch.jit.script
def Yl94_m_minus_7(theta, phi):
    return 8.20141436451245e-14*(1.0 - cos(theta)**2)**3.5*(5.93824925300655e+40*cos(theta)**87 - 1.1879674040373e+42*cos(theta)**85 + 1.14622800876031e+43*cos(theta)**83 - 7.10494337670555e+43*cos(theta)**81 + 3.17956029565276e+44*cos(theta)**79 - 1.09455030959845e+45*cos(theta)**77 + 3.01568192644545e+45*cos(theta)**75 - 6.83144273133562e+45*cos(theta)**73 + 1.2971843567883e+46*cos(theta)**71 - 2.09454394192262e+46*cos(theta)**69 + 2.9075740164204e+46*cos(theta)**67 - 3.49953519341617e+46*cos(theta)**65 + 3.67627939510385e+46*cos(theta)**63 - 3.38828393517594e+46*cos(theta)**61 + 2.7509137539361e+46*cos(theta)**59 - 1.97350668049672e+46*cos(theta)**57 + 1.2538680979589e+46*cos(theta)**55 - 7.06639136800368e+45*cos(theta)**53 + 3.5357615486961e+45*cos(theta)**51 - 1.57131264363455e+45*cos(theta)**49 + 6.20088479501421e+44*cos(theta)**47 - 2.17141446822493e+44*cos(theta)**45 + 6.73887248759461e+43*cos(theta)**43 - 1.85016778847611e+43*cos(theta)**41 + 4.48326709973526e+42*cos(theta)**39 - 9.56000265008295e+41*cos(theta)**37 + 1.78746821026256e+41*cos(theta)**35 - 2.9178150483024e+40*cos(theta)**33 + 4.1369665561323e+39*cos(theta)**31 - 5.06367319979341e+38*cos(theta)**29 + 5.31227731037759e+37*cos(theta)**27 - 4.7361171855284e+36*cos(theta)**25 + 3.5520878891463e+35*cos(theta)**23 - 2.21403852169011e+34*cos(theta)**21 + 1.13016064549082e+33*cos(theta)**19 - 4.6400353032156e+31*cos(theta)**17 + 1.49820703047797e+30*cos(theta)**15 - 3.69710313043918e+28*cos(theta)**13 + 6.71574392580941e+26*cos(theta)**11 - 8.53236119010205e+24*cos(theta)**9 + 7.04506887256132e+22*cos(theta)**7 - 3.37238309377223e+20*cos(theta)**5 + 7.64712719676243e+17*cos(theta)**3 - 517981069999713.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl94_m_minus_6(theta, phi):
    return 7.73198098857658e-12*(1.0 - cos(theta)**2)**3*(6.74801051478017e+38*cos(theta)**88 - 1.381357446555e+40*cos(theta)**86 + 1.36455715328609e+41*cos(theta)**84 - 8.66456509354335e+41*cos(theta)**82 + 3.97445036956595e+42*cos(theta)**80 - 1.40326962769032e+43*cos(theta)**78 + 3.96800253479665e+43*cos(theta)**76 - 9.23167936666976e+43*cos(theta)**74 + 1.80164493998374e+44*cos(theta)**72 - 2.99220563131803e+44*cos(theta)**70 + 4.2758441417947e+44*cos(theta)**68 - 5.30232605063055e+44*cos(theta)**66 + 5.74418655484977e+44*cos(theta)**64 - 5.46497408899345e+44*cos(theta)**62 + 4.58485625656017e+44*cos(theta)**60 - 3.40259772499434e+44*cos(theta)**58 + 2.23905017492661e+44*cos(theta)**56 - 1.30859099407475e+44*cos(theta)**54 + 6.7995414398002e+43*cos(theta)**52 - 3.1426252872691e+43*cos(theta)**50 + 1.29185099896129e+43*cos(theta)**48 - 4.72046623527159e+42*cos(theta)**46 + 1.53156192899877e+42*cos(theta)**44 - 4.4051614011336e+41*cos(theta)**42 + 1.12081677493381e+41*cos(theta)**40 - 2.51579017107446e+40*cos(theta)**38 + 4.96518947295156e+39*cos(theta)**36 - 8.58180896559529e+38*cos(theta)**34 + 1.29280204879134e+38*cos(theta)**32 - 1.6878910665978e+37*cos(theta)**30 + 1.89724189656342e+36*cos(theta)**28 - 1.82158353289554e+35*cos(theta)**26 + 1.48003662047763e+34*cos(theta)**24 - 1.00638114622278e+33*cos(theta)**22 + 5.65080322745409e+31*cos(theta)**20 - 2.57779739067534e+30*cos(theta)**18 + 9.36379394048733e+28*cos(theta)**16 - 2.6407879503137e+27*cos(theta)**14 + 5.59645327150784e+25*cos(theta)**12 - 8.53236119010205e+23*cos(theta)**10 + 8.80633609070165e+21*cos(theta)**8 - 5.62063848962038e+19*cos(theta)**6 + 1.91178179919061e+17*cos(theta)**4 - 258990534999856.0*cos(theta)**2 + 58278698244.7922)*sin(6*phi)

#@torch.jit.script
def Yl94_m_minus_5(theta, phi):
    return 7.29433627596518e-10*(1.0 - cos(theta)**2)**2.5*(7.58203428626985e+36*cos(theta)**89 - 1.58776717994827e+38*cos(theta)**87 + 1.60536135680716e+39*cos(theta)**85 - 1.04392350524619e+40*cos(theta)**83 + 4.90672885131599e+40*cos(theta)**81 - 1.77629066796244e+41*cos(theta)**79 + 5.15325004519045e+41*cos(theta)**77 - 1.23089058222263e+42*cos(theta)**75 + 2.46800676710102e+42*cos(theta)**73 - 4.21437412861694e+42*cos(theta)**71 + 6.19687556781841e+42*cos(theta)**69 - 7.91391947855307e+42*cos(theta)**67 + 8.83721008438426e+42*cos(theta)**65 - 8.67456204602136e+42*cos(theta)**63 + 7.51615779763962e+42*cos(theta)**61 - 5.767114788126e+42*cos(theta)**59 + 3.92815820162563e+42*cos(theta)**57 - 2.37925635286319e+42*cos(theta)**55 + 1.28293234713211e+42*cos(theta)**53 - 6.16201036719432e+41*cos(theta)**51 + 2.63643061012509e+41*cos(theta)**49 - 1.00435451814289e+41*cos(theta)**47 + 3.40347095333061e+40*cos(theta)**45 - 1.02445613979851e+40*cos(theta)**43 + 2.73369945105808e+39*cos(theta)**41 - 6.45074402839606e+38*cos(theta)**39 + 1.34194310079772e+38*cos(theta)**37 - 2.45194541874151e+37*cos(theta)**35 + 3.91758196603437e+36*cos(theta)**33 - 5.44480989225098e+35*cos(theta)**31 + 6.5422134364256e+34*cos(theta)**29 - 6.74660567739089e+33*cos(theta)**27 + 5.92014648191051e+32*cos(theta)**25 - 4.37557020096859e+31*cos(theta)**23 + 2.69085867974004e+30*cos(theta)**21 - 1.35673546877649e+29*cos(theta)**19 + 5.50811408263961e+27*cos(theta)**17 - 1.76052530020913e+26*cos(theta)**15 + 4.30496405500603e+24*cos(theta)**13 - 7.75669199100186e+22*cos(theta)**11 + 9.78481787855739e+20*cos(theta)**9 - 8.02948355660055e+18*cos(theta)**7 + 3.82356359838121e+16*cos(theta)**5 - 86330178333285.5*cos(theta)**3 + 58278698244.7922*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl94_m_minus_4(theta, phi):
    return 6.88532798498471e-8*(1.0 - cos(theta)**2)**2*(8.42448254029984e+34*cos(theta)**90 - 1.80428088630486e+36*cos(theta)**88 + 1.86669925210135e+37*cos(theta)**86 - 1.24276607767403e+38*cos(theta)**84 + 5.98381567233657e+38*cos(theta)**82 - 2.22036333495304e+39*cos(theta)**80 + 6.60673082716725e+39*cos(theta)**78 - 1.61959287134557e+40*cos(theta)**76 + 3.33514427986624e+40*cos(theta)**74 - 5.85329740085687e+40*cos(theta)**72 + 8.85267938259772e+40*cos(theta)**70 - 1.16381168802251e+41*cos(theta)**68 + 1.33897122490671e+41*cos(theta)**66 - 1.35540031969084e+41*cos(theta)**64 + 1.21228351574833e+41*cos(theta)**62 - 9.61185798021e+40*cos(theta)**60 + 6.77268655452695e+40*cos(theta)**58 - 4.24867205868427e+40*cos(theta)**56 + 2.37580064283725e+40*cos(theta)**54 - 1.18500199369122e+40*cos(theta)**52 + 5.27286122025018e+39*cos(theta)**50 - 2.09240524613102e+39*cos(theta)**48 + 7.39884989854481e+38*cos(theta)**46 - 2.32830940863298e+38*cos(theta)**44 + 6.50880821680496e+37*cos(theta)**42 - 1.61268600709901e+37*cos(theta)**40 + 3.53142921262558e+36*cos(theta)**38 - 6.8109594965042e+35*cos(theta)**36 + 1.15222999001011e+35*cos(theta)**34 - 1.70150309132843e+34*cos(theta)**32 + 2.18073781214187e+33*cos(theta)**30 - 2.4095020276396e+32*cos(theta)**28 + 2.27697941611943e+31*cos(theta)**26 - 1.82315425040358e+30*cos(theta)**24 + 1.22311758170002e+29*cos(theta)**22 - 6.78367734388246e+27*cos(theta)**20 + 3.06006337924423e+26*cos(theta)**18 - 1.10032831263071e+25*cos(theta)**16 + 3.07497432500431e+23*cos(theta)**14 - 6.46390999250155e+21*cos(theta)**12 + 9.78481787855739e+19*cos(theta)**10 - 1.00368544457507e+18*cos(theta)**8 + 6.37260599730202e+15*cos(theta)**6 - 21582544583321.4*cos(theta)**4 + 29139349122.3961*cos(theta)**2 - 6540819.10715962)*sin(4*phi)

#@torch.jit.script
def Yl94_m_minus_3(theta, phi):
    return 6.50217070175442e-6*(1.0 - cos(theta)**2)**1.5*(9.25767312120861e+32*cos(theta)**91 - 2.02728189472456e+34*cos(theta)**89 + 2.14563132425443e+35*cos(theta)**87 - 1.46207773844004e+36*cos(theta)**85 + 7.20941647269466e+36*cos(theta)**83 - 2.74118930241117e+37*cos(theta)**81 + 8.36295041413576e+37*cos(theta)**79 - 2.10336736538386e+38*cos(theta)**77 + 4.44685903982166e+38*cos(theta)**75 - 8.01821561761215e+38*cos(theta)**73 + 1.2468562510701e+39*cos(theta)**71 - 1.68668360582972e+39*cos(theta)**69 + 1.99846451478613e+39*cos(theta)**67 - 2.08523126106283e+39*cos(theta)**65 + 1.92425954880687e+39*cos(theta)**63 - 1.57571442298525e+39*cos(theta)**61 + 1.14791297534355e+39*cos(theta)**59 - 7.45381062927065e+38*cos(theta)**57 + 4.31963753243136e+38*cos(theta)**55 - 2.23585281828531e+38*cos(theta)**53 + 1.0338943569118e+38*cos(theta)**51 - 4.27021478802249e+37*cos(theta)**49 + 1.57422338266911e+37*cos(theta)**47 - 5.17402090807329e+36*cos(theta)**45 + 1.51367632948953e+36*cos(theta)**43 - 3.93338050511955e+35*cos(theta)**41 + 9.05494669903994e+34*cos(theta)**39 - 1.84079986392005e+34*cos(theta)**37 + 3.29208568574317e+33*cos(theta)**35 - 5.15606997372252e+32*cos(theta)**33 + 7.03463810368344e+31*cos(theta)**31 - 8.30862768151587e+30*cos(theta)**29 + 8.43325709673861e+29*cos(theta)**27 - 7.29261700161432e+28*cos(theta)**25 + 5.31790252913052e+27*cos(theta)**23 - 3.23032254470593e+26*cos(theta)**21 + 1.61055967328643e+25*cos(theta)**19 - 6.47251948606299e+23*cos(theta)**17 + 2.04998288333621e+22*cos(theta)**15 - 4.97223845577042e+20*cos(theta)**13 + 8.89528898050672e+18*cos(theta)**11 - 1.11520604952785e+17*cos(theta)**9 + 910372285328861.0*cos(theta)**7 - 4316508916664.27*cos(theta)**5 + 9713116374.13203*cos(theta)**3 - 6540819.10715962*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl94_m_minus_2(theta, phi):
    return 0.00061424007480898*(1.0 - cos(theta)**2)*(1.00626881752268e+31*cos(theta)**92 - 2.25253543858284e+32*cos(theta)**90 + 2.43821741392548e+33*cos(theta)**88 - 1.70009039353493e+34*cos(theta)**86 + 8.58263865796983e+34*cos(theta)**84 - 3.34291378342825e+35*cos(theta)**82 + 1.04536880176697e+36*cos(theta)**80 - 2.6966248274152e+36*cos(theta)**78 + 5.85113031555481e+36*cos(theta)**76 - 1.08354265102867e+37*cos(theta)**74 + 1.73174479315292e+37*cos(theta)**72 - 2.40954800832818e+37*cos(theta)**70 + 2.93891840409725e+37*cos(theta)**68 - 3.15944130464065e+37*cos(theta)**66 + 3.00665554501073e+37*cos(theta)**64 - 2.54147487578265e+37*cos(theta)**62 + 1.91318829223925e+37*cos(theta)**60 - 1.28513976366735e+37*cos(theta)**58 + 7.71363845077028e+36*cos(theta)**56 - 4.14046818200984e+36*cos(theta)**54 + 1.98825837867654e+36*cos(theta)**52 - 8.54042957604499e+35*cos(theta)**50 + 3.27963204722731e+35*cos(theta)**48 - 1.12478715392898e+35*cos(theta)**46 + 3.44017347611256e+34*cos(theta)**44 - 9.36519167885606e+33*cos(theta)**42 + 2.26373667475999e+33*cos(theta)**40 - 4.84421016821067e+32*cos(theta)**38 + 9.14468246039769e+31*cos(theta)**36 - 1.51649116874192e+31*cos(theta)**34 + 2.19832440740107e+30*cos(theta)**32 - 2.76954256050529e+29*cos(theta)**30 + 3.0118775345495e+28*cos(theta)**28 - 2.80485269292858e+27*cos(theta)**26 + 2.21579272047105e+26*cos(theta)**24 - 1.46832842941179e+25*cos(theta)**22 + 8.05279836643217e+23*cos(theta)**20 - 3.59584415892388e+22*cos(theta)**18 + 1.28123930208513e+21*cos(theta)**16 - 3.55159889697887e+19*cos(theta)**14 + 7.41274081708893e+17*cos(theta)**12 - 1.11520604952785e+16*cos(theta)**10 + 113796535666108.0*cos(theta)**8 - 719418152777.379*cos(theta)**6 + 2428279093.53301*cos(theta)**4 - 3270409.55357981*cos(theta)**2 + 732.947008870419)*sin(2*phi)

#@torch.jit.script
def Yl94_m_minus_1(theta, phi):
    return 0.0580383742269541*(1.0 - cos(theta)**2)**0.5*(1.08200948120718e+29*cos(theta)**93 - 2.47531366877236e+30*cos(theta)**91 + 2.73957012800616e+31*cos(theta)**89 - 1.95412688912061e+32*cos(theta)**87 + 1.00972219505527e+33*cos(theta)**85 - 4.02760696798584e+33*cos(theta)**83 + 1.29057876761354e+34*cos(theta)**81 - 3.41344914862684e+34*cos(theta)**79 + 7.59887053968157e+34*cos(theta)**77 - 1.44472353470489e+35*cos(theta)**75 + 2.37225314130537e+35*cos(theta)**73 - 3.39372958919462e+35*cos(theta)**71 + 4.25930203492355e+35*cos(theta)**69 - 4.71558403677708e+35*cos(theta)**67 + 4.62562391540112e+35*cos(theta)**65 - 4.03408710441691e+35*cos(theta)**63 + 3.13637424957254e+35*cos(theta)**61 - 2.1782029892667e+35*cos(theta)**59 + 1.35326990364391e+35*cos(theta)**57 - 7.52812396729062e+34*cos(theta)**55 + 3.75143090316328e+34*cos(theta)**53 - 1.67459403451862e+34*cos(theta)**51 + 6.6931266269945e+33*cos(theta)**49 - 2.39316415729569e+33*cos(theta)**47 + 7.6448299469168e+32*cos(theta)**45 - 2.17795155322234e+32*cos(theta)**43 + 5.52130896282923e+31*cos(theta)**41 - 1.24210517133607e+31*cos(theta)**39 + 2.47153580010748e+30*cos(theta)**37 - 4.33283191069119e+29*cos(theta)**35 + 6.66158911333659e+28*cos(theta)**33 - 8.93400825969449e+27*cos(theta)**31 + 1.03857846018948e+27*cos(theta)**29 - 1.03883433071429e+26*cos(theta)**27 + 8.8631708818842e+24*cos(theta)**25 - 6.38403664961647e+23*cos(theta)**23 + 3.83466588877722e+22*cos(theta)**21 - 1.89254955732836e+21*cos(theta)**19 + 7.53670177697135e+19*cos(theta)**17 - 2.36773259798592e+18*cos(theta)**15 + 5.70210832083764e+16*cos(theta)**13 - 1.01382368138896e+15*cos(theta)**11 + 12644059518456.4*cos(theta)**9 - 102774021825.34*cos(theta)**7 + 485655818.706602*cos(theta)**5 - 1090136.51785994*cos(theta)**3 + 732.947008870419*cos(theta))*sin(phi)

#@torch.jit.script
def Yl94_m0(theta, phi):
    return 1.4024230963831e+28*cos(theta)**94 - 3.27807024293611e+29*cos(theta)**92 + 3.70864919917043e+30*cos(theta)**90 - 2.70548998955875e+31*cos(theta)**88 + 1.43047177900979e+32*cos(theta)**86 - 5.84175905282771e+32*cos(theta)**84 + 1.91754915801859e+33*cos(theta)**82 - 5.19851490104467e+33*cos(theta)**80 + 1.18694415370673e+34*cos(theta)**78 - 2.31604502506908e+34*cos(theta)**76 + 3.90575640322301e+34*cos(theta)**74 - 5.74275887049828e+34*cos(theta)**72 + 7.41337963282505e+34*cos(theta)**70 - 8.44894375331406e+34*cos(theta)**68 + 8.53890588733338e+34*cos(theta)**66 - 7.67964491753882e+34*cos(theta)**64 + 6.16328190834326e+34*cos(theta)**62 - 4.42306113422281e+34*cos(theta)**60 + 2.84270813637414e+34*cos(theta)**58 - 1.63785170771225e+34*cos(theta)**56 + 8.46406587207002e+33*cos(theta)**54 - 3.92357572495374e+33*cos(theta)**52 + 1.63092834209676e+33*cos(theta)**50 - 6.07445186703719e+32*cos(theta)**48 + 2.02481728901239e+32*cos(theta)**46 - 6.03075077446857e+31*cos(theta)**44 + 1.60165363072635e+31*cos(theta)**42 - 3.7833299754606e+30*cos(theta)**40 + 7.92426794000878e+29*cos(theta)**38 - 1.46637545717983e+29*cos(theta)**36 + 2.38712283726949e+28*cos(theta)**34 - 3.40151361876603e+27*cos(theta)**32 + 4.21787688726987e+26*cos(theta)**30 - 4.52026717408818e+25*cos(theta)**28 + 4.15328388868579e+24*cos(theta)**26 - 3.24085777628543e+23*cos(theta)**24 + 2.12363899870555e+22*cos(theta)**22 - 1.15290389823968e+21*cos(theta)**20 + 5.10134468247645e+19*cos(theta)**18 - 1.8029700540977e+18*cos(theta)**16 + 4.96230290118634e+16*cos(theta)**14 - 1.02933568271702e+15*cos(theta)**12 + 15405023822975.8*cos(theta)**10 - 156519772416.779*cos(theta)**8 + 986173183.54406*cos(theta)**6 - 3320448.42944128*cos(theta)**4 + 4464.9687531707*cos(theta)**2 - 0.999993001829944

#@torch.jit.script
def Yl94_m1(theta, phi):
    return 0.0580383742269541*(1.0 - cos(theta)**2)**0.5*(1.08200948120718e+29*cos(theta)**93 - 2.47531366877236e+30*cos(theta)**91 + 2.73957012800616e+31*cos(theta)**89 - 1.95412688912061e+32*cos(theta)**87 + 1.00972219505527e+33*cos(theta)**85 - 4.02760696798584e+33*cos(theta)**83 + 1.29057876761354e+34*cos(theta)**81 - 3.41344914862684e+34*cos(theta)**79 + 7.59887053968157e+34*cos(theta)**77 - 1.44472353470489e+35*cos(theta)**75 + 2.37225314130537e+35*cos(theta)**73 - 3.39372958919462e+35*cos(theta)**71 + 4.25930203492355e+35*cos(theta)**69 - 4.71558403677708e+35*cos(theta)**67 + 4.62562391540112e+35*cos(theta)**65 - 4.03408710441691e+35*cos(theta)**63 + 3.13637424957254e+35*cos(theta)**61 - 2.1782029892667e+35*cos(theta)**59 + 1.35326990364391e+35*cos(theta)**57 - 7.52812396729062e+34*cos(theta)**55 + 3.75143090316328e+34*cos(theta)**53 - 1.67459403451862e+34*cos(theta)**51 + 6.6931266269945e+33*cos(theta)**49 - 2.39316415729569e+33*cos(theta)**47 + 7.6448299469168e+32*cos(theta)**45 - 2.17795155322234e+32*cos(theta)**43 + 5.52130896282923e+31*cos(theta)**41 - 1.24210517133607e+31*cos(theta)**39 + 2.47153580010748e+30*cos(theta)**37 - 4.33283191069119e+29*cos(theta)**35 + 6.66158911333659e+28*cos(theta)**33 - 8.93400825969449e+27*cos(theta)**31 + 1.03857846018948e+27*cos(theta)**29 - 1.03883433071429e+26*cos(theta)**27 + 8.8631708818842e+24*cos(theta)**25 - 6.38403664961647e+23*cos(theta)**23 + 3.83466588877722e+22*cos(theta)**21 - 1.89254955732836e+21*cos(theta)**19 + 7.53670177697135e+19*cos(theta)**17 - 2.36773259798592e+18*cos(theta)**15 + 5.70210832083764e+16*cos(theta)**13 - 1.01382368138896e+15*cos(theta)**11 + 12644059518456.4*cos(theta)**9 - 102774021825.34*cos(theta)**7 + 485655818.706602*cos(theta)**5 - 1090136.51785994*cos(theta)**3 + 732.947008870419*cos(theta))*cos(phi)

#@torch.jit.script
def Yl94_m2(theta, phi):
    return 0.00061424007480898*(1.0 - cos(theta)**2)*(1.00626881752268e+31*cos(theta)**92 - 2.25253543858284e+32*cos(theta)**90 + 2.43821741392548e+33*cos(theta)**88 - 1.70009039353493e+34*cos(theta)**86 + 8.58263865796983e+34*cos(theta)**84 - 3.34291378342825e+35*cos(theta)**82 + 1.04536880176697e+36*cos(theta)**80 - 2.6966248274152e+36*cos(theta)**78 + 5.85113031555481e+36*cos(theta)**76 - 1.08354265102867e+37*cos(theta)**74 + 1.73174479315292e+37*cos(theta)**72 - 2.40954800832818e+37*cos(theta)**70 + 2.93891840409725e+37*cos(theta)**68 - 3.15944130464065e+37*cos(theta)**66 + 3.00665554501073e+37*cos(theta)**64 - 2.54147487578265e+37*cos(theta)**62 + 1.91318829223925e+37*cos(theta)**60 - 1.28513976366735e+37*cos(theta)**58 + 7.71363845077028e+36*cos(theta)**56 - 4.14046818200984e+36*cos(theta)**54 + 1.98825837867654e+36*cos(theta)**52 - 8.54042957604499e+35*cos(theta)**50 + 3.27963204722731e+35*cos(theta)**48 - 1.12478715392898e+35*cos(theta)**46 + 3.44017347611256e+34*cos(theta)**44 - 9.36519167885606e+33*cos(theta)**42 + 2.26373667475999e+33*cos(theta)**40 - 4.84421016821067e+32*cos(theta)**38 + 9.14468246039769e+31*cos(theta)**36 - 1.51649116874192e+31*cos(theta)**34 + 2.19832440740107e+30*cos(theta)**32 - 2.76954256050529e+29*cos(theta)**30 + 3.0118775345495e+28*cos(theta)**28 - 2.80485269292858e+27*cos(theta)**26 + 2.21579272047105e+26*cos(theta)**24 - 1.46832842941179e+25*cos(theta)**22 + 8.05279836643217e+23*cos(theta)**20 - 3.59584415892388e+22*cos(theta)**18 + 1.28123930208513e+21*cos(theta)**16 - 3.55159889697887e+19*cos(theta)**14 + 7.41274081708893e+17*cos(theta)**12 - 1.11520604952785e+16*cos(theta)**10 + 113796535666108.0*cos(theta)**8 - 719418152777.379*cos(theta)**6 + 2428279093.53301*cos(theta)**4 - 3270409.55357981*cos(theta)**2 + 732.947008870419)*cos(2*phi)

#@torch.jit.script
def Yl94_m3(theta, phi):
    return 6.50217070175442e-6*(1.0 - cos(theta)**2)**1.5*(9.25767312120861e+32*cos(theta)**91 - 2.02728189472456e+34*cos(theta)**89 + 2.14563132425443e+35*cos(theta)**87 - 1.46207773844004e+36*cos(theta)**85 + 7.20941647269466e+36*cos(theta)**83 - 2.74118930241117e+37*cos(theta)**81 + 8.36295041413576e+37*cos(theta)**79 - 2.10336736538386e+38*cos(theta)**77 + 4.44685903982166e+38*cos(theta)**75 - 8.01821561761215e+38*cos(theta)**73 + 1.2468562510701e+39*cos(theta)**71 - 1.68668360582972e+39*cos(theta)**69 + 1.99846451478613e+39*cos(theta)**67 - 2.08523126106283e+39*cos(theta)**65 + 1.92425954880687e+39*cos(theta)**63 - 1.57571442298525e+39*cos(theta)**61 + 1.14791297534355e+39*cos(theta)**59 - 7.45381062927065e+38*cos(theta)**57 + 4.31963753243136e+38*cos(theta)**55 - 2.23585281828531e+38*cos(theta)**53 + 1.0338943569118e+38*cos(theta)**51 - 4.27021478802249e+37*cos(theta)**49 + 1.57422338266911e+37*cos(theta)**47 - 5.17402090807329e+36*cos(theta)**45 + 1.51367632948953e+36*cos(theta)**43 - 3.93338050511955e+35*cos(theta)**41 + 9.05494669903994e+34*cos(theta)**39 - 1.84079986392005e+34*cos(theta)**37 + 3.29208568574317e+33*cos(theta)**35 - 5.15606997372252e+32*cos(theta)**33 + 7.03463810368344e+31*cos(theta)**31 - 8.30862768151587e+30*cos(theta)**29 + 8.43325709673861e+29*cos(theta)**27 - 7.29261700161432e+28*cos(theta)**25 + 5.31790252913052e+27*cos(theta)**23 - 3.23032254470593e+26*cos(theta)**21 + 1.61055967328643e+25*cos(theta)**19 - 6.47251948606299e+23*cos(theta)**17 + 2.04998288333621e+22*cos(theta)**15 - 4.97223845577042e+20*cos(theta)**13 + 8.89528898050672e+18*cos(theta)**11 - 1.11520604952785e+17*cos(theta)**9 + 910372285328861.0*cos(theta)**7 - 4316508916664.27*cos(theta)**5 + 9713116374.13203*cos(theta)**3 - 6540819.10715962*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl94_m4(theta, phi):
    return 6.88532798498471e-8*(1.0 - cos(theta)**2)**2*(8.42448254029984e+34*cos(theta)**90 - 1.80428088630486e+36*cos(theta)**88 + 1.86669925210135e+37*cos(theta)**86 - 1.24276607767403e+38*cos(theta)**84 + 5.98381567233657e+38*cos(theta)**82 - 2.22036333495304e+39*cos(theta)**80 + 6.60673082716725e+39*cos(theta)**78 - 1.61959287134557e+40*cos(theta)**76 + 3.33514427986624e+40*cos(theta)**74 - 5.85329740085687e+40*cos(theta)**72 + 8.85267938259772e+40*cos(theta)**70 - 1.16381168802251e+41*cos(theta)**68 + 1.33897122490671e+41*cos(theta)**66 - 1.35540031969084e+41*cos(theta)**64 + 1.21228351574833e+41*cos(theta)**62 - 9.61185798021e+40*cos(theta)**60 + 6.77268655452695e+40*cos(theta)**58 - 4.24867205868427e+40*cos(theta)**56 + 2.37580064283725e+40*cos(theta)**54 - 1.18500199369122e+40*cos(theta)**52 + 5.27286122025018e+39*cos(theta)**50 - 2.09240524613102e+39*cos(theta)**48 + 7.39884989854481e+38*cos(theta)**46 - 2.32830940863298e+38*cos(theta)**44 + 6.50880821680496e+37*cos(theta)**42 - 1.61268600709901e+37*cos(theta)**40 + 3.53142921262558e+36*cos(theta)**38 - 6.8109594965042e+35*cos(theta)**36 + 1.15222999001011e+35*cos(theta)**34 - 1.70150309132843e+34*cos(theta)**32 + 2.18073781214187e+33*cos(theta)**30 - 2.4095020276396e+32*cos(theta)**28 + 2.27697941611943e+31*cos(theta)**26 - 1.82315425040358e+30*cos(theta)**24 + 1.22311758170002e+29*cos(theta)**22 - 6.78367734388246e+27*cos(theta)**20 + 3.06006337924423e+26*cos(theta)**18 - 1.10032831263071e+25*cos(theta)**16 + 3.07497432500431e+23*cos(theta)**14 - 6.46390999250155e+21*cos(theta)**12 + 9.78481787855739e+19*cos(theta)**10 - 1.00368544457507e+18*cos(theta)**8 + 6.37260599730202e+15*cos(theta)**6 - 21582544583321.4*cos(theta)**4 + 29139349122.3961*cos(theta)**2 - 6540819.10715962)*cos(4*phi)

#@torch.jit.script
def Yl94_m5(theta, phi):
    return 7.29433627596518e-10*(1.0 - cos(theta)**2)**2.5*(7.58203428626985e+36*cos(theta)**89 - 1.58776717994827e+38*cos(theta)**87 + 1.60536135680716e+39*cos(theta)**85 - 1.04392350524619e+40*cos(theta)**83 + 4.90672885131599e+40*cos(theta)**81 - 1.77629066796244e+41*cos(theta)**79 + 5.15325004519045e+41*cos(theta)**77 - 1.23089058222263e+42*cos(theta)**75 + 2.46800676710102e+42*cos(theta)**73 - 4.21437412861694e+42*cos(theta)**71 + 6.19687556781841e+42*cos(theta)**69 - 7.91391947855307e+42*cos(theta)**67 + 8.83721008438426e+42*cos(theta)**65 - 8.67456204602136e+42*cos(theta)**63 + 7.51615779763962e+42*cos(theta)**61 - 5.767114788126e+42*cos(theta)**59 + 3.92815820162563e+42*cos(theta)**57 - 2.37925635286319e+42*cos(theta)**55 + 1.28293234713211e+42*cos(theta)**53 - 6.16201036719432e+41*cos(theta)**51 + 2.63643061012509e+41*cos(theta)**49 - 1.00435451814289e+41*cos(theta)**47 + 3.40347095333061e+40*cos(theta)**45 - 1.02445613979851e+40*cos(theta)**43 + 2.73369945105808e+39*cos(theta)**41 - 6.45074402839606e+38*cos(theta)**39 + 1.34194310079772e+38*cos(theta)**37 - 2.45194541874151e+37*cos(theta)**35 + 3.91758196603437e+36*cos(theta)**33 - 5.44480989225098e+35*cos(theta)**31 + 6.5422134364256e+34*cos(theta)**29 - 6.74660567739089e+33*cos(theta)**27 + 5.92014648191051e+32*cos(theta)**25 - 4.37557020096859e+31*cos(theta)**23 + 2.69085867974004e+30*cos(theta)**21 - 1.35673546877649e+29*cos(theta)**19 + 5.50811408263961e+27*cos(theta)**17 - 1.76052530020913e+26*cos(theta)**15 + 4.30496405500603e+24*cos(theta)**13 - 7.75669199100186e+22*cos(theta)**11 + 9.78481787855739e+20*cos(theta)**9 - 8.02948355660055e+18*cos(theta)**7 + 3.82356359838121e+16*cos(theta)**5 - 86330178333285.5*cos(theta)**3 + 58278698244.7922*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl94_m6(theta, phi):
    return 7.73198098857658e-12*(1.0 - cos(theta)**2)**3*(6.74801051478017e+38*cos(theta)**88 - 1.381357446555e+40*cos(theta)**86 + 1.36455715328609e+41*cos(theta)**84 - 8.66456509354335e+41*cos(theta)**82 + 3.97445036956595e+42*cos(theta)**80 - 1.40326962769032e+43*cos(theta)**78 + 3.96800253479665e+43*cos(theta)**76 - 9.23167936666976e+43*cos(theta)**74 + 1.80164493998374e+44*cos(theta)**72 - 2.99220563131803e+44*cos(theta)**70 + 4.2758441417947e+44*cos(theta)**68 - 5.30232605063055e+44*cos(theta)**66 + 5.74418655484977e+44*cos(theta)**64 - 5.46497408899345e+44*cos(theta)**62 + 4.58485625656017e+44*cos(theta)**60 - 3.40259772499434e+44*cos(theta)**58 + 2.23905017492661e+44*cos(theta)**56 - 1.30859099407475e+44*cos(theta)**54 + 6.7995414398002e+43*cos(theta)**52 - 3.1426252872691e+43*cos(theta)**50 + 1.29185099896129e+43*cos(theta)**48 - 4.72046623527159e+42*cos(theta)**46 + 1.53156192899877e+42*cos(theta)**44 - 4.4051614011336e+41*cos(theta)**42 + 1.12081677493381e+41*cos(theta)**40 - 2.51579017107446e+40*cos(theta)**38 + 4.96518947295156e+39*cos(theta)**36 - 8.58180896559529e+38*cos(theta)**34 + 1.29280204879134e+38*cos(theta)**32 - 1.6878910665978e+37*cos(theta)**30 + 1.89724189656342e+36*cos(theta)**28 - 1.82158353289554e+35*cos(theta)**26 + 1.48003662047763e+34*cos(theta)**24 - 1.00638114622278e+33*cos(theta)**22 + 5.65080322745409e+31*cos(theta)**20 - 2.57779739067534e+30*cos(theta)**18 + 9.36379394048733e+28*cos(theta)**16 - 2.6407879503137e+27*cos(theta)**14 + 5.59645327150784e+25*cos(theta)**12 - 8.53236119010205e+23*cos(theta)**10 + 8.80633609070165e+21*cos(theta)**8 - 5.62063848962038e+19*cos(theta)**6 + 1.91178179919061e+17*cos(theta)**4 - 258990534999856.0*cos(theta)**2 + 58278698244.7922)*cos(6*phi)

#@torch.jit.script
def Yl94_m7(theta, phi):
    return 8.20141436451245e-14*(1.0 - cos(theta)**2)**3.5*(5.93824925300655e+40*cos(theta)**87 - 1.1879674040373e+42*cos(theta)**85 + 1.14622800876031e+43*cos(theta)**83 - 7.10494337670555e+43*cos(theta)**81 + 3.17956029565276e+44*cos(theta)**79 - 1.09455030959845e+45*cos(theta)**77 + 3.01568192644545e+45*cos(theta)**75 - 6.83144273133562e+45*cos(theta)**73 + 1.2971843567883e+46*cos(theta)**71 - 2.09454394192262e+46*cos(theta)**69 + 2.9075740164204e+46*cos(theta)**67 - 3.49953519341617e+46*cos(theta)**65 + 3.67627939510385e+46*cos(theta)**63 - 3.38828393517594e+46*cos(theta)**61 + 2.7509137539361e+46*cos(theta)**59 - 1.97350668049672e+46*cos(theta)**57 + 1.2538680979589e+46*cos(theta)**55 - 7.06639136800368e+45*cos(theta)**53 + 3.5357615486961e+45*cos(theta)**51 - 1.57131264363455e+45*cos(theta)**49 + 6.20088479501421e+44*cos(theta)**47 - 2.17141446822493e+44*cos(theta)**45 + 6.73887248759461e+43*cos(theta)**43 - 1.85016778847611e+43*cos(theta)**41 + 4.48326709973526e+42*cos(theta)**39 - 9.56000265008295e+41*cos(theta)**37 + 1.78746821026256e+41*cos(theta)**35 - 2.9178150483024e+40*cos(theta)**33 + 4.1369665561323e+39*cos(theta)**31 - 5.06367319979341e+38*cos(theta)**29 + 5.31227731037759e+37*cos(theta)**27 - 4.7361171855284e+36*cos(theta)**25 + 3.5520878891463e+35*cos(theta)**23 - 2.21403852169011e+34*cos(theta)**21 + 1.13016064549082e+33*cos(theta)**19 - 4.6400353032156e+31*cos(theta)**17 + 1.49820703047797e+30*cos(theta)**15 - 3.69710313043918e+28*cos(theta)**13 + 6.71574392580941e+26*cos(theta)**11 - 8.53236119010205e+24*cos(theta)**9 + 7.04506887256132e+22*cos(theta)**7 - 3.37238309377223e+20*cos(theta)**5 + 7.64712719676243e+17*cos(theta)**3 - 517981069999713.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl94_m8(theta, phi):
    return 8.70620807381728e-16*(1.0 - cos(theta)**2)**4*(5.1662768501157e+42*cos(theta)**86 - 1.0097722934317e+44*cos(theta)**84 + 9.5136924727106e+44*cos(theta)**82 - 5.75500413513149e+45*cos(theta)**80 + 2.51185263356568e+46*cos(theta)**78 - 8.42803738390808e+46*cos(theta)**76 + 2.26176144483409e+47*cos(theta)**74 - 4.986953193875e+47*cos(theta)**72 + 9.2100089331969e+47*cos(theta)**70 - 1.44523531992661e+48*cos(theta)**68 + 1.94807459100167e+48*cos(theta)**66 - 2.27469787572051e+48*cos(theta)**64 + 2.31605601891543e+48*cos(theta)**62 - 2.06685320045732e+48*cos(theta)**60 + 1.6230391148223e+48*cos(theta)**58 - 1.12489880788313e+48*cos(theta)**56 + 6.89627453877396e+47*cos(theta)**54 - 3.74518742504195e+47*cos(theta)**52 + 1.80323838983501e+47*cos(theta)**50 - 7.69943195380931e+46*cos(theta)**48 + 2.91441585365668e+46*cos(theta)**46 - 9.77136510701218e+45*cos(theta)**44 + 2.89771516966568e+45*cos(theta)**42 - 7.58568793275206e+44*cos(theta)**40 + 1.74847416889675e+44*cos(theta)**38 - 3.53720098053069e+43*cos(theta)**36 + 6.25613873591897e+42*cos(theta)**34 - 9.62878965939792e+41*cos(theta)**32 + 1.28245963240101e+41*cos(theta)**30 - 1.46846522794009e+40*cos(theta)**28 + 1.43431487380195e+39*cos(theta)**26 - 1.1840292963821e+38*cos(theta)**24 + 8.1698021450365e+36*cos(theta)**22 - 4.64948089554923e+35*cos(theta)**20 + 2.14730522643255e+34*cos(theta)**18 - 7.88806001546653e+32*cos(theta)**16 + 2.24731054571696e+31*cos(theta)**14 - 4.80623406957094e+29*cos(theta)**12 + 7.38731831839035e+27*cos(theta)**10 - 7.67912507109184e+25*cos(theta)**8 + 4.93154821079293e+23*cos(theta)**6 - 1.68619154688612e+21*cos(theta)**4 + 2.29413815902873e+18*cos(theta)**2 - 517981069999713.0)*cos(8*phi)

#@torch.jit.script
def Yl94_m9(theta, phi):
    return 9.2504147341075e-18*(1.0 - cos(theta)**2)**4.5*(4.4429980910995e+44*cos(theta)**85 - 8.48208726482632e+45*cos(theta)**83 + 7.80122782762269e+46*cos(theta)**81 - 4.60400330810519e+47*cos(theta)**79 + 1.95924505418123e+48*cos(theta)**77 - 6.40530841177014e+48*cos(theta)**75 + 1.67370346917723e+49*cos(theta)**73 - 3.59060629959e+49*cos(theta)**71 + 6.44700625323783e+49*cos(theta)**69 - 9.82760017550094e+49*cos(theta)**67 + 1.2857292300611e+50*cos(theta)**65 - 1.45580664046112e+50*cos(theta)**63 + 1.43595473172756e+50*cos(theta)**61 - 1.24011192027439e+50*cos(theta)**59 + 9.41362686596934e+49*cos(theta)**57 - 6.29943332414552e+49*cos(theta)**55 + 3.72398825093794e+49*cos(theta)**53 - 1.94749746102181e+49*cos(theta)**51 + 9.01619194917506e+48*cos(theta)**49 - 3.69572733782847e+48*cos(theta)**47 + 1.34063129268207e+48*cos(theta)**45 - 4.29940064708536e+47*cos(theta)**43 + 1.21704037125959e+47*cos(theta)**41 - 3.03427517310082e+46*cos(theta)**39 + 6.64420184180765e+45*cos(theta)**37 - 1.27339235299105e+45*cos(theta)**35 + 2.12708717021245e+44*cos(theta)**33 - 3.08121269100733e+43*cos(theta)**31 + 3.84737889720304e+42*cos(theta)**29 - 4.11170263823225e+41*cos(theta)**27 + 3.72921867188507e+40*cos(theta)**25 - 2.84167031131704e+39*cos(theta)**23 + 1.79735647190803e+38*cos(theta)**21 - 9.29896179109845e+36*cos(theta)**19 + 3.8651494075786e+35*cos(theta)**17 - 1.26208960247464e+34*cos(theta)**15 + 3.14623476400374e+32*cos(theta)**13 - 5.76748088348512e+30*cos(theta)**11 + 7.38731831839035e+28*cos(theta)**9 - 6.14330005687347e+26*cos(theta)**7 + 2.95892892647576e+24*cos(theta)**5 - 6.74476618754446e+21*cos(theta)**3 + 4.58827631805746e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl94_m10(theta, phi):
    return 9.8386400460569e-20*(1.0 - cos(theta)**2)**5*(3.77654837743457e+46*cos(theta)**84 - 7.04013242980584e+47*cos(theta)**82 + 6.31899454037438e+48*cos(theta)**80 - 3.6371626134031e+49*cos(theta)**78 + 1.50861869171955e+50*cos(theta)**76 - 4.80398130882761e+50*cos(theta)**74 + 1.22180353249938e+51*cos(theta)**72 - 2.5493304727089e+51*cos(theta)**70 + 4.4484343147341e+51*cos(theta)**68 - 6.58449211758563e+51*cos(theta)**66 + 8.35723999539714e+51*cos(theta)**64 - 9.17158183490509e+51*cos(theta)**62 + 8.75932386353814e+51*cos(theta)**60 - 7.31666032961893e+51*cos(theta)**58 + 5.36576731360252e+51*cos(theta)**56 - 3.46468832828004e+51*cos(theta)**54 + 1.97371377299711e+51*cos(theta)**52 - 9.93223705121125e+50*cos(theta)**50 + 4.41793405509578e+50*cos(theta)**48 - 1.73699184877938e+50*cos(theta)**46 + 6.03284081706932e+49*cos(theta)**44 - 1.8487422782467e+49*cos(theta)**42 + 4.9898655221643e+48*cos(theta)**40 - 1.18336731750932e+48*cos(theta)**38 + 2.45835468146883e+47*cos(theta)**36 - 4.45687323546867e+46*cos(theta)**34 + 7.01938766170108e+45*cos(theta)**32 - 9.55175934212274e+44*cos(theta)**30 + 1.11573988018888e+44*cos(theta)**28 - 1.11015971232271e+43*cos(theta)**26 + 9.32304667971266e+41*cos(theta)**24 - 6.5358417160292e+40*cos(theta)**22 + 3.77444859100686e+39*cos(theta)**20 - 1.76680274030871e+38*cos(theta)**18 + 6.57075399288362e+36*cos(theta)**16 - 1.89313440371197e+35*cos(theta)**14 + 4.09010519320487e+33*cos(theta)**12 - 6.34422897183363e+31*cos(theta)**10 + 6.64858648655132e+29*cos(theta)**8 - 4.30031003981143e+27*cos(theta)**6 + 1.47946446323788e+25*cos(theta)**4 - 2.02342985626334e+22*cos(theta)**2 + 4.58827631805746e+18)*cos(10*phi)

#@torch.jit.script
def Yl94_m11(theta, phi):
    return 1.04761275948261e-21*(1.0 - cos(theta)**2)**5.5*(3.17230063704504e+48*cos(theta)**83 - 5.77290859244079e+49*cos(theta)**81 + 5.0551956322995e+50*cos(theta)**79 - 2.83698683845442e+51*cos(theta)**77 + 1.14655020570686e+52*cos(theta)**75 - 3.55494616853243e+52*cos(theta)**73 + 8.7969854339955e+52*cos(theta)**71 - 1.78453133089623e+53*cos(theta)**69 + 3.02493533401919e+53*cos(theta)**67 - 4.34576479760652e+53*cos(theta)**65 + 5.34863359705417e+53*cos(theta)**63 - 5.68638073764115e+53*cos(theta)**61 + 5.25559431812288e+53*cos(theta)**59 - 4.24366299117898e+53*cos(theta)**57 + 3.00482969561741e+53*cos(theta)**55 - 1.87093169727122e+53*cos(theta)**53 + 1.0263311619585e+53*cos(theta)**51 - 4.96611852560562e+52*cos(theta)**49 + 2.12060834644597e+52*cos(theta)**47 - 7.99016250438515e+51*cos(theta)**45 + 2.6544499595105e+51*cos(theta)**43 - 7.76471756863616e+50*cos(theta)**41 + 1.99594620886572e+50*cos(theta)**39 - 4.49679580653542e+49*cos(theta)**37 + 8.85007685328779e+48*cos(theta)**35 - 1.51533690005935e+48*cos(theta)**33 + 2.24620405174435e+47*cos(theta)**31 - 2.86552780263682e+46*cos(theta)**29 + 3.12407166452886e+45*cos(theta)**27 - 2.88641525203904e+44*cos(theta)**25 + 2.23753120313104e+43*cos(theta)**23 - 1.43788517752642e+42*cos(theta)**21 + 7.54889718201372e+40*cos(theta)**19 - 3.18024493255567e+39*cos(theta)**17 + 1.05132063886138e+38*cos(theta)**15 - 2.65038816519675e+36*cos(theta)**13 + 4.90812623184584e+34*cos(theta)**11 - 6.34422897183363e+32*cos(theta)**9 + 5.31886918924105e+30*cos(theta)**7 - 2.58018602388686e+28*cos(theta)**5 + 5.91785785295151e+25*cos(theta)**3 - 4.04685971252668e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl94_m12(theta, phi):
    return 1.11688587998697e-23*(1.0 - cos(theta)**2)**6*(2.63300952874739e+50*cos(theta)**82 - 4.67605595987704e+51*cos(theta)**80 + 3.99360454951661e+52*cos(theta)**78 - 2.1844798656099e+53*cos(theta)**76 + 8.59912654280142e+53*cos(theta)**74 - 2.59511070302867e+54*cos(theta)**72 + 6.24585965813681e+54*cos(theta)**70 - 1.2313266183184e+55*cos(theta)**68 + 2.02670667379286e+55*cos(theta)**66 - 2.82474711844424e+55*cos(theta)**64 + 3.36963916614413e+55*cos(theta)**62 - 3.4686922499611e+55*cos(theta)**60 + 3.1008006476925e+55*cos(theta)**58 - 2.41888790497202e+55*cos(theta)**56 + 1.65265633258958e+55*cos(theta)**54 - 9.91593799553746e+54*cos(theta)**52 + 5.23428892598833e+54*cos(theta)**50 - 2.43339807754676e+54*cos(theta)**48 + 9.96685922829608e+53*cos(theta)**46 - 3.59557312697332e+53*cos(theta)**44 + 1.14141348258952e+53*cos(theta)**42 - 3.18353420314083e+52*cos(theta)**40 + 7.78419021457631e+51*cos(theta)**38 - 1.66381444841811e+51*cos(theta)**36 + 3.09752689865073e+50*cos(theta)**34 - 5.00061177019585e+49*cos(theta)**32 + 6.96323256040747e+48*cos(theta)**30 - 8.31003062764678e+47*cos(theta)**28 + 8.43499349422793e+46*cos(theta)**26 - 7.2160381300976e+45*cos(theta)**24 + 5.14632176720139e+44*cos(theta)**22 - 3.01955887280549e+43*cos(theta)**20 + 1.43429046458261e+42*cos(theta)**18 - 5.40641638534464e+40*cos(theta)**16 + 1.57698095829207e+39*cos(theta)**14 - 3.44550461475578e+37*cos(theta)**12 + 5.39893885503042e+35*cos(theta)**10 - 5.70980607465027e+33*cos(theta)**8 + 3.72320843246874e+31*cos(theta)**6 - 1.29009301194343e+29*cos(theta)**4 + 1.77535735588545e+26*cos(theta)**2 - 4.04685971252668e+22)*cos(12*phi)

#@torch.jit.script
def Yl94_m13(theta, phi):
    return 1.19236710290311e-25*(1.0 - cos(theta)**2)**6.5*(2.15906781357286e+52*cos(theta)**81 - 3.74084476790163e+53*cos(theta)**79 + 3.11501154862295e+54*cos(theta)**77 - 1.66020469786353e+55*cos(theta)**75 + 6.36335364167305e+55*cos(theta)**73 - 1.86847970618065e+56*cos(theta)**71 + 4.37210176069577e+56*cos(theta)**69 - 8.37302100456512e+56*cos(theta)**67 + 1.33762640470329e+57*cos(theta)**65 - 1.80783815580431e+57*cos(theta)**63 + 2.08917628300936e+57*cos(theta)**61 - 2.08121534997666e+57*cos(theta)**59 + 1.79846437566165e+57*cos(theta)**57 - 1.35457722678433e+57*cos(theta)**55 + 8.92434419598372e+56*cos(theta)**53 - 5.15628775767948e+56*cos(theta)**51 + 2.61714446299416e+56*cos(theta)**49 - 1.16803107722244e+56*cos(theta)**47 + 4.5847552450162e+55*cos(theta)**45 - 1.58205217586826e+55*cos(theta)**43 + 4.79393662687597e+54*cos(theta)**41 - 1.27341368125633e+54*cos(theta)**39 + 2.957992281539e+53*cos(theta)**37 - 5.98973201430518e+52*cos(theta)**35 + 1.05315914554125e+52*cos(theta)**33 - 1.60019576646267e+51*cos(theta)**31 + 2.08896976812224e+50*cos(theta)**29 - 2.3268085757411e+49*cos(theta)**27 + 2.19309830849926e+48*cos(theta)**25 - 1.73184915122342e+47*cos(theta)**23 + 1.13219078878431e+46*cos(theta)**21 - 6.03911774561098e+44*cos(theta)**19 + 2.58172283624869e+43*cos(theta)**17 - 8.65026621655142e+41*cos(theta)**15 + 2.2077733416089e+40*cos(theta)**13 - 4.13460553770693e+38*cos(theta)**11 + 5.39893885503042e+36*cos(theta)**9 - 4.56784485972022e+34*cos(theta)**7 + 2.23392505948124e+32*cos(theta)**5 - 5.16037204777372e+29*cos(theta)**3 + 3.55071471177091e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl94_m14(theta, phi):
    return 1.27483975524809e-27*(1.0 - cos(theta)**2)**7*(1.74884492899401e+54*cos(theta)**80 - 2.95526736664229e+55*cos(theta)**78 + 2.39855889243967e+56*cos(theta)**76 - 1.24515352339765e+57*cos(theta)**74 + 4.64524815842133e+57*cos(theta)**72 - 1.32662059138826e+58*cos(theta)**70 + 3.01675021488008e+58*cos(theta)**68 - 5.60992407305863e+58*cos(theta)**66 + 8.69457163057136e+58*cos(theta)**64 - 1.13893803815672e+59*cos(theta)**62 + 1.27439753263571e+59*cos(theta)**60 - 1.22791705648623e+59*cos(theta)**58 + 1.02512469412714e+59*cos(theta)**56 - 7.45017474731382e+58*cos(theta)**54 + 4.72990242387137e+58*cos(theta)**52 - 2.62970675641654e+58*cos(theta)**50 + 1.28240078686714e+58*cos(theta)**48 - 5.48974606294548e+57*cos(theta)**46 + 2.06313986025729e+57*cos(theta)**44 - 6.80282435623351e+56*cos(theta)**42 + 1.96551401701915e+56*cos(theta)**40 - 4.96631335689969e+55*cos(theta)**38 + 1.09445714416943e+55*cos(theta)**36 - 2.09640620500681e+54*cos(theta)**34 + 3.47542518028612e+53*cos(theta)**32 - 4.96060687603429e+52*cos(theta)**30 + 6.0580123275545e+51*cos(theta)**28 - 6.28238315450097e+50*cos(theta)**26 + 5.48274577124816e+49*cos(theta)**24 - 3.98325304781388e+48*cos(theta)**22 + 2.37760065644704e+47*cos(theta)**20 - 1.14743237166609e+46*cos(theta)**18 + 4.38892882162278e+44*cos(theta)**16 - 1.29753993248271e+43*cos(theta)**14 + 2.87010534409156e+41*cos(theta)**12 - 4.54806609147763e+39*cos(theta)**10 + 4.85904496952738e+37*cos(theta)**8 - 3.19749140180415e+35*cos(theta)**6 + 1.11696252974062e+33*cos(theta)**4 - 1.54811161433212e+30*cos(theta)**2 + 3.55071471177091e+26)*cos(14*phi)

#@torch.jit.script
def Yl94_m15(theta, phi):
    return 1.36520338302375e-29*(1.0 - cos(theta)**2)**7.5*(1.39907594319521e+56*cos(theta)**79 - 2.30510854598099e+57*cos(theta)**77 + 1.82290475825415e+58*cos(theta)**75 - 9.21413607314258e+58*cos(theta)**73 + 3.34457867406335e+59*cos(theta)**71 - 9.28634413971781e+59*cos(theta)**69 + 2.05139014611845e+60*cos(theta)**67 - 3.70254988821869e+60*cos(theta)**65 + 5.56452584356567e+60*cos(theta)**63 - 7.06141583657164e+60*cos(theta)**61 + 7.64638519581426e+60*cos(theta)**59 - 7.12191892762014e+60*cos(theta)**57 + 5.74069828711199e+60*cos(theta)**55 - 4.02309436354946e+60*cos(theta)**53 + 2.45954926041311e+60*cos(theta)**51 - 1.31485337820827e+60*cos(theta)**49 + 6.15552377696227e+59*cos(theta)**47 - 2.52528318895492e+59*cos(theta)**45 + 9.07781538513207e+58*cos(theta)**43 - 2.85718622961808e+58*cos(theta)**41 + 7.86205606807658e+57*cos(theta)**39 - 1.88719907562188e+57*cos(theta)**37 + 3.94004571900995e+56*cos(theta)**35 - 7.12778109702316e+55*cos(theta)**33 + 1.11213605769156e+55*cos(theta)**31 - 1.48818206281029e+54*cos(theta)**29 + 1.69624345171526e+53*cos(theta)**27 - 1.63341962017025e+52*cos(theta)**25 + 1.31585898509956e+51*cos(theta)**23 - 8.76315670519053e+49*cos(theta)**21 + 4.75520131289408e+48*cos(theta)**19 - 2.06537826899895e+47*cos(theta)**17 + 7.02228611459645e+45*cos(theta)**15 - 1.8165559054758e+44*cos(theta)**13 + 3.44412641290988e+42*cos(theta)**11 - 4.54806609147763e+40*cos(theta)**9 + 3.8872359756219e+38*cos(theta)**7 - 1.91849484108249e+36*cos(theta)**5 + 4.46785011896248e+33*cos(theta)**3 - 3.09622322866423e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl94_m16(theta, phi):
    return 1.46449356450711e-31*(1.0 - cos(theta)**2)**8*(1.10526999512422e+58*cos(theta)**78 - 1.77493358040536e+59*cos(theta)**76 + 1.36717856869061e+60*cos(theta)**74 - 6.72631933339408e+60*cos(theta)**72 + 2.37465085858498e+61*cos(theta)**70 - 6.40757745640529e+61*cos(theta)**68 + 1.37443139789936e+62*cos(theta)**66 - 2.40665742734215e+62*cos(theta)**64 + 3.50565128144637e+62*cos(theta)**62 - 4.3074636603087e+62*cos(theta)**60 + 4.51136726553041e+62*cos(theta)**58 - 4.05949378874348e+62*cos(theta)**56 + 3.15738405791159e+62*cos(theta)**54 - 2.13224001268121e+62*cos(theta)**52 + 1.25437012281069e+62*cos(theta)**50 - 6.44278155322051e+61*cos(theta)**48 + 2.89309617517227e+61*cos(theta)**46 - 1.13637743502971e+61*cos(theta)**44 + 3.90346061560679e+60*cos(theta)**42 - 1.17144635414341e+60*cos(theta)**40 + 3.06620186654987e+59*cos(theta)**38 - 6.98263657980096e+58*cos(theta)**36 + 1.37901600165348e+58*cos(theta)**34 - 2.35216776201764e+57*cos(theta)**32 + 3.44762177884383e+56*cos(theta)**30 - 4.31572798214983e+55*cos(theta)**28 + 4.5798573196312e+54*cos(theta)**26 - 4.08354905042563e+53*cos(theta)**24 + 3.02647566572898e+52*cos(theta)**22 - 1.84026290809001e+51*cos(theta)**20 + 9.03488249449876e+49*cos(theta)**18 - 3.51114305729822e+48*cos(theta)**16 + 1.05334291718947e+47*cos(theta)**14 - 2.36152267711854e+45*cos(theta)**12 + 3.78853905420086e+43*cos(theta)**10 - 4.09325948232987e+41*cos(theta)**8 + 2.72106518293533e+39*cos(theta)**6 - 9.59247420541246e+36*cos(theta)**4 + 1.34035503568875e+34*cos(theta)**2 - 3.09622322866423e+30)*cos(16*phi)

#@torch.jit.script
def Yl94_m17(theta, phi):
    return 1.57390558634765e-33*(1.0 - cos(theta)**2)**8.5*(8.62110596196889e+59*cos(theta)**77 - 1.34894952110807e+61*cos(theta)**75 + 1.01171214083105e+62*cos(theta)**73 - 4.84294992004374e+62*cos(theta)**71 + 1.66225560100949e+63*cos(theta)**69 - 4.3571526703556e+63*cos(theta)**67 + 9.0712472261358e+63*cos(theta)**65 - 1.54026075349898e+64*cos(theta)**63 + 2.17350379449675e+64*cos(theta)**61 - 2.58447819618522e+64*cos(theta)**59 + 2.61659301400764e+64*cos(theta)**57 - 2.27331652169635e+64*cos(theta)**55 + 1.70498739127226e+64*cos(theta)**53 - 1.10876480659423e+64*cos(theta)**51 + 6.27185061405344e+63*cos(theta)**49 - 3.09253514554585e+63*cos(theta)**47 + 1.33082424057924e+63*cos(theta)**45 - 5.00006071413074e+62*cos(theta)**43 + 1.63945345855485e+62*cos(theta)**41 - 4.68578541657364e+61*cos(theta)**39 + 1.16515670928895e+61*cos(theta)**37 - 2.51374916872835e+60*cos(theta)**35 + 4.68865440562184e+59*cos(theta)**33 - 7.52693683845646e+58*cos(theta)**31 + 1.03428653365315e+58*cos(theta)**29 - 1.20840383500195e+57*cos(theta)**27 + 1.19076290310411e+56*cos(theta)**25 - 9.80051772102151e+54*cos(theta)**23 + 6.65824646460376e+53*cos(theta)**21 - 3.68052581618002e+52*cos(theta)**19 + 1.62627884900978e+51*cos(theta)**17 - 5.61782889167716e+49*cos(theta)**15 + 1.47468008406525e+48*cos(theta)**13 - 2.83382721254225e+46*cos(theta)**11 + 3.78853905420086e+44*cos(theta)**9 - 3.27460758586389e+42*cos(theta)**7 + 1.6326391097612e+40*cos(theta)**5 - 3.83698968216498e+37*cos(theta)**3 + 2.68071007137749e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl94_m18(theta, phi):
    return 1.69482281992191e-35*(1.0 - cos(theta)**2)**9*(6.63825159071604e+61*cos(theta)**76 - 1.01171214083105e+63*cos(theta)**74 + 7.3854986280667e+63*cos(theta)**72 - 3.43849444323105e+64*cos(theta)**70 + 1.14695636469655e+65*cos(theta)**68 - 2.91929228913825e+65*cos(theta)**66 + 5.89631069698827e+65*cos(theta)**64 - 9.70364274704355e+65*cos(theta)**62 + 1.32583731464302e+66*cos(theta)**60 - 1.52484213574928e+66*cos(theta)**58 + 1.49145801798435e+66*cos(theta)**56 - 1.25032408693299e+66*cos(theta)**54 + 9.03643317374298e+65*cos(theta)**52 - 5.65470051363058e+65*cos(theta)**50 + 3.07320680088618e+65*cos(theta)**48 - 1.45349151840655e+65*cos(theta)**46 + 5.9887090826066e+64*cos(theta)**44 - 2.15002610707622e+64*cos(theta)**42 + 6.72175918007489e+63*cos(theta)**40 - 1.82745631246372e+63*cos(theta)**38 + 4.31107982436911e+62*cos(theta)**36 - 8.79812209054921e+61*cos(theta)**34 + 1.54725595385521e+61*cos(theta)**32 - 2.3333504199215e+60*cos(theta)**30 + 2.99943094759413e+59*cos(theta)**28 - 3.26269035450527e+58*cos(theta)**26 + 2.97690725776028e+57*cos(theta)**24 - 2.25411907583495e+56*cos(theta)**22 + 1.39823175756679e+55*cos(theta)**20 - 6.99299905074204e+53*cos(theta)**18 + 2.76467404331662e+52*cos(theta)**16 - 8.42674333751574e+50*cos(theta)**14 + 1.91708410928483e+49*cos(theta)**12 - 3.11720993379647e+47*cos(theta)**10 + 3.40968514878078e+45*cos(theta)**8 - 2.29222531010472e+43*cos(theta)**6 + 8.163195548806e+40*cos(theta)**4 - 1.15109690464949e+38*cos(theta)**2 + 2.68071007137749e+34)*cos(18*phi)

#@torch.jit.script
def Yl94_m19(theta, phi):
    return 1.82885083545686e-37*(1.0 - cos(theta)**2)**9.5*(5.04507120894419e+63*cos(theta)**75 - 7.48666984214981e+64*cos(theta)**73 + 5.31755901220802e+65*cos(theta)**71 - 2.40694611026174e+66*cos(theta)**69 + 7.79930327993651e+66*cos(theta)**67 - 1.92673291083124e+67*cos(theta)**65 + 3.77363884607249e+67*cos(theta)**63 - 6.016258503167e+67*cos(theta)**61 + 7.9550238878581e+67*cos(theta)**59 - 8.84408438734582e+67*cos(theta)**57 + 8.35216490071238e+67*cos(theta)**55 - 6.75175006943815e+67*cos(theta)**53 + 4.69894525034635e+67*cos(theta)**51 - 2.82735025681529e+67*cos(theta)**49 + 1.47513926442537e+67*cos(theta)**47 - 6.68606098467012e+66*cos(theta)**45 + 2.6350319963469e+66*cos(theta)**43 - 9.03010964972012e+65*cos(theta)**41 + 2.68870367202996e+65*cos(theta)**39 - 6.94433398736214e+64*cos(theta)**37 + 1.55198873677288e+64*cos(theta)**35 - 2.99136151078673e+63*cos(theta)**33 + 4.95121905233666e+62*cos(theta)**31 - 7.00005125976451e+61*cos(theta)**29 + 8.39840665326356e+60*cos(theta)**27 - 8.4829949217137e+59*cos(theta)**25 + 7.14457741862468e+58*cos(theta)**23 - 4.95906196683688e+57*cos(theta)**21 + 2.79646351513358e+56*cos(theta)**19 - 1.25873982913357e+55*cos(theta)**17 + 4.42347846930659e+53*cos(theta)**15 - 1.1797440672522e+52*cos(theta)**13 + 2.3005009311418e+50*cos(theta)**11 - 3.11720993379647e+48*cos(theta)**9 + 2.72774811902462e+46*cos(theta)**7 - 1.37533518606283e+44*cos(theta)**5 + 3.2652782195224e+41*cos(theta)**3 - 2.30219380929899e+38*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl94_m20(theta, phi):
    return 1.97785854375996e-39*(1.0 - cos(theta)**2)**10*(3.78380340670815e+65*cos(theta)**74 - 5.46526898476936e+66*cos(theta)**72 + 3.7754668986677e+67*cos(theta)**70 - 1.6607928160806e+68*cos(theta)**68 + 5.22553319755747e+68*cos(theta)**66 - 1.25237639204031e+69*cos(theta)**64 + 2.37739247302567e+69*cos(theta)**62 - 3.66991768693187e+69*cos(theta)**60 + 4.69346409383628e+69*cos(theta)**58 - 5.04112810078712e+69*cos(theta)**56 + 4.59369069539181e+69*cos(theta)**54 - 3.57842753680222e+69*cos(theta)**52 + 2.39646207767664e+69*cos(theta)**50 - 1.38540162583949e+69*cos(theta)**48 + 6.93315454279923e+68*cos(theta)**46 - 3.00872744310155e+68*cos(theta)**44 + 1.13306375842917e+68*cos(theta)**42 - 3.70234495638525e+67*cos(theta)**40 + 1.04859443209168e+67*cos(theta)**38 - 2.56940357532399e+66*cos(theta)**36 + 5.43196057870508e+65*cos(theta)**34 - 9.87149298559621e+64*cos(theta)**32 + 1.53487790622436e+64*cos(theta)**30 - 2.03001486533171e+63*cos(theta)**28 + 2.26756979638116e+62*cos(theta)**26 - 2.12074873042843e+61*cos(theta)**24 + 1.64325280628368e+60*cos(theta)**22 - 1.04140301303575e+59*cos(theta)**20 + 5.3132806787538e+57*cos(theta)**18 - 2.13985770952706e+56*cos(theta)**16 + 6.63521770395989e+54*cos(theta)**14 - 1.53366728742786e+53*cos(theta)**12 + 2.53055102425598e+51*cos(theta)**10 - 2.80548894041682e+49*cos(theta)**8 + 1.90942368331724e+47*cos(theta)**6 - 6.87667593031417e+44*cos(theta)**4 + 9.7958346585672e+41*cos(theta)**2 - 2.30219380929899e+38)*cos(20*phi)

#@torch.jit.script
def Yl94_m21(theta, phi):
    return 2.14402797478665e-41*(1.0 - cos(theta)**2)**10.5*(2.80001452096403e+67*cos(theta)**73 - 3.93499366903394e+68*cos(theta)**71 + 2.64282682906739e+69*cos(theta)**69 - 1.12933911493481e+70*cos(theta)**67 + 3.44885191038793e+70*cos(theta)**65 - 8.01520890905798e+70*cos(theta)**63 + 1.47398333327592e+71*cos(theta)**61 - 2.20195061215912e+71*cos(theta)**59 + 2.72220917442504e+71*cos(theta)**57 - 2.82303173644079e+71*cos(theta)**55 + 2.48059297551158e+71*cos(theta)**53 - 1.86078231913716e+71*cos(theta)**51 + 1.19823103883832e+71*cos(theta)**49 - 6.64992780402956e+70*cos(theta)**47 + 3.18925108968765e+70*cos(theta)**45 - 1.32384007496468e+70*cos(theta)**43 + 4.7588677854025e+69*cos(theta)**41 - 1.4809379825541e+69*cos(theta)**39 + 3.9846588419484e+68*cos(theta)**37 - 9.24985287116637e+67*cos(theta)**35 + 1.84686659675973e+67*cos(theta)**33 - 3.15887775539079e+66*cos(theta)**31 + 4.60463371867309e+65*cos(theta)**29 - 5.68404162292878e+64*cos(theta)**27 + 5.89568147059102e+63*cos(theta)**25 - 5.08979695302822e+62*cos(theta)**23 + 3.61515617382409e+61*cos(theta)**21 - 2.08280602607149e+60*cos(theta)**19 + 9.56390522175684e+58*cos(theta)**17 - 3.4237723352433e+57*cos(theta)**15 + 9.28930478554385e+55*cos(theta)**13 - 1.84040074491344e+54*cos(theta)**11 + 2.53055102425598e+52*cos(theta)**9 - 2.24439115233346e+50*cos(theta)**7 + 1.14565420999034e+48*cos(theta)**5 - 2.75067037212567e+45*cos(theta)**3 + 1.95916693171344e+42*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl94_m22(theta, phi):
    return 2.32991470806215e-43*(1.0 - cos(theta)**2)**11*(2.04401060030374e+69*cos(theta)**72 - 2.7938455050141e+70*cos(theta)**70 + 1.8235505120565e+71*cos(theta)**68 - 7.56657207006321e+71*cos(theta)**66 + 2.24175374175215e+72*cos(theta)**64 - 5.04958161270652e+72*cos(theta)**62 + 8.99129833298309e+72*cos(theta)**60 - 1.29915086117388e+73*cos(theta)**58 + 1.55165922942227e+73*cos(theta)**56 - 1.55266745504243e+73*cos(theta)**54 + 1.31471427702114e+73*cos(theta)**52 - 9.48998982759949e+72*cos(theta)**50 + 5.87133209030777e+72*cos(theta)**48 - 3.12546606789389e+72*cos(theta)**46 + 1.43516299035944e+72*cos(theta)**44 - 5.69251232234814e+71*cos(theta)**42 + 1.95113579201503e+71*cos(theta)**40 - 5.77565813196099e+70*cos(theta)**38 + 1.47432377152091e+70*cos(theta)**36 - 3.23744850490823e+69*cos(theta)**34 + 6.0946597693071e+68*cos(theta)**32 - 9.79252104171144e+67*cos(theta)**30 + 1.3353437784152e+67*cos(theta)**28 - 1.53469123819077e+66*cos(theta)**26 + 1.47392036764776e+65*cos(theta)**24 - 1.17065329919649e+64*cos(theta)**22 + 7.59182796503058e+62*cos(theta)**20 - 3.95733144953583e+61*cos(theta)**18 + 1.62586388769866e+60*cos(theta)**16 - 5.13565850286495e+58*cos(theta)**14 + 1.2076096221207e+57*cos(theta)**12 - 2.02444081940478e+55*cos(theta)**10 + 2.27749592183038e+53*cos(theta)**8 - 1.57107380663342e+51*cos(theta)**6 + 5.72827104995171e+48*cos(theta)**4 - 8.25201111637701e+45*cos(theta)**2 + 1.95916693171344e+42)*cos(22*phi)

#@torch.jit.script
def Yl94_m23(theta, phi):
    return 2.53852148748199e-45*(1.0 - cos(theta)**2)**11.5*(1.47168763221869e+71*cos(theta)**71 - 1.95569185350987e+72*cos(theta)**69 + 1.24001434819842e+73*cos(theta)**67 - 4.99393756624172e+73*cos(theta)**65 + 1.43472239472138e+74*cos(theta)**63 - 3.13074059987805e+74*cos(theta)**61 + 5.39477899978985e+74*cos(theta)**59 - 7.53507499480852e+74*cos(theta)**57 + 8.68929168476474e+74*cos(theta)**55 - 8.38440425722913e+74*cos(theta)**53 + 6.83651424050991e+74*cos(theta)**51 - 4.74499491379975e+74*cos(theta)**49 + 2.81823940334773e+74*cos(theta)**47 - 1.43771439123119e+74*cos(theta)**45 + 6.31471715758154e+73*cos(theta)**43 - 2.39085517538622e+73*cos(theta)**41 + 7.80454316806011e+72*cos(theta)**39 - 2.19475009014518e+72*cos(theta)**37 + 5.30756557747526e+71*cos(theta)**35 - 1.1007324916688e+71*cos(theta)**33 + 1.95029112617827e+70*cos(theta)**31 - 2.93775631251343e+69*cos(theta)**29 + 3.73896257956255e+68*cos(theta)**27 - 3.990197219296e+67*cos(theta)**25 + 3.53740888235461e+66*cos(theta)**23 - 2.57543725823228e+65*cos(theta)**21 + 1.51836559300612e+64*cos(theta)**19 - 7.1231966091645e+62*cos(theta)**17 + 2.60138222031786e+61*cos(theta)**15 - 7.18992190401094e+59*cos(theta)**13 + 1.44913154654484e+58*cos(theta)**11 - 2.02444081940478e+56*cos(theta)**9 + 1.8219967374643e+54*cos(theta)**7 - 9.42644283980053e+51*cos(theta)**5 + 2.29130841998068e+49*cos(theta)**3 - 1.6504022232754e+46*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl94_m24(theta, phi):
    return 2.77338821558175e-47*(1.0 - cos(theta)**2)**12*(1.04489821887527e+73*cos(theta)**70 - 1.34942737892181e+74*cos(theta)**68 + 8.3080961329294e+74*cos(theta)**66 - 3.24605941805712e+75*cos(theta)**64 + 9.03875108674468e+75*cos(theta)**62 - 1.90975176592561e+76*cos(theta)**60 + 3.18291960987601e+76*cos(theta)**58 - 4.29499274704086e+76*cos(theta)**56 + 4.77911042662061e+76*cos(theta)**54 - 4.44373425633144e+76*cos(theta)**52 + 3.48662226266005e+76*cos(theta)**50 - 2.32504750776188e+76*cos(theta)**48 + 1.32457251957343e+76*cos(theta)**46 - 6.46971476054036e+75*cos(theta)**44 + 2.71532837776006e+75*cos(theta)**42 - 9.8025062190835e+74*cos(theta)**40 + 3.04377183554344e+74*cos(theta)**38 - 8.12057533353715e+73*cos(theta)**36 + 1.85764795211634e+73*cos(theta)**34 - 3.63241722250703e+72*cos(theta)**32 + 6.04590249115265e+71*cos(theta)**30 - 8.51949330628896e+70*cos(theta)**28 + 1.00951989648189e+70*cos(theta)**26 - 9.97549304824001e+68*cos(theta)**24 + 8.13604042941561e+67*cos(theta)**22 - 5.40841824228779e+66*cos(theta)**20 + 2.88489462671162e+65*cos(theta)**18 - 1.21094342355796e+64*cos(theta)**16 + 3.90207333047679e+62*cos(theta)**14 - 9.34689847521422e+60*cos(theta)**12 + 1.59404470119932e+59*cos(theta)**10 - 1.8219967374643e+57*cos(theta)**8 + 1.27539771622501e+55*cos(theta)**6 - 4.71322141990026e+52*cos(theta)**4 + 6.87392525994205e+49*cos(theta)**2 - 1.6504022232754e+46)*cos(24*phi)

#@torch.jit.script
def Yl94_m25(theta, phi):
    return 3.03870237404727e-49*(1.0 - cos(theta)**2)**12.5*(7.3142875321269e+74*cos(theta)**69 - 9.1761061766683e+75*cos(theta)**67 + 5.48334344773341e+76*cos(theta)**65 - 2.07747802755655e+77*cos(theta)**63 + 5.6040256737817e+77*cos(theta)**61 - 1.14585105955536e+78*cos(theta)**59 + 1.84609337372809e+78*cos(theta)**57 - 2.40519593834288e+78*cos(theta)**55 + 2.58071963037513e+78*cos(theta)**53 - 2.31074181329235e+78*cos(theta)**51 + 1.74331113133003e+78*cos(theta)**49 - 1.1160228037257e+78*cos(theta)**47 + 6.09303359003779e+77*cos(theta)**45 - 2.84667449463776e+77*cos(theta)**43 + 1.14043791865923e+77*cos(theta)**41 - 3.9210024876334e+76*cos(theta)**39 + 1.15663329750651e+76*cos(theta)**37 - 2.92340712007337e+75*cos(theta)**35 + 6.31600303719556e+74*cos(theta)**33 - 1.16237351120225e+74*cos(theta)**31 + 1.81377074734579e+73*cos(theta)**29 - 2.38545812576091e+72*cos(theta)**27 + 2.62475173085291e+71*cos(theta)**25 - 2.3941183315776e+70*cos(theta)**23 + 1.78992889447143e+69*cos(theta)**21 - 1.08168364845756e+68*cos(theta)**19 + 5.19281032808092e+66*cos(theta)**17 - 1.93750947769274e+65*cos(theta)**15 + 5.46290266266751e+63*cos(theta)**13 - 1.12162781702571e+62*cos(theta)**11 + 1.59404470119932e+60*cos(theta)**9 - 1.45759738997144e+58*cos(theta)**7 + 7.65238629735007e+55*cos(theta)**5 - 1.88528856796011e+53*cos(theta)**3 + 1.37478505198841e+50*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl94_m26(theta, phi):
    return 3.33943501651365e-51*(1.0 - cos(theta)**2)**13*(5.04685839716756e+76*cos(theta)**68 - 6.14799113836776e+77*cos(theta)**66 + 3.56417324102671e+78*cos(theta)**64 - 1.30881115736063e+79*cos(theta)**62 + 3.41845566100684e+79*cos(theta)**60 - 6.76052125137665e+79*cos(theta)**58 + 1.05227322302501e+80*cos(theta)**56 - 1.32285776608858e+80*cos(theta)**54 + 1.36778140409882e+80*cos(theta)**52 - 1.1784783247791e+80*cos(theta)**50 + 8.54222454351713e+79*cos(theta)**48 - 5.24530717751079e+79*cos(theta)**46 + 2.741865115517e+79*cos(theta)**44 - 1.22407003269424e+79*cos(theta)**42 + 4.67579546650283e+78*cos(theta)**40 - 1.52919097017703e+78*cos(theta)**38 + 4.27954320077408e+77*cos(theta)**36 - 1.02319249202568e+77*cos(theta)**34 + 2.08428100227454e+76*cos(theta)**32 - 3.60335788472698e+75*cos(theta)**30 + 5.2599351673028e+74*cos(theta)**28 - 6.44073693955445e+73*cos(theta)**26 + 6.56187932713228e+72*cos(theta)**24 - 5.50647216262849e+71*cos(theta)**22 + 3.75885067839001e+70*cos(theta)**20 - 2.05519893206936e+69*cos(theta)**18 + 8.82777755773756e+67*cos(theta)**16 - 2.90626421653912e+66*cos(theta)**14 + 7.10177346146776e+64*cos(theta)**12 - 1.23379059872828e+63*cos(theta)**10 + 1.43464023107939e+61*cos(theta)**8 - 1.02031817298001e+59*cos(theta)**6 + 3.82619314867503e+56*cos(theta)**4 - 5.65586570388032e+53*cos(theta)**2 + 1.37478505198841e+50)*cos(26*phi)

#@torch.jit.script
def Yl94_m27(theta, phi):
    return 3.68150890453798e-53*(1.0 - cos(theta)**2)**13.5*(3.43186371007394e+78*cos(theta)**67 - 4.05767415132272e+79*cos(theta)**65 + 2.2810708742571e+80*cos(theta)**63 - 8.1146291756359e+80*cos(theta)**61 + 2.0510733966041e+81*cos(theta)**59 - 3.92110232579846e+81*cos(theta)**57 + 5.89273004894005e+81*cos(theta)**55 - 7.14343193687835e+81*cos(theta)**53 + 7.11246330131385e+81*cos(theta)**51 - 5.89239162389549e+81*cos(theta)**49 + 4.10026778088822e+81*cos(theta)**47 - 2.41284130165496e+81*cos(theta)**45 + 1.20642065082748e+81*cos(theta)**43 - 5.14109413731579e+80*cos(theta)**41 + 1.87031818660113e+80*cos(theta)**39 - 5.8109256866727e+79*cos(theta)**37 + 1.54063555227867e+79*cos(theta)**35 - 3.47885447288732e+78*cos(theta)**33 + 6.66969920727851e+77*cos(theta)**31 - 1.08100736541809e+77*cos(theta)**29 + 1.47278184684478e+76*cos(theta)**27 - 1.67459160428416e+75*cos(theta)**25 + 1.57485103851175e+74*cos(theta)**23 - 1.21142387577827e+73*cos(theta)**21 + 7.51770135678002e+71*cos(theta)**19 - 3.69935807772485e+70*cos(theta)**17 + 1.41244440923801e+69*cos(theta)**15 - 4.06876990315476e+67*cos(theta)**13 + 8.52212815376132e+65*cos(theta)**11 - 1.23379059872828e+64*cos(theta)**9 + 1.14771218486351e+62*cos(theta)**7 - 6.12190903788006e+59*cos(theta)**5 + 1.53047725947001e+57*cos(theta)**3 - 1.13117314077606e+54*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl94_m28(theta, phi):
    return 4.07200721244265e-55*(1.0 - cos(theta)**2)**14*(2.29934868574954e+80*cos(theta)**66 - 2.63748819835977e+81*cos(theta)**64 + 1.43707465078197e+82*cos(theta)**62 - 4.9499237971379e+82*cos(theta)**60 + 1.21013330399642e+83*cos(theta)**58 - 2.23502832570512e+83*cos(theta)**56 + 3.24100152691703e+83*cos(theta)**54 - 3.78601892654553e+83*cos(theta)**52 + 3.62735628367006e+83*cos(theta)**50 - 2.88727189570879e+83*cos(theta)**48 + 1.92712585701746e+83*cos(theta)**46 - 1.08577858574473e+83*cos(theta)**44 + 5.18760879855817e+82*cos(theta)**42 - 2.10784859629947e+82*cos(theta)**40 + 7.29424092774441e+81*cos(theta)**38 - 2.1500425040689e+81*cos(theta)**36 + 5.39222443297534e+80*cos(theta)**34 - 1.14802197605281e+80*cos(theta)**32 + 2.06760675425634e+79*cos(theta)**30 - 3.13492135971247e+78*cos(theta)**28 + 3.97651098648092e+77*cos(theta)**26 - 4.18647901071039e+76*cos(theta)**24 + 3.62215738857702e+75*cos(theta)**22 - 2.54399013913436e+74*cos(theta)**20 + 1.4283632577882e+73*cos(theta)**18 - 6.28890873213224e+71*cos(theta)**16 + 2.11866661385701e+70*cos(theta)**14 - 5.28940087410119e+68*cos(theta)**12 + 9.37434096913745e+66*cos(theta)**10 - 1.11041153885545e+65*cos(theta)**8 + 8.03398529404459e+62*cos(theta)**6 - 3.06095451894003e+60*cos(theta)**4 + 4.59143177841004e+57*cos(theta)**2 - 1.13117314077606e+54)*cos(28*phi)

#@torch.jit.script
def Yl94_m29(theta, phi):
    return 4.51943365200135e-57*(1.0 - cos(theta)**2)**14.5*(1.5175701325947e+82*cos(theta)**65 - 1.68799244695025e+83*cos(theta)**63 + 8.90986283484822e+83*cos(theta)**61 - 2.96995427828274e+84*cos(theta)**59 + 7.01877316317924e+84*cos(theta)**57 - 1.25161586239487e+85*cos(theta)**55 + 1.7501408245352e+85*cos(theta)**53 - 1.96872984180367e+85*cos(theta)**51 + 1.81367814183503e+85*cos(theta)**49 - 1.38589050994022e+85*cos(theta)**47 + 8.86477894228034e+84*cos(theta)**45 - 4.77742577727683e+84*cos(theta)**43 + 2.17879569539443e+84*cos(theta)**41 - 8.4313943851979e+83*cos(theta)**39 + 2.77181155254288e+83*cos(theta)**37 - 7.74015301464803e+82*cos(theta)**35 + 1.83335630721162e+82*cos(theta)**33 - 3.67367032336901e+81*cos(theta)**31 + 6.20282026276902e+80*cos(theta)**29 - 8.77777980719492e+79*cos(theta)**27 + 1.03389285648504e+79*cos(theta)**25 - 1.00475496257049e+78*cos(theta)**23 + 7.96874625486944e+76*cos(theta)**21 - 5.08798027826872e+75*cos(theta)**19 + 2.57105386401877e+74*cos(theta)**17 - 1.00622539714116e+73*cos(theta)**15 + 2.96613325939982e+71*cos(theta)**13 - 6.34728104892143e+69*cos(theta)**11 + 9.37434096913745e+67*cos(theta)**9 - 8.88329231084359e+65*cos(theta)**7 + 4.82039117642676e+63*cos(theta)**5 - 1.22438180757601e+61*cos(theta)**3 + 9.18286355682008e+57*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl94_m30(theta, phi):
    return 5.03403805360215e-59*(1.0 - cos(theta)**2)**15*(9.86420586186554e+83*cos(theta)**64 - 1.06343524157866e+85*cos(theta)**62 + 5.43501632925741e+85*cos(theta)**60 - 1.75227302418682e+86*cos(theta)**58 + 4.00070070301217e+86*cos(theta)**56 - 6.88388724317177e+86*cos(theta)**54 + 9.27574637003654e+86*cos(theta)**52 - 1.00405221931987e+87*cos(theta)**50 + 8.88702289499166e+86*cos(theta)**48 - 6.51368539671903e+86*cos(theta)**46 + 3.98915052402615e+86*cos(theta)**44 - 2.05429308422904e+86*cos(theta)**42 + 8.93306235111717e+85*cos(theta)**40 - 3.28824381022718e+85*cos(theta)**38 + 1.02557027444086e+85*cos(theta)**36 - 2.70905355512681e+84*cos(theta)**34 + 6.05007581379833e+83*cos(theta)**32 - 1.13883780024439e+83*cos(theta)**30 + 1.79881787620302e+82*cos(theta)**28 - 2.37000054794263e+81*cos(theta)**26 + 2.5847321412126e+80*cos(theta)**24 - 2.31093641391214e+79*cos(theta)**22 + 1.67343671352258e+78*cos(theta)**20 - 9.66716252871057e+76*cos(theta)**18 + 4.37079156883191e+75*cos(theta)**16 - 1.50933809571174e+74*cos(theta)**14 + 3.85597323721977e+72*cos(theta)**12 - 6.98200915381357e+70*cos(theta)**10 + 8.4369068722237e+68*cos(theta)**8 - 6.21830461759051e+66*cos(theta)**6 + 2.41019558821338e+64*cos(theta)**4 - 3.67314542272803e+61*cos(theta)**2 + 9.18286355682008e+57)*cos(30*phi)

#@torch.jit.script
def Yl94_m31(theta, phi):
    return 5.62822564458757e-61*(1.0 - cos(theta)**2)**15.5*(6.31309175159394e+85*cos(theta)**63 - 6.59329849778768e+86*cos(theta)**61 + 3.26100979755445e+87*cos(theta)**59 - 1.01631835402835e+88*cos(theta)**57 + 2.24039239368681e+88*cos(theta)**55 - 3.71729911131276e+88*cos(theta)**53 + 4.823388112419e+88*cos(theta)**51 - 5.02026109659937e+88*cos(theta)**49 + 4.265770989596e+88*cos(theta)**47 - 2.99629528249075e+88*cos(theta)**45 + 1.75522623057151e+88*cos(theta)**43 - 8.62803095376195e+87*cos(theta)**41 + 3.57322494044687e+87*cos(theta)**39 - 1.24953264788633e+87*cos(theta)**37 + 3.69205298798711e+86*cos(theta)**35 - 9.21078208743116e+85*cos(theta)**33 + 1.93602426041547e+85*cos(theta)**31 - 3.41651340073318e+84*cos(theta)**29 + 5.03669005336844e+83*cos(theta)**27 - 6.16200142465083e+82*cos(theta)**25 + 6.20335713891023e+81*cos(theta)**23 - 5.0840601106067e+80*cos(theta)**21 + 3.34687342704516e+79*cos(theta)**19 - 1.7400892551679e+78*cos(theta)**17 + 6.99326651013105e+76*cos(theta)**15 - 2.11307333399643e+75*cos(theta)**13 + 4.62716788466372e+73*cos(theta)**11 - 6.98200915381357e+71*cos(theta)**9 + 6.74952549777896e+69*cos(theta)**7 - 3.73098277055431e+67*cos(theta)**5 + 9.64078235285351e+64*cos(theta)**3 - 7.34629084545607e+61*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl94_m32(theta, phi):
    return 6.31707384021571e-63*(1.0 - cos(theta)**2)**16*(3.97724780350418e+87*cos(theta)**62 - 4.02191208365049e+88*cos(theta)**60 + 1.92399578055712e+89*cos(theta)**58 - 5.79301461796162e+89*cos(theta)**56 + 1.23221581652775e+90*cos(theta)**54 - 1.97016852899576e+90*cos(theta)**52 + 2.45992793733369e+90*cos(theta)**50 - 2.45992793733369e+90*cos(theta)**48 + 2.00491236511012e+90*cos(theta)**46 - 1.34833287712084e+90*cos(theta)**44 + 7.54747279145748e+89*cos(theta)**42 - 3.5374926910424e+89*cos(theta)**40 + 1.39355772677428e+89*cos(theta)**38 - 4.62327079717942e+88*cos(theta)**36 + 1.29221854579549e+88*cos(theta)**34 - 3.03955808885228e+87*cos(theta)**32 + 6.00167520728794e+86*cos(theta)**30 - 9.90788886212621e+85*cos(theta)**28 + 1.35990631440948e+85*cos(theta)**26 - 1.54050035616271e+84*cos(theta)**24 + 1.42677214194935e+83*cos(theta)**22 - 1.06765262322741e+82*cos(theta)**20 + 6.35905951138581e+80*cos(theta)**18 - 2.95815173378543e+79*cos(theta)**16 + 1.04898997651966e+78*cos(theta)**14 - 2.74699533419536e+76*cos(theta)**12 + 5.08988467313009e+74*cos(theta)**10 - 6.28380823843221e+72*cos(theta)**8 + 4.72466784844527e+70*cos(theta)**6 - 1.86549138527715e+68*cos(theta)**4 + 2.89223470585605e+65*cos(theta)**2 - 7.34629084545607e+61)*cos(32*phi)

#@torch.jit.script
def Yl94_m33(theta, phi):
    return 7.11898779156498e-65*(1.0 - cos(theta)**2)**16.5*(2.46589363817259e+89*cos(theta)**61 - 2.41314725019029e+90*cos(theta)**59 + 1.11591755272313e+91*cos(theta)**57 - 3.24408818605851e+91*cos(theta)**55 + 6.65396540924984e+91*cos(theta)**53 - 1.0244876350778e+92*cos(theta)**51 + 1.22996396866685e+92*cos(theta)**49 - 1.18076540992017e+92*cos(theta)**47 + 9.22259687950654e+91*cos(theta)**45 - 5.93266465933169e+91*cos(theta)**43 + 3.16993857241214e+91*cos(theta)**41 - 1.41499707641696e+91*cos(theta)**39 + 5.29551936174226e+90*cos(theta)**37 - 1.66437748698459e+90*cos(theta)**35 + 4.39354305570466e+89*cos(theta)**33 - 9.7265858843273e+88*cos(theta)**31 + 1.80050256218638e+88*cos(theta)**29 - 2.77420888139534e+87*cos(theta)**27 + 3.53575641746465e+86*cos(theta)**25 - 3.6972008547905e+85*cos(theta)**23 + 3.13889871228858e+84*cos(theta)**21 - 2.13530524645482e+83*cos(theta)**19 + 1.14463071204945e+82*cos(theta)**17 - 4.73304277405669e+80*cos(theta)**15 + 1.46858596712752e+79*cos(theta)**13 - 3.29639440103443e+77*cos(theta)**11 + 5.08988467313009e+75*cos(theta)**9 - 5.02704659074577e+73*cos(theta)**7 + 2.83480070906716e+71*cos(theta)**5 - 7.46196554110862e+68*cos(theta)**3 + 5.78446941171211e+65*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl94_m34(theta, phi):
    return 8.05653588471146e-67*(1.0 - cos(theta)**2)**17*(1.50419511928528e+91*cos(theta)**60 - 1.42375687761227e+92*cos(theta)**58 + 6.36073005052185e+92*cos(theta)**56 - 1.78424850233218e+93*cos(theta)**54 + 3.52660166690241e+93*cos(theta)**52 - 5.22488693889676e+93*cos(theta)**50 + 6.02682344646754e+93*cos(theta)**48 - 5.54959742662481e+93*cos(theta)**46 + 4.15016859577794e+93*cos(theta)**44 - 2.55104580351263e+93*cos(theta)**42 + 1.29967481468898e+93*cos(theta)**40 - 5.51848859802614e+92*cos(theta)**38 + 1.95934216384464e+92*cos(theta)**36 - 5.82532120444606e+91*cos(theta)**34 + 1.44986920838254e+91*cos(theta)**32 - 3.01524162414146e+90*cos(theta)**30 + 5.22145743034051e+89*cos(theta)**28 - 7.49036397976741e+88*cos(theta)**26 + 8.83939104366162e+87*cos(theta)**24 - 8.50356196601815e+86*cos(theta)**22 + 6.59168729580601e+85*cos(theta)**20 - 4.05707996826415e+84*cos(theta)**18 + 1.94587221048406e+83*cos(theta)**16 - 7.09956416108504e+81*cos(theta)**14 + 1.90916175726578e+80*cos(theta)**12 - 3.62603384113788e+78*cos(theta)**10 + 4.58089620581708e+76*cos(theta)**8 - 3.51893261352204e+74*cos(theta)**6 + 1.41740035453358e+72*cos(theta)**4 - 2.23858966233259e+69*cos(theta)**2 + 5.78446941171211e+65)*cos(34*phi)

#@torch.jit.script
def Yl94_m35(theta, phi):
    return 9.15751978185659e-69*(1.0 - cos(theta)**2)**17.5*(9.02517071571169e+92*cos(theta)**59 - 8.25778989015118e+93*cos(theta)**57 + 3.56200882829224e+94*cos(theta)**55 - 9.63494191259376e+94*cos(theta)**53 + 1.83383286678925e+95*cos(theta)**51 - 2.61244346944838e+95*cos(theta)**49 + 2.89287525430442e+95*cos(theta)**47 - 2.55281481624741e+95*cos(theta)**45 + 1.8260741821423e+95*cos(theta)**43 - 1.0714392374753e+95*cos(theta)**41 + 5.19869925875591e+94*cos(theta)**39 - 2.09702566724993e+94*cos(theta)**37 + 7.05363178984069e+93*cos(theta)**35 - 1.98060920951166e+93*cos(theta)**33 + 4.63958146682412e+92*cos(theta)**31 - 9.04572487242439e+91*cos(theta)**29 + 1.46200808049534e+91*cos(theta)**27 - 1.94749463473953e+90*cos(theta)**25 + 2.12145385047879e+89*cos(theta)**23 - 1.87078363252399e+88*cos(theta)**21 + 1.3183374591612e+87*cos(theta)**19 - 7.30274394287547e+85*cos(theta)**17 + 3.11339553677449e+84*cos(theta)**15 - 9.93938982551906e+82*cos(theta)**13 + 2.29099410871893e+81*cos(theta)**11 - 3.62603384113788e+79*cos(theta)**9 + 3.66471696465367e+77*cos(theta)**7 - 2.11135956811322e+75*cos(theta)**5 + 5.66960141813433e+72*cos(theta)**3 - 4.47717932466517e+69*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl94_m36(theta, phi):
    return 1.04563517283457e-70*(1.0 - cos(theta)**2)**18*(5.3248507222699e+94*cos(theta)**58 - 4.70694023738617e+95*cos(theta)**56 + 1.95910485556073e+96*cos(theta)**54 - 5.10651921367469e+96*cos(theta)**52 + 9.3525476206252e+96*cos(theta)**50 - 1.28009730002971e+97*cos(theta)**48 + 1.35965136952308e+97*cos(theta)**46 - 1.14876666731133e+97*cos(theta)**44 + 7.85211898321187e+96*cos(theta)**42 - 4.39290087364875e+96*cos(theta)**40 + 2.02749271091481e+96*cos(theta)**38 - 7.75899496882476e+95*cos(theta)**36 + 2.46877112644424e+95*cos(theta)**34 - 6.53601039138848e+94*cos(theta)**32 + 1.43827025471548e+94*cos(theta)**30 - 2.62326021300307e+93*cos(theta)**28 + 3.94742181733743e+92*cos(theta)**26 - 4.86873658684882e+91*cos(theta)**24 + 4.87934385610121e+90*cos(theta)**22 - 3.92864562830038e+89*cos(theta)**20 + 2.50484117240629e+88*cos(theta)**18 - 1.24146647028883e+87*cos(theta)**16 + 4.67009330516174e+85*cos(theta)**14 - 1.29212067731748e+84*cos(theta)**12 + 2.52009351959083e+82*cos(theta)**10 - 3.26343045702409e+80*cos(theta)**8 + 2.56530187525757e+78*cos(theta)**6 - 1.05567978405661e+76*cos(theta)**4 + 1.7008804254403e+73*cos(theta)**2 - 4.47717932466517e+69)*cos(36*phi)

#@torch.jit.script
def Yl94_m37(theta, phi):
    return 1.19958365302349e-72*(1.0 - cos(theta)**2)**18.5*(3.08841341891654e+96*cos(theta)**57 - 2.63588653293626e+97*cos(theta)**55 + 1.05791662200279e+98*cos(theta)**53 - 2.65538999111084e+98*cos(theta)**51 + 4.6762738103126e+98*cos(theta)**49 - 6.14446704014259e+98*cos(theta)**47 + 6.25439629980616e+98*cos(theta)**45 - 5.05457333616987e+98*cos(theta)**43 + 3.29788997294898e+98*cos(theta)**41 - 1.7571603494595e+98*cos(theta)**39 + 7.70447230147626e+97*cos(theta)**37 - 2.79323818877691e+97*cos(theta)**35 + 8.39382182991042e+96*cos(theta)**33 - 2.09152332524431e+96*cos(theta)**31 + 4.31481076414643e+95*cos(theta)**29 - 7.34512859640861e+94*cos(theta)**27 + 1.02632967250773e+94*cos(theta)**25 - 1.16849678084372e+93*cos(theta)**23 + 1.07345564834227e+92*cos(theta)**21 - 7.85729125660077e+90*cos(theta)**19 + 4.50871411033131e+89*cos(theta)**17 - 1.98634635246213e+88*cos(theta)**15 + 6.53813062722644e+86*cos(theta)**13 - 1.55054481278097e+85*cos(theta)**11 + 2.52009351959083e+83*cos(theta)**9 - 2.61074436561927e+81*cos(theta)**7 + 1.53918112515454e+79*cos(theta)**5 - 4.22271913622645e+76*cos(theta)**3 + 3.4017608508806e+73*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl94_m38(theta, phi):
    return 1.38294893902275e-74*(1.0 - cos(theta)**2)**19*(1.76039564878243e+98*cos(theta)**56 - 1.44973759311494e+99*cos(theta)**54 + 5.60695809661481e+99*cos(theta)**52 - 1.35424889546653e+100*cos(theta)**50 + 2.29137416705317e+100*cos(theta)**48 - 2.88789950886702e+100*cos(theta)**46 + 2.81447833491277e+100*cos(theta)**44 - 2.17346653455305e+100*cos(theta)**42 + 1.35213488890908e+100*cos(theta)**40 - 6.85292536289204e+99*cos(theta)**38 + 2.85065475154622e+99*cos(theta)**36 - 9.7763336607192e+98*cos(theta)**34 + 2.76996120387044e+98*cos(theta)**32 - 6.48372230825738e+97*cos(theta)**30 + 1.25129512160247e+97*cos(theta)**28 - 1.98318472103032e+96*cos(theta)**26 + 2.56582418126933e+95*cos(theta)**24 - 2.68754259594055e+94*cos(theta)**22 + 2.25425686151876e+93*cos(theta)**20 - 1.49288533875415e+92*cos(theta)**18 + 7.66481398756323e+90*cos(theta)**16 - 2.97951952869319e+89*cos(theta)**14 + 8.49956981539437e+87*cos(theta)**12 - 1.70559929405907e+86*cos(theta)**10 + 2.26808416763174e+84*cos(theta)**8 - 1.82752105593349e+82*cos(theta)**6 + 7.6959056257727e+79*cos(theta)**4 - 1.26681574086793e+77*cos(theta)**2 + 3.4017608508806e+73)*cos(38*phi)

#@torch.jit.script
def Yl94_m39(theta, phi):
    return 1.6024567302825e-76*(1.0 - cos(theta)**2)**19.5*(9.8582156331816e+99*cos(theta)**55 - 7.82858300282068e+100*cos(theta)**53 + 2.9156182102397e+101*cos(theta)**51 - 6.77124447733264e+101*cos(theta)**49 + 1.09985960018552e+102*cos(theta)**47 - 1.32843377407883e+102*cos(theta)**45 + 1.23837046736162e+102*cos(theta)**43 - 9.12855944512279e+101*cos(theta)**41 + 5.40853955563634e+101*cos(theta)**39 - 2.60411163789898e+101*cos(theta)**37 + 1.02623571055664e+101*cos(theta)**35 - 3.32395344464453e+100*cos(theta)**33 + 8.86387585238541e+99*cos(theta)**31 - 1.94511669247721e+99*cos(theta)**29 + 3.5036263404869e+98*cos(theta)**27 - 5.15628027467884e+97*cos(theta)**25 + 6.15797803504639e+96*cos(theta)**23 - 5.91259371106921e+95*cos(theta)**21 + 4.50851372303752e+94*cos(theta)**19 - 2.68719360975746e+93*cos(theta)**17 + 1.22637023801012e+92*cos(theta)**15 - 4.17132734017047e+90*cos(theta)**13 + 1.01994837784732e+89*cos(theta)**11 - 1.70559929405907e+87*cos(theta)**9 + 1.81446733410539e+85*cos(theta)**7 - 1.09651263356009e+83*cos(theta)**5 + 3.07836225030908e+80*cos(theta)**3 - 2.53363148173587e+77*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl94_m40(theta, phi):
    return 1.86660561345564e-78*(1.0 - cos(theta)**2)**20*(5.42201859824988e+101*cos(theta)**54 - 4.14914899149496e+102*cos(theta)**52 + 1.48696528722225e+103*cos(theta)**50 - 3.317909793893e+103*cos(theta)**48 + 5.16934012087196e+103*cos(theta)**46 - 5.97795198335472e+103*cos(theta)**44 + 5.32499300965496e+103*cos(theta)**42 - 3.74270937250034e+103*cos(theta)**40 + 2.10933042669817e+103*cos(theta)**38 - 9.63521306022621e+102*cos(theta)**36 + 3.59182498694823e+102*cos(theta)**34 - 1.09690463673269e+102*cos(theta)**32 + 2.74780151423948e+101*cos(theta)**30 - 5.64083840818392e+100*cos(theta)**28 + 9.45979111931464e+99*cos(theta)**26 - 1.28907006866971e+99*cos(theta)**24 + 1.41633494806067e+98*cos(theta)**22 - 1.24164467932453e+97*cos(theta)**20 + 8.56617607377129e+95*cos(theta)**18 - 4.56822913658769e+94*cos(theta)**16 + 1.83955535701518e+93*cos(theta)**14 - 5.42272554222161e+91*cos(theta)**12 + 1.12194321563206e+90*cos(theta)**10 - 1.53503936465316e+88*cos(theta)**8 + 1.27012713387378e+86*cos(theta)**6 - 5.48256316780047e+83*cos(theta)**4 + 9.23508675092724e+80*cos(theta)**2 - 2.53363148173587e+77)*cos(40*phi)

#@torch.jit.script
def Yl94_m41(theta, phi):
    return 2.18619453028729e-80*(1.0 - cos(theta)**2)**20.5*(2.92789004305494e+103*cos(theta)**53 - 2.15755747557738e+104*cos(theta)**51 + 7.43482643611124e+104*cos(theta)**49 - 1.59259670106864e+105*cos(theta)**47 + 2.3778964556011e+105*cos(theta)**45 - 2.63029887267608e+105*cos(theta)**43 + 2.23649706405508e+105*cos(theta)**41 - 1.49708374900014e+105*cos(theta)**39 + 8.01545562145305e+104*cos(theta)**37 - 3.46867670168144e+104*cos(theta)**35 + 1.2212204955624e+104*cos(theta)**33 - 3.51009483754462e+103*cos(theta)**31 + 8.24340454271843e+102*cos(theta)**29 - 1.5794347542915e+102*cos(theta)**27 + 2.45954569102181e+101*cos(theta)**25 - 3.0937681648073e+100*cos(theta)**23 + 3.11593688573347e+99*cos(theta)**21 - 2.48328935864907e+98*cos(theta)**19 + 1.54191169327883e+97*cos(theta)**17 - 7.3091666185403e+95*cos(theta)**15 + 2.57537749982125e+94*cos(theta)**13 - 6.50727065066593e+92*cos(theta)**11 + 1.12194321563206e+91*cos(theta)**9 - 1.22803149172253e+89*cos(theta)**7 + 7.62076280324265e+86*cos(theta)**5 - 2.19302526712019e+84*cos(theta)**3 + 1.84701735018545e+81*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl94_m42(theta, phi):
    return 2.57502479009705e-82*(1.0 - cos(theta)**2)**21*(1.55178172281912e+105*cos(theta)**52 - 1.10035431254446e+106*cos(theta)**50 + 3.64306495369451e+106*cos(theta)**48 - 7.4852044950226e+106*cos(theta)**46 + 1.0700534050205e+107*cos(theta)**44 - 1.13102851525071e+107*cos(theta)**42 + 9.16963796262584e+106*cos(theta)**40 - 5.83862662110054e+106*cos(theta)**38 + 2.96571857993763e+106*cos(theta)**36 - 1.2140368455885e+106*cos(theta)**34 + 4.03002763535592e+105*cos(theta)**32 - 1.08812939963883e+105*cos(theta)**30 + 2.39058731738834e+104*cos(theta)**28 - 4.26447383658704e+103*cos(theta)**26 + 6.14886422755452e+102*cos(theta)**24 - 7.1156667790568e+101*cos(theta)**22 + 6.54346746004029e+100*cos(theta)**20 - 4.71824978143323e+99*cos(theta)**18 + 2.62124987857401e+98*cos(theta)**16 - 1.09637499278104e+97*cos(theta)**14 + 3.34799074976762e+95*cos(theta)**12 - 7.15799771573252e+93*cos(theta)**10 + 1.00974889406885e+92*cos(theta)**8 - 8.59622044205772e+89*cos(theta)**6 + 3.81038140162133e+87*cos(theta)**4 - 6.57907580136057e+84*cos(theta)**2 + 1.84701735018545e+81)*cos(42*phi)

#@torch.jit.script
def Yl94_m43(theta, phi):
    return 3.05084019079274e-84*(1.0 - cos(theta)**2)**21.5*(8.0692649586594e+106*cos(theta)**51 - 5.50177156272232e+107*cos(theta)**49 + 1.74867117777336e+108*cos(theta)**47 - 3.44319406771039e+108*cos(theta)**45 + 4.70823498209018e+108*cos(theta)**43 - 4.750319764053e+108*cos(theta)**41 + 3.66785518505034e+108*cos(theta)**39 - 2.2186781160182e+108*cos(theta)**37 + 1.06765868877755e+108*cos(theta)**35 - 4.12772527500091e+107*cos(theta)**33 + 1.28960884331389e+107*cos(theta)**31 - 3.2643881989165e+106*cos(theta)**29 + 6.69364448868736e+105*cos(theta)**27 - 1.10876319751263e+105*cos(theta)**25 + 1.47572741461308e+104*cos(theta)**23 - 1.5654466913925e+103*cos(theta)**21 + 1.30869349200806e+102*cos(theta)**19 - 8.49284960657981e+100*cos(theta)**17 + 4.19399980571842e+99*cos(theta)**15 - 1.53492498989346e+98*cos(theta)**13 + 4.01758889972114e+96*cos(theta)**11 - 7.15799771573252e+94*cos(theta)**9 + 8.07799115255081e+92*cos(theta)**7 - 5.15773226523463e+90*cos(theta)**5 + 1.52415256064853e+88*cos(theta)**3 - 1.31581516027211e+85*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl94_m44(theta, phi):
    return 3.63659408296205e-86*(1.0 - cos(theta)**2)**22*(4.11532512891629e+108*cos(theta)**50 - 2.69586806573394e+109*cos(theta)**48 + 8.21875453553481e+109*cos(theta)**46 - 1.54943733046968e+110*cos(theta)**44 + 2.02454104229878e+110*cos(theta)**42 - 1.94763110326173e+110*cos(theta)**40 + 1.43046352216963e+110*cos(theta)**38 - 8.20910902926736e+109*cos(theta)**36 + 3.73680541072141e+109*cos(theta)**34 - 1.3621493407503e+109*cos(theta)**32 + 3.99778741427307e+108*cos(theta)**30 - 9.46672577685784e+107*cos(theta)**28 + 1.80728401194559e+107*cos(theta)**26 - 2.77190799378158e+106*cos(theta)**24 + 3.39417305361009e+105*cos(theta)**22 - 3.28743805192424e+104*cos(theta)**20 + 2.48651763481531e+103*cos(theta)**18 - 1.44378443311857e+102*cos(theta)**16 + 6.29099970857764e+100*cos(theta)**14 - 1.9954024868615e+99*cos(theta)**12 + 4.41934778969326e+97*cos(theta)**10 - 6.44219794415927e+95*cos(theta)**8 + 5.65459380678556e+93*cos(theta)**6 - 2.57886613261731e+91*cos(theta)**4 + 4.57245768194559e+88*cos(theta)**2 - 1.31581516027211e+85)*cos(44*phi)

#@torch.jit.script
def Yl94_m45(theta, phi):
    return 4.36216838103599e-88*(1.0 - cos(theta)**2)**22.5*(2.05766256445815e+110*cos(theta)**49 - 1.29401667155229e+111*cos(theta)**47 + 3.78062708634601e+111*cos(theta)**45 - 6.81752425406658e+111*cos(theta)**43 + 8.50307237765487e+111*cos(theta)**41 - 7.79052441304692e+111*cos(theta)**39 + 5.4357613842446e+111*cos(theta)**37 - 2.95527925053625e+111*cos(theta)**35 + 1.27051383964528e+111*cos(theta)**33 - 4.35887789040096e+110*cos(theta)**31 + 1.19933622428192e+110*cos(theta)**29 - 2.6506832175202e+109*cos(theta)**27 + 4.69893843105853e+108*cos(theta)**25 - 6.65257918507578e+107*cos(theta)**23 + 7.46718071794221e+106*cos(theta)**21 - 6.57487610384848e+105*cos(theta)**19 + 4.47573174266756e+104*cos(theta)**17 - 2.31005509298971e+103*cos(theta)**15 + 8.80739959200869e+101*cos(theta)**13 - 2.3944829842338e+100*cos(theta)**11 + 4.41934778969326e+98*cos(theta)**9 - 5.15375835532742e+96*cos(theta)**7 + 3.39275628407134e+94*cos(theta)**5 - 1.03154645304693e+92*cos(theta)**3 + 9.14491536389119e+88*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl94_m46(theta, phi):
    return 5.26672166724968e-90*(1.0 - cos(theta)**2)**23*(1.00825465658449e+112*cos(theta)**48 - 6.08187835629576e+112*cos(theta)**46 + 1.70128218885571e+113*cos(theta)**44 - 2.93153542924863e+113*cos(theta)**42 + 3.4862596748385e+113*cos(theta)**40 - 3.0383045210883e+113*cos(theta)**38 + 2.0112317121705e+113*cos(theta)**36 - 1.03434773768769e+113*cos(theta)**34 + 4.19269567082942e+112*cos(theta)**32 - 1.3512521460243e+112*cos(theta)**30 + 3.47807505041757e+111*cos(theta)**28 - 7.15684468730453e+110*cos(theta)**26 + 1.17473460776463e+110*cos(theta)**24 - 1.53009321256743e+109*cos(theta)**22 + 1.56810795076786e+108*cos(theta)**20 - 1.24922645973121e+107*cos(theta)**18 + 7.60874396253485e+105*cos(theta)**16 - 3.46508263948456e+104*cos(theta)**14 + 1.14496194696113e+103*cos(theta)**12 - 2.63393128265718e+101*cos(theta)**10 + 3.97741301072393e+99*cos(theta)**8 - 3.60763084872919e+97*cos(theta)**6 + 1.69637814203567e+95*cos(theta)**4 - 3.09463935914078e+92*cos(theta)**2 + 9.14491536389119e+88)*cos(46*phi)

#@torch.jit.script
def Yl94_m47(theta, phi):
    return 6.40191926012626e-92*(1.0 - cos(theta)**2)**23.5*(4.83962235160556e+113*cos(theta)**47 - 2.79766404389605e+114*cos(theta)**45 + 7.48564163096511e+114*cos(theta)**43 - 1.23124488028442e+115*cos(theta)**41 + 1.3945038699354e+115*cos(theta)**39 - 1.15455571801355e+115*cos(theta)**37 + 7.24043416381381e+114*cos(theta)**35 - 3.51678230813813e+114*cos(theta)**33 + 1.34166261466542e+114*cos(theta)**31 - 4.05375643807289e+113*cos(theta)**29 + 9.7386101411692e+112*cos(theta)**27 - 1.86077961869918e+112*cos(theta)**25 + 2.81936305863512e+111*cos(theta)**23 - 3.36620506764835e+110*cos(theta)**21 + 3.13621590153573e+109*cos(theta)**19 - 2.24860762751618e+108*cos(theta)**17 + 1.21739903400558e+107*cos(theta)**15 - 4.85111569527839e+105*cos(theta)**13 + 1.37395433635336e+104*cos(theta)**11 - 2.63393128265718e+102*cos(theta)**9 + 3.18193040857915e+100*cos(theta)**7 - 2.16457850923751e+98*cos(theta)**5 + 6.78551256814268e+95*cos(theta)**3 - 6.18927871828155e+92*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl94_m48(theta, phi):
    return 7.83640894059076e-94*(1.0 - cos(theta)**2)**24*(2.27462250525461e+115*cos(theta)**46 - 1.25894881975322e+116*cos(theta)**44 + 3.218825901315e+116*cos(theta)**42 - 5.04810400916614e+116*cos(theta)**40 + 5.43856509274805e+116*cos(theta)**38 - 4.27185615665015e+116*cos(theta)**36 + 2.53415195733483e+116*cos(theta)**34 - 1.16053816168558e+116*cos(theta)**32 + 4.15915410546279e+115*cos(theta)**30 - 1.17558936704114e+115*cos(theta)**28 + 2.62942473811568e+114*cos(theta)**26 - 4.65194904674794e+113*cos(theta)**24 + 6.48453503486077e+112*cos(theta)**22 - 7.06903064206153e+111*cos(theta)**20 + 5.95881021291788e+110*cos(theta)**18 - 3.82263296677751e+109*cos(theta)**16 + 1.82609855100836e+108*cos(theta)**14 - 6.3064504038619e+106*cos(theta)**12 + 1.51134976998869e+105*cos(theta)**10 - 2.37053815439146e+103*cos(theta)**8 + 2.2273512860054e+101*cos(theta)**6 - 1.08228925461876e+99*cos(theta)**4 + 2.0356537704428e+96*cos(theta)**2 - 6.18927871828155e+92)*cos(48*phi)

#@torch.jit.script
def Yl94_m49(theta, phi):
    return 9.66206949532334e-96*(1.0 - cos(theta)**2)**24.5*(1.04632635241712e+117*cos(theta)**45 - 5.53937480691418e+117*cos(theta)**43 + 1.3519068785523e+118*cos(theta)**41 - 2.01924160366646e+118*cos(theta)**39 + 2.06665473524426e+118*cos(theta)**37 - 1.53786821639405e+118*cos(theta)**35 + 8.61611665493843e+117*cos(theta)**33 - 3.71372211739387e+117*cos(theta)**31 + 1.24774623163884e+117*cos(theta)**29 - 3.29165022771519e+116*cos(theta)**27 + 6.83650431910078e+115*cos(theta)**25 - 1.11646777121951e+115*cos(theta)**23 + 1.42659770766937e+114*cos(theta)**21 - 1.41380612841231e+113*cos(theta)**19 + 1.07258583832522e+112*cos(theta)**17 - 6.11621274684401e+110*cos(theta)**15 + 2.55653797141171e+109*cos(theta)**13 - 7.56774048463428e+107*cos(theta)**11 + 1.51134976998869e+106*cos(theta)**9 - 1.89643052351317e+104*cos(theta)**7 + 1.33641077160324e+102*cos(theta)**5 - 4.32915701847503e+99*cos(theta)**3 + 4.07130754088561e+96*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl94_m50(theta, phi):
    return 1.20028023304834e-97*(1.0 - cos(theta)**2)**25*(4.70846858587705e+118*cos(theta)**44 - 2.3819311669731e+119*cos(theta)**42 + 5.54281820206442e+119*cos(theta)**40 - 7.87504225429918e+119*cos(theta)**38 + 7.64662252040376e+119*cos(theta)**36 - 5.38253875737918e+119*cos(theta)**34 + 2.84331849612968e+119*cos(theta)**32 - 1.1512538563921e+119*cos(theta)**30 + 3.61846407175263e+118*cos(theta)**28 - 8.88745561483101e+117*cos(theta)**26 + 1.70912607977519e+117*cos(theta)**24 - 2.56787587380486e+116*cos(theta)**22 + 2.99585518610568e+115*cos(theta)**20 - 2.68623164398338e+114*cos(theta)**18 + 1.82339592515287e+113*cos(theta)**16 - 9.17431912026602e+111*cos(theta)**14 + 3.32349936283522e+110*cos(theta)**12 - 8.32451453309771e+108*cos(theta)**10 + 1.36021479298982e+107*cos(theta)**8 - 1.32750136645922e+105*cos(theta)**6 + 6.68205385801621e+102*cos(theta)**4 - 1.29874710554251e+100*cos(theta)**2 + 4.07130754088561e+96)*cos(50*phi)

#@torch.jit.script
def Yl94_m51(theta, phi):
    return 1.50270009743515e-99*(1.0 - cos(theta)**2)**25.5*(2.0717261777859e+120*cos(theta)**43 - 1.0004110901287e+121*cos(theta)**41 + 2.21712728082577e+121*cos(theta)**39 - 2.99251605663369e+121*cos(theta)**37 + 2.75278410734535e+121*cos(theta)**35 - 1.83006317750892e+121*cos(theta)**33 + 9.09861918761498e+120*cos(theta)**31 - 3.4537615691763e+120*cos(theta)**29 + 1.01316994009074e+120*cos(theta)**27 - 2.31073845985606e+119*cos(theta)**25 + 4.10190259146047e+118*cos(theta)**23 - 5.6493269223707e+117*cos(theta)**21 + 5.99171037221135e+116*cos(theta)**19 - 4.83521695917009e+115*cos(theta)**17 + 2.91743348024459e+114*cos(theta)**15 - 1.28440467683724e+113*cos(theta)**13 + 3.98819923540227e+111*cos(theta)**11 - 8.32451453309771e+109*cos(theta)**9 + 1.08817183439186e+108*cos(theta)**7 - 7.96500819875532e+105*cos(theta)**5 + 2.67282154320648e+103*cos(theta)**3 - 2.59749421108502e+100*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl94_m52(theta, phi):
    return 1.89653848043213e-101*(1.0 - cos(theta)**2)**26*(8.90842256447938e+121*cos(theta)**42 - 4.10168546952767e+122*cos(theta)**40 + 8.6467963952205e+122*cos(theta)**38 - 1.10723094095446e+123*cos(theta)**36 + 9.63474437570874e+122*cos(theta)**34 - 6.03920848577944e+122*cos(theta)**32 + 2.82057194816064e+122*cos(theta)**30 - 1.00159085506113e+122*cos(theta)**28 + 2.73555883824499e+121*cos(theta)**26 - 5.77684614964016e+120*cos(theta)**24 + 9.43437596035907e+119*cos(theta)**22 - 1.18635865369785e+119*cos(theta)**20 + 1.13842497072016e+118*cos(theta)**18 - 8.21986883058915e+116*cos(theta)**16 + 4.37615022036689e+115*cos(theta)**14 - 1.66972607988842e+114*cos(theta)**12 + 4.38701915894249e+112*cos(theta)**10 - 7.49206307978794e+110*cos(theta)**8 + 7.617202840743e+108*cos(theta)**6 - 3.98250409937766e+106*cos(theta)**4 + 8.01846462961945e+103*cos(theta)**2 - 2.59749421108502e+100)*cos(52*phi)

#@torch.jit.script
def Yl94_m53(theta, phi):
    return 2.41367252197616e-103*(1.0 - cos(theta)**2)**26.5*(3.74153747708134e+123*cos(theta)**41 - 1.64067418781107e+124*cos(theta)**39 + 3.28578263018379e+124*cos(theta)**37 - 3.98603138743607e+124*cos(theta)**35 + 3.27581308774097e+124*cos(theta)**33 - 1.93254671544942e+124*cos(theta)**31 + 8.46171584448193e+123*cos(theta)**29 - 2.80445439417116e+123*cos(theta)**27 + 7.11245297943696e+122*cos(theta)**25 - 1.38644307591364e+122*cos(theta)**23 + 2.075562711279e+121*cos(theta)**21 - 2.37271730739569e+120*cos(theta)**19 + 2.04916494729628e+119*cos(theta)**17 - 1.31517901289426e+118*cos(theta)**15 + 6.12661030851365e+116*cos(theta)**13 - 2.0036712958661e+115*cos(theta)**11 + 4.38701915894249e+113*cos(theta)**9 - 5.99365046383035e+111*cos(theta)**7 + 4.5703217044458e+109*cos(theta)**5 - 1.59300163975106e+107*cos(theta)**3 + 1.60369292592389e+104*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl94_m54(theta, phi):
    return 3.09852896481309e-105*(1.0 - cos(theta)**2)**27*(1.53403036560335e+125*cos(theta)**40 - 6.39862933246317e+125*cos(theta)**38 + 1.215739573168e+126*cos(theta)**36 - 1.39511098560263e+126*cos(theta)**34 + 1.08101831895452e+126*cos(theta)**32 - 5.99089481789321e+125*cos(theta)**30 + 2.45389759489976e+125*cos(theta)**28 - 7.57202686426212e+124*cos(theta)**26 + 1.77811324485924e+124*cos(theta)**24 - 3.18881907460137e+123*cos(theta)**22 + 4.35868169368589e+122*cos(theta)**20 - 4.50816288405182e+121*cos(theta)**18 + 3.48358041040368e+120*cos(theta)**16 - 1.97276851934139e+119*cos(theta)**14 + 7.96459340106774e+117*cos(theta)**12 - 2.20403842545271e+116*cos(theta)**10 + 3.94831724304824e+114*cos(theta)**8 - 4.19555532468125e+112*cos(theta)**6 + 2.2851608522229e+110*cos(theta)**4 - 4.77900491925319e+107*cos(theta)**2 + 1.60369292592389e+104)*cos(54*phi)

#@torch.jit.script
def Yl94_m55(theta, phi):
    return 4.01358468075277e-107*(1.0 - cos(theta)**2)**27.5*(6.1361214624134e+126*cos(theta)**39 - 2.431479146336e+127*cos(theta)**37 + 4.37666246340481e+127*cos(theta)**35 - 4.74337735104893e+127*cos(theta)**33 + 3.45925862065447e+127*cos(theta)**31 - 1.79726844536796e+127*cos(theta)**29 + 6.87091326571933e+126*cos(theta)**27 - 1.96872698470815e+126*cos(theta)**25 + 4.26747178766218e+125*cos(theta)**23 - 7.01540196412301e+124*cos(theta)**21 + 8.71736338737178e+123*cos(theta)**19 - 8.11469319129328e+122*cos(theta)**17 + 5.57372865664589e+121*cos(theta)**15 - 2.76187592707795e+120*cos(theta)**13 + 9.55751208128129e+118*cos(theta)**11 - 2.20403842545271e+117*cos(theta)**9 + 3.1586537944386e+115*cos(theta)**7 - 2.51733319480875e+113*cos(theta)**5 + 9.1406434088916e+110*cos(theta)**3 - 9.55800983850638e+107*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl94_m56(theta, phi):
    return 5.24752477092704e-109*(1.0 - cos(theta)**2)**28*(2.39308737034123e+128*cos(theta)**38 - 8.99647284144322e+128*cos(theta)**36 + 1.53183186219168e+129*cos(theta)**34 - 1.56531452584615e+129*cos(theta)**32 + 1.07237017240288e+129*cos(theta)**30 - 5.21207849156709e+128*cos(theta)**28 + 1.85514658174422e+128*cos(theta)**26 - 4.92181746177038e+127*cos(theta)**24 + 9.81518511162301e+126*cos(theta)**22 - 1.47323441246583e+126*cos(theta)**20 + 1.65629904360064e+125*cos(theta)**18 - 1.37949784251986e+124*cos(theta)**16 + 8.36059298496883e+122*cos(theta)**14 - 3.59043870520134e+121*cos(theta)**12 + 1.05132632894094e+120*cos(theta)**10 - 1.98363458290744e+118*cos(theta)**8 + 2.21105765610702e+116*cos(theta)**6 - 1.25866659740437e+114*cos(theta)**4 + 2.74219302266748e+111*cos(theta)**2 - 9.55800983850638e+107)*cos(56*phi)

#@torch.jit.script
def Yl94_m57(theta, phi):
    return 6.92746316785253e-111*(1.0 - cos(theta)**2)**28.5*(9.09373200729666e+129*cos(theta)**37 - 3.23873022291956e+130*cos(theta)**35 + 5.20822833145172e+130*cos(theta)**33 - 5.00900648270767e+130*cos(theta)**31 + 3.21711051720865e+130*cos(theta)**29 - 1.45938197763879e+130*cos(theta)**27 + 4.82338111253497e+129*cos(theta)**25 - 1.18123619082489e+129*cos(theta)**23 + 2.15934072455706e+128*cos(theta)**21 - 2.94646882493166e+127*cos(theta)**19 + 2.98133827848115e+126*cos(theta)**17 - 2.20719654803177e+125*cos(theta)**15 + 1.17048301789564e+124*cos(theta)**13 - 4.30852644624161e+122*cos(theta)**11 + 1.05132632894094e+121*cos(theta)**9 - 1.58690766632595e+119*cos(theta)**7 + 1.32663459366421e+117*cos(theta)**5 - 5.0346663896175e+114*cos(theta)**3 + 5.48438604533496e+111*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl94_m58(theta, phi):
    return 9.23743869929569e-113*(1.0 - cos(theta)**2)**29*(3.36468084269976e+131*cos(theta)**36 - 1.13355557802185e+132*cos(theta)**34 + 1.71871534937907e+132*cos(theta)**32 - 1.55279200963938e+132*cos(theta)**30 + 9.32962049990509e+131*cos(theta)**28 - 3.94033133962472e+131*cos(theta)**26 + 1.20584527813374e+131*cos(theta)**24 - 2.71684323889725e+130*cos(theta)**22 + 4.53461552156983e+129*cos(theta)**20 - 5.59829076737016e+128*cos(theta)**18 + 5.06827507341796e+127*cos(theta)**16 - 3.31079482204766e+126*cos(theta)**14 + 1.52162792326433e+125*cos(theta)**12 - 4.73937909086577e+123*cos(theta)**10 + 9.46193696046848e+121*cos(theta)**8 - 1.11083536642817e+120*cos(theta)**6 + 6.63317296832105e+117*cos(theta)**4 - 1.51039991688525e+115*cos(theta)**2 + 5.48438604533496e+111)*cos(58*phi)

#@torch.jit.script
def Yl94_m59(theta, phi):
    return 1.24467109370472e-114*(1.0 - cos(theta)**2)**29.5*(1.21128510337191e+133*cos(theta)**35 - 3.85408896527427e+133*cos(theta)**33 + 5.49988911801302e+133*cos(theta)**31 - 4.65837602891813e+133*cos(theta)**29 + 2.61229373997343e+133*cos(theta)**27 - 1.02448614830243e+133*cos(theta)**25 + 2.89402866752098e+132*cos(theta)**23 - 5.97705512557395e+131*cos(theta)**21 + 9.06923104313966e+130*cos(theta)**19 - 1.00769233812663e+130*cos(theta)**17 + 8.10924011746873e+128*cos(theta)**15 - 4.63511275086672e+127*cos(theta)**13 + 1.82595350791719e+126*cos(theta)**11 - 4.73937909086577e+124*cos(theta)**9 + 7.56954956837478e+122*cos(theta)**7 - 6.66501219856899e+120*cos(theta)**5 + 2.65326918732842e+118*cos(theta)**3 - 3.0207998337705e+115*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl94_m60(theta, phi):
    return 1.6953533196612e-116*(1.0 - cos(theta)**2)**30*(4.2394978618017e+134*cos(theta)**34 - 1.27184935854051e+135*cos(theta)**32 + 1.70496562658404e+135*cos(theta)**30 - 1.35092904838626e+135*cos(theta)**28 + 7.05319309792825e+134*cos(theta)**26 - 2.56121537075607e+134*cos(theta)**24 + 6.65626593529826e+133*cos(theta)**22 - 1.25518157637053e+133*cos(theta)**20 + 1.72315389819654e+132*cos(theta)**18 - 1.71307697481527e+131*cos(theta)**16 + 1.21638601762031e+130*cos(theta)**14 - 6.02564657612674e+128*cos(theta)**12 + 2.00854885870891e+127*cos(theta)**10 - 4.26544118177919e+125*cos(theta)**8 + 5.29868469786235e+123*cos(theta)**6 - 3.3325060992845e+121*cos(theta)**4 + 7.95980756198526e+118*cos(theta)**2 - 3.0207998337705e+115)*cos(60*phi)

#@torch.jit.script
def Yl94_m61(theta, phi):
    return 2.33536578628732e-118*(1.0 - cos(theta)**2)**30.5*(1.44142927301258e+136*cos(theta)**33 - 4.06991794732963e+136*cos(theta)**31 + 5.11489687975211e+136*cos(theta)**29 - 3.78260133548152e+136*cos(theta)**27 + 1.83383020546135e+136*cos(theta)**25 - 6.14691688981457e+135*cos(theta)**23 + 1.46437850576562e+135*cos(theta)**21 - 2.51036315274106e+134*cos(theta)**19 + 3.10167701675376e+133*cos(theta)**17 - 2.74092315970443e+132*cos(theta)**15 + 1.70294042466843e+131*cos(theta)**13 - 7.23077589135208e+129*cos(theta)**11 + 2.00854885870891e+128*cos(theta)**9 - 3.41235294542335e+126*cos(theta)**7 + 3.17921081871741e+124*cos(theta)**5 - 1.3330024397138e+122*cos(theta)**3 + 1.59196151239705e+119*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl94_m62(theta, phi):
    return 3.25488496537784e-120*(1.0 - cos(theta)**2)**31*(4.75671660094151e+137*cos(theta)**32 - 1.26167456367219e+138*cos(theta)**30 + 1.48332009512811e+138*cos(theta)**28 - 1.02130236058001e+138*cos(theta)**26 + 4.58457551365336e+137*cos(theta)**24 - 1.41379088465735e+137*cos(theta)**22 + 3.0751948621078e+136*cos(theta)**20 - 4.76968999020801e+135*cos(theta)**18 + 5.2728509284814e+134*cos(theta)**16 - 4.11138473955665e+133*cos(theta)**14 + 2.21382255206896e+132*cos(theta)**12 - 7.95385348048729e+130*cos(theta)**10 + 1.80769397283802e+129*cos(theta)**8 - 2.38864706179635e+127*cos(theta)**6 + 1.5896054093587e+125*cos(theta)**4 - 3.99900731914139e+122*cos(theta)**2 + 1.59196151239705e+119)*cos(62*phi)

#@torch.jit.script
def Yl94_m63(theta, phi):
    return 4.59209462848014e-122*(1.0 - cos(theta)**2)**31.5*(1.52214931230128e+139*cos(theta)**31 - 3.78502369101656e+139*cos(theta)**29 + 4.15329626635871e+139*cos(theta)**27 - 2.65538613750803e+139*cos(theta)**25 + 1.10029812327681e+139*cos(theta)**23 - 3.11033994624617e+138*cos(theta)**21 + 6.15038972421559e+137*cos(theta)**19 - 8.58544198237442e+136*cos(theta)**17 + 8.43656148557024e+135*cos(theta)**15 - 5.7559386353793e+134*cos(theta)**13 + 2.65658706248276e+133*cos(theta)**11 - 7.95385348048729e+131*cos(theta)**9 + 1.44615517827042e+130*cos(theta)**7 - 1.43318823707781e+128*cos(theta)**5 + 6.35842163743482e+125*cos(theta)**3 - 7.99801463828279e+122*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl94_m64(theta, phi):
    return 6.56147439661888e-124*(1.0 - cos(theta)**2)**32*(4.71866286813398e+140*cos(theta)**30 - 1.0976568703948e+141*cos(theta)**28 + 1.12138999191685e+141*cos(theta)**26 - 6.63846534377007e+140*cos(theta)**24 + 2.53068568353666e+140*cos(theta)**22 - 6.53171388711696e+139*cos(theta)**20 + 1.16857404760096e+139*cos(theta)**18 - 1.45952513700365e+138*cos(theta)**16 + 1.26548422283554e+137*cos(theta)**14 - 7.48272022599309e+135*cos(theta)**12 + 2.92224576873103e+134*cos(theta)**10 - 7.15846813243856e+132*cos(theta)**8 + 1.01230862478929e+131*cos(theta)**6 - 7.16594118538904e+128*cos(theta)**4 + 1.90752649123045e+126*cos(theta)**2 - 7.99801463828279e+122)*cos(64*phi)

#@torch.jit.script
def Yl94_m65(theta, phi):
    return 9.50040783163933e-126*(1.0 - cos(theta)**2)**32.5*(1.41559886044019e+142*cos(theta)**29 - 3.07343923710545e+142*cos(theta)**27 + 2.91561397898381e+142*cos(theta)**25 - 1.59323168250482e+142*cos(theta)**23 + 5.56750850378064e+141*cos(theta)**21 - 1.30634277742339e+141*cos(theta)**19 + 2.10343328568173e+140*cos(theta)**17 - 2.33524021920584e+139*cos(theta)**15 + 1.77167791196975e+138*cos(theta)**13 - 8.97926427119171e+136*cos(theta)**11 + 2.92224576873103e+135*cos(theta)**9 - 5.72677450595085e+133*cos(theta)**7 + 6.07385174873575e+131*cos(theta)**5 - 2.86637647415562e+129*cos(theta)**3 + 3.81505298246089e+126*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl94_m66(theta, phi):
    return 1.39470789309361e-127*(1.0 - cos(theta)**2)**33*(4.10523669527656e+143*cos(theta)**28 - 8.2982859401847e+143*cos(theta)**26 + 7.28903494745954e+143*cos(theta)**24 - 3.66443286976108e+143*cos(theta)**22 + 1.16917678579394e+143*cos(theta)**20 - 2.48205127710444e+142*cos(theta)**18 + 3.57583658565894e+141*cos(theta)**16 - 3.50286032880876e+140*cos(theta)**14 + 2.30318128556067e+139*cos(theta)**12 - 9.87719069831088e+137*cos(theta)**10 + 2.63002119185793e+136*cos(theta)**8 - 4.00874215416559e+134*cos(theta)**6 + 3.03692587436787e+132*cos(theta)**4 - 8.59912942246685e+129*cos(theta)**2 + 3.81505298246089e+126)*cos(66*phi)

#@torch.jit.script
def Yl94_m67(theta, phi):
    return 2.07726213649423e-129*(1.0 - cos(theta)**2)**33.5*(1.14946627467744e+145*cos(theta)**27 - 2.15755434444802e+145*cos(theta)**25 + 1.74936838739029e+145*cos(theta)**23 - 8.06175231347437e+144*cos(theta)**21 + 2.33835357158787e+144*cos(theta)**19 - 4.467692298788e+143*cos(theta)**17 + 5.72133853705431e+142*cos(theta)**15 - 4.90400446033227e+141*cos(theta)**13 + 2.76381754267281e+140*cos(theta)**11 - 9.87719069831088e+138*cos(theta)**9 + 2.10401695348634e+137*cos(theta)**7 - 2.40524529249936e+135*cos(theta)**5 + 1.21477034974715e+133*cos(theta)**3 - 1.71982588449337e+130*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl94_m68(theta, phi):
    return 3.14088413358919e-131*(1.0 - cos(theta)**2)**34*(3.10355894162908e+146*cos(theta)**26 - 5.39388586112006e+146*cos(theta)**24 + 4.02354729099766e+146*cos(theta)**22 - 1.69296798582962e+146*cos(theta)**20 + 4.44287178601695e+145*cos(theta)**18 - 7.5950769079396e+144*cos(theta)**16 + 8.58200780558147e+143*cos(theta)**14 - 6.37520579843195e+142*cos(theta)**12 + 3.04019929694009e+141*cos(theta)**10 - 8.8894716284798e+139*cos(theta)**8 + 1.47281186744044e+138*cos(theta)**6 - 1.20262264624968e+136*cos(theta)**4 + 3.64431104924145e+133*cos(theta)**2 - 1.71982588449337e+130)*cos(68*phi)

#@torch.jit.script
def Yl94_m69(theta, phi):
    return 4.82471250262325e-133*(1.0 - cos(theta)**2)**34.5*(8.06925324823561e+147*cos(theta)**25 - 1.29453260666881e+148*cos(theta)**23 + 8.85180404019486e+147*cos(theta)**21 - 3.38593597165924e+147*cos(theta)**19 + 7.99716921483052e+146*cos(theta)**17 - 1.21521230527034e+146*cos(theta)**15 + 1.20148109278141e+145*cos(theta)**13 - 7.65024695811834e+143*cos(theta)**11 + 3.04019929694009e+142*cos(theta)**9 - 7.11157730278384e+140*cos(theta)**7 + 8.83687120464264e+138*cos(theta)**5 - 4.81049058499871e+136*cos(theta)**3 + 7.2886220984829e+133*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl94_m70(theta, phi):
    return 7.53493501565664e-135*(1.0 - cos(theta)**2)**35*(2.0173133120589e+149*cos(theta)**24 - 2.97742499533827e+149*cos(theta)**22 + 1.85887884844092e+149*cos(theta)**20 - 6.43327834615255e+148*cos(theta)**18 + 1.35951876652119e+148*cos(theta)**16 - 1.8228184579055e+147*cos(theta)**14 + 1.56192542061583e+146*cos(theta)**12 - 8.41527165393017e+144*cos(theta)**10 + 2.73617936724608e+143*cos(theta)**8 - 4.97810411194869e+141*cos(theta)**6 + 4.41843560232132e+139*cos(theta)**4 - 1.44314717549961e+137*cos(theta)**2 + 7.2886220984829e+133)*cos(70*phi)

#@torch.jit.script
def Yl94_m71(theta, phi):
    return 1.19737977497088e-136*(1.0 - cos(theta)**2)**35.5*(4.84155194894136e+150*cos(theta)**23 - 6.5503349897442e+150*cos(theta)**21 + 3.71775769688184e+150*cos(theta)**19 - 1.15799010230746e+150*cos(theta)**17 + 2.1752300264339e+149*cos(theta)**15 - 2.5519458410677e+148*cos(theta)**13 + 1.87431050473899e+147*cos(theta)**11 - 8.41527165393017e+145*cos(theta)**9 + 2.18894349379686e+144*cos(theta)**7 - 2.98686246716921e+142*cos(theta)**5 + 1.76737424092853e+140*cos(theta)**3 - 2.88629435099923e+137*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl94_m72(theta, phi):
    return 1.93782233028034e-138*(1.0 - cos(theta)**2)**36*(1.11355694825651e+152*cos(theta)**22 - 1.37557034784628e+152*cos(theta)**20 + 7.0637396240755e+151*cos(theta)**18 - 1.96858317392268e+151*cos(theta)**16 + 3.26284503965085e+150*cos(theta)**14 - 3.31752959338802e+149*cos(theta)**12 + 2.06174155521289e+148*cos(theta)**10 - 7.57374448853715e+146*cos(theta)**8 + 1.53226044565781e+145*cos(theta)**6 - 1.49343123358461e+143*cos(theta)**4 + 5.30212272278558e+140*cos(theta)**2 - 2.88629435099923e+137)*cos(72*phi)

#@torch.jit.script
def Yl94_m73(theta, phi):
    return 3.19701283740957e-140*(1.0 - cos(theta)**2)**36.5*(2.44982528616433e+153*cos(theta)**21 - 2.75114069569256e+153*cos(theta)**19 + 1.27147313233359e+153*cos(theta)**17 - 3.14973307827629e+152*cos(theta)**15 + 4.56798305551119e+151*cos(theta)**13 - 3.98103551206562e+150*cos(theta)**11 + 2.06174155521289e+149*cos(theta)**9 - 6.05899559082972e+147*cos(theta)**7 + 9.19356267394683e+145*cos(theta)**5 - 5.97372493433842e+143*cos(theta)**3 + 1.06042454455712e+141*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl94_m74(theta, phi):
    return 5.38245108779227e-142*(1.0 - cos(theta)**2)**37*(5.14463310094509e+154*cos(theta)**20 - 5.22716732181587e+154*cos(theta)**18 + 2.1615043249671e+154*cos(theta)**16 - 4.72459961741443e+153*cos(theta)**14 + 5.93837797216455e+152*cos(theta)**12 - 4.37913906327218e+151*cos(theta)**10 + 1.8555673996916e+150*cos(theta)**8 - 4.24129691358081e+148*cos(theta)**6 + 4.59678133697342e+146*cos(theta)**4 - 1.79211748030153e+144*cos(theta)**2 + 1.06042454455712e+141)*cos(74*phi)

#@torch.jit.script
def Yl94_m75(theta, phi):
    return 9.25809732143938e-144*(1.0 - cos(theta)**2)**37.5*(1.02892662018902e+156*cos(theta)**19 - 9.40890117926856e+155*cos(theta)**17 + 3.45840691994736e+155*cos(theta)**15 - 6.61443946438021e+154*cos(theta)**13 + 7.12605356659746e+153*cos(theta)**11 - 4.37913906327218e+152*cos(theta)**9 + 1.48445391975328e+151*cos(theta)**7 - 2.54477814814848e+149*cos(theta)**5 + 1.83871253478937e+147*cos(theta)**3 - 3.58423496060305e+144*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl94_m76(theta, phi):
    return 1.6289977356341e-145*(1.0 - cos(theta)**2)**38*(1.95496057835914e+157*cos(theta)**18 - 1.59951320047566e+157*cos(theta)**16 + 5.18761037992105e+156*cos(theta)**14 - 8.59877130369427e+155*cos(theta)**12 + 7.8386589232572e+154*cos(theta)**10 - 3.94122515694496e+153*cos(theta)**8 + 1.0391177438273e+152*cos(theta)**6 - 1.27238907407424e+150*cos(theta)**4 + 5.5161376043681e+147*cos(theta)**2 - 3.58423496060305e+144)*cos(76*phi)

#@torch.jit.script
def Yl94_m77(theta, phi):
    return 2.93620364103731e-147*(1.0 - cos(theta)**2)**38.5*(3.51892904104644e+158*cos(theta)**17 - 2.55922112076105e+158*cos(theta)**15 + 7.26265453188947e+157*cos(theta)**13 - 1.03185255644331e+157*cos(theta)**11 + 7.8386589232572e+155*cos(theta)**9 - 3.15298012555597e+154*cos(theta)**7 + 6.23470646296378e+152*cos(theta)**5 - 5.08955629629697e+150*cos(theta)**3 + 1.10322752087362e+148*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl94_m78(theta, phi):
    return 5.42997073227417e-149*(1.0 - cos(theta)**2)**39*(5.98217936977895e+159*cos(theta)**16 - 3.83883168114157e+159*cos(theta)**14 + 9.4414508914563e+158*cos(theta)**12 - 1.13503781208764e+158*cos(theta)**10 + 7.05479303093148e+156*cos(theta)**8 - 2.20708608788918e+155*cos(theta)**6 + 3.11735323148189e+153*cos(theta)**4 - 1.52686688888909e+151*cos(theta)**2 + 1.10322752087362e+148)*cos(78*phi)

#@torch.jit.script
def Yl94_m79(theta, phi):
    return 1.03208257516365e-150*(1.0 - cos(theta)**2)**39.5*(9.57148699164633e+160*cos(theta)**15 - 5.3743643535982e+160*cos(theta)**13 + 1.13297410697476e+160*cos(theta)**11 - 1.13503781208764e+159*cos(theta)**9 + 5.64383442474519e+157*cos(theta)**7 - 1.32425165273351e+156*cos(theta)**5 + 1.24694129259276e+154*cos(theta)**3 - 3.05373377777818e+151*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl94_m80(theta, phi):
    return 2.02019918781633e-152*(1.0 - cos(theta)**2)**40*(1.43572304874695e+162*cos(theta)**14 - 6.98667365967767e+161*cos(theta)**12 + 1.24627151767223e+161*cos(theta)**10 - 1.02153403087888e+160*cos(theta)**8 + 3.95068409732163e+158*cos(theta)**6 - 6.62125826366754e+156*cos(theta)**4 + 3.74082387777827e+154*cos(theta)**2 - 3.05373377777818e+151)*cos(80*phi)

#@torch.jit.script
def Yl94_m81(theta, phi):
    return 4.08141870014996e-154*(1.0 - cos(theta)**2)**40.5*(2.01001226824573e+163*cos(theta)**13 - 8.3840083916132e+162*cos(theta)**11 + 1.24627151767223e+162*cos(theta)**9 - 8.17227224703103e+160*cos(theta)**7 + 2.37041045839298e+159*cos(theta)**5 - 2.64850330546702e+157*cos(theta)**3 + 7.48164775555654e+154*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl94_m82(theta, phi):
    return 8.53263444373482e-156*(1.0 - cos(theta)**2)**41*(2.61301594871945e+164*cos(theta)**12 - 9.22240923077452e+163*cos(theta)**10 + 1.12164436590501e+163*cos(theta)**8 - 5.72059057292172e+161*cos(theta)**6 + 1.18520522919649e+160*cos(theta)**4 - 7.94550991640105e+157*cos(theta)**2 + 7.48164775555654e+154)*cos(82*phi)

#@torch.jit.script
def Yl94_m83(theta, phi):
    return 1.85142397671217e-157*(1.0 - cos(theta)**2)**41.5*(3.13561913846334e+165*cos(theta)**11 - 9.22240923077452e+164*cos(theta)**9 + 8.97315492724007e+163*cos(theta)**7 - 3.43235434375303e+162*cos(theta)**5 + 4.74082091678596e+160*cos(theta)**3 - 1.58910198328021e+158*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl94_m84(theta, phi):
    return 4.18407576385452e-159*(1.0 - cos(theta)**2)**42*(3.44918105230967e+166*cos(theta)**10 - 8.30016830769707e+165*cos(theta)**8 + 6.28120844906805e+164*cos(theta)**6 - 1.71617717187652e+163*cos(theta)**4 + 1.42224627503579e+161*cos(theta)**2 - 1.58910198328021e+158)*cos(84*phi)

#@torch.jit.script
def Yl94_m85(theta, phi):
    return 9.8894701626903e-161*(1.0 - cos(theta)**2)**42.5*(3.44918105230967e+167*cos(theta)**9 - 6.64013464615765e+166*cos(theta)**7 + 3.76872506944083e+165*cos(theta)**5 - 6.86470868750607e+163*cos(theta)**3 + 2.84449255007157e+161*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl94_m86(theta, phi):
    return 2.45705861613682e-162*(1.0 - cos(theta)**2)**43*(3.1042629470787e+168*cos(theta)**8 - 4.64809425231036e+167*cos(theta)**6 + 1.88436253472042e+166*cos(theta)**4 - 2.05941260625182e+164*cos(theta)**2 + 2.84449255007157e+161)*cos(86*phi)

#@torch.jit.script
def Yl94_m87(theta, phi):
    return 6.4570066889192e-164*(1.0 - cos(theta)**2)**43.5*(2.48341035766296e+169*cos(theta)**7 - 2.78885655138621e+168*cos(theta)**5 + 7.53745013888166e+166*cos(theta)**3 - 4.11882521250364e+164*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl94_m88(theta, phi):
    return 1.80903313770319e-165*(1.0 - cos(theta)**2)**44*(1.73838725036407e+170*cos(theta)**6 - 1.39442827569311e+169*cos(theta)**4 + 2.2612350416645e+167*cos(theta)**2 - 4.11882521250364e+164)*cos(88*phi)

#@torch.jit.script
def Yl94_m89(theta, phi):
    return 5.45940549125323e-167*(1.0 - cos(theta)**2)**44.5*(1.04303235021844e+171*cos(theta)**5 - 5.57771310277243e+169*cos(theta)**3 + 4.522470083329e+167*cos(theta))*cos(89*phi)

#@torch.jit.script
def Yl94_m90(theta, phi):
    return 1.79991268864106e-168*(1.0 - cos(theta)**2)**45*(5.21516175109222e+171*cos(theta)**4 - 1.67331393083173e+170*cos(theta)**2 + 4.522470083329e+167)*cos(90*phi)

#@torch.jit.script
def Yl94_m91(theta, phi):
    return 6.61661063590542e-170*(1.0 - cos(theta)**2)**45.5*(2.08606470043689e+172*cos(theta)**3 - 3.34662786166346e+170*cos(theta))*cos(91*phi)

#@torch.jit.script
def Yl94_m92(theta, phi):
    return 2.80103463690266e-171*(1.0 - cos(theta)**2)**46*(6.25819410131067e+172*cos(theta)**2 - 3.34662786166346e+170)*cos(92*phi)

#@torch.jit.script
def Yl94_m93(theta, phi):
    return 18.1284929784988*(1.0 - cos(theta)**2)**46.5*cos(93*phi)*cos(theta)

#@torch.jit.script
def Yl94_m94(theta, phi):
    return 1.32215623708918*(1.0 - cos(theta)**2)**47*cos(94*phi)

#@torch.jit.script
def Yl95_m_minus_95(theta, phi):
    return 1.32563102951268*(1.0 - cos(theta)**2)**47.5*sin(95*phi)

#@torch.jit.script
def Yl95_m_minus_94(theta, phi):
    return 18.2725627380863*(1.0 - cos(theta)**2)**47*sin(94*phi)*cos(theta)

#@torch.jit.script
def Yl95_m_minus_93(theta, phi):
    return 1.50177383295964e-173*(1.0 - cos(theta)**2)**46.5*(1.18279868514772e+175*cos(theta)**2 - 6.25819410131067e+172)*sin(93*phi)

#@torch.jit.script
def Yl95_m_minus_92(theta, phi):
    return 3.56651524598497e-172*(1.0 - cos(theta)**2)**46*(3.94266228382572e+174*cos(theta)**3 - 6.25819410131067e+172*cos(theta))*sin(92*phi)

#@torch.jit.script
def Yl95_m_minus_91(theta, phi):
    return 9.75427249357057e-171*(1.0 - cos(theta)**2)**45.5*(9.8566557095643e+173*cos(theta)**4 - 3.12909705065533e+172*cos(theta)**2 + 8.36656965415864e+169)*sin(91*phi)

#@torch.jit.script
def Yl95_m_minus_90(theta, phi):
    return 2.97465331841056e-169*(1.0 - cos(theta)**2)**45*(1.97133114191286e+173*cos(theta)**5 - 1.04303235021844e+172*cos(theta)**3 + 8.36656965415864e+169*cos(theta))*sin(90*phi)

#@torch.jit.script
def Yl95_m_minus_89(theta, phi):
    return 9.91055206577886e-168*(1.0 - cos(theta)**2)**44.5*(3.2855519031881e+172*cos(theta)**6 - 2.60758087554611e+171*cos(theta)**4 + 4.18328482707932e+169*cos(theta)**2 - 7.53745013888166e+166)*sin(89*phi)

#@torch.jit.script
def Yl95_m_minus_88(theta, phi):
    return 3.55676997310882e-166*(1.0 - cos(theta)**2)**44*(4.693645575983e+171*cos(theta)**7 - 5.21516175109222e+170*cos(theta)**5 + 1.39442827569311e+169*cos(theta)**3 - 7.53745013888166e+166*cos(theta))*sin(88*phi)

#@torch.jit.script
def Yl95_m_minus_87(theta, phi):
    return 1.36090032358417e-164*(1.0 - cos(theta)**2)**43.5*(5.86705696997875e+170*cos(theta)**8 - 8.69193625182037e+169*cos(theta)**6 + 3.48607068923277e+168*cos(theta)**4 - 3.76872506944083e+166*cos(theta)**2 + 5.14853151562955e+163)*sin(87*phi)

#@torch.jit.script
def Yl95_m_minus_86(theta, phi):
    return 5.50786473455747e-163*(1.0 - cos(theta)**2)**43*(6.51895218886528e+169*cos(theta)**9 - 1.24170517883148e+169*cos(theta)**7 + 6.97214137846554e+167*cos(theta)**5 - 1.25624168981361e+166*cos(theta)**3 + 5.14853151562955e+163*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl95_m_minus_85(theta, phi):
    return 2.34327119260382e-161*(1.0 - cos(theta)**2)**42.5*(6.51895218886528e+168*cos(theta)**10 - 1.55213147353935e+168*cos(theta)**8 + 1.16202356307759e+167*cos(theta)**6 - 3.14060422453403e+165*cos(theta)**4 + 2.57426575781477e+163*cos(theta)**2 - 2.84449255007157e+160)*sin(85*phi)

#@torch.jit.script
def Yl95_m_minus_84(theta, phi):
    return 1.0426898564066e-159*(1.0 - cos(theta)**2)**42*(5.92632017169571e+167*cos(theta)**11 - 1.72459052615484e+167*cos(theta)**9 + 1.66003366153941e+166*cos(theta)**7 - 6.28120844906805e+164*cos(theta)**5 + 8.58088585938258e+162*cos(theta)**3 - 2.84449255007157e+160*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl95_m_minus_83(theta, phi):
    return 4.83250472274067e-158*(1.0 - cos(theta)**2)**41.5*(4.93860014307975e+166*cos(theta)**12 - 1.72459052615484e+166*cos(theta)**10 + 2.07504207692427e+165*cos(theta)**8 - 1.04686807484468e+164*cos(theta)**6 + 2.14522146484565e+162*cos(theta)**4 - 1.42224627503579e+160*cos(theta)**2 + 1.32425165273351e+157)*sin(83*phi)

#@torch.jit.script
def Yl95_m_minus_82(theta, phi):
    return 2.32463067573646e-156*(1.0 - cos(theta)**2)**41*(3.79892318698443e+165*cos(theta)**13 - 1.56780956923167e+165*cos(theta)**11 + 2.30560230769363e+164*cos(theta)**9 - 1.49552582120668e+163*cos(theta)**7 + 4.29044292969129e+161*cos(theta)**5 - 4.74082091678596e+159*cos(theta)**3 + 1.32425165273351e+157*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl95_m_minus_81(theta, phi):
    return 1.15718984938984e-154*(1.0 - cos(theta)**2)**40.5*(2.71351656213173e+164*cos(theta)**14 - 1.30650797435972e+164*cos(theta)**12 + 2.30560230769363e+163*cos(theta)**10 - 1.86940727650835e+162*cos(theta)**8 + 7.15073821615215e+160*cos(theta)**6 - 1.18520522919649e+159*cos(theta)**4 + 6.62125826366754e+156*cos(theta)**2 - 5.34403411111181e+153)*sin(81*phi)

#@torch.jit.script
def Yl95_m_minus_80(theta, phi):
    return 5.94574910123317e-153*(1.0 - cos(theta)**2)**40*(1.80901104142116e+163*cos(theta)**15 - 1.00500613412286e+163*cos(theta)**13 + 2.0960020979033e+162*cos(theta)**11 - 2.07711919612039e+161*cos(theta)**9 + 1.02153403087888e+160*cos(theta)**7 - 2.37041045839298e+158*cos(theta)**5 + 2.20708608788918e+156*cos(theta)**3 - 5.34403411111181e+153*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl95_m_minus_79(theta, phi):
    return 3.14619469596975e-151*(1.0 - cos(theta)**2)**39.5*(1.13063190088822e+162*cos(theta)**16 - 7.17861524373474e+161*cos(theta)**14 + 1.74666841491942e+161*cos(theta)**12 - 2.07711919612039e+160*cos(theta)**10 + 1.2769175385986e+159*cos(theta)**8 - 3.95068409732163e+157*cos(theta)**6 + 5.51771521972295e+155*cos(theta)**4 - 2.67201705555591e+153*cos(theta)**2 + 1.90858361111136e+150)*sin(79*phi)

#@torch.jit.script
def Yl95_m_minus_78(theta, phi):
    return 1.71113659507699e-149*(1.0 - cos(theta)**2)**39*(6.65077588757778e+160*cos(theta)**17 - 4.78574349582316e+160*cos(theta)**15 + 1.34359108839955e+160*cos(theta)**13 - 1.88829017829126e+159*cos(theta)**11 + 1.41879726510955e+158*cos(theta)**9 - 5.64383442474519e+156*cos(theta)**7 + 1.10354304394459e+155*cos(theta)**5 - 8.90672351851969e+152*cos(theta)**3 + 1.90858361111136e+150*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl95_m_minus_77(theta, phi):
    return 9.54869416412232e-148*(1.0 - cos(theta)**2)**38.5*(3.69487549309877e+159*cos(theta)**18 - 2.99108968488948e+159*cos(theta)**16 + 9.59707920285394e+158*cos(theta)**14 - 1.57357514857605e+158*cos(theta)**12 + 1.41879726510955e+157*cos(theta)**10 - 7.05479303093148e+155*cos(theta)**8 + 1.83923840657432e+154*cos(theta)**6 - 2.22668087962992e+152*cos(theta)**4 + 9.54291805555681e+149*cos(theta)**2 - 6.12904178263122e+146)*sin(77*phi)

#@torch.jit.script
def Yl95_m_minus_76(theta, phi):
    return 5.45864696480855e-146*(1.0 - cos(theta)**2)**38*(1.94467131215725e+158*cos(theta)**19 - 1.75946452052322e+158*cos(theta)**17 + 6.39805280190262e+157*cos(theta)**15 - 1.21044242198158e+157*cos(theta)**13 + 1.28981569555414e+156*cos(theta)**11 - 7.8386589232572e+154*cos(theta)**9 + 2.62748343796331e+153*cos(theta)**7 - 4.45336175925985e+151*cos(theta)**5 + 3.1809726851856e+149*cos(theta)**3 - 6.12904178263122e+146*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl95_m_minus_75(theta, phi):
    return 3.19225856201428e-144*(1.0 - cos(theta)**2)**37.5*(9.72335656078622e+156*cos(theta)**20 - 9.77480289179568e+156*cos(theta)**18 + 3.99878300118914e+156*cos(theta)**16 - 8.64601729986841e+155*cos(theta)**14 + 1.07484641296178e+155*cos(theta)**12 - 7.83865892325721e+153*cos(theta)**10 + 3.28435429745414e+152*cos(theta)**8 - 7.42226959876641e+150*cos(theta)**6 + 7.95243171296401e+148*cos(theta)**4 - 3.06452089131561e+146*cos(theta)**2 + 1.79211748030153e+143)*sin(75*phi)

#@torch.jit.script
def Yl95_m_minus_74(theta, phi):
    return 1.90735779481748e-142*(1.0 - cos(theta)**2)**37*(4.63016979085058e+155*cos(theta)**21 - 5.14463310094509e+155*cos(theta)**19 + 2.35222529481714e+155*cos(theta)**17 - 5.76401153324561e+154*cos(theta)**15 + 8.26804933047526e+153*cos(theta)**13 - 7.12605356659746e+152*cos(theta)**11 + 3.64928255272682e+151*cos(theta)**9 - 1.0603242283952e+150*cos(theta)**7 + 1.5904863425928e+148*cos(theta)**5 - 1.02150696377187e+146*cos(theta)**3 + 1.79211748030153e+143*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl95_m_minus_73(theta, phi):
    return 1.16301913785641e-140*(1.0 - cos(theta)**2)**36.5*(2.10462263220481e+154*cos(theta)**22 - 2.57231655047255e+154*cos(theta)**20 + 1.30679183045397e+154*cos(theta)**18 - 3.6025072082785e+153*cos(theta)**16 + 5.90574952176804e+152*cos(theta)**14 - 5.93837797216455e+151*cos(theta)**12 + 3.64928255272682e+150*cos(theta)**10 - 1.325405285494e+149*cos(theta)**8 + 2.650810570988e+147*cos(theta)**6 - 2.55376740942968e+145*cos(theta)**4 + 8.96058740150763e+142*cos(theta)**2 - 4.82011156616871e+139)*sin(73*phi)

#@torch.jit.script
def Yl95_m_minus_72(theta, phi):
    return 7.22945269162081e-139*(1.0 - cos(theta)**2)**36*(9.15053318349918e+152*cos(theta)**23 - 1.22491264308216e+153*cos(theta)**21 + 6.87785173923141e+152*cos(theta)**19 - 2.11912188722265e+152*cos(theta)**17 + 3.93716634784536e+151*cos(theta)**15 - 4.56798305551119e+150*cos(theta)**13 + 3.31752959338802e+149*cos(theta)**11 - 1.47267253943778e+148*cos(theta)**9 + 3.78687224426858e+146*cos(theta)**7 - 5.10753481885935e+144*cos(theta)**5 + 2.98686246716921e+142*cos(theta)**3 - 4.82011156616871e+139*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl95_m_minus_71(theta, phi):
    return 4.57687737186935e-137*(1.0 - cos(theta)**2)**35.5*(3.81272215979132e+151*cos(theta)**24 - 5.56778474128257e+151*cos(theta)**22 + 3.4389258696157e+151*cos(theta)**20 - 1.17728993734592e+151*cos(theta)**18 + 2.46072896740335e+150*cos(theta)**16 - 3.26284503965085e+149*cos(theta)**14 + 2.76460799449001e+148*cos(theta)**12 - 1.47267253943778e+147*cos(theta)**10 + 4.73359030533572e+145*cos(theta)**8 - 8.51255803143225e+143*cos(theta)**6 + 7.46715616792303e+141*cos(theta)**4 - 2.41005578308436e+139*cos(theta)**2 + 1.20262264624968e+136)*sin(71*phi)

#@torch.jit.script
def Yl95_m_minus_70(theta, phi):
    return 2.94844699596395e-135*(1.0 - cos(theta)**2)**35*(1.52508886391653e+150*cos(theta)**25 - 2.42077597447068e+150*cos(theta)**23 + 1.63758374743605e+150*cos(theta)**21 - 6.1962628281364e+149*cos(theta)**19 + 1.44748762788432e+149*cos(theta)**17 - 2.1752300264339e+148*cos(theta)**15 + 2.12662153422309e+147*cos(theta)**13 - 1.33879321767071e+146*cos(theta)**11 + 5.25954478370636e+144*cos(theta)**9 - 1.21607971877604e+143*cos(theta)**7 + 1.49343123358461e+141*cos(theta)**5 - 8.03351927694785e+138*cos(theta)**3 + 1.20262264624968e+136*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl95_m_minus_69(theta, phi):
    return 1.93117651346421e-133*(1.0 - cos(theta)**2)**34.5*(5.86572639967896e+148*cos(theta)**26 - 1.00865665602945e+149*cos(theta)**24 + 7.44356248834568e+148*cos(theta)**22 - 3.0981314140682e+148*cos(theta)**20 + 8.04159793269069e+147*cos(theta)**18 - 1.35951876652119e+147*cos(theta)**16 + 1.51901538158792e+146*cos(theta)**14 - 1.11566101472559e+145*cos(theta)**12 + 5.25954478370636e+143*cos(theta)**10 - 1.52009964847005e+142*cos(theta)**8 + 2.48905205597434e+140*cos(theta)**6 - 2.00837981923696e+138*cos(theta)**4 + 6.01311323124839e+135*cos(theta)**2 - 2.80331619172419e+132)*sin(69*phi)

#@torch.jit.script
def Yl95_m_minus_68(theta, phi):
    return 1.28506701737372e-131*(1.0 - cos(theta)**2)**34*(2.17249125914036e+147*cos(theta)**27 - 4.0346266241178e+147*cos(theta)**25 + 3.23633151667203e+147*cos(theta)**23 - 1.47530067336581e+147*cos(theta)**21 + 4.23241996457405e+146*cos(theta)**19 - 7.99716921483052e+145*cos(theta)**17 + 1.01267692105861e+145*cos(theta)**15 - 8.58200780558147e+143*cos(theta)**13 + 4.78140434882396e+142*cos(theta)**11 - 1.68899960941116e+141*cos(theta)**9 + 3.55578865139192e+139*cos(theta)**7 - 4.01675963847393e+137*cos(theta)**5 + 2.0043710770828e+135*cos(theta)**3 - 2.80331619172419e+132*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl95_m_minus_67(theta, phi):
    return 8.68157646942252e-130*(1.0 - cos(theta)**2)**33.5*(7.7588973540727e+145*cos(theta)**28 - 1.55177947081454e+146*cos(theta)**26 + 1.34847146528001e+146*cos(theta)**24 - 6.70591215166277e+145*cos(theta)**22 + 2.11620998228702e+145*cos(theta)**20 - 4.44287178601695e+144*cos(theta)**18 + 6.32923075661633e+143*cos(theta)**16 - 6.13000557541533e+142*cos(theta)**14 + 3.98450362401997e+141*cos(theta)**12 - 1.68899960941116e+140*cos(theta)**10 + 4.4447358142399e+138*cos(theta)**8 - 6.69459939745654e+136*cos(theta)**6 + 5.01092769270699e+134*cos(theta)**4 - 1.4016580958621e+132*cos(theta)**2 + 6.14223530176203e+128)*sin(67*phi)

#@torch.jit.script
def Yl95_m_minus_66(theta, phi):
    return 5.95052249330961e-128*(1.0 - cos(theta)**2)**33*(2.67548184623196e+144*cos(theta)**29 - 5.74733137338718e+144*cos(theta)**27 + 5.39388586112006e+144*cos(theta)**25 - 2.91561397898381e+144*cos(theta)**23 + 1.0077190391843e+144*cos(theta)**21 - 2.33835357158787e+143*cos(theta)**19 + 3.72307691565667e+142*cos(theta)**17 - 4.08667038361022e+141*cos(theta)**15 + 3.06500278770767e+140*cos(theta)**13 - 1.53545419037378e+139*cos(theta)**11 + 4.93859534915544e+137*cos(theta)**9 - 9.56371342493792e+135*cos(theta)**7 + 1.0021855385414e+134*cos(theta)**5 - 4.67219365287365e+131*cos(theta)**3 + 6.14223530176203e+128*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl95_m_minus_65(theta, phi):
    return 4.13550610767948e-126*(1.0 - cos(theta)**2)**32.5*(8.91827282077322e+142*cos(theta)**30 - 2.05261834763828e+143*cos(theta)**28 + 2.07457148504618e+143*cos(theta)**26 - 1.21483915790992e+143*cos(theta)**24 + 4.58054108720135e+142*cos(theta)**22 - 1.16917678579394e+142*cos(theta)**20 + 2.0683760642537e+141*cos(theta)**18 - 2.55416898975639e+140*cos(theta)**16 + 2.18928770550548e+139*cos(theta)**14 - 1.27954515864482e+138*cos(theta)**12 + 4.93859534915544e+136*cos(theta)**10 - 1.19546417811724e+135*cos(theta)**8 + 1.67030923090233e+133*cos(theta)**6 - 1.16804841321841e+131*cos(theta)**4 + 3.07111765088102e+128*cos(theta)**2 - 1.27168432748696e+125)*sin(65*phi)

#@torch.jit.script
def Yl95_m_minus_64(theta, phi):
    return 2.9125239467274e-124*(1.0 - cos(theta)**2)**32*(2.87686220024942e+141*cos(theta)**31 - 7.07799430220096e+141*cos(theta)**29 + 7.68359809276361e+141*cos(theta)**27 - 4.85935663163969e+141*cos(theta)**25 + 1.99153960313102e+141*cos(theta)**23 - 5.56750850378064e+140*cos(theta)**21 + 1.08861898118616e+140*cos(theta)**19 - 1.50245234691552e+139*cos(theta)**17 + 1.45952513700365e+138*cos(theta)**15 - 9.84265506649861e+136*cos(theta)**13 + 4.48963213559586e+135*cos(theta)**11 - 1.32829353124138e+134*cos(theta)**9 + 2.38615604414619e+132*cos(theta)**7 - 2.33609682643683e+130*cos(theta)**5 + 1.02370588362701e+128*cos(theta)**3 - 1.27168432748696e+125*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl95_m_minus_63(theta, phi):
    return 2.07750968051765e-122*(1.0 - cos(theta)**2)**31.5*(8.99019437577945e+139*cos(theta)**32 - 2.35933143406699e+140*cos(theta)**30 + 2.74414217598701e+140*cos(theta)**28 - 1.86898331986142e+140*cos(theta)**26 + 8.29808167971259e+139*cos(theta)**24 - 2.53068568353666e+139*cos(theta)**22 + 5.4430949059308e+138*cos(theta)**20 - 8.34695748286402e+137*cos(theta)**18 + 9.12203210627282e+136*cos(theta)**16 - 7.03046790464186e+135*cos(theta)**14 + 3.74136011299655e+134*cos(theta)**12 - 1.32829353124138e+133*cos(theta)**10 + 2.98269505518273e+131*cos(theta)**8 - 3.89349471072804e+129*cos(theta)**6 + 2.55926470906751e+127*cos(theta)**4 - 6.35842163743482e+124*cos(theta)**2 + 2.49937957446337e+121)*sin(63*phi)

#@torch.jit.script
def Yl95_m_minus_62(theta, phi):
    return 1.50012887140968e-120*(1.0 - cos(theta)**2)**31*(2.72430132599377e+138*cos(theta)**33 - 7.61074656150641e+138*cos(theta)**31 + 9.4625592275414e+138*cos(theta)**29 - 6.92216044393118e+138*cos(theta)**27 + 3.31923267188503e+138*cos(theta)**25 - 1.10029812327681e+138*cos(theta)**23 + 2.59194995520514e+137*cos(theta)**21 - 4.39313551729685e+136*cos(theta)**19 + 5.36590123898401e+135*cos(theta)**17 - 4.68697860309458e+134*cos(theta)**15 + 2.87796931768965e+133*cos(theta)**13 - 1.2075395738558e+132*cos(theta)**11 + 3.3141056168697e+130*cos(theta)**9 - 5.56213530104006e+128*cos(theta)**7 + 5.11852941813503e+126*cos(theta)**5 - 2.11947387914494e+124*cos(theta)**3 + 2.49937957446337e+121*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl95_m_minus_61(theta, phi):
    return 1.0960184229933e-118*(1.0 - cos(theta)**2)**30.5*(8.01265095880522e+136*cos(theta)**34 - 2.37835830047075e+137*cos(theta)**32 + 3.15418640918047e+137*cos(theta)**30 - 2.47220015854685e+137*cos(theta)**28 + 1.27662795072501e+137*cos(theta)**26 - 4.58457551365336e+136*cos(theta)**24 + 1.17815907054779e+136*cos(theta)**22 - 2.19656775864843e+135*cos(theta)**20 + 2.98105624388001e+134*cos(theta)**18 - 2.92936162693411e+133*cos(theta)**16 + 2.05569236977832e+132*cos(theta)**14 - 1.00628297821316e+131*cos(theta)**12 + 3.3141056168697e+129*cos(theta)**10 - 6.95266912630008e+127*cos(theta)**8 + 8.53088236355838e+125*cos(theta)**6 - 5.29868469786235e+123*cos(theta)**4 + 1.24968978723169e+121*cos(theta)**2 - 4.68223974234427e+117)*sin(61*phi)

#@torch.jit.script
def Yl95_m_minus_60(theta, phi):
    return 8.09867881455509e-117*(1.0 - cos(theta)**2)**30*(2.28932884537292e+135*cos(theta)**35 - 7.20714636506289e+135*cos(theta)**33 + 1.01747948683241e+136*cos(theta)**31 - 8.52482813292018e+135*cos(theta)**29 + 4.7282516693519e+135*cos(theta)**27 - 1.83383020546135e+135*cos(theta)**25 + 5.12243074151214e+134*cos(theta)**23 - 1.04598464697544e+134*cos(theta)**21 + 1.56897697046316e+133*cos(theta)**19 - 1.72315389819654e+132*cos(theta)**17 + 1.37046157985222e+131*cos(theta)**15 - 7.74063829394742e+129*cos(theta)**13 + 3.01282328806337e+128*cos(theta)**11 - 7.7251879181112e+126*cos(theta)**9 + 1.21869748050834e+125*cos(theta)**7 - 1.05973693957247e+123*cos(theta)**5 + 4.16563262410562e+120*cos(theta)**3 - 4.68223974234427e+117*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl95_m_minus_59(theta, phi):
    return 6.04966428705415e-115*(1.0 - cos(theta)**2)**29.5*(6.35924679270255e+133*cos(theta)**36 - 2.11974893090085e+134*cos(theta)**34 + 3.17962339635128e+134*cos(theta)**32 - 2.84160937764006e+134*cos(theta)**30 + 1.68866131048282e+134*cos(theta)**28 - 7.05319309792825e+133*cos(theta)**26 + 2.13434614229672e+133*cos(theta)**24 - 4.75447566807018e+132*cos(theta)**22 + 7.8448848523158e+131*cos(theta)**20 - 9.57307721220297e+130*cos(theta)**18 + 8.56538487407634e+129*cos(theta)**16 - 5.52902735281959e+128*cos(theta)**14 + 2.51068607338614e+127*cos(theta)**12 - 7.7251879181112e+125*cos(theta)**10 + 1.52337185063543e+124*cos(theta)**8 - 1.76622823262078e+122*cos(theta)**6 + 1.0414081560264e+120*cos(theta)**4 - 2.34111987117214e+117*cos(theta)**2 + 8.39111064936249e+113)*sin(59*phi)

#@torch.jit.script
def Yl95_m_minus_58(theta, phi):
    return 4.56659500771156e-113*(1.0 - cos(theta)**2)**29*(1.71871534937907e+132*cos(theta)**37 - 6.05642551685957e+132*cos(theta)**35 + 9.63522241318568e+132*cos(theta)**33 - 9.16648186335503e+132*cos(theta)**31 + 5.82297003614766e+132*cos(theta)**29 - 2.61229373997343e+132*cos(theta)**27 + 8.5373845691869e+131*cos(theta)**25 - 2.06716333394356e+131*cos(theta)**23 + 3.73565945348372e+130*cos(theta)**21 - 5.03846169063314e+129*cos(theta)**19 + 5.03846169063314e+128*cos(theta)**17 - 3.68601823521306e+127*cos(theta)**15 + 1.9312969795278e+126*cos(theta)**13 - 7.02289810737382e+124*cos(theta)**11 + 1.69263538959492e+123*cos(theta)**9 - 2.52318318945826e+121*cos(theta)**7 + 2.08281631205281e+119*cos(theta)**5 - 7.80373290390712e+116*cos(theta)**3 + 8.39111064936249e+113*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl95_m_minus_57(theta, phi):
    return 3.48200997777645e-111*(1.0 - cos(theta)**2)**28.5*(4.52293512994492e+130*cos(theta)**38 - 1.68234042134988e+131*cos(theta)**36 + 2.83388894505461e+131*cos(theta)**34 - 2.86452558229845e+131*cos(theta)**32 + 1.94099001204922e+131*cos(theta)**30 - 9.32962049990509e+130*cos(theta)**28 + 3.28360944968727e+130*cos(theta)**26 - 8.61318055809816e+129*cos(theta)**24 + 1.69802702431078e+129*cos(theta)**22 - 2.51923084531657e+128*cos(theta)**20 + 2.79914538368508e+127*cos(theta)**18 - 2.30376139700816e+126*cos(theta)**16 + 1.37949784251986e+125*cos(theta)**14 - 5.85241508947818e+123*cos(theta)**12 + 1.69263538959492e+122*cos(theta)**10 - 3.15397898682283e+120*cos(theta)**8 + 3.47136052008802e+118*cos(theta)**6 - 1.95093322597678e+116*cos(theta)**4 + 4.19555532468125e+113*cos(theta)**2 - 1.44325948561446e+110)*sin(57*phi)

#@torch.jit.script
def Yl95_m_minus_56(theta, phi):
    return 2.68092156880921e-109*(1.0 - cos(theta)**2)**28*(1.15972695639613e+129*cos(theta)**39 - 4.54686600364833e+129*cos(theta)**37 + 8.09682555729889e+129*cos(theta)**35 - 8.68038055241954e+129*cos(theta)**33 + 6.26125810338458e+129*cos(theta)**31 - 3.21711051720865e+129*cos(theta)**29 + 1.21615164803232e+129*cos(theta)**27 - 3.44527222323926e+128*cos(theta)**25 + 7.38272619265557e+127*cos(theta)**23 - 1.19963373586503e+127*cos(theta)**21 + 1.47323441246583e+126*cos(theta)**19 - 1.35515376294598e+125*cos(theta)**17 + 9.19665228346571e+123*cos(theta)**15 - 4.50185776113706e+122*cos(theta)**13 + 1.53875944508629e+121*cos(theta)**11 - 3.50442109646981e+119*cos(theta)**9 + 4.95908645726859e+117*cos(theta)**7 - 3.90186645195356e+115*cos(theta)**5 + 1.39851844156042e+113*cos(theta)**3 - 1.44325948561446e+110*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl95_m_minus_55(theta, phi):
    return 2.08354352887006e-107*(1.0 - cos(theta)**2)**27.5*(2.89931739099033e+127*cos(theta)**40 - 1.19654368517061e+128*cos(theta)**38 + 2.2491182103608e+128*cos(theta)**36 - 2.5530531036528e+128*cos(theta)**34 + 1.95664315730768e+128*cos(theta)**32 - 1.07237017240288e+128*cos(theta)**30 + 4.34339874297258e+127*cos(theta)**28 - 1.32510470124587e+127*cos(theta)**26 + 3.07613591360649e+126*cos(theta)**24 - 5.45288061756834e+125*cos(theta)**22 + 7.36617206232916e+124*cos(theta)**20 - 7.52863201636654e+123*cos(theta)**18 + 5.74790767716607e+122*cos(theta)**16 - 3.21561268652647e+121*cos(theta)**14 + 1.28229953757191e+120*cos(theta)**12 - 3.50442109646981e+118*cos(theta)**10 + 6.19885807158574e+116*cos(theta)**8 - 6.50311075325593e+114*cos(theta)**6 + 3.49629610390104e+112*cos(theta)**4 - 7.21629742807232e+109*cos(theta)**2 + 2.3895024596266e+106)*sin(55*phi)

#@torch.jit.script
def Yl95_m_minus_54(theta, phi):
    return 1.63395516663347e-105*(1.0 - cos(theta)**2)**27*(7.07150583168373e+125*cos(theta)**41 - 3.0680607312067e+126*cos(theta)**39 + 6.07869786584001e+126*cos(theta)**37 - 7.29443743900801e+126*cos(theta)**35 + 5.92922168881116e+126*cos(theta)**33 - 3.45925862065447e+126*cos(theta)**31 + 1.4977237044733e+126*cos(theta)**29 - 4.90779518979952e+125*cos(theta)**27 + 1.23045436544259e+125*cos(theta)**25 - 2.37081765981232e+124*cos(theta)**23 + 3.5077009820615e+123*cos(theta)**21 - 3.96243790335081e+122*cos(theta)**19 + 3.38112216303887e+121*cos(theta)**17 - 2.14374179101765e+120*cos(theta)**15 + 9.86384259670697e+118*cos(theta)**13 - 3.1858373604271e+117*cos(theta)**11 + 6.88762007953971e+115*cos(theta)**9 - 9.29015821893704e+113*cos(theta)**7 + 6.99259220780208e+111*cos(theta)**5 - 2.40543247602411e+109*cos(theta)**3 + 2.3895024596266e+106*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl95_m_minus_53(theta, phi):
    return 1.29258143909558e-103*(1.0 - cos(theta)**2)**26.5*(1.6836918646866e+124*cos(theta)**42 - 7.67015182801675e+124*cos(theta)**40 + 1.59965733311579e+125*cos(theta)**38 - 2.02623262194667e+125*cos(theta)**36 + 1.74388873200328e+125*cos(theta)**34 - 1.08101831895452e+125*cos(theta)**32 + 4.99241234824434e+124*cos(theta)**30 - 1.75278399635697e+124*cos(theta)**28 + 4.73251679016382e+123*cos(theta)**26 - 9.87840691588467e+122*cos(theta)**24 + 1.59440953730068e+122*cos(theta)**22 - 1.98121895167541e+121*cos(theta)**20 + 1.87840120168826e+120*cos(theta)**18 - 1.33983861938603e+119*cos(theta)**16 + 7.04560185479069e+117*cos(theta)**14 - 2.65486446702258e+116*cos(theta)**12 + 6.88762007953971e+114*cos(theta)**10 - 1.16126977736713e+113*cos(theta)**8 + 1.16543203463368e+111*cos(theta)**6 - 6.01358119006027e+108*cos(theta)**4 + 1.1947512298133e+106*cos(theta)**2 - 3.81831649029498e+102)*sin(53*phi)

#@torch.jit.script
def Yl95_m_minus_52(theta, phi):
    return 1.03115274168685e-101*(1.0 - cos(theta)**2)**26*(3.91556247601536e+122*cos(theta)**43 - 1.87076873854067e+123*cos(theta)**41 + 4.10168546952767e+123*cos(theta)**39 - 5.47630438363965e+123*cos(theta)**37 + 4.98253923429509e+123*cos(theta)**35 - 3.27581308774097e+123*cos(theta)**33 + 1.61045559620785e+123*cos(theta)**31 - 6.04408274605852e+122*cos(theta)**29 + 1.75278399635697e+122*cos(theta)**27 - 3.95136276635387e+121*cos(theta)**25 + 6.93221537956819e+120*cos(theta)**23 - 9.43437596035907e+119*cos(theta)**21 + 9.88632211414873e+118*cos(theta)**19 - 7.88140364344724e+117*cos(theta)**17 + 4.6970679031938e+116*cos(theta)**15 - 2.04220343617122e+115*cos(theta)**13 + 6.26147279958156e+113*cos(theta)**11 - 1.29029975263015e+112*cos(theta)**9 + 1.66490290661954e+110*cos(theta)**7 - 1.20271623801205e+108*cos(theta)**5 + 3.98250409937766e+105*cos(theta)**3 - 3.81831649029498e+102*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl95_m_minus_51(theta, phi):
    return 8.2929301318774e-100*(1.0 - cos(theta)**2)**25.5*(8.89900562730763e+120*cos(theta)**44 - 4.45421128223969e+121*cos(theta)**42 + 1.02542136738192e+122*cos(theta)**40 - 1.44113273253675e+122*cos(theta)**38 + 1.38403867619308e+122*cos(theta)**36 - 9.63474437570874e+121*cos(theta)**34 + 5.03267373814954e+121*cos(theta)**32 - 2.01469424868617e+121*cos(theta)**30 + 6.25994284413204e+120*cos(theta)**28 - 1.5197549101361e+120*cos(theta)**26 + 2.88842307482008e+119*cos(theta)**24 - 4.28835270925412e+118*cos(theta)**22 + 4.94316105707436e+117*cos(theta)**20 - 4.37855757969291e+116*cos(theta)**18 + 2.93566743949612e+115*cos(theta)**16 - 1.4587167401223e+114*cos(theta)**14 + 5.2178939996513e+112*cos(theta)**12 - 1.29029975263015e+111*cos(theta)**10 + 2.08112863327443e+109*cos(theta)**8 - 2.00452706335342e+107*cos(theta)**6 + 9.95626024844415e+104*cos(theta)**4 - 1.90915824514749e+102*cos(theta)**2 + 5.90339593428413e+98)*sin(51*phi)

#@torch.jit.script
def Yl95_m_minus_50(theta, phi):
    return 6.72187901134314e-98*(1.0 - cos(theta)**2)**25*(1.97755680606836e+119*cos(theta)**45 - 1.03586308889295e+120*cos(theta)**43 + 2.50102772532175e+120*cos(theta)**41 - 3.69521213470961e+120*cos(theta)**39 + 3.74064507079211e+120*cos(theta)**37 - 2.75278410734535e+120*cos(theta)**35 + 1.5250526479241e+120*cos(theta)**33 - 6.49901370543927e+119*cos(theta)**31 + 2.15860098073519e+119*cos(theta)**29 - 5.62872188939297e+118*cos(theta)**27 + 1.15536922992803e+118*cos(theta)**25 - 1.86450117793658e+117*cos(theta)**23 + 2.35388621765446e+116*cos(theta)**21 - 2.30450398931206e+115*cos(theta)**19 + 1.7268631997036e+114*cos(theta)**17 - 9.72477826748198e+112*cos(theta)**15 + 4.01376461511638e+111*cos(theta)**13 - 1.17299977511831e+110*cos(theta)**11 + 2.3123651480827e+108*cos(theta)**9 - 2.86361009050489e+106*cos(theta)**7 + 1.99125204968883e+104*cos(theta)**5 - 6.36386081715829e+101*cos(theta)**3 + 5.90339593428413e+98*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl95_m_minus_49(theta, phi):
    return 5.4897631565097e-96*(1.0 - cos(theta)**2)**24.5*(4.29903653493122e+117*cos(theta)**46 - 2.35423429293853e+118*cos(theta)**44 + 5.95482791743274e+118*cos(theta)**42 - 9.23803033677404e+118*cos(theta)**40 + 9.84380281787397e+118*cos(theta)**38 - 7.64662252040376e+118*cos(theta)**36 + 4.48544896448265e+118*cos(theta)**34 - 2.03094178294977e+118*cos(theta)**32 + 7.19533660245062e+117*cos(theta)**30 - 2.01025781764035e+117*cos(theta)**28 + 4.44372780741551e+116*cos(theta)**26 - 7.76875490806907e+115*cos(theta)**24 + 1.06994828075203e+115*cos(theta)**22 - 1.15225199465603e+114*cos(theta)**20 + 9.59368444279779e+112*cos(theta)**18 - 6.07798641717624e+111*cos(theta)**16 + 2.86697472508313e+110*cos(theta)**14 - 9.77499812598595e+108*cos(theta)**12 + 2.3123651480827e+107*cos(theta)**10 - 3.57951261313111e+105*cos(theta)**8 + 3.31875341614805e+103*cos(theta)**6 - 1.59096520428957e+101*cos(theta)**4 + 2.95169796714207e+98*cos(theta)**2 - 8.85066856714262e+94)*sin(49*phi)

#@torch.jit.script
def Yl95_m_minus_48(theta, phi):
    return 4.51631040468455e-94*(1.0 - cos(theta)**2)**24*(9.14688624453451e+115*cos(theta)**47 - 5.23163176208561e+116*cos(theta)**45 + 1.38484370172854e+117*cos(theta)**43 - 2.2531781309205e+117*cos(theta)**41 + 2.52405200458307e+117*cos(theta)**39 - 2.06665473524426e+117*cos(theta)**37 + 1.28155684699504e+117*cos(theta)**35 - 6.15436903924174e+116*cos(theta)**33 + 2.32107632337117e+116*cos(theta)**31 - 6.93192350910465e+115*cos(theta)**29 + 1.64582511385759e+115*cos(theta)**27 - 3.10750196322763e+114*cos(theta)**25 + 4.65194904674794e+113*cos(theta)**23 - 5.48691426026681e+112*cos(theta)**21 + 5.04930760147252e+111*cos(theta)**19 - 3.57528612775073e+110*cos(theta)**17 + 1.91131648338875e+109*cos(theta)**15 - 7.5192293276815e+107*cos(theta)**13 + 2.10215013462063e+106*cos(theta)**11 - 3.97723623681234e+104*cos(theta)**9 + 4.74107630878293e+102*cos(theta)**7 - 3.18193040857915e+100*cos(theta)**5 + 9.83899322380688e+97*cos(theta)**3 - 8.85066856714262e+94*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl95_m_minus_47(theta, phi):
    return 3.7417297815972e-92*(1.0 - cos(theta)**2)**23.5*(1.90560130094469e+114*cos(theta)**48 - 1.13731125262731e+115*cos(theta)**46 + 3.14737204938306e+115*cos(theta)**44 - 5.36470983552499e+115*cos(theta)**42 + 6.31013001145768e+115*cos(theta)**40 - 5.43856509274805e+115*cos(theta)**38 + 3.55988013054179e+115*cos(theta)**36 - 1.81010854095345e+115*cos(theta)**34 + 7.2533635105349e+114*cos(theta)**32 - 2.31064116970155e+114*cos(theta)**30 + 5.8779468352057e+113*cos(theta)**28 - 1.19519306277986e+113*cos(theta)**26 + 1.93831210281164e+112*cos(theta)**24 - 2.49405193648491e+111*cos(theta)**22 + 2.52465380073626e+110*cos(theta)**20 - 1.98627007097263e+109*cos(theta)**18 + 1.19457280211797e+108*cos(theta)**16 - 5.37087809120107e+106*cos(theta)**14 + 1.75179177885053e+105*cos(theta)**12 - 3.97723623681235e+103*cos(theta)**10 + 5.92634538597866e+101*cos(theta)**8 - 5.30321734763191e+99*cos(theta)**6 + 2.45974830595172e+97*cos(theta)**4 - 4.42533428357131e+94*cos(theta)**2 + 1.28943306630866e+91)*sin(47*phi)

#@torch.jit.script
def Yl95_m_minus_46(theta, phi):
    return 3.12114994121691e-90*(1.0 - cos(theta)**2)**23*(3.8889822468259e+112*cos(theta)**49 - 2.41981117580278e+113*cos(theta)**47 + 6.99416010974013e+113*cos(theta)**45 - 1.24760693849418e+114*cos(theta)**43 + 1.53905610035553e+114*cos(theta)**41 - 1.3945038699354e+114*cos(theta)**39 + 9.62129765011294e+113*cos(theta)**37 - 5.17173868843843e+113*cos(theta)**35 + 2.19798894258633e+113*cos(theta)**33 - 7.45368119258564e+112*cos(theta)**31 + 2.02687821903645e+112*cos(theta)**29 - 4.42664097325873e+111*cos(theta)**27 + 7.75324841124657e+110*cos(theta)**25 - 1.08437040716735e+110*cos(theta)**23 + 1.2022160955887e+109*cos(theta)**21 - 1.04540530051191e+108*cos(theta)**19 + 7.02689883598807e+106*cos(theta)**17 - 3.58058539413405e+105*cos(theta)**15 + 1.34753213757733e+104*cos(theta)**13 - 3.61566930619304e+102*cos(theta)**11 + 6.58482820664295e+100*cos(theta)**9 - 7.5760247823313e+98*cos(theta)**7 + 4.91949661190344e+96*cos(theta)**5 - 1.4751114278571e+94*cos(theta)**3 + 1.28943306630866e+91*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl95_m_minus_45(theta, phi):
    return 2.62065101714605e-88*(1.0 - cos(theta)**2)**22.5*(7.7779644936518e+110*cos(theta)**50 - 5.04127328292246e+111*cos(theta)**48 + 1.52046958907394e+112*cos(theta)**46 - 2.83547031475951e+112*cos(theta)**44 + 3.66441928656079e+112*cos(theta)**42 - 3.4862596748385e+112*cos(theta)**40 + 2.53192043424025e+112*cos(theta)**38 - 1.43659408012179e+112*cos(theta)**36 + 6.46467336054804e+111*cos(theta)**34 - 2.32927537268301e+111*cos(theta)**32 + 6.75626073012149e+110*cos(theta)**30 - 1.58094320473526e+110*cos(theta)**28 + 2.98201861971022e+109*cos(theta)**26 - 4.51821002986397e+108*cos(theta)**24 + 5.46461861631225e+107*cos(theta)**22 - 5.22702650255954e+106*cos(theta)**20 + 3.90383268666004e+105*cos(theta)**18 - 2.23786587133378e+104*cos(theta)**16 + 9.62522955412378e+102*cos(theta)**14 - 3.01305775516087e+101*cos(theta)**12 + 6.58482820664296e+99*cos(theta)**10 - 9.47003097791413e+97*cos(theta)**8 + 8.19916101983907e+95*cos(theta)**6 - 3.68777856964276e+93*cos(theta)**4 + 6.44716533154329e+90*cos(theta)**2 - 1.82898307277824e+87)*sin(45*phi)

#@torch.jit.script
def Yl95_m_minus_44(theta, phi):
    return 2.21441134212219e-86*(1.0 - cos(theta)**2)**22*(1.52509107718663e+109*cos(theta)**51 - 1.02883128222907e+110*cos(theta)**49 + 3.23504167888072e+110*cos(theta)**47 - 6.30104514391002e+110*cos(theta)**45 + 8.52190531758323e+110*cos(theta)**43 - 8.50307237765487e+110*cos(theta)**41 + 6.4921036775391e+110*cos(theta)**39 - 3.88268670303186e+110*cos(theta)**37 + 1.84704953158515e+110*cos(theta)**35 - 7.05841022025156e+109*cos(theta)**33 + 2.17943894520048e+109*cos(theta)**31 - 5.45152829219055e+108*cos(theta)**29 + 1.10445134063341e+108*cos(theta)**27 - 1.80728401194559e+107*cos(theta)**25 + 2.37592113752707e+106*cos(theta)**23 - 2.48906023931407e+105*cos(theta)**21 + 2.05464878245265e+104*cos(theta)**19 - 1.31639168901987e+103*cos(theta)**17 + 6.41681970274919e+101*cos(theta)**15 - 2.31773673473913e+100*cos(theta)**13 + 5.9862074605845e+98*cos(theta)**11 - 1.05222566421268e+97*cos(theta)**9 + 1.17130871711987e+95*cos(theta)**7 - 7.37555713928552e+92*cos(theta)**5 + 2.14905511051443e+90*cos(theta)**3 - 1.82898307277824e+87*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl95_m_minus_43(theta, phi):
    return 1.88264037871918e-84*(1.0 - cos(theta)**2)**21.5*(2.93286745612813e+107*cos(theta)**52 - 2.05766256445815e+108*cos(theta)**50 + 6.73967016433484e+108*cos(theta)**48 - 1.36979242258914e+109*cos(theta)**46 + 1.9367966630871e+109*cos(theta)**44 - 2.02454104229878e+109*cos(theta)**42 + 1.62302591938477e+109*cos(theta)**40 - 1.02175965869259e+109*cos(theta)**38 + 5.1306931432921e+108*cos(theta)**36 - 2.07600300595634e+108*cos(theta)**34 + 6.8107467037515e+107*cos(theta)**32 - 1.81717609739685e+107*cos(theta)**30 + 3.94446907369077e+106*cos(theta)**28 - 6.95109235363688e+105*cos(theta)**26 + 9.89967140636277e+104*cos(theta)**24 - 1.13139101787003e+104*cos(theta)**22 + 1.02732439122633e+103*cos(theta)**20 - 7.3132871612215e+101*cos(theta)**18 + 4.01051231421824e+100*cos(theta)**16 - 1.65552623909938e+99*cos(theta)**14 + 4.98850621715375e+97*cos(theta)**12 - 1.05222566421268e+96*cos(theta)**10 + 1.46413589639983e+94*cos(theta)**8 - 1.22925952321425e+92*cos(theta)**6 + 5.37263777628607e+89*cos(theta)**4 - 9.14491536389119e+86*cos(theta)**2 + 2.53041376975406e+83)*sin(43*phi)

#@torch.jit.script
def Yl95_m_minus_42(theta, phi):
    return 1.61007033060363e-82*(1.0 - cos(theta)**2)**21*(5.53371218137383e+105*cos(theta)**53 - 4.0346324793297e+106*cos(theta)**51 + 1.37544289068058e+107*cos(theta)**49 - 2.91445196295561e+107*cos(theta)**47 + 4.30399258463799e+107*cos(theta)**45 - 4.70823498209018e+107*cos(theta)**43 + 3.9585998033775e+107*cos(theta)**41 - 2.61989656075024e+107*cos(theta)**39 + 1.38667382251138e+107*cos(theta)**37 - 5.93143715987526e+106*cos(theta)**35 + 2.06386263750045e+106*cos(theta)**33 - 5.86185837869952e+105*cos(theta)**31 + 1.36016174954854e+105*cos(theta)**29 - 2.57447864949514e+104*cos(theta)**27 + 3.95986856254511e+103*cos(theta)**25 - 4.91909138204361e+102*cos(theta)**23 + 4.89202091060155e+101*cos(theta)**21 - 3.84909850590605e+100*cos(theta)**19 + 2.35912489071661e+99*cos(theta)**17 - 1.10368415939959e+98*cos(theta)**15 + 3.83731247473366e+96*cos(theta)**13 - 9.56568785647891e+94*cos(theta)**11 + 1.62681766266648e+93*cos(theta)**9 - 1.75608503316322e+91*cos(theta)**7 + 1.07452755525721e+89*cos(theta)**5 - 3.04830512129706e+86*cos(theta)**3 + 2.53041376975406e+83*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl95_m_minus_41(theta, phi):
    return 1.38484768914446e-80*(1.0 - cos(theta)**2)**20.5*(1.02476151506923e+104*cos(theta)**54 - 7.75890861409558e+104*cos(theta)**52 + 2.75088578136116e+105*cos(theta)**50 - 6.07177492282418e+105*cos(theta)**48 + 9.35650561877825e+105*cos(theta)**46 - 1.0700534050205e+106*cos(theta)**44 + 9.42523762708928e+105*cos(theta)**42 - 6.5497414018756e+105*cos(theta)**40 + 3.64914163818784e+105*cos(theta)**38 - 1.64762143329868e+105*cos(theta)**36 + 6.07018422794251e+104*cos(theta)**34 - 1.8318307433436e+104*cos(theta)**32 + 4.53387249849513e+103*cos(theta)**30 - 9.19456660533978e+102*cos(theta)**28 + 1.52302637020966e+102*cos(theta)**26 - 2.04962140918484e+101*cos(theta)**24 + 2.22364586845525e+100*cos(theta)**22 - 1.92454925295303e+99*cos(theta)**20 + 1.31062493928701e+98*cos(theta)**18 - 6.89802599624741e+96*cos(theta)**16 + 2.74093748195261e+95*cos(theta)**14 - 7.97140654706576e+93*cos(theta)**12 + 1.62681766266648e+92*cos(theta)**10 - 2.19510629145402e+90*cos(theta)**8 + 1.79087925876202e+88*cos(theta)**6 - 7.62076280324266e+85*cos(theta)**4 + 1.26520688487703e+83*cos(theta)**2 - 3.42040250034342e+79)*sin(41*phi)

#@torch.jit.script
def Yl95_m_minus_40(theta, phi):
    return 1.19771312731902e-78*(1.0 - cos(theta)**2)**20*(1.86320275467132e+102*cos(theta)**55 - 1.46394502152747e+103*cos(theta)**53 + 5.39389368894345e+103*cos(theta)**51 - 1.23913773935187e+104*cos(theta)**49 + 1.9907458763358e+104*cos(theta)**47 - 2.3778964556011e+104*cos(theta)**45 + 2.19191572723007e+104*cos(theta)**43 - 1.59749790289649e+104*cos(theta)**41 + 9.35677343125086e+103*cos(theta)**39 - 4.45303090080725e+103*cos(theta)**37 + 1.73433835084072e+103*cos(theta)**35 - 5.55100225255636e+102*cos(theta)**33 + 1.46253951564359e+102*cos(theta)**31 - 3.17054020873786e+101*cos(theta)**29 + 5.64083840818392e+100*cos(theta)**27 - 8.19848563673936e+99*cos(theta)**25 + 9.66802551502283e+98*cos(theta)**23 - 9.16452025215727e+97*cos(theta)**21 + 6.89802599624741e+96*cos(theta)**19 - 4.05766235073377e+95*cos(theta)**17 + 1.82729165463507e+94*cos(theta)**15 - 6.13185119005059e+92*cos(theta)**13 + 1.47892514787862e+91*cos(theta)**11 - 2.43900699050447e+89*cos(theta)**9 + 2.55839894108861e+87*cos(theta)**7 - 1.52415256064853e+85*cos(theta)**5 + 4.21735628292344e+82*cos(theta)**3 - 3.42040250034342e+79*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl95_m_minus_39(theta, phi):
    return 1.0413907297102e-76*(1.0 - cos(theta)**2)**19.5*(3.32714777619879e+100*cos(theta)**56 - 2.71100929912494e+101*cos(theta)**54 + 1.03728724787374e+102*cos(theta)**52 - 2.47827547870375e+102*cos(theta)**50 + 4.14738724236624e+102*cos(theta)**48 - 5.16934012087196e+102*cos(theta)**46 + 4.9816266527956e+102*cos(theta)**44 - 3.80356643546783e+102*cos(theta)**42 + 2.33919335781271e+102*cos(theta)**40 - 1.17185023705454e+102*cos(theta)**38 + 4.81760653011311e+101*cos(theta)**36 - 1.63264772134011e+101*cos(theta)**34 + 4.57043598638622e+100*cos(theta)**32 - 1.05684673624595e+100*cos(theta)**30 + 2.01458514577997e+99*cos(theta)**28 - 3.15326370643821e+98*cos(theta)**26 + 4.02834396459284e+97*cos(theta)**24 - 4.16569102370785e+96*cos(theta)**22 + 3.4490129981237e+95*cos(theta)**20 - 2.25425686151876e+94*cos(theta)**18 + 1.14205728414692e+93*cos(theta)**16 - 4.37989370717899e+91*cos(theta)**14 + 1.23243762323218e+90*cos(theta)**12 - 2.43900699050447e+88*cos(theta)**10 + 3.19799867636076e+86*cos(theta)**8 - 2.54025426774755e+84*cos(theta)**6 + 1.05433907073086e+82*cos(theta)**4 - 1.71020125017171e+79*cos(theta)**2 + 4.52434193167119e+75)*sin(39*phi)

#@torch.jit.script
def Yl95_m_minus_38(theta, phi):
    return 9.10130218782643e-75*(1.0 - cos(theta)**2)**19*(5.83710136175226e+98*cos(theta)**57 - 4.9291078165908e+99*cos(theta)**55 + 1.95714575070517e+100*cos(theta)**53 - 4.85936368373284e+100*cos(theta)**51 + 8.4640555966658e+100*cos(theta)**49 - 1.09985960018552e+101*cos(theta)**47 + 1.10702814506569e+101*cos(theta)**45 - 8.84550333829728e+100*cos(theta)**43 + 5.70534965320174e+100*cos(theta)**41 - 3.00474419757574e+100*cos(theta)**39 + 1.30205581894949e+100*cos(theta)**37 - 4.66470777525745e+99*cos(theta)**35 + 1.38498060193522e+99*cos(theta)**33 - 3.40918302014823e+98*cos(theta)**31 + 6.94684533027576e+97*cos(theta)**29 - 1.16787544682897e+97*cos(theta)**27 + 1.61133758583714e+96*cos(theta)**25 - 1.81117001030776e+95*cos(theta)**23 + 1.64238714196367e+94*cos(theta)**21 - 1.18645097974672e+93*cos(theta)**19 + 6.71798402439366e+91*cos(theta)**17 - 2.91992913811933e+90*cos(theta)**15 + 9.48028940947833e+88*cos(theta)**13 - 2.21727908227679e+87*cos(theta)**11 + 3.55333186262306e+85*cos(theta)**9 - 3.62893466821079e+83*cos(theta)**7 + 2.10867814146172e+81*cos(theta)**5 - 5.7006708339057e+78*cos(theta)**3 + 4.52434193167119e+75*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl95_m_minus_37(theta, phi):
    return 7.99361728806196e-73*(1.0 - cos(theta)**2)**18.5*(1.00639678650901e+97*cos(theta)**58 - 8.80197824391214e+97*cos(theta)**56 + 3.62434398278735e+98*cos(theta)**54 - 9.34493016102469e+98*cos(theta)**52 + 1.69281111933316e+99*cos(theta)**50 - 2.29137416705317e+99*cos(theta)**48 + 2.40658292405585e+99*cos(theta)**46 - 2.01034166779484e+99*cos(theta)**44 + 1.35841658409565e+99*cos(theta)**42 - 7.51186049393935e+98*cos(theta)**40 + 3.42646268144602e+98*cos(theta)**38 - 1.29575215979373e+98*cos(theta)**36 + 4.073472358633e+97*cos(theta)**34 - 1.06536969379632e+97*cos(theta)**32 + 2.31561511009192e+96*cos(theta)**30 - 4.17098373867489e+95*cos(theta)**28 + 6.19745225321976e+94*cos(theta)**26 - 7.54654170961567e+93*cos(theta)**24 + 7.46539609983486e+92*cos(theta)**22 - 5.93225489873358e+91*cos(theta)**20 + 3.73221334688536e+90*cos(theta)**18 - 1.82495571132458e+89*cos(theta)**16 + 6.77163529248452e+87*cos(theta)**14 - 1.84773256856399e+86*cos(theta)**12 + 3.55333186262306e+84*cos(theta)**10 - 4.53616833526349e+82*cos(theta)**8 + 3.51446356910287e+80*cos(theta)**6 - 1.42516770847643e+78*cos(theta)**4 + 2.2621709658356e+75*cos(theta)**2 - 5.86510491531137e+71)*sin(37*phi)

#@torch.jit.script
def Yl95_m_minus_36(theta, phi):
    return 7.05433895064767e-71*(1.0 - cos(theta)**2)**18*(1.70575726526951e+95*cos(theta)**59 - 1.54420670945827e+96*cos(theta)**57 + 6.58971633234064e+96*cos(theta)**55 - 1.76319437000466e+97*cos(theta)**53 + 3.31923748888855e+97*cos(theta)**51 - 4.6762738103126e+97*cos(theta)**49 + 5.12038920011882e+97*cos(theta)**47 - 4.46742592843297e+97*cos(theta)**45 + 3.15910833510617e+97*cos(theta)**43 - 1.83216109608277e+97*cos(theta)**41 + 8.78580174729749e+96*cos(theta)**39 - 3.50203286430739e+96*cos(theta)**37 + 1.16384924532371e+96*cos(theta)**35 - 3.22839301150401e+95*cos(theta)**33 + 7.46972616158684e+94*cos(theta)**31 - 1.43827025471548e+94*cos(theta)**29 + 2.29535268637769e+93*cos(theta)**27 - 3.01861668384627e+92*cos(theta)**25 + 3.24582439123255e+91*cos(theta)**23 - 2.82488328511123e+90*cos(theta)**21 + 1.96432281415019e+89*cos(theta)**19 - 1.07350335960269e+88*cos(theta)**17 + 4.51442352832302e+86*cos(theta)**15 - 1.42133274504923e+85*cos(theta)**13 + 3.23030169329369e+83*cos(theta)**11 - 5.04018703918165e+81*cos(theta)**9 + 5.02066224157552e+79*cos(theta)**7 - 2.85033541695285e+77*cos(theta)**5 + 7.54056988611866e+74*cos(theta)**3 - 5.86510491531137e+71*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl95_m_minus_35(theta, phi):
    return 6.25413996102351e-69*(1.0 - cos(theta)**2)**17.5*(2.84292877544918e+93*cos(theta)**60 - 2.66242536113495e+94*cos(theta)**58 + 1.17673505934654e+95*cos(theta)**56 - 3.26517475926789e+95*cos(theta)**54 + 6.38314901709337e+95*cos(theta)**52 - 9.3525476206252e+95*cos(theta)**50 + 1.06674775002475e+96*cos(theta)**48 - 9.71179549659341e+95*cos(theta)**46 + 7.17979167069584e+95*cos(theta)**44 - 4.36228832400659e+95*cos(theta)**42 + 2.19645043682437e+95*cos(theta)**40 - 9.21587595870366e+94*cos(theta)**38 + 3.23291457034365e+94*cos(theta)**36 - 9.49527356324708e+93*cos(theta)**34 + 2.33428942549589e+93*cos(theta)**32 - 4.79423418238493e+92*cos(theta)**30 + 8.1976881656346e+91*cos(theta)**28 - 1.16100641686395e+91*cos(theta)**26 + 1.35242682968023e+90*cos(theta)**24 - 1.28403785686874e+89*cos(theta)**22 + 9.82161407075096e+87*cos(theta)**20 - 5.9639075533483e+86*cos(theta)**18 + 2.82151470520188e+85*cos(theta)**16 - 1.01523767503516e+84*cos(theta)**14 + 2.69191807774475e+82*cos(theta)**12 - 5.04018703918165e+80*cos(theta)**10 + 6.2758278019694e+78*cos(theta)**8 - 4.75055902825475e+76*cos(theta)**6 + 1.88514247152966e+74*cos(theta)**4 - 2.93255245765569e+71*cos(theta)**2 + 7.46196554110862e+67)*sin(35*phi)

#@torch.jit.script
def Yl95_m_minus_34(theta, phi):
    return 5.56934587317868e-67*(1.0 - cos(theta)**2)**17*(4.6605389761462e+91*cos(theta)**61 - 4.51258535785585e+92*cos(theta)**59 + 2.0644474725378e+93*cos(theta)**57 - 5.93668138048706e+93*cos(theta)**55 + 1.20436773907422e+94*cos(theta)**53 - 1.83383286678925e+94*cos(theta)**51 + 2.17703622454032e+94*cos(theta)**49 - 2.0663394673603e+94*cos(theta)**47 + 1.59550926015463e+94*cos(theta)**45 - 1.01448565674572e+94*cos(theta)**43 + 5.35719618737652e+93*cos(theta)**41 - 2.36304511761632e+93*cos(theta)**39 + 8.73760694687473e+92*cos(theta)**37 - 2.71293530378488e+92*cos(theta)**35 + 7.07360431968451e+91*cos(theta)**33 - 1.54652715560804e+91*cos(theta)**31 + 2.82678902263262e+90*cos(theta)**29 - 4.30002376616277e+89*cos(theta)**27 + 5.40970731872091e+88*cos(theta)**25 - 5.58277329073365e+87*cos(theta)**23 + 4.67695908130998e+86*cos(theta)**21 - 3.13889871228858e+85*cos(theta)**19 + 1.6597145324717e+84*cos(theta)**17 - 6.76825116690107e+82*cos(theta)**15 + 2.0707062136498e+81*cos(theta)**13 - 4.58198821743786e+79*cos(theta)**11 + 6.97314200218823e+77*cos(theta)**9 - 6.78651289750679e+75*cos(theta)**7 + 3.77028494305933e+73*cos(theta)**5 - 9.77517485885229e+70*cos(theta)**3 + 7.46196554110862e+67*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl95_m_minus_33(theta, phi):
    return 4.9807516743342e-65*(1.0 - cos(theta)**2)**16.5*(7.51699834862291e+89*cos(theta)**62 - 7.52097559642641e+90*cos(theta)**60 + 3.55939219403068e+91*cos(theta)**58 - 1.06012167508698e+92*cos(theta)**56 + 2.23031062791522e+92*cos(theta)**54 - 3.52660166690241e+92*cos(theta)**52 + 4.35407244908063e+92*cos(theta)**50 - 4.30487389033396e+92*cos(theta)**48 + 3.4684983916405e+92*cos(theta)**46 - 2.30564921987664e+92*cos(theta)**44 + 1.27552290175631e+92*cos(theta)**42 - 5.90761279404081e+91*cos(theta)**40 + 2.29937024917756e+91*cos(theta)**38 - 7.53593139940245e+90*cos(theta)**36 + 2.08047185873074e+90*cos(theta)**34 - 4.83289736127513e+89*cos(theta)**32 + 9.42263007544207e+88*cos(theta)**30 - 1.53572277362956e+88*cos(theta)**28 + 2.0806566610465e+87*cos(theta)**26 - 2.32615553780569e+86*cos(theta)**24 + 2.12589049150454e+85*cos(theta)**22 - 1.56944935614429e+84*cos(theta)**20 + 9.22063629150943e+82*cos(theta)**18 - 4.23015697931317e+81*cos(theta)**16 + 1.47907586689272e+80*cos(theta)**14 - 3.81832351453155e+78*cos(theta)**12 + 6.97314200218823e+76*cos(theta)**10 - 8.48314112188349e+74*cos(theta)**8 + 6.28380823843221e+72*cos(theta)**6 - 2.44379371471307e+70*cos(theta)**4 + 3.73098277055431e+67*cos(theta)**2 - 9.3297893737292e+63)*sin(33*phi)

#@torch.jit.script
def Yl95_m_minus_32(theta, phi):
    return 4.47270391055021e-63*(1.0 - cos(theta)**2)**16*(1.19317434105126e+88*cos(theta)**63 - 1.2329468190863e+89*cos(theta)**61 + 6.03286812547573e+89*cos(theta)**59 - 1.85986258787189e+90*cos(theta)**57 + 4.05511023257313e+90*cos(theta)**55 - 6.65396540924984e+90*cos(theta)**53 + 8.53739695898163e+90*cos(theta)**51 - 8.78545691904889e+90*cos(theta)**49 + 7.37978381200107e+90*cos(theta)**47 - 5.12366493305919e+90*cos(theta)**45 + 2.96633232966585e+90*cos(theta)**43 - 1.44088116927825e+90*cos(theta)**41 + 5.89582115173733e+89*cos(theta)**39 - 2.03673821605472e+89*cos(theta)**37 + 5.94420531065925e+88*cos(theta)**35 - 1.46451435190155e+88*cos(theta)**33 + 3.03955808885228e+87*cos(theta)**31 - 5.29559577113642e+86*cos(theta)**29 + 7.70613578165372e+85*cos(theta)**27 - 9.30462215122275e+84*cos(theta)**25 + 9.24300213697625e+83*cos(theta)**23 - 7.47356836259185e+82*cos(theta)**21 + 4.85296646921549e+81*cos(theta)**19 - 2.4883276348901e+80*cos(theta)**17 + 9.86050577928478e+78*cos(theta)**15 - 2.93717193425504e+77*cos(theta)**13 + 6.3392200019893e+75*cos(theta)**11 - 9.42571235764832e+73*cos(theta)**9 + 8.97686891204602e+71*cos(theta)**7 - 4.88758742942614e+69*cos(theta)**5 + 1.2436609235181e+67*cos(theta)**3 - 9.3297893737292e+63*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl95_m_minus_31(theta, phi):
    return 4.03238505659312e-61*(1.0 - cos(theta)**2)**15.5*(1.86433490789259e+86*cos(theta)**64 - 1.98862390175209e+87*cos(theta)**62 + 1.00547802091262e+88*cos(theta)**60 - 3.20665963426188e+88*cos(theta)**58 + 7.24126827245202e+88*cos(theta)**56 - 1.23221581652775e+89*cos(theta)**54 + 1.64180710749647e+89*cos(theta)**52 - 1.75709138380978e+89*cos(theta)**50 + 1.53745496083356e+89*cos(theta)**48 - 1.11384020283895e+89*cos(theta)**46 + 6.7416643856042e+88*cos(theta)**44 - 3.43066945066249e+88*cos(theta)**42 + 1.47395528793433e+88*cos(theta)**40 - 5.3598374106703e+87*cos(theta)**38 + 1.65116814184979e+87*cos(theta)**36 - 4.30739515265163e+86*cos(theta)**34 + 9.49861902766338e+85*cos(theta)**32 - 1.76519859037881e+85*cos(theta)**30 + 2.75219135059061e+84*cos(theta)**28 - 3.57870082739337e+83*cos(theta)**26 + 3.85125089040677e+82*cos(theta)**24 - 3.39707652845084e+81*cos(theta)**22 + 2.42648323460774e+80*cos(theta)**20 - 1.38240424160561e+79*cos(theta)**18 + 6.16281611205299e+77*cos(theta)**16 - 2.09797995303932e+76*cos(theta)**14 + 5.28268333499108e+74*cos(theta)**12 - 9.42571235764832e+72*cos(theta)**10 + 1.12210861400575e+71*cos(theta)**8 - 8.14597904904357e+68*cos(theta)**6 + 3.10915230879526e+66*cos(theta)**4 - 4.6648946868646e+63*cos(theta)**2 + 1.14785794460251e+60)*sin(31*phi)

#@torch.jit.script
def Yl95_m_minus_30(theta, phi):
    return 3.64925277986555e-59*(1.0 - cos(theta)**2)**15*(2.86820755060398e+84*cos(theta)**65 - 3.15654587579697e+85*cos(theta)**63 + 1.64832462444692e+86*cos(theta)**61 - 5.43501632925742e+86*cos(theta)**59 + 1.27039794253544e+87*cos(theta)**57 - 2.24039239368681e+87*cos(theta)**55 + 3.0977492594273e+87*cos(theta)**53 - 3.44527722315643e+87*cos(theta)**51 + 3.13766318537461e+87*cos(theta)**49 - 2.36987277199778e+87*cos(theta)**47 + 1.49814764124538e+87*cos(theta)**45 - 7.9783010480523e+86*cos(theta)**43 + 3.59501289740081e+86*cos(theta)**41 - 1.37431728478726e+86*cos(theta)**39 + 4.46261659959403e+85*cos(theta)**37 - 1.23068432932904e+85*cos(theta)**35 + 2.87836940232224e+84*cos(theta)**33 - 5.69418900122196e+83*cos(theta)**31 + 9.4903150020366e+82*cos(theta)**29 - 1.32544475088643e+82*cos(theta)**27 + 1.54050035616271e+81*cos(theta)**25 - 1.47698979497863e+80*cos(theta)**23 + 1.15546820695607e+79*cos(theta)**21 - 7.27581179792427e+77*cos(theta)**19 + 3.62518594826646e+76*cos(theta)**17 - 1.39865330202621e+75*cos(theta)**15 + 4.06360256537775e+73*cos(theta)**13 - 8.56882941604393e+71*cos(theta)**11 + 1.24678734889528e+70*cos(theta)**9 - 1.16371129272051e+68*cos(theta)**7 + 6.21830461759051e+65*cos(theta)**5 - 1.55496489562153e+63*cos(theta)**3 + 1.14785794460251e+60*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl95_m_minus_29(theta, phi):
    return 3.31459844134536e-57*(1.0 - cos(theta)**2)**14.5*(4.34576901606663e+82*cos(theta)**66 - 4.93210293093277e+83*cos(theta)**64 + 2.65858810394665e+84*cos(theta)**62 - 9.05836054876236e+84*cos(theta)**60 + 2.19034128023352e+85*cos(theta)**58 - 4.00070070301217e+85*cos(theta)**56 + 5.73657270264314e+85*cos(theta)**54 - 6.62553312145467e+85*cos(theta)**52 + 6.27532637074921e+85*cos(theta)**50 - 4.93723494166203e+85*cos(theta)**48 + 3.25684269835952e+85*cos(theta)**46 - 1.81325023819371e+85*cos(theta)**44 + 8.55955451762098e+84*cos(theta)**42 - 3.43579321196814e+84*cos(theta)**40 + 1.17437278936685e+84*cos(theta)**38 - 3.41856758146955e+83*cos(theta)**36 + 8.46579235977128e+82*cos(theta)**34 - 1.77943406288186e+82*cos(theta)**32 + 3.1634383340122e+81*cos(theta)**30 - 4.73373125316583e+80*cos(theta)**28 + 5.92500136985657e+79*cos(theta)**26 - 6.15412414574428e+78*cos(theta)**24 + 5.25212821343668e+77*cos(theta)**22 - 3.63790589896214e+76*cos(theta)**20 + 2.01399219348137e+75*cos(theta)**18 - 8.74158313766381e+73*cos(theta)**16 + 2.90257326098411e+72*cos(theta)**14 - 7.14069118003661e+70*cos(theta)**12 + 1.24678734889528e+69*cos(theta)**10 - 1.45463911590064e+67*cos(theta)**8 + 1.03638410293175e+65*cos(theta)**6 - 3.88741223905384e+62*cos(theta)**4 + 5.73928972301255e+59*cos(theta)**2 - 1.39134296315456e+56)*sin(29*phi)

#@torch.jit.script
def Yl95_m_minus_28(theta, phi):
    return 3.02119784141626e-55*(1.0 - cos(theta)**2)**14*(6.48622241203975e+80*cos(theta)**67 - 7.58785066297349e+81*cos(theta)**65 + 4.21998111737563e+82*cos(theta)**63 - 1.48497713914137e+83*cos(theta)**61 + 3.71244284785343e+83*cos(theta)**59 - 7.01877316317924e+83*cos(theta)**57 + 1.04301321866239e+84*cos(theta)**55 - 1.25010058895371e+84*cos(theta)**53 + 1.2304561511273e+84*cos(theta)**51 - 1.00759896768613e+84*cos(theta)**49 + 6.9294525497011e+83*cos(theta)**47 - 4.02944497376379e+83*cos(theta)**45 + 1.99059407386535e+83*cos(theta)**43 - 8.37998344382474e+82*cos(theta)**41 + 3.01121228042782e+82*cos(theta)**39 - 9.23937184180959e+81*cos(theta)**37 + 2.41879781707751e+81*cos(theta)**35 - 5.39222443297534e+80*cos(theta)**33 + 1.02046397871361e+80*cos(theta)**31 - 1.63232112178132e+79*cos(theta)**29 + 2.19444495179873e+78*cos(theta)**27 - 2.46164965829771e+77*cos(theta)**25 + 2.28353400584203e+76*cos(theta)**23 - 1.73233614236292e+75*cos(theta)**21 + 1.05999589130598e+74*cos(theta)**19 - 5.14210772803754e+72*cos(theta)**17 + 1.93504884065607e+71*cos(theta)**15 - 5.49283936925893e+69*cos(theta)**13 + 1.13344304445025e+68*cos(theta)**11 - 1.61626568433404e+66*cos(theta)**9 + 1.48054871847393e+64*cos(theta)**7 - 7.77482447810767e+61*cos(theta)**5 + 1.91309657433752e+59*cos(theta)**3 - 1.39134296315456e+56*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl95_m_minus_27(theta, phi):
    return 2.76303367377826e-53*(1.0 - cos(theta)**2)**13.5*(9.53856237064669e+78*cos(theta)**68 - 1.14967434287477e+80*cos(theta)**66 + 6.59372049589942e+80*cos(theta)**64 - 2.39512441796995e+81*cos(theta)**62 + 6.18740474642238e+81*cos(theta)**60 - 1.21013330399642e+82*cos(theta)**58 + 1.86252360475427e+82*cos(theta)**56 - 2.31500109065502e+82*cos(theta)**54 + 2.36626182909095e+82*cos(theta)**52 - 2.01519793537226e+82*cos(theta)**50 + 1.4436359478544e+82*cos(theta)**48 - 8.75966298644302e+81*cos(theta)**46 + 4.52407744060306e+81*cos(theta)**44 - 1.9952341532916e+81*cos(theta)**42 + 7.52803070106955e+80*cos(theta)**40 - 2.43141364258147e+80*cos(theta)**38 + 6.7188828252153e+79*cos(theta)**36 - 1.58594836263981e+79*cos(theta)**34 + 3.18894993348004e+78*cos(theta)**32 - 5.44107040593774e+77*cos(theta)**30 + 7.83730339928118e+76*cos(theta)**28 - 9.46788330114504e+75*cos(theta)**26 + 9.5147250243418e+74*cos(theta)**24 - 7.87425519255873e+73*cos(theta)**22 + 5.29997945652992e+72*cos(theta)**20 - 2.85672651557641e+71*cos(theta)**18 + 1.20940552541005e+70*cos(theta)**16 - 3.92345669232781e+68*cos(theta)**14 + 9.44535870375212e+66*cos(theta)**12 - 1.61626568433404e+65*cos(theta)**10 + 1.85068589809242e+63*cos(theta)**8 - 1.29580407968461e+61*cos(theta)**6 + 4.78274143584379e+58*cos(theta)**4 - 6.95671481577279e+55*cos(theta)**2 + 1.66348991290598e+52)*sin(27*phi)

#@torch.jit.script
def Yl95_m_minus_26(theta, phi):
    return 2.53507398479645e-51*(1.0 - cos(theta)**2)**13*(1.38240034357198e+77*cos(theta)**69 - 1.71593185503697e+78*cos(theta)**67 + 1.01441853783068e+79*cos(theta)**65 - 3.8017847904285e+79*cos(theta)**63 + 1.01432864695449e+80*cos(theta)**61 - 2.0510733966041e+80*cos(theta)**59 + 3.26758527149871e+80*cos(theta)**57 - 4.20909289210004e+80*cos(theta)**55 + 4.46464496054897e+80*cos(theta)**53 - 3.95136850072992e+80*cos(theta)**51 + 2.94619581194775e+80*cos(theta)**49 - 1.86375808222192e+80*cos(theta)**47 + 1.00535054235623e+80*cos(theta)**45 - 4.64007942625955e+79*cos(theta)**43 + 1.83610504904135e+79*cos(theta)**41 - 6.2343939553371e+78*cos(theta)**39 + 1.81591427708522e+78*cos(theta)**37 - 4.53128103611373e+77*cos(theta)**35 + 9.66348464690921e+76*cos(theta)**33 - 1.7551840019154e+76*cos(theta)**31 + 2.70251841354523e+75*cos(theta)**29 - 3.50662344486853e+74*cos(theta)**27 + 3.80589000973672e+73*cos(theta)**25 - 3.42358921415597e+72*cos(theta)**23 + 2.52379974120472e+71*cos(theta)**21 - 1.503540271356e+70*cos(theta)**19 + 7.11415014947086e+68*cos(theta)**17 - 2.6156377948852e+67*cos(theta)**15 + 7.26566054134779e+65*cos(theta)**13 - 1.46933244030367e+64*cos(theta)**11 + 2.05631766454713e+62*cos(theta)**9 - 1.85114868526373e+60*cos(theta)**7 + 9.56548287168759e+57*cos(theta)**5 - 2.31890493859093e+55*cos(theta)**3 + 1.66348991290598e+52*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl95_m_minus_25(theta, phi):
    return 2.33309457412421e-49*(1.0 - cos(theta)**2)**12.5*(1.97485763367426e+75*cos(theta)**70 - 2.52342919858378e+76*cos(theta)**68 + 1.53699778459194e+77*cos(theta)**66 - 5.94028873504452e+77*cos(theta)**64 + 1.63601394670079e+78*cos(theta)**62 - 3.41845566100684e+78*cos(theta)**60 + 5.63376770948054e+78*cos(theta)**58 - 7.5162373073215e+78*cos(theta)**56 + 8.26786103805365e+78*cos(theta)**54 - 7.59878557832676e+78*cos(theta)**52 + 5.89239162389549e+78*cos(theta)**50 - 3.88282933796233e+78*cos(theta)**48 + 2.18554465729616e+78*cos(theta)**46 - 1.05456350596808e+78*cos(theta)**44 + 4.3716786881937e+77*cos(theta)**42 - 1.55859848883428e+77*cos(theta)**40 + 4.7787217818032e+76*cos(theta)**38 - 1.25868917669826e+76*cos(theta)**36 + 2.842201366738e+75*cos(theta)**34 - 5.48495000598562e+74*cos(theta)**32 + 9.00839471181744e+73*cos(theta)**30 - 1.25236551602448e+73*cos(theta)**28 + 1.46380384989874e+72*cos(theta)**26 - 1.42649550589832e+71*cos(theta)**24 + 1.1471817005476e+70*cos(theta)**22 - 7.51770135678002e+68*cos(theta)**20 + 3.95230563859492e+67*cos(theta)**18 - 1.63477362180325e+66*cos(theta)**16 + 5.18975752953413e+64*cos(theta)**14 - 1.22444370025306e+63*cos(theta)**12 + 2.05631766454713e+61*cos(theta)**10 - 2.31393585657966e+59*cos(theta)**8 + 1.59424714528126e+57*cos(theta)**6 - 5.79726234647733e+54*cos(theta)**4 + 8.31744956452988e+51*cos(theta)**2 - 1.96397864569773e+48)*sin(25*phi)

#@torch.jit.script
def Yl95_m_minus_24(theta, phi):
    return 2.1535360244538e-47*(1.0 - cos(theta)**2)**12*(2.78148962489333e+73*cos(theta)**71 - 3.65714376606345e+74*cos(theta)**69 + 2.29402654416707e+75*cos(theta)**67 - 9.13890574622234e+75*cos(theta)**65 + 2.59684753444569e+76*cos(theta)**63 - 5.6040256737817e+76*cos(theta)**61 + 9.54875882962804e+76*cos(theta)**59 - 1.31863812409149e+77*cos(theta)**57 + 1.5032474614643e+77*cos(theta)**55 - 1.43373312798618e+77*cos(theta)**53 + 1.15537090664617e+77*cos(theta)**51 - 7.92414150604558e+76*cos(theta)**49 + 4.65009501552375e+76*cos(theta)**47 - 2.34347445770684e+76*cos(theta)**45 + 1.01666946237063e+76*cos(theta)**43 - 3.80145972886409e+75*cos(theta)**41 + 1.22531327738544e+75*cos(theta)**39 - 3.40186263972502e+74*cos(theta)**37 + 8.12057533353715e+73*cos(theta)**35 - 1.66210606241988e+73*cos(theta)**33 + 2.90593377800563e+72*cos(theta)**31 - 4.31850177939475e+71*cos(theta)**29 + 5.4214957403657e+70*cos(theta)**27 - 5.70598202359329e+69*cos(theta)**25 + 4.98774652412001e+68*cos(theta)**23 - 3.57985778894287e+67*cos(theta)**21 + 2.08016086241838e+66*cos(theta)**19 - 9.61631542237207e+64*cos(theta)**17 + 3.45983835302276e+63*cos(theta)**15 - 9.41879769425433e+61*cos(theta)**13 + 1.86937969504284e+60*cos(theta)**11 - 2.57103984064407e+58*cos(theta)**9 + 2.27749592183038e+56*cos(theta)**7 - 1.15945246929546e+54*cos(theta)**5 + 2.77248318817663e+51*cos(theta)**3 - 1.96397864569773e+48*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl95_m_minus_23(theta, phi):
    return 1.99338813975248e-45*(1.0 - cos(theta)**2)**11.5*(3.86318003457407e+71*cos(theta)**72 - 5.22449109437636e+72*cos(theta)**70 + 3.37356844730452e+73*cos(theta)**68 - 1.38468268882157e+74*cos(theta)**66 + 4.0575742725714e+74*cos(theta)**64 - 9.03875108674468e+74*cos(theta)**62 + 1.59145980493801e+75*cos(theta)**60 - 2.27351400705429e+75*cos(theta)**58 + 2.68437046690053e+75*cos(theta)**56 - 2.65506134812256e+75*cos(theta)**54 + 2.22186712816572e+75*cos(theta)**52 - 1.58482830120912e+75*cos(theta)**50 + 9.68769794900781e+74*cos(theta)**48 - 5.09450969066705e+74*cos(theta)**46 + 2.3106124144787e+74*cos(theta)**44 - 9.05109459253354e+73*cos(theta)**42 + 3.06328319346359e+73*cos(theta)**40 - 8.95227010453954e+72*cos(theta)**38 + 2.25571537042699e+72*cos(theta)**36 - 4.88854724241143e+71*cos(theta)**34 + 9.08104305626758e+70*cos(theta)**32 - 1.43950059313158e+70*cos(theta)**30 + 1.93624847870204e+69*cos(theta)**28 - 2.1946084706128e+68*cos(theta)**26 + 2.07822771838334e+67*cos(theta)**24 - 1.62720808588312e+66*cos(theta)**22 + 1.04008043120919e+65*cos(theta)**20 - 5.34239745687337e+63*cos(theta)**18 + 2.16239897063922e+62*cos(theta)**16 - 6.72771263875309e+60*cos(theta)**14 + 1.5578164125357e+59*cos(theta)**12 - 2.57103984064407e+57*cos(theta)**10 + 2.84686990228797e+55*cos(theta)**8 - 1.93242078215911e+53*cos(theta)**6 + 6.93120797044157e+50*cos(theta)**4 - 9.81989322848864e+47*cos(theta)**2 + 2.29222531010472e+44)*sin(23*phi)

#@torch.jit.script
def Yl95_m_minus_22(theta, phi):
    return 1.85009616828234e-43*(1.0 - cos(theta)**2)**11*(5.29202744462201e+69*cos(theta)**73 - 7.35843816109346e+70*cos(theta)**71 + 4.88922963377467e+71*cos(theta)**69 - 2.0666905803307e+72*cos(theta)**67 + 6.24242195780215e+72*cos(theta)**65 - 1.43472239472138e+73*cos(theta)**63 + 2.60895049989837e+73*cos(theta)**61 - 3.85341357127847e+73*cos(theta)**59 + 4.70942187175532e+73*cos(theta)**57 - 4.82738426931374e+73*cos(theta)**55 + 4.19220212861457e+73*cos(theta)**53 - 3.10750647295905e+73*cos(theta)**51 + 1.97708121408323e+73*cos(theta)**49 - 1.08393823205682e+73*cos(theta)**47 + 5.13469425439711e+72*cos(theta)**45 - 2.10490571919385e+72*cos(theta)**43 + 7.47142242308193e+71*cos(theta)**41 - 2.29545387295886e+71*cos(theta)**39 + 6.09652802818105e+70*cos(theta)**37 - 1.39672778354612e+70*cos(theta)**35 + 2.751831229172e+69*cos(theta)**33 - 4.64355030042446e+68*cos(theta)**31 + 6.67671889207599e+67*cos(theta)**29 - 8.12817952078816e+66*cos(theta)**27 + 8.31291087353334e+65*cos(theta)**25 - 7.07481776470923e+64*cos(theta)**23 + 4.952763958139e+63*cos(theta)**21 - 2.81178813519651e+62*cos(theta)**19 + 1.27199939449366e+61*cos(theta)**17 - 4.48514175916873e+59*cos(theta)**15 + 1.19832031733516e+58*cos(theta)**13 - 2.33730894604006e+56*cos(theta)**11 + 3.16318878031997e+54*cos(theta)**9 - 2.76060111737016e+52*cos(theta)**7 + 1.38624159408831e+50*cos(theta)**5 - 3.27329774282955e+47*cos(theta)**3 + 2.29222531010472e+44*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl95_m_minus_21(theta, phi):
    return 1.72148441156258e-41*(1.0 - cos(theta)**2)**10.5*(7.15138843867839e+67*cos(theta)**74 - 1.02200530015187e+69*cos(theta)**72 + 6.98461376253524e+69*cos(theta)**70 - 3.0392508534275e+70*cos(theta)**68 + 9.45821508757901e+70*cos(theta)**66 - 2.24175374175215e+71*cos(theta)**64 + 4.20798467725544e+71*cos(theta)**62 - 6.42235595213078e+71*cos(theta)**60 + 8.11969288233677e+71*cos(theta)**58 - 8.62032905234597e+71*cos(theta)**56 + 7.76333727521216e+71*cos(theta)**54 - 5.97597398645971e+71*cos(theta)**52 + 3.95416242816646e+71*cos(theta)**50 - 2.25820465011837e+71*cos(theta)**48 + 1.11623788139068e+71*cos(theta)**46 - 4.78387663453147e+70*cos(theta)**44 + 1.77891010073379e+70*cos(theta)**42 - 5.73863468239714e+69*cos(theta)**40 + 1.60434948110028e+69*cos(theta)**38 - 3.87979939873923e+68*cos(theta)**36 + 8.09362126227057e+67*cos(theta)**34 - 1.45110946888264e+67*cos(theta)**32 + 2.22557296402533e+66*cos(theta)**30 - 2.90292125742434e+65*cos(theta)**28 + 3.19727341289744e+64*cos(theta)**26 - 2.94784073529551e+63*cos(theta)**24 + 2.25125634460864e+62*cos(theta)**22 - 1.40589406759826e+61*cos(theta)**20 + 7.06666330274256e+59*cos(theta)**18 - 2.80321359948045e+58*cos(theta)**16 + 8.55943083810826e+56*cos(theta)**14 - 1.94775745503339e+55*cos(theta)**12 + 3.16318878031997e+53*cos(theta)**10 - 3.45075139671269e+51*cos(theta)**8 + 2.31040265681386e+49*cos(theta)**6 - 8.18324435707387e+46*cos(theta)**4 + 1.14611265505236e+44*cos(theta)**2 - 2.64752288069384e+40)*sin(21*phi)

#@torch.jit.script
def Yl95_m_minus_20(theta, phi):
    return 1.60569376406278e-39*(1.0 - cos(theta)**2)**10*(9.53518458490452e+65*cos(theta)**75 - 1.40000726048201e+67*cos(theta)**73 + 9.83748417258484e+67*cos(theta)**71 - 4.40471138177898e+68*cos(theta)**69 + 1.41167389366851e+69*cos(theta)**67 - 3.44885191038793e+69*cos(theta)**65 + 6.67934075754831e+69*cos(theta)**63 - 1.05284523805423e+70*cos(theta)**61 + 1.37621913259945e+70*cos(theta)**59 - 1.51233843023614e+70*cos(theta)**57 + 1.41151586822039e+70*cos(theta)**55 - 1.12754226159617e+70*cos(theta)**53 + 7.75325966307148e+69*cos(theta)**51 - 4.60858091860892e+69*cos(theta)**49 + 2.37497421572484e+69*cos(theta)**47 - 1.06308369656255e+69*cos(theta)**45 + 4.13700023426464e+68*cos(theta)**43 - 1.39966699570662e+68*cos(theta)**41 + 4.11371661820583e+67*cos(theta)**39 - 1.04859443209168e+67*cos(theta)**37 + 2.31246321779159e+66*cos(theta)**35 - 4.3973014208565e+65*cos(theta)**33 + 7.17926762588816e+64*cos(theta)**31 - 1.00100733014632e+64*cos(theta)**29 + 1.18417533811016e+63*cos(theta)**27 - 1.1791362941182e+62*cos(theta)**25 + 9.78807106351581e+60*cos(theta)**23 - 6.69473365522979e+59*cos(theta)**21 + 3.71929647512766e+58*cos(theta)**19 - 1.64894917616497e+57*cos(theta)**17 + 5.70628722540551e+55*cos(theta)**15 - 1.4982749654103e+54*cos(theta)**13 + 2.87562616392724e+52*cos(theta)**11 - 3.83416821856966e+50*cos(theta)**9 + 3.30057522401979e+48*cos(theta)**7 - 1.63664887141477e+46*cos(theta)**5 + 3.82037551684121e+43*cos(theta)**3 - 2.64752288069384e+40*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl95_m_minus_19(theta, phi):
    return 1.50113045851864e-37*(1.0 - cos(theta)**2)**9.5*(1.25462955064533e+64*cos(theta)**76 - 1.89190170335407e+65*cos(theta)**74 + 1.36631724619234e+66*cos(theta)**72 - 6.29244483111283e+66*cos(theta)**70 + 2.07599102010075e+67*cos(theta)**68 - 5.22553319755747e+67*cos(theta)**66 + 1.04364699336692e+68*cos(theta)**64 - 1.69813748073262e+68*cos(theta)**62 + 2.29369855433242e+68*cos(theta)**60 - 2.60748005213127e+68*cos(theta)**58 + 2.52056405039356e+68*cos(theta)**56 - 2.0880412251781e+68*cos(theta)**54 + 1.49101147366759e+68*cos(theta)**52 - 9.21716183721784e+67*cos(theta)**50 + 4.94786294942676e+67*cos(theta)**48 - 2.31105151426641e+67*cos(theta)**46 + 9.40227325969235e+66*cos(theta)**44 - 3.33254046596814e+66*cos(theta)**42 + 1.02842915455146e+66*cos(theta)**40 - 2.75945903182022e+65*cos(theta)**38 + 6.42350893830998e+64*cos(theta)**36 - 1.29332394731073e+64*cos(theta)**34 + 2.24352113309005e+63*cos(theta)**32 - 3.33669110048775e+62*cos(theta)**30 + 4.22919763610772e+61*cos(theta)**28 - 4.53513959276232e+60*cos(theta)**26 + 4.07836294313159e+59*cos(theta)**24 - 3.04306075237718e+58*cos(theta)**22 + 1.85964823756383e+57*cos(theta)**20 - 9.16082875647207e+55*cos(theta)**18 + 3.56642951587844e+54*cos(theta)**16 - 1.0701964038645e+53*cos(theta)**14 + 2.39635513660604e+51*cos(theta)**12 - 3.83416821856966e+49*cos(theta)**10 + 4.12571903002474e+47*cos(theta)**8 - 2.72774811902462e+45*cos(theta)**6 + 9.55093879210302e+42*cos(theta)**4 - 1.32376144034692e+40*cos(theta)**2 + 3.02920238065656e+36)*sin(19*phi)

#@torch.jit.script
def Yl95_m_minus_18(theta, phi):
    return 1.4064238590253e-35*(1.0 - cos(theta)**2)**9*(1.62938902681212e+62*cos(theta)**77 - 2.5225356044721e+63*cos(theta)**75 + 1.87166746053745e+64*cos(theta)**73 - 8.86259835368004e+64*cos(theta)**71 + 3.00868263782717e+65*cos(theta)**69 - 7.79930327993651e+65*cos(theta)**67 + 1.60561075902604e+66*cos(theta)**65 - 2.69545631862321e+66*cos(theta)**63 + 3.76016156447938e+66*cos(theta)**61 - 4.41945771547672e+66*cos(theta)**59 + 4.42204219367291e+66*cos(theta)**57 - 3.7964385912329e+66*cos(theta)**55 + 2.81322919559923e+66*cos(theta)**53 - 1.8072866347486e+66*cos(theta)**51 + 1.0097679488626e+66*cos(theta)**49 - 4.91713088141789e+65*cos(theta)**47 + 2.08939405770941e+65*cos(theta)**45 - 7.75009410690265e+64*cos(theta)**43 + 2.50836379158892e+64*cos(theta)**41 - 7.0755359790262e+63*cos(theta)**39 + 1.73608349684054e+63*cos(theta)**37 - 3.69521127803067e+62*cos(theta)**35 + 6.79854888815166e+61*cos(theta)**33 - 1.07635196789927e+61*cos(theta)**31 + 1.45834401245094e+60*cos(theta)**29 - 1.67968133065271e+59*cos(theta)**27 + 1.63134517725263e+58*cos(theta)**25 - 1.3230698923379e+57*cos(theta)**23 + 8.855467797923e+55*cos(theta)**21 - 4.82148881919583e+54*cos(theta)**19 + 2.09789971522261e+53*cos(theta)**17 - 7.13464269242999e+51*cos(theta)**15 + 1.84335010508157e+50*cos(theta)**13 - 3.48560747142696e+48*cos(theta)**11 + 4.58413225558305e+46*cos(theta)**9 - 3.89678302717803e+44*cos(theta)**7 + 1.9101877584206e+42*cos(theta)**5 - 4.41253813448973e+39*cos(theta)**3 + 3.02920238065656e+36*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl95_m_minus_17(theta, phi):
    return 1.32039158660871e-33*(1.0 - cos(theta)**2)**8.5*(2.08896029078477e+60*cos(theta)**78 - 3.31912579535802e+61*cos(theta)**76 + 2.52928035207764e+62*cos(theta)**74 - 1.23091643801112e+63*cos(theta)**72 + 4.29811805403882e+63*cos(theta)**70 - 1.14695636469655e+64*cos(theta)**68 + 2.43274357428187e+64*cos(theta)**66 - 4.21165049784876e+64*cos(theta)**64 + 6.06477671690222e+64*cos(theta)**62 - 7.36576285912787e+64*cos(theta)**60 + 7.6242106787464e+64*cos(theta)**58 - 6.77935462720161e+64*cos(theta)**56 + 5.20968369555413e+64*cos(theta)**54 - 3.47555122067038e+64*cos(theta)**52 + 2.01953589772521e+64*cos(theta)**50 - 1.02440226696206e+64*cos(theta)**48 + 4.54216099502046e+63*cos(theta)**46 - 1.76138502429606e+63*cos(theta)**44 + 5.97229474187839e+62*cos(theta)**42 - 1.76888399475655e+62*cos(theta)**40 + 4.5686407811593e+61*cos(theta)**38 - 1.02644757723074e+61*cos(theta)**36 + 1.99957320239755e+60*cos(theta)**34 - 3.36359989968523e+59*cos(theta)**32 + 4.8611467081698e+58*cos(theta)**30 - 5.99886189518826e+57*cos(theta)**28 + 6.27440452789475e+56*cos(theta)**26 - 5.5127912180746e+55*cos(theta)**24 + 4.02521263541955e+54*cos(theta)**22 - 2.41074440959791e+53*cos(theta)**20 + 1.16549984179034e+52*cos(theta)**18 - 4.45915168276874e+50*cos(theta)**16 + 1.31667864648683e+49*cos(theta)**14 - 2.9046728928558e+47*cos(theta)**12 + 4.58413225558305e+45*cos(theta)**10 - 4.87097878397254e+43*cos(theta)**8 + 3.18364626403434e+41*cos(theta)**6 - 1.10313453362243e+39*cos(theta)**4 + 1.51460119032828e+36*cos(theta)**2 - 3.4368077838173e+32)*sin(17*phi)

#@torch.jit.script
def Yl95_m_minus_16(theta, phi):
    return 1.24201060859807e-31*(1.0 - cos(theta)**2)**8*(2.64425353263895e+58*cos(theta)**79 - 4.31055298098444e+59*cos(theta)**77 + 3.37237380277018e+60*cos(theta)**75 - 1.68618690138509e+61*cos(theta)**73 + 6.05368740005467e+61*cos(theta)**71 - 1.66225560100949e+62*cos(theta)**69 + 3.63096055862966e+62*cos(theta)**67 - 6.47946230438272e+62*cos(theta)**65 + 9.62662970936861e+62*cos(theta)**63 - 1.20750210805375e+63*cos(theta)**61 + 1.29223909809261e+63*cos(theta)**59 - 1.18936046091256e+63*cos(theta)**57 + 9.47215217373478e+62*cos(theta)**55 - 6.55764381258562e+62*cos(theta)**53 + 3.95987430926511e+62*cos(theta)**51 - 2.09061687135115e+62*cos(theta)**49 + 9.66417232983077e+61*cos(theta)**47 - 3.91418894288013e+61*cos(theta)**45 + 1.38890575392521e+61*cos(theta)**43 - 4.31435120672329e+60*cos(theta)**41 + 1.17144635414341e+60*cos(theta)**39 - 2.77418264116417e+59*cos(theta)**37 + 5.71306629256442e+58*cos(theta)**35 - 1.01927269687431e+58*cos(theta)**33 + 1.5681118413451e+57*cos(theta)**31 - 2.0685730673063e+56*cos(theta)**29 + 2.32385352884991e+55*cos(theta)**27 - 2.20511648722984e+54*cos(theta)**25 + 1.75009245018241e+53*cos(theta)**23 - 1.14797352837996e+52*cos(theta)**21 + 6.13420969363337e+50*cos(theta)**19 - 2.62303040162867e+49*cos(theta)**17 + 8.77785764324556e+47*cos(theta)**15 - 2.23436376373523e+46*cos(theta)**13 + 4.16739295962095e+44*cos(theta)**11 - 5.41219864885838e+42*cos(theta)**9 + 4.54806609147763e+40*cos(theta)**7 - 2.20626906724486e+38*cos(theta)**5 + 5.04867063442761e+35*cos(theta)**3 - 3.4368077838173e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl95_m_minus_15(theta, phi):
    return 1.17039319566575e-29*(1.0 - cos(theta)**2)**7.5*(3.30531691579869e+56*cos(theta)**80 - 5.52634997562108e+57*cos(theta)**78 + 4.4373339510134e+58*cos(theta)**76 - 2.27863094781769e+59*cos(theta)**74 + 8.4078991667426e+59*cos(theta)**72 - 2.37465085858498e+60*cos(theta)**70 + 5.33964788033774e+60*cos(theta)**68 - 9.8173671278526e+60*cos(theta)**66 + 1.50416089208884e+61*cos(theta)**64 - 1.94758404524798e+61*cos(theta)**62 + 2.15373183015435e+61*cos(theta)**60 - 2.05062148433201e+61*cos(theta)**58 + 1.69145574530978e+61*cos(theta)**56 - 1.21437848381215e+61*cos(theta)**54 + 7.61514290243291e+60*cos(theta)**52 - 4.18123374270229e+60*cos(theta)**50 + 2.01336923538141e+60*cos(theta)**48 - 8.5091063975655e+59*cos(theta)**46 + 3.15660398619365e+59*cos(theta)**44 - 1.02722647779126e+59*cos(theta)**42 + 2.92861588535853e+58*cos(theta)**40 - 7.30048063464254e+57*cos(theta)**38 + 1.58696285904567e+57*cos(theta)**36 - 2.99786087315974e+56*cos(theta)**34 + 4.90034950420342e+55*cos(theta)**32 - 6.89524355768766e+54*cos(theta)**30 + 8.29947688874967e+53*cos(theta)**28 - 8.4812172585763e+52*cos(theta)**26 + 7.29205187576005e+51*cos(theta)**24 - 5.21806149263618e+50*cos(theta)**22 + 3.06710484681668e+49*cos(theta)**20 - 1.45723911201593e+48*cos(theta)**18 + 5.48616102702847e+46*cos(theta)**16 - 1.59597411695374e+45*cos(theta)**14 + 3.47282746635079e+43*cos(theta)**12 - 5.41219864885838e+41*cos(theta)**10 + 5.68508261434704e+39*cos(theta)**8 - 3.67711511207477e+37*cos(theta)**6 + 1.2621676586069e+35*cos(theta)**4 - 1.71840389190865e+32*cos(theta)**2 + 3.87027903583029e+28)*sin(15*phi)

#@torch.jit.script
def Yl95_m_minus_14(theta, phi):
    return 1.10476686550714e-27*(1.0 - cos(theta)**2)**7*(4.0806381676527e+54*cos(theta)**81 - 6.99537971597605e+55*cos(theta)**79 + 5.76277136495247e+56*cos(theta)**77 - 3.03817459709025e+57*cos(theta)**75 + 1.15176700914282e+58*cos(theta)**73 - 3.34457867406336e+58*cos(theta)**71 + 7.73862011643151e+58*cos(theta)**69 - 1.4652786757989e+59*cos(theta)**67 + 2.31409368013668e+59*cos(theta)**65 - 3.09140324642537e+59*cos(theta)**63 + 3.53070791828582e+59*cos(theta)**61 - 3.47562963446103e+59*cos(theta)**59 + 2.96746621984172e+59*cos(theta)**57 - 2.20796087965846e+59*cos(theta)**55 + 1.43681941555338e+59*cos(theta)**53 - 8.19849753471038e+58*cos(theta)**51 + 4.10891680690084e+58*cos(theta)**49 - 1.81044816969479e+58*cos(theta)**47 + 7.01467552487478e+57*cos(theta)**45 - 2.38889878556107e+57*cos(theta)**43 + 7.14296557404519e+56*cos(theta)**41 - 1.87191811144681e+56*cos(theta)**39 + 4.28908880823155e+55*cos(theta)**37 - 8.56531678045641e+54*cos(theta)**35 + 1.48495439521316e+54*cos(theta)**33 - 2.22427211538311e+53*cos(theta)**31 + 2.86188858232747e+52*cos(theta)**29 - 3.14119157725048e+51*cos(theta)**27 + 2.91682075030402e+50*cos(theta)**25 - 2.26872238810269e+49*cos(theta)**23 + 1.46052611753175e+48*cos(theta)**21 - 7.66967953692594e+46*cos(theta)**19 + 3.22715354531087e+45*cos(theta)**17 - 1.06398274463583e+44*cos(theta)**15 + 2.67140574334676e+42*cos(theta)**13 - 4.92018058987125e+40*cos(theta)**11 + 6.31675846038559e+38*cos(theta)**9 - 5.25302158867825e+36*cos(theta)**7 + 2.5243353172138e+34*cos(theta)**5 - 5.72801297302883e+31*cos(theta)**3 + 3.87027903583029e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl95_m_minus_13(theta, phi):
    return 1.04445760252969e-25*(1.0 - cos(theta)**2)**6.5*(4.97638800933256e+52*cos(theta)**82 - 8.74422464497007e+53*cos(theta)**80 + 7.38816841660573e+54*cos(theta)**78 - 3.99759815406612e+55*cos(theta)**76 + 1.55644190424706e+56*cos(theta)**74 - 4.64524815842133e+56*cos(theta)**72 + 1.10551715949022e+57*cos(theta)**70 - 2.1548215820572e+57*cos(theta)**68 + 3.50620254566164e+57*cos(theta)**66 - 4.83031757253964e+57*cos(theta)**64 + 5.69469019078358e+57*cos(theta)**62 - 5.79271605743504e+57*cos(theta)**60 + 5.11632106869263e+57*cos(theta)**58 - 3.94278728510439e+57*cos(theta)**56 + 2.66077669546922e+57*cos(theta)**54 - 1.57663414129046e+57*cos(theta)**52 + 8.21783361380167e+56*cos(theta)**50 - 3.77176702019747e+56*cos(theta)**48 + 1.5249294619293e+56*cos(theta)**46 - 5.42931542172971e+55*cos(theta)**44 + 1.70070608905838e+55*cos(theta)**42 - 4.67979527861701e+54*cos(theta)**40 + 1.12870758111357e+54*cos(theta)**38 - 2.37925466123789e+53*cos(theta)**36 + 4.36751292709753e+52*cos(theta)**34 - 6.95085036057223e+51*cos(theta)**32 + 9.53962860775824e+50*cos(theta)**30 - 1.12185413473232e+50*cos(theta)**28 + 1.12185413473232e+49*cos(theta)**26 - 9.45300995042786e+47*cos(theta)**24 + 6.63875507968979e+46*cos(theta)**22 - 3.83483976846297e+45*cos(theta)**20 + 1.79286308072826e+44*cos(theta)**18 - 6.64989215397391e+42*cos(theta)**16 + 1.9081469595334e+41*cos(theta)**14 - 4.10015049155938e+39*cos(theta)**12 + 6.31675846038559e+37*cos(theta)**10 - 6.56627698584781e+35*cos(theta)**8 + 4.20722552868967e+33*cos(theta)**6 - 1.43200324325721e+31*cos(theta)**4 + 1.93513951791514e+28*cos(theta)**2 - 4.33013989240354e+24)*sin(13*phi)

#@torch.jit.script
def Yl95_m_minus_12(theta, phi):
    return 9.88875778383378e-24*(1.0 - cos(theta)**2)**6*(5.99564820401513e+50*cos(theta)**83 - 1.07953390678643e+52*cos(theta)**81 + 9.35211191975408e+52*cos(theta)**79 - 5.19168591437159e+53*cos(theta)**77 + 2.07525587232941e+54*cos(theta)**75 - 6.36335364167305e+54*cos(theta)**73 + 1.5570664218172e+55*cos(theta)**71 - 3.1229298290684e+55*cos(theta)**69 + 5.2331381278532e+55*cos(theta)**67 - 7.43125780390714e+55*cos(theta)**65 + 9.03919077902155e+55*cos(theta)**63 - 9.49625583186073e+55*cos(theta)**61 + 8.67173062490276e+55*cos(theta)**59 - 6.91717067562173e+55*cos(theta)**57 + 4.83777580994404e+55*cos(theta)**55 - 2.97478139866124e+55*cos(theta)**53 + 1.61133992427484e+55*cos(theta)**51 - 7.69748371468872e+54*cos(theta)**49 + 3.24453077006234e+54*cos(theta)**47 - 1.20651453816216e+54*cos(theta)**45 + 3.95513043967065e+53*cos(theta)**43 - 1.14141348258952e+53*cos(theta)**41 + 2.8941220028553e+52*cos(theta)**39 - 6.43041800334565e+51*cos(theta)**37 + 1.24786083631358e+51*cos(theta)**35 - 2.10631829108249e+50*cos(theta)**33 + 3.07729955088975e+49*cos(theta)**31 - 3.86846253355971e+48*cos(theta)**29 + 4.15501531382339e+47*cos(theta)**27 - 3.78120398017114e+46*cos(theta)**25 + 2.88641525203904e+45*cos(theta)**23 - 1.82611417545856e+44*cos(theta)**21 + 9.43612147751715e+42*cos(theta)**19 - 3.91170126704347e+41*cos(theta)**17 + 1.27209797302227e+40*cos(theta)**15 - 3.15396191658414e+38*cos(theta)**13 + 5.74250769125963e+36*cos(theta)**11 - 7.29586331760868e+34*cos(theta)**9 + 6.01032218384239e+32*cos(theta)**7 - 2.86400648651441e+30*cos(theta)**5 + 6.45046505971715e+27*cos(theta)**3 - 4.33013989240354e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl95_m_minus_11(theta, phi):
    return 9.37504306230062e-22*(1.0 - cos(theta)**2)**5.5*(7.13767643335135e+48*cos(theta)**84 - 1.31650476437369e+50*cos(theta)**82 + 1.16901398996926e+51*cos(theta)**80 - 6.65600758252768e+51*cos(theta)**78 + 2.73059983201238e+52*cos(theta)**76 - 8.59912654280142e+52*cos(theta)**74 + 2.1625922525239e+53*cos(theta)**72 - 4.46132832724058e+53*cos(theta)**70 + 7.69579136449e+53*cos(theta)**68 - 1.12594815210714e+54*cos(theta)**66 + 1.41237355922212e+54*cos(theta)**64 - 1.53165416642915e+54*cos(theta)**62 + 1.44528843748379e+54*cos(theta)**60 - 1.19261563372789e+54*cos(theta)**58 + 8.63888537490006e+53*cos(theta)**56 - 5.50885444196526e+53*cos(theta)**54 + 3.09873062360546e+53*cos(theta)**52 - 1.53949674293774e+53*cos(theta)**50 + 6.75943910429654e+52*cos(theta)**48 - 2.62285769165686e+52*cos(theta)**46 + 8.98893281743329e+51*cos(theta)**44 - 2.71765114902266e+51*cos(theta)**42 + 7.23530500713824e+50*cos(theta)**40 - 1.69221526403833e+50*cos(theta)**38 + 3.46628010087105e+49*cos(theta)**36 - 6.19505379730146e+48*cos(theta)**34 + 9.61656109653048e+47*cos(theta)**32 - 1.28948751118657e+47*cos(theta)**30 + 1.48393404065121e+46*cos(theta)**28 - 1.45430922314275e+45*cos(theta)**26 + 1.20267302168293e+44*cos(theta)**24 - 8.30051897935708e+42*cos(theta)**22 + 4.71806073875858e+41*cos(theta)**20 - 2.17316737057971e+40*cos(theta)**18 + 7.95061233138918e+38*cos(theta)**16 - 2.25282994041724e+37*cos(theta)**14 + 4.78542307604969e+35*cos(theta)**12 - 7.29586331760868e+33*cos(theta)**10 + 7.51290272980299e+31*cos(theta)**8 - 4.77334414419069e+29*cos(theta)**6 + 1.61261626492929e+27*cos(theta)**4 - 2.16506994620177e+24*cos(theta)**2 + 4.81769013396033e+20)*sin(11*phi)

#@torch.jit.script
def Yl95_m_minus_10(theta, phi):
    return 8.89888648148811e-20*(1.0 - cos(theta)**2)**5*(8.39726639217805e+46*cos(theta)**85 - 1.58615031852252e+48*cos(theta)**83 + 1.4432271481102e+49*cos(theta)**81 - 8.42532605383251e+49*cos(theta)**79 + 3.54623354806803e+50*cos(theta)**77 - 1.14655020570686e+51*cos(theta)**75 + 2.96245514044369e+51*cos(theta)**73 - 6.2835610242825e+51*cos(theta)**71 + 1.11533208181014e+52*cos(theta)**69 - 1.68051963001066e+52*cos(theta)**67 + 2.17288239880326e+52*cos(theta)**65 - 2.43119708957008e+52*cos(theta)**63 + 2.36932530735048e+52*cos(theta)**61 - 2.02138243004726e+52*cos(theta)**59 + 1.51559392542106e+52*cos(theta)**57 - 1.00160989853914e+52*cos(theta)**55 + 5.84666155397256e+51*cos(theta)**53 - 3.01862106458381e+51*cos(theta)**51 + 1.37947736822378e+51*cos(theta)**49 - 5.58054828012098e+50*cos(theta)**47 + 1.99754062609629e+50*cos(theta)**45 - 6.32011895121548e+49*cos(theta)**43 + 1.7647085383264e+49*cos(theta)**41 - 4.33901349753418e+48*cos(theta)**39 + 9.36832459694879e+47*cos(theta)**37 - 1.77001537065756e+47*cos(theta)**35 + 2.91410942319106e+46*cos(theta)**33 - 4.1596371328599e+45*cos(theta)**31 + 5.11701393328004e+44*cos(theta)**29 - 5.38633045608425e+43*cos(theta)**27 + 4.81069208673173e+42*cos(theta)**25 - 3.60892129537264e+41*cos(theta)**23 + 2.24669558988504e+40*cos(theta)**21 - 1.14377230030511e+39*cos(theta)**19 + 4.6768307831701e+37*cos(theta)**17 - 1.50188662694483e+36*cos(theta)**15 + 3.68109467388438e+34*cos(theta)**13 - 6.63260301600789e+32*cos(theta)**11 + 8.3476696997811e+30*cos(theta)**9 - 6.81906306312956e+28*cos(theta)**7 + 3.22523252985857e+26*cos(theta)**5 - 7.21689982067257e+23*cos(theta)**3 + 4.81769013396033e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl95_m_minus_9(theta, phi):
    return 8.45628364538477e-18*(1.0 - cos(theta)**2)**4.5*(9.76426324671867e+44*cos(theta)**86 - 1.88827418871729e+46*cos(theta)**84 + 1.76003310745146e+47*cos(theta)**82 - 1.05316575672906e+48*cos(theta)**80 + 4.54645326675388e+48*cos(theta)**78 - 1.50861869171955e+49*cos(theta)**76 + 4.00331775735634e+49*cos(theta)**74 - 8.72716808928125e+49*cos(theta)**72 + 1.59333154544306e+50*cos(theta)**70 - 2.4713523970745e+50*cos(theta)**68 + 3.29224605879281e+50*cos(theta)**66 - 3.79874545245325e+50*cos(theta)**64 + 3.82149243121045e+50*cos(theta)**62 - 3.36897071674544e+50*cos(theta)**60 + 2.6130929748639e+50*cos(theta)**58 - 1.78858910453417e+50*cos(theta)**56 + 1.08271510258751e+50*cos(theta)**54 - 5.80504050881502e+49*cos(theta)**52 + 2.75895473644757e+49*cos(theta)**50 - 1.16261422502521e+49*cos(theta)**48 + 4.34247962194845e+48*cos(theta)**46 - 1.43639067073079e+48*cos(theta)**44 + 4.20168699601524e+47*cos(theta)**42 - 1.08475337438354e+47*cos(theta)**40 + 2.46534857814442e+46*cos(theta)**38 - 4.91670936293766e+45*cos(theta)**36 + 8.57091006820899e+44*cos(theta)**34 - 1.29988660401872e+44*cos(theta)**32 + 1.70567131109335e+43*cos(theta)**30 - 1.92368944860152e+42*cos(theta)**28 + 1.85026618720451e+41*cos(theta)**26 - 1.50371720640527e+40*cos(theta)**24 + 1.02122526812956e+39*cos(theta)**22 - 5.71886150152555e+37*cos(theta)**20 + 2.59823932398339e+36*cos(theta)**18 - 9.38679141840517e+34*cos(theta)**16 + 2.62935333848884e+33*cos(theta)**14 - 5.52716918000658e+31*cos(theta)**12 + 8.3476696997811e+29*cos(theta)**10 - 8.52382882891194e+27*cos(theta)**8 + 5.37538754976429e+25*cos(theta)**6 - 1.80422495516814e+23*cos(theta)**4 + 2.40884506698017e+20*cos(theta)**2 - 5.33520502099704e+16)*sin(9*phi)

#@torch.jit.script
def Yl95_m_minus_8(theta, phi):
    return 8.04369950339516e-16*(1.0 - cos(theta)**2)**4*(1.12232910881824e+43*cos(theta)**87 - 2.22149904554975e+44*cos(theta)**85 + 2.12052181620658e+45*cos(theta)**83 - 1.30020463793712e+46*cos(theta)**81 + 5.75500413513149e+46*cos(theta)**79 - 1.95924505418123e+47*cos(theta)**77 + 5.33775700980845e+47*cos(theta)**75 - 1.19550247798373e+48*cos(theta)**73 + 2.24412893724375e+48*cos(theta)**71 - 3.58167014068768e+48*cos(theta)**69 + 4.91380008775047e+48*cos(theta)**67 - 5.844223773005e+48*cos(theta)**65 + 6.06586100192135e+48*cos(theta)**63 - 5.52290281433678e+48*cos(theta)**61 + 4.42897114383712e+48*cos(theta)**59 - 3.13787562198978e+48*cos(theta)**57 + 1.96857291379548e+48*cos(theta)**55 - 1.09529066204057e+48*cos(theta)**53 + 5.40971516950504e+47*cos(theta)**51 - 2.37268209188817e+47*cos(theta)**49 + 9.23931834457117e+46*cos(theta)**47 - 3.19197926829065e+46*cos(theta)**45 + 9.77136510701218e+45*cos(theta)**43 - 2.64573993752084e+45*cos(theta)**41 + 6.32140661062671e+44*cos(theta)**39 - 1.32884036836153e+44*cos(theta)**37 + 2.44883144805971e+43*cos(theta)**35 - 3.93905031520824e+42*cos(theta)**33 + 5.50216551965595e+41*cos(theta)**31 - 6.63341189172937e+40*cos(theta)**29 + 6.85283773038709e+39*cos(theta)**27 - 6.01486882562107e+38*cos(theta)**25 + 4.44010986143288e+37*cos(theta)**23 - 2.72326738167883e+36*cos(theta)**21 + 1.36749438104389e+35*cos(theta)**19 - 5.52164201082657e+33*cos(theta)**17 + 1.75290222565923e+32*cos(theta)**15 - 4.25166860000506e+30*cos(theta)**13 + 7.58879063616463e+28*cos(theta)**11 - 9.47092092101327e+26*cos(theta)**9 + 7.67912507109184e+24*cos(theta)**7 - 3.60844991033629e+22*cos(theta)**5 + 8.02948355660055e+19*cos(theta)**3 - 5.33520502099704e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl95_m_minus_7(theta, phi):
    return 7.65800748117377e-14*(1.0 - cos(theta)**2)**3.5*(1.27537398729345e+41*cos(theta)**88 - 2.58313842505785e+42*cos(theta)**86 + 2.52443073357926e+43*cos(theta)**84 - 1.58561541211843e+44*cos(theta)**82 + 7.19375516891437e+44*cos(theta)**80 - 2.51185263356568e+45*cos(theta)**78 + 7.02336448659007e+45*cos(theta)**76 - 1.61554388916721e+46*cos(theta)**74 + 3.11684574617188e+46*cos(theta)**72 - 5.11667162955383e+46*cos(theta)**70 + 7.22617659963304e+46*cos(theta)**68 - 8.85488450455303e+46*cos(theta)**66 + 9.47790781550211e+46*cos(theta)**64 - 8.90790776505933e+46*cos(theta)**62 + 7.38161857306187e+46*cos(theta)**60 - 5.410130382741e+46*cos(theta)**58 + 3.51530877463478e+46*cos(theta)**56 - 2.02831604081587e+46*cos(theta)**54 + 1.04032984028943e+46*cos(theta)**52 - 4.74536418377635e+45*cos(theta)**50 + 1.92485798845233e+45*cos(theta)**48 - 6.93908536584923e+44*cos(theta)**46 + 2.22076479704822e+44*cos(theta)**44 - 6.29938080362105e+43*cos(theta)**42 + 1.58035165265668e+43*cos(theta)**40 - 3.4969483377935e+42*cos(theta)**38 + 6.80230957794364e+41*cos(theta)**36 - 1.15854421035536e+41*cos(theta)**34 + 1.71942672489249e+40*cos(theta)**32 - 2.21113729724312e+39*cos(theta)**30 + 2.44744204656682e+38*cos(theta)**28 - 2.31341108677734e+37*cos(theta)**26 + 1.85004577559703e+36*cos(theta)**24 - 1.23784880985401e+35*cos(theta)**22 + 6.83747190521945e+33*cos(theta)**20 - 3.06757889490365e+32*cos(theta)**18 + 1.09556389103702e+31*cos(theta)**16 - 3.03690614286076e+29*cos(theta)**14 + 6.32399219680386e+27*cos(theta)**12 - 9.47092092101327e+25*cos(theta)**10 + 9.5989063388648e+23*cos(theta)**8 - 6.01408318389381e+21*cos(theta)**6 + 2.00737088915014e+19*cos(theta)**4 - 2.66760251049852e+16*cos(theta)**2 + 5886148522724.01)*sin(7*phi)

#@torch.jit.script
def Yl95_m_minus_6(theta, phi):
    return 7.29643764699456e-12*(1.0 - cos(theta)**2)**3*(1.433004480105e+39*cos(theta)**89 - 2.96912462650327e+40*cos(theta)**87 + 2.96991851009325e+41*cos(theta)**85 - 1.91038001460052e+42*cos(theta)**83 + 8.88117922088193e+42*cos(theta)**81 - 3.17956029565276e+43*cos(theta)**79 + 9.12125257998711e+43*cos(theta)**77 - 2.15405851888961e+44*cos(theta)**75 + 4.26965170708476e+44*cos(theta)**73 - 7.20657975993497e+44*cos(theta)**71 + 1.04727197096131e+45*cos(theta)**69 - 1.32162455291836e+45*cos(theta)**67 + 1.4581396639234e+45*cos(theta)**65 - 1.41395361350148e+45*cos(theta)**63 + 1.21010140541998e+45*cos(theta)**61 - 9.16971251312034e+44*cos(theta)**59 + 6.16720837655224e+44*cos(theta)**57 - 3.68784734693795e+44*cos(theta)**55 + 1.96288649111213e+44*cos(theta)**53 - 9.30463565446343e+43*cos(theta)**51 + 3.92828160908638e+43*cos(theta)**49 - 1.47640114167005e+43*cos(theta)**47 + 4.93503288232938e+42*cos(theta)**45 - 1.46497227991187e+42*cos(theta)**43 + 3.8545162259919e+41*cos(theta)**41 - 8.96653419947052e+40*cos(theta)**39 + 1.83846204809288e+40*cos(theta)**37 - 3.31012631530104e+39*cos(theta)**35 + 5.21038401482571e+38*cos(theta)**33 - 7.13270095884879e+37*cos(theta)**31 + 8.43945533298902e+36*cos(theta)**29 - 8.56818921028643e+35*cos(theta)**27 + 7.40018310238813e+34*cos(theta)**25 - 5.38195134719137e+33*cos(theta)**23 + 3.25593900248545e+32*cos(theta)**21 - 1.61451520784403e+31*cos(theta)**19 + 6.44449347668834e+29*cos(theta)**17 - 2.0246040952405e+28*cos(theta)**15 + 4.86460938215682e+26*cos(theta)**13 - 8.60992811001206e+24*cos(theta)**11 + 1.06654514876276e+23*cos(theta)**9 - 8.59154740556259e+20*cos(theta)**7 + 4.01474177830028e+18*cos(theta)**5 - 8.89200836832841e+15*cos(theta)**3 + 5886148522724.01*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl95_m_minus_5(theta, phi):
    return 6.95653247845935e-10*(1.0 - cos(theta)**2)**2.5*(1.59222720011667e+37*cos(theta)**90 - 3.37400525739008e+38*cos(theta)**88 + 3.4533936163875e+39*cos(theta)**86 - 2.27426192214348e+40*cos(theta)**84 + 1.08307063669292e+41*cos(theta)**82 - 3.97445036956595e+41*cos(theta)**80 + 1.1693913564086e+42*cos(theta)**78 - 2.83428752485475e+42*cos(theta)**76 + 5.7697996041686e+42*cos(theta)**74 - 1.00091385554652e+43*cos(theta)**72 + 1.49610281565902e+43*cos(theta)**70 - 1.94356551899759e+43*cos(theta)**68 + 2.20930252109606e+43*cos(theta)**66 - 2.20930252109606e+43*cos(theta)**64 + 1.95177646035481e+43*cos(theta)**62 - 1.52828541885339e+43*cos(theta)**60 + 1.06331178906073e+43*cos(theta)**58 - 6.58544169096062e+42*cos(theta)**56 + 3.63497498354099e+42*cos(theta)**54 - 1.78935301047374e+42*cos(theta)**52 + 7.85656321817276e+41*cos(theta)**50 - 3.0758357118126e+41*cos(theta)**48 + 1.072833235289e+41*cos(theta)**46 - 3.32948245434516e+40*cos(theta)**44 + 9.177419585695e+39*cos(theta)**42 - 2.24163354986763e+39*cos(theta)**40 + 4.83805802129704e+38*cos(theta)**38 - 9.19479532028067e+37*cos(theta)**36 + 1.53246588671345e+37*cos(theta)**34 - 2.22896904964025e+36*cos(theta)**32 + 2.81315177766301e+35*cos(theta)**30 - 3.0600675751023e+34*cos(theta)**28 + 2.84622427014928e+33*cos(theta)**26 - 2.2424797279964e+32*cos(theta)**24 + 1.47997227385702e+31*cos(theta)**22 - 8.07257603922013e+29*cos(theta)**20 + 3.58027415371574e+28*cos(theta)**18 - 1.26537755952531e+27*cos(theta)**16 + 3.47472098725487e+25*cos(theta)**14 - 7.17494009167672e+23*cos(theta)**12 + 1.06654514876276e+22*cos(theta)**10 - 1.07394342569532e+20*cos(theta)**8 + 6.69123629716713e+17*cos(theta)**6 - 2.2230020920821e+15*cos(theta)**4 + 2943074261362.01*cos(theta)**2 - 647541091.608802)*sin(5*phi)

#@torch.jit.script
def Yl95_m_minus_4(theta, phi):
    return 6.63610903713256e-8*(1.0 - cos(theta)**2)**2*(1.74970021990843e+35*cos(theta)**91 - 3.79101714313493e+36*cos(theta)**89 + 3.96941794987069e+37*cos(theta)**87 - 2.67560226134527e+38*cos(theta)**85 + 1.30490438155773e+39*cos(theta)**83 - 4.90672885131599e+39*cos(theta)**81 + 1.48024222330203e+40*cos(theta)**79 - 3.68089288942175e+40*cos(theta)**77 + 7.69306613889146e+40*cos(theta)**75 - 1.37111487061168e+41*cos(theta)**73 + 2.10718706430847e+41*cos(theta)**71 - 2.81676162173564e+41*cos(theta)**69 + 3.29746644939711e+41*cos(theta)**67 - 3.39892695553241e+41*cos(theta)**65 + 3.09805787357906e+41*cos(theta)**63 - 2.50538593254654e+41*cos(theta)**61 + 1.80222337128937e+41*cos(theta)**59 - 1.15534064753695e+41*cos(theta)**57 + 6.60904542461997e+40*cos(theta)**55 - 3.37613775561082e+40*cos(theta)**53 + 1.54050259179858e+40*cos(theta)**51 - 6.27721573839307e+39*cos(theta)**49 + 2.28262390487021e+39*cos(theta)**47 - 7.39884989854481e+38*cos(theta)**45 + 2.13428362458023e+38*cos(theta)**43 - 5.46739890211617e+37*cos(theta)**41 + 1.24052769776847e+37*cos(theta)**39 - 2.48507981629207e+36*cos(theta)**37 + 4.37847396203841e+35*cos(theta)**35 - 6.7544516655765e+34*cos(theta)**33 + 9.07468315375164e+33*cos(theta)**31 - 1.05519571555252e+33*cos(theta)**29 + 1.05415713709233e+32*cos(theta)**27 - 8.96991891198561e+30*cos(theta)**25 + 6.43466206024793e+29*cos(theta)**23 - 3.84408382820006e+28*cos(theta)**21 + 1.88435481774513e+27*cos(theta)**19 - 7.44339740897244e+25*cos(theta)**17 + 2.31648065816991e+24*cos(theta)**15 - 5.51918468590517e+22*cos(theta)**13 + 9.69586498875233e+20*cos(theta)**11 - 1.1932704729948e+19*cos(theta)**9 + 9.55890899595304e+16*cos(theta)**7 - 444600418416420.0*cos(theta)**5 + 981024753787.335*cos(theta)**3 - 647541091.608802*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl95_m_minus_3(theta, phi):
    return 6.33322655709477e-6*(1.0 - cos(theta)**2)**1.5*(1.90184806511786e+33*cos(theta)**92 - 4.21224127014992e+34*cos(theta)**90 + 4.51070221576214e+35*cos(theta)**88 - 3.11116542016892e+36*cos(theta)**86 + 1.55345759709254e+37*cos(theta)**84 - 5.98381567233657e+37*cos(theta)**82 + 1.85030277912754e+38*cos(theta)**80 - 4.71909344797661e+38*cos(theta)**78 + 1.01224554459098e+39*cos(theta)**76 - 1.85285793325902e+39*cos(theta)**74 + 2.92664870042843e+39*cos(theta)**72 - 4.02394517390806e+39*cos(theta)**70 + 4.84921536676046e+39*cos(theta)**68 - 5.14988932656425e+39*cos(theta)**66 + 4.84071542746727e+39*cos(theta)**64 - 4.04094505249442e+39*cos(theta)**62 + 3.00370561881562e+39*cos(theta)**60 - 1.9919666336844e+39*cos(theta)**58 + 1.18018668296785e+39*cos(theta)**56 - 6.25210695483486e+38*cos(theta)**54 + 2.96250498422804e+38*cos(theta)**52 - 1.25544314767861e+38*cos(theta)**50 + 4.7554664684796e+37*cos(theta)**48 - 1.60844563011844e+37*cos(theta)**46 + 4.85064460131871e+36*cos(theta)**44 - 1.30176164336099e+36*cos(theta)**42 + 3.10131924442118e+35*cos(theta)**40 - 6.5396837270844e+34*cos(theta)**38 + 1.21624276723289e+34*cos(theta)**36 - 1.98660343105191e+33*cos(theta)**34 + 2.83583848554739e+32*cos(theta)**32 - 3.51731905184172e+31*cos(theta)**30 + 3.76484691818688e+30*cos(theta)**28 - 3.44996881230216e+29*cos(theta)**26 + 2.68110919176997e+28*cos(theta)**24 - 1.74731083100003e+27*cos(theta)**22 + 9.42177408872564e+25*cos(theta)**20 - 4.13522078276247e+24*cos(theta)**18 + 1.4478004113562e+23*cos(theta)**16 - 3.94227477564655e+21*cos(theta)**14 + 8.07988749062694e+19*cos(theta)**12 - 1.1932704729948e+18*cos(theta)**10 + 1.19486362449413e+16*cos(theta)**8 - 74100069736070.0*cos(theta)**6 + 245256188446.834*cos(theta)**4 - 323770545.804401*cos(theta)**2 + 71095.8598604306)*sin(3*phi)

#@torch.jit.script
def Yl95_m_minus_2(theta, phi):
    return 0.000604615861596843*(1.0 - cos(theta)**2)*(2.04499791948157e+31*cos(theta)**93 - 4.62883656060431e+32*cos(theta)**91 + 5.0682047368114e+33*cos(theta)**89 - 3.57605220709071e+34*cos(theta)**87 + 1.82759717305005e+35*cos(theta)**85 - 7.20941647269466e+35*cos(theta)**83 + 2.28432441867597e+36*cos(theta)**81 - 5.97353601009697e+36*cos(theta)**79 + 1.31460460336491e+37*cos(theta)**77 - 2.47047724434536e+37*cos(theta)**75 + 4.00910780880607e+37*cos(theta)**73 - 5.66752841395501e+37*cos(theta)**71 + 7.02784835762385e+37*cos(theta)**69 - 7.68640197994664e+37*cos(theta)**67 + 7.44725450379581e+37*cos(theta)**65 - 6.41419849602289e+37*cos(theta)**63 + 4.92410757182889e+37*cos(theta)**61 - 3.37621463336338e+37*cos(theta)**59 + 2.07050295257518e+37*cos(theta)**57 - 1.13674671906088e+37*cos(theta)**55 + 5.58963204571328e+36*cos(theta)**53 - 2.46165323074238e+36*cos(theta)**51 + 9.70503360914203e+35*cos(theta)**49 - 3.42222474493284e+35*cos(theta)**47 + 1.07792102251527e+35*cos(theta)**45 - 3.02735265897905e+34*cos(theta)**43 + 7.56419327907605e+33*cos(theta)**41 - 1.67684198130369e+33*cos(theta)**39 + 3.28714261414295e+32*cos(theta)**37 - 5.67600980300546e+31*cos(theta)**35 + 8.5934499562042e+30*cos(theta)**33 - 1.1346190489812e+30*cos(theta)**31 + 1.29822307523686e+29*cos(theta)**29 - 1.27776622677858e+28*cos(theta)**27 + 1.07244367670799e+27*cos(theta)**25 - 7.5970036130436e+25*cos(theta)**23 + 4.48655908986935e+24*cos(theta)**21 - 2.17643199092761e+23*cos(theta)**19 + 8.51647300797762e+21*cos(theta)**17 - 2.62818318376437e+20*cos(theta)**15 + 6.21529806971303e+18*cos(theta)**13 - 1.08479133908619e+17*cos(theta)**11 + 1.32762624943792e+15*cos(theta)**9 - 10585724248010.0*cos(theta)**7 + 49051237689.3668*cos(theta)**5 - 107923515.268134*cos(theta)**3 + 71095.8598604306*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl95_m_minus_1(theta, phi):
    return 0.057733691905001*(1.0 - cos(theta)**2)**0.5*(2.17552970157613e+29*cos(theta)**94 - 5.03134408761338e+30*cos(theta)**92 + 5.63133859645711e+31*cos(theta)**90 - 4.06369568987581e+32*cos(theta)**88 + 2.12511299191866e+33*cos(theta)**86 - 8.58263865796983e+33*cos(theta)**84 + 2.78576148619021e+34*cos(theta)**82 - 7.46692001262121e+34*cos(theta)**80 + 1.6853905171345e+35*cos(theta)**78 - 3.25062795308601e+35*cos(theta)**76 + 5.41771325514334e+35*cos(theta)**74 - 7.87156724160418e+35*cos(theta)**72 + 1.00397833680341e+36*cos(theta)**70 - 1.13035323234509e+36*cos(theta)**68 + 1.12837189451452e+36*cos(theta)**66 - 1.00221851500358e+36*cos(theta)**64 + 7.9421089868208e+35*cos(theta)**62 - 5.62702438893897e+35*cos(theta)**60 + 3.56983267685376e+35*cos(theta)**58 - 2.02990485546586e+35*cos(theta)**56 + 1.03511704550246e+35*cos(theta)**54 - 4.73394852065842e+34*cos(theta)**52 + 1.94100672182841e+34*cos(theta)**50 - 7.12963488527675e+33*cos(theta)**48 + 2.34330657068537e+33*cos(theta)**46 - 6.88034695222512e+32*cos(theta)**44 + 1.80099839978001e+32*cos(theta)**42 - 4.19210495325923e+31*cos(theta)**40 + 8.6503753003762e+30*cos(theta)**38 - 1.57666938972374e+30*cos(theta)**36 + 2.52748528123653e+29*cos(theta)**34 - 3.54568452806625e+28*cos(theta)**32 + 4.32741025078952e+27*cos(theta)**30 - 4.56345080992349e+26*cos(theta)**28 + 4.1247833719538e+25*cos(theta)**26 - 3.1654181721015e+24*cos(theta)**24 + 2.03934504084971e+23*cos(theta)**22 - 1.08821599546381e+22*cos(theta)**20 + 4.7313738933209e+20*cos(theta)**18 - 1.64261448985273e+19*cos(theta)**16 + 4.43949862122359e+17*cos(theta)**14 - 9.03992782571821e+15*cos(theta)**12 + 132762624943792.0*cos(theta)**10 - 1323215531001.25*cos(theta)**8 + 8175206281.56113*cos(theta)**6 - 26980878.8170334*cos(theta)**4 + 35547.9299302153*cos(theta)**2 - 7.79730860500445)*sin(phi)

#@torch.jit.script
def Yl95_m0(theta, phi):
    return 2.80480734421195e+28*cos(theta)**95 - 6.62617184756949e+29*cos(theta)**93 + 7.57934843954607e+30*cos(theta)**91 - 5.59233006485426e+31*cos(theta)**89 + 2.99174378879362e+32*cos(theta)**87 - 1.23669762584275e+33*cos(theta)**85 + 4.11081054400245e+33*cos(theta)**83 - 1.12906281527364e+34*cos(theta)**81 + 2.61297394391898e+34*cos(theta)**79 - 5.17056693719614e+34*cos(theta)**77 + 8.84741453698007e+34*cos(theta)**75 - 1.32068721571381e+35*cos(theta)**73 + 1.7319191631217e+35*cos(theta)**71 - 2.00644248035311e+35*cos(theta)**69 + 2.06271431152866e+35*cos(theta)**67 - 1.88847260571009e+35*cos(theta)**65 + 1.54403420592649e+35*cos(theta)**63 - 1.12982345604138e+35*cos(theta)**61 + 7.41066998048644e+34*cos(theta)**59 - 4.36176688565955e+34*cos(theta)**57 + 2.30509269851412e+34*cos(theta)**55 - 1.09397975624591e+34*cos(theta)**53 + 4.66142270905031e+33*cos(theta)**51 - 1.78210313464442e+33*cos(theta)**49 + 6.10650724458577e+32*cos(theta)**47 - 1.87266222167297e+32*cos(theta)**45 + 5.12987160889939e+31*cos(theta)**43 - 1.25230442358371e+31*cos(theta)**41 + 2.71663922576361e+30*cos(theta)**39 - 5.21915910368378e+29*cos(theta)**37 + 8.84468183983053e+28*cos(theta)**35 - 1.31597541752917e+28*cos(theta)**33 + 1.70973184167176e+27*cos(theta)**31 - 1.92733407606635e+26*cos(theta)**29 + 1.87110864390946e+25*cos(theta)**27 - 1.5507889823193e+24*cos(theta)**25 + 1.08598668229643e+23*cos(theta)**23 - 6.34683831418331e+21*cos(theta)**21 + 3.04996806860068e+20*cos(theta)**19 - 1.183445744794e+19*cos(theta)**17 + 3.62496894801766e+17*cos(theta)**15 - 8.5169330844004e+15*cos(theta)**13 + 147823938714560.0*cos(theta)**11 - 1800734580133.06*cos(theta)**9 + 14304158182.8752*cos(theta)**7 - 66091819.986882*cos(theta)**5 + 145129.161148182*cos(theta)**3 - 95.5006544076652*cos(theta)

#@torch.jit.script
def Yl95_m1(theta, phi):
    return 0.057733691905001*(1.0 - cos(theta)**2)**0.5*(2.17552970157613e+29*cos(theta)**94 - 5.03134408761338e+30*cos(theta)**92 + 5.63133859645711e+31*cos(theta)**90 - 4.06369568987581e+32*cos(theta)**88 + 2.12511299191866e+33*cos(theta)**86 - 8.58263865796983e+33*cos(theta)**84 + 2.78576148619021e+34*cos(theta)**82 - 7.46692001262121e+34*cos(theta)**80 + 1.6853905171345e+35*cos(theta)**78 - 3.25062795308601e+35*cos(theta)**76 + 5.41771325514334e+35*cos(theta)**74 - 7.87156724160418e+35*cos(theta)**72 + 1.00397833680341e+36*cos(theta)**70 - 1.13035323234509e+36*cos(theta)**68 + 1.12837189451452e+36*cos(theta)**66 - 1.00221851500358e+36*cos(theta)**64 + 7.9421089868208e+35*cos(theta)**62 - 5.62702438893897e+35*cos(theta)**60 + 3.56983267685376e+35*cos(theta)**58 - 2.02990485546586e+35*cos(theta)**56 + 1.03511704550246e+35*cos(theta)**54 - 4.73394852065842e+34*cos(theta)**52 + 1.94100672182841e+34*cos(theta)**50 - 7.12963488527675e+33*cos(theta)**48 + 2.34330657068537e+33*cos(theta)**46 - 6.88034695222512e+32*cos(theta)**44 + 1.80099839978001e+32*cos(theta)**42 - 4.19210495325923e+31*cos(theta)**40 + 8.6503753003762e+30*cos(theta)**38 - 1.57666938972374e+30*cos(theta)**36 + 2.52748528123653e+29*cos(theta)**34 - 3.54568452806625e+28*cos(theta)**32 + 4.32741025078952e+27*cos(theta)**30 - 4.56345080992349e+26*cos(theta)**28 + 4.1247833719538e+25*cos(theta)**26 - 3.1654181721015e+24*cos(theta)**24 + 2.03934504084971e+23*cos(theta)**22 - 1.08821599546381e+22*cos(theta)**20 + 4.7313738933209e+20*cos(theta)**18 - 1.64261448985273e+19*cos(theta)**16 + 4.43949862122359e+17*cos(theta)**14 - 9.03992782571821e+15*cos(theta)**12 + 132762624943792.0*cos(theta)**10 - 1323215531001.25*cos(theta)**8 + 8175206281.56113*cos(theta)**6 - 26980878.8170334*cos(theta)**4 + 35547.9299302153*cos(theta)**2 - 7.79730860500445)*cos(phi)

#@torch.jit.script
def Yl95_m2(theta, phi):
    return 0.000604615861596843*(1.0 - cos(theta)**2)*(2.04499791948157e+31*cos(theta)**93 - 4.62883656060431e+32*cos(theta)**91 + 5.0682047368114e+33*cos(theta)**89 - 3.57605220709071e+34*cos(theta)**87 + 1.82759717305005e+35*cos(theta)**85 - 7.20941647269466e+35*cos(theta)**83 + 2.28432441867597e+36*cos(theta)**81 - 5.97353601009697e+36*cos(theta)**79 + 1.31460460336491e+37*cos(theta)**77 - 2.47047724434536e+37*cos(theta)**75 + 4.00910780880607e+37*cos(theta)**73 - 5.66752841395501e+37*cos(theta)**71 + 7.02784835762385e+37*cos(theta)**69 - 7.68640197994664e+37*cos(theta)**67 + 7.44725450379581e+37*cos(theta)**65 - 6.41419849602289e+37*cos(theta)**63 + 4.92410757182889e+37*cos(theta)**61 - 3.37621463336338e+37*cos(theta)**59 + 2.07050295257518e+37*cos(theta)**57 - 1.13674671906088e+37*cos(theta)**55 + 5.58963204571328e+36*cos(theta)**53 - 2.46165323074238e+36*cos(theta)**51 + 9.70503360914203e+35*cos(theta)**49 - 3.42222474493284e+35*cos(theta)**47 + 1.07792102251527e+35*cos(theta)**45 - 3.02735265897905e+34*cos(theta)**43 + 7.56419327907605e+33*cos(theta)**41 - 1.67684198130369e+33*cos(theta)**39 + 3.28714261414295e+32*cos(theta)**37 - 5.67600980300546e+31*cos(theta)**35 + 8.5934499562042e+30*cos(theta)**33 - 1.1346190489812e+30*cos(theta)**31 + 1.29822307523686e+29*cos(theta)**29 - 1.27776622677858e+28*cos(theta)**27 + 1.07244367670799e+27*cos(theta)**25 - 7.5970036130436e+25*cos(theta)**23 + 4.48655908986935e+24*cos(theta)**21 - 2.17643199092761e+23*cos(theta)**19 + 8.51647300797762e+21*cos(theta)**17 - 2.62818318376437e+20*cos(theta)**15 + 6.21529806971303e+18*cos(theta)**13 - 1.08479133908619e+17*cos(theta)**11 + 1.32762624943792e+15*cos(theta)**9 - 10585724248010.0*cos(theta)**7 + 49051237689.3668*cos(theta)**5 - 107923515.268134*cos(theta)**3 + 71095.8598604306*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl95_m3(theta, phi):
    return 6.33322655709477e-6*(1.0 - cos(theta)**2)**1.5*(1.90184806511786e+33*cos(theta)**92 - 4.21224127014992e+34*cos(theta)**90 + 4.51070221576214e+35*cos(theta)**88 - 3.11116542016892e+36*cos(theta)**86 + 1.55345759709254e+37*cos(theta)**84 - 5.98381567233657e+37*cos(theta)**82 + 1.85030277912754e+38*cos(theta)**80 - 4.71909344797661e+38*cos(theta)**78 + 1.01224554459098e+39*cos(theta)**76 - 1.85285793325902e+39*cos(theta)**74 + 2.92664870042843e+39*cos(theta)**72 - 4.02394517390806e+39*cos(theta)**70 + 4.84921536676046e+39*cos(theta)**68 - 5.14988932656425e+39*cos(theta)**66 + 4.84071542746727e+39*cos(theta)**64 - 4.04094505249442e+39*cos(theta)**62 + 3.00370561881562e+39*cos(theta)**60 - 1.9919666336844e+39*cos(theta)**58 + 1.18018668296785e+39*cos(theta)**56 - 6.25210695483486e+38*cos(theta)**54 + 2.96250498422804e+38*cos(theta)**52 - 1.25544314767861e+38*cos(theta)**50 + 4.7554664684796e+37*cos(theta)**48 - 1.60844563011844e+37*cos(theta)**46 + 4.85064460131871e+36*cos(theta)**44 - 1.30176164336099e+36*cos(theta)**42 + 3.10131924442118e+35*cos(theta)**40 - 6.5396837270844e+34*cos(theta)**38 + 1.21624276723289e+34*cos(theta)**36 - 1.98660343105191e+33*cos(theta)**34 + 2.83583848554739e+32*cos(theta)**32 - 3.51731905184172e+31*cos(theta)**30 + 3.76484691818688e+30*cos(theta)**28 - 3.44996881230216e+29*cos(theta)**26 + 2.68110919176997e+28*cos(theta)**24 - 1.74731083100003e+27*cos(theta)**22 + 9.42177408872564e+25*cos(theta)**20 - 4.13522078276247e+24*cos(theta)**18 + 1.4478004113562e+23*cos(theta)**16 - 3.94227477564655e+21*cos(theta)**14 + 8.07988749062694e+19*cos(theta)**12 - 1.1932704729948e+18*cos(theta)**10 + 1.19486362449413e+16*cos(theta)**8 - 74100069736070.0*cos(theta)**6 + 245256188446.834*cos(theta)**4 - 323770545.804401*cos(theta)**2 + 71095.8598604306)*cos(3*phi)

#@torch.jit.script
def Yl95_m4(theta, phi):
    return 6.63610903713256e-8*(1.0 - cos(theta)**2)**2*(1.74970021990843e+35*cos(theta)**91 - 3.79101714313493e+36*cos(theta)**89 + 3.96941794987069e+37*cos(theta)**87 - 2.67560226134527e+38*cos(theta)**85 + 1.30490438155773e+39*cos(theta)**83 - 4.90672885131599e+39*cos(theta)**81 + 1.48024222330203e+40*cos(theta)**79 - 3.68089288942175e+40*cos(theta)**77 + 7.69306613889146e+40*cos(theta)**75 - 1.37111487061168e+41*cos(theta)**73 + 2.10718706430847e+41*cos(theta)**71 - 2.81676162173564e+41*cos(theta)**69 + 3.29746644939711e+41*cos(theta)**67 - 3.39892695553241e+41*cos(theta)**65 + 3.09805787357906e+41*cos(theta)**63 - 2.50538593254654e+41*cos(theta)**61 + 1.80222337128937e+41*cos(theta)**59 - 1.15534064753695e+41*cos(theta)**57 + 6.60904542461997e+40*cos(theta)**55 - 3.37613775561082e+40*cos(theta)**53 + 1.54050259179858e+40*cos(theta)**51 - 6.27721573839307e+39*cos(theta)**49 + 2.28262390487021e+39*cos(theta)**47 - 7.39884989854481e+38*cos(theta)**45 + 2.13428362458023e+38*cos(theta)**43 - 5.46739890211617e+37*cos(theta)**41 + 1.24052769776847e+37*cos(theta)**39 - 2.48507981629207e+36*cos(theta)**37 + 4.37847396203841e+35*cos(theta)**35 - 6.7544516655765e+34*cos(theta)**33 + 9.07468315375164e+33*cos(theta)**31 - 1.05519571555252e+33*cos(theta)**29 + 1.05415713709233e+32*cos(theta)**27 - 8.96991891198561e+30*cos(theta)**25 + 6.43466206024793e+29*cos(theta)**23 - 3.84408382820006e+28*cos(theta)**21 + 1.88435481774513e+27*cos(theta)**19 - 7.44339740897244e+25*cos(theta)**17 + 2.31648065816991e+24*cos(theta)**15 - 5.51918468590517e+22*cos(theta)**13 + 9.69586498875233e+20*cos(theta)**11 - 1.1932704729948e+19*cos(theta)**9 + 9.55890899595304e+16*cos(theta)**7 - 444600418416420.0*cos(theta)**5 + 981024753787.335*cos(theta)**3 - 647541091.608802*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl95_m5(theta, phi):
    return 6.95653247845935e-10*(1.0 - cos(theta)**2)**2.5*(1.59222720011667e+37*cos(theta)**90 - 3.37400525739008e+38*cos(theta)**88 + 3.4533936163875e+39*cos(theta)**86 - 2.27426192214348e+40*cos(theta)**84 + 1.08307063669292e+41*cos(theta)**82 - 3.97445036956595e+41*cos(theta)**80 + 1.1693913564086e+42*cos(theta)**78 - 2.83428752485475e+42*cos(theta)**76 + 5.7697996041686e+42*cos(theta)**74 - 1.00091385554652e+43*cos(theta)**72 + 1.49610281565902e+43*cos(theta)**70 - 1.94356551899759e+43*cos(theta)**68 + 2.20930252109606e+43*cos(theta)**66 - 2.20930252109606e+43*cos(theta)**64 + 1.95177646035481e+43*cos(theta)**62 - 1.52828541885339e+43*cos(theta)**60 + 1.06331178906073e+43*cos(theta)**58 - 6.58544169096062e+42*cos(theta)**56 + 3.63497498354099e+42*cos(theta)**54 - 1.78935301047374e+42*cos(theta)**52 + 7.85656321817276e+41*cos(theta)**50 - 3.0758357118126e+41*cos(theta)**48 + 1.072833235289e+41*cos(theta)**46 - 3.32948245434516e+40*cos(theta)**44 + 9.177419585695e+39*cos(theta)**42 - 2.24163354986763e+39*cos(theta)**40 + 4.83805802129704e+38*cos(theta)**38 - 9.19479532028067e+37*cos(theta)**36 + 1.53246588671345e+37*cos(theta)**34 - 2.22896904964025e+36*cos(theta)**32 + 2.81315177766301e+35*cos(theta)**30 - 3.0600675751023e+34*cos(theta)**28 + 2.84622427014928e+33*cos(theta)**26 - 2.2424797279964e+32*cos(theta)**24 + 1.47997227385702e+31*cos(theta)**22 - 8.07257603922013e+29*cos(theta)**20 + 3.58027415371574e+28*cos(theta)**18 - 1.26537755952531e+27*cos(theta)**16 + 3.47472098725487e+25*cos(theta)**14 - 7.17494009167672e+23*cos(theta)**12 + 1.06654514876276e+22*cos(theta)**10 - 1.07394342569532e+20*cos(theta)**8 + 6.69123629716713e+17*cos(theta)**6 - 2.2230020920821e+15*cos(theta)**4 + 2943074261362.01*cos(theta)**2 - 647541091.608802)*cos(5*phi)

#@torch.jit.script
def Yl95_m6(theta, phi):
    return 7.29643764699456e-12*(1.0 - cos(theta)**2)**3*(1.433004480105e+39*cos(theta)**89 - 2.96912462650327e+40*cos(theta)**87 + 2.96991851009325e+41*cos(theta)**85 - 1.91038001460052e+42*cos(theta)**83 + 8.88117922088193e+42*cos(theta)**81 - 3.17956029565276e+43*cos(theta)**79 + 9.12125257998711e+43*cos(theta)**77 - 2.15405851888961e+44*cos(theta)**75 + 4.26965170708476e+44*cos(theta)**73 - 7.20657975993497e+44*cos(theta)**71 + 1.04727197096131e+45*cos(theta)**69 - 1.32162455291836e+45*cos(theta)**67 + 1.4581396639234e+45*cos(theta)**65 - 1.41395361350148e+45*cos(theta)**63 + 1.21010140541998e+45*cos(theta)**61 - 9.16971251312034e+44*cos(theta)**59 + 6.16720837655224e+44*cos(theta)**57 - 3.68784734693795e+44*cos(theta)**55 + 1.96288649111213e+44*cos(theta)**53 - 9.30463565446343e+43*cos(theta)**51 + 3.92828160908638e+43*cos(theta)**49 - 1.47640114167005e+43*cos(theta)**47 + 4.93503288232938e+42*cos(theta)**45 - 1.46497227991187e+42*cos(theta)**43 + 3.8545162259919e+41*cos(theta)**41 - 8.96653419947052e+40*cos(theta)**39 + 1.83846204809288e+40*cos(theta)**37 - 3.31012631530104e+39*cos(theta)**35 + 5.21038401482571e+38*cos(theta)**33 - 7.13270095884879e+37*cos(theta)**31 + 8.43945533298902e+36*cos(theta)**29 - 8.56818921028643e+35*cos(theta)**27 + 7.40018310238813e+34*cos(theta)**25 - 5.38195134719137e+33*cos(theta)**23 + 3.25593900248545e+32*cos(theta)**21 - 1.61451520784403e+31*cos(theta)**19 + 6.44449347668834e+29*cos(theta)**17 - 2.0246040952405e+28*cos(theta)**15 + 4.86460938215682e+26*cos(theta)**13 - 8.60992811001206e+24*cos(theta)**11 + 1.06654514876276e+23*cos(theta)**9 - 8.59154740556259e+20*cos(theta)**7 + 4.01474177830028e+18*cos(theta)**5 - 8.89200836832841e+15*cos(theta)**3 + 5886148522724.01*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl95_m7(theta, phi):
    return 7.65800748117377e-14*(1.0 - cos(theta)**2)**3.5*(1.27537398729345e+41*cos(theta)**88 - 2.58313842505785e+42*cos(theta)**86 + 2.52443073357926e+43*cos(theta)**84 - 1.58561541211843e+44*cos(theta)**82 + 7.19375516891437e+44*cos(theta)**80 - 2.51185263356568e+45*cos(theta)**78 + 7.02336448659007e+45*cos(theta)**76 - 1.61554388916721e+46*cos(theta)**74 + 3.11684574617188e+46*cos(theta)**72 - 5.11667162955383e+46*cos(theta)**70 + 7.22617659963304e+46*cos(theta)**68 - 8.85488450455303e+46*cos(theta)**66 + 9.47790781550211e+46*cos(theta)**64 - 8.90790776505933e+46*cos(theta)**62 + 7.38161857306187e+46*cos(theta)**60 - 5.410130382741e+46*cos(theta)**58 + 3.51530877463478e+46*cos(theta)**56 - 2.02831604081587e+46*cos(theta)**54 + 1.04032984028943e+46*cos(theta)**52 - 4.74536418377635e+45*cos(theta)**50 + 1.92485798845233e+45*cos(theta)**48 - 6.93908536584923e+44*cos(theta)**46 + 2.22076479704822e+44*cos(theta)**44 - 6.29938080362105e+43*cos(theta)**42 + 1.58035165265668e+43*cos(theta)**40 - 3.4969483377935e+42*cos(theta)**38 + 6.80230957794364e+41*cos(theta)**36 - 1.15854421035536e+41*cos(theta)**34 + 1.71942672489249e+40*cos(theta)**32 - 2.21113729724312e+39*cos(theta)**30 + 2.44744204656682e+38*cos(theta)**28 - 2.31341108677734e+37*cos(theta)**26 + 1.85004577559703e+36*cos(theta)**24 - 1.23784880985401e+35*cos(theta)**22 + 6.83747190521945e+33*cos(theta)**20 - 3.06757889490365e+32*cos(theta)**18 + 1.09556389103702e+31*cos(theta)**16 - 3.03690614286076e+29*cos(theta)**14 + 6.32399219680386e+27*cos(theta)**12 - 9.47092092101327e+25*cos(theta)**10 + 9.5989063388648e+23*cos(theta)**8 - 6.01408318389381e+21*cos(theta)**6 + 2.00737088915014e+19*cos(theta)**4 - 2.66760251049852e+16*cos(theta)**2 + 5886148522724.01)*cos(7*phi)

#@torch.jit.script
def Yl95_m8(theta, phi):
    return 8.04369950339516e-16*(1.0 - cos(theta)**2)**4*(1.12232910881824e+43*cos(theta)**87 - 2.22149904554975e+44*cos(theta)**85 + 2.12052181620658e+45*cos(theta)**83 - 1.30020463793712e+46*cos(theta)**81 + 5.75500413513149e+46*cos(theta)**79 - 1.95924505418123e+47*cos(theta)**77 + 5.33775700980845e+47*cos(theta)**75 - 1.19550247798373e+48*cos(theta)**73 + 2.24412893724375e+48*cos(theta)**71 - 3.58167014068768e+48*cos(theta)**69 + 4.91380008775047e+48*cos(theta)**67 - 5.844223773005e+48*cos(theta)**65 + 6.06586100192135e+48*cos(theta)**63 - 5.52290281433678e+48*cos(theta)**61 + 4.42897114383712e+48*cos(theta)**59 - 3.13787562198978e+48*cos(theta)**57 + 1.96857291379548e+48*cos(theta)**55 - 1.09529066204057e+48*cos(theta)**53 + 5.40971516950504e+47*cos(theta)**51 - 2.37268209188817e+47*cos(theta)**49 + 9.23931834457117e+46*cos(theta)**47 - 3.19197926829065e+46*cos(theta)**45 + 9.77136510701218e+45*cos(theta)**43 - 2.64573993752084e+45*cos(theta)**41 + 6.32140661062671e+44*cos(theta)**39 - 1.32884036836153e+44*cos(theta)**37 + 2.44883144805971e+43*cos(theta)**35 - 3.93905031520824e+42*cos(theta)**33 + 5.50216551965595e+41*cos(theta)**31 - 6.63341189172937e+40*cos(theta)**29 + 6.85283773038709e+39*cos(theta)**27 - 6.01486882562107e+38*cos(theta)**25 + 4.44010986143288e+37*cos(theta)**23 - 2.72326738167883e+36*cos(theta)**21 + 1.36749438104389e+35*cos(theta)**19 - 5.52164201082657e+33*cos(theta)**17 + 1.75290222565923e+32*cos(theta)**15 - 4.25166860000506e+30*cos(theta)**13 + 7.58879063616463e+28*cos(theta)**11 - 9.47092092101327e+26*cos(theta)**9 + 7.67912507109184e+24*cos(theta)**7 - 3.60844991033629e+22*cos(theta)**5 + 8.02948355660055e+19*cos(theta)**3 - 5.33520502099704e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl95_m9(theta, phi):
    return 8.45628364538477e-18*(1.0 - cos(theta)**2)**4.5*(9.76426324671867e+44*cos(theta)**86 - 1.88827418871729e+46*cos(theta)**84 + 1.76003310745146e+47*cos(theta)**82 - 1.05316575672906e+48*cos(theta)**80 + 4.54645326675388e+48*cos(theta)**78 - 1.50861869171955e+49*cos(theta)**76 + 4.00331775735634e+49*cos(theta)**74 - 8.72716808928125e+49*cos(theta)**72 + 1.59333154544306e+50*cos(theta)**70 - 2.4713523970745e+50*cos(theta)**68 + 3.29224605879281e+50*cos(theta)**66 - 3.79874545245325e+50*cos(theta)**64 + 3.82149243121045e+50*cos(theta)**62 - 3.36897071674544e+50*cos(theta)**60 + 2.6130929748639e+50*cos(theta)**58 - 1.78858910453417e+50*cos(theta)**56 + 1.08271510258751e+50*cos(theta)**54 - 5.80504050881502e+49*cos(theta)**52 + 2.75895473644757e+49*cos(theta)**50 - 1.16261422502521e+49*cos(theta)**48 + 4.34247962194845e+48*cos(theta)**46 - 1.43639067073079e+48*cos(theta)**44 + 4.20168699601524e+47*cos(theta)**42 - 1.08475337438354e+47*cos(theta)**40 + 2.46534857814442e+46*cos(theta)**38 - 4.91670936293766e+45*cos(theta)**36 + 8.57091006820899e+44*cos(theta)**34 - 1.29988660401872e+44*cos(theta)**32 + 1.70567131109335e+43*cos(theta)**30 - 1.92368944860152e+42*cos(theta)**28 + 1.85026618720451e+41*cos(theta)**26 - 1.50371720640527e+40*cos(theta)**24 + 1.02122526812956e+39*cos(theta)**22 - 5.71886150152555e+37*cos(theta)**20 + 2.59823932398339e+36*cos(theta)**18 - 9.38679141840517e+34*cos(theta)**16 + 2.62935333848884e+33*cos(theta)**14 - 5.52716918000658e+31*cos(theta)**12 + 8.3476696997811e+29*cos(theta)**10 - 8.52382882891194e+27*cos(theta)**8 + 5.37538754976429e+25*cos(theta)**6 - 1.80422495516814e+23*cos(theta)**4 + 2.40884506698017e+20*cos(theta)**2 - 5.33520502099704e+16)*cos(9*phi)

#@torch.jit.script
def Yl95_m10(theta, phi):
    return 8.89888648148811e-20*(1.0 - cos(theta)**2)**5*(8.39726639217805e+46*cos(theta)**85 - 1.58615031852252e+48*cos(theta)**83 + 1.4432271481102e+49*cos(theta)**81 - 8.42532605383251e+49*cos(theta)**79 + 3.54623354806803e+50*cos(theta)**77 - 1.14655020570686e+51*cos(theta)**75 + 2.96245514044369e+51*cos(theta)**73 - 6.2835610242825e+51*cos(theta)**71 + 1.11533208181014e+52*cos(theta)**69 - 1.68051963001066e+52*cos(theta)**67 + 2.17288239880326e+52*cos(theta)**65 - 2.43119708957008e+52*cos(theta)**63 + 2.36932530735048e+52*cos(theta)**61 - 2.02138243004726e+52*cos(theta)**59 + 1.51559392542106e+52*cos(theta)**57 - 1.00160989853914e+52*cos(theta)**55 + 5.84666155397256e+51*cos(theta)**53 - 3.01862106458381e+51*cos(theta)**51 + 1.37947736822378e+51*cos(theta)**49 - 5.58054828012098e+50*cos(theta)**47 + 1.99754062609629e+50*cos(theta)**45 - 6.32011895121548e+49*cos(theta)**43 + 1.7647085383264e+49*cos(theta)**41 - 4.33901349753418e+48*cos(theta)**39 + 9.36832459694879e+47*cos(theta)**37 - 1.77001537065756e+47*cos(theta)**35 + 2.91410942319106e+46*cos(theta)**33 - 4.1596371328599e+45*cos(theta)**31 + 5.11701393328004e+44*cos(theta)**29 - 5.38633045608425e+43*cos(theta)**27 + 4.81069208673173e+42*cos(theta)**25 - 3.60892129537264e+41*cos(theta)**23 + 2.24669558988504e+40*cos(theta)**21 - 1.14377230030511e+39*cos(theta)**19 + 4.6768307831701e+37*cos(theta)**17 - 1.50188662694483e+36*cos(theta)**15 + 3.68109467388438e+34*cos(theta)**13 - 6.63260301600789e+32*cos(theta)**11 + 8.3476696997811e+30*cos(theta)**9 - 6.81906306312956e+28*cos(theta)**7 + 3.22523252985857e+26*cos(theta)**5 - 7.21689982067257e+23*cos(theta)**3 + 4.81769013396033e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl95_m11(theta, phi):
    return 9.37504306230062e-22*(1.0 - cos(theta)**2)**5.5*(7.13767643335135e+48*cos(theta)**84 - 1.31650476437369e+50*cos(theta)**82 + 1.16901398996926e+51*cos(theta)**80 - 6.65600758252768e+51*cos(theta)**78 + 2.73059983201238e+52*cos(theta)**76 - 8.59912654280142e+52*cos(theta)**74 + 2.1625922525239e+53*cos(theta)**72 - 4.46132832724058e+53*cos(theta)**70 + 7.69579136449e+53*cos(theta)**68 - 1.12594815210714e+54*cos(theta)**66 + 1.41237355922212e+54*cos(theta)**64 - 1.53165416642915e+54*cos(theta)**62 + 1.44528843748379e+54*cos(theta)**60 - 1.19261563372789e+54*cos(theta)**58 + 8.63888537490006e+53*cos(theta)**56 - 5.50885444196526e+53*cos(theta)**54 + 3.09873062360546e+53*cos(theta)**52 - 1.53949674293774e+53*cos(theta)**50 + 6.75943910429654e+52*cos(theta)**48 - 2.62285769165686e+52*cos(theta)**46 + 8.98893281743329e+51*cos(theta)**44 - 2.71765114902266e+51*cos(theta)**42 + 7.23530500713824e+50*cos(theta)**40 - 1.69221526403833e+50*cos(theta)**38 + 3.46628010087105e+49*cos(theta)**36 - 6.19505379730146e+48*cos(theta)**34 + 9.61656109653048e+47*cos(theta)**32 - 1.28948751118657e+47*cos(theta)**30 + 1.48393404065121e+46*cos(theta)**28 - 1.45430922314275e+45*cos(theta)**26 + 1.20267302168293e+44*cos(theta)**24 - 8.30051897935708e+42*cos(theta)**22 + 4.71806073875858e+41*cos(theta)**20 - 2.17316737057971e+40*cos(theta)**18 + 7.95061233138918e+38*cos(theta)**16 - 2.25282994041724e+37*cos(theta)**14 + 4.78542307604969e+35*cos(theta)**12 - 7.29586331760868e+33*cos(theta)**10 + 7.51290272980299e+31*cos(theta)**8 - 4.77334414419069e+29*cos(theta)**6 + 1.61261626492929e+27*cos(theta)**4 - 2.16506994620177e+24*cos(theta)**2 + 4.81769013396033e+20)*cos(11*phi)

#@torch.jit.script
def Yl95_m12(theta, phi):
    return 9.88875778383378e-24*(1.0 - cos(theta)**2)**6*(5.99564820401513e+50*cos(theta)**83 - 1.07953390678643e+52*cos(theta)**81 + 9.35211191975408e+52*cos(theta)**79 - 5.19168591437159e+53*cos(theta)**77 + 2.07525587232941e+54*cos(theta)**75 - 6.36335364167305e+54*cos(theta)**73 + 1.5570664218172e+55*cos(theta)**71 - 3.1229298290684e+55*cos(theta)**69 + 5.2331381278532e+55*cos(theta)**67 - 7.43125780390714e+55*cos(theta)**65 + 9.03919077902155e+55*cos(theta)**63 - 9.49625583186073e+55*cos(theta)**61 + 8.67173062490276e+55*cos(theta)**59 - 6.91717067562173e+55*cos(theta)**57 + 4.83777580994404e+55*cos(theta)**55 - 2.97478139866124e+55*cos(theta)**53 + 1.61133992427484e+55*cos(theta)**51 - 7.69748371468872e+54*cos(theta)**49 + 3.24453077006234e+54*cos(theta)**47 - 1.20651453816216e+54*cos(theta)**45 + 3.95513043967065e+53*cos(theta)**43 - 1.14141348258952e+53*cos(theta)**41 + 2.8941220028553e+52*cos(theta)**39 - 6.43041800334565e+51*cos(theta)**37 + 1.24786083631358e+51*cos(theta)**35 - 2.10631829108249e+50*cos(theta)**33 + 3.07729955088975e+49*cos(theta)**31 - 3.86846253355971e+48*cos(theta)**29 + 4.15501531382339e+47*cos(theta)**27 - 3.78120398017114e+46*cos(theta)**25 + 2.88641525203904e+45*cos(theta)**23 - 1.82611417545856e+44*cos(theta)**21 + 9.43612147751715e+42*cos(theta)**19 - 3.91170126704347e+41*cos(theta)**17 + 1.27209797302227e+40*cos(theta)**15 - 3.15396191658414e+38*cos(theta)**13 + 5.74250769125963e+36*cos(theta)**11 - 7.29586331760868e+34*cos(theta)**9 + 6.01032218384239e+32*cos(theta)**7 - 2.86400648651441e+30*cos(theta)**5 + 6.45046505971715e+27*cos(theta)**3 - 4.33013989240354e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl95_m13(theta, phi):
    return 1.04445760252969e-25*(1.0 - cos(theta)**2)**6.5*(4.97638800933256e+52*cos(theta)**82 - 8.74422464497007e+53*cos(theta)**80 + 7.38816841660573e+54*cos(theta)**78 - 3.99759815406612e+55*cos(theta)**76 + 1.55644190424706e+56*cos(theta)**74 - 4.64524815842133e+56*cos(theta)**72 + 1.10551715949022e+57*cos(theta)**70 - 2.1548215820572e+57*cos(theta)**68 + 3.50620254566164e+57*cos(theta)**66 - 4.83031757253964e+57*cos(theta)**64 + 5.69469019078358e+57*cos(theta)**62 - 5.79271605743504e+57*cos(theta)**60 + 5.11632106869263e+57*cos(theta)**58 - 3.94278728510439e+57*cos(theta)**56 + 2.66077669546922e+57*cos(theta)**54 - 1.57663414129046e+57*cos(theta)**52 + 8.21783361380167e+56*cos(theta)**50 - 3.77176702019747e+56*cos(theta)**48 + 1.5249294619293e+56*cos(theta)**46 - 5.42931542172971e+55*cos(theta)**44 + 1.70070608905838e+55*cos(theta)**42 - 4.67979527861701e+54*cos(theta)**40 + 1.12870758111357e+54*cos(theta)**38 - 2.37925466123789e+53*cos(theta)**36 + 4.36751292709753e+52*cos(theta)**34 - 6.95085036057223e+51*cos(theta)**32 + 9.53962860775824e+50*cos(theta)**30 - 1.12185413473232e+50*cos(theta)**28 + 1.12185413473232e+49*cos(theta)**26 - 9.45300995042786e+47*cos(theta)**24 + 6.63875507968979e+46*cos(theta)**22 - 3.83483976846297e+45*cos(theta)**20 + 1.79286308072826e+44*cos(theta)**18 - 6.64989215397391e+42*cos(theta)**16 + 1.9081469595334e+41*cos(theta)**14 - 4.10015049155938e+39*cos(theta)**12 + 6.31675846038559e+37*cos(theta)**10 - 6.56627698584781e+35*cos(theta)**8 + 4.20722552868967e+33*cos(theta)**6 - 1.43200324325721e+31*cos(theta)**4 + 1.93513951791514e+28*cos(theta)**2 - 4.33013989240354e+24)*cos(13*phi)

#@torch.jit.script
def Yl95_m14(theta, phi):
    return 1.10476686550714e-27*(1.0 - cos(theta)**2)**7*(4.0806381676527e+54*cos(theta)**81 - 6.99537971597605e+55*cos(theta)**79 + 5.76277136495247e+56*cos(theta)**77 - 3.03817459709025e+57*cos(theta)**75 + 1.15176700914282e+58*cos(theta)**73 - 3.34457867406336e+58*cos(theta)**71 + 7.73862011643151e+58*cos(theta)**69 - 1.4652786757989e+59*cos(theta)**67 + 2.31409368013668e+59*cos(theta)**65 - 3.09140324642537e+59*cos(theta)**63 + 3.53070791828582e+59*cos(theta)**61 - 3.47562963446103e+59*cos(theta)**59 + 2.96746621984172e+59*cos(theta)**57 - 2.20796087965846e+59*cos(theta)**55 + 1.43681941555338e+59*cos(theta)**53 - 8.19849753471038e+58*cos(theta)**51 + 4.10891680690084e+58*cos(theta)**49 - 1.81044816969479e+58*cos(theta)**47 + 7.01467552487478e+57*cos(theta)**45 - 2.38889878556107e+57*cos(theta)**43 + 7.14296557404519e+56*cos(theta)**41 - 1.87191811144681e+56*cos(theta)**39 + 4.28908880823155e+55*cos(theta)**37 - 8.56531678045641e+54*cos(theta)**35 + 1.48495439521316e+54*cos(theta)**33 - 2.22427211538311e+53*cos(theta)**31 + 2.86188858232747e+52*cos(theta)**29 - 3.14119157725048e+51*cos(theta)**27 + 2.91682075030402e+50*cos(theta)**25 - 2.26872238810269e+49*cos(theta)**23 + 1.46052611753175e+48*cos(theta)**21 - 7.66967953692594e+46*cos(theta)**19 + 3.22715354531087e+45*cos(theta)**17 - 1.06398274463583e+44*cos(theta)**15 + 2.67140574334676e+42*cos(theta)**13 - 4.92018058987125e+40*cos(theta)**11 + 6.31675846038559e+38*cos(theta)**9 - 5.25302158867825e+36*cos(theta)**7 + 2.5243353172138e+34*cos(theta)**5 - 5.72801297302883e+31*cos(theta)**3 + 3.87027903583029e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl95_m15(theta, phi):
    return 1.17039319566575e-29*(1.0 - cos(theta)**2)**7.5*(3.30531691579869e+56*cos(theta)**80 - 5.52634997562108e+57*cos(theta)**78 + 4.4373339510134e+58*cos(theta)**76 - 2.27863094781769e+59*cos(theta)**74 + 8.4078991667426e+59*cos(theta)**72 - 2.37465085858498e+60*cos(theta)**70 + 5.33964788033774e+60*cos(theta)**68 - 9.8173671278526e+60*cos(theta)**66 + 1.50416089208884e+61*cos(theta)**64 - 1.94758404524798e+61*cos(theta)**62 + 2.15373183015435e+61*cos(theta)**60 - 2.05062148433201e+61*cos(theta)**58 + 1.69145574530978e+61*cos(theta)**56 - 1.21437848381215e+61*cos(theta)**54 + 7.61514290243291e+60*cos(theta)**52 - 4.18123374270229e+60*cos(theta)**50 + 2.01336923538141e+60*cos(theta)**48 - 8.5091063975655e+59*cos(theta)**46 + 3.15660398619365e+59*cos(theta)**44 - 1.02722647779126e+59*cos(theta)**42 + 2.92861588535853e+58*cos(theta)**40 - 7.30048063464254e+57*cos(theta)**38 + 1.58696285904567e+57*cos(theta)**36 - 2.99786087315974e+56*cos(theta)**34 + 4.90034950420342e+55*cos(theta)**32 - 6.89524355768766e+54*cos(theta)**30 + 8.29947688874967e+53*cos(theta)**28 - 8.4812172585763e+52*cos(theta)**26 + 7.29205187576005e+51*cos(theta)**24 - 5.21806149263618e+50*cos(theta)**22 + 3.06710484681668e+49*cos(theta)**20 - 1.45723911201593e+48*cos(theta)**18 + 5.48616102702847e+46*cos(theta)**16 - 1.59597411695374e+45*cos(theta)**14 + 3.47282746635079e+43*cos(theta)**12 - 5.41219864885838e+41*cos(theta)**10 + 5.68508261434704e+39*cos(theta)**8 - 3.67711511207477e+37*cos(theta)**6 + 1.2621676586069e+35*cos(theta)**4 - 1.71840389190865e+32*cos(theta)**2 + 3.87027903583029e+28)*cos(15*phi)

#@torch.jit.script
def Yl95_m16(theta, phi):
    return 1.24201060859807e-31*(1.0 - cos(theta)**2)**8*(2.64425353263895e+58*cos(theta)**79 - 4.31055298098444e+59*cos(theta)**77 + 3.37237380277018e+60*cos(theta)**75 - 1.68618690138509e+61*cos(theta)**73 + 6.05368740005467e+61*cos(theta)**71 - 1.66225560100949e+62*cos(theta)**69 + 3.63096055862966e+62*cos(theta)**67 - 6.47946230438272e+62*cos(theta)**65 + 9.62662970936861e+62*cos(theta)**63 - 1.20750210805375e+63*cos(theta)**61 + 1.29223909809261e+63*cos(theta)**59 - 1.18936046091256e+63*cos(theta)**57 + 9.47215217373478e+62*cos(theta)**55 - 6.55764381258562e+62*cos(theta)**53 + 3.95987430926511e+62*cos(theta)**51 - 2.09061687135115e+62*cos(theta)**49 + 9.66417232983077e+61*cos(theta)**47 - 3.91418894288013e+61*cos(theta)**45 + 1.38890575392521e+61*cos(theta)**43 - 4.31435120672329e+60*cos(theta)**41 + 1.17144635414341e+60*cos(theta)**39 - 2.77418264116417e+59*cos(theta)**37 + 5.71306629256442e+58*cos(theta)**35 - 1.01927269687431e+58*cos(theta)**33 + 1.5681118413451e+57*cos(theta)**31 - 2.0685730673063e+56*cos(theta)**29 + 2.32385352884991e+55*cos(theta)**27 - 2.20511648722984e+54*cos(theta)**25 + 1.75009245018241e+53*cos(theta)**23 - 1.14797352837996e+52*cos(theta)**21 + 6.13420969363337e+50*cos(theta)**19 - 2.62303040162867e+49*cos(theta)**17 + 8.77785764324556e+47*cos(theta)**15 - 2.23436376373523e+46*cos(theta)**13 + 4.16739295962095e+44*cos(theta)**11 - 5.41219864885838e+42*cos(theta)**9 + 4.54806609147763e+40*cos(theta)**7 - 2.20626906724486e+38*cos(theta)**5 + 5.04867063442761e+35*cos(theta)**3 - 3.4368077838173e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl95_m17(theta, phi):
    return 1.32039158660871e-33*(1.0 - cos(theta)**2)**8.5*(2.08896029078477e+60*cos(theta)**78 - 3.31912579535802e+61*cos(theta)**76 + 2.52928035207764e+62*cos(theta)**74 - 1.23091643801112e+63*cos(theta)**72 + 4.29811805403882e+63*cos(theta)**70 - 1.14695636469655e+64*cos(theta)**68 + 2.43274357428187e+64*cos(theta)**66 - 4.21165049784876e+64*cos(theta)**64 + 6.06477671690222e+64*cos(theta)**62 - 7.36576285912787e+64*cos(theta)**60 + 7.6242106787464e+64*cos(theta)**58 - 6.77935462720161e+64*cos(theta)**56 + 5.20968369555413e+64*cos(theta)**54 - 3.47555122067038e+64*cos(theta)**52 + 2.01953589772521e+64*cos(theta)**50 - 1.02440226696206e+64*cos(theta)**48 + 4.54216099502046e+63*cos(theta)**46 - 1.76138502429606e+63*cos(theta)**44 + 5.97229474187839e+62*cos(theta)**42 - 1.76888399475655e+62*cos(theta)**40 + 4.5686407811593e+61*cos(theta)**38 - 1.02644757723074e+61*cos(theta)**36 + 1.99957320239755e+60*cos(theta)**34 - 3.36359989968523e+59*cos(theta)**32 + 4.8611467081698e+58*cos(theta)**30 - 5.99886189518826e+57*cos(theta)**28 + 6.27440452789475e+56*cos(theta)**26 - 5.5127912180746e+55*cos(theta)**24 + 4.02521263541955e+54*cos(theta)**22 - 2.41074440959791e+53*cos(theta)**20 + 1.16549984179034e+52*cos(theta)**18 - 4.45915168276874e+50*cos(theta)**16 + 1.31667864648683e+49*cos(theta)**14 - 2.9046728928558e+47*cos(theta)**12 + 4.58413225558305e+45*cos(theta)**10 - 4.87097878397254e+43*cos(theta)**8 + 3.18364626403434e+41*cos(theta)**6 - 1.10313453362243e+39*cos(theta)**4 + 1.51460119032828e+36*cos(theta)**2 - 3.4368077838173e+32)*cos(17*phi)

#@torch.jit.script
def Yl95_m18(theta, phi):
    return 1.4064238590253e-35*(1.0 - cos(theta)**2)**9*(1.62938902681212e+62*cos(theta)**77 - 2.5225356044721e+63*cos(theta)**75 + 1.87166746053745e+64*cos(theta)**73 - 8.86259835368004e+64*cos(theta)**71 + 3.00868263782717e+65*cos(theta)**69 - 7.79930327993651e+65*cos(theta)**67 + 1.60561075902604e+66*cos(theta)**65 - 2.69545631862321e+66*cos(theta)**63 + 3.76016156447938e+66*cos(theta)**61 - 4.41945771547672e+66*cos(theta)**59 + 4.42204219367291e+66*cos(theta)**57 - 3.7964385912329e+66*cos(theta)**55 + 2.81322919559923e+66*cos(theta)**53 - 1.8072866347486e+66*cos(theta)**51 + 1.0097679488626e+66*cos(theta)**49 - 4.91713088141789e+65*cos(theta)**47 + 2.08939405770941e+65*cos(theta)**45 - 7.75009410690265e+64*cos(theta)**43 + 2.50836379158892e+64*cos(theta)**41 - 7.0755359790262e+63*cos(theta)**39 + 1.73608349684054e+63*cos(theta)**37 - 3.69521127803067e+62*cos(theta)**35 + 6.79854888815166e+61*cos(theta)**33 - 1.07635196789927e+61*cos(theta)**31 + 1.45834401245094e+60*cos(theta)**29 - 1.67968133065271e+59*cos(theta)**27 + 1.63134517725263e+58*cos(theta)**25 - 1.3230698923379e+57*cos(theta)**23 + 8.855467797923e+55*cos(theta)**21 - 4.82148881919583e+54*cos(theta)**19 + 2.09789971522261e+53*cos(theta)**17 - 7.13464269242999e+51*cos(theta)**15 + 1.84335010508157e+50*cos(theta)**13 - 3.48560747142696e+48*cos(theta)**11 + 4.58413225558305e+46*cos(theta)**9 - 3.89678302717803e+44*cos(theta)**7 + 1.9101877584206e+42*cos(theta)**5 - 4.41253813448973e+39*cos(theta)**3 + 3.02920238065656e+36*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl95_m19(theta, phi):
    return 1.50113045851864e-37*(1.0 - cos(theta)**2)**9.5*(1.25462955064533e+64*cos(theta)**76 - 1.89190170335407e+65*cos(theta)**74 + 1.36631724619234e+66*cos(theta)**72 - 6.29244483111283e+66*cos(theta)**70 + 2.07599102010075e+67*cos(theta)**68 - 5.22553319755747e+67*cos(theta)**66 + 1.04364699336692e+68*cos(theta)**64 - 1.69813748073262e+68*cos(theta)**62 + 2.29369855433242e+68*cos(theta)**60 - 2.60748005213127e+68*cos(theta)**58 + 2.52056405039356e+68*cos(theta)**56 - 2.0880412251781e+68*cos(theta)**54 + 1.49101147366759e+68*cos(theta)**52 - 9.21716183721784e+67*cos(theta)**50 + 4.94786294942676e+67*cos(theta)**48 - 2.31105151426641e+67*cos(theta)**46 + 9.40227325969235e+66*cos(theta)**44 - 3.33254046596814e+66*cos(theta)**42 + 1.02842915455146e+66*cos(theta)**40 - 2.75945903182022e+65*cos(theta)**38 + 6.42350893830998e+64*cos(theta)**36 - 1.29332394731073e+64*cos(theta)**34 + 2.24352113309005e+63*cos(theta)**32 - 3.33669110048775e+62*cos(theta)**30 + 4.22919763610772e+61*cos(theta)**28 - 4.53513959276232e+60*cos(theta)**26 + 4.07836294313159e+59*cos(theta)**24 - 3.04306075237718e+58*cos(theta)**22 + 1.85964823756383e+57*cos(theta)**20 - 9.16082875647207e+55*cos(theta)**18 + 3.56642951587844e+54*cos(theta)**16 - 1.0701964038645e+53*cos(theta)**14 + 2.39635513660604e+51*cos(theta)**12 - 3.83416821856966e+49*cos(theta)**10 + 4.12571903002474e+47*cos(theta)**8 - 2.72774811902462e+45*cos(theta)**6 + 9.55093879210302e+42*cos(theta)**4 - 1.32376144034692e+40*cos(theta)**2 + 3.02920238065656e+36)*cos(19*phi)

#@torch.jit.script
def Yl95_m20(theta, phi):
    return 1.60569376406278e-39*(1.0 - cos(theta)**2)**10*(9.53518458490452e+65*cos(theta)**75 - 1.40000726048201e+67*cos(theta)**73 + 9.83748417258484e+67*cos(theta)**71 - 4.40471138177898e+68*cos(theta)**69 + 1.41167389366851e+69*cos(theta)**67 - 3.44885191038793e+69*cos(theta)**65 + 6.67934075754831e+69*cos(theta)**63 - 1.05284523805423e+70*cos(theta)**61 + 1.37621913259945e+70*cos(theta)**59 - 1.51233843023614e+70*cos(theta)**57 + 1.41151586822039e+70*cos(theta)**55 - 1.12754226159617e+70*cos(theta)**53 + 7.75325966307148e+69*cos(theta)**51 - 4.60858091860892e+69*cos(theta)**49 + 2.37497421572484e+69*cos(theta)**47 - 1.06308369656255e+69*cos(theta)**45 + 4.13700023426464e+68*cos(theta)**43 - 1.39966699570662e+68*cos(theta)**41 + 4.11371661820583e+67*cos(theta)**39 - 1.04859443209168e+67*cos(theta)**37 + 2.31246321779159e+66*cos(theta)**35 - 4.3973014208565e+65*cos(theta)**33 + 7.17926762588816e+64*cos(theta)**31 - 1.00100733014632e+64*cos(theta)**29 + 1.18417533811016e+63*cos(theta)**27 - 1.1791362941182e+62*cos(theta)**25 + 9.78807106351581e+60*cos(theta)**23 - 6.69473365522979e+59*cos(theta)**21 + 3.71929647512766e+58*cos(theta)**19 - 1.64894917616497e+57*cos(theta)**17 + 5.70628722540551e+55*cos(theta)**15 - 1.4982749654103e+54*cos(theta)**13 + 2.87562616392724e+52*cos(theta)**11 - 3.83416821856966e+50*cos(theta)**9 + 3.30057522401979e+48*cos(theta)**7 - 1.63664887141477e+46*cos(theta)**5 + 3.82037551684121e+43*cos(theta)**3 - 2.64752288069384e+40*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl95_m21(theta, phi):
    return 1.72148441156258e-41*(1.0 - cos(theta)**2)**10.5*(7.15138843867839e+67*cos(theta)**74 - 1.02200530015187e+69*cos(theta)**72 + 6.98461376253524e+69*cos(theta)**70 - 3.0392508534275e+70*cos(theta)**68 + 9.45821508757901e+70*cos(theta)**66 - 2.24175374175215e+71*cos(theta)**64 + 4.20798467725544e+71*cos(theta)**62 - 6.42235595213078e+71*cos(theta)**60 + 8.11969288233677e+71*cos(theta)**58 - 8.62032905234597e+71*cos(theta)**56 + 7.76333727521216e+71*cos(theta)**54 - 5.97597398645971e+71*cos(theta)**52 + 3.95416242816646e+71*cos(theta)**50 - 2.25820465011837e+71*cos(theta)**48 + 1.11623788139068e+71*cos(theta)**46 - 4.78387663453147e+70*cos(theta)**44 + 1.77891010073379e+70*cos(theta)**42 - 5.73863468239714e+69*cos(theta)**40 + 1.60434948110028e+69*cos(theta)**38 - 3.87979939873923e+68*cos(theta)**36 + 8.09362126227057e+67*cos(theta)**34 - 1.45110946888264e+67*cos(theta)**32 + 2.22557296402533e+66*cos(theta)**30 - 2.90292125742434e+65*cos(theta)**28 + 3.19727341289744e+64*cos(theta)**26 - 2.94784073529551e+63*cos(theta)**24 + 2.25125634460864e+62*cos(theta)**22 - 1.40589406759826e+61*cos(theta)**20 + 7.06666330274256e+59*cos(theta)**18 - 2.80321359948045e+58*cos(theta)**16 + 8.55943083810826e+56*cos(theta)**14 - 1.94775745503339e+55*cos(theta)**12 + 3.16318878031997e+53*cos(theta)**10 - 3.45075139671269e+51*cos(theta)**8 + 2.31040265681386e+49*cos(theta)**6 - 8.18324435707387e+46*cos(theta)**4 + 1.14611265505236e+44*cos(theta)**2 - 2.64752288069384e+40)*cos(21*phi)

#@torch.jit.script
def Yl95_m22(theta, phi):
    return 1.85009616828234e-43*(1.0 - cos(theta)**2)**11*(5.29202744462201e+69*cos(theta)**73 - 7.35843816109346e+70*cos(theta)**71 + 4.88922963377467e+71*cos(theta)**69 - 2.0666905803307e+72*cos(theta)**67 + 6.24242195780215e+72*cos(theta)**65 - 1.43472239472138e+73*cos(theta)**63 + 2.60895049989837e+73*cos(theta)**61 - 3.85341357127847e+73*cos(theta)**59 + 4.70942187175532e+73*cos(theta)**57 - 4.82738426931374e+73*cos(theta)**55 + 4.19220212861457e+73*cos(theta)**53 - 3.10750647295905e+73*cos(theta)**51 + 1.97708121408323e+73*cos(theta)**49 - 1.08393823205682e+73*cos(theta)**47 + 5.13469425439711e+72*cos(theta)**45 - 2.10490571919385e+72*cos(theta)**43 + 7.47142242308193e+71*cos(theta)**41 - 2.29545387295886e+71*cos(theta)**39 + 6.09652802818105e+70*cos(theta)**37 - 1.39672778354612e+70*cos(theta)**35 + 2.751831229172e+69*cos(theta)**33 - 4.64355030042446e+68*cos(theta)**31 + 6.67671889207599e+67*cos(theta)**29 - 8.12817952078816e+66*cos(theta)**27 + 8.31291087353334e+65*cos(theta)**25 - 7.07481776470923e+64*cos(theta)**23 + 4.952763958139e+63*cos(theta)**21 - 2.81178813519651e+62*cos(theta)**19 + 1.27199939449366e+61*cos(theta)**17 - 4.48514175916873e+59*cos(theta)**15 + 1.19832031733516e+58*cos(theta)**13 - 2.33730894604006e+56*cos(theta)**11 + 3.16318878031997e+54*cos(theta)**9 - 2.76060111737016e+52*cos(theta)**7 + 1.38624159408831e+50*cos(theta)**5 - 3.27329774282955e+47*cos(theta)**3 + 2.29222531010472e+44*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl95_m23(theta, phi):
    return 1.99338813975248e-45*(1.0 - cos(theta)**2)**11.5*(3.86318003457407e+71*cos(theta)**72 - 5.22449109437636e+72*cos(theta)**70 + 3.37356844730452e+73*cos(theta)**68 - 1.38468268882157e+74*cos(theta)**66 + 4.0575742725714e+74*cos(theta)**64 - 9.03875108674468e+74*cos(theta)**62 + 1.59145980493801e+75*cos(theta)**60 - 2.27351400705429e+75*cos(theta)**58 + 2.68437046690053e+75*cos(theta)**56 - 2.65506134812256e+75*cos(theta)**54 + 2.22186712816572e+75*cos(theta)**52 - 1.58482830120912e+75*cos(theta)**50 + 9.68769794900781e+74*cos(theta)**48 - 5.09450969066705e+74*cos(theta)**46 + 2.3106124144787e+74*cos(theta)**44 - 9.05109459253354e+73*cos(theta)**42 + 3.06328319346359e+73*cos(theta)**40 - 8.95227010453954e+72*cos(theta)**38 + 2.25571537042699e+72*cos(theta)**36 - 4.88854724241143e+71*cos(theta)**34 + 9.08104305626758e+70*cos(theta)**32 - 1.43950059313158e+70*cos(theta)**30 + 1.93624847870204e+69*cos(theta)**28 - 2.1946084706128e+68*cos(theta)**26 + 2.07822771838334e+67*cos(theta)**24 - 1.62720808588312e+66*cos(theta)**22 + 1.04008043120919e+65*cos(theta)**20 - 5.34239745687337e+63*cos(theta)**18 + 2.16239897063922e+62*cos(theta)**16 - 6.72771263875309e+60*cos(theta)**14 + 1.5578164125357e+59*cos(theta)**12 - 2.57103984064407e+57*cos(theta)**10 + 2.84686990228797e+55*cos(theta)**8 - 1.93242078215911e+53*cos(theta)**6 + 6.93120797044157e+50*cos(theta)**4 - 9.81989322848864e+47*cos(theta)**2 + 2.29222531010472e+44)*cos(23*phi)

#@torch.jit.script
def Yl95_m24(theta, phi):
    return 2.1535360244538e-47*(1.0 - cos(theta)**2)**12*(2.78148962489333e+73*cos(theta)**71 - 3.65714376606345e+74*cos(theta)**69 + 2.29402654416707e+75*cos(theta)**67 - 9.13890574622234e+75*cos(theta)**65 + 2.59684753444569e+76*cos(theta)**63 - 5.6040256737817e+76*cos(theta)**61 + 9.54875882962804e+76*cos(theta)**59 - 1.31863812409149e+77*cos(theta)**57 + 1.5032474614643e+77*cos(theta)**55 - 1.43373312798618e+77*cos(theta)**53 + 1.15537090664617e+77*cos(theta)**51 - 7.92414150604558e+76*cos(theta)**49 + 4.65009501552375e+76*cos(theta)**47 - 2.34347445770684e+76*cos(theta)**45 + 1.01666946237063e+76*cos(theta)**43 - 3.80145972886409e+75*cos(theta)**41 + 1.22531327738544e+75*cos(theta)**39 - 3.40186263972502e+74*cos(theta)**37 + 8.12057533353715e+73*cos(theta)**35 - 1.66210606241988e+73*cos(theta)**33 + 2.90593377800563e+72*cos(theta)**31 - 4.31850177939475e+71*cos(theta)**29 + 5.4214957403657e+70*cos(theta)**27 - 5.70598202359329e+69*cos(theta)**25 + 4.98774652412001e+68*cos(theta)**23 - 3.57985778894287e+67*cos(theta)**21 + 2.08016086241838e+66*cos(theta)**19 - 9.61631542237207e+64*cos(theta)**17 + 3.45983835302276e+63*cos(theta)**15 - 9.41879769425433e+61*cos(theta)**13 + 1.86937969504284e+60*cos(theta)**11 - 2.57103984064407e+58*cos(theta)**9 + 2.27749592183038e+56*cos(theta)**7 - 1.15945246929546e+54*cos(theta)**5 + 2.77248318817663e+51*cos(theta)**3 - 1.96397864569773e+48*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl95_m25(theta, phi):
    return 2.33309457412421e-49*(1.0 - cos(theta)**2)**12.5*(1.97485763367426e+75*cos(theta)**70 - 2.52342919858378e+76*cos(theta)**68 + 1.53699778459194e+77*cos(theta)**66 - 5.94028873504452e+77*cos(theta)**64 + 1.63601394670079e+78*cos(theta)**62 - 3.41845566100684e+78*cos(theta)**60 + 5.63376770948054e+78*cos(theta)**58 - 7.5162373073215e+78*cos(theta)**56 + 8.26786103805365e+78*cos(theta)**54 - 7.59878557832676e+78*cos(theta)**52 + 5.89239162389549e+78*cos(theta)**50 - 3.88282933796233e+78*cos(theta)**48 + 2.18554465729616e+78*cos(theta)**46 - 1.05456350596808e+78*cos(theta)**44 + 4.3716786881937e+77*cos(theta)**42 - 1.55859848883428e+77*cos(theta)**40 + 4.7787217818032e+76*cos(theta)**38 - 1.25868917669826e+76*cos(theta)**36 + 2.842201366738e+75*cos(theta)**34 - 5.48495000598562e+74*cos(theta)**32 + 9.00839471181744e+73*cos(theta)**30 - 1.25236551602448e+73*cos(theta)**28 + 1.46380384989874e+72*cos(theta)**26 - 1.42649550589832e+71*cos(theta)**24 + 1.1471817005476e+70*cos(theta)**22 - 7.51770135678002e+68*cos(theta)**20 + 3.95230563859492e+67*cos(theta)**18 - 1.63477362180325e+66*cos(theta)**16 + 5.18975752953413e+64*cos(theta)**14 - 1.22444370025306e+63*cos(theta)**12 + 2.05631766454713e+61*cos(theta)**10 - 2.31393585657966e+59*cos(theta)**8 + 1.59424714528126e+57*cos(theta)**6 - 5.79726234647733e+54*cos(theta)**4 + 8.31744956452988e+51*cos(theta)**2 - 1.96397864569773e+48)*cos(25*phi)

#@torch.jit.script
def Yl95_m26(theta, phi):
    return 2.53507398479645e-51*(1.0 - cos(theta)**2)**13*(1.38240034357198e+77*cos(theta)**69 - 1.71593185503697e+78*cos(theta)**67 + 1.01441853783068e+79*cos(theta)**65 - 3.8017847904285e+79*cos(theta)**63 + 1.01432864695449e+80*cos(theta)**61 - 2.0510733966041e+80*cos(theta)**59 + 3.26758527149871e+80*cos(theta)**57 - 4.20909289210004e+80*cos(theta)**55 + 4.46464496054897e+80*cos(theta)**53 - 3.95136850072992e+80*cos(theta)**51 + 2.94619581194775e+80*cos(theta)**49 - 1.86375808222192e+80*cos(theta)**47 + 1.00535054235623e+80*cos(theta)**45 - 4.64007942625955e+79*cos(theta)**43 + 1.83610504904135e+79*cos(theta)**41 - 6.2343939553371e+78*cos(theta)**39 + 1.81591427708522e+78*cos(theta)**37 - 4.53128103611373e+77*cos(theta)**35 + 9.66348464690921e+76*cos(theta)**33 - 1.7551840019154e+76*cos(theta)**31 + 2.70251841354523e+75*cos(theta)**29 - 3.50662344486853e+74*cos(theta)**27 + 3.80589000973672e+73*cos(theta)**25 - 3.42358921415597e+72*cos(theta)**23 + 2.52379974120472e+71*cos(theta)**21 - 1.503540271356e+70*cos(theta)**19 + 7.11415014947086e+68*cos(theta)**17 - 2.6156377948852e+67*cos(theta)**15 + 7.26566054134779e+65*cos(theta)**13 - 1.46933244030367e+64*cos(theta)**11 + 2.05631766454713e+62*cos(theta)**9 - 1.85114868526373e+60*cos(theta)**7 + 9.56548287168759e+57*cos(theta)**5 - 2.31890493859093e+55*cos(theta)**3 + 1.66348991290598e+52*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl95_m27(theta, phi):
    return 2.76303367377826e-53*(1.0 - cos(theta)**2)**13.5*(9.53856237064669e+78*cos(theta)**68 - 1.14967434287477e+80*cos(theta)**66 + 6.59372049589942e+80*cos(theta)**64 - 2.39512441796995e+81*cos(theta)**62 + 6.18740474642238e+81*cos(theta)**60 - 1.21013330399642e+82*cos(theta)**58 + 1.86252360475427e+82*cos(theta)**56 - 2.31500109065502e+82*cos(theta)**54 + 2.36626182909095e+82*cos(theta)**52 - 2.01519793537226e+82*cos(theta)**50 + 1.4436359478544e+82*cos(theta)**48 - 8.75966298644302e+81*cos(theta)**46 + 4.52407744060306e+81*cos(theta)**44 - 1.9952341532916e+81*cos(theta)**42 + 7.52803070106955e+80*cos(theta)**40 - 2.43141364258147e+80*cos(theta)**38 + 6.7188828252153e+79*cos(theta)**36 - 1.58594836263981e+79*cos(theta)**34 + 3.18894993348004e+78*cos(theta)**32 - 5.44107040593774e+77*cos(theta)**30 + 7.83730339928118e+76*cos(theta)**28 - 9.46788330114504e+75*cos(theta)**26 + 9.5147250243418e+74*cos(theta)**24 - 7.87425519255873e+73*cos(theta)**22 + 5.29997945652992e+72*cos(theta)**20 - 2.85672651557641e+71*cos(theta)**18 + 1.20940552541005e+70*cos(theta)**16 - 3.92345669232781e+68*cos(theta)**14 + 9.44535870375212e+66*cos(theta)**12 - 1.61626568433404e+65*cos(theta)**10 + 1.85068589809242e+63*cos(theta)**8 - 1.29580407968461e+61*cos(theta)**6 + 4.78274143584379e+58*cos(theta)**4 - 6.95671481577279e+55*cos(theta)**2 + 1.66348991290598e+52)*cos(27*phi)

#@torch.jit.script
def Yl95_m28(theta, phi):
    return 3.02119784141626e-55*(1.0 - cos(theta)**2)**14*(6.48622241203975e+80*cos(theta)**67 - 7.58785066297349e+81*cos(theta)**65 + 4.21998111737563e+82*cos(theta)**63 - 1.48497713914137e+83*cos(theta)**61 + 3.71244284785343e+83*cos(theta)**59 - 7.01877316317924e+83*cos(theta)**57 + 1.04301321866239e+84*cos(theta)**55 - 1.25010058895371e+84*cos(theta)**53 + 1.2304561511273e+84*cos(theta)**51 - 1.00759896768613e+84*cos(theta)**49 + 6.9294525497011e+83*cos(theta)**47 - 4.02944497376379e+83*cos(theta)**45 + 1.99059407386535e+83*cos(theta)**43 - 8.37998344382474e+82*cos(theta)**41 + 3.01121228042782e+82*cos(theta)**39 - 9.23937184180959e+81*cos(theta)**37 + 2.41879781707751e+81*cos(theta)**35 - 5.39222443297534e+80*cos(theta)**33 + 1.02046397871361e+80*cos(theta)**31 - 1.63232112178132e+79*cos(theta)**29 + 2.19444495179873e+78*cos(theta)**27 - 2.46164965829771e+77*cos(theta)**25 + 2.28353400584203e+76*cos(theta)**23 - 1.73233614236292e+75*cos(theta)**21 + 1.05999589130598e+74*cos(theta)**19 - 5.14210772803754e+72*cos(theta)**17 + 1.93504884065607e+71*cos(theta)**15 - 5.49283936925893e+69*cos(theta)**13 + 1.13344304445025e+68*cos(theta)**11 - 1.61626568433404e+66*cos(theta)**9 + 1.48054871847393e+64*cos(theta)**7 - 7.77482447810767e+61*cos(theta)**5 + 1.91309657433752e+59*cos(theta)**3 - 1.39134296315456e+56*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl95_m29(theta, phi):
    return 3.31459844134536e-57*(1.0 - cos(theta)**2)**14.5*(4.34576901606663e+82*cos(theta)**66 - 4.93210293093277e+83*cos(theta)**64 + 2.65858810394665e+84*cos(theta)**62 - 9.05836054876236e+84*cos(theta)**60 + 2.19034128023352e+85*cos(theta)**58 - 4.00070070301217e+85*cos(theta)**56 + 5.73657270264314e+85*cos(theta)**54 - 6.62553312145467e+85*cos(theta)**52 + 6.27532637074921e+85*cos(theta)**50 - 4.93723494166203e+85*cos(theta)**48 + 3.25684269835952e+85*cos(theta)**46 - 1.81325023819371e+85*cos(theta)**44 + 8.55955451762098e+84*cos(theta)**42 - 3.43579321196814e+84*cos(theta)**40 + 1.17437278936685e+84*cos(theta)**38 - 3.41856758146955e+83*cos(theta)**36 + 8.46579235977128e+82*cos(theta)**34 - 1.77943406288186e+82*cos(theta)**32 + 3.1634383340122e+81*cos(theta)**30 - 4.73373125316583e+80*cos(theta)**28 + 5.92500136985657e+79*cos(theta)**26 - 6.15412414574428e+78*cos(theta)**24 + 5.25212821343668e+77*cos(theta)**22 - 3.63790589896214e+76*cos(theta)**20 + 2.01399219348137e+75*cos(theta)**18 - 8.74158313766381e+73*cos(theta)**16 + 2.90257326098411e+72*cos(theta)**14 - 7.14069118003661e+70*cos(theta)**12 + 1.24678734889528e+69*cos(theta)**10 - 1.45463911590064e+67*cos(theta)**8 + 1.03638410293175e+65*cos(theta)**6 - 3.88741223905384e+62*cos(theta)**4 + 5.73928972301255e+59*cos(theta)**2 - 1.39134296315456e+56)*cos(29*phi)

#@torch.jit.script
def Yl95_m30(theta, phi):
    return 3.64925277986555e-59*(1.0 - cos(theta)**2)**15*(2.86820755060398e+84*cos(theta)**65 - 3.15654587579697e+85*cos(theta)**63 + 1.64832462444692e+86*cos(theta)**61 - 5.43501632925742e+86*cos(theta)**59 + 1.27039794253544e+87*cos(theta)**57 - 2.24039239368681e+87*cos(theta)**55 + 3.0977492594273e+87*cos(theta)**53 - 3.44527722315643e+87*cos(theta)**51 + 3.13766318537461e+87*cos(theta)**49 - 2.36987277199778e+87*cos(theta)**47 + 1.49814764124538e+87*cos(theta)**45 - 7.9783010480523e+86*cos(theta)**43 + 3.59501289740081e+86*cos(theta)**41 - 1.37431728478726e+86*cos(theta)**39 + 4.46261659959403e+85*cos(theta)**37 - 1.23068432932904e+85*cos(theta)**35 + 2.87836940232224e+84*cos(theta)**33 - 5.69418900122196e+83*cos(theta)**31 + 9.4903150020366e+82*cos(theta)**29 - 1.32544475088643e+82*cos(theta)**27 + 1.54050035616271e+81*cos(theta)**25 - 1.47698979497863e+80*cos(theta)**23 + 1.15546820695607e+79*cos(theta)**21 - 7.27581179792427e+77*cos(theta)**19 + 3.62518594826646e+76*cos(theta)**17 - 1.39865330202621e+75*cos(theta)**15 + 4.06360256537775e+73*cos(theta)**13 - 8.56882941604393e+71*cos(theta)**11 + 1.24678734889528e+70*cos(theta)**9 - 1.16371129272051e+68*cos(theta)**7 + 6.21830461759051e+65*cos(theta)**5 - 1.55496489562153e+63*cos(theta)**3 + 1.14785794460251e+60*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl95_m31(theta, phi):
    return 4.03238505659312e-61*(1.0 - cos(theta)**2)**15.5*(1.86433490789259e+86*cos(theta)**64 - 1.98862390175209e+87*cos(theta)**62 + 1.00547802091262e+88*cos(theta)**60 - 3.20665963426188e+88*cos(theta)**58 + 7.24126827245202e+88*cos(theta)**56 - 1.23221581652775e+89*cos(theta)**54 + 1.64180710749647e+89*cos(theta)**52 - 1.75709138380978e+89*cos(theta)**50 + 1.53745496083356e+89*cos(theta)**48 - 1.11384020283895e+89*cos(theta)**46 + 6.7416643856042e+88*cos(theta)**44 - 3.43066945066249e+88*cos(theta)**42 + 1.47395528793433e+88*cos(theta)**40 - 5.3598374106703e+87*cos(theta)**38 + 1.65116814184979e+87*cos(theta)**36 - 4.30739515265163e+86*cos(theta)**34 + 9.49861902766338e+85*cos(theta)**32 - 1.76519859037881e+85*cos(theta)**30 + 2.75219135059061e+84*cos(theta)**28 - 3.57870082739337e+83*cos(theta)**26 + 3.85125089040677e+82*cos(theta)**24 - 3.39707652845084e+81*cos(theta)**22 + 2.42648323460774e+80*cos(theta)**20 - 1.38240424160561e+79*cos(theta)**18 + 6.16281611205299e+77*cos(theta)**16 - 2.09797995303932e+76*cos(theta)**14 + 5.28268333499108e+74*cos(theta)**12 - 9.42571235764832e+72*cos(theta)**10 + 1.12210861400575e+71*cos(theta)**8 - 8.14597904904357e+68*cos(theta)**6 + 3.10915230879526e+66*cos(theta)**4 - 4.6648946868646e+63*cos(theta)**2 + 1.14785794460251e+60)*cos(31*phi)

#@torch.jit.script
def Yl95_m32(theta, phi):
    return 4.47270391055021e-63*(1.0 - cos(theta)**2)**16*(1.19317434105126e+88*cos(theta)**63 - 1.2329468190863e+89*cos(theta)**61 + 6.03286812547573e+89*cos(theta)**59 - 1.85986258787189e+90*cos(theta)**57 + 4.05511023257313e+90*cos(theta)**55 - 6.65396540924984e+90*cos(theta)**53 + 8.53739695898163e+90*cos(theta)**51 - 8.78545691904889e+90*cos(theta)**49 + 7.37978381200107e+90*cos(theta)**47 - 5.12366493305919e+90*cos(theta)**45 + 2.96633232966585e+90*cos(theta)**43 - 1.44088116927825e+90*cos(theta)**41 + 5.89582115173733e+89*cos(theta)**39 - 2.03673821605472e+89*cos(theta)**37 + 5.94420531065925e+88*cos(theta)**35 - 1.46451435190155e+88*cos(theta)**33 + 3.03955808885228e+87*cos(theta)**31 - 5.29559577113642e+86*cos(theta)**29 + 7.70613578165372e+85*cos(theta)**27 - 9.30462215122275e+84*cos(theta)**25 + 9.24300213697625e+83*cos(theta)**23 - 7.47356836259185e+82*cos(theta)**21 + 4.85296646921549e+81*cos(theta)**19 - 2.4883276348901e+80*cos(theta)**17 + 9.86050577928478e+78*cos(theta)**15 - 2.93717193425504e+77*cos(theta)**13 + 6.3392200019893e+75*cos(theta)**11 - 9.42571235764832e+73*cos(theta)**9 + 8.97686891204602e+71*cos(theta)**7 - 4.88758742942614e+69*cos(theta)**5 + 1.2436609235181e+67*cos(theta)**3 - 9.3297893737292e+63*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl95_m33(theta, phi):
    return 4.9807516743342e-65*(1.0 - cos(theta)**2)**16.5*(7.51699834862291e+89*cos(theta)**62 - 7.52097559642641e+90*cos(theta)**60 + 3.55939219403068e+91*cos(theta)**58 - 1.06012167508698e+92*cos(theta)**56 + 2.23031062791522e+92*cos(theta)**54 - 3.52660166690241e+92*cos(theta)**52 + 4.35407244908063e+92*cos(theta)**50 - 4.30487389033396e+92*cos(theta)**48 + 3.4684983916405e+92*cos(theta)**46 - 2.30564921987664e+92*cos(theta)**44 + 1.27552290175631e+92*cos(theta)**42 - 5.90761279404081e+91*cos(theta)**40 + 2.29937024917756e+91*cos(theta)**38 - 7.53593139940245e+90*cos(theta)**36 + 2.08047185873074e+90*cos(theta)**34 - 4.83289736127513e+89*cos(theta)**32 + 9.42263007544207e+88*cos(theta)**30 - 1.53572277362956e+88*cos(theta)**28 + 2.0806566610465e+87*cos(theta)**26 - 2.32615553780569e+86*cos(theta)**24 + 2.12589049150454e+85*cos(theta)**22 - 1.56944935614429e+84*cos(theta)**20 + 9.22063629150943e+82*cos(theta)**18 - 4.23015697931317e+81*cos(theta)**16 + 1.47907586689272e+80*cos(theta)**14 - 3.81832351453155e+78*cos(theta)**12 + 6.97314200218823e+76*cos(theta)**10 - 8.48314112188349e+74*cos(theta)**8 + 6.28380823843221e+72*cos(theta)**6 - 2.44379371471307e+70*cos(theta)**4 + 3.73098277055431e+67*cos(theta)**2 - 9.3297893737292e+63)*cos(33*phi)

#@torch.jit.script
def Yl95_m34(theta, phi):
    return 5.56934587317868e-67*(1.0 - cos(theta)**2)**17*(4.6605389761462e+91*cos(theta)**61 - 4.51258535785585e+92*cos(theta)**59 + 2.0644474725378e+93*cos(theta)**57 - 5.93668138048706e+93*cos(theta)**55 + 1.20436773907422e+94*cos(theta)**53 - 1.83383286678925e+94*cos(theta)**51 + 2.17703622454032e+94*cos(theta)**49 - 2.0663394673603e+94*cos(theta)**47 + 1.59550926015463e+94*cos(theta)**45 - 1.01448565674572e+94*cos(theta)**43 + 5.35719618737652e+93*cos(theta)**41 - 2.36304511761632e+93*cos(theta)**39 + 8.73760694687473e+92*cos(theta)**37 - 2.71293530378488e+92*cos(theta)**35 + 7.07360431968451e+91*cos(theta)**33 - 1.54652715560804e+91*cos(theta)**31 + 2.82678902263262e+90*cos(theta)**29 - 4.30002376616277e+89*cos(theta)**27 + 5.40970731872091e+88*cos(theta)**25 - 5.58277329073365e+87*cos(theta)**23 + 4.67695908130998e+86*cos(theta)**21 - 3.13889871228858e+85*cos(theta)**19 + 1.6597145324717e+84*cos(theta)**17 - 6.76825116690107e+82*cos(theta)**15 + 2.0707062136498e+81*cos(theta)**13 - 4.58198821743786e+79*cos(theta)**11 + 6.97314200218823e+77*cos(theta)**9 - 6.78651289750679e+75*cos(theta)**7 + 3.77028494305933e+73*cos(theta)**5 - 9.77517485885229e+70*cos(theta)**3 + 7.46196554110862e+67*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl95_m35(theta, phi):
    return 6.25413996102351e-69*(1.0 - cos(theta)**2)**17.5*(2.84292877544918e+93*cos(theta)**60 - 2.66242536113495e+94*cos(theta)**58 + 1.17673505934654e+95*cos(theta)**56 - 3.26517475926789e+95*cos(theta)**54 + 6.38314901709337e+95*cos(theta)**52 - 9.3525476206252e+95*cos(theta)**50 + 1.06674775002475e+96*cos(theta)**48 - 9.71179549659341e+95*cos(theta)**46 + 7.17979167069584e+95*cos(theta)**44 - 4.36228832400659e+95*cos(theta)**42 + 2.19645043682437e+95*cos(theta)**40 - 9.21587595870366e+94*cos(theta)**38 + 3.23291457034365e+94*cos(theta)**36 - 9.49527356324708e+93*cos(theta)**34 + 2.33428942549589e+93*cos(theta)**32 - 4.79423418238493e+92*cos(theta)**30 + 8.1976881656346e+91*cos(theta)**28 - 1.16100641686395e+91*cos(theta)**26 + 1.35242682968023e+90*cos(theta)**24 - 1.28403785686874e+89*cos(theta)**22 + 9.82161407075096e+87*cos(theta)**20 - 5.9639075533483e+86*cos(theta)**18 + 2.82151470520188e+85*cos(theta)**16 - 1.01523767503516e+84*cos(theta)**14 + 2.69191807774475e+82*cos(theta)**12 - 5.04018703918165e+80*cos(theta)**10 + 6.2758278019694e+78*cos(theta)**8 - 4.75055902825475e+76*cos(theta)**6 + 1.88514247152966e+74*cos(theta)**4 - 2.93255245765569e+71*cos(theta)**2 + 7.46196554110862e+67)*cos(35*phi)

#@torch.jit.script
def Yl95_m36(theta, phi):
    return 7.05433895064767e-71*(1.0 - cos(theta)**2)**18*(1.70575726526951e+95*cos(theta)**59 - 1.54420670945827e+96*cos(theta)**57 + 6.58971633234064e+96*cos(theta)**55 - 1.76319437000466e+97*cos(theta)**53 + 3.31923748888855e+97*cos(theta)**51 - 4.6762738103126e+97*cos(theta)**49 + 5.12038920011882e+97*cos(theta)**47 - 4.46742592843297e+97*cos(theta)**45 + 3.15910833510617e+97*cos(theta)**43 - 1.83216109608277e+97*cos(theta)**41 + 8.78580174729749e+96*cos(theta)**39 - 3.50203286430739e+96*cos(theta)**37 + 1.16384924532371e+96*cos(theta)**35 - 3.22839301150401e+95*cos(theta)**33 + 7.46972616158684e+94*cos(theta)**31 - 1.43827025471548e+94*cos(theta)**29 + 2.29535268637769e+93*cos(theta)**27 - 3.01861668384627e+92*cos(theta)**25 + 3.24582439123255e+91*cos(theta)**23 - 2.82488328511123e+90*cos(theta)**21 + 1.96432281415019e+89*cos(theta)**19 - 1.07350335960269e+88*cos(theta)**17 + 4.51442352832302e+86*cos(theta)**15 - 1.42133274504923e+85*cos(theta)**13 + 3.23030169329369e+83*cos(theta)**11 - 5.04018703918165e+81*cos(theta)**9 + 5.02066224157552e+79*cos(theta)**7 - 2.85033541695285e+77*cos(theta)**5 + 7.54056988611866e+74*cos(theta)**3 - 5.86510491531137e+71*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl95_m37(theta, phi):
    return 7.99361728806196e-73*(1.0 - cos(theta)**2)**18.5*(1.00639678650901e+97*cos(theta)**58 - 8.80197824391214e+97*cos(theta)**56 + 3.62434398278735e+98*cos(theta)**54 - 9.34493016102469e+98*cos(theta)**52 + 1.69281111933316e+99*cos(theta)**50 - 2.29137416705317e+99*cos(theta)**48 + 2.40658292405585e+99*cos(theta)**46 - 2.01034166779484e+99*cos(theta)**44 + 1.35841658409565e+99*cos(theta)**42 - 7.51186049393935e+98*cos(theta)**40 + 3.42646268144602e+98*cos(theta)**38 - 1.29575215979373e+98*cos(theta)**36 + 4.073472358633e+97*cos(theta)**34 - 1.06536969379632e+97*cos(theta)**32 + 2.31561511009192e+96*cos(theta)**30 - 4.17098373867489e+95*cos(theta)**28 + 6.19745225321976e+94*cos(theta)**26 - 7.54654170961567e+93*cos(theta)**24 + 7.46539609983486e+92*cos(theta)**22 - 5.93225489873358e+91*cos(theta)**20 + 3.73221334688536e+90*cos(theta)**18 - 1.82495571132458e+89*cos(theta)**16 + 6.77163529248452e+87*cos(theta)**14 - 1.84773256856399e+86*cos(theta)**12 + 3.55333186262306e+84*cos(theta)**10 - 4.53616833526349e+82*cos(theta)**8 + 3.51446356910287e+80*cos(theta)**6 - 1.42516770847643e+78*cos(theta)**4 + 2.2621709658356e+75*cos(theta)**2 - 5.86510491531137e+71)*cos(37*phi)

#@torch.jit.script
def Yl95_m38(theta, phi):
    return 9.10130218782643e-75*(1.0 - cos(theta)**2)**19*(5.83710136175226e+98*cos(theta)**57 - 4.9291078165908e+99*cos(theta)**55 + 1.95714575070517e+100*cos(theta)**53 - 4.85936368373284e+100*cos(theta)**51 + 8.4640555966658e+100*cos(theta)**49 - 1.09985960018552e+101*cos(theta)**47 + 1.10702814506569e+101*cos(theta)**45 - 8.84550333829728e+100*cos(theta)**43 + 5.70534965320174e+100*cos(theta)**41 - 3.00474419757574e+100*cos(theta)**39 + 1.30205581894949e+100*cos(theta)**37 - 4.66470777525745e+99*cos(theta)**35 + 1.38498060193522e+99*cos(theta)**33 - 3.40918302014823e+98*cos(theta)**31 + 6.94684533027576e+97*cos(theta)**29 - 1.16787544682897e+97*cos(theta)**27 + 1.61133758583714e+96*cos(theta)**25 - 1.81117001030776e+95*cos(theta)**23 + 1.64238714196367e+94*cos(theta)**21 - 1.18645097974672e+93*cos(theta)**19 + 6.71798402439366e+91*cos(theta)**17 - 2.91992913811933e+90*cos(theta)**15 + 9.48028940947833e+88*cos(theta)**13 - 2.21727908227679e+87*cos(theta)**11 + 3.55333186262306e+85*cos(theta)**9 - 3.62893466821079e+83*cos(theta)**7 + 2.10867814146172e+81*cos(theta)**5 - 5.7006708339057e+78*cos(theta)**3 + 4.52434193167119e+75*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl95_m39(theta, phi):
    return 1.0413907297102e-76*(1.0 - cos(theta)**2)**19.5*(3.32714777619879e+100*cos(theta)**56 - 2.71100929912494e+101*cos(theta)**54 + 1.03728724787374e+102*cos(theta)**52 - 2.47827547870375e+102*cos(theta)**50 + 4.14738724236624e+102*cos(theta)**48 - 5.16934012087196e+102*cos(theta)**46 + 4.9816266527956e+102*cos(theta)**44 - 3.80356643546783e+102*cos(theta)**42 + 2.33919335781271e+102*cos(theta)**40 - 1.17185023705454e+102*cos(theta)**38 + 4.81760653011311e+101*cos(theta)**36 - 1.63264772134011e+101*cos(theta)**34 + 4.57043598638622e+100*cos(theta)**32 - 1.05684673624595e+100*cos(theta)**30 + 2.01458514577997e+99*cos(theta)**28 - 3.15326370643821e+98*cos(theta)**26 + 4.02834396459284e+97*cos(theta)**24 - 4.16569102370785e+96*cos(theta)**22 + 3.4490129981237e+95*cos(theta)**20 - 2.25425686151876e+94*cos(theta)**18 + 1.14205728414692e+93*cos(theta)**16 - 4.37989370717899e+91*cos(theta)**14 + 1.23243762323218e+90*cos(theta)**12 - 2.43900699050447e+88*cos(theta)**10 + 3.19799867636076e+86*cos(theta)**8 - 2.54025426774755e+84*cos(theta)**6 + 1.05433907073086e+82*cos(theta)**4 - 1.71020125017171e+79*cos(theta)**2 + 4.52434193167119e+75)*cos(39*phi)

#@torch.jit.script
def Yl95_m40(theta, phi):
    return 1.19771312731902e-78*(1.0 - cos(theta)**2)**20*(1.86320275467132e+102*cos(theta)**55 - 1.46394502152747e+103*cos(theta)**53 + 5.39389368894345e+103*cos(theta)**51 - 1.23913773935187e+104*cos(theta)**49 + 1.9907458763358e+104*cos(theta)**47 - 2.3778964556011e+104*cos(theta)**45 + 2.19191572723007e+104*cos(theta)**43 - 1.59749790289649e+104*cos(theta)**41 + 9.35677343125086e+103*cos(theta)**39 - 4.45303090080725e+103*cos(theta)**37 + 1.73433835084072e+103*cos(theta)**35 - 5.55100225255636e+102*cos(theta)**33 + 1.46253951564359e+102*cos(theta)**31 - 3.17054020873786e+101*cos(theta)**29 + 5.64083840818392e+100*cos(theta)**27 - 8.19848563673936e+99*cos(theta)**25 + 9.66802551502283e+98*cos(theta)**23 - 9.16452025215727e+97*cos(theta)**21 + 6.89802599624741e+96*cos(theta)**19 - 4.05766235073377e+95*cos(theta)**17 + 1.82729165463507e+94*cos(theta)**15 - 6.13185119005059e+92*cos(theta)**13 + 1.47892514787862e+91*cos(theta)**11 - 2.43900699050447e+89*cos(theta)**9 + 2.55839894108861e+87*cos(theta)**7 - 1.52415256064853e+85*cos(theta)**5 + 4.21735628292344e+82*cos(theta)**3 - 3.42040250034342e+79*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl95_m41(theta, phi):
    return 1.38484768914446e-80*(1.0 - cos(theta)**2)**20.5*(1.02476151506923e+104*cos(theta)**54 - 7.75890861409558e+104*cos(theta)**52 + 2.75088578136116e+105*cos(theta)**50 - 6.07177492282418e+105*cos(theta)**48 + 9.35650561877825e+105*cos(theta)**46 - 1.0700534050205e+106*cos(theta)**44 + 9.42523762708928e+105*cos(theta)**42 - 6.5497414018756e+105*cos(theta)**40 + 3.64914163818784e+105*cos(theta)**38 - 1.64762143329868e+105*cos(theta)**36 + 6.07018422794251e+104*cos(theta)**34 - 1.8318307433436e+104*cos(theta)**32 + 4.53387249849513e+103*cos(theta)**30 - 9.19456660533978e+102*cos(theta)**28 + 1.52302637020966e+102*cos(theta)**26 - 2.04962140918484e+101*cos(theta)**24 + 2.22364586845525e+100*cos(theta)**22 - 1.92454925295303e+99*cos(theta)**20 + 1.31062493928701e+98*cos(theta)**18 - 6.89802599624741e+96*cos(theta)**16 + 2.74093748195261e+95*cos(theta)**14 - 7.97140654706576e+93*cos(theta)**12 + 1.62681766266648e+92*cos(theta)**10 - 2.19510629145402e+90*cos(theta)**8 + 1.79087925876202e+88*cos(theta)**6 - 7.62076280324266e+85*cos(theta)**4 + 1.26520688487703e+83*cos(theta)**2 - 3.42040250034342e+79)*cos(41*phi)

#@torch.jit.script
def Yl95_m42(theta, phi):
    return 1.61007033060363e-82*(1.0 - cos(theta)**2)**21*(5.53371218137383e+105*cos(theta)**53 - 4.0346324793297e+106*cos(theta)**51 + 1.37544289068058e+107*cos(theta)**49 - 2.91445196295561e+107*cos(theta)**47 + 4.30399258463799e+107*cos(theta)**45 - 4.70823498209018e+107*cos(theta)**43 + 3.9585998033775e+107*cos(theta)**41 - 2.61989656075024e+107*cos(theta)**39 + 1.38667382251138e+107*cos(theta)**37 - 5.93143715987526e+106*cos(theta)**35 + 2.06386263750045e+106*cos(theta)**33 - 5.86185837869952e+105*cos(theta)**31 + 1.36016174954854e+105*cos(theta)**29 - 2.57447864949514e+104*cos(theta)**27 + 3.95986856254511e+103*cos(theta)**25 - 4.91909138204361e+102*cos(theta)**23 + 4.89202091060155e+101*cos(theta)**21 - 3.84909850590605e+100*cos(theta)**19 + 2.35912489071661e+99*cos(theta)**17 - 1.10368415939959e+98*cos(theta)**15 + 3.83731247473366e+96*cos(theta)**13 - 9.56568785647891e+94*cos(theta)**11 + 1.62681766266648e+93*cos(theta)**9 - 1.75608503316322e+91*cos(theta)**7 + 1.07452755525721e+89*cos(theta)**5 - 3.04830512129706e+86*cos(theta)**3 + 2.53041376975406e+83*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl95_m43(theta, phi):
    return 1.88264037871918e-84*(1.0 - cos(theta)**2)**21.5*(2.93286745612813e+107*cos(theta)**52 - 2.05766256445815e+108*cos(theta)**50 + 6.73967016433484e+108*cos(theta)**48 - 1.36979242258914e+109*cos(theta)**46 + 1.9367966630871e+109*cos(theta)**44 - 2.02454104229878e+109*cos(theta)**42 + 1.62302591938477e+109*cos(theta)**40 - 1.02175965869259e+109*cos(theta)**38 + 5.1306931432921e+108*cos(theta)**36 - 2.07600300595634e+108*cos(theta)**34 + 6.8107467037515e+107*cos(theta)**32 - 1.81717609739685e+107*cos(theta)**30 + 3.94446907369077e+106*cos(theta)**28 - 6.95109235363688e+105*cos(theta)**26 + 9.89967140636277e+104*cos(theta)**24 - 1.13139101787003e+104*cos(theta)**22 + 1.02732439122633e+103*cos(theta)**20 - 7.3132871612215e+101*cos(theta)**18 + 4.01051231421824e+100*cos(theta)**16 - 1.65552623909938e+99*cos(theta)**14 + 4.98850621715375e+97*cos(theta)**12 - 1.05222566421268e+96*cos(theta)**10 + 1.46413589639983e+94*cos(theta)**8 - 1.22925952321425e+92*cos(theta)**6 + 5.37263777628607e+89*cos(theta)**4 - 9.14491536389119e+86*cos(theta)**2 + 2.53041376975406e+83)*cos(43*phi)

#@torch.jit.script
def Yl95_m44(theta, phi):
    return 2.21441134212219e-86*(1.0 - cos(theta)**2)**22*(1.52509107718663e+109*cos(theta)**51 - 1.02883128222907e+110*cos(theta)**49 + 3.23504167888072e+110*cos(theta)**47 - 6.30104514391002e+110*cos(theta)**45 + 8.52190531758323e+110*cos(theta)**43 - 8.50307237765487e+110*cos(theta)**41 + 6.4921036775391e+110*cos(theta)**39 - 3.88268670303186e+110*cos(theta)**37 + 1.84704953158515e+110*cos(theta)**35 - 7.05841022025156e+109*cos(theta)**33 + 2.17943894520048e+109*cos(theta)**31 - 5.45152829219055e+108*cos(theta)**29 + 1.10445134063341e+108*cos(theta)**27 - 1.80728401194559e+107*cos(theta)**25 + 2.37592113752707e+106*cos(theta)**23 - 2.48906023931407e+105*cos(theta)**21 + 2.05464878245265e+104*cos(theta)**19 - 1.31639168901987e+103*cos(theta)**17 + 6.41681970274919e+101*cos(theta)**15 - 2.31773673473913e+100*cos(theta)**13 + 5.9862074605845e+98*cos(theta)**11 - 1.05222566421268e+97*cos(theta)**9 + 1.17130871711987e+95*cos(theta)**7 - 7.37555713928552e+92*cos(theta)**5 + 2.14905511051443e+90*cos(theta)**3 - 1.82898307277824e+87*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl95_m45(theta, phi):
    return 2.62065101714605e-88*(1.0 - cos(theta)**2)**22.5*(7.7779644936518e+110*cos(theta)**50 - 5.04127328292246e+111*cos(theta)**48 + 1.52046958907394e+112*cos(theta)**46 - 2.83547031475951e+112*cos(theta)**44 + 3.66441928656079e+112*cos(theta)**42 - 3.4862596748385e+112*cos(theta)**40 + 2.53192043424025e+112*cos(theta)**38 - 1.43659408012179e+112*cos(theta)**36 + 6.46467336054804e+111*cos(theta)**34 - 2.32927537268301e+111*cos(theta)**32 + 6.75626073012149e+110*cos(theta)**30 - 1.58094320473526e+110*cos(theta)**28 + 2.98201861971022e+109*cos(theta)**26 - 4.51821002986397e+108*cos(theta)**24 + 5.46461861631225e+107*cos(theta)**22 - 5.22702650255954e+106*cos(theta)**20 + 3.90383268666004e+105*cos(theta)**18 - 2.23786587133378e+104*cos(theta)**16 + 9.62522955412378e+102*cos(theta)**14 - 3.01305775516087e+101*cos(theta)**12 + 6.58482820664296e+99*cos(theta)**10 - 9.47003097791413e+97*cos(theta)**8 + 8.19916101983907e+95*cos(theta)**6 - 3.68777856964276e+93*cos(theta)**4 + 6.44716533154329e+90*cos(theta)**2 - 1.82898307277824e+87)*cos(45*phi)

#@torch.jit.script
def Yl95_m46(theta, phi):
    return 3.12114994121691e-90*(1.0 - cos(theta)**2)**23*(3.8889822468259e+112*cos(theta)**49 - 2.41981117580278e+113*cos(theta)**47 + 6.99416010974013e+113*cos(theta)**45 - 1.24760693849418e+114*cos(theta)**43 + 1.53905610035553e+114*cos(theta)**41 - 1.3945038699354e+114*cos(theta)**39 + 9.62129765011294e+113*cos(theta)**37 - 5.17173868843843e+113*cos(theta)**35 + 2.19798894258633e+113*cos(theta)**33 - 7.45368119258564e+112*cos(theta)**31 + 2.02687821903645e+112*cos(theta)**29 - 4.42664097325873e+111*cos(theta)**27 + 7.75324841124657e+110*cos(theta)**25 - 1.08437040716735e+110*cos(theta)**23 + 1.2022160955887e+109*cos(theta)**21 - 1.04540530051191e+108*cos(theta)**19 + 7.02689883598807e+106*cos(theta)**17 - 3.58058539413405e+105*cos(theta)**15 + 1.34753213757733e+104*cos(theta)**13 - 3.61566930619304e+102*cos(theta)**11 + 6.58482820664295e+100*cos(theta)**9 - 7.5760247823313e+98*cos(theta)**7 + 4.91949661190344e+96*cos(theta)**5 - 1.4751114278571e+94*cos(theta)**3 + 1.28943306630866e+91*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl95_m47(theta, phi):
    return 3.7417297815972e-92*(1.0 - cos(theta)**2)**23.5*(1.90560130094469e+114*cos(theta)**48 - 1.13731125262731e+115*cos(theta)**46 + 3.14737204938306e+115*cos(theta)**44 - 5.36470983552499e+115*cos(theta)**42 + 6.31013001145768e+115*cos(theta)**40 - 5.43856509274805e+115*cos(theta)**38 + 3.55988013054179e+115*cos(theta)**36 - 1.81010854095345e+115*cos(theta)**34 + 7.2533635105349e+114*cos(theta)**32 - 2.31064116970155e+114*cos(theta)**30 + 5.8779468352057e+113*cos(theta)**28 - 1.19519306277986e+113*cos(theta)**26 + 1.93831210281164e+112*cos(theta)**24 - 2.49405193648491e+111*cos(theta)**22 + 2.52465380073626e+110*cos(theta)**20 - 1.98627007097263e+109*cos(theta)**18 + 1.19457280211797e+108*cos(theta)**16 - 5.37087809120107e+106*cos(theta)**14 + 1.75179177885053e+105*cos(theta)**12 - 3.97723623681235e+103*cos(theta)**10 + 5.92634538597866e+101*cos(theta)**8 - 5.30321734763191e+99*cos(theta)**6 + 2.45974830595172e+97*cos(theta)**4 - 4.42533428357131e+94*cos(theta)**2 + 1.28943306630866e+91)*cos(47*phi)

#@torch.jit.script
def Yl95_m48(theta, phi):
    return 4.51631040468455e-94*(1.0 - cos(theta)**2)**24*(9.14688624453451e+115*cos(theta)**47 - 5.23163176208561e+116*cos(theta)**45 + 1.38484370172854e+117*cos(theta)**43 - 2.2531781309205e+117*cos(theta)**41 + 2.52405200458307e+117*cos(theta)**39 - 2.06665473524426e+117*cos(theta)**37 + 1.28155684699504e+117*cos(theta)**35 - 6.15436903924174e+116*cos(theta)**33 + 2.32107632337117e+116*cos(theta)**31 - 6.93192350910465e+115*cos(theta)**29 + 1.64582511385759e+115*cos(theta)**27 - 3.10750196322763e+114*cos(theta)**25 + 4.65194904674794e+113*cos(theta)**23 - 5.48691426026681e+112*cos(theta)**21 + 5.04930760147252e+111*cos(theta)**19 - 3.57528612775073e+110*cos(theta)**17 + 1.91131648338875e+109*cos(theta)**15 - 7.5192293276815e+107*cos(theta)**13 + 2.10215013462063e+106*cos(theta)**11 - 3.97723623681234e+104*cos(theta)**9 + 4.74107630878293e+102*cos(theta)**7 - 3.18193040857915e+100*cos(theta)**5 + 9.83899322380688e+97*cos(theta)**3 - 8.85066856714262e+94*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl95_m49(theta, phi):
    return 5.4897631565097e-96*(1.0 - cos(theta)**2)**24.5*(4.29903653493122e+117*cos(theta)**46 - 2.35423429293853e+118*cos(theta)**44 + 5.95482791743274e+118*cos(theta)**42 - 9.23803033677404e+118*cos(theta)**40 + 9.84380281787397e+118*cos(theta)**38 - 7.64662252040376e+118*cos(theta)**36 + 4.48544896448265e+118*cos(theta)**34 - 2.03094178294977e+118*cos(theta)**32 + 7.19533660245062e+117*cos(theta)**30 - 2.01025781764035e+117*cos(theta)**28 + 4.44372780741551e+116*cos(theta)**26 - 7.76875490806907e+115*cos(theta)**24 + 1.06994828075203e+115*cos(theta)**22 - 1.15225199465603e+114*cos(theta)**20 + 9.59368444279779e+112*cos(theta)**18 - 6.07798641717624e+111*cos(theta)**16 + 2.86697472508313e+110*cos(theta)**14 - 9.77499812598595e+108*cos(theta)**12 + 2.3123651480827e+107*cos(theta)**10 - 3.57951261313111e+105*cos(theta)**8 + 3.31875341614805e+103*cos(theta)**6 - 1.59096520428957e+101*cos(theta)**4 + 2.95169796714207e+98*cos(theta)**2 - 8.85066856714262e+94)*cos(49*phi)

#@torch.jit.script
def Yl95_m50(theta, phi):
    return 6.72187901134314e-98*(1.0 - cos(theta)**2)**25*(1.97755680606836e+119*cos(theta)**45 - 1.03586308889295e+120*cos(theta)**43 + 2.50102772532175e+120*cos(theta)**41 - 3.69521213470961e+120*cos(theta)**39 + 3.74064507079211e+120*cos(theta)**37 - 2.75278410734535e+120*cos(theta)**35 + 1.5250526479241e+120*cos(theta)**33 - 6.49901370543927e+119*cos(theta)**31 + 2.15860098073519e+119*cos(theta)**29 - 5.62872188939297e+118*cos(theta)**27 + 1.15536922992803e+118*cos(theta)**25 - 1.86450117793658e+117*cos(theta)**23 + 2.35388621765446e+116*cos(theta)**21 - 2.30450398931206e+115*cos(theta)**19 + 1.7268631997036e+114*cos(theta)**17 - 9.72477826748198e+112*cos(theta)**15 + 4.01376461511638e+111*cos(theta)**13 - 1.17299977511831e+110*cos(theta)**11 + 2.3123651480827e+108*cos(theta)**9 - 2.86361009050489e+106*cos(theta)**7 + 1.99125204968883e+104*cos(theta)**5 - 6.36386081715829e+101*cos(theta)**3 + 5.90339593428413e+98*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl95_m51(theta, phi):
    return 8.2929301318774e-100*(1.0 - cos(theta)**2)**25.5*(8.89900562730763e+120*cos(theta)**44 - 4.45421128223969e+121*cos(theta)**42 + 1.02542136738192e+122*cos(theta)**40 - 1.44113273253675e+122*cos(theta)**38 + 1.38403867619308e+122*cos(theta)**36 - 9.63474437570874e+121*cos(theta)**34 + 5.03267373814954e+121*cos(theta)**32 - 2.01469424868617e+121*cos(theta)**30 + 6.25994284413204e+120*cos(theta)**28 - 1.5197549101361e+120*cos(theta)**26 + 2.88842307482008e+119*cos(theta)**24 - 4.28835270925412e+118*cos(theta)**22 + 4.94316105707436e+117*cos(theta)**20 - 4.37855757969291e+116*cos(theta)**18 + 2.93566743949612e+115*cos(theta)**16 - 1.4587167401223e+114*cos(theta)**14 + 5.2178939996513e+112*cos(theta)**12 - 1.29029975263015e+111*cos(theta)**10 + 2.08112863327443e+109*cos(theta)**8 - 2.00452706335342e+107*cos(theta)**6 + 9.95626024844415e+104*cos(theta)**4 - 1.90915824514749e+102*cos(theta)**2 + 5.90339593428413e+98)*cos(51*phi)

#@torch.jit.script
def Yl95_m52(theta, phi):
    return 1.03115274168685e-101*(1.0 - cos(theta)**2)**26*(3.91556247601536e+122*cos(theta)**43 - 1.87076873854067e+123*cos(theta)**41 + 4.10168546952767e+123*cos(theta)**39 - 5.47630438363965e+123*cos(theta)**37 + 4.98253923429509e+123*cos(theta)**35 - 3.27581308774097e+123*cos(theta)**33 + 1.61045559620785e+123*cos(theta)**31 - 6.04408274605852e+122*cos(theta)**29 + 1.75278399635697e+122*cos(theta)**27 - 3.95136276635387e+121*cos(theta)**25 + 6.93221537956819e+120*cos(theta)**23 - 9.43437596035907e+119*cos(theta)**21 + 9.88632211414873e+118*cos(theta)**19 - 7.88140364344724e+117*cos(theta)**17 + 4.6970679031938e+116*cos(theta)**15 - 2.04220343617122e+115*cos(theta)**13 + 6.26147279958156e+113*cos(theta)**11 - 1.29029975263015e+112*cos(theta)**9 + 1.66490290661954e+110*cos(theta)**7 - 1.20271623801205e+108*cos(theta)**5 + 3.98250409937766e+105*cos(theta)**3 - 3.81831649029498e+102*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl95_m53(theta, phi):
    return 1.29258143909558e-103*(1.0 - cos(theta)**2)**26.5*(1.6836918646866e+124*cos(theta)**42 - 7.67015182801675e+124*cos(theta)**40 + 1.59965733311579e+125*cos(theta)**38 - 2.02623262194667e+125*cos(theta)**36 + 1.74388873200328e+125*cos(theta)**34 - 1.08101831895452e+125*cos(theta)**32 + 4.99241234824434e+124*cos(theta)**30 - 1.75278399635697e+124*cos(theta)**28 + 4.73251679016382e+123*cos(theta)**26 - 9.87840691588467e+122*cos(theta)**24 + 1.59440953730068e+122*cos(theta)**22 - 1.98121895167541e+121*cos(theta)**20 + 1.87840120168826e+120*cos(theta)**18 - 1.33983861938603e+119*cos(theta)**16 + 7.04560185479069e+117*cos(theta)**14 - 2.65486446702258e+116*cos(theta)**12 + 6.88762007953971e+114*cos(theta)**10 - 1.16126977736713e+113*cos(theta)**8 + 1.16543203463368e+111*cos(theta)**6 - 6.01358119006027e+108*cos(theta)**4 + 1.1947512298133e+106*cos(theta)**2 - 3.81831649029498e+102)*cos(53*phi)

#@torch.jit.script
def Yl95_m54(theta, phi):
    return 1.63395516663347e-105*(1.0 - cos(theta)**2)**27*(7.07150583168373e+125*cos(theta)**41 - 3.0680607312067e+126*cos(theta)**39 + 6.07869786584001e+126*cos(theta)**37 - 7.29443743900801e+126*cos(theta)**35 + 5.92922168881116e+126*cos(theta)**33 - 3.45925862065447e+126*cos(theta)**31 + 1.4977237044733e+126*cos(theta)**29 - 4.90779518979952e+125*cos(theta)**27 + 1.23045436544259e+125*cos(theta)**25 - 2.37081765981232e+124*cos(theta)**23 + 3.5077009820615e+123*cos(theta)**21 - 3.96243790335081e+122*cos(theta)**19 + 3.38112216303887e+121*cos(theta)**17 - 2.14374179101765e+120*cos(theta)**15 + 9.86384259670697e+118*cos(theta)**13 - 3.1858373604271e+117*cos(theta)**11 + 6.88762007953971e+115*cos(theta)**9 - 9.29015821893704e+113*cos(theta)**7 + 6.99259220780208e+111*cos(theta)**5 - 2.40543247602411e+109*cos(theta)**3 + 2.3895024596266e+106*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl95_m55(theta, phi):
    return 2.08354352887006e-107*(1.0 - cos(theta)**2)**27.5*(2.89931739099033e+127*cos(theta)**40 - 1.19654368517061e+128*cos(theta)**38 + 2.2491182103608e+128*cos(theta)**36 - 2.5530531036528e+128*cos(theta)**34 + 1.95664315730768e+128*cos(theta)**32 - 1.07237017240288e+128*cos(theta)**30 + 4.34339874297258e+127*cos(theta)**28 - 1.32510470124587e+127*cos(theta)**26 + 3.07613591360649e+126*cos(theta)**24 - 5.45288061756834e+125*cos(theta)**22 + 7.36617206232916e+124*cos(theta)**20 - 7.52863201636654e+123*cos(theta)**18 + 5.74790767716607e+122*cos(theta)**16 - 3.21561268652647e+121*cos(theta)**14 + 1.28229953757191e+120*cos(theta)**12 - 3.50442109646981e+118*cos(theta)**10 + 6.19885807158574e+116*cos(theta)**8 - 6.50311075325593e+114*cos(theta)**6 + 3.49629610390104e+112*cos(theta)**4 - 7.21629742807232e+109*cos(theta)**2 + 2.3895024596266e+106)*cos(55*phi)

#@torch.jit.script
def Yl95_m56(theta, phi):
    return 2.68092156880921e-109*(1.0 - cos(theta)**2)**28*(1.15972695639613e+129*cos(theta)**39 - 4.54686600364833e+129*cos(theta)**37 + 8.09682555729889e+129*cos(theta)**35 - 8.68038055241954e+129*cos(theta)**33 + 6.26125810338458e+129*cos(theta)**31 - 3.21711051720865e+129*cos(theta)**29 + 1.21615164803232e+129*cos(theta)**27 - 3.44527222323926e+128*cos(theta)**25 + 7.38272619265557e+127*cos(theta)**23 - 1.19963373586503e+127*cos(theta)**21 + 1.47323441246583e+126*cos(theta)**19 - 1.35515376294598e+125*cos(theta)**17 + 9.19665228346571e+123*cos(theta)**15 - 4.50185776113706e+122*cos(theta)**13 + 1.53875944508629e+121*cos(theta)**11 - 3.50442109646981e+119*cos(theta)**9 + 4.95908645726859e+117*cos(theta)**7 - 3.90186645195356e+115*cos(theta)**5 + 1.39851844156042e+113*cos(theta)**3 - 1.44325948561446e+110*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl95_m57(theta, phi):
    return 3.48200997777645e-111*(1.0 - cos(theta)**2)**28.5*(4.52293512994492e+130*cos(theta)**38 - 1.68234042134988e+131*cos(theta)**36 + 2.83388894505461e+131*cos(theta)**34 - 2.86452558229845e+131*cos(theta)**32 + 1.94099001204922e+131*cos(theta)**30 - 9.32962049990509e+130*cos(theta)**28 + 3.28360944968727e+130*cos(theta)**26 - 8.61318055809816e+129*cos(theta)**24 + 1.69802702431078e+129*cos(theta)**22 - 2.51923084531657e+128*cos(theta)**20 + 2.79914538368508e+127*cos(theta)**18 - 2.30376139700816e+126*cos(theta)**16 + 1.37949784251986e+125*cos(theta)**14 - 5.85241508947818e+123*cos(theta)**12 + 1.69263538959492e+122*cos(theta)**10 - 3.15397898682283e+120*cos(theta)**8 + 3.47136052008802e+118*cos(theta)**6 - 1.95093322597678e+116*cos(theta)**4 + 4.19555532468125e+113*cos(theta)**2 - 1.44325948561446e+110)*cos(57*phi)

#@torch.jit.script
def Yl95_m58(theta, phi):
    return 4.56659500771156e-113*(1.0 - cos(theta)**2)**29*(1.71871534937907e+132*cos(theta)**37 - 6.05642551685957e+132*cos(theta)**35 + 9.63522241318568e+132*cos(theta)**33 - 9.16648186335503e+132*cos(theta)**31 + 5.82297003614766e+132*cos(theta)**29 - 2.61229373997343e+132*cos(theta)**27 + 8.5373845691869e+131*cos(theta)**25 - 2.06716333394356e+131*cos(theta)**23 + 3.73565945348372e+130*cos(theta)**21 - 5.03846169063314e+129*cos(theta)**19 + 5.03846169063314e+128*cos(theta)**17 - 3.68601823521306e+127*cos(theta)**15 + 1.9312969795278e+126*cos(theta)**13 - 7.02289810737382e+124*cos(theta)**11 + 1.69263538959492e+123*cos(theta)**9 - 2.52318318945826e+121*cos(theta)**7 + 2.08281631205281e+119*cos(theta)**5 - 7.80373290390712e+116*cos(theta)**3 + 8.39111064936249e+113*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl95_m59(theta, phi):
    return 6.04966428705415e-115*(1.0 - cos(theta)**2)**29.5*(6.35924679270255e+133*cos(theta)**36 - 2.11974893090085e+134*cos(theta)**34 + 3.17962339635128e+134*cos(theta)**32 - 2.84160937764006e+134*cos(theta)**30 + 1.68866131048282e+134*cos(theta)**28 - 7.05319309792825e+133*cos(theta)**26 + 2.13434614229672e+133*cos(theta)**24 - 4.75447566807018e+132*cos(theta)**22 + 7.8448848523158e+131*cos(theta)**20 - 9.57307721220297e+130*cos(theta)**18 + 8.56538487407634e+129*cos(theta)**16 - 5.52902735281959e+128*cos(theta)**14 + 2.51068607338614e+127*cos(theta)**12 - 7.7251879181112e+125*cos(theta)**10 + 1.52337185063543e+124*cos(theta)**8 - 1.76622823262078e+122*cos(theta)**6 + 1.0414081560264e+120*cos(theta)**4 - 2.34111987117214e+117*cos(theta)**2 + 8.39111064936249e+113)*cos(59*phi)

#@torch.jit.script
def Yl95_m60(theta, phi):
    return 8.09867881455509e-117*(1.0 - cos(theta)**2)**30*(2.28932884537292e+135*cos(theta)**35 - 7.20714636506289e+135*cos(theta)**33 + 1.01747948683241e+136*cos(theta)**31 - 8.52482813292018e+135*cos(theta)**29 + 4.7282516693519e+135*cos(theta)**27 - 1.83383020546135e+135*cos(theta)**25 + 5.12243074151214e+134*cos(theta)**23 - 1.04598464697544e+134*cos(theta)**21 + 1.56897697046316e+133*cos(theta)**19 - 1.72315389819654e+132*cos(theta)**17 + 1.37046157985222e+131*cos(theta)**15 - 7.74063829394742e+129*cos(theta)**13 + 3.01282328806337e+128*cos(theta)**11 - 7.7251879181112e+126*cos(theta)**9 + 1.21869748050834e+125*cos(theta)**7 - 1.05973693957247e+123*cos(theta)**5 + 4.16563262410562e+120*cos(theta)**3 - 4.68223974234427e+117*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl95_m61(theta, phi):
    return 1.0960184229933e-118*(1.0 - cos(theta)**2)**30.5*(8.01265095880522e+136*cos(theta)**34 - 2.37835830047075e+137*cos(theta)**32 + 3.15418640918047e+137*cos(theta)**30 - 2.47220015854685e+137*cos(theta)**28 + 1.27662795072501e+137*cos(theta)**26 - 4.58457551365336e+136*cos(theta)**24 + 1.17815907054779e+136*cos(theta)**22 - 2.19656775864843e+135*cos(theta)**20 + 2.98105624388001e+134*cos(theta)**18 - 2.92936162693411e+133*cos(theta)**16 + 2.05569236977832e+132*cos(theta)**14 - 1.00628297821316e+131*cos(theta)**12 + 3.3141056168697e+129*cos(theta)**10 - 6.95266912630008e+127*cos(theta)**8 + 8.53088236355838e+125*cos(theta)**6 - 5.29868469786235e+123*cos(theta)**4 + 1.24968978723169e+121*cos(theta)**2 - 4.68223974234427e+117)*cos(61*phi)

#@torch.jit.script
def Yl95_m62(theta, phi):
    return 1.50012887140968e-120*(1.0 - cos(theta)**2)**31*(2.72430132599377e+138*cos(theta)**33 - 7.61074656150641e+138*cos(theta)**31 + 9.4625592275414e+138*cos(theta)**29 - 6.92216044393118e+138*cos(theta)**27 + 3.31923267188503e+138*cos(theta)**25 - 1.10029812327681e+138*cos(theta)**23 + 2.59194995520514e+137*cos(theta)**21 - 4.39313551729685e+136*cos(theta)**19 + 5.36590123898401e+135*cos(theta)**17 - 4.68697860309458e+134*cos(theta)**15 + 2.87796931768965e+133*cos(theta)**13 - 1.2075395738558e+132*cos(theta)**11 + 3.3141056168697e+130*cos(theta)**9 - 5.56213530104006e+128*cos(theta)**7 + 5.11852941813503e+126*cos(theta)**5 - 2.11947387914494e+124*cos(theta)**3 + 2.49937957446337e+121*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl95_m63(theta, phi):
    return 2.07750968051765e-122*(1.0 - cos(theta)**2)**31.5*(8.99019437577945e+139*cos(theta)**32 - 2.35933143406699e+140*cos(theta)**30 + 2.74414217598701e+140*cos(theta)**28 - 1.86898331986142e+140*cos(theta)**26 + 8.29808167971259e+139*cos(theta)**24 - 2.53068568353666e+139*cos(theta)**22 + 5.4430949059308e+138*cos(theta)**20 - 8.34695748286402e+137*cos(theta)**18 + 9.12203210627282e+136*cos(theta)**16 - 7.03046790464186e+135*cos(theta)**14 + 3.74136011299655e+134*cos(theta)**12 - 1.32829353124138e+133*cos(theta)**10 + 2.98269505518273e+131*cos(theta)**8 - 3.89349471072804e+129*cos(theta)**6 + 2.55926470906751e+127*cos(theta)**4 - 6.35842163743482e+124*cos(theta)**2 + 2.49937957446337e+121)*cos(63*phi)

#@torch.jit.script
def Yl95_m64(theta, phi):
    return 2.9125239467274e-124*(1.0 - cos(theta)**2)**32*(2.87686220024942e+141*cos(theta)**31 - 7.07799430220096e+141*cos(theta)**29 + 7.68359809276361e+141*cos(theta)**27 - 4.85935663163969e+141*cos(theta)**25 + 1.99153960313102e+141*cos(theta)**23 - 5.56750850378064e+140*cos(theta)**21 + 1.08861898118616e+140*cos(theta)**19 - 1.50245234691552e+139*cos(theta)**17 + 1.45952513700365e+138*cos(theta)**15 - 9.84265506649861e+136*cos(theta)**13 + 4.48963213559586e+135*cos(theta)**11 - 1.32829353124138e+134*cos(theta)**9 + 2.38615604414619e+132*cos(theta)**7 - 2.33609682643683e+130*cos(theta)**5 + 1.02370588362701e+128*cos(theta)**3 - 1.27168432748696e+125*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl95_m65(theta, phi):
    return 4.13550610767948e-126*(1.0 - cos(theta)**2)**32.5*(8.91827282077322e+142*cos(theta)**30 - 2.05261834763828e+143*cos(theta)**28 + 2.07457148504618e+143*cos(theta)**26 - 1.21483915790992e+143*cos(theta)**24 + 4.58054108720135e+142*cos(theta)**22 - 1.16917678579394e+142*cos(theta)**20 + 2.0683760642537e+141*cos(theta)**18 - 2.55416898975639e+140*cos(theta)**16 + 2.18928770550548e+139*cos(theta)**14 - 1.27954515864482e+138*cos(theta)**12 + 4.93859534915544e+136*cos(theta)**10 - 1.19546417811724e+135*cos(theta)**8 + 1.67030923090233e+133*cos(theta)**6 - 1.16804841321841e+131*cos(theta)**4 + 3.07111765088102e+128*cos(theta)**2 - 1.27168432748696e+125)*cos(65*phi)

#@torch.jit.script
def Yl95_m66(theta, phi):
    return 5.95052249330961e-128*(1.0 - cos(theta)**2)**33*(2.67548184623196e+144*cos(theta)**29 - 5.74733137338718e+144*cos(theta)**27 + 5.39388586112006e+144*cos(theta)**25 - 2.91561397898381e+144*cos(theta)**23 + 1.0077190391843e+144*cos(theta)**21 - 2.33835357158787e+143*cos(theta)**19 + 3.72307691565667e+142*cos(theta)**17 - 4.08667038361022e+141*cos(theta)**15 + 3.06500278770767e+140*cos(theta)**13 - 1.53545419037378e+139*cos(theta)**11 + 4.93859534915544e+137*cos(theta)**9 - 9.56371342493792e+135*cos(theta)**7 + 1.0021855385414e+134*cos(theta)**5 - 4.67219365287365e+131*cos(theta)**3 + 6.14223530176203e+128*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl95_m67(theta, phi):
    return 8.68157646942252e-130*(1.0 - cos(theta)**2)**33.5*(7.7588973540727e+145*cos(theta)**28 - 1.55177947081454e+146*cos(theta)**26 + 1.34847146528001e+146*cos(theta)**24 - 6.70591215166277e+145*cos(theta)**22 + 2.11620998228702e+145*cos(theta)**20 - 4.44287178601695e+144*cos(theta)**18 + 6.32923075661633e+143*cos(theta)**16 - 6.13000557541533e+142*cos(theta)**14 + 3.98450362401997e+141*cos(theta)**12 - 1.68899960941116e+140*cos(theta)**10 + 4.4447358142399e+138*cos(theta)**8 - 6.69459939745654e+136*cos(theta)**6 + 5.01092769270699e+134*cos(theta)**4 - 1.4016580958621e+132*cos(theta)**2 + 6.14223530176203e+128)*cos(67*phi)

#@torch.jit.script
def Yl95_m68(theta, phi):
    return 1.28506701737372e-131*(1.0 - cos(theta)**2)**34*(2.17249125914036e+147*cos(theta)**27 - 4.0346266241178e+147*cos(theta)**25 + 3.23633151667203e+147*cos(theta)**23 - 1.47530067336581e+147*cos(theta)**21 + 4.23241996457405e+146*cos(theta)**19 - 7.99716921483052e+145*cos(theta)**17 + 1.01267692105861e+145*cos(theta)**15 - 8.58200780558147e+143*cos(theta)**13 + 4.78140434882396e+142*cos(theta)**11 - 1.68899960941116e+141*cos(theta)**9 + 3.55578865139192e+139*cos(theta)**7 - 4.01675963847393e+137*cos(theta)**5 + 2.0043710770828e+135*cos(theta)**3 - 2.80331619172419e+132*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl95_m69(theta, phi):
    return 1.93117651346421e-133*(1.0 - cos(theta)**2)**34.5*(5.86572639967896e+148*cos(theta)**26 - 1.00865665602945e+149*cos(theta)**24 + 7.44356248834568e+148*cos(theta)**22 - 3.0981314140682e+148*cos(theta)**20 + 8.04159793269069e+147*cos(theta)**18 - 1.35951876652119e+147*cos(theta)**16 + 1.51901538158792e+146*cos(theta)**14 - 1.11566101472559e+145*cos(theta)**12 + 5.25954478370636e+143*cos(theta)**10 - 1.52009964847005e+142*cos(theta)**8 + 2.48905205597434e+140*cos(theta)**6 - 2.00837981923696e+138*cos(theta)**4 + 6.01311323124839e+135*cos(theta)**2 - 2.80331619172419e+132)*cos(69*phi)

#@torch.jit.script
def Yl95_m70(theta, phi):
    return 2.94844699596395e-135*(1.0 - cos(theta)**2)**35*(1.52508886391653e+150*cos(theta)**25 - 2.42077597447068e+150*cos(theta)**23 + 1.63758374743605e+150*cos(theta)**21 - 6.1962628281364e+149*cos(theta)**19 + 1.44748762788432e+149*cos(theta)**17 - 2.1752300264339e+148*cos(theta)**15 + 2.12662153422309e+147*cos(theta)**13 - 1.33879321767071e+146*cos(theta)**11 + 5.25954478370636e+144*cos(theta)**9 - 1.21607971877604e+143*cos(theta)**7 + 1.49343123358461e+141*cos(theta)**5 - 8.03351927694785e+138*cos(theta)**3 + 1.20262264624968e+136*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl95_m71(theta, phi):
    return 4.57687737186935e-137*(1.0 - cos(theta)**2)**35.5*(3.81272215979132e+151*cos(theta)**24 - 5.56778474128257e+151*cos(theta)**22 + 3.4389258696157e+151*cos(theta)**20 - 1.17728993734592e+151*cos(theta)**18 + 2.46072896740335e+150*cos(theta)**16 - 3.26284503965085e+149*cos(theta)**14 + 2.76460799449001e+148*cos(theta)**12 - 1.47267253943778e+147*cos(theta)**10 + 4.73359030533572e+145*cos(theta)**8 - 8.51255803143225e+143*cos(theta)**6 + 7.46715616792303e+141*cos(theta)**4 - 2.41005578308436e+139*cos(theta)**2 + 1.20262264624968e+136)*cos(71*phi)

#@torch.jit.script
def Yl95_m72(theta, phi):
    return 7.22945269162081e-139*(1.0 - cos(theta)**2)**36*(9.15053318349918e+152*cos(theta)**23 - 1.22491264308216e+153*cos(theta)**21 + 6.87785173923141e+152*cos(theta)**19 - 2.11912188722265e+152*cos(theta)**17 + 3.93716634784536e+151*cos(theta)**15 - 4.56798305551119e+150*cos(theta)**13 + 3.31752959338802e+149*cos(theta)**11 - 1.47267253943778e+148*cos(theta)**9 + 3.78687224426858e+146*cos(theta)**7 - 5.10753481885935e+144*cos(theta)**5 + 2.98686246716921e+142*cos(theta)**3 - 4.82011156616871e+139*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl95_m73(theta, phi):
    return 1.16301913785641e-140*(1.0 - cos(theta)**2)**36.5*(2.10462263220481e+154*cos(theta)**22 - 2.57231655047255e+154*cos(theta)**20 + 1.30679183045397e+154*cos(theta)**18 - 3.6025072082785e+153*cos(theta)**16 + 5.90574952176804e+152*cos(theta)**14 - 5.93837797216455e+151*cos(theta)**12 + 3.64928255272682e+150*cos(theta)**10 - 1.325405285494e+149*cos(theta)**8 + 2.650810570988e+147*cos(theta)**6 - 2.55376740942968e+145*cos(theta)**4 + 8.96058740150763e+142*cos(theta)**2 - 4.82011156616871e+139)*cos(73*phi)

#@torch.jit.script
def Yl95_m74(theta, phi):
    return 1.90735779481748e-142*(1.0 - cos(theta)**2)**37*(4.63016979085058e+155*cos(theta)**21 - 5.14463310094509e+155*cos(theta)**19 + 2.35222529481714e+155*cos(theta)**17 - 5.76401153324561e+154*cos(theta)**15 + 8.26804933047526e+153*cos(theta)**13 - 7.12605356659746e+152*cos(theta)**11 + 3.64928255272682e+151*cos(theta)**9 - 1.0603242283952e+150*cos(theta)**7 + 1.5904863425928e+148*cos(theta)**5 - 1.02150696377187e+146*cos(theta)**3 + 1.79211748030153e+143*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl95_m75(theta, phi):
    return 3.19225856201428e-144*(1.0 - cos(theta)**2)**37.5*(9.72335656078622e+156*cos(theta)**20 - 9.77480289179568e+156*cos(theta)**18 + 3.99878300118914e+156*cos(theta)**16 - 8.64601729986841e+155*cos(theta)**14 + 1.07484641296178e+155*cos(theta)**12 - 7.83865892325721e+153*cos(theta)**10 + 3.28435429745414e+152*cos(theta)**8 - 7.42226959876641e+150*cos(theta)**6 + 7.95243171296401e+148*cos(theta)**4 - 3.06452089131561e+146*cos(theta)**2 + 1.79211748030153e+143)*cos(75*phi)

#@torch.jit.script
def Yl95_m76(theta, phi):
    return 5.45864696480855e-146*(1.0 - cos(theta)**2)**38*(1.94467131215725e+158*cos(theta)**19 - 1.75946452052322e+158*cos(theta)**17 + 6.39805280190262e+157*cos(theta)**15 - 1.21044242198158e+157*cos(theta)**13 + 1.28981569555414e+156*cos(theta)**11 - 7.8386589232572e+154*cos(theta)**9 + 2.62748343796331e+153*cos(theta)**7 - 4.45336175925985e+151*cos(theta)**5 + 3.1809726851856e+149*cos(theta)**3 - 6.12904178263122e+146*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl95_m77(theta, phi):
    return 9.54869416412232e-148*(1.0 - cos(theta)**2)**38.5*(3.69487549309877e+159*cos(theta)**18 - 2.99108968488948e+159*cos(theta)**16 + 9.59707920285394e+158*cos(theta)**14 - 1.57357514857605e+158*cos(theta)**12 + 1.41879726510955e+157*cos(theta)**10 - 7.05479303093148e+155*cos(theta)**8 + 1.83923840657432e+154*cos(theta)**6 - 2.22668087962992e+152*cos(theta)**4 + 9.54291805555681e+149*cos(theta)**2 - 6.12904178263122e+146)*cos(77*phi)

#@torch.jit.script
def Yl95_m78(theta, phi):
    return 1.71113659507699e-149*(1.0 - cos(theta)**2)**39*(6.65077588757778e+160*cos(theta)**17 - 4.78574349582316e+160*cos(theta)**15 + 1.34359108839955e+160*cos(theta)**13 - 1.88829017829126e+159*cos(theta)**11 + 1.41879726510955e+158*cos(theta)**9 - 5.64383442474519e+156*cos(theta)**7 + 1.10354304394459e+155*cos(theta)**5 - 8.90672351851969e+152*cos(theta)**3 + 1.90858361111136e+150*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl95_m79(theta, phi):
    return 3.14619469596975e-151*(1.0 - cos(theta)**2)**39.5*(1.13063190088822e+162*cos(theta)**16 - 7.17861524373474e+161*cos(theta)**14 + 1.74666841491942e+161*cos(theta)**12 - 2.07711919612039e+160*cos(theta)**10 + 1.2769175385986e+159*cos(theta)**8 - 3.95068409732163e+157*cos(theta)**6 + 5.51771521972295e+155*cos(theta)**4 - 2.67201705555591e+153*cos(theta)**2 + 1.90858361111136e+150)*cos(79*phi)

#@torch.jit.script
def Yl95_m80(theta, phi):
    return 5.94574910123317e-153*(1.0 - cos(theta)**2)**40*(1.80901104142116e+163*cos(theta)**15 - 1.00500613412286e+163*cos(theta)**13 + 2.0960020979033e+162*cos(theta)**11 - 2.07711919612039e+161*cos(theta)**9 + 1.02153403087888e+160*cos(theta)**7 - 2.37041045839298e+158*cos(theta)**5 + 2.20708608788918e+156*cos(theta)**3 - 5.34403411111181e+153*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl95_m81(theta, phi):
    return 1.15718984938984e-154*(1.0 - cos(theta)**2)**40.5*(2.71351656213173e+164*cos(theta)**14 - 1.30650797435972e+164*cos(theta)**12 + 2.30560230769363e+163*cos(theta)**10 - 1.86940727650835e+162*cos(theta)**8 + 7.15073821615215e+160*cos(theta)**6 - 1.18520522919649e+159*cos(theta)**4 + 6.62125826366754e+156*cos(theta)**2 - 5.34403411111181e+153)*cos(81*phi)

#@torch.jit.script
def Yl95_m82(theta, phi):
    return 2.32463067573646e-156*(1.0 - cos(theta)**2)**41*(3.79892318698443e+165*cos(theta)**13 - 1.56780956923167e+165*cos(theta)**11 + 2.30560230769363e+164*cos(theta)**9 - 1.49552582120668e+163*cos(theta)**7 + 4.29044292969129e+161*cos(theta)**5 - 4.74082091678596e+159*cos(theta)**3 + 1.32425165273351e+157*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl95_m83(theta, phi):
    return 4.83250472274067e-158*(1.0 - cos(theta)**2)**41.5*(4.93860014307975e+166*cos(theta)**12 - 1.72459052615484e+166*cos(theta)**10 + 2.07504207692427e+165*cos(theta)**8 - 1.04686807484468e+164*cos(theta)**6 + 2.14522146484565e+162*cos(theta)**4 - 1.42224627503579e+160*cos(theta)**2 + 1.32425165273351e+157)*cos(83*phi)

#@torch.jit.script
def Yl95_m84(theta, phi):
    return 1.0426898564066e-159*(1.0 - cos(theta)**2)**42*(5.92632017169571e+167*cos(theta)**11 - 1.72459052615484e+167*cos(theta)**9 + 1.66003366153941e+166*cos(theta)**7 - 6.28120844906805e+164*cos(theta)**5 + 8.58088585938258e+162*cos(theta)**3 - 2.84449255007157e+160*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl95_m85(theta, phi):
    return 2.34327119260382e-161*(1.0 - cos(theta)**2)**42.5*(6.51895218886528e+168*cos(theta)**10 - 1.55213147353935e+168*cos(theta)**8 + 1.16202356307759e+167*cos(theta)**6 - 3.14060422453403e+165*cos(theta)**4 + 2.57426575781477e+163*cos(theta)**2 - 2.84449255007157e+160)*cos(85*phi)

#@torch.jit.script
def Yl95_m86(theta, phi):
    return 5.50786473455747e-163*(1.0 - cos(theta)**2)**43*(6.51895218886528e+169*cos(theta)**9 - 1.24170517883148e+169*cos(theta)**7 + 6.97214137846554e+167*cos(theta)**5 - 1.25624168981361e+166*cos(theta)**3 + 5.14853151562955e+163*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl95_m87(theta, phi):
    return 1.36090032358417e-164*(1.0 - cos(theta)**2)**43.5*(5.86705696997875e+170*cos(theta)**8 - 8.69193625182037e+169*cos(theta)**6 + 3.48607068923277e+168*cos(theta)**4 - 3.76872506944083e+166*cos(theta)**2 + 5.14853151562955e+163)*cos(87*phi)

#@torch.jit.script
def Yl95_m88(theta, phi):
    return 3.55676997310882e-166*(1.0 - cos(theta)**2)**44*(4.693645575983e+171*cos(theta)**7 - 5.21516175109222e+170*cos(theta)**5 + 1.39442827569311e+169*cos(theta)**3 - 7.53745013888166e+166*cos(theta))*cos(88*phi)

#@torch.jit.script
def Yl95_m89(theta, phi):
    return 9.91055206577886e-168*(1.0 - cos(theta)**2)**44.5*(3.2855519031881e+172*cos(theta)**6 - 2.60758087554611e+171*cos(theta)**4 + 4.18328482707932e+169*cos(theta)**2 - 7.53745013888166e+166)*cos(89*phi)

#@torch.jit.script
def Yl95_m90(theta, phi):
    return 2.97465331841056e-169*(1.0 - cos(theta)**2)**45*(1.97133114191286e+173*cos(theta)**5 - 1.04303235021844e+172*cos(theta)**3 + 8.36656965415864e+169*cos(theta))*cos(90*phi)

#@torch.jit.script
def Yl95_m91(theta, phi):
    return 9.75427249357057e-171*(1.0 - cos(theta)**2)**45.5*(9.8566557095643e+173*cos(theta)**4 - 3.12909705065533e+172*cos(theta)**2 + 8.36656965415864e+169)*cos(91*phi)

#@torch.jit.script
def Yl95_m92(theta, phi):
    return 3.56651524598497e-172*(1.0 - cos(theta)**2)**46*(3.94266228382572e+174*cos(theta)**3 - 6.25819410131067e+172*cos(theta))*cos(92*phi)

#@torch.jit.script
def Yl95_m93(theta, phi):
    return 1.50177383295964e-173*(1.0 - cos(theta)**2)**46.5*(1.18279868514772e+175*cos(theta)**2 - 6.25819410131067e+172)*cos(93*phi)

#@torch.jit.script
def Yl95_m94(theta, phi):
    return 18.2725627380863*(1.0 - cos(theta)**2)**47*cos(94*phi)*cos(theta)

#@torch.jit.script
def Yl95_m95(theta, phi):
    return 1.32563102951268*(1.0 - cos(theta)**2)**47.5*cos(95*phi)

#@torch.jit.script
def Yl96_m_minus_96(theta, phi):
    return 1.32907871031442*(1.0 - cos(theta)**2)**48*sin(96*phi)

#@torch.jit.script
def Yl96_m_minus_95(theta, phi):
    return 18.4162548281816*(1.0 - cos(theta)**2)**47.5*sin(95*phi)*cos(theta)

#@torch.jit.script
def Yl96_m_minus_94(theta, phi):
    return 7.96633932527857e-176*(1.0 - cos(theta)**2)**47*(2.25914548863214e+177*cos(theta)**2 - 1.18279868514772e+175)*sin(94*phi)

#@torch.jit.script
def Yl96_m_minus_93(theta, phi):
    return 1.90193744586733e-174*(1.0 - cos(theta)**2)**46.5*(7.53048496210712e+176*cos(theta)**3 - 1.18279868514772e+175*cos(theta))*sin(93*phi)

#@torch.jit.script
def Yl96_m_minus_92(theta, phi):
    return 5.22946338765481e-173*(1.0 - cos(theta)**2)**46*(1.88262124052678e+176*cos(theta)**4 - 5.91399342573858e+174*cos(theta)**2 + 1.56454852532767e+172)*sin(92*phi)

#@torch.jit.script
def Yl96_m_minus_91(theta, phi):
    return 1.60332311414302e-171*(1.0 - cos(theta)**2)**45.5*(3.76524248105356e+175*cos(theta)**5 - 1.97133114191286e+174*cos(theta)**3 + 1.56454852532767e+172*cos(theta))*sin(91*phi)

#@torch.jit.script
def Yl96_m_minus_90(theta, phi):
    return 5.37053414416425e-170*(1.0 - cos(theta)**2)**45*(6.27540413508927e+174*cos(theta)**6 - 4.92832785478215e+173*cos(theta)**4 + 7.82274262663833e+171*cos(theta)**2 - 1.39442827569311e+169)*sin(90*phi)

#@torch.jit.script
def Yl96_m_minus_89(theta, phi):
    return 1.93786256906189e-168*(1.0 - cos(theta)**2)**44.5*(8.96486305012753e+173*cos(theta)**7 - 9.8566557095643e+172*cos(theta)**5 + 2.60758087554611e+171*cos(theta)**3 - 1.39442827569311e+169*cos(theta))*sin(89*phi)

#@torch.jit.script
def Yl96_m_minus_88(theta, phi):
    return 7.45510615492852e-167*(1.0 - cos(theta)**2)**44*(1.12060788126594e+173*cos(theta)**8 - 1.64277595159405e+172*cos(theta)**6 + 6.51895218886528e+170*cos(theta)**4 - 6.97214137846554e+168*cos(theta)**2 + 9.42181267360208e+165)*sin(88*phi)

#@torch.jit.script
def Yl96_m_minus_87(theta, phi):
    return 3.03377940011721e-165*(1.0 - cos(theta)**2)**43.5*(1.24511986807327e+172*cos(theta)**9 - 2.3468227879915e+171*cos(theta)**7 + 1.30379043777306e+170*cos(theta)**5 - 2.32404712615518e+168*cos(theta)**3 + 9.42181267360208e+165*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl96_m_minus_86(theta, phi):
    return 1.29780529860581e-163*(1.0 - cos(theta)**2)**43*(1.24511986807327e+171*cos(theta)**10 - 2.93352848498937e+170*cos(theta)**8 + 2.17298406295509e+169*cos(theta)**6 - 5.81011781538795e+167*cos(theta)**4 + 4.71090633680104e+165*cos(theta)**2 - 5.14853151562955e+162)*sin(86*phi)

#@torch.jit.script
def Yl96_m_minus_85(theta, phi):
    return 5.80686299422056e-162*(1.0 - cos(theta)**2)**42.5*(1.13192715279388e+170*cos(theta)**11 - 3.25947609443264e+169*cos(theta)**9 + 3.1042629470787e+168*cos(theta)**7 - 1.16202356307759e+167*cos(theta)**5 + 1.57030211226701e+165*cos(theta)**3 - 5.14853151562955e+162*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl96_m_minus_84(theta, phi):
    return 2.70627228516799e-160*(1.0 - cos(theta)**2)**42*(9.43272627328233e+168*cos(theta)**12 - 3.25947609443264e+168*cos(theta)**10 + 3.88032868384838e+167*cos(theta)**8 - 1.93670593846265e+166*cos(theta)**6 + 3.92575528066753e+164*cos(theta)**4 - 2.57426575781477e+162*cos(theta)**2 + 2.37041045839298e+159)*sin(84*phi)

#@torch.jit.script
def Yl96_m_minus_83(theta, phi):
    return 1.30911988200608e-158*(1.0 - cos(theta)**2)**41.5*(7.25594328714026e+167*cos(theta)**13 - 2.96316008584785e+167*cos(theta)**11 + 4.31147631538709e+166*cos(theta)**9 - 2.76672276923236e+165*cos(theta)**7 + 7.85151056133506e+163*cos(theta)**5 - 8.58088585938258e+161*cos(theta)**3 + 2.37041045839298e+159*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl96_m_minus_82(theta, phi):
    return 6.55344942213777e-157*(1.0 - cos(theta)**2)**41*(5.18281663367161e+166*cos(theta)**14 - 2.46930007153988e+166*cos(theta)**12 + 4.31147631538709e+165*cos(theta)**10 - 3.45840346154044e+164*cos(theta)**8 + 1.30858509355584e+163*cos(theta)**6 - 2.14522146484565e+161*cos(theta)**4 + 1.18520522919649e+159*cos(theta)**2 - 9.45894037666791e+155)*sin(82*phi)

#@torch.jit.script
def Yl96_m_minus_81(theta, phi):
    return 3.38630118576512e-155*(1.0 - cos(theta)**2)**40.5*(3.45521108911441e+165*cos(theta)**15 - 1.89946159349221e+165*cos(theta)**13 + 3.91952392307917e+164*cos(theta)**11 - 3.84267051282272e+163*cos(theta)**9 + 1.86940727650835e+162*cos(theta)**7 - 4.29044292969129e+160*cos(theta)**5 + 3.95068409732163e+158*cos(theta)**3 - 9.45894037666791e+155*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl96_m_minus_80(theta, phi):
    return 1.80207228381835e-153*(1.0 - cos(theta)**2)**40*(2.1595069306965e+164*cos(theta)**16 - 1.35675828106587e+164*cos(theta)**14 + 3.26626993589931e+163*cos(theta)**12 - 3.84267051282272e+162*cos(theta)**10 + 2.33675909563544e+161*cos(theta)**8 - 7.15073821615215e+159*cos(theta)**6 + 9.87671024330408e+157*cos(theta)**4 - 4.72947018833396e+155*cos(theta)**2 + 3.34002131944488e+152)*sin(80*phi)

#@torch.jit.script
def Yl96_m_minus_79(theta, phi):
    return 9.85718714045239e-152*(1.0 - cos(theta)**2)**39.5*(1.27029819452736e+163*cos(theta)**17 - 9.04505520710578e+162*cos(theta)**15 + 2.51251533530716e+162*cos(theta)**13 - 3.49333682983883e+161*cos(theta)**11 + 2.59639899515048e+160*cos(theta)**9 - 1.02153403087888e+159*cos(theta)**7 + 1.97534204866082e+157*cos(theta)**5 - 1.57649006277799e+155*cos(theta)**3 + 3.34002131944488e+152*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl96_m_minus_78(theta, phi):
    return 5.53233256153302e-150*(1.0 - cos(theta)**2)**39*(7.05721219181864e+161*cos(theta)**18 - 5.65315950444111e+161*cos(theta)**16 + 1.79465381093369e+161*cos(theta)**14 - 2.91111402486569e+160*cos(theta)**12 + 2.59639899515048e+159*cos(theta)**10 - 1.2769175385986e+158*cos(theta)**8 + 3.29223674776803e+156*cos(theta)**6 - 3.94122515694496e+154*cos(theta)**4 + 1.67001065972244e+152*cos(theta)**2 - 1.0603242283952e+149)*sin(78*phi)

#@torch.jit.script
def Yl96_m_minus_77(theta, phi):
    return 3.18097095250874e-148*(1.0 - cos(theta)**2)**38.5*(3.71432220622034e+160*cos(theta)**19 - 3.32538794378889e+160*cos(theta)**17 + 1.19643587395579e+160*cos(theta)**15 - 2.23931848066592e+159*cos(theta)**13 + 2.36036272286408e+158*cos(theta)**11 - 1.41879726510955e+157*cos(theta)**9 + 4.70319535395432e+155*cos(theta)**7 - 7.88245031388993e+153*cos(theta)**5 + 5.56670219907481e+151*cos(theta)**3 - 1.0603242283952e+149*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl96_m_minus_76(theta, phi):
    return 1.87110324820511e-146*(1.0 - cos(theta)**2)**38*(1.85716110311017e+159*cos(theta)**20 - 1.84743774654938e+159*cos(theta)**18 + 7.47772421222369e+158*cos(theta)**16 - 1.59951320047566e+158*cos(theta)**14 + 1.96696893572006e+157*cos(theta)**12 - 1.41879726510955e+156*cos(theta)**10 + 5.8789941924429e+154*cos(theta)**8 - 1.31374171898165e+153*cos(theta)**6 + 1.3916755497687e+151*cos(theta)**4 - 5.30162114197601e+148*cos(theta)**2 + 3.06452089131561e+145)*sin(76*phi)

#@torch.jit.script
def Yl96_m_minus_75(theta, phi):
    return 1.12453149551192e-144*(1.0 - cos(theta)**2)**37.5*(8.84362430052461e+157*cos(theta)**21 - 9.72335656078623e+157*cos(theta)**19 + 4.39866130130805e+157*cos(theta)**17 - 1.06634213365044e+157*cos(theta)**15 + 1.51305302747697e+156*cos(theta)**13 - 1.28981569555414e+155*cos(theta)**11 + 6.532215769381e+153*cos(theta)**9 - 1.87677388425951e+152*cos(theta)**7 + 2.7833510995374e+150*cos(theta)**5 - 1.76720704732534e+148*cos(theta)**3 + 3.06452089131561e+145*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl96_m_minus_74(theta, phi):
    return 6.89733022227171e-143*(1.0 - cos(theta)**2)**37*(4.01982922751119e+156*cos(theta)**22 - 4.86167828039311e+156*cos(theta)**20 + 2.44370072294892e+156*cos(theta)**18 - 6.66463833531523e+155*cos(theta)**16 + 1.08075216248355e+155*cos(theta)**14 - 1.07484641296178e+154*cos(theta)**12 + 6.532215769381e+152*cos(theta)**10 - 2.34596735532438e+151*cos(theta)**8 + 4.63891849922901e+149*cos(theta)**6 - 4.41801761831334e+147*cos(theta)**4 + 1.53226044565781e+145*cos(theta)**2 - 8.14598854682512e+141)*sin(74*phi)

#@torch.jit.script
def Yl96_m_minus_73(theta, phi):
    return 4.31290009161695e-141*(1.0 - cos(theta)**2)**36.5*(1.74775183804834e+155*cos(theta)**23 - 2.31508489542529e+155*cos(theta)**21 + 1.28615827523627e+155*cos(theta)**19 - 3.9203754913619e+154*cos(theta)**17 + 7.20501441655701e+153*cos(theta)**15 - 8.26804933047526e+152*cos(theta)**13 + 5.93837797216455e+151*cos(theta)**11 - 2.60663039480487e+150*cos(theta)**9 + 6.62702642747001e+148*cos(theta)**7 - 8.83603523662668e+146*cos(theta)**5 + 5.10753481885935e+144*cos(theta)**3 - 8.14598854682512e+141*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl96_m_minus_72(theta, phi):
    return 2.74674517937673e-139*(1.0 - cos(theta)**2)**36*(7.28229932520143e+153*cos(theta)**24 - 1.05231131610241e+154*cos(theta)**22 + 6.43079137618137e+153*cos(theta)**20 - 2.17798638408995e+153*cos(theta)**18 + 4.50313401034813e+152*cos(theta)**16 - 5.90574952176804e+151*cos(theta)**14 + 4.94864831013712e+150*cos(theta)**12 - 2.60663039480487e+149*cos(theta)**10 + 8.28378303433751e+147*cos(theta)**8 - 1.47267253943778e+146*cos(theta)**6 + 1.27688370471484e+144*cos(theta)**4 - 4.07299427341256e+141*cos(theta)**2 + 2.00837981923696e+138)*sin(72*phi)

#@torch.jit.script
def Yl96_m_minus_71(theta, phi):
    return 1.78009432721424e-137*(1.0 - cos(theta)**2)**35.5*(2.91291973008057e+152*cos(theta)**25 - 4.57526659174959e+152*cos(theta)**23 + 3.06228160770541e+152*cos(theta)**21 - 1.14630862320523e+152*cos(theta)**19 + 2.64890235902831e+151*cos(theta)**17 - 3.93716634784536e+150*cos(theta)**15 + 3.80665254625933e+149*cos(theta)**13 - 2.36966399527715e+148*cos(theta)**11 + 9.20420337148612e+146*cos(theta)**9 - 2.10381791348254e+145*cos(theta)**7 + 2.55376740942968e+143*cos(theta)**5 - 1.35766475780419e+141*cos(theta)**3 + 2.00837981923696e+138*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl96_m_minus_70(theta, phi):
    return 1.1729727577158e-135*(1.0 - cos(theta)**2)**35*(1.12035374233868e+151*cos(theta)**26 - 1.90636107989566e+151*cos(theta)**24 + 1.39194618532064e+151*cos(theta)**22 - 5.73154311602617e+150*cos(theta)**20 + 1.4716124216824e+150*cos(theta)**18 - 2.46072896740335e+149*cos(theta)**16 + 2.71903753304238e+148*cos(theta)**14 - 1.9747199960643e+147*cos(theta)**12 + 9.20420337148612e+145*cos(theta)**10 - 2.62977239185318e+144*cos(theta)**8 + 4.25627901571613e+142*cos(theta)**6 - 3.39416189451047e+140*cos(theta)**4 + 1.00418990961848e+138*cos(theta)**2 - 4.62547171634492e+134)*sin(70*phi)

#@torch.jit.script
def Yl96_m_minus_69(theta, phi):
    return 7.85278761645772e-134*(1.0 - cos(theta)**2)**34.5*(4.14945830495808e+149*cos(theta)**27 - 7.62544431958265e+149*cos(theta)**25 + 6.0519399361767e+149*cos(theta)**23 - 2.72930624572675e+149*cos(theta)**21 + 7.7453285351705e+148*cos(theta)**19 - 1.44748762788432e+148*cos(theta)**17 + 1.81269168869492e+147*cos(theta)**15 - 1.51901538158792e+146*cos(theta)**13 + 8.36745761044193e+144*cos(theta)**11 - 2.92196932428131e+143*cos(theta)**9 + 6.08039859388018e+141*cos(theta)**7 - 6.78832378902094e+139*cos(theta)**5 + 3.34729969872827e+137*cos(theta)**3 - 4.62547171634492e+134*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl96_m_minus_68(theta, phi):
    return 5.33758543606813e-132*(1.0 - cos(theta)**2)**34*(1.48194939462789e+148*cos(theta)**28 - 2.93286319983948e+148*cos(theta)**26 + 2.52164164007363e+148*cos(theta)**24 - 1.24059374805761e+148*cos(theta)**22 + 3.87266426758525e+147*cos(theta)**20 - 8.04159793269069e+146*cos(theta)**18 + 1.13293230543432e+146*cos(theta)**16 - 1.08501098684851e+145*cos(theta)**14 + 6.97288134203494e+143*cos(theta)**12 - 2.92196932428131e+142*cos(theta)**10 + 7.60049824235023e+140*cos(theta)**8 - 1.13138729817016e+139*cos(theta)**6 + 8.36824924682068e+136*cos(theta)**4 - 2.31273585817246e+134*cos(theta)**2 + 1.00118435418721e+131)*sin(68*phi)

#@torch.jit.script
def Yl96_m_minus_67(theta, phi):
    return 3.68099953510626e-130*(1.0 - cos(theta)**2)**33.5*(5.11017032630305e+146*cos(theta)**29 - 1.08624562957018e+147*cos(theta)**27 + 1.00865665602945e+147*cos(theta)**25 - 5.39388586112006e+146*cos(theta)**23 + 1.84412584170726e+146*cos(theta)**21 - 4.23241996457405e+145*cos(theta)**19 + 6.66430767902543e+144*cos(theta)**17 - 7.23340657899009e+143*cos(theta)**15 + 5.36375487848842e+142*cos(theta)**13 - 2.65633574934664e+141*cos(theta)**11 + 8.44499804705581e+139*cos(theta)**9 - 1.61626756881451e+138*cos(theta)**7 + 1.67364984936414e+136*cos(theta)**5 - 7.70911952724153e+133*cos(theta)**3 + 1.00118435418721e+131*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl96_m_minus_66(theta, phi):
    return 2.57406904634943e-128*(1.0 - cos(theta)**2)**33*(1.70339010876768e+145*cos(theta)**30 - 3.87944867703635e+145*cos(theta)**28 + 3.87944867703635e+145*cos(theta)**26 - 2.24745244213336e+145*cos(theta)**24 + 8.38239018957847e+144*cos(theta)**22 - 2.11620998228702e+144*cos(theta)**20 + 3.70239315501413e+143*cos(theta)**18 - 4.52087911186881e+142*cos(theta)**16 + 3.83125348463458e+141*cos(theta)**14 - 2.21361312445554e+140*cos(theta)**12 + 8.44499804705581e+138*cos(theta)**10 - 2.02033446101814e+137*cos(theta)**8 + 2.78941641560689e+135*cos(theta)**6 - 1.92727988181038e+133*cos(theta)**4 + 5.00592177093606e+130*cos(theta)**2 - 2.04741176725401e+127)*sin(66*phi)

#@torch.jit.script
def Yl96_m_minus_65(theta, phi):
    return 1.8241415945285e-126*(1.0 - cos(theta)**2)**32.5*(5.4948068024764e+143*cos(theta)**31 - 1.33774092311598e+144*cos(theta)**29 + 1.4368328433468e+144*cos(theta)**27 - 8.98980976853343e+143*cos(theta)**25 + 3.64451747372977e+143*cos(theta)**23 - 1.0077190391843e+143*cos(theta)**21 + 1.94862797632323e+142*cos(theta)**19 - 2.65934065404048e+141*cos(theta)**17 + 2.55416898975639e+140*cos(theta)**15 - 1.70277932650426e+139*cos(theta)**13 + 7.67727095186891e+137*cos(theta)**11 - 2.24481606779793e+136*cos(theta)**9 + 3.98488059372413e+134*cos(theta)**7 - 3.85455976362076e+132*cos(theta)**5 + 1.66864059031202e+130*cos(theta)**3 - 2.04741176725401e+127*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl96_m_minus_64(theta, phi):
    return 1.30932202506075e-124*(1.0 - cos(theta)**2)**32*(1.71712712577388e+142*cos(theta)**32 - 4.45913641038661e+142*cos(theta)**30 + 5.1315458690957e+142*cos(theta)**28 - 3.45761914174363e+142*cos(theta)**26 + 1.5185489473874e+142*cos(theta)**24 - 4.58054108720135e+141*cos(theta)**22 + 9.74313988161613e+140*cos(theta)**20 - 1.47741147446693e+140*cos(theta)**18 + 1.59635561859774e+139*cos(theta)**16 - 1.21627094750304e+138*cos(theta)**14 + 6.3977257932241e+136*cos(theta)**12 - 2.24481606779793e+135*cos(theta)**10 + 4.98110074215517e+133*cos(theta)**8 - 6.42426627270127e+131*cos(theta)**6 + 4.17160147578005e+129*cos(theta)**4 - 1.02370588362701e+127*cos(theta)**2 + 3.97401352339676e+123)*sin(64*phi)

#@torch.jit.script
def Yl96_m_minus_63(theta, phi):
    return 9.51400630272681e-123*(1.0 - cos(theta)**2)**31.5*(5.20341553264811e+140*cos(theta)**33 - 1.43843110012471e+141*cos(theta)**31 + 1.76949857555024e+141*cos(theta)**29 - 1.28059968212727e+141*cos(theta)**27 + 6.07419578954961e+140*cos(theta)**25 - 1.99153960313102e+140*cos(theta)**23 + 4.6395904198172e+139*cos(theta)**21 - 7.77584986561543e+138*cos(theta)**19 + 9.39032716822202e+137*cos(theta)**17 - 8.10847298335361e+136*cos(theta)**15 + 4.9213275332493e+135*cos(theta)**13 - 2.0407418798163e+134*cos(theta)**11 + 5.53455638017241e+132*cos(theta)**9 - 9.17752324671611e+130*cos(theta)**7 + 8.3432029515601e+128*cos(theta)**5 - 3.41235294542335e+126*cos(theta)**3 + 3.97401352339676e+123*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl96_m_minus_62(theta, phi):
    return 6.99522125388846e-121*(1.0 - cos(theta)**2)**31*(1.5304163331318e+139*cos(theta)**34 - 4.49509718788973e+139*cos(theta)**32 + 5.89832858516747e+139*cos(theta)**30 - 4.57357029331168e+139*cos(theta)**28 + 2.33622914982677e+139*cos(theta)**26 - 8.29808167971259e+138*cos(theta)**24 + 2.10890473628055e+138*cos(theta)**22 - 3.88792493280771e+137*cos(theta)**20 + 5.21684842679001e+136*cos(theta)**18 - 5.06779561459601e+135*cos(theta)**16 + 3.51523395232093e+134*cos(theta)**14 - 1.70061823318025e+133*cos(theta)**12 + 5.53455638017241e+131*cos(theta)**10 - 1.14719040583951e+130*cos(theta)**8 + 1.39053382526002e+128*cos(theta)**6 - 8.53088236355838e+125*cos(theta)**4 + 1.98700676169838e+123*cos(theta)**2 - 7.3511163954805e+119)*sin(62*phi)

#@torch.jit.script
def Yl96_m_minus_61(theta, phi):
    return 5.20192421860811e-119*(1.0 - cos(theta)**2)**30.5*(4.37261809466227e+137*cos(theta)**35 - 1.36215066299689e+138*cos(theta)**33 + 1.9026866403766e+138*cos(theta)**31 - 1.57709320459023e+138*cos(theta)**29 + 8.65270055491398e+137*cos(theta)**27 - 3.31923267188503e+137*cos(theta)**25 + 9.16915102730673e+136*cos(theta)**23 - 1.85139282514653e+136*cos(theta)**21 + 2.74570969831053e+135*cos(theta)**19 - 2.98105624388001e+134*cos(theta)**17 + 2.34348930154729e+133*cos(theta)**15 - 1.30816787167711e+132*cos(theta)**13 + 5.03141489106582e+130*cos(theta)**11 - 1.27465600648835e+129*cos(theta)**9 + 1.98647689322859e+127*cos(theta)**7 - 1.70617647271168e+125*cos(theta)**5 + 6.62335587232794e+122*cos(theta)**3 - 7.3511163954805e+119*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl96_m_minus_60(theta, phi):
    return 3.91079541827941e-117*(1.0 - cos(theta)**2)**30*(1.21461613740619e+136*cos(theta)**36 - 4.00632547940261e+136*cos(theta)**34 + 5.94589575117689e+136*cos(theta)**32 - 5.25697734863411e+136*cos(theta)**30 + 3.09025019818356e+136*cos(theta)**28 - 1.27662795072501e+136*cos(theta)**26 + 3.82047959471114e+135*cos(theta)**24 - 8.41542193248423e+134*cos(theta)**22 + 1.37285484915527e+134*cos(theta)**20 - 1.65614235771111e+133*cos(theta)**18 + 1.46468081346705e+132*cos(theta)**16 - 9.3440562262651e+130*cos(theta)**14 + 4.19284574255485e+129*cos(theta)**12 - 1.27465600648835e+128*cos(theta)**10 + 2.48309611653574e+126*cos(theta)**8 - 2.84362745451946e+124*cos(theta)**6 + 1.65583896808198e+122*cos(theta)**4 - 3.67555819774025e+119*cos(theta)**2 + 1.30062215065119e+116)*sin(60*phi)

#@torch.jit.script
def Yl96_m_minus_59(theta, phi):
    return 2.97117518296351e-115*(1.0 - cos(theta)**2)**29.5*(3.28274631731402e+134*cos(theta)**37 - 1.14466442268646e+135*cos(theta)**35 + 1.80178659126572e+135*cos(theta)**33 - 1.69579914472068e+135*cos(theta)**31 + 1.06560351661502e+135*cos(theta)**29 - 4.7282516693519e+134*cos(theta)**27 + 1.52819183788445e+134*cos(theta)**25 - 3.6588791010801e+133*cos(theta)**23 + 6.5374040435965e+132*cos(theta)**21 - 8.71653872479534e+131*cos(theta)**19 + 8.61576949098268e+130*cos(theta)**17 - 6.22937081751007e+129*cos(theta)**15 + 3.22526595581143e+128*cos(theta)**13 - 1.15877818771668e+127*cos(theta)**11 + 2.75899568503971e+125*cos(theta)**9 - 4.0623249350278e+123*cos(theta)**7 + 3.31167793616397e+121*cos(theta)**5 - 1.22518606591342e+119*cos(theta)**3 + 1.30062215065119e+116*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl96_m_minus_58(theta, phi):
    return 2.28026807175571e-113*(1.0 - cos(theta)**2)**29*(8.63880609819479e+132*cos(theta)**38 - 3.17962339635128e+133*cos(theta)**36 + 5.29937232725213e+133*cos(theta)**34 - 5.29937232725213e+133*cos(theta)**32 + 3.55201172205007e+133*cos(theta)**30 - 1.68866131048282e+133*cos(theta)**28 + 5.87766091494021e+132*cos(theta)**26 - 1.52453295878337e+132*cos(theta)**24 + 2.97154729254387e+131*cos(theta)**22 - 4.35826936239767e+130*cos(theta)**20 + 4.78653860610149e+129*cos(theta)**18 - 3.89335676094379e+128*cos(theta)**16 + 2.30376139700816e+127*cos(theta)**14 - 9.656484897639e+125*cos(theta)**12 + 2.75899568503971e+124*cos(theta)**10 - 5.07790616878475e+122*cos(theta)**8 + 5.51946322693995e+120*cos(theta)**6 - 3.06296516478354e+118*cos(theta)**4 + 6.50311075325593e+115*cos(theta)**2 - 2.20818701299013e+112)*sin(58*phi)

#@torch.jit.script
def Yl96_m_minus_57(theta, phi):
    return 1.76717097671067e-111*(1.0 - cos(theta)**2)**28.5*(2.21507848671661e+131*cos(theta)**39 - 8.59357674689534e+131*cos(theta)**37 + 1.51410637921489e+132*cos(theta)**35 - 1.60587040219761e+132*cos(theta)**33 + 1.14581023291938e+132*cos(theta)**31 - 5.82297003614766e+131*cos(theta)**29 + 2.17691144997786e+131*cos(theta)**27 - 6.0981318351335e+130*cos(theta)**25 + 1.29197708371472e+130*cos(theta)**23 - 2.07536636304651e+129*cos(theta)**21 + 2.51923084531657e+128*cos(theta)**19 - 2.2902098593787e+127*cos(theta)**17 + 1.53584093133877e+126*cos(theta)**15 - 7.42806530587615e+124*cos(theta)**13 + 2.50817789549065e+123*cos(theta)**11 - 5.64211796531639e+121*cos(theta)**9 + 7.88494746705706e+119*cos(theta)**7 - 6.12593032956709e+117*cos(theta)**5 + 2.16770358441864e+115*cos(theta)**3 - 2.20818701299013e+112*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl96_m_minus_56(theta, phi):
    return 1.38246543381318e-109*(1.0 - cos(theta)**2)**28*(5.53769621679153e+129*cos(theta)**40 - 2.26146756497246e+130*cos(theta)**38 + 4.2058510533747e+130*cos(theta)**36 - 4.72314824175769e+130*cos(theta)**34 + 3.58065697787306e+130*cos(theta)**32 - 1.94099001204922e+130*cos(theta)**30 + 7.77468374992091e+129*cos(theta)**28 - 2.34543532120519e+129*cos(theta)**26 + 5.38323784881135e+128*cos(theta)**24 - 9.43348346839322e+127*cos(theta)**22 + 1.25961542265829e+127*cos(theta)**20 - 1.27233881076595e+126*cos(theta)**18 + 9.59900582086734e+124*cos(theta)**16 - 5.30576093276868e+123*cos(theta)**14 + 2.09014824624221e+122*cos(theta)**12 - 5.64211796531639e+120*cos(theta)**10 + 9.85618433382133e+118*cos(theta)**8 - 1.02098838826118e+117*cos(theta)**6 + 5.41925896104661e+114*cos(theta)**4 - 1.10409350649506e+112*cos(theta)**2 + 3.60814871403616e+108)*sin(56*phi)

#@torch.jit.script
def Yl96_m_minus_55(theta, phi):
    return 1.0913599282954e-107*(1.0 - cos(theta)**2)**27.5*(1.35065761385159e+128*cos(theta)**41 - 5.79863478198066e+128*cos(theta)**39 + 1.13671650091208e+129*cos(theta)**37 - 1.34947092621648e+129*cos(theta)**35 + 1.08504756905244e+129*cos(theta)**33 - 6.26125810338458e+128*cos(theta)**31 + 2.68092543100721e+128*cos(theta)**29 - 8.68679748594515e+127*cos(theta)**27 + 2.15329513952454e+127*cos(theta)**25 - 4.10151455147531e+126*cos(theta)**23 + 5.99816867932517e+125*cos(theta)**21 - 6.69652005666287e+124*cos(theta)**19 + 5.6464740122749e+123*cos(theta)**17 - 3.53717395517912e+122*cos(theta)**15 + 1.60780634326324e+121*cos(theta)**13 - 5.12919815028763e+119*cos(theta)**11 + 1.09513159264681e+118*cos(theta)**9 - 1.45855484037312e+116*cos(theta)**7 + 1.08385179220932e+114*cos(theta)**5 - 3.68031168831688e+111*cos(theta)**3 + 3.60814871403616e+108*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl96_m_minus_54(theta, phi):
    return 8.69122758830419e-106*(1.0 - cos(theta)**2)**27*(3.21585146155141e+126*cos(theta)**42 - 1.44965869549517e+127*cos(theta)**40 + 2.99135921292653e+127*cos(theta)**38 - 3.74853035060134e+127*cos(theta)**36 + 3.19131637956601e+127*cos(theta)**34 - 1.95664315730768e+127*cos(theta)**32 + 8.93641810335737e+126*cos(theta)**30 - 3.10242767355184e+126*cos(theta)**28 + 8.28190438278669e+125*cos(theta)**26 - 1.70896439644805e+125*cos(theta)**24 + 2.72644030878417e+124*cos(theta)**22 - 3.34826002833143e+123*cos(theta)**20 + 3.13693000681939e+122*cos(theta)**18 - 2.21073372198695e+121*cos(theta)**16 + 1.14843310233088e+120*cos(theta)**14 - 4.27433179190635e+118*cos(theta)**12 + 1.09513159264681e+117*cos(theta)**10 - 1.82319355046639e+115*cos(theta)**8 + 1.8064196536822e+113*cos(theta)**6 - 9.20077922079221e+110*cos(theta)**4 + 1.80407435701808e+108*cos(theta)**2 - 5.68929157053951e+104)*sin(54*phi)

#@torch.jit.script
def Yl96_m_minus_53(theta, phi):
    return 6.98008931602214e-104*(1.0 - cos(theta)**2)**26.5*(7.47872432918933e+124*cos(theta)**43 - 3.53575291584187e+125*cos(theta)**41 + 7.67015182801675e+125*cos(theta)**39 - 1.01311631097334e+126*cos(theta)**37 + 9.11804679876002e+125*cos(theta)**35 - 5.92922168881116e+125*cos(theta)**33 + 2.88271551721205e+125*cos(theta)**31 - 1.06980264605236e+125*cos(theta)**29 + 3.0673719936247e+124*cos(theta)**27 - 6.83585758579219e+123*cos(theta)**25 + 1.18540882990616e+123*cos(theta)**23 - 1.59440953730068e+122*cos(theta)**21 + 1.65101579306284e+121*cos(theta)**19 - 1.30043160116879e+120*cos(theta)**17 + 7.65622068220589e+118*cos(theta)**15 - 3.28794753223566e+117*cos(theta)**13 + 9.95574175133468e+115*cos(theta)**11 - 2.02577061162933e+114*cos(theta)**9 + 2.58059950526029e+112*cos(theta)**7 - 1.84015584415844e+110*cos(theta)**5 + 6.01358119006027e+107*cos(theta)**3 - 5.68929157053951e+104*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl96_m_minus_52(theta, phi):
    return 5.65171758682122e-102*(1.0 - cos(theta)**2)**26*(1.69971007481576e+123*cos(theta)**44 - 8.41845932343302e+123*cos(theta)**42 + 1.91753795700419e+124*cos(theta)**40 - 2.66609555519299e+124*cos(theta)**38 + 2.53279077743334e+124*cos(theta)**36 - 1.74388873200328e+124*cos(theta)**34 + 9.00848599128767e+123*cos(theta)**32 - 3.56600882017453e+123*cos(theta)**30 + 1.09548999772311e+123*cos(theta)**28 - 2.62917599453546e+122*cos(theta)**26 + 4.93920345794233e+121*cos(theta)**24 - 7.24731607863947e+120*cos(theta)**22 + 8.25507896531419e+119*cos(theta)**20 - 7.2246200064933e+118*cos(theta)**18 + 4.78513792637868e+117*cos(theta)**16 - 2.3485339515969e+116*cos(theta)**14 + 8.29645145944557e+114*cos(theta)**12 - 2.02577061162933e+113*cos(theta)**10 + 3.22574938157536e+111*cos(theta)**8 - 3.06692640693074e+109*cos(theta)**6 + 1.50339529751507e+107*cos(theta)**4 - 2.84464578526976e+104*cos(theta)**2 + 8.67799202339767e+100)*sin(52*phi)

#@torch.jit.script
def Yl96_m_minus_51(theta, phi):
    return 4.61230020485101e-100*(1.0 - cos(theta)**2)**25.5*(3.77713349959057e+121*cos(theta)**45 - 1.95778123800768e+122*cos(theta)**43 + 4.67692184635168e+122*cos(theta)**41 - 6.83614244921279e+122*cos(theta)**39 + 6.84538047954956e+122*cos(theta)**37 - 4.98253923429509e+122*cos(theta)**35 + 2.72984423978414e+122*cos(theta)**33 - 1.15032542586275e+122*cos(theta)**31 + 3.77755171628658e+121*cos(theta)**29 - 9.73768886864984e+120*cos(theta)**27 + 1.97568138317693e+120*cos(theta)**25 - 3.15100699071281e+119*cos(theta)**23 + 3.93098998348295e+118*cos(theta)**21 - 3.8024315823649e+117*cos(theta)**19 + 2.81478701551687e+116*cos(theta)**17 - 1.5656893010646e+115*cos(theta)**15 + 6.38188573803505e+113*cos(theta)**13 - 1.84160964693575e+112*cos(theta)**11 + 3.58416597952818e+110*cos(theta)**9 - 4.38132343847248e+108*cos(theta)**7 + 3.00679059503013e+106*cos(theta)**5 - 9.48215261756586e+103*cos(theta)**3 + 8.67799202339767e+100*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl96_m_minus_50(theta, phi):
    return 3.79275814837856e-98*(1.0 - cos(theta)**2)**25*(8.21115978171863e+119*cos(theta)**46 - 4.44950281365381e+120*cos(theta)**44 + 1.11355282055992e+121*cos(theta)**42 - 1.7090356123032e+121*cos(theta)**40 + 1.80141591567094e+121*cos(theta)**38 - 1.38403867619308e+121*cos(theta)**36 + 8.02895364642395e+120*cos(theta)**34 - 3.5947669558211e+120*cos(theta)**32 + 1.25918390542886e+120*cos(theta)**30 - 3.4777460245178e+119*cos(theta)**28 + 7.59877455068051e+118*cos(theta)**26 - 1.31291957946367e+118*cos(theta)**24 + 1.78681362885589e+117*cos(theta)**22 - 1.90121579118245e+116*cos(theta)**20 + 1.56377056417604e+115*cos(theta)**18 - 9.78555813165374e+113*cos(theta)**16 + 4.55848981288218e+112*cos(theta)**14 - 1.53467470577979e+111*cos(theta)**12 + 3.58416597952818e+109*cos(theta)**10 - 5.4766542980906e+107*cos(theta)**8 + 5.01131765838355e+105*cos(theta)**6 - 2.37053815439146e+103*cos(theta)**4 + 4.33899601169884e+100*cos(theta)**2 - 1.28334694223568e+97)*sin(50*phi)

#@torch.jit.script
def Yl96_m_minus_49(theta, phi):
    return 3.14181426283119e-96*(1.0 - cos(theta)**2)**24.5*(1.74705527270609e+118*cos(theta)**47 - 9.88778403034181e+118*cos(theta)**45 + 2.58965772223238e+119*cos(theta)**43 - 4.16837954220292e+119*cos(theta)**41 + 4.61901516838702e+119*cos(theta)**39 - 3.74064507079211e+119*cos(theta)**37 + 2.29398675612113e+119*cos(theta)**35 - 1.08932331994579e+119*cos(theta)**33 + 4.06188356589955e+118*cos(theta)**31 - 1.1992227670751e+118*cos(theta)**29 + 2.81436094469649e+117*cos(theta)**27 - 5.25167831785469e+116*cos(theta)**25 + 7.76875490806907e+115*cos(theta)**23 - 9.05340852944023e+114*cos(theta)**21 + 8.23037139040021e+113*cos(theta)**19 - 5.75621066567867e+112*cos(theta)**17 + 3.03899320858812e+111*cos(theta)**15 - 1.180519004446e+110*cos(theta)**13 + 3.25833270866198e+108*cos(theta)**11 - 6.08517144232289e+106*cos(theta)**9 + 7.15902522626222e+104*cos(theta)**7 - 4.74107630878293e+102*cos(theta)**5 + 1.44633200389961e+100*cos(theta)**3 - 1.28334694223568e+97*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl96_m_minus_48(theta, phi):
    return 2.62110927205299e-94*(1.0 - cos(theta)**2)**24*(3.63969848480436e+116*cos(theta)**48 - 2.14951826746561e+117*cos(theta)**46 + 5.88558573234631e+117*cos(theta)**44 - 9.92471319572124e+117*cos(theta)**42 + 1.15475379209675e+118*cos(theta)**40 - 9.84380281787397e+117*cos(theta)**38 + 6.3721854336698e+117*cos(theta)**36 - 3.20389211748761e+117*cos(theta)**34 + 1.26933861434361e+117*cos(theta)**32 - 3.99740922358368e+116*cos(theta)**30 + 1.00512890882017e+116*cos(theta)**28 - 2.01987627609796e+115*cos(theta)**26 + 3.23698121169544e+114*cos(theta)**24 - 4.1151856952001e+113*cos(theta)**22 + 4.1151856952001e+112*cos(theta)**20 - 3.19789481426593e+111*cos(theta)**18 + 1.89937075536757e+110*cos(theta)**16 - 8.43227860318568e+108*cos(theta)**14 + 2.71527725721832e+107*cos(theta)**12 - 6.08517144232289e+105*cos(theta)**10 + 8.94878153282778e+103*cos(theta)**8 - 7.90179384797155e+101*cos(theta)**6 + 3.61583000974903e+99*cos(theta)**4 - 6.4167347111784e+96*cos(theta)**2 + 1.84388928482138e+93)*sin(48*phi)

#@torch.jit.script
def Yl96_m_minus_47(theta, phi):
    return 2.20173178852451e-92*(1.0 - cos(theta)**2)**23.5*(7.42795609143747e+114*cos(theta)**49 - 4.57344312226726e+115*cos(theta)**47 + 1.3079079405214e+116*cos(theta)**45 - 2.30807283621424e+116*cos(theta)**43 + 2.81647266365062e+116*cos(theta)**41 - 2.52405200458307e+116*cos(theta)**39 + 1.72221227937022e+116*cos(theta)**37 - 9.15397747853603e+115*cos(theta)**35 + 3.84648064952608e+115*cos(theta)**33 - 1.28948684631732e+115*cos(theta)**31 + 3.46596175455232e+114*cos(theta)**29 - 7.48102324480725e+113*cos(theta)**27 + 1.29479248467818e+113*cos(theta)**25 - 1.78921117182613e+112*cos(theta)**23 + 1.95961223580957e+111*cos(theta)**21 - 1.68310253382417e+110*cos(theta)**19 + 1.1172769149221e+109*cos(theta)**17 - 5.62151906879045e+107*cos(theta)**15 + 2.08867481324486e+106*cos(theta)**13 - 5.53197403847535e+104*cos(theta)**11 + 9.94309059203086e+102*cos(theta)**9 - 1.12882769256736e+101*cos(theta)**7 + 7.23166001949806e+98*cos(theta)**5 - 2.1389115703928e+96*cos(theta)**3 + 1.84388928482138e+93*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl96_m_minus_46(theta, phi):
    return 1.86173315785279e-90*(1.0 - cos(theta)**2)**23*(1.48559121828749e+113*cos(theta)**50 - 9.52800650472345e+113*cos(theta)**48 + 2.84327813156827e+114*cos(theta)**46 - 5.24562008230509e+114*cos(theta)**44 + 6.70588729440624e+114*cos(theta)**42 - 6.31013001145768e+114*cos(theta)**40 + 4.53213757729004e+114*cos(theta)**38 - 2.54277152181556e+114*cos(theta)**36 + 1.13131783809591e+114*cos(theta)**34 - 4.02964639474161e+113*cos(theta)**32 + 1.15532058485077e+113*cos(theta)**30 - 2.67179401600259e+112*cos(theta)**28 + 4.97997109491607e+111*cos(theta)**26 - 7.45504654927555e+110*cos(theta)**24 + 8.90732834458897e+109*cos(theta)**22 - 8.41551266912087e+108*cos(theta)**20 + 6.20709397178946e+107*cos(theta)**18 - 3.51344941799403e+106*cos(theta)**16 + 1.49191058088919e+105*cos(theta)**14 - 4.60997836539613e+103*cos(theta)**12 + 9.94309059203086e+101*cos(theta)**10 - 1.4110346157092e+100*cos(theta)**8 + 1.20527666991634e+98*cos(theta)**6 - 5.347278925982e+95*cos(theta)**4 + 9.2194464241069e+92*cos(theta)**2 - 2.57886613261731e+89)*sin(46*phi)

#@torch.jit.script
def Yl96_m_minus_45(theta, phi):
    return 1.58433382348208e-88*(1.0 - cos(theta)**2)**22.5*(2.91292395742646e+111*cos(theta)**51 - 1.94449112341295e+112*cos(theta)**49 + 6.04952793950695e+112*cos(theta)**47 - 1.16569335162335e+113*cos(theta)**45 + 1.55950867311773e+113*cos(theta)**43 - 1.53905610035553e+113*cos(theta)**41 + 1.1620865582795e+113*cos(theta)**39 - 6.87235546436639e+112*cos(theta)**37 + 3.23233668027402e+112*cos(theta)**35 - 1.22110496810352e+112*cos(theta)**33 + 3.72684059629282e+111*cos(theta)**31 - 9.21308281380203e+110*cos(theta)**29 + 1.8444337388578e+110*cos(theta)**27 - 2.98201861971022e+109*cos(theta)**25 + 3.87275145416912e+108*cos(theta)**23 - 4.00738698529565e+107*cos(theta)**21 + 3.26689156409972e+106*cos(theta)**19 - 2.0667349517612e+105*cos(theta)**17 + 9.94607053926124e+103*cos(theta)**15 - 3.54613720415087e+102*cos(theta)**13 + 9.0391732654826e+100*cos(theta)**11 - 1.56781623967689e+99*cos(theta)**9 + 1.7218238141662e+97*cos(theta)**7 - 1.0694557851964e+95*cos(theta)**5 + 3.07314880803563e+92*cos(theta)**3 - 2.57886613261731e+89*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl96_m_minus_44(theta, phi):
    return 1.35661908383044e-86*(1.0 - cos(theta)**2)**22*(5.60177684120473e+109*cos(theta)**52 - 3.8889822468259e+110*cos(theta)**50 + 1.26031832073062e+111*cos(theta)**48 - 2.5341159817899e+111*cos(theta)**46 + 3.54433789344939e+111*cos(theta)**44 - 3.66441928656079e+111*cos(theta)**42 + 2.90521639569875e+111*cos(theta)**40 - 1.80851459588589e+111*cos(theta)**38 + 8.97871300076117e+110*cos(theta)**36 - 3.59148520030447e+110*cos(theta)**34 + 1.16463768634151e+110*cos(theta)**32 - 3.07102760460068e+109*cos(theta)**30 + 6.58726335306358e+108*cos(theta)**28 - 1.14693023835008e+108*cos(theta)**26 + 1.61364643923713e+107*cos(theta)**24 - 1.82153953877075e+106*cos(theta)**22 + 1.63344578204986e+105*cos(theta)**20 - 1.14818608431178e+104*cos(theta)**18 + 6.21629408703828e+102*cos(theta)**16 - 2.53295514582205e+101*cos(theta)**14 + 7.53264438790217e+99*cos(theta)**12 - 1.56781623967689e+98*cos(theta)**10 + 2.15227976770776e+96*cos(theta)**8 - 1.78242630866067e+94*cos(theta)**6 + 7.68287202008908e+91*cos(theta)**4 - 1.28943306630866e+89*cos(theta)**2 + 3.51727513995815e+85)*sin(44*phi)

#@torch.jit.script
def Yl96_m_minus_43(theta, phi):
    return 1.16858383578193e-84*(1.0 - cos(theta)**2)**21.5*(1.0569390266424e+108*cos(theta)**53 - 7.62545538593313e+108*cos(theta)**51 + 2.57207820557268e+109*cos(theta)**49 - 5.39173613146787e+109*cos(theta)**47 + 7.87630642988753e+109*cos(theta)**45 - 8.52190531758323e+109*cos(theta)**43 + 7.08589364804572e+109*cos(theta)**41 - 4.63721691252793e+109*cos(theta)**39 + 2.42667918939491e+109*cos(theta)**37 - 1.02613862865842e+109*cos(theta)**35 + 3.52920511012578e+108*cos(theta)**33 - 9.90654066000218e+107*cos(theta)**31 + 2.27147012174606e+107*cos(theta)**29 - 4.24788977166698e+106*cos(theta)**27 + 6.45458575694853e+105*cos(theta)**25 - 7.91973712509022e+104*cos(theta)**23 + 7.77831324785646e+103*cos(theta)**21 - 6.0430846542725e+102*cos(theta)**19 + 3.65664358061075e+101*cos(theta)**17 - 1.68863676388137e+100*cos(theta)**15 + 5.79434183684782e+98*cos(theta)**13 - 1.42528749061536e+97*cos(theta)**11 + 2.39142196411973e+95*cos(theta)**9 - 2.54632329808667e+93*cos(theta)**7 + 1.53657440401782e+91*cos(theta)**5 - 4.29811022102886e+88*cos(theta)**3 + 3.51727513995815e+85*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl96_m_minus_42(theta, phi):
    return 1.01242801662482e-82*(1.0 - cos(theta)**2)**21*(1.95729449378222e+106*cos(theta)**54 - 1.46643372806406e+107*cos(theta)**52 + 5.14415641114537e+107*cos(theta)**50 - 1.12327836072247e+108*cos(theta)**48 + 1.71224052823642e+108*cos(theta)**46 - 1.9367966630871e+108*cos(theta)**44 + 1.68711753524898e+108*cos(theta)**42 - 1.15930422813198e+108*cos(theta)**40 + 6.38599786682871e+107*cos(theta)**38 - 2.85038507960672e+107*cos(theta)**36 + 1.03800150297817e+107*cos(theta)**34 - 3.09579395625068e+106*cos(theta)**32 + 7.57156707248687e+105*cos(theta)**30 - 1.51710348988106e+105*cos(theta)**28 + 2.48253298344174e+104*cos(theta)**26 - 3.29989046878759e+103*cos(theta)**24 + 3.53559693084385e+102*cos(theta)**22 - 3.02154232713625e+101*cos(theta)**20 + 2.03146865589486e+100*cos(theta)**18 - 1.05539797742585e+99*cos(theta)**16 + 4.13881559774844e+97*cos(theta)**14 - 1.1877395755128e+96*cos(theta)**12 + 2.39142196411973e+94*cos(theta)**10 - 3.18290412260833e+92*cos(theta)**8 + 2.56095734002969e+90*cos(theta)**6 - 1.07452755525721e+88*cos(theta)**4 + 1.75863756997907e+85*cos(theta)**2 - 4.68595142547049e+81)*sin(42*phi)

#@torch.jit.script
def Yl96_m_minus_41(theta, phi):
    return 8.8203342398957e-81*(1.0 - cos(theta)**2)**20.5*(3.55871726142223e+104*cos(theta)**55 - 2.76685609068691e+105*cos(theta)**53 + 1.00865811983243e+106*cos(theta)**51 - 2.29240481780097e+106*cos(theta)**49 + 3.64306495369451e+106*cos(theta)**47 - 4.30399258463799e+106*cos(theta)**45 + 3.92352915174182e+106*cos(theta)**43 - 2.82757128812678e+106*cos(theta)**41 + 1.6374353504689e+106*cos(theta)**39 - 7.70374345839654e+105*cos(theta)**37 + 2.96571857993763e+105*cos(theta)**35 - 9.38119380682025e+104*cos(theta)**33 + 2.4424409911248e+104*cos(theta)**31 - 5.23139134441746e+103*cos(theta)**29 + 9.19456660533978e+102*cos(theta)**27 - 1.31995618751504e+102*cos(theta)**25 + 1.53721605688863e+101*cos(theta)**23 - 1.43882967958869e+100*cos(theta)**21 + 1.06919402941835e+99*cos(theta)**19 - 6.20822339662267e+97*cos(theta)**17 + 2.75921039849896e+96*cos(theta)**15 - 9.13645827317537e+94*cos(theta)**13 + 2.17401996738157e+93*cos(theta)**11 - 3.53656013623148e+91*cos(theta)**9 + 3.65851048575671e+89*cos(theta)**7 - 2.14905511051443e+87*cos(theta)**5 + 5.86212523326358e+84*cos(theta)**3 - 4.68595142547049e+81*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl96_m_minus_40(theta, phi):
    return 7.72572668236375e-79*(1.0 - cos(theta)**2)**20*(6.35485225253969e+102*cos(theta)**56 - 5.12380757534614e+103*cos(theta)**54 + 1.93972715352389e+104*cos(theta)**52 - 4.58480963560193e+104*cos(theta)**50 + 7.58971865353023e+104*cos(theta)**48 - 9.35650561877825e+104*cos(theta)**46 + 8.91711170850413e+104*cos(theta)**44 - 6.73231259077806e+104*cos(theta)**42 + 4.09358837617225e+104*cos(theta)**40 - 2.02730091010435e+104*cos(theta)**38 + 8.23810716649341e+103*cos(theta)**36 - 2.75917464906478e+103*cos(theta)**34 + 7.63262809726499e+102*cos(theta)**32 - 1.74379711480582e+102*cos(theta)**30 + 3.28377378762135e+101*cos(theta)**28 - 5.07675456736553e+100*cos(theta)**26 + 6.40506690370262e+99*cos(theta)**24 - 6.54013490722132e+98*cos(theta)**22 + 5.34597014709174e+97*cos(theta)**20 - 3.4490129981237e+96*cos(theta)**18 + 1.72450649906185e+95*cos(theta)**16 - 6.52604162369669e+93*cos(theta)**14 + 1.81168330615131e+92*cos(theta)**12 - 3.53656013623148e+90*cos(theta)**10 + 4.57313810719588e+88*cos(theta)**8 - 3.58175851752405e+86*cos(theta)**6 + 1.4655313083159e+84*cos(theta)**4 - 2.34297571273524e+81*cos(theta)**2 + 6.10786160775611e+77)*sin(40*phi)

#@torch.jit.script
def Yl96_m_minus_39(theta, phi):
    return 6.80215026794904e-77*(1.0 - cos(theta)**2)**19.5*(1.11488636009468e+101*cos(theta)**57 - 9.31601377335661e+101*cos(theta)**55 + 3.65986255381867e+102*cos(theta)**53 - 8.98982281490575e+102*cos(theta)**51 + 1.54892217418984e+103*cos(theta)**49 - 1.9907458763358e+103*cos(theta)**47 + 1.98158037966758e+103*cos(theta)**45 - 1.56565409087862e+103*cos(theta)**43 + 9.98436189310305e+102*cos(theta)**41 - 5.19820746180603e+102*cos(theta)**39 + 2.22651545040362e+102*cos(theta)**37 - 7.88335614018508e+101*cos(theta)**35 + 2.31291760523182e+101*cos(theta)**33 - 5.62515198324458e+100*cos(theta)**31 + 1.13233578883495e+100*cos(theta)**29 - 1.88027946939464e+99*cos(theta)**27 + 2.56202676148105e+98*cos(theta)**25 - 2.84353691618318e+97*cos(theta)**23 + 2.54570007004369e+96*cos(theta)**21 - 1.81526999901248e+95*cos(theta)**19 + 1.01441558768344e+94*cos(theta)**17 - 4.3506944157978e+92*cos(theta)**15 + 1.39360254319332e+91*cos(theta)**13 - 3.21505466930135e+89*cos(theta)**11 + 5.08126456355098e+87*cos(theta)**9 - 5.11679788217721e+85*cos(theta)**7 + 2.93106261663179e+83*cos(theta)**5 - 7.80991904245081e+80*cos(theta)**3 + 6.10786160775611e+77*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl96_m_minus_38(theta, phi):
    return 6.01903824490719e-75*(1.0 - cos(theta)**2)**19*(1.92221786223221e+99*cos(theta)**58 - 1.66357388809939e+100*cos(theta)**56 + 6.77752324781235e+100*cos(theta)**54 - 1.72881207978957e+101*cos(theta)**52 + 3.09784434837968e+101*cos(theta)**50 - 4.14738724236624e+101*cos(theta)**48 + 4.30778343405997e+101*cos(theta)**46 - 3.55830475199686e+101*cos(theta)**44 + 2.37722902216739e+101*cos(theta)**42 - 1.29955186545151e+101*cos(theta)**40 + 5.8592511852727e+100*cos(theta)**38 - 2.18982115005141e+100*cos(theta)**36 + 6.80269883891711e+99*cos(theta)**34 - 1.75785999476393e+99*cos(theta)**32 + 3.77445262944983e+98*cos(theta)**30 - 6.71528381926657e+97*cos(theta)**28 + 9.85394908261942e+96*cos(theta)**26 - 1.18480704840966e+96*cos(theta)**24 + 1.1571363954744e+95*cos(theta)**22 - 9.07634999506238e+93*cos(theta)**20 + 5.6356421537969e+92*cos(theta)**18 - 2.71918400987362e+91*cos(theta)**16 + 9.95430387995225e+89*cos(theta)**14 - 2.67921222441779e+88*cos(theta)**12 + 5.08126456355098e+86*cos(theta)**10 - 6.39599735272151e+84*cos(theta)**8 + 4.88510436105298e+82*cos(theta)**6 - 1.9524797606127e+80*cos(theta)**4 + 3.05393080387806e+77*cos(theta)**2 - 7.80058953736413e+73)*sin(38*phi)

#@torch.jit.script
def Yl96_m_minus_37(theta, phi):
    return 5.35186941113327e-73*(1.0 - cos(theta)**2)**18.5*(3.25799637666476e+97*cos(theta)**59 - 2.91855068087613e+98*cos(theta)**57 + 1.2322769541477e+99*cos(theta)**55 - 3.26190958450862e+99*cos(theta)**53 + 6.07420460466605e+99*cos(theta)**51 - 8.4640555966658e+99*cos(theta)**49 + 9.16549666821269e+99*cos(theta)**47 - 7.90734389332635e+99*cos(theta)**45 + 5.5284395864358e+99*cos(theta)**43 - 3.16963869622319e+99*cos(theta)**41 + 1.50237209878787e+99*cos(theta)**39 - 5.91843554067949e+98*cos(theta)**37 + 1.9436282396906e+98*cos(theta)**35 - 5.32684846898161e+97*cos(theta)**33 + 1.21756536433865e+97*cos(theta)**31 - 2.31561511009192e+96*cos(theta)**29 + 3.64961077134053e+95*cos(theta)**27 - 4.73922819363864e+94*cos(theta)**25 + 5.03102780641045e+93*cos(theta)**23 - 4.32207142622018e+92*cos(theta)**21 + 2.96612744936679e+91*cos(theta)**19 - 1.59952000580801e+90*cos(theta)**17 + 6.63620258663483e+88*cos(theta)**15 - 2.06093248032138e+87*cos(theta)**13 + 4.61933142140998e+85*cos(theta)**11 - 7.10666372524613e+83*cos(theta)**9 + 6.97872051578998e+81*cos(theta)**7 - 3.90495952122541e+79*cos(theta)**5 + 1.01797693462602e+77*cos(theta)**3 - 7.80058953736413e+73*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl96_m_minus_36(theta, phi):
    return 4.78087020767889e-71*(1.0 - cos(theta)**2)**18*(5.42999396110794e+95*cos(theta)**60 - 5.03198393254505e+96*cos(theta)**58 + 2.20049456097804e+97*cos(theta)**56 - 6.04057330464559e+97*cos(theta)**54 + 1.16811627012809e+98*cos(theta)**52 - 1.69281111933316e+98*cos(theta)**50 + 1.90947847254431e+98*cos(theta)**48 - 1.71898780289703e+98*cos(theta)**46 + 1.25646354237177e+98*cos(theta)**44 - 7.54675880053141e+97*cos(theta)**42 + 3.75593024696968e+97*cos(theta)**40 - 1.55748303702092e+97*cos(theta)**38 + 5.39896733247389e+96*cos(theta)**36 - 1.56672013793577e+96*cos(theta)**34 + 3.8048917635583e+95*cos(theta)**32 - 7.71871703363973e+94*cos(theta)**30 + 1.3034324183359e+94*cos(theta)**28 - 1.8227800744764e+93*cos(theta)**26 + 2.09626158600435e+92*cos(theta)**24 - 1.96457792100917e+91*cos(theta)**22 + 1.48306372468339e+90*cos(theta)**20 - 8.88622225448896e+88*cos(theta)**18 + 4.14762661664677e+87*cos(theta)**16 - 1.47209462880098e+86*cos(theta)**14 + 3.84944285117499e+84*cos(theta)**12 - 7.10666372524613e+82*cos(theta)**10 + 8.72340064473747e+80*cos(theta)**8 - 6.50826586870901e+78*cos(theta)**6 + 2.54494233656505e+76*cos(theta)**4 - 3.90029476868206e+73*cos(theta)**2 + 9.77517485885229e+69)*sin(36*phi)

#@torch.jit.script
def Yl96_m_minus_35(theta, phi):
    return 4.29001525613128e-69*(1.0 - cos(theta)**2)**17.5*(8.90162944443925e+93*cos(theta)**61 - 8.52878632634755e+94*cos(theta)**59 + 3.86051677364568e+95*cos(theta)**57 - 1.09828605539011e+96*cos(theta)**55 + 2.20399296250582e+96*cos(theta)**53 - 3.31923748888855e+96*cos(theta)**51 + 3.89689484192717e+96*cos(theta)**49 - 3.65742085722773e+96*cos(theta)**47 + 2.79214120527061e+96*cos(theta)**45 - 1.75506018617009e+96*cos(theta)**43 + 9.16080548041385e+95*cos(theta)**41 - 3.99354624877159e+95*cos(theta)**39 + 1.45918036012808e+95*cos(theta)**37 - 4.47634325124505e+94*cos(theta)**35 + 1.15299750410857e+94*cos(theta)**33 - 2.48990872052895e+93*cos(theta)**31 + 4.49459454598587e+92*cos(theta)**29 - 6.75103731287556e+91*cos(theta)**27 + 8.38504634401741e+90*cos(theta)**25 - 8.54164313482249e+89*cos(theta)**23 + 7.06220821277807e+88*cos(theta)**21 - 4.67695908130998e+87*cos(theta)**19 + 2.43978036273339e+86*cos(theta)**17 - 9.81396419200656e+84*cos(theta)**15 + 2.96110988551922e+83*cos(theta)**13 - 6.46060338658739e+81*cos(theta)**11 + 9.69266738304164e+79*cos(theta)**9 - 9.2975226695843e+77*cos(theta)**7 + 5.08988467313009e+75*cos(theta)**5 - 1.30009825622735e+73*cos(theta)**3 + 9.77517485885229e+69*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl96_m_minus_34(theta, phi):
    return 3.86625352702393e-67*(1.0 - cos(theta)**2)**17*(1.43574668458698e+92*cos(theta)**62 - 1.42146438772459e+93*cos(theta)**60 + 6.65606340283737e+93*cos(theta)**58 - 1.96122509891091e+94*cos(theta)**56 + 4.08146844908486e+94*cos(theta)**54 - 6.38314901709337e+94*cos(theta)**52 + 7.79378968385433e+94*cos(theta)**50 - 7.61962678589111e+94*cos(theta)**48 + 6.06987218537088e+94*cos(theta)**46 - 3.98877315038658e+94*cos(theta)**44 + 2.1811441620033e+94*cos(theta)**42 - 9.98386562192897e+93*cos(theta)**40 + 3.83994831612653e+93*cos(theta)**38 - 1.2434286809014e+93*cos(theta)**36 + 3.3911691297311e+92*cos(theta)**34 - 7.78096475165296e+91*cos(theta)**32 + 1.49819818199529e+91*cos(theta)**30 - 2.41108475459841e+90*cos(theta)**28 + 3.22501782462208e+89*cos(theta)**26 - 3.5590179728427e+88*cos(theta)**24 + 3.21009464217185e+87*cos(theta)**22 - 2.33847954065499e+86*cos(theta)**20 + 1.35543353485189e+85*cos(theta)**18 - 6.1337276200041e+83*cos(theta)**16 + 2.11507848965659e+82*cos(theta)**14 - 5.38383615548949e+80*cos(theta)**12 + 9.69266738304164e+78*cos(theta)**10 - 1.16219033369804e+77*cos(theta)**8 + 8.48314112188349e+74*cos(theta)**6 - 3.25024564056839e+72*cos(theta)**4 + 4.88758742942614e+69*cos(theta)**2 - 1.20354282921107e+66)*sin(34*phi)

#@torch.jit.script
def Yl96_m_minus_33(theta, phi):
    return 3.49890604025733e-65*(1.0 - cos(theta)**2)**16.5*(2.2789629914079e+90*cos(theta)**63 - 2.3302694880731e+91*cos(theta)**61 + 1.12814633946396e+92*cos(theta)**59 - 3.44074578756299e+92*cos(theta)**57 + 7.42085172560883e+92*cos(theta)**55 - 1.20436773907422e+93*cos(theta)**53 + 1.52819405565771e+93*cos(theta)**51 - 1.55502587467165e+93*cos(theta)**49 + 1.29146216710019e+93*cos(theta)**47 - 8.8639403341924e+92*cos(theta)**45 + 5.0724282837286e+92*cos(theta)**43 - 2.43508917608024e+92*cos(theta)**41 + 9.84602132340135e+91*cos(theta)**39 - 3.36061805649028e+91*cos(theta)**37 + 9.68905465637458e+90*cos(theta)**35 - 2.3578681065615e+90*cos(theta)**33 + 4.83289736127513e+89*cos(theta)**31 - 8.31408536068418e+88*cos(theta)**29 + 1.19445104615633e+88*cos(theta)**27 - 1.42360718913708e+87*cos(theta)**25 + 1.39569332268341e+86*cos(theta)**23 - 1.11356168602619e+85*cos(theta)**21 + 7.13386070974677e+83*cos(theta)**19 - 3.60807507059065e+82*cos(theta)**17 + 1.41005232643772e+81*cos(theta)**15 - 4.14141242729961e+79*cos(theta)**13 + 8.81151580276512e+77*cos(theta)**11 - 1.29132259299782e+76*cos(theta)**9 + 1.21187730312621e+74*cos(theta)**7 - 6.50049128113677e+71*cos(theta)**5 + 1.62919580980871e+69*cos(theta)**3 - 1.20354282921107e+66*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl96_m_minus_32(theta, phi):
    return 3.17919467411013e-63*(1.0 - cos(theta)**2)**16*(3.56087967407484e+88*cos(theta)**64 - 3.75849917431145e+89*cos(theta)**62 + 1.8802438991066e+90*cos(theta)**60 - 5.93232032338447e+90*cos(theta)**58 + 1.32515209385872e+91*cos(theta)**56 - 2.23031062791522e+91*cos(theta)**54 + 2.93883472241868e+91*cos(theta)**52 - 3.11005174934331e+91*cos(theta)**50 + 2.69054618145872e+91*cos(theta)**48 - 1.92694355091139e+91*cos(theta)**46 + 1.15282460993832e+91*cos(theta)**44 - 5.79783137161961e+90*cos(theta)**42 + 2.46150533085034e+90*cos(theta)**40 - 8.843731727606e+89*cos(theta)**38 + 2.69140407121516e+89*cos(theta)**36 - 6.93490619576912e+88*cos(theta)**34 + 1.51028042539848e+88*cos(theta)**32 - 2.77136178689473e+87*cos(theta)**30 + 4.26589659341545e+86*cos(theta)**28 - 5.47541226591185e+85*cos(theta)**26 + 5.81538884451422e+84*cos(theta)**24 - 5.06164402739175e+83*cos(theta)**22 + 3.56693035487338e+82*cos(theta)**20 - 2.00448615032814e+81*cos(theta)**18 + 8.81282704023577e+79*cos(theta)**16 - 2.95815173378543e+78*cos(theta)**14 + 7.3429298356376e+76*cos(theta)**12 - 1.29132259299782e+75*cos(theta)**10 + 1.51484662890777e+73*cos(theta)**8 - 1.0834152135228e+71*cos(theta)**6 + 4.07298952452179e+68*cos(theta)**4 - 6.01771414605534e+65*cos(theta)**2 + 1.45777958964519e+62)*sin(32*phi)

#@torch.jit.script
def Yl96_m_minus_31(theta, phi):
    return 2.89987171122115e-61*(1.0 - cos(theta)**2)**15.5*(5.4782764216536e+86*cos(theta)**65 - 5.96587170525628e+87*cos(theta)**63 + 3.08236704771574e+88*cos(theta)**61 - 1.00547802091262e+89*cos(theta)**59 + 2.32482823483986e+89*cos(theta)**57 - 4.05511023257313e+89*cos(theta)**55 + 5.54497117437486e+89*cos(theta)**53 - 6.09814068498688e+89*cos(theta)**51 + 5.49091057440556e+89*cos(theta)**49 - 4.09987989555615e+89*cos(theta)**47 + 2.5618324665296e+89*cos(theta)**45 - 1.34833287712084e+89*cos(theta)**43 + 6.00367153865936e+88*cos(theta)**41 - 2.26762351989897e+88*cos(theta)**39 + 7.27406505733827e+87*cos(theta)**37 - 1.98140177021975e+87*cos(theta)**35 + 4.57660734969236e+86*cos(theta)**33 - 8.93987673191848e+85*cos(theta)**31 + 1.47099882531567e+85*cos(theta)**29 - 2.02793046885624e+84*cos(theta)**27 + 2.32615553780569e+83*cos(theta)**25 - 2.20071479451815e+82*cos(theta)**23 + 1.69853826422542e+81*cos(theta)**21 - 1.05499271069902e+80*cos(theta)**19 + 5.18401590602104e+78*cos(theta)**17 - 1.97210115585696e+77*cos(theta)**15 + 5.64840756587508e+75*cos(theta)**13 - 1.17392962999802e+74*cos(theta)**11 + 1.68316292100863e+72*cos(theta)**9 - 1.54773601931828e+70*cos(theta)**7 + 8.14597904904357e+67*cos(theta)**5 - 2.00590471535178e+65*cos(theta)**3 + 1.45777958964519e+62*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl96_m_minus_30(theta, phi):
    return 2.65492717982987e-59*(1.0 - cos(theta)**2)**15*(8.30041882068727e+84*cos(theta)**66 - 9.32167453946293e+85*cos(theta)**64 + 4.97155975438023e+86*cos(theta)**62 - 1.67579670152104e+87*cos(theta)**60 + 4.00832454282734e+87*cos(theta)**58 - 7.24126827245202e+87*cos(theta)**56 + 1.02684651377312e+88*cos(theta)**54 - 1.17271936249748e+88*cos(theta)**52 + 1.09818211488111e+88*cos(theta)**50 - 8.54141644907531e+87*cos(theta)**48 + 5.56920101419477e+87*cos(theta)**46 - 3.06439290254736e+87*cos(theta)**44 + 1.4294456044427e+87*cos(theta)**42 - 5.66905879974744e+86*cos(theta)**40 + 1.91422764666797e+86*cos(theta)**38 - 5.50389380616597e+85*cos(theta)**36 + 1.34606098520363e+85*cos(theta)**34 - 2.79371147872452e+84*cos(theta)**32 + 4.90332941771891e+83*cos(theta)**30 - 7.24260881734372e+82*cos(theta)**28 + 8.94675206848342e+81*cos(theta)**26 - 9.16964497715898e+80*cos(theta)**24 + 7.72062847375191e+79*cos(theta)**22 - 5.2749635534951e+78*cos(theta)**20 + 2.88000883667836e+77*cos(theta)**18 - 1.2325632224106e+76*cos(theta)**16 + 4.03457683276791e+74*cos(theta)**14 - 9.78274691665015e+72*cos(theta)**12 + 1.68316292100863e+71*cos(theta)**10 - 1.93467002414785e+69*cos(theta)**8 + 1.3576631748406e+67*cos(theta)**6 - 5.01476178837945e+64*cos(theta)**4 + 7.28889794822594e+61*cos(theta)**2 - 1.7391787039432e+58)*sin(30*phi)

#@torch.jit.script
def Yl96_m_minus_29(theta, phi):
    return 2.43935657056412e-57*(1.0 - cos(theta)**2)**14.5*(1.23886848069959e+83*cos(theta)**67 - 1.43410377530199e+84*cos(theta)**65 + 7.89136468949243e+84*cos(theta)**63 - 2.74720770741153e+85*cos(theta)**61 + 6.79377041157177e+85*cos(theta)**59 - 1.27039794253544e+86*cos(theta)**57 + 1.86699366140568e+86*cos(theta)**55 - 2.21267804244807e+86*cos(theta)**53 + 2.15329826447277e+86*cos(theta)**51 - 1.743146214097e+86*cos(theta)**49 + 1.18493638599889e+86*cos(theta)**47 - 6.8097620056608e+85*cos(theta)**45 + 3.32429210335513e+85*cos(theta)**43 - 1.38269726823108e+85*cos(theta)**41 + 4.90827601709735e+84*cos(theta)**39 - 1.48753886653134e+84*cos(theta)**37 + 3.84588852915324e+83*cos(theta)**35 - 8.46579235977128e+82*cos(theta)**33 + 1.5817191670061e+82*cos(theta)**31 - 2.49745131632542e+81*cos(theta)**29 + 3.31361187721608e+80*cos(theta)**27 - 3.66785799086359e+79*cos(theta)**25 + 3.35679498858779e+78*cos(theta)**23 - 2.51188740642624e+77*cos(theta)**21 + 1.51579412456756e+76*cos(theta)**19 - 7.25037189653293e+74*cos(theta)**17 + 2.68971788851194e+73*cos(theta)**15 - 7.52518993588473e+71*cos(theta)**13 + 1.53014811000784e+70*cos(theta)**11 - 2.14963336016428e+68*cos(theta)**9 + 1.93951882120085e+66*cos(theta)**7 - 1.00295235767589e+64*cos(theta)**5 + 2.42963264940865e+61*cos(theta)**3 - 1.7391787039432e+58*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl96_m_minus_28(theta, phi):
    return 2.24897563495054e-55*(1.0 - cos(theta)**2)**14*(1.82186541279352e+81*cos(theta)**68 - 2.17288450803332e+82*cos(theta)**66 + 1.23302573273319e+83*cos(theta)**64 - 4.43098017324441e+83*cos(theta)**62 + 1.13229506859529e+84*cos(theta)**60 - 2.19034128023352e+84*cos(theta)**58 + 3.33391725251014e+84*cos(theta)**56 - 4.09755193045939e+84*cos(theta)**54 + 4.14095820090917e+84*cos(theta)**52 - 3.48629242819401e+84*cos(theta)**50 + 2.46861747083102e+84*cos(theta)**48 - 1.48038304470887e+84*cos(theta)**46 + 7.55520932580711e+83*cos(theta)**44 - 3.29213635293115e+83*cos(theta)**42 + 1.22706900427434e+83*cos(theta)**40 - 3.91457596455617e+82*cos(theta)**38 + 1.06830236920923e+82*cos(theta)**36 - 2.4899389293445e+81*cos(theta)**34 + 4.94287239689406e+80*cos(theta)**32 - 8.32483772108474e+79*cos(theta)**30 + 1.18343281329146e+79*cos(theta)**28 - 1.41071461187061e+78*cos(theta)**26 + 1.39866457857825e+77*cos(theta)**24 - 1.14176700292102e+76*cos(theta)**22 + 7.57897062283778e+74*cos(theta)**20 - 4.02798438696274e+73*cos(theta)**18 + 1.68107368031996e+72*cos(theta)**16 - 5.37513566848909e+70*cos(theta)**14 + 1.27512342500654e+69*cos(theta)**12 - 2.14963336016428e+67*cos(theta)**10 + 2.42439852650106e+65*cos(theta)**8 - 1.67158726279315e+63*cos(theta)**6 + 6.07408162352162e+60*cos(theta)**4 - 8.69589351971599e+57*cos(theta)**2 + 2.04609259287435e+54)*sin(28*phi)

#@torch.jit.script
def Yl96_m_minus_27(theta, phi):
    return 2.08027207054461e-53*(1.0 - cos(theta)**2)**13.5*(2.64038465622249e+79*cos(theta)**69 - 3.24311120601988e+80*cos(theta)**67 + 1.89696266574337e+81*cos(theta)**65 - 7.03330186229272e+81*cos(theta)**63 + 1.85622142392671e+82*cos(theta)**61 - 3.71244284785343e+82*cos(theta)**59 + 5.8489776359827e+82*cos(theta)**57 - 7.45009441901707e+82*cos(theta)**55 + 7.8131286809607e+82*cos(theta)**53 - 6.83586750626276e+82*cos(theta)**51 + 5.03799483843064e+82*cos(theta)**49 - 3.14975115895504e+82*cos(theta)**47 + 1.67893540573491e+82*cos(theta)**45 - 7.65613105332825e+81*cos(theta)**43 + 2.99285122993741e+81*cos(theta)**41 - 1.00373742680927e+81*cos(theta)**39 + 2.8873037005655e+80*cos(theta)**37 - 7.11411122669856e+79*cos(theta)**35 + 1.49784012027093e+79*cos(theta)**33 - 2.68543152293056e+78*cos(theta)**31 + 4.0808028044533e+77*cos(theta)**29 - 5.22486893285412e+76*cos(theta)**27 + 5.59465831431298e+75*cos(theta)**25 - 4.96420436052616e+74*cos(theta)**23 + 3.60903362992275e+73*cos(theta)**21 - 2.11999178261197e+72*cos(theta)**19 + 9.88866870776449e+70*cos(theta)**17 - 3.58342377899273e+69*cos(theta)**15 + 9.80864173081951e+67*cos(theta)**13 - 1.95421214560389e+66*cos(theta)**11 + 2.69377614055674e+64*cos(theta)**9 - 2.38798180399021e+62*cos(theta)**7 + 1.21481632470432e+60*cos(theta)**5 - 2.89863117323866e+57*cos(theta)**3 + 2.04609259287435e+54*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl96_m_minus_26(theta, phi):
    return 1.93028623657921e-51*(1.0 - cos(theta)**2)**13*(3.77197808031784e+77*cos(theta)**70 - 4.76928118532335e+78*cos(theta)**68 + 2.87418585718693e+79*cos(theta)**66 - 1.09895341598324e+80*cos(theta)**64 + 2.99390552246244e+80*cos(theta)**62 - 6.18740474642238e+80*cos(theta)**60 + 1.00844441999702e+81*cos(theta)**58 - 1.33037400339591e+81*cos(theta)**56 + 1.44687568165939e+81*cos(theta)**54 - 1.31458990505053e+81*cos(theta)**52 + 1.00759896768613e+81*cos(theta)**50 - 6.56198158115634e+80*cos(theta)**48 + 3.64985957768459e+80*cos(theta)**46 - 1.74002978484733e+80*cos(theta)**44 + 7.12583626175573e+79*cos(theta)**42 - 2.50934356702318e+79*cos(theta)**40 + 7.59816763306709e+78*cos(theta)**38 - 1.97614200741627e+78*cos(theta)**36 + 4.40541211844391e+77*cos(theta)**34 - 8.391973509158e+76*cos(theta)**32 + 1.36026760148443e+76*cos(theta)**30 - 1.86602461887647e+75*cos(theta)**28 + 2.15179165935115e+74*cos(theta)**26 - 2.06841848355257e+73*cos(theta)**24 + 1.64046983178307e+72*cos(theta)**22 - 1.05999589130598e+71*cos(theta)**20 + 5.49370483764694e+69*cos(theta)**18 - 2.23963986187046e+68*cos(theta)**16 + 7.00617266487108e+66*cos(theta)**14 - 1.62851012133657e+65*cos(theta)**12 + 2.69377614055674e+63*cos(theta)**10 - 2.98497725498777e+61*cos(theta)**8 + 2.02469387450721e+59*cos(theta)**6 - 7.24657793309666e+56*cos(theta)**4 + 1.02304629643718e+54*cos(theta)**2 - 2.37641416129425e+50)*sin(26*phi)

#@torch.jit.script
def Yl96_m_minus_25(theta, phi):
    return 1.79651481823311e-49*(1.0 - cos(theta)**2)**12.5*(5.31264518354626e+75*cos(theta)**71 - 6.91200171785992e+76*cos(theta)**69 + 4.28982963759243e+77*cos(theta)**67 - 1.69069756305113e+78*cos(theta)**65 + 4.75223098803562e+78*cos(theta)**63 - 1.01432864695449e+79*cos(theta)**61 + 1.70922783050342e+79*cos(theta)**59 - 2.33398947964194e+79*cos(theta)**57 + 2.63068305756252e+79*cos(theta)**55 - 2.48035831141609e+79*cos(theta)**53 + 1.97568425036496e+79*cos(theta)**51 - 1.3391799145217e+79*cos(theta)**49 + 7.76565867592466e+78*cos(theta)**47 - 3.86673285521629e+78*cos(theta)**45 + 1.65717122366412e+78*cos(theta)**43 - 6.12035016347118e+77*cos(theta)**41 + 1.94824811104284e+77*cos(theta)**39 - 5.34092434436829e+76*cos(theta)**37 + 1.25868917669826e+76*cos(theta)**35 - 2.54302227550242e+75*cos(theta)**33 + 4.3879600047885e+74*cos(theta)**31 - 6.43456765129817e+73*cos(theta)**29 + 7.96959873833758e+72*cos(theta)**27 - 8.27367393421026e+71*cos(theta)**25 + 7.13247752949161e+70*cos(theta)**23 - 5.04759948240944e+69*cos(theta)**21 + 2.89142359876155e+68*cos(theta)**19 - 1.31743521286497e+67*cos(theta)**17 + 4.67078177658072e+65*cos(theta)**15 - 1.25270009333583e+64*cos(theta)**13 + 2.44888740050613e+62*cos(theta)**11 - 3.31664139443085e+60*cos(theta)**9 + 2.89241982072458e+58*cos(theta)**7 - 1.44931558661933e+56*cos(theta)**5 + 3.41015432145725e+53*cos(theta)**3 - 2.37641416129425e+50*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl96_m_minus_24(theta, phi):
    return 1.67683270982667e-47*(1.0 - cos(theta)**2)**12*(7.37867386603647e+73*cos(theta)**72 - 9.87428816837132e+74*cos(theta)**70 + 6.30857299645945e+75*cos(theta)**68 - 2.5616629743199e+76*cos(theta)**66 + 7.42536091880565e+76*cos(theta)**64 - 1.63601394670079e+77*cos(theta)**62 + 2.84871305083903e+77*cos(theta)**60 - 4.0241197924861e+77*cos(theta)**58 + 4.69764831707594e+77*cos(theta)**56 - 4.59325613225203e+77*cos(theta)**54 + 3.79939278916338e+77*cos(theta)**52 - 2.6783598290434e+77*cos(theta)**50 + 1.61784555748431e+77*cos(theta)**48 - 8.40594098960063e+76*cos(theta)**46 + 3.76629823560028e+76*cos(theta)**44 - 1.4572262293979e+76*cos(theta)**42 + 4.87062027760711e+75*cos(theta)**40 - 1.40550640641271e+75*cos(theta)**38 + 3.49635882416183e+74*cos(theta)**36 - 7.47947728088948e+73*cos(theta)**34 + 1.37123750149641e+73*cos(theta)**32 - 2.14485588376606e+72*cos(theta)**30 + 2.84628526369199e+71*cos(theta)**28 - 3.18218228238856e+70*cos(theta)**26 + 2.97186563728817e+69*cos(theta)**24 - 2.2943634010952e+68*cos(theta)**22 + 1.44571179938077e+67*cos(theta)**20 - 7.31908451591652e+65*cos(theta)**18 + 2.91923861036295e+64*cos(theta)**16 - 8.94785780954161e+62*cos(theta)**14 + 2.04073950042177e+61*cos(theta)**12 - 3.31664139443085e+59*cos(theta)**10 + 3.61552477590572e+57*cos(theta)**8 - 2.41552597769889e+55*cos(theta)**6 + 8.52538580364313e+52*cos(theta)**4 - 1.18820708064713e+50*cos(theta)**2 + 2.72774811902462e+46)*sin(24*phi)

#@torch.jit.script
def Yl96_m_minus_23(theta, phi):
    return 1.56942942262094e-45*(1.0 - cos(theta)**2)**11.5*(1.0107772419228e+72*cos(theta)**73 - 1.39074481244666e+73*cos(theta)**71 + 9.14285941515863e+73*cos(theta)**69 - 3.82337757361179e+74*cos(theta)**67 + 1.14236321827779e+75*cos(theta)**65 - 2.59684753444569e+75*cos(theta)**63 + 4.67002139481808e+75*cos(theta)**61 - 6.82054202116288e+75*cos(theta)**59 + 8.24148827557182e+75*cos(theta)**57 - 8.35137478591278e+75*cos(theta)**55 + 7.16866563993091e+75*cos(theta)**53 - 5.25168593930079e+75*cos(theta)**51 + 3.30172562751899e+75*cos(theta)**49 - 1.78849808289375e+75*cos(theta)**47 + 8.36955163466729e+74*cos(theta)**45 - 3.38889820790209e+74*cos(theta)**43 + 1.18795616527003e+74*cos(theta)**41 - 3.6038625805454e+73*cos(theta)**39 + 9.44961844368062e+72*cos(theta)**37 - 2.13699350882557e+72*cos(theta)**35 + 4.15526515604971e+71*cos(theta)**33 - 6.91888994763245e+70*cos(theta)**31 + 9.8147767713517e+69*cos(theta)**29 - 1.17858603051428e+69*cos(theta)**27 + 1.18874625491527e+68*cos(theta)**25 - 9.97549304824001e+66*cos(theta)**23 + 6.88434190181321e+65*cos(theta)**21 - 3.85214974521922e+64*cos(theta)**19 + 1.71719918256644e+63*cos(theta)**17 - 5.96523853969441e+61*cos(theta)**15 + 1.56979961570905e+60*cos(theta)**13 - 3.01512854039168e+58*cos(theta)**11 + 4.01724975100636e+56*cos(theta)**9 - 3.45075139671269e+54*cos(theta)**7 + 1.70507716072863e+52*cos(theta)**5 - 3.96069026882375e+49*cos(theta)**3 + 2.72774811902462e+46*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl96_m_minus_22(theta, phi):
    return 1.47275711925126e-43*(1.0 - cos(theta)**2)**11*(1.36591519178757e+70*cos(theta)**74 - 1.93159001728703e+71*cos(theta)**72 + 1.30612277359409e+72*cos(theta)**70 - 5.62261407884087e+72*cos(theta)**68 + 1.73085336102696e+73*cos(theta)**66 - 4.0575742725714e+73*cos(theta)**64 + 7.53229257228723e+73*cos(theta)**62 - 1.13675700352715e+74*cos(theta)**60 + 1.42094625440893e+74*cos(theta)**58 - 1.49131692605585e+74*cos(theta)**56 + 1.32753067406128e+74*cos(theta)**54 - 1.00993960371169e+74*cos(theta)**52 + 6.60345125503798e+73*cos(theta)**50 - 3.72603767269531e+73*cos(theta)**48 + 1.8194677466668e+73*cos(theta)**46 - 7.70204138159567e+72*cos(theta)**44 + 2.82846706016673e+72*cos(theta)**42 - 9.00965645136351e+71*cos(theta)**40 + 2.48674169570543e+71*cos(theta)**38 - 5.93609308007102e+70*cos(theta)**36 + 1.22213681060286e+70*cos(theta)**34 - 2.16215310863514e+69*cos(theta)**32 + 3.27159225711723e+68*cos(theta)**30 - 4.2092358232653e+67*cos(theta)**28 + 4.57210098044334e+66*cos(theta)**26 - 4.15645543676667e+65*cos(theta)**24 + 3.129246319006e+64*cos(theta)**22 - 1.92607487260961e+63*cos(theta)**20 + 9.53999545870245e+61*cos(theta)**18 - 3.728274087309e+60*cos(theta)**16 + 1.12128543979218e+59*cos(theta)**14 - 2.51260711699307e+57*cos(theta)**12 + 4.01724975100636e+55*cos(theta)**10 - 4.31343924589087e+53*cos(theta)**8 + 2.84179526788104e+51*cos(theta)**6 - 9.90172567205938e+48*cos(theta)**4 + 1.36387405951231e+46*cos(theta)**2 - 3.09760177041179e+42)*sin(22*phi)

#@torch.jit.script
def Yl96_m_minus_21(theta, phi):
    return 1.38548799204113e-41*(1.0 - cos(theta)**2)**10.5*(1.82122025571676e+68*cos(theta)**75 - 2.64601372231101e+69*cos(theta)**73 + 1.83960954027337e+70*cos(theta)**71 - 8.14871605629111e+70*cos(theta)**69 + 2.58336322541337e+71*cos(theta)**67 - 6.24242195780215e+71*cos(theta)**65 + 1.19560199560115e+72*cos(theta)**63 - 1.86353607135598e+72*cos(theta)**61 + 2.40838348204904e+72*cos(theta)**59 - 2.61634548430851e+72*cos(theta)**57 + 2.41369213465687e+72*cos(theta)**55 - 1.90554642209753e+72*cos(theta)**53 + 1.29479436373294e+72*cos(theta)**51 - 7.60415851570472e+71*cos(theta)**49 + 3.87120797163149e+71*cos(theta)**47 - 1.7115647514657e+71*cos(theta)**45 + 6.57783037248077e+70*cos(theta)**43 - 2.19747718325939e+70*cos(theta)**41 + 6.37626075821904e+69*cos(theta)**39 - 1.60434948110028e+69*cos(theta)**37 + 3.4918194588653e+68*cos(theta)**35 - 6.55197911707618e+67*cos(theta)**33 + 1.05535234100556e+67*cos(theta)**31 - 1.45146062871217e+66*cos(theta)**29 + 1.69337073349753e+65*cos(theta)**27 - 1.66258217470667e+64*cos(theta)**25 + 1.3605418778287e+63*cos(theta)**23 - 9.17178510766481e+61*cos(theta)**21 + 5.02105024142234e+60*cos(theta)**19 - 2.19310240429941e+59*cos(theta)**17 + 7.47523626528121e+57*cos(theta)**15 - 1.93277470537928e+56*cos(theta)**13 + 3.6520452281876e+54*cos(theta)**11 - 4.79271027321207e+52*cos(theta)**9 + 4.05970752554435e+50*cos(theta)**7 - 1.98034513441188e+48*cos(theta)**5 + 4.54624686504104e+45*cos(theta)**3 - 3.09760177041179e+42*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl96_m_minus_20(theta, phi):
    return 1.30647917975732e-39*(1.0 - cos(theta)**2)**10*(2.39634244173258e+66*cos(theta)**76 - 3.5756942193392e+67*cos(theta)**74 + 2.55501325037967e+68*cos(theta)**72 - 1.16410229375587e+69*cos(theta)**70 + 3.79906356678437e+69*cos(theta)**68 - 9.45821508757901e+69*cos(theta)**66 + 1.86812811812679e+70*cos(theta)**64 - 3.00570334089674e+70*cos(theta)**62 + 4.01397247008174e+70*cos(theta)**60 - 4.51094049018709e+70*cos(theta)**58 + 4.31016452617299e+70*cos(theta)**56 - 3.52878967055098e+70*cos(theta)**54 + 2.48998916102488e+70*cos(theta)**52 - 1.52083170314094e+70*cos(theta)**50 + 8.06501660756561e+69*cos(theta)**48 - 3.72079293796892e+69*cos(theta)**46 + 1.49496144829108e+69*cos(theta)**44 - 5.23208853156998e+68*cos(theta)**42 + 1.59406518955476e+68*cos(theta)**40 - 4.22197231868493e+67*cos(theta)**38 + 9.69949849684807e+66*cos(theta)**36 - 1.92705268149299e+66*cos(theta)**34 + 3.29797606564237e+65*cos(theta)**32 - 4.83820209570724e+64*cos(theta)**30 + 6.04775261963404e+63*cos(theta)**28 - 6.39454682579488e+62*cos(theta)**26 + 5.66892449095291e+61*cos(theta)**24 - 4.16899323075673e+60*cos(theta)**22 + 2.51052512071117e+59*cos(theta)**20 - 1.21839022461079e+58*cos(theta)**18 + 4.67202266580076e+56*cos(theta)**16 - 1.3805533609852e+55*cos(theta)**14 + 3.04337102348967e+53*cos(theta)**12 - 4.79271027321207e+51*cos(theta)**10 + 5.07463440693043e+49*cos(theta)**8 - 3.30057522401979e+47*cos(theta)**6 + 1.13656171626026e+45*cos(theta)**4 - 1.54880088520589e+42*cos(theta)**2 + 3.48358273775505e+38)*sin(20*phi)

#@torch.jit.script
def Yl96_m_minus_19(theta, phi):
    return 1.23474378923924e-37*(1.0 - cos(theta)**2)**9.5*(3.11213304121115e+64*cos(theta)**77 - 4.76759229245226e+65*cos(theta)**75 + 3.50001815120503e+66*cos(theta)**73 - 1.63958069543081e+67*cos(theta)**71 + 5.50588922722372e+67*cos(theta)**69 - 1.41167389366851e+68*cos(theta)**67 + 2.87404325865661e+68*cos(theta)**65 - 4.77095768396308e+68*cos(theta)**63 + 6.58028273783891e+68*cos(theta)**61 - 7.64566184777473e+68*cos(theta)**59 + 7.56169215118068e+68*cos(theta)**57 - 6.4159812191836e+68*cos(theta)**55 + 4.69809275665072e+68*cos(theta)**53 - 2.98202294733518e+68*cos(theta)**51 + 1.64592175664604e+68*cos(theta)**49 - 7.91658071908281e+67*cos(theta)**47 + 3.32213655175797e+67*cos(theta)**45 - 1.21676477478372e+67*cos(theta)**43 + 3.88796387696283e+66*cos(theta)**41 - 1.08255700479101e+66*cos(theta)**39 + 2.62148608022921e+65*cos(theta)**37 - 5.5058648042657e+64*cos(theta)**35 + 9.99386686558295e+63*cos(theta)**33 - 1.56071035345395e+63*cos(theta)**31 + 2.08543193780484e+62*cos(theta)**29 - 2.36835067622033e+61*cos(theta)**27 + 2.26756979638116e+60*cos(theta)**25 - 1.81260575250293e+59*cos(theta)**23 + 1.19548815271961e+58*cos(theta)**21 - 6.41258012953045e+56*cos(theta)**19 + 2.74824862694162e+55*cos(theta)**17 - 9.20368907323469e+53*cos(theta)**15 + 2.34105463345359e+52*cos(theta)**13 - 4.3570093392837e+50*cos(theta)**11 + 5.63848267436715e+48*cos(theta)**9 - 4.71510746288542e+46*cos(theta)**7 + 2.27312343252052e+44*cos(theta)**5 - 5.16266961735298e+41*cos(theta)**3 + 3.48358273775505e+38*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl96_m_minus_18(theta, phi):
    return 1.16942687923752e-35*(1.0 - cos(theta)**2)**9*(3.98991415539891e+62*cos(theta)**78 - 6.27314775322666e+63*cos(theta)**76 + 4.72975425838518e+64*cos(theta)**74 - 2.27719541032057e+65*cos(theta)**72 + 7.86555603889104e+65*cos(theta)**70 - 2.07599102010075e+66*cos(theta)**68 + 4.35461099796455e+66*cos(theta)**66 - 7.45462138119231e+66*cos(theta)**64 + 1.06133592545789e+67*cos(theta)**62 - 1.27427697462912e+67*cos(theta)**60 + 1.30374002606563e+67*cos(theta)**58 - 1.14571093199707e+67*cos(theta)**56 + 8.7001717715754e+66*cos(theta)**54 - 5.73465951410612e+66*cos(theta)**52 + 3.29184351329209e+66*cos(theta)**50 - 1.64928764980892e+66*cos(theta)**48 + 7.22203598208253e+65*cos(theta)**46 - 2.76537448814481e+65*cos(theta)**44 + 9.2570568499115e+64*cos(theta)**42 - 2.70639251197752e+64*cos(theta)**40 + 6.89864757955055e+63*cos(theta)**38 - 1.5294068900738e+63*cos(theta)**36 + 2.9393726075244e+62*cos(theta)**34 - 4.87721985454358e+61*cos(theta)**32 + 6.95143979268281e+60*cos(theta)**30 - 8.45839527221545e+59*cos(theta)**28 + 8.7214222937737e+58*cos(theta)**26 - 7.5525239687622e+57*cos(theta)**24 + 5.43403705781639e+56*cos(theta)**22 - 3.20629006476523e+55*cos(theta)**20 + 1.52680479274535e+54*cos(theta)**18 - 5.75230567077168e+52*cos(theta)**16 + 1.67218188103828e+51*cos(theta)**14 - 3.63084111606975e+49*cos(theta)**12 + 5.63848267436715e+47*cos(theta)**10 - 5.89388432860677e+45*cos(theta)**8 + 3.78853905420086e+43*cos(theta)**6 - 1.29066740433825e+41*cos(theta)**4 + 1.74179136887752e+38*cos(theta)**2 - 3.88359279571354e+34)*sin(18*phi)

#@torch.jit.script
def Yl96_m_minus_17(theta, phi):
    return 1.10978549225984e-33*(1.0 - cos(theta)**2)**8.5*(5.05052424734039e+60*cos(theta)**79 - 8.1469451340606e+61*cos(theta)**77 + 6.30633901118024e+62*cos(theta)**75 - 3.11944576756242e+63*cos(theta)**73 + 1.10782479421001e+64*cos(theta)**71 - 3.00868263782717e+64*cos(theta)**69 + 6.4994193999471e+64*cos(theta)**67 - 1.14686482787574e+65*cos(theta)**65 + 1.68466019913951e+65*cos(theta)**63 - 2.08897864693299e+65*cos(theta)**61 + 2.20972885773836e+65*cos(theta)**59 - 2.01001917894223e+65*cos(theta)**57 + 1.58184941301371e+65*cos(theta)**55 - 1.08201122907663e+65*cos(theta)**53 + 6.45459512410213e+64*cos(theta)**51 - 3.36589316287534e+64*cos(theta)**49 + 1.53660340044309e+64*cos(theta)**47 - 6.1452766403218e+63*cos(theta)**45 + 2.15280391858407e+63*cos(theta)**43 - 6.60095734628664e+62*cos(theta)**41 + 1.76888399475655e+62*cos(theta)**39 - 4.13353213533461e+61*cos(theta)**37 + 8.3982074500697e+60*cos(theta)**35 - 1.47794541046775e+60*cos(theta)**33 + 2.24239993312349e+59*cos(theta)**31 - 2.91668802490188e+58*cos(theta)**29 + 3.23015640510137e+57*cos(theta)**27 - 3.02100958750488e+56*cos(theta)**25 + 2.36262480774626e+55*cos(theta)**23 - 1.52680479274535e+54*cos(theta)**21 + 8.03581469865971e+52*cos(theta)**19 - 3.38370921810099e+51*cos(theta)**17 + 1.11478792069219e+50*cos(theta)**15 - 2.79295470466904e+48*cos(theta)**13 + 5.12589334033377e+46*cos(theta)**11 - 6.54876036511864e+44*cos(theta)**9 + 5.41219864885838e+42*cos(theta)**7 - 2.58133480867649e+40*cos(theta)**5 + 5.80597122959175e+37*cos(theta)**3 - 3.88359279571354e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl96_m_minus_16(theta, phi):
    return 1.05517200034056e-31*(1.0 - cos(theta)**2)**8*(6.31315530917549e+58*cos(theta)**80 - 1.04448014539238e+60*cos(theta)**78 + 8.29781448839505e+60*cos(theta)**76 - 4.21546725346273e+61*cos(theta)**74 + 1.5386455475139e+62*cos(theta)**72 - 4.29811805403882e+62*cos(theta)**70 + 9.55796970580455e+62*cos(theta)**68 - 1.73767398162991e+63*cos(theta)**66 + 2.63228156115548e+63*cos(theta)**64 - 3.36932039827901e+63*cos(theta)**62 + 3.68288142956394e+63*cos(theta)**60 - 3.46555030852109e+63*cos(theta)**58 + 2.82473109466734e+63*cos(theta)**56 - 2.00372449829005e+63*cos(theta)**54 + 1.24126829309656e+63*cos(theta)**52 - 6.73178632575069e+62*cos(theta)**50 + 3.20125708425644e+62*cos(theta)**48 - 1.33592970441778e+62*cos(theta)**46 + 4.89273617860016e+61*cos(theta)**44 - 1.57165651102063e+61*cos(theta)**42 + 4.42220998689138e+60*cos(theta)**40 - 1.08777161456174e+60*cos(theta)**38 + 2.33283540279714e+59*cos(theta)**36 - 4.34689826608163e+58*cos(theta)**34 + 7.0074997910109e+57*cos(theta)**32 - 9.72229341633959e+56*cos(theta)**30 + 1.1536272875362e+56*cos(theta)**28 - 1.16192676442495e+55*cos(theta)**26 + 9.84427003227607e+53*cos(theta)**24 - 6.94002178520612e+52*cos(theta)**22 + 4.01790734932986e+51*cos(theta)**20 - 1.87983845450055e+50*cos(theta)**18 + 6.96742450432616e+48*cos(theta)**16 - 1.99496764619217e+47*cos(theta)**14 + 4.27157778361147e+45*cos(theta)**12 - 6.54876036511864e+43*cos(theta)**10 + 6.76524831107297e+41*cos(theta)**8 - 4.30222468112749e+39*cos(theta)**6 + 1.45149280739794e+37*cos(theta)**4 - 1.94179639785677e+34*cos(theta)**2 + 4.29600972977162e+30)*sin(16*phi)

#@torch.jit.script
def Yl96_m_minus_15(theta, phi):
    return 1.00502017318788e-29*(1.0 - cos(theta)**2)**7.5*(7.79401890021665e+56*cos(theta)**81 - 1.32212676631947e+58*cos(theta)**79 + 1.07763824524611e+59*cos(theta)**77 - 5.62062300461697e+59*cos(theta)**75 + 2.10773362673136e+60*cos(theta)**73 - 6.05368740005467e+60*cos(theta)**71 + 1.38521300084124e+61*cos(theta)**69 - 2.59354325616404e+61*cos(theta)**67 + 4.0496639402392e+61*cos(theta)**65 - 5.34812761631589e+61*cos(theta)**63 + 6.03751054026875e+61*cos(theta)**61 - 5.87381408223913e+61*cos(theta)**59 + 4.95566858713568e+61*cos(theta)**57 - 3.64313545143646e+61*cos(theta)**55 + 2.34201564735201e+61*cos(theta)**53 - 1.31995810308837e+61*cos(theta)**51 + 6.53317772297233e+60*cos(theta)**49 - 2.84240362642081e+60*cos(theta)**47 + 1.08727470635559e+60*cos(theta)**45 - 3.65501514190844e+59*cos(theta)**43 + 1.07858780168082e+59*cos(theta)**41 - 2.78915798605574e+58*cos(theta)**39 + 6.30496054810038e+57*cos(theta)**37 - 1.24197093316618e+57*cos(theta)**35 + 2.12348478515482e+56*cos(theta)**33 - 3.13622368269019e+55*cos(theta)**31 + 3.97802512943519e+54*cos(theta)**29 - 4.30343246083316e+53*cos(theta)**27 + 3.93770801291043e+52*cos(theta)**25 - 3.01740077617657e+51*cos(theta)**23 + 1.9132892139666e+50*cos(theta)**21 - 9.89388660263447e+48*cos(theta)**19 + 4.0984850025448e+47*cos(theta)**17 - 1.32997843079478e+46*cos(theta)**15 + 3.28582906431652e+44*cos(theta)**13 - 5.95341851374421e+42*cos(theta)**11 + 7.51694256785886e+40*cos(theta)**9 - 6.14603525875355e+38*cos(theta)**7 + 2.90298561479587e+36*cos(theta)**5 - 6.47265465952257e+33*cos(theta)**3 + 4.29600972977162e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl96_m_minus_14(theta, phi):
    return 9.58833490371498e-28*(1.0 - cos(theta)**2)**7*(9.50490109782519e+54*cos(theta)**82 - 1.65265845789934e+56*cos(theta)**80 + 1.38158749390527e+57*cos(theta)**78 - 7.39555658502233e+57*cos(theta)**76 + 2.84828868477211e+58*cos(theta)**74 - 8.4078991667426e+58*cos(theta)**72 + 1.97887571548748e+59*cos(theta)**70 - 3.81403420024124e+59*cos(theta)**68 + 6.13585445490787e+59*cos(theta)**66 - 8.35644940049358e+59*cos(theta)**64 + 9.73792022623992e+59*cos(theta)**62 - 9.78969013706522e+59*cos(theta)**60 + 8.54425618471669e+59*cos(theta)**58 - 6.50559902042224e+59*cos(theta)**56 + 4.33706601361483e+59*cos(theta)**54 - 2.53838096747764e+59*cos(theta)**52 + 1.30663554459447e+59*cos(theta)**50 - 5.92167422171003e+58*cos(theta)**48 + 2.36364066599042e+58*cos(theta)**46 - 8.30685259524645e+57*cos(theta)**44 + 2.56806619447815e+57*cos(theta)**42 - 6.97289496513935e+56*cos(theta)**40 + 1.65920014423694e+56*cos(theta)**38 - 3.44991925879494e+55*cos(theta)**36 + 6.24554348574946e+54*cos(theta)**34 - 9.80069900840685e+53*cos(theta)**32 + 1.3260083764784e+53*cos(theta)**30 - 1.53694016458327e+52*cos(theta)**28 + 1.51450308188863e+51*cos(theta)**26 - 1.25725032340691e+50*cos(theta)**24 + 8.69676915439363e+48*cos(theta)**22 - 4.94694330131723e+47*cos(theta)**20 + 2.27693611252489e+46*cos(theta)**18 - 8.31236519246738e+44*cos(theta)**16 + 2.34702076022608e+43*cos(theta)**14 - 4.96118209478685e+41*cos(theta)**12 + 7.51694256785886e+39*cos(theta)**10 - 7.68254407344194e+37*cos(theta)**8 + 4.83830935799312e+35*cos(theta)**6 - 1.61816366488064e+33*cos(theta)**4 + 2.14800486488581e+30*cos(theta)**2 - 4.71985248271986e+26)*sin(14*phi)

#@torch.jit.script
def Yl96_m_minus_13(theta, phi):
    return 9.16175309447676e-26*(1.0 - cos(theta)**2)**6.5*(1.14516880696689e+53*cos(theta)**83 - 2.04031908382635e+54*cos(theta)**81 + 1.74884492899401e+55*cos(theta)**79 - 9.60461894158744e+55*cos(theta)**77 + 3.79771824636282e+56*cos(theta)**75 - 1.15176700914282e+57*cos(theta)**73 + 2.7871488950528e+57*cos(theta)**71 - 5.52758579745108e+57*cos(theta)**69 + 9.1579917237431e+57*cos(theta)**67 - 1.28560760007594e+58*cos(theta)**65 + 1.54570162321269e+58*cos(theta)**63 - 1.60486723558446e+58*cos(theta)**61 + 1.44817901435876e+58*cos(theta)**59 - 1.14133316147759e+58*cos(theta)**57 + 7.88557457020878e+57*cos(theta)**55 - 4.78939805184459e+57*cos(theta)**53 + 2.56203047959699e+57*cos(theta)**51 - 1.20850494320613e+57*cos(theta)**49 + 5.02902269359663e+56*cos(theta)**47 - 1.8459672433881e+56*cos(theta)**45 + 5.97224696390268e+55*cos(theta)**43 - 1.70070608905838e+55*cos(theta)**41 + 4.25435934419729e+54*cos(theta)**39 - 9.32410610485119e+53*cos(theta)**37 + 1.78444099592842e+53*cos(theta)**35 - 2.96990879042632e+52*cos(theta)**33 + 4.27744637573676e+51*cos(theta)**31 - 5.2997936709768e+50*cos(theta)**29 + 5.60927067366158e+49*cos(theta)**27 - 5.02900129362762e+48*cos(theta)**25 + 3.78120398017114e+47*cos(theta)**23 - 2.35568728634154e+46*cos(theta)**21 + 1.19838742764468e+45*cos(theta)**19 - 4.88962658380434e+43*cos(theta)**17 + 1.56468050681739e+42*cos(theta)**15 - 3.8162939190668e+40*cos(theta)**13 + 6.83358415259896e+38*cos(theta)**11 - 8.53616008160215e+36*cos(theta)**9 + 6.91187051141875e+34*cos(theta)**7 - 3.23632732976129e+32*cos(theta)**5 + 7.16001621628603e+29*cos(theta)**3 - 4.71985248271986e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl96_m_minus_12(theta, phi):
    return 8.76660574088169e-24*(1.0 - cos(theta)**2)**6*(1.36329619877011e+51*cos(theta)**84 - 2.48819400466628e+52*cos(theta)**82 + 2.18605616124252e+53*cos(theta)**80 - 1.23136140276762e+54*cos(theta)**78 + 4.99699769258266e+54*cos(theta)**76 - 1.55644190424706e+55*cos(theta)**74 + 3.87104013201777e+55*cos(theta)**72 - 7.89655113921582e+55*cos(theta)**70 + 1.34676348878575e+56*cos(theta)**68 - 1.94789030314536e+56*cos(theta)**66 + 2.41515878626982e+56*cos(theta)**64 - 2.58849554126526e+56*cos(theta)**62 + 2.41363169059793e+56*cos(theta)**60 - 1.96781579565101e+56*cos(theta)**58 + 1.40813831610871e+56*cos(theta)**56 - 8.86925565156406e+55*cos(theta)**54 + 4.92698169153268e+55*cos(theta)**52 - 2.41700988641226e+55*cos(theta)**50 + 1.04771306116596e+55*cos(theta)**48 - 4.012972268235e+54*cos(theta)**46 + 1.35732885543243e+54*cos(theta)**44 - 4.04930021204376e+53*cos(theta)**42 + 1.06358983604932e+53*cos(theta)**40 - 2.45371213285558e+52*cos(theta)**38 + 4.95678054424561e+51*cos(theta)**36 - 8.73502585419505e+50*cos(theta)**34 + 1.33670199241774e+50*cos(theta)**32 - 1.7665978903256e+49*cos(theta)**30 + 2.00331095487913e+48*cos(theta)**28 - 1.93423126677985e+47*cos(theta)**26 + 1.57550165840464e+46*cos(theta)**24 - 1.07076694833706e+45*cos(theta)**22 + 5.99193713822339e+43*cos(theta)**20 - 2.71645921322464e+42*cos(theta)**18 + 9.77925316760869e+40*cos(theta)**16 - 2.72592422790486e+39*cos(theta)**14 + 5.69465346049913e+37*cos(theta)**12 - 8.53616008160216e+35*cos(theta)**10 + 8.63983813927344e+33*cos(theta)**8 - 5.39387888293548e+31*cos(theta)**6 + 1.79000405407151e+29*cos(theta)**4 - 2.35992624135993e+26*cos(theta)**2 + 5.15492844333755e+22)*sin(12*phi)

#@torch.jit.script
def Yl96_m_minus_11(theta, phi):
    return 8.39948804191916e-22*(1.0 - cos(theta)**2)**5.5*(1.60387788090601e+49*cos(theta)**85 - 2.99782410200757e+50*cos(theta)**83 + 2.69883476696607e+51*cos(theta)**81 - 1.55868531995901e+52*cos(theta)**79 + 6.48960739296449e+52*cos(theta)**77 - 2.07525587232941e+53*cos(theta)**75 + 5.30279470139421e+53*cos(theta)**73 - 1.112190301298e+54*cos(theta)**71 + 1.95183114316775e+54*cos(theta)**69 - 2.90729895991844e+54*cos(theta)**67 + 3.71562890195357e+54*cos(theta)**65 - 4.10872308137343e+54*cos(theta)**63 + 3.9567732632753e+54*cos(theta)**61 - 3.33528100957798e+54*cos(theta)**59 + 2.47041809843633e+54*cos(theta)**57 - 1.61259193664801e+54*cos(theta)**55 + 9.29619187081637e+53*cos(theta)**53 - 4.73923507139658e+53*cos(theta)**51 + 2.13818992074687e+53*cos(theta)**49 - 8.53823886858511e+52*cos(theta)**47 + 3.01628634540539e+52*cos(theta)**45 - 9.41697723731106e+51*cos(theta)**43 + 2.59412155133981e+51*cos(theta)**41 - 6.29156957142456e+50*cos(theta)**39 + 1.33967041736368e+50*cos(theta)**37 - 2.49572167262716e+49*cos(theta)**35 + 4.05061209823557e+48*cos(theta)**33 - 5.69870287201806e+47*cos(theta)**31 + 6.90796880992805e+46*cos(theta)**29 - 7.16381950659205e+45*cos(theta)**27 + 6.30200663361857e+44*cos(theta)**25 - 4.65550847103071e+43*cos(theta)**23 + 2.853303399154e+42*cos(theta)**21 - 1.42971537538139e+41*cos(theta)**19 + 5.75250186329923e+39*cos(theta)**17 - 1.81728281860324e+38*cos(theta)**15 + 4.38050266192241e+36*cos(theta)**13 - 7.76014552872923e+34*cos(theta)**11 + 9.59982015474826e+32*cos(theta)**9 - 7.7055412613364e+30*cos(theta)**7 + 3.58000810814302e+28*cos(theta)**5 - 7.86642080453311e+25*cos(theta)**3 + 5.15492844333755e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl96_m_minus_10(theta, phi):
    return 8.05738156580094e-20*(1.0 - cos(theta)**2)**5*(1.86497428012327e+47*cos(theta)**86 - 3.56883821667567e+48*cos(theta)**84 + 3.29126191093423e+49*cos(theta)**82 - 1.94835664994877e+50*cos(theta)**80 + 8.3200094781596e+50*cos(theta)**78 - 2.73059983201238e+51*cos(theta)**76 + 7.16593878566785e+51*cos(theta)**74 - 1.54470875180278e+52*cos(theta)**72 + 2.78833020452536e+52*cos(theta)**70 - 4.27543964693889e+52*cos(theta)**68 + 5.62974076053571e+52*cos(theta)**66 - 6.41987981464599e+52*cos(theta)**64 + 6.38189236012146e+52*cos(theta)**62 - 5.55880168262997e+52*cos(theta)**60 + 4.25934154902816e+52*cos(theta)**58 - 2.87962845830002e+52*cos(theta)**56 + 1.72151701311414e+52*cos(theta)**54 - 9.11391359883958e+51*cos(theta)**52 + 4.27637984149373e+51*cos(theta)**50 - 1.77879976428856e+51*cos(theta)**48 + 6.55714422914216e+50*cos(theta)**46 - 2.14022209938888e+50*cos(theta)**44 + 6.1764798841424e+49*cos(theta)**42 - 1.57289239285614e+49*cos(theta)**40 + 3.52544846674652e+48*cos(theta)**38 - 6.93256020174211e+47*cos(theta)**36 + 1.19135649948105e+47*cos(theta)**34 - 1.78084464750565e+46*cos(theta)**32 + 2.30265626997602e+45*cos(theta)**30 - 2.55850696664002e+44*cos(theta)**28 + 2.42384870523791e+43*cos(theta)**26 - 1.9397951962628e+42*cos(theta)**24 + 1.29695609052454e+41*cos(theta)**22 - 7.14857687690693e+39*cos(theta)**20 + 3.19583436849957e+38*cos(theta)**18 - 1.13580176162703e+37*cos(theta)**16 + 3.12893047280172e+35*cos(theta)**14 - 6.46678794060769e+33*cos(theta)**12 + 9.59982015474826e+31*cos(theta)**10 - 9.6319265766705e+29*cos(theta)**8 + 5.96668018023836e+27*cos(theta)**6 - 1.96660520113328e+25*cos(theta)**4 + 2.57746422166878e+22*cos(theta)**2 - 5.6019652720469e+18)*sin(10*phi)

#@torch.jit.script
def Yl96_m_minus_9(theta, phi):
    return 7.73760382522195e-18*(1.0 - cos(theta)**2)**4.5*(2.14364859784283e+45*cos(theta)**87 - 4.19863319608903e+46*cos(theta)**85 + 3.9653757963063e+47*cos(theta)**83 - 2.40537858018366e+48*cos(theta)**81 + 1.05316575672906e+49*cos(theta)**79 - 3.54623354806803e+49*cos(theta)**77 + 9.55458504755713e+49*cos(theta)**75 - 2.11603938603121e+50*cos(theta)**73 + 3.92722564017656e+50*cos(theta)**71 - 6.19628934338969e+50*cos(theta)**69 + 8.4025981500533e+50*cos(theta)**67 - 9.87673817637844e+50*cos(theta)**65 + 1.01299878732087e+51*cos(theta)**63 - 9.1127896436557e+50*cos(theta)**61 + 7.21922296445451e+50*cos(theta)**59 - 5.05197975140355e+50*cos(theta)**57 + 3.13003093293481e+50*cos(theta)**55 - 1.71960633940369e+50*cos(theta)**53 + 8.38505851273281e+49*cos(theta)**51 - 3.63020360058891e+49*cos(theta)**49 + 1.39513707003025e+49*cos(theta)**47 - 4.75604910975306e+48*cos(theta)**45 + 1.43639067073079e+48*cos(theta)**43 - 3.83632290940522e+47*cos(theta)**41 + 9.0396114531962e+46*cos(theta)**39 - 1.87366491938976e+46*cos(theta)**37 + 3.403875712803e+45*cos(theta)**35 - 5.39649893183529e+44*cos(theta)**33 + 7.42792345153554e+43*cos(theta)**31 - 8.82243781600006e+42*cos(theta)**29 + 8.97721742680708e+41*cos(theta)**27 - 7.75918078505118e+40*cos(theta)**25 + 5.63893952401976e+39*cos(theta)**23 - 3.40408422709854e+38*cos(theta)**21 + 1.68201808868398e+37*cos(theta)**19 - 6.68118683310015e+35*cos(theta)**17 + 2.08595364853448e+34*cos(theta)**15 - 4.97445226200592e+32*cos(theta)**13 + 8.72710923158933e+30*cos(theta)**11 - 1.0702140640745e+29*cos(theta)**9 + 8.52382882891194e+26*cos(theta)**7 - 3.93321040226655e+24*cos(theta)**5 + 8.59154740556259e+21*cos(theta)**3 - 5.6019652720469e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl96_m_minus_8(theta, phi):
    return 7.43776538830222e-16*(1.0 - cos(theta)**2)**4*(2.43596431573049e+43*cos(theta)**88 - 4.88213162335933e+44*cos(theta)**86 + 4.72068547179322e+45*cos(theta)**84 - 2.9333885124191e+46*cos(theta)**82 + 1.31645719591133e+47*cos(theta)**80 - 4.54645326675388e+47*cos(theta)**78 + 1.25718224309962e+48*cos(theta)**76 - 2.85951268382596e+48*cos(theta)**74 + 5.45448005580078e+48*cos(theta)**72 - 8.85184191912813e+48*cos(theta)**70 + 1.23567619853725e+49*cos(theta)**68 - 1.49647548126946e+49*cos(theta)**66 + 1.58281060518885e+49*cos(theta)**64 - 1.46980478123479e+49*cos(theta)**62 + 1.20320382740909e+49*cos(theta)**60 - 8.71030991621301e+48*cos(theta)**58 + 5.5893409516693e+48*cos(theta)**56 - 3.18445618408092e+48*cos(theta)**54 + 1.61251125244862e+48*cos(theta)**52 - 7.26040720117781e+47*cos(theta)**50 + 2.90653556256301e+47*cos(theta)**48 - 1.03392371951154e+47*cos(theta)**46 + 3.26452425166089e+46*cos(theta)**44 - 9.13410216525052e+45*cos(theta)**42 + 2.25990286329905e+45*cos(theta)**40 - 4.93069715628884e+44*cos(theta)**38 + 9.45521031334166e+43*cos(theta)**36 - 1.58720556818685e+43*cos(theta)**34 + 2.32122607860486e+42*cos(theta)**32 - 2.94081260533335e+41*cos(theta)**30 + 3.20614908100253e+40*cos(theta)**28 - 2.98430030194276e+39*cos(theta)**26 + 2.34955813500823e+38*cos(theta)**24 - 1.54731101231752e+37*cos(theta)**22 + 8.41009044341992e+35*cos(theta)**20 - 3.71177046283342e+34*cos(theta)**18 + 1.30372103033405e+33*cos(theta)**16 - 3.55318018714708e+31*cos(theta)**14 + 7.27259102632444e+29*cos(theta)**12 - 1.0702140640745e+28*cos(theta)**10 + 1.06547860361399e+26*cos(theta)**8 - 6.55535067044426e+23*cos(theta)**6 + 2.14788685139065e+21*cos(theta)**4 - 2.80098263602345e+18*cos(theta)**2 + 606273297840573.0)*sin(8*phi)

#@torch.jit.script
def Yl96_m_minus_7(theta, phi):
    return 7.15573334019319e-14*(1.0 - cos(theta)**2)**3.5*(2.73703855700055e+41*cos(theta)**89 - 5.61164554409119e+42*cos(theta)**87 + 5.55374761387437e+43*cos(theta)**85 - 3.53420302701097e+44*cos(theta)**83 + 1.62525579742139e+45*cos(theta)**81 - 5.75500413513149e+45*cos(theta)**79 + 1.63270421181769e+46*cos(theta)**77 - 3.81268357843461e+46*cos(theta)**75 + 7.47189048739833e+46*cos(theta)**73 - 1.24673829846875e+47*cos(theta)**71 + 1.79083507034384e+47*cos(theta)**69 - 2.23354549443203e+47*cos(theta)**67 + 2.43509323875208e+47*cos(theta)**65 - 2.33302346227744e+47*cos(theta)**63 + 1.97246529083457e+47*cos(theta)**61 - 1.47632371461237e+47*cos(theta)**59 + 9.80586131871806e+46*cos(theta)**57 - 5.78992033469257e+46*cos(theta)**55 + 3.0424740612238e+46*cos(theta)**53 - 1.4236092551329e+46*cos(theta)**51 + 5.93170522972043e+45*cos(theta)**49 - 2.19983770108837e+45*cos(theta)**47 + 7.2544983370242e+44*cos(theta)**45 - 2.12420980587221e+44*cos(theta)**43 + 5.51195820316842e+43*cos(theta)**41 - 1.26428132212534e+43*cos(theta)**39 + 2.5554622468491e+42*cos(theta)**37 - 4.53487305196243e+41*cos(theta)**35 + 7.03401842001471e+40*cos(theta)**33 - 9.48649227526889e+39*cos(theta)**31 + 1.10556864862156e+39*cos(theta)**29 - 1.10529640812695e+38*cos(theta)**27 + 9.39823254003293e+36*cos(theta)**25 - 6.72743918398921e+35*cos(theta)**23 + 4.00480497305711e+34*cos(theta)**21 - 1.95356340149127e+33*cos(theta)**19 + 7.66894723725912e+31*cos(theta)**17 - 2.36878679143139e+30*cos(theta)**15 + 5.59430078948034e+28*cos(theta)**13 - 9.72921876431363e+26*cos(theta)**11 + 1.18386511512666e+25*cos(theta)**9 - 9.36478667206322e+22*cos(theta)**7 + 4.29577370278129e+20*cos(theta)**5 - 9.33660878674483e+17*cos(theta)**3 + 606273297840573.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl96_m_minus_6(theta, phi):
    return 6.88960011194611e-12*(1.0 - cos(theta)**2)**3*(3.04115395222284e+39*cos(theta)**90 - 6.37686993646726e+40*cos(theta)**88 + 6.45784606264462e+41*cos(theta)**86 - 4.20738455596543e+42*cos(theta)**84 + 1.98201926514804e+43*cos(theta)**82 - 7.19375516891437e+43*cos(theta)**80 + 2.0932105279714e+44*cos(theta)**78 - 5.01668891899291e+44*cos(theta)**76 + 1.0097149307295e+45*cos(theta)**74 - 1.73158097009549e+45*cos(theta)**72 + 2.55833581477692e+45*cos(theta)**70 - 3.28462572710593e+45*cos(theta)**68 + 3.68953521023043e+45*cos(theta)**66 - 3.64534915980851e+45*cos(theta)**64 + 3.18139563037833e+45*cos(theta)**62 - 2.46053952435396e+45*cos(theta)**60 + 1.69066574460656e+45*cos(theta)**58 - 1.03391434548082e+45*cos(theta)**56 + 5.63421122448853e+44*cos(theta)**54 - 2.73771010602482e+44*cos(theta)**52 + 1.18634104594409e+44*cos(theta)**50 - 4.58299521060078e+43*cos(theta)**48 + 1.57706485587483e+43*cos(theta)**46 - 4.82774955880048e+42*cos(theta)**44 + 1.31237100075438e+42*cos(theta)**42 - 3.16070330531336e+41*cos(theta)**40 + 6.72490064960289e+40*cos(theta)**38 - 1.25968695887845e+40*cos(theta)**36 + 2.06882894706315e+39*cos(theta)**34 - 2.96452883602153e+38*cos(theta)**32 + 3.68522882873854e+37*cos(theta)**30 - 3.94748717188196e+36*cos(theta)**28 + 3.61470482308959e+35*cos(theta)**26 - 2.8030996599955e+34*cos(theta)**24 + 1.82036589684414e+33*cos(theta)**22 - 9.76781700745636e+31*cos(theta)**20 + 4.26052624292174e+30*cos(theta)**18 - 1.48049174464462e+29*cos(theta)**16 + 3.9959291353431e+27*cos(theta)**14 - 8.10768230359469e+25*cos(theta)**12 + 1.18386511512666e+24*cos(theta)**10 - 1.1705983340079e+22*cos(theta)**8 + 7.15962283796882e+19*cos(theta)**6 - 2.33415219668621e+17*cos(theta)**4 + 303136648920287.0*cos(theta)**2 - 65401650252.489)*sin(6*phi)

#@torch.jit.script
def Yl96_m_minus_5(theta, phi):
    return 6.63765685779902e-10*(1.0 - cos(theta)**2)**2.5*(3.3419274200251e+37*cos(theta)**91 - 7.16502240052501e+38*cos(theta)**89 + 7.42281156625819e+39*cos(theta)**87 - 4.94986418348875e+40*cos(theta)**85 + 2.38797501825065e+41*cos(theta)**83 - 8.88117922088193e+41*cos(theta)**81 + 2.64963357971063e+42*cos(theta)**79 - 6.5151804142765e+42*cos(theta)**77 + 1.34628657430601e+43*cos(theta)**75 - 2.3720287261582e+43*cos(theta)**73 + 3.60328987996749e+43*cos(theta)**71 - 4.76032714073323e+43*cos(theta)**69 + 5.50676897049317e+43*cos(theta)**67 - 5.60822947662847e+43*cos(theta)**65 + 5.04983433393386e+43*cos(theta)**63 - 4.03367135139993e+43*cos(theta)**61 + 2.86553516035011e+43*cos(theta)**59 - 1.81388481663301e+43*cos(theta)**57 + 1.0244020408161e+43*cos(theta)**55 - 5.16549076608456e+42*cos(theta)**53 + 2.32615891361586e+42*cos(theta)**51 - 9.35305145020567e+41*cos(theta)**49 + 3.3554571401592e+41*cos(theta)**47 - 1.072833235289e+41*cos(theta)**45 + 3.05202558314973e+40*cos(theta)**43 - 7.7090324519838e+39*cos(theta)**41 + 1.72433349989818e+39*cos(theta)**39 - 3.40455934832014e+38*cos(theta)**37 + 5.91093984875186e+37*cos(theta)**35 - 8.98342071521675e+36*cos(theta)**33 + 1.18878349314146e+36*cos(theta)**31 - 1.36120247306275e+35*cos(theta)**29 + 1.33877956410725e+34*cos(theta)**27 - 1.1212398639982e+33*cos(theta)**25 + 7.91463433410495e+31*cos(theta)**23 - 4.65134143212207e+30*cos(theta)**21 + 2.2423822331167e+29*cos(theta)**19 - 8.70877496849775e+27*cos(theta)**17 + 2.6639527568954e+26*cos(theta)**15 - 6.23667869507284e+24*cos(theta)**13 + 1.07624101375151e+23*cos(theta)**11 - 1.30066481556434e+21*cos(theta)**9 + 1.02280326256697e+19*cos(theta)**7 - 4.66830439337241e+16*cos(theta)**5 + 101045549640096.0*cos(theta)**3 - 65401650252.489*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl96_m_minus_4(theta, phi):
    return 6.39837069664651e-8*(1.0 - cos(theta)**2)**2*(3.6325298043751e+35*cos(theta)**92 - 7.96113600058334e+36*cos(theta)**90 + 8.43501314347521e+37*cos(theta)**88 - 5.7556560273125e+38*cos(theta)**86 + 2.84282740267935e+39*cos(theta)**84 - 1.08307063669292e+40*cos(theta)**82 + 3.31204197463829e+40*cos(theta)**80 - 8.35279540291859e+40*cos(theta)**78 + 1.77142970303422e+41*cos(theta)**76 - 3.20544422453811e+41*cos(theta)**74 + 5.00456927773262e+41*cos(theta)**72 - 6.80046734390461e+41*cos(theta)**70 + 8.09818966248996e+41*cos(theta)**68 - 8.49731738883102e+41*cos(theta)**66 + 7.89036614677166e+41*cos(theta)**64 - 6.50592153451602e+41*cos(theta)**62 + 4.77589193391684e+41*cos(theta)**60 - 3.1273876148845e+41*cos(theta)**58 + 1.82928935860017e+41*cos(theta)**56 - 9.56572364089733e+40*cos(theta)**54 + 4.47338252618434e+40*cos(theta)**52 - 1.87061029004113e+40*cos(theta)**50 + 6.990535708665e+39*cos(theta)**48 - 2.33224616367173e+39*cos(theta)**46 + 6.93642177988575e+38*cos(theta)**44 - 1.835483917139e+38*cos(theta)**42 + 4.31083374974544e+37*cos(theta)**40 - 8.95936670610563e+36*cos(theta)**38 + 1.64192773576441e+36*cos(theta)**36 - 2.64218256329904e+35*cos(theta)**34 + 3.71494841606708e+34*cos(theta)**32 - 4.53734157687582e+33*cos(theta)**30 + 4.78135558609734e+32*cos(theta)**28 - 4.3124610153777e+31*cos(theta)**26 + 3.29776430587706e+30*cos(theta)**24 - 2.11424610551003e+29*cos(theta)**22 + 1.12119111655835e+28*cos(theta)**20 - 4.83820831583209e+26*cos(theta)**18 + 1.66497047305962e+25*cos(theta)**16 - 4.4547704964806e+23*cos(theta)**14 + 8.9686751145959e+21*cos(theta)**12 - 1.30066481556434e+20*cos(theta)**10 + 1.27850407820872e+18*cos(theta)**8 - 7.78050732228736e+15*cos(theta)**6 + 25261387410023.9*cos(theta)**4 - 32700825126.2445*cos(theta)**2 + 7038490.12618263)*sin(4*phi)

#@torch.jit.script
def Yl96_m_minus_3(theta, phi):
    return 6.17036524378302e-6*(1.0 - cos(theta)**2)**1.5*(3.90594602620979e+33*cos(theta)**93 - 8.74850109954214e+34*cos(theta)**91 + 9.47754285783732e+35*cos(theta)**89 - 6.61569658311781e+36*cos(theta)**87 + 3.34450282668159e+37*cos(theta)**85 - 1.30490438155773e+38*cos(theta)**83 + 4.08894070942999e+38*cos(theta)**81 - 1.05731587378716e+39*cos(theta)**79 + 2.3005580558886e+39*cos(theta)**77 - 4.27392563271748e+39*cos(theta)**75 + 6.85557435305839e+39*cos(theta)**73 - 9.57812301958396e+39*cos(theta)**71 + 1.17365067572318e+40*cos(theta)**69 - 1.2682563266912e+40*cos(theta)**67 + 1.21390248411872e+40*cos(theta)**65 - 1.03268595785969e+40*cos(theta)**63 + 7.82933103920794e+39*cos(theta)**61 - 5.30065697438051e+39*cos(theta)**59 + 3.20927957649153e+39*cos(theta)**57 - 1.73922248016315e+39*cos(theta)**55 + 8.44034438902706e+38*cos(theta)**53 - 3.66786331380614e+38*cos(theta)**51 + 1.42663994054388e+38*cos(theta)**49 - 4.96222588015262e+37*cos(theta)**47 + 1.54142706219683e+37*cos(theta)**45 - 4.26856724916046e+36*cos(theta)**43 + 1.05142286579157e+36*cos(theta)**41 - 2.29727351438606e+35*cos(theta)**39 + 4.43764252909299e+34*cos(theta)**37 - 7.54909303799727e+33*cos(theta)**35 + 1.12574194426275e+33*cos(theta)**33 - 1.46365857318575e+32*cos(theta)**31 + 1.64874330555081e+31*cos(theta)**29 - 1.59720778347322e+30*cos(theta)**27 + 1.31910572235083e+29*cos(theta)**25 - 9.19237437178276e+27*cos(theta)**23 + 5.33900531694453e+26*cos(theta)**21 - 2.54642542938531e+25*cos(theta)**19 + 9.79394395917426e+23*cos(theta)**17 - 2.96984699765373e+22*cos(theta)**15 + 6.89898085738146e+20*cos(theta)**13 - 1.18242255960394e+19*cos(theta)**11 + 1.42056008689858e+17*cos(theta)**9 - 1.11150104604105e+15*cos(theta)**7 + 5052277482004.78*cos(theta)**5 - 10900275042.0815*cos(theta)**3 + 7038490.12618263*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl96_m_minus_2(theta, phi):
    return 0.00059524039495915*(1.0 - cos(theta)**2)*(4.15526173001042e+31*cos(theta)**94 - 9.50924032558928e+32*cos(theta)**92 + 1.05306031753748e+34*cos(theta)**90 - 7.51783702627024e+34*cos(theta)**88 + 3.88895677521115e+35*cos(theta)**86 - 1.55345759709254e+36*cos(theta)**84 + 4.98651306028047e+36*cos(theta)**82 - 1.32164484223395e+37*cos(theta)**80 + 2.94943340498538e+37*cos(theta)**78 - 5.62358635883879e+37*cos(theta)**76 + 9.26428966629512e+37*cos(theta)**74 - 1.33029486383111e+38*cos(theta)**72 + 1.67664382246169e+38*cos(theta)**70 - 1.86508283336941e+38*cos(theta)**68 + 1.83924618805866e+38*cos(theta)**66 - 1.61357180915576e+38*cos(theta)**64 + 1.26279532890451e+38*cos(theta)**62 - 8.83442829063419e+37*cos(theta)**60 + 5.53324064912333e+37*cos(theta)**58 - 3.10575442886277e+37*cos(theta)**56 + 1.56302673870871e+37*cos(theta)**54 - 7.05358329578105e+36*cos(theta)**52 + 2.85327988108776e+36*cos(theta)**50 - 1.03379705836513e+36*cos(theta)**48 + 3.35092839608007e+35*cos(theta)**46 - 9.70128920263742e+34*cos(theta)**44 + 2.50338777569422e+34*cos(theta)**42 - 5.74318378596515e+33*cos(theta)**40 + 1.16780066555079e+33*cos(theta)**38 - 2.09697028833257e+32*cos(theta)**36 + 3.31100571841985e+31*cos(theta)**34 - 4.57393304120546e+30*cos(theta)**32 + 5.49581101850269e+29*cos(theta)**30 - 5.70431351240436e+28*cos(theta)**28 + 5.07348354750317e+27*cos(theta)**26 - 3.83015598824282e+26*cos(theta)**24 + 2.42682059861115e+25*cos(theta)**22 - 1.27321271469265e+24*cos(theta)**20 + 5.44107997731904e+22*cos(theta)**18 - 1.85615437353358e+21*cos(theta)**16 + 4.92784346955819e+19*cos(theta)**14 - 9.85352133003285e+17*cos(theta)**12 + 1.42056008689858e+16*cos(theta)**10 - 138937630755131.0*cos(theta)**8 + 842046247000.796*cos(theta)**6 - 2725068760.52038*cos(theta)**4 + 3519245.06309132*cos(theta)**2 - 756.338934685432)*sin(2*phi)

#@torch.jit.script
def Yl96_m_minus_1(theta, phi):
    return 0.0574337583633125*(1.0 - cos(theta)**2)**0.5*(4.37395971580044e+29*cos(theta)**95 - 1.02249895974078e+31*cos(theta)**93 + 1.15720914015108e+32*cos(theta)**91 - 8.44700789468566e+32*cos(theta)**89 + 4.47006525886339e+33*cos(theta)**87 - 1.82759717305005e+34*cos(theta)**85 + 6.00784706057888e+34*cos(theta)**83 - 1.63166029905427e+35*cos(theta)**81 + 3.73346000631061e+35*cos(theta)**79 - 7.30335890758284e+35*cos(theta)**77 + 1.23523862217268e+36*cos(theta)**75 - 1.82232173127549e+36*cos(theta)**73 + 2.36147017248125e+36*cos(theta)**71 - 2.7030185990861e+36*cos(theta)**69 + 2.74514356426666e+36*cos(theta)**67 - 2.48241816793194e+36*cos(theta)**65 + 2.00443703000715e+36*cos(theta)**63 - 1.44826693289085e+36*cos(theta)**61 + 9.37837398156496e+35*cos(theta)**59 - 5.448691980461e+35*cos(theta)**57 + 2.84186679765221e+35*cos(theta)**55 - 1.33086477278888e+35*cos(theta)**53 + 5.59466643350541e+34*cos(theta)**51 - 2.10978991503088e+34*cos(theta)**49 + 7.12963488527675e+33*cos(theta)**47 - 2.15584204503054e+33*cos(theta)**45 + 5.82183203649818e+32*cos(theta)**43 - 1.40077653316223e+32*cos(theta)**41 + 2.99436068089945e+31*cos(theta)**39 - 5.66748726576371e+30*cos(theta)**37 + 9.46001633834244e+29*cos(theta)**35 - 1.38604031551681e+29*cos(theta)**33 + 1.77284226403312e+28*cos(theta)**31 - 1.96700465944978e+27*cos(theta)**29 + 1.87906798055673e+26*cos(theta)**27 - 1.53206239529713e+25*cos(theta)**25 + 1.0551393907005e+24*cos(theta)**23 - 6.06291768901264e+22*cos(theta)**21 + 2.86372630385212e+21*cos(theta)**19 - 1.09185551384328e+20*cos(theta)**17 + 3.28522897970546e+18*cos(theta)**15 - 7.57963179233296e+16*cos(theta)**13 + 1.29141826081689e+15*cos(theta)**11 - 15437514528347.9*cos(theta)**9 + 120292321000.114*cos(theta)**7 - 545013752.104075*cos(theta)**5 + 1173081.68769711*cos(theta)**3 - 756.338934685432*cos(theta))*sin(phi)

#@torch.jit.script
def Yl96_m0(theta, phi):
    return 5.60953860263923e+28*cos(theta)**96 - 1.33924062974005e+30*cos(theta)**94 + 1.54862983931051e+31*cos(theta)**92 - 1.15553734533936e+32*cos(theta)**90 + 6.253955497411e+32*cos(theta)**88 - 2.61640892285129e+33*cos(theta)**86 + 8.80568564734942e+33*cos(theta)**84 - 2.44984997339665e+34*cos(theta)**82 + 5.74572864523325e+34*cos(theta)**80 - 1.15279381072616e+35*cos(theta)**78 + 2.00106347607553e+35*cos(theta)**76 - 3.0319143576902e+35*cos(theta)**74 + 4.03806739650948e+35*cos(theta)**72 - 4.75416870818896e+35*cos(theta)**70 + 4.97026728583391e+35*cos(theta)**68 - 4.63078481682195e+35*cos(theta)**66 + 3.85599123916268e+35*cos(theta)**64 - 2.8759446312068e+35*cos(theta)**62 + 1.92442013362068e+35*cos(theta)**60 - 1.15661244024061e+35*cos(theta)**58 + 6.2479750448292e+34*cos(theta)**56 - 3.03433666636297e+34*cos(theta)**54 + 1.32462958192965e+34*cos(theta)**52 - 5.19508673658303e+33*cos(theta)**50 + 1.82873024491788e+33*cos(theta)**48 - 5.77009151403459e+32*cos(theta)**46 + 1.62903565658096e+32*cos(theta)**44 - 4.10622896649504e+31*cos(theta)**42 + 9.21653581895784e+30*cos(theta)**40 - 1.83624468423681e+30*cos(theta)**38 + 3.23528825317914e+29*cos(theta)**36 - 5.01903865920428e+28*cos(theta)**34 + 6.82093189877327e+27*cos(theta)**32 - 8.07249396752932e+26*cos(theta)**30 + 8.26243500205943e+25*cos(theta)**28 - 7.25482097741803e+24*cos(theta)**26 + 5.41280261170996e+23*cos(theta)**24 - 3.39299005412662e+22*cos(theta)**22 + 1.76288956928306e+21*cos(theta)**20 - 7.46820553319468e+19*cos(theta)**18 + 2.52795452782917e+18*cos(theta)**16 - 6.6656678387058e+16*cos(theta)**14 + 1.3249798456143e+15*cos(theta)**12 - 19006448556953.7*cos(theta)**10 + 185127745684.614*cos(theta)**8 - 1118355313.73661*cos(theta)**6 + 3610703.76798303*cos(theta)**4 - 4655.96875304066*cos(theta)**2 + 0.999993288883303

#@torch.jit.script
def Yl96_m1(theta, phi):
    return 0.0574337583633125*(1.0 - cos(theta)**2)**0.5*(4.37395971580044e+29*cos(theta)**95 - 1.02249895974078e+31*cos(theta)**93 + 1.15720914015108e+32*cos(theta)**91 - 8.44700789468566e+32*cos(theta)**89 + 4.47006525886339e+33*cos(theta)**87 - 1.82759717305005e+34*cos(theta)**85 + 6.00784706057888e+34*cos(theta)**83 - 1.63166029905427e+35*cos(theta)**81 + 3.73346000631061e+35*cos(theta)**79 - 7.30335890758284e+35*cos(theta)**77 + 1.23523862217268e+36*cos(theta)**75 - 1.82232173127549e+36*cos(theta)**73 + 2.36147017248125e+36*cos(theta)**71 - 2.7030185990861e+36*cos(theta)**69 + 2.74514356426666e+36*cos(theta)**67 - 2.48241816793194e+36*cos(theta)**65 + 2.00443703000715e+36*cos(theta)**63 - 1.44826693289085e+36*cos(theta)**61 + 9.37837398156496e+35*cos(theta)**59 - 5.448691980461e+35*cos(theta)**57 + 2.84186679765221e+35*cos(theta)**55 - 1.33086477278888e+35*cos(theta)**53 + 5.59466643350541e+34*cos(theta)**51 - 2.10978991503088e+34*cos(theta)**49 + 7.12963488527675e+33*cos(theta)**47 - 2.15584204503054e+33*cos(theta)**45 + 5.82183203649818e+32*cos(theta)**43 - 1.40077653316223e+32*cos(theta)**41 + 2.99436068089945e+31*cos(theta)**39 - 5.66748726576371e+30*cos(theta)**37 + 9.46001633834244e+29*cos(theta)**35 - 1.38604031551681e+29*cos(theta)**33 + 1.77284226403312e+28*cos(theta)**31 - 1.96700465944978e+27*cos(theta)**29 + 1.87906798055673e+26*cos(theta)**27 - 1.53206239529713e+25*cos(theta)**25 + 1.0551393907005e+24*cos(theta)**23 - 6.06291768901264e+22*cos(theta)**21 + 2.86372630385212e+21*cos(theta)**19 - 1.09185551384328e+20*cos(theta)**17 + 3.28522897970546e+18*cos(theta)**15 - 7.57963179233296e+16*cos(theta)**13 + 1.29141826081689e+15*cos(theta)**11 - 15437514528347.9*cos(theta)**9 + 120292321000.114*cos(theta)**7 - 545013752.104075*cos(theta)**5 + 1173081.68769711*cos(theta)**3 - 756.338934685432*cos(theta))*cos(phi)

#@torch.jit.script
def Yl96_m2(theta, phi):
    return 0.00059524039495915*(1.0 - cos(theta)**2)*(4.15526173001042e+31*cos(theta)**94 - 9.50924032558928e+32*cos(theta)**92 + 1.05306031753748e+34*cos(theta)**90 - 7.51783702627024e+34*cos(theta)**88 + 3.88895677521115e+35*cos(theta)**86 - 1.55345759709254e+36*cos(theta)**84 + 4.98651306028047e+36*cos(theta)**82 - 1.32164484223395e+37*cos(theta)**80 + 2.94943340498538e+37*cos(theta)**78 - 5.62358635883879e+37*cos(theta)**76 + 9.26428966629512e+37*cos(theta)**74 - 1.33029486383111e+38*cos(theta)**72 + 1.67664382246169e+38*cos(theta)**70 - 1.86508283336941e+38*cos(theta)**68 + 1.83924618805866e+38*cos(theta)**66 - 1.61357180915576e+38*cos(theta)**64 + 1.26279532890451e+38*cos(theta)**62 - 8.83442829063419e+37*cos(theta)**60 + 5.53324064912333e+37*cos(theta)**58 - 3.10575442886277e+37*cos(theta)**56 + 1.56302673870871e+37*cos(theta)**54 - 7.05358329578105e+36*cos(theta)**52 + 2.85327988108776e+36*cos(theta)**50 - 1.03379705836513e+36*cos(theta)**48 + 3.35092839608007e+35*cos(theta)**46 - 9.70128920263742e+34*cos(theta)**44 + 2.50338777569422e+34*cos(theta)**42 - 5.74318378596515e+33*cos(theta)**40 + 1.16780066555079e+33*cos(theta)**38 - 2.09697028833257e+32*cos(theta)**36 + 3.31100571841985e+31*cos(theta)**34 - 4.57393304120546e+30*cos(theta)**32 + 5.49581101850269e+29*cos(theta)**30 - 5.70431351240436e+28*cos(theta)**28 + 5.07348354750317e+27*cos(theta)**26 - 3.83015598824282e+26*cos(theta)**24 + 2.42682059861115e+25*cos(theta)**22 - 1.27321271469265e+24*cos(theta)**20 + 5.44107997731904e+22*cos(theta)**18 - 1.85615437353358e+21*cos(theta)**16 + 4.92784346955819e+19*cos(theta)**14 - 9.85352133003285e+17*cos(theta)**12 + 1.42056008689858e+16*cos(theta)**10 - 138937630755131.0*cos(theta)**8 + 842046247000.796*cos(theta)**6 - 2725068760.52038*cos(theta)**4 + 3519245.06309132*cos(theta)**2 - 756.338934685432)*cos(2*phi)

#@torch.jit.script
def Yl96_m3(theta, phi):
    return 6.17036524378302e-6*(1.0 - cos(theta)**2)**1.5*(3.90594602620979e+33*cos(theta)**93 - 8.74850109954214e+34*cos(theta)**91 + 9.47754285783732e+35*cos(theta)**89 - 6.61569658311781e+36*cos(theta)**87 + 3.34450282668159e+37*cos(theta)**85 - 1.30490438155773e+38*cos(theta)**83 + 4.08894070942999e+38*cos(theta)**81 - 1.05731587378716e+39*cos(theta)**79 + 2.3005580558886e+39*cos(theta)**77 - 4.27392563271748e+39*cos(theta)**75 + 6.85557435305839e+39*cos(theta)**73 - 9.57812301958396e+39*cos(theta)**71 + 1.17365067572318e+40*cos(theta)**69 - 1.2682563266912e+40*cos(theta)**67 + 1.21390248411872e+40*cos(theta)**65 - 1.03268595785969e+40*cos(theta)**63 + 7.82933103920794e+39*cos(theta)**61 - 5.30065697438051e+39*cos(theta)**59 + 3.20927957649153e+39*cos(theta)**57 - 1.73922248016315e+39*cos(theta)**55 + 8.44034438902706e+38*cos(theta)**53 - 3.66786331380614e+38*cos(theta)**51 + 1.42663994054388e+38*cos(theta)**49 - 4.96222588015262e+37*cos(theta)**47 + 1.54142706219683e+37*cos(theta)**45 - 4.26856724916046e+36*cos(theta)**43 + 1.05142286579157e+36*cos(theta)**41 - 2.29727351438606e+35*cos(theta)**39 + 4.43764252909299e+34*cos(theta)**37 - 7.54909303799727e+33*cos(theta)**35 + 1.12574194426275e+33*cos(theta)**33 - 1.46365857318575e+32*cos(theta)**31 + 1.64874330555081e+31*cos(theta)**29 - 1.59720778347322e+30*cos(theta)**27 + 1.31910572235083e+29*cos(theta)**25 - 9.19237437178276e+27*cos(theta)**23 + 5.33900531694453e+26*cos(theta)**21 - 2.54642542938531e+25*cos(theta)**19 + 9.79394395917426e+23*cos(theta)**17 - 2.96984699765373e+22*cos(theta)**15 + 6.89898085738146e+20*cos(theta)**13 - 1.18242255960394e+19*cos(theta)**11 + 1.42056008689858e+17*cos(theta)**9 - 1.11150104604105e+15*cos(theta)**7 + 5052277482004.78*cos(theta)**5 - 10900275042.0815*cos(theta)**3 + 7038490.12618263*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl96_m4(theta, phi):
    return 6.39837069664651e-8*(1.0 - cos(theta)**2)**2*(3.6325298043751e+35*cos(theta)**92 - 7.96113600058334e+36*cos(theta)**90 + 8.43501314347521e+37*cos(theta)**88 - 5.7556560273125e+38*cos(theta)**86 + 2.84282740267935e+39*cos(theta)**84 - 1.08307063669292e+40*cos(theta)**82 + 3.31204197463829e+40*cos(theta)**80 - 8.35279540291859e+40*cos(theta)**78 + 1.77142970303422e+41*cos(theta)**76 - 3.20544422453811e+41*cos(theta)**74 + 5.00456927773262e+41*cos(theta)**72 - 6.80046734390461e+41*cos(theta)**70 + 8.09818966248996e+41*cos(theta)**68 - 8.49731738883102e+41*cos(theta)**66 + 7.89036614677166e+41*cos(theta)**64 - 6.50592153451602e+41*cos(theta)**62 + 4.77589193391684e+41*cos(theta)**60 - 3.1273876148845e+41*cos(theta)**58 + 1.82928935860017e+41*cos(theta)**56 - 9.56572364089733e+40*cos(theta)**54 + 4.47338252618434e+40*cos(theta)**52 - 1.87061029004113e+40*cos(theta)**50 + 6.990535708665e+39*cos(theta)**48 - 2.33224616367173e+39*cos(theta)**46 + 6.93642177988575e+38*cos(theta)**44 - 1.835483917139e+38*cos(theta)**42 + 4.31083374974544e+37*cos(theta)**40 - 8.95936670610563e+36*cos(theta)**38 + 1.64192773576441e+36*cos(theta)**36 - 2.64218256329904e+35*cos(theta)**34 + 3.71494841606708e+34*cos(theta)**32 - 4.53734157687582e+33*cos(theta)**30 + 4.78135558609734e+32*cos(theta)**28 - 4.3124610153777e+31*cos(theta)**26 + 3.29776430587706e+30*cos(theta)**24 - 2.11424610551003e+29*cos(theta)**22 + 1.12119111655835e+28*cos(theta)**20 - 4.83820831583209e+26*cos(theta)**18 + 1.66497047305962e+25*cos(theta)**16 - 4.4547704964806e+23*cos(theta)**14 + 8.9686751145959e+21*cos(theta)**12 - 1.30066481556434e+20*cos(theta)**10 + 1.27850407820872e+18*cos(theta)**8 - 7.78050732228736e+15*cos(theta)**6 + 25261387410023.9*cos(theta)**4 - 32700825126.2445*cos(theta)**2 + 7038490.12618263)*cos(4*phi)

#@torch.jit.script
def Yl96_m5(theta, phi):
    return 6.63765685779902e-10*(1.0 - cos(theta)**2)**2.5*(3.3419274200251e+37*cos(theta)**91 - 7.16502240052501e+38*cos(theta)**89 + 7.42281156625819e+39*cos(theta)**87 - 4.94986418348875e+40*cos(theta)**85 + 2.38797501825065e+41*cos(theta)**83 - 8.88117922088193e+41*cos(theta)**81 + 2.64963357971063e+42*cos(theta)**79 - 6.5151804142765e+42*cos(theta)**77 + 1.34628657430601e+43*cos(theta)**75 - 2.3720287261582e+43*cos(theta)**73 + 3.60328987996749e+43*cos(theta)**71 - 4.76032714073323e+43*cos(theta)**69 + 5.50676897049317e+43*cos(theta)**67 - 5.60822947662847e+43*cos(theta)**65 + 5.04983433393386e+43*cos(theta)**63 - 4.03367135139993e+43*cos(theta)**61 + 2.86553516035011e+43*cos(theta)**59 - 1.81388481663301e+43*cos(theta)**57 + 1.0244020408161e+43*cos(theta)**55 - 5.16549076608456e+42*cos(theta)**53 + 2.32615891361586e+42*cos(theta)**51 - 9.35305145020567e+41*cos(theta)**49 + 3.3554571401592e+41*cos(theta)**47 - 1.072833235289e+41*cos(theta)**45 + 3.05202558314973e+40*cos(theta)**43 - 7.7090324519838e+39*cos(theta)**41 + 1.72433349989818e+39*cos(theta)**39 - 3.40455934832014e+38*cos(theta)**37 + 5.91093984875186e+37*cos(theta)**35 - 8.98342071521675e+36*cos(theta)**33 + 1.18878349314146e+36*cos(theta)**31 - 1.36120247306275e+35*cos(theta)**29 + 1.33877956410725e+34*cos(theta)**27 - 1.1212398639982e+33*cos(theta)**25 + 7.91463433410495e+31*cos(theta)**23 - 4.65134143212207e+30*cos(theta)**21 + 2.2423822331167e+29*cos(theta)**19 - 8.70877496849775e+27*cos(theta)**17 + 2.6639527568954e+26*cos(theta)**15 - 6.23667869507284e+24*cos(theta)**13 + 1.07624101375151e+23*cos(theta)**11 - 1.30066481556434e+21*cos(theta)**9 + 1.02280326256697e+19*cos(theta)**7 - 4.66830439337241e+16*cos(theta)**5 + 101045549640096.0*cos(theta)**3 - 65401650252.489*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl96_m6(theta, phi):
    return 6.88960011194611e-12*(1.0 - cos(theta)**2)**3*(3.04115395222284e+39*cos(theta)**90 - 6.37686993646726e+40*cos(theta)**88 + 6.45784606264462e+41*cos(theta)**86 - 4.20738455596543e+42*cos(theta)**84 + 1.98201926514804e+43*cos(theta)**82 - 7.19375516891437e+43*cos(theta)**80 + 2.0932105279714e+44*cos(theta)**78 - 5.01668891899291e+44*cos(theta)**76 + 1.0097149307295e+45*cos(theta)**74 - 1.73158097009549e+45*cos(theta)**72 + 2.55833581477692e+45*cos(theta)**70 - 3.28462572710593e+45*cos(theta)**68 + 3.68953521023043e+45*cos(theta)**66 - 3.64534915980851e+45*cos(theta)**64 + 3.18139563037833e+45*cos(theta)**62 - 2.46053952435396e+45*cos(theta)**60 + 1.69066574460656e+45*cos(theta)**58 - 1.03391434548082e+45*cos(theta)**56 + 5.63421122448853e+44*cos(theta)**54 - 2.73771010602482e+44*cos(theta)**52 + 1.18634104594409e+44*cos(theta)**50 - 4.58299521060078e+43*cos(theta)**48 + 1.57706485587483e+43*cos(theta)**46 - 4.82774955880048e+42*cos(theta)**44 + 1.31237100075438e+42*cos(theta)**42 - 3.16070330531336e+41*cos(theta)**40 + 6.72490064960289e+40*cos(theta)**38 - 1.25968695887845e+40*cos(theta)**36 + 2.06882894706315e+39*cos(theta)**34 - 2.96452883602153e+38*cos(theta)**32 + 3.68522882873854e+37*cos(theta)**30 - 3.94748717188196e+36*cos(theta)**28 + 3.61470482308959e+35*cos(theta)**26 - 2.8030996599955e+34*cos(theta)**24 + 1.82036589684414e+33*cos(theta)**22 - 9.76781700745636e+31*cos(theta)**20 + 4.26052624292174e+30*cos(theta)**18 - 1.48049174464462e+29*cos(theta)**16 + 3.9959291353431e+27*cos(theta)**14 - 8.10768230359469e+25*cos(theta)**12 + 1.18386511512666e+24*cos(theta)**10 - 1.1705983340079e+22*cos(theta)**8 + 7.15962283796882e+19*cos(theta)**6 - 2.33415219668621e+17*cos(theta)**4 + 303136648920287.0*cos(theta)**2 - 65401650252.489)*cos(6*phi)

#@torch.jit.script
def Yl96_m7(theta, phi):
    return 7.15573334019319e-14*(1.0 - cos(theta)**2)**3.5*(2.73703855700055e+41*cos(theta)**89 - 5.61164554409119e+42*cos(theta)**87 + 5.55374761387437e+43*cos(theta)**85 - 3.53420302701097e+44*cos(theta)**83 + 1.62525579742139e+45*cos(theta)**81 - 5.75500413513149e+45*cos(theta)**79 + 1.63270421181769e+46*cos(theta)**77 - 3.81268357843461e+46*cos(theta)**75 + 7.47189048739833e+46*cos(theta)**73 - 1.24673829846875e+47*cos(theta)**71 + 1.79083507034384e+47*cos(theta)**69 - 2.23354549443203e+47*cos(theta)**67 + 2.43509323875208e+47*cos(theta)**65 - 2.33302346227744e+47*cos(theta)**63 + 1.97246529083457e+47*cos(theta)**61 - 1.47632371461237e+47*cos(theta)**59 + 9.80586131871806e+46*cos(theta)**57 - 5.78992033469257e+46*cos(theta)**55 + 3.0424740612238e+46*cos(theta)**53 - 1.4236092551329e+46*cos(theta)**51 + 5.93170522972043e+45*cos(theta)**49 - 2.19983770108837e+45*cos(theta)**47 + 7.2544983370242e+44*cos(theta)**45 - 2.12420980587221e+44*cos(theta)**43 + 5.51195820316842e+43*cos(theta)**41 - 1.26428132212534e+43*cos(theta)**39 + 2.5554622468491e+42*cos(theta)**37 - 4.53487305196243e+41*cos(theta)**35 + 7.03401842001471e+40*cos(theta)**33 - 9.48649227526889e+39*cos(theta)**31 + 1.10556864862156e+39*cos(theta)**29 - 1.10529640812695e+38*cos(theta)**27 + 9.39823254003293e+36*cos(theta)**25 - 6.72743918398921e+35*cos(theta)**23 + 4.00480497305711e+34*cos(theta)**21 - 1.95356340149127e+33*cos(theta)**19 + 7.66894723725912e+31*cos(theta)**17 - 2.36878679143139e+30*cos(theta)**15 + 5.59430078948034e+28*cos(theta)**13 - 9.72921876431363e+26*cos(theta)**11 + 1.18386511512666e+25*cos(theta)**9 - 9.36478667206322e+22*cos(theta)**7 + 4.29577370278129e+20*cos(theta)**5 - 9.33660878674483e+17*cos(theta)**3 + 606273297840573.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl96_m8(theta, phi):
    return 7.43776538830222e-16*(1.0 - cos(theta)**2)**4*(2.43596431573049e+43*cos(theta)**88 - 4.88213162335933e+44*cos(theta)**86 + 4.72068547179322e+45*cos(theta)**84 - 2.9333885124191e+46*cos(theta)**82 + 1.31645719591133e+47*cos(theta)**80 - 4.54645326675388e+47*cos(theta)**78 + 1.25718224309962e+48*cos(theta)**76 - 2.85951268382596e+48*cos(theta)**74 + 5.45448005580078e+48*cos(theta)**72 - 8.85184191912813e+48*cos(theta)**70 + 1.23567619853725e+49*cos(theta)**68 - 1.49647548126946e+49*cos(theta)**66 + 1.58281060518885e+49*cos(theta)**64 - 1.46980478123479e+49*cos(theta)**62 + 1.20320382740909e+49*cos(theta)**60 - 8.71030991621301e+48*cos(theta)**58 + 5.5893409516693e+48*cos(theta)**56 - 3.18445618408092e+48*cos(theta)**54 + 1.61251125244862e+48*cos(theta)**52 - 7.26040720117781e+47*cos(theta)**50 + 2.90653556256301e+47*cos(theta)**48 - 1.03392371951154e+47*cos(theta)**46 + 3.26452425166089e+46*cos(theta)**44 - 9.13410216525052e+45*cos(theta)**42 + 2.25990286329905e+45*cos(theta)**40 - 4.93069715628884e+44*cos(theta)**38 + 9.45521031334166e+43*cos(theta)**36 - 1.58720556818685e+43*cos(theta)**34 + 2.32122607860486e+42*cos(theta)**32 - 2.94081260533335e+41*cos(theta)**30 + 3.20614908100253e+40*cos(theta)**28 - 2.98430030194276e+39*cos(theta)**26 + 2.34955813500823e+38*cos(theta)**24 - 1.54731101231752e+37*cos(theta)**22 + 8.41009044341992e+35*cos(theta)**20 - 3.71177046283342e+34*cos(theta)**18 + 1.30372103033405e+33*cos(theta)**16 - 3.55318018714708e+31*cos(theta)**14 + 7.27259102632444e+29*cos(theta)**12 - 1.0702140640745e+28*cos(theta)**10 + 1.06547860361399e+26*cos(theta)**8 - 6.55535067044426e+23*cos(theta)**6 + 2.14788685139065e+21*cos(theta)**4 - 2.80098263602345e+18*cos(theta)**2 + 606273297840573.0)*cos(8*phi)

#@torch.jit.script
def Yl96_m9(theta, phi):
    return 7.73760382522195e-18*(1.0 - cos(theta)**2)**4.5*(2.14364859784283e+45*cos(theta)**87 - 4.19863319608903e+46*cos(theta)**85 + 3.9653757963063e+47*cos(theta)**83 - 2.40537858018366e+48*cos(theta)**81 + 1.05316575672906e+49*cos(theta)**79 - 3.54623354806803e+49*cos(theta)**77 + 9.55458504755713e+49*cos(theta)**75 - 2.11603938603121e+50*cos(theta)**73 + 3.92722564017656e+50*cos(theta)**71 - 6.19628934338969e+50*cos(theta)**69 + 8.4025981500533e+50*cos(theta)**67 - 9.87673817637844e+50*cos(theta)**65 + 1.01299878732087e+51*cos(theta)**63 - 9.1127896436557e+50*cos(theta)**61 + 7.21922296445451e+50*cos(theta)**59 - 5.05197975140355e+50*cos(theta)**57 + 3.13003093293481e+50*cos(theta)**55 - 1.71960633940369e+50*cos(theta)**53 + 8.38505851273281e+49*cos(theta)**51 - 3.63020360058891e+49*cos(theta)**49 + 1.39513707003025e+49*cos(theta)**47 - 4.75604910975306e+48*cos(theta)**45 + 1.43639067073079e+48*cos(theta)**43 - 3.83632290940522e+47*cos(theta)**41 + 9.0396114531962e+46*cos(theta)**39 - 1.87366491938976e+46*cos(theta)**37 + 3.403875712803e+45*cos(theta)**35 - 5.39649893183529e+44*cos(theta)**33 + 7.42792345153554e+43*cos(theta)**31 - 8.82243781600006e+42*cos(theta)**29 + 8.97721742680708e+41*cos(theta)**27 - 7.75918078505118e+40*cos(theta)**25 + 5.63893952401976e+39*cos(theta)**23 - 3.40408422709854e+38*cos(theta)**21 + 1.68201808868398e+37*cos(theta)**19 - 6.68118683310015e+35*cos(theta)**17 + 2.08595364853448e+34*cos(theta)**15 - 4.97445226200592e+32*cos(theta)**13 + 8.72710923158933e+30*cos(theta)**11 - 1.0702140640745e+29*cos(theta)**9 + 8.52382882891194e+26*cos(theta)**7 - 3.93321040226655e+24*cos(theta)**5 + 8.59154740556259e+21*cos(theta)**3 - 5.6019652720469e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl96_m10(theta, phi):
    return 8.05738156580094e-20*(1.0 - cos(theta)**2)**5*(1.86497428012327e+47*cos(theta)**86 - 3.56883821667567e+48*cos(theta)**84 + 3.29126191093423e+49*cos(theta)**82 - 1.94835664994877e+50*cos(theta)**80 + 8.3200094781596e+50*cos(theta)**78 - 2.73059983201238e+51*cos(theta)**76 + 7.16593878566785e+51*cos(theta)**74 - 1.54470875180278e+52*cos(theta)**72 + 2.78833020452536e+52*cos(theta)**70 - 4.27543964693889e+52*cos(theta)**68 + 5.62974076053571e+52*cos(theta)**66 - 6.41987981464599e+52*cos(theta)**64 + 6.38189236012146e+52*cos(theta)**62 - 5.55880168262997e+52*cos(theta)**60 + 4.25934154902816e+52*cos(theta)**58 - 2.87962845830002e+52*cos(theta)**56 + 1.72151701311414e+52*cos(theta)**54 - 9.11391359883958e+51*cos(theta)**52 + 4.27637984149373e+51*cos(theta)**50 - 1.77879976428856e+51*cos(theta)**48 + 6.55714422914216e+50*cos(theta)**46 - 2.14022209938888e+50*cos(theta)**44 + 6.1764798841424e+49*cos(theta)**42 - 1.57289239285614e+49*cos(theta)**40 + 3.52544846674652e+48*cos(theta)**38 - 6.93256020174211e+47*cos(theta)**36 + 1.19135649948105e+47*cos(theta)**34 - 1.78084464750565e+46*cos(theta)**32 + 2.30265626997602e+45*cos(theta)**30 - 2.55850696664002e+44*cos(theta)**28 + 2.42384870523791e+43*cos(theta)**26 - 1.9397951962628e+42*cos(theta)**24 + 1.29695609052454e+41*cos(theta)**22 - 7.14857687690693e+39*cos(theta)**20 + 3.19583436849957e+38*cos(theta)**18 - 1.13580176162703e+37*cos(theta)**16 + 3.12893047280172e+35*cos(theta)**14 - 6.46678794060769e+33*cos(theta)**12 + 9.59982015474826e+31*cos(theta)**10 - 9.6319265766705e+29*cos(theta)**8 + 5.96668018023836e+27*cos(theta)**6 - 1.96660520113328e+25*cos(theta)**4 + 2.57746422166878e+22*cos(theta)**2 - 5.6019652720469e+18)*cos(10*phi)

#@torch.jit.script
def Yl96_m11(theta, phi):
    return 8.39948804191916e-22*(1.0 - cos(theta)**2)**5.5*(1.60387788090601e+49*cos(theta)**85 - 2.99782410200757e+50*cos(theta)**83 + 2.69883476696607e+51*cos(theta)**81 - 1.55868531995901e+52*cos(theta)**79 + 6.48960739296449e+52*cos(theta)**77 - 2.07525587232941e+53*cos(theta)**75 + 5.30279470139421e+53*cos(theta)**73 - 1.112190301298e+54*cos(theta)**71 + 1.95183114316775e+54*cos(theta)**69 - 2.90729895991844e+54*cos(theta)**67 + 3.71562890195357e+54*cos(theta)**65 - 4.10872308137343e+54*cos(theta)**63 + 3.9567732632753e+54*cos(theta)**61 - 3.33528100957798e+54*cos(theta)**59 + 2.47041809843633e+54*cos(theta)**57 - 1.61259193664801e+54*cos(theta)**55 + 9.29619187081637e+53*cos(theta)**53 - 4.73923507139658e+53*cos(theta)**51 + 2.13818992074687e+53*cos(theta)**49 - 8.53823886858511e+52*cos(theta)**47 + 3.01628634540539e+52*cos(theta)**45 - 9.41697723731106e+51*cos(theta)**43 + 2.59412155133981e+51*cos(theta)**41 - 6.29156957142456e+50*cos(theta)**39 + 1.33967041736368e+50*cos(theta)**37 - 2.49572167262716e+49*cos(theta)**35 + 4.05061209823557e+48*cos(theta)**33 - 5.69870287201806e+47*cos(theta)**31 + 6.90796880992805e+46*cos(theta)**29 - 7.16381950659205e+45*cos(theta)**27 + 6.30200663361857e+44*cos(theta)**25 - 4.65550847103071e+43*cos(theta)**23 + 2.853303399154e+42*cos(theta)**21 - 1.42971537538139e+41*cos(theta)**19 + 5.75250186329923e+39*cos(theta)**17 - 1.81728281860324e+38*cos(theta)**15 + 4.38050266192241e+36*cos(theta)**13 - 7.76014552872923e+34*cos(theta)**11 + 9.59982015474826e+32*cos(theta)**9 - 7.7055412613364e+30*cos(theta)**7 + 3.58000810814302e+28*cos(theta)**5 - 7.86642080453311e+25*cos(theta)**3 + 5.15492844333755e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl96_m12(theta, phi):
    return 8.76660574088169e-24*(1.0 - cos(theta)**2)**6*(1.36329619877011e+51*cos(theta)**84 - 2.48819400466628e+52*cos(theta)**82 + 2.18605616124252e+53*cos(theta)**80 - 1.23136140276762e+54*cos(theta)**78 + 4.99699769258266e+54*cos(theta)**76 - 1.55644190424706e+55*cos(theta)**74 + 3.87104013201777e+55*cos(theta)**72 - 7.89655113921582e+55*cos(theta)**70 + 1.34676348878575e+56*cos(theta)**68 - 1.94789030314536e+56*cos(theta)**66 + 2.41515878626982e+56*cos(theta)**64 - 2.58849554126526e+56*cos(theta)**62 + 2.41363169059793e+56*cos(theta)**60 - 1.96781579565101e+56*cos(theta)**58 + 1.40813831610871e+56*cos(theta)**56 - 8.86925565156406e+55*cos(theta)**54 + 4.92698169153268e+55*cos(theta)**52 - 2.41700988641226e+55*cos(theta)**50 + 1.04771306116596e+55*cos(theta)**48 - 4.012972268235e+54*cos(theta)**46 + 1.35732885543243e+54*cos(theta)**44 - 4.04930021204376e+53*cos(theta)**42 + 1.06358983604932e+53*cos(theta)**40 - 2.45371213285558e+52*cos(theta)**38 + 4.95678054424561e+51*cos(theta)**36 - 8.73502585419505e+50*cos(theta)**34 + 1.33670199241774e+50*cos(theta)**32 - 1.7665978903256e+49*cos(theta)**30 + 2.00331095487913e+48*cos(theta)**28 - 1.93423126677985e+47*cos(theta)**26 + 1.57550165840464e+46*cos(theta)**24 - 1.07076694833706e+45*cos(theta)**22 + 5.99193713822339e+43*cos(theta)**20 - 2.71645921322464e+42*cos(theta)**18 + 9.77925316760869e+40*cos(theta)**16 - 2.72592422790486e+39*cos(theta)**14 + 5.69465346049913e+37*cos(theta)**12 - 8.53616008160216e+35*cos(theta)**10 + 8.63983813927344e+33*cos(theta)**8 - 5.39387888293548e+31*cos(theta)**6 + 1.79000405407151e+29*cos(theta)**4 - 2.35992624135993e+26*cos(theta)**2 + 5.15492844333755e+22)*cos(12*phi)

#@torch.jit.script
def Yl96_m13(theta, phi):
    return 9.16175309447676e-26*(1.0 - cos(theta)**2)**6.5*(1.14516880696689e+53*cos(theta)**83 - 2.04031908382635e+54*cos(theta)**81 + 1.74884492899401e+55*cos(theta)**79 - 9.60461894158744e+55*cos(theta)**77 + 3.79771824636282e+56*cos(theta)**75 - 1.15176700914282e+57*cos(theta)**73 + 2.7871488950528e+57*cos(theta)**71 - 5.52758579745108e+57*cos(theta)**69 + 9.1579917237431e+57*cos(theta)**67 - 1.28560760007594e+58*cos(theta)**65 + 1.54570162321269e+58*cos(theta)**63 - 1.60486723558446e+58*cos(theta)**61 + 1.44817901435876e+58*cos(theta)**59 - 1.14133316147759e+58*cos(theta)**57 + 7.88557457020878e+57*cos(theta)**55 - 4.78939805184459e+57*cos(theta)**53 + 2.56203047959699e+57*cos(theta)**51 - 1.20850494320613e+57*cos(theta)**49 + 5.02902269359663e+56*cos(theta)**47 - 1.8459672433881e+56*cos(theta)**45 + 5.97224696390268e+55*cos(theta)**43 - 1.70070608905838e+55*cos(theta)**41 + 4.25435934419729e+54*cos(theta)**39 - 9.32410610485119e+53*cos(theta)**37 + 1.78444099592842e+53*cos(theta)**35 - 2.96990879042632e+52*cos(theta)**33 + 4.27744637573676e+51*cos(theta)**31 - 5.2997936709768e+50*cos(theta)**29 + 5.60927067366158e+49*cos(theta)**27 - 5.02900129362762e+48*cos(theta)**25 + 3.78120398017114e+47*cos(theta)**23 - 2.35568728634154e+46*cos(theta)**21 + 1.19838742764468e+45*cos(theta)**19 - 4.88962658380434e+43*cos(theta)**17 + 1.56468050681739e+42*cos(theta)**15 - 3.8162939190668e+40*cos(theta)**13 + 6.83358415259896e+38*cos(theta)**11 - 8.53616008160215e+36*cos(theta)**9 + 6.91187051141875e+34*cos(theta)**7 - 3.23632732976129e+32*cos(theta)**5 + 7.16001621628603e+29*cos(theta)**3 - 4.71985248271986e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl96_m14(theta, phi):
    return 9.58833490371498e-28*(1.0 - cos(theta)**2)**7*(9.50490109782519e+54*cos(theta)**82 - 1.65265845789934e+56*cos(theta)**80 + 1.38158749390527e+57*cos(theta)**78 - 7.39555658502233e+57*cos(theta)**76 + 2.84828868477211e+58*cos(theta)**74 - 8.4078991667426e+58*cos(theta)**72 + 1.97887571548748e+59*cos(theta)**70 - 3.81403420024124e+59*cos(theta)**68 + 6.13585445490787e+59*cos(theta)**66 - 8.35644940049358e+59*cos(theta)**64 + 9.73792022623992e+59*cos(theta)**62 - 9.78969013706522e+59*cos(theta)**60 + 8.54425618471669e+59*cos(theta)**58 - 6.50559902042224e+59*cos(theta)**56 + 4.33706601361483e+59*cos(theta)**54 - 2.53838096747764e+59*cos(theta)**52 + 1.30663554459447e+59*cos(theta)**50 - 5.92167422171003e+58*cos(theta)**48 + 2.36364066599042e+58*cos(theta)**46 - 8.30685259524645e+57*cos(theta)**44 + 2.56806619447815e+57*cos(theta)**42 - 6.97289496513935e+56*cos(theta)**40 + 1.65920014423694e+56*cos(theta)**38 - 3.44991925879494e+55*cos(theta)**36 + 6.24554348574946e+54*cos(theta)**34 - 9.80069900840685e+53*cos(theta)**32 + 1.3260083764784e+53*cos(theta)**30 - 1.53694016458327e+52*cos(theta)**28 + 1.51450308188863e+51*cos(theta)**26 - 1.25725032340691e+50*cos(theta)**24 + 8.69676915439363e+48*cos(theta)**22 - 4.94694330131723e+47*cos(theta)**20 + 2.27693611252489e+46*cos(theta)**18 - 8.31236519246738e+44*cos(theta)**16 + 2.34702076022608e+43*cos(theta)**14 - 4.96118209478685e+41*cos(theta)**12 + 7.51694256785886e+39*cos(theta)**10 - 7.68254407344194e+37*cos(theta)**8 + 4.83830935799312e+35*cos(theta)**6 - 1.61816366488064e+33*cos(theta)**4 + 2.14800486488581e+30*cos(theta)**2 - 4.71985248271986e+26)*cos(14*phi)

#@torch.jit.script
def Yl96_m15(theta, phi):
    return 1.00502017318788e-29*(1.0 - cos(theta)**2)**7.5*(7.79401890021665e+56*cos(theta)**81 - 1.32212676631947e+58*cos(theta)**79 + 1.07763824524611e+59*cos(theta)**77 - 5.62062300461697e+59*cos(theta)**75 + 2.10773362673136e+60*cos(theta)**73 - 6.05368740005467e+60*cos(theta)**71 + 1.38521300084124e+61*cos(theta)**69 - 2.59354325616404e+61*cos(theta)**67 + 4.0496639402392e+61*cos(theta)**65 - 5.34812761631589e+61*cos(theta)**63 + 6.03751054026875e+61*cos(theta)**61 - 5.87381408223913e+61*cos(theta)**59 + 4.95566858713568e+61*cos(theta)**57 - 3.64313545143646e+61*cos(theta)**55 + 2.34201564735201e+61*cos(theta)**53 - 1.31995810308837e+61*cos(theta)**51 + 6.53317772297233e+60*cos(theta)**49 - 2.84240362642081e+60*cos(theta)**47 + 1.08727470635559e+60*cos(theta)**45 - 3.65501514190844e+59*cos(theta)**43 + 1.07858780168082e+59*cos(theta)**41 - 2.78915798605574e+58*cos(theta)**39 + 6.30496054810038e+57*cos(theta)**37 - 1.24197093316618e+57*cos(theta)**35 + 2.12348478515482e+56*cos(theta)**33 - 3.13622368269019e+55*cos(theta)**31 + 3.97802512943519e+54*cos(theta)**29 - 4.30343246083316e+53*cos(theta)**27 + 3.93770801291043e+52*cos(theta)**25 - 3.01740077617657e+51*cos(theta)**23 + 1.9132892139666e+50*cos(theta)**21 - 9.89388660263447e+48*cos(theta)**19 + 4.0984850025448e+47*cos(theta)**17 - 1.32997843079478e+46*cos(theta)**15 + 3.28582906431652e+44*cos(theta)**13 - 5.95341851374421e+42*cos(theta)**11 + 7.51694256785886e+40*cos(theta)**9 - 6.14603525875355e+38*cos(theta)**7 + 2.90298561479587e+36*cos(theta)**5 - 6.47265465952257e+33*cos(theta)**3 + 4.29600972977162e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl96_m16(theta, phi):
    return 1.05517200034056e-31*(1.0 - cos(theta)**2)**8*(6.31315530917549e+58*cos(theta)**80 - 1.04448014539238e+60*cos(theta)**78 + 8.29781448839505e+60*cos(theta)**76 - 4.21546725346273e+61*cos(theta)**74 + 1.5386455475139e+62*cos(theta)**72 - 4.29811805403882e+62*cos(theta)**70 + 9.55796970580455e+62*cos(theta)**68 - 1.73767398162991e+63*cos(theta)**66 + 2.63228156115548e+63*cos(theta)**64 - 3.36932039827901e+63*cos(theta)**62 + 3.68288142956394e+63*cos(theta)**60 - 3.46555030852109e+63*cos(theta)**58 + 2.82473109466734e+63*cos(theta)**56 - 2.00372449829005e+63*cos(theta)**54 + 1.24126829309656e+63*cos(theta)**52 - 6.73178632575069e+62*cos(theta)**50 + 3.20125708425644e+62*cos(theta)**48 - 1.33592970441778e+62*cos(theta)**46 + 4.89273617860016e+61*cos(theta)**44 - 1.57165651102063e+61*cos(theta)**42 + 4.42220998689138e+60*cos(theta)**40 - 1.08777161456174e+60*cos(theta)**38 + 2.33283540279714e+59*cos(theta)**36 - 4.34689826608163e+58*cos(theta)**34 + 7.0074997910109e+57*cos(theta)**32 - 9.72229341633959e+56*cos(theta)**30 + 1.1536272875362e+56*cos(theta)**28 - 1.16192676442495e+55*cos(theta)**26 + 9.84427003227607e+53*cos(theta)**24 - 6.94002178520612e+52*cos(theta)**22 + 4.01790734932986e+51*cos(theta)**20 - 1.87983845450055e+50*cos(theta)**18 + 6.96742450432616e+48*cos(theta)**16 - 1.99496764619217e+47*cos(theta)**14 + 4.27157778361147e+45*cos(theta)**12 - 6.54876036511864e+43*cos(theta)**10 + 6.76524831107297e+41*cos(theta)**8 - 4.30222468112749e+39*cos(theta)**6 + 1.45149280739794e+37*cos(theta)**4 - 1.94179639785677e+34*cos(theta)**2 + 4.29600972977162e+30)*cos(16*phi)

#@torch.jit.script
def Yl96_m17(theta, phi):
    return 1.10978549225984e-33*(1.0 - cos(theta)**2)**8.5*(5.05052424734039e+60*cos(theta)**79 - 8.1469451340606e+61*cos(theta)**77 + 6.30633901118024e+62*cos(theta)**75 - 3.11944576756242e+63*cos(theta)**73 + 1.10782479421001e+64*cos(theta)**71 - 3.00868263782717e+64*cos(theta)**69 + 6.4994193999471e+64*cos(theta)**67 - 1.14686482787574e+65*cos(theta)**65 + 1.68466019913951e+65*cos(theta)**63 - 2.08897864693299e+65*cos(theta)**61 + 2.20972885773836e+65*cos(theta)**59 - 2.01001917894223e+65*cos(theta)**57 + 1.58184941301371e+65*cos(theta)**55 - 1.08201122907663e+65*cos(theta)**53 + 6.45459512410213e+64*cos(theta)**51 - 3.36589316287534e+64*cos(theta)**49 + 1.53660340044309e+64*cos(theta)**47 - 6.1452766403218e+63*cos(theta)**45 + 2.15280391858407e+63*cos(theta)**43 - 6.60095734628664e+62*cos(theta)**41 + 1.76888399475655e+62*cos(theta)**39 - 4.13353213533461e+61*cos(theta)**37 + 8.3982074500697e+60*cos(theta)**35 - 1.47794541046775e+60*cos(theta)**33 + 2.24239993312349e+59*cos(theta)**31 - 2.91668802490188e+58*cos(theta)**29 + 3.23015640510137e+57*cos(theta)**27 - 3.02100958750488e+56*cos(theta)**25 + 2.36262480774626e+55*cos(theta)**23 - 1.52680479274535e+54*cos(theta)**21 + 8.03581469865971e+52*cos(theta)**19 - 3.38370921810099e+51*cos(theta)**17 + 1.11478792069219e+50*cos(theta)**15 - 2.79295470466904e+48*cos(theta)**13 + 5.12589334033377e+46*cos(theta)**11 - 6.54876036511864e+44*cos(theta)**9 + 5.41219864885838e+42*cos(theta)**7 - 2.58133480867649e+40*cos(theta)**5 + 5.80597122959175e+37*cos(theta)**3 - 3.88359279571354e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl96_m18(theta, phi):
    return 1.16942687923752e-35*(1.0 - cos(theta)**2)**9*(3.98991415539891e+62*cos(theta)**78 - 6.27314775322666e+63*cos(theta)**76 + 4.72975425838518e+64*cos(theta)**74 - 2.27719541032057e+65*cos(theta)**72 + 7.86555603889104e+65*cos(theta)**70 - 2.07599102010075e+66*cos(theta)**68 + 4.35461099796455e+66*cos(theta)**66 - 7.45462138119231e+66*cos(theta)**64 + 1.06133592545789e+67*cos(theta)**62 - 1.27427697462912e+67*cos(theta)**60 + 1.30374002606563e+67*cos(theta)**58 - 1.14571093199707e+67*cos(theta)**56 + 8.7001717715754e+66*cos(theta)**54 - 5.73465951410612e+66*cos(theta)**52 + 3.29184351329209e+66*cos(theta)**50 - 1.64928764980892e+66*cos(theta)**48 + 7.22203598208253e+65*cos(theta)**46 - 2.76537448814481e+65*cos(theta)**44 + 9.2570568499115e+64*cos(theta)**42 - 2.70639251197752e+64*cos(theta)**40 + 6.89864757955055e+63*cos(theta)**38 - 1.5294068900738e+63*cos(theta)**36 + 2.9393726075244e+62*cos(theta)**34 - 4.87721985454358e+61*cos(theta)**32 + 6.95143979268281e+60*cos(theta)**30 - 8.45839527221545e+59*cos(theta)**28 + 8.7214222937737e+58*cos(theta)**26 - 7.5525239687622e+57*cos(theta)**24 + 5.43403705781639e+56*cos(theta)**22 - 3.20629006476523e+55*cos(theta)**20 + 1.52680479274535e+54*cos(theta)**18 - 5.75230567077168e+52*cos(theta)**16 + 1.67218188103828e+51*cos(theta)**14 - 3.63084111606975e+49*cos(theta)**12 + 5.63848267436715e+47*cos(theta)**10 - 5.89388432860677e+45*cos(theta)**8 + 3.78853905420086e+43*cos(theta)**6 - 1.29066740433825e+41*cos(theta)**4 + 1.74179136887752e+38*cos(theta)**2 - 3.88359279571354e+34)*cos(18*phi)

#@torch.jit.script
def Yl96_m19(theta, phi):
    return 1.23474378923924e-37*(1.0 - cos(theta)**2)**9.5*(3.11213304121115e+64*cos(theta)**77 - 4.76759229245226e+65*cos(theta)**75 + 3.50001815120503e+66*cos(theta)**73 - 1.63958069543081e+67*cos(theta)**71 + 5.50588922722372e+67*cos(theta)**69 - 1.41167389366851e+68*cos(theta)**67 + 2.87404325865661e+68*cos(theta)**65 - 4.77095768396308e+68*cos(theta)**63 + 6.58028273783891e+68*cos(theta)**61 - 7.64566184777473e+68*cos(theta)**59 + 7.56169215118068e+68*cos(theta)**57 - 6.4159812191836e+68*cos(theta)**55 + 4.69809275665072e+68*cos(theta)**53 - 2.98202294733518e+68*cos(theta)**51 + 1.64592175664604e+68*cos(theta)**49 - 7.91658071908281e+67*cos(theta)**47 + 3.32213655175797e+67*cos(theta)**45 - 1.21676477478372e+67*cos(theta)**43 + 3.88796387696283e+66*cos(theta)**41 - 1.08255700479101e+66*cos(theta)**39 + 2.62148608022921e+65*cos(theta)**37 - 5.5058648042657e+64*cos(theta)**35 + 9.99386686558295e+63*cos(theta)**33 - 1.56071035345395e+63*cos(theta)**31 + 2.08543193780484e+62*cos(theta)**29 - 2.36835067622033e+61*cos(theta)**27 + 2.26756979638116e+60*cos(theta)**25 - 1.81260575250293e+59*cos(theta)**23 + 1.19548815271961e+58*cos(theta)**21 - 6.41258012953045e+56*cos(theta)**19 + 2.74824862694162e+55*cos(theta)**17 - 9.20368907323469e+53*cos(theta)**15 + 2.34105463345359e+52*cos(theta)**13 - 4.3570093392837e+50*cos(theta)**11 + 5.63848267436715e+48*cos(theta)**9 - 4.71510746288542e+46*cos(theta)**7 + 2.27312343252052e+44*cos(theta)**5 - 5.16266961735298e+41*cos(theta)**3 + 3.48358273775505e+38*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl96_m20(theta, phi):
    return 1.30647917975732e-39*(1.0 - cos(theta)**2)**10*(2.39634244173258e+66*cos(theta)**76 - 3.5756942193392e+67*cos(theta)**74 + 2.55501325037967e+68*cos(theta)**72 - 1.16410229375587e+69*cos(theta)**70 + 3.79906356678437e+69*cos(theta)**68 - 9.45821508757901e+69*cos(theta)**66 + 1.86812811812679e+70*cos(theta)**64 - 3.00570334089674e+70*cos(theta)**62 + 4.01397247008174e+70*cos(theta)**60 - 4.51094049018709e+70*cos(theta)**58 + 4.31016452617299e+70*cos(theta)**56 - 3.52878967055098e+70*cos(theta)**54 + 2.48998916102488e+70*cos(theta)**52 - 1.52083170314094e+70*cos(theta)**50 + 8.06501660756561e+69*cos(theta)**48 - 3.72079293796892e+69*cos(theta)**46 + 1.49496144829108e+69*cos(theta)**44 - 5.23208853156998e+68*cos(theta)**42 + 1.59406518955476e+68*cos(theta)**40 - 4.22197231868493e+67*cos(theta)**38 + 9.69949849684807e+66*cos(theta)**36 - 1.92705268149299e+66*cos(theta)**34 + 3.29797606564237e+65*cos(theta)**32 - 4.83820209570724e+64*cos(theta)**30 + 6.04775261963404e+63*cos(theta)**28 - 6.39454682579488e+62*cos(theta)**26 + 5.66892449095291e+61*cos(theta)**24 - 4.16899323075673e+60*cos(theta)**22 + 2.51052512071117e+59*cos(theta)**20 - 1.21839022461079e+58*cos(theta)**18 + 4.67202266580076e+56*cos(theta)**16 - 1.3805533609852e+55*cos(theta)**14 + 3.04337102348967e+53*cos(theta)**12 - 4.79271027321207e+51*cos(theta)**10 + 5.07463440693043e+49*cos(theta)**8 - 3.30057522401979e+47*cos(theta)**6 + 1.13656171626026e+45*cos(theta)**4 - 1.54880088520589e+42*cos(theta)**2 + 3.48358273775505e+38)*cos(20*phi)

#@torch.jit.script
def Yl96_m21(theta, phi):
    return 1.38548799204113e-41*(1.0 - cos(theta)**2)**10.5*(1.82122025571676e+68*cos(theta)**75 - 2.64601372231101e+69*cos(theta)**73 + 1.83960954027337e+70*cos(theta)**71 - 8.14871605629111e+70*cos(theta)**69 + 2.58336322541337e+71*cos(theta)**67 - 6.24242195780215e+71*cos(theta)**65 + 1.19560199560115e+72*cos(theta)**63 - 1.86353607135598e+72*cos(theta)**61 + 2.40838348204904e+72*cos(theta)**59 - 2.61634548430851e+72*cos(theta)**57 + 2.41369213465687e+72*cos(theta)**55 - 1.90554642209753e+72*cos(theta)**53 + 1.29479436373294e+72*cos(theta)**51 - 7.60415851570472e+71*cos(theta)**49 + 3.87120797163149e+71*cos(theta)**47 - 1.7115647514657e+71*cos(theta)**45 + 6.57783037248077e+70*cos(theta)**43 - 2.19747718325939e+70*cos(theta)**41 + 6.37626075821904e+69*cos(theta)**39 - 1.60434948110028e+69*cos(theta)**37 + 3.4918194588653e+68*cos(theta)**35 - 6.55197911707618e+67*cos(theta)**33 + 1.05535234100556e+67*cos(theta)**31 - 1.45146062871217e+66*cos(theta)**29 + 1.69337073349753e+65*cos(theta)**27 - 1.66258217470667e+64*cos(theta)**25 + 1.3605418778287e+63*cos(theta)**23 - 9.17178510766481e+61*cos(theta)**21 + 5.02105024142234e+60*cos(theta)**19 - 2.19310240429941e+59*cos(theta)**17 + 7.47523626528121e+57*cos(theta)**15 - 1.93277470537928e+56*cos(theta)**13 + 3.6520452281876e+54*cos(theta)**11 - 4.79271027321207e+52*cos(theta)**9 + 4.05970752554435e+50*cos(theta)**7 - 1.98034513441188e+48*cos(theta)**5 + 4.54624686504104e+45*cos(theta)**3 - 3.09760177041179e+42*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl96_m22(theta, phi):
    return 1.47275711925126e-43*(1.0 - cos(theta)**2)**11*(1.36591519178757e+70*cos(theta)**74 - 1.93159001728703e+71*cos(theta)**72 + 1.30612277359409e+72*cos(theta)**70 - 5.62261407884087e+72*cos(theta)**68 + 1.73085336102696e+73*cos(theta)**66 - 4.0575742725714e+73*cos(theta)**64 + 7.53229257228723e+73*cos(theta)**62 - 1.13675700352715e+74*cos(theta)**60 + 1.42094625440893e+74*cos(theta)**58 - 1.49131692605585e+74*cos(theta)**56 + 1.32753067406128e+74*cos(theta)**54 - 1.00993960371169e+74*cos(theta)**52 + 6.60345125503798e+73*cos(theta)**50 - 3.72603767269531e+73*cos(theta)**48 + 1.8194677466668e+73*cos(theta)**46 - 7.70204138159567e+72*cos(theta)**44 + 2.82846706016673e+72*cos(theta)**42 - 9.00965645136351e+71*cos(theta)**40 + 2.48674169570543e+71*cos(theta)**38 - 5.93609308007102e+70*cos(theta)**36 + 1.22213681060286e+70*cos(theta)**34 - 2.16215310863514e+69*cos(theta)**32 + 3.27159225711723e+68*cos(theta)**30 - 4.2092358232653e+67*cos(theta)**28 + 4.57210098044334e+66*cos(theta)**26 - 4.15645543676667e+65*cos(theta)**24 + 3.129246319006e+64*cos(theta)**22 - 1.92607487260961e+63*cos(theta)**20 + 9.53999545870245e+61*cos(theta)**18 - 3.728274087309e+60*cos(theta)**16 + 1.12128543979218e+59*cos(theta)**14 - 2.51260711699307e+57*cos(theta)**12 + 4.01724975100636e+55*cos(theta)**10 - 4.31343924589087e+53*cos(theta)**8 + 2.84179526788104e+51*cos(theta)**6 - 9.90172567205938e+48*cos(theta)**4 + 1.36387405951231e+46*cos(theta)**2 - 3.09760177041179e+42)*cos(22*phi)

#@torch.jit.script
def Yl96_m23(theta, phi):
    return 1.56942942262094e-45*(1.0 - cos(theta)**2)**11.5*(1.0107772419228e+72*cos(theta)**73 - 1.39074481244666e+73*cos(theta)**71 + 9.14285941515863e+73*cos(theta)**69 - 3.82337757361179e+74*cos(theta)**67 + 1.14236321827779e+75*cos(theta)**65 - 2.59684753444569e+75*cos(theta)**63 + 4.67002139481808e+75*cos(theta)**61 - 6.82054202116288e+75*cos(theta)**59 + 8.24148827557182e+75*cos(theta)**57 - 8.35137478591278e+75*cos(theta)**55 + 7.16866563993091e+75*cos(theta)**53 - 5.25168593930079e+75*cos(theta)**51 + 3.30172562751899e+75*cos(theta)**49 - 1.78849808289375e+75*cos(theta)**47 + 8.36955163466729e+74*cos(theta)**45 - 3.38889820790209e+74*cos(theta)**43 + 1.18795616527003e+74*cos(theta)**41 - 3.6038625805454e+73*cos(theta)**39 + 9.44961844368062e+72*cos(theta)**37 - 2.13699350882557e+72*cos(theta)**35 + 4.15526515604971e+71*cos(theta)**33 - 6.91888994763245e+70*cos(theta)**31 + 9.8147767713517e+69*cos(theta)**29 - 1.17858603051428e+69*cos(theta)**27 + 1.18874625491527e+68*cos(theta)**25 - 9.97549304824001e+66*cos(theta)**23 + 6.88434190181321e+65*cos(theta)**21 - 3.85214974521922e+64*cos(theta)**19 + 1.71719918256644e+63*cos(theta)**17 - 5.96523853969441e+61*cos(theta)**15 + 1.56979961570905e+60*cos(theta)**13 - 3.01512854039168e+58*cos(theta)**11 + 4.01724975100636e+56*cos(theta)**9 - 3.45075139671269e+54*cos(theta)**7 + 1.70507716072863e+52*cos(theta)**5 - 3.96069026882375e+49*cos(theta)**3 + 2.72774811902462e+46*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl96_m24(theta, phi):
    return 1.67683270982667e-47*(1.0 - cos(theta)**2)**12*(7.37867386603647e+73*cos(theta)**72 - 9.87428816837132e+74*cos(theta)**70 + 6.30857299645945e+75*cos(theta)**68 - 2.5616629743199e+76*cos(theta)**66 + 7.42536091880565e+76*cos(theta)**64 - 1.63601394670079e+77*cos(theta)**62 + 2.84871305083903e+77*cos(theta)**60 - 4.0241197924861e+77*cos(theta)**58 + 4.69764831707594e+77*cos(theta)**56 - 4.59325613225203e+77*cos(theta)**54 + 3.79939278916338e+77*cos(theta)**52 - 2.6783598290434e+77*cos(theta)**50 + 1.61784555748431e+77*cos(theta)**48 - 8.40594098960063e+76*cos(theta)**46 + 3.76629823560028e+76*cos(theta)**44 - 1.4572262293979e+76*cos(theta)**42 + 4.87062027760711e+75*cos(theta)**40 - 1.40550640641271e+75*cos(theta)**38 + 3.49635882416183e+74*cos(theta)**36 - 7.47947728088948e+73*cos(theta)**34 + 1.37123750149641e+73*cos(theta)**32 - 2.14485588376606e+72*cos(theta)**30 + 2.84628526369199e+71*cos(theta)**28 - 3.18218228238856e+70*cos(theta)**26 + 2.97186563728817e+69*cos(theta)**24 - 2.2943634010952e+68*cos(theta)**22 + 1.44571179938077e+67*cos(theta)**20 - 7.31908451591652e+65*cos(theta)**18 + 2.91923861036295e+64*cos(theta)**16 - 8.94785780954161e+62*cos(theta)**14 + 2.04073950042177e+61*cos(theta)**12 - 3.31664139443085e+59*cos(theta)**10 + 3.61552477590572e+57*cos(theta)**8 - 2.41552597769889e+55*cos(theta)**6 + 8.52538580364313e+52*cos(theta)**4 - 1.18820708064713e+50*cos(theta)**2 + 2.72774811902462e+46)*cos(24*phi)

#@torch.jit.script
def Yl96_m25(theta, phi):
    return 1.79651481823311e-49*(1.0 - cos(theta)**2)**12.5*(5.31264518354626e+75*cos(theta)**71 - 6.91200171785992e+76*cos(theta)**69 + 4.28982963759243e+77*cos(theta)**67 - 1.69069756305113e+78*cos(theta)**65 + 4.75223098803562e+78*cos(theta)**63 - 1.01432864695449e+79*cos(theta)**61 + 1.70922783050342e+79*cos(theta)**59 - 2.33398947964194e+79*cos(theta)**57 + 2.63068305756252e+79*cos(theta)**55 - 2.48035831141609e+79*cos(theta)**53 + 1.97568425036496e+79*cos(theta)**51 - 1.3391799145217e+79*cos(theta)**49 + 7.76565867592466e+78*cos(theta)**47 - 3.86673285521629e+78*cos(theta)**45 + 1.65717122366412e+78*cos(theta)**43 - 6.12035016347118e+77*cos(theta)**41 + 1.94824811104284e+77*cos(theta)**39 - 5.34092434436829e+76*cos(theta)**37 + 1.25868917669826e+76*cos(theta)**35 - 2.54302227550242e+75*cos(theta)**33 + 4.3879600047885e+74*cos(theta)**31 - 6.43456765129817e+73*cos(theta)**29 + 7.96959873833758e+72*cos(theta)**27 - 8.27367393421026e+71*cos(theta)**25 + 7.13247752949161e+70*cos(theta)**23 - 5.04759948240944e+69*cos(theta)**21 + 2.89142359876155e+68*cos(theta)**19 - 1.31743521286497e+67*cos(theta)**17 + 4.67078177658072e+65*cos(theta)**15 - 1.25270009333583e+64*cos(theta)**13 + 2.44888740050613e+62*cos(theta)**11 - 3.31664139443085e+60*cos(theta)**9 + 2.89241982072458e+58*cos(theta)**7 - 1.44931558661933e+56*cos(theta)**5 + 3.41015432145725e+53*cos(theta)**3 - 2.37641416129425e+50*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl96_m26(theta, phi):
    return 1.93028623657921e-51*(1.0 - cos(theta)**2)**13*(3.77197808031784e+77*cos(theta)**70 - 4.76928118532335e+78*cos(theta)**68 + 2.87418585718693e+79*cos(theta)**66 - 1.09895341598324e+80*cos(theta)**64 + 2.99390552246244e+80*cos(theta)**62 - 6.18740474642238e+80*cos(theta)**60 + 1.00844441999702e+81*cos(theta)**58 - 1.33037400339591e+81*cos(theta)**56 + 1.44687568165939e+81*cos(theta)**54 - 1.31458990505053e+81*cos(theta)**52 + 1.00759896768613e+81*cos(theta)**50 - 6.56198158115634e+80*cos(theta)**48 + 3.64985957768459e+80*cos(theta)**46 - 1.74002978484733e+80*cos(theta)**44 + 7.12583626175573e+79*cos(theta)**42 - 2.50934356702318e+79*cos(theta)**40 + 7.59816763306709e+78*cos(theta)**38 - 1.97614200741627e+78*cos(theta)**36 + 4.40541211844391e+77*cos(theta)**34 - 8.391973509158e+76*cos(theta)**32 + 1.36026760148443e+76*cos(theta)**30 - 1.86602461887647e+75*cos(theta)**28 + 2.15179165935115e+74*cos(theta)**26 - 2.06841848355257e+73*cos(theta)**24 + 1.64046983178307e+72*cos(theta)**22 - 1.05999589130598e+71*cos(theta)**20 + 5.49370483764694e+69*cos(theta)**18 - 2.23963986187046e+68*cos(theta)**16 + 7.00617266487108e+66*cos(theta)**14 - 1.62851012133657e+65*cos(theta)**12 + 2.69377614055674e+63*cos(theta)**10 - 2.98497725498777e+61*cos(theta)**8 + 2.02469387450721e+59*cos(theta)**6 - 7.24657793309666e+56*cos(theta)**4 + 1.02304629643718e+54*cos(theta)**2 - 2.37641416129425e+50)*cos(26*phi)

#@torch.jit.script
def Yl96_m27(theta, phi):
    return 2.08027207054461e-53*(1.0 - cos(theta)**2)**13.5*(2.64038465622249e+79*cos(theta)**69 - 3.24311120601988e+80*cos(theta)**67 + 1.89696266574337e+81*cos(theta)**65 - 7.03330186229272e+81*cos(theta)**63 + 1.85622142392671e+82*cos(theta)**61 - 3.71244284785343e+82*cos(theta)**59 + 5.8489776359827e+82*cos(theta)**57 - 7.45009441901707e+82*cos(theta)**55 + 7.8131286809607e+82*cos(theta)**53 - 6.83586750626276e+82*cos(theta)**51 + 5.03799483843064e+82*cos(theta)**49 - 3.14975115895504e+82*cos(theta)**47 + 1.67893540573491e+82*cos(theta)**45 - 7.65613105332825e+81*cos(theta)**43 + 2.99285122993741e+81*cos(theta)**41 - 1.00373742680927e+81*cos(theta)**39 + 2.8873037005655e+80*cos(theta)**37 - 7.11411122669856e+79*cos(theta)**35 + 1.49784012027093e+79*cos(theta)**33 - 2.68543152293056e+78*cos(theta)**31 + 4.0808028044533e+77*cos(theta)**29 - 5.22486893285412e+76*cos(theta)**27 + 5.59465831431298e+75*cos(theta)**25 - 4.96420436052616e+74*cos(theta)**23 + 3.60903362992275e+73*cos(theta)**21 - 2.11999178261197e+72*cos(theta)**19 + 9.88866870776449e+70*cos(theta)**17 - 3.58342377899273e+69*cos(theta)**15 + 9.80864173081951e+67*cos(theta)**13 - 1.95421214560389e+66*cos(theta)**11 + 2.69377614055674e+64*cos(theta)**9 - 2.38798180399021e+62*cos(theta)**7 + 1.21481632470432e+60*cos(theta)**5 - 2.89863117323866e+57*cos(theta)**3 + 2.04609259287435e+54*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl96_m28(theta, phi):
    return 2.24897563495054e-55*(1.0 - cos(theta)**2)**14*(1.82186541279352e+81*cos(theta)**68 - 2.17288450803332e+82*cos(theta)**66 + 1.23302573273319e+83*cos(theta)**64 - 4.43098017324441e+83*cos(theta)**62 + 1.13229506859529e+84*cos(theta)**60 - 2.19034128023352e+84*cos(theta)**58 + 3.33391725251014e+84*cos(theta)**56 - 4.09755193045939e+84*cos(theta)**54 + 4.14095820090917e+84*cos(theta)**52 - 3.48629242819401e+84*cos(theta)**50 + 2.46861747083102e+84*cos(theta)**48 - 1.48038304470887e+84*cos(theta)**46 + 7.55520932580711e+83*cos(theta)**44 - 3.29213635293115e+83*cos(theta)**42 + 1.22706900427434e+83*cos(theta)**40 - 3.91457596455617e+82*cos(theta)**38 + 1.06830236920923e+82*cos(theta)**36 - 2.4899389293445e+81*cos(theta)**34 + 4.94287239689406e+80*cos(theta)**32 - 8.32483772108474e+79*cos(theta)**30 + 1.18343281329146e+79*cos(theta)**28 - 1.41071461187061e+78*cos(theta)**26 + 1.39866457857825e+77*cos(theta)**24 - 1.14176700292102e+76*cos(theta)**22 + 7.57897062283778e+74*cos(theta)**20 - 4.02798438696274e+73*cos(theta)**18 + 1.68107368031996e+72*cos(theta)**16 - 5.37513566848909e+70*cos(theta)**14 + 1.27512342500654e+69*cos(theta)**12 - 2.14963336016428e+67*cos(theta)**10 + 2.42439852650106e+65*cos(theta)**8 - 1.67158726279315e+63*cos(theta)**6 + 6.07408162352162e+60*cos(theta)**4 - 8.69589351971599e+57*cos(theta)**2 + 2.04609259287435e+54)*cos(28*phi)

#@torch.jit.script
def Yl96_m29(theta, phi):
    return 2.43935657056412e-57*(1.0 - cos(theta)**2)**14.5*(1.23886848069959e+83*cos(theta)**67 - 1.43410377530199e+84*cos(theta)**65 + 7.89136468949243e+84*cos(theta)**63 - 2.74720770741153e+85*cos(theta)**61 + 6.79377041157177e+85*cos(theta)**59 - 1.27039794253544e+86*cos(theta)**57 + 1.86699366140568e+86*cos(theta)**55 - 2.21267804244807e+86*cos(theta)**53 + 2.15329826447277e+86*cos(theta)**51 - 1.743146214097e+86*cos(theta)**49 + 1.18493638599889e+86*cos(theta)**47 - 6.8097620056608e+85*cos(theta)**45 + 3.32429210335513e+85*cos(theta)**43 - 1.38269726823108e+85*cos(theta)**41 + 4.90827601709735e+84*cos(theta)**39 - 1.48753886653134e+84*cos(theta)**37 + 3.84588852915324e+83*cos(theta)**35 - 8.46579235977128e+82*cos(theta)**33 + 1.5817191670061e+82*cos(theta)**31 - 2.49745131632542e+81*cos(theta)**29 + 3.31361187721608e+80*cos(theta)**27 - 3.66785799086359e+79*cos(theta)**25 + 3.35679498858779e+78*cos(theta)**23 - 2.51188740642624e+77*cos(theta)**21 + 1.51579412456756e+76*cos(theta)**19 - 7.25037189653293e+74*cos(theta)**17 + 2.68971788851194e+73*cos(theta)**15 - 7.52518993588473e+71*cos(theta)**13 + 1.53014811000784e+70*cos(theta)**11 - 2.14963336016428e+68*cos(theta)**9 + 1.93951882120085e+66*cos(theta)**7 - 1.00295235767589e+64*cos(theta)**5 + 2.42963264940865e+61*cos(theta)**3 - 1.7391787039432e+58*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl96_m30(theta, phi):
    return 2.65492717982987e-59*(1.0 - cos(theta)**2)**15*(8.30041882068727e+84*cos(theta)**66 - 9.32167453946293e+85*cos(theta)**64 + 4.97155975438023e+86*cos(theta)**62 - 1.67579670152104e+87*cos(theta)**60 + 4.00832454282734e+87*cos(theta)**58 - 7.24126827245202e+87*cos(theta)**56 + 1.02684651377312e+88*cos(theta)**54 - 1.17271936249748e+88*cos(theta)**52 + 1.09818211488111e+88*cos(theta)**50 - 8.54141644907531e+87*cos(theta)**48 + 5.56920101419477e+87*cos(theta)**46 - 3.06439290254736e+87*cos(theta)**44 + 1.4294456044427e+87*cos(theta)**42 - 5.66905879974744e+86*cos(theta)**40 + 1.91422764666797e+86*cos(theta)**38 - 5.50389380616597e+85*cos(theta)**36 + 1.34606098520363e+85*cos(theta)**34 - 2.79371147872452e+84*cos(theta)**32 + 4.90332941771891e+83*cos(theta)**30 - 7.24260881734372e+82*cos(theta)**28 + 8.94675206848342e+81*cos(theta)**26 - 9.16964497715898e+80*cos(theta)**24 + 7.72062847375191e+79*cos(theta)**22 - 5.2749635534951e+78*cos(theta)**20 + 2.88000883667836e+77*cos(theta)**18 - 1.2325632224106e+76*cos(theta)**16 + 4.03457683276791e+74*cos(theta)**14 - 9.78274691665015e+72*cos(theta)**12 + 1.68316292100863e+71*cos(theta)**10 - 1.93467002414785e+69*cos(theta)**8 + 1.3576631748406e+67*cos(theta)**6 - 5.01476178837945e+64*cos(theta)**4 + 7.28889794822594e+61*cos(theta)**2 - 1.7391787039432e+58)*cos(30*phi)

#@torch.jit.script
def Yl96_m31(theta, phi):
    return 2.89987171122115e-61*(1.0 - cos(theta)**2)**15.5*(5.4782764216536e+86*cos(theta)**65 - 5.96587170525628e+87*cos(theta)**63 + 3.08236704771574e+88*cos(theta)**61 - 1.00547802091262e+89*cos(theta)**59 + 2.32482823483986e+89*cos(theta)**57 - 4.05511023257313e+89*cos(theta)**55 + 5.54497117437486e+89*cos(theta)**53 - 6.09814068498688e+89*cos(theta)**51 + 5.49091057440556e+89*cos(theta)**49 - 4.09987989555615e+89*cos(theta)**47 + 2.5618324665296e+89*cos(theta)**45 - 1.34833287712084e+89*cos(theta)**43 + 6.00367153865936e+88*cos(theta)**41 - 2.26762351989897e+88*cos(theta)**39 + 7.27406505733827e+87*cos(theta)**37 - 1.98140177021975e+87*cos(theta)**35 + 4.57660734969236e+86*cos(theta)**33 - 8.93987673191848e+85*cos(theta)**31 + 1.47099882531567e+85*cos(theta)**29 - 2.02793046885624e+84*cos(theta)**27 + 2.32615553780569e+83*cos(theta)**25 - 2.20071479451815e+82*cos(theta)**23 + 1.69853826422542e+81*cos(theta)**21 - 1.05499271069902e+80*cos(theta)**19 + 5.18401590602104e+78*cos(theta)**17 - 1.97210115585696e+77*cos(theta)**15 + 5.64840756587508e+75*cos(theta)**13 - 1.17392962999802e+74*cos(theta)**11 + 1.68316292100863e+72*cos(theta)**9 - 1.54773601931828e+70*cos(theta)**7 + 8.14597904904357e+67*cos(theta)**5 - 2.00590471535178e+65*cos(theta)**3 + 1.45777958964519e+62*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl96_m32(theta, phi):
    return 3.17919467411013e-63*(1.0 - cos(theta)**2)**16*(3.56087967407484e+88*cos(theta)**64 - 3.75849917431145e+89*cos(theta)**62 + 1.8802438991066e+90*cos(theta)**60 - 5.93232032338447e+90*cos(theta)**58 + 1.32515209385872e+91*cos(theta)**56 - 2.23031062791522e+91*cos(theta)**54 + 2.93883472241868e+91*cos(theta)**52 - 3.11005174934331e+91*cos(theta)**50 + 2.69054618145872e+91*cos(theta)**48 - 1.92694355091139e+91*cos(theta)**46 + 1.15282460993832e+91*cos(theta)**44 - 5.79783137161961e+90*cos(theta)**42 + 2.46150533085034e+90*cos(theta)**40 - 8.843731727606e+89*cos(theta)**38 + 2.69140407121516e+89*cos(theta)**36 - 6.93490619576912e+88*cos(theta)**34 + 1.51028042539848e+88*cos(theta)**32 - 2.77136178689473e+87*cos(theta)**30 + 4.26589659341545e+86*cos(theta)**28 - 5.47541226591185e+85*cos(theta)**26 + 5.81538884451422e+84*cos(theta)**24 - 5.06164402739175e+83*cos(theta)**22 + 3.56693035487338e+82*cos(theta)**20 - 2.00448615032814e+81*cos(theta)**18 + 8.81282704023577e+79*cos(theta)**16 - 2.95815173378543e+78*cos(theta)**14 + 7.3429298356376e+76*cos(theta)**12 - 1.29132259299782e+75*cos(theta)**10 + 1.51484662890777e+73*cos(theta)**8 - 1.0834152135228e+71*cos(theta)**6 + 4.07298952452179e+68*cos(theta)**4 - 6.01771414605534e+65*cos(theta)**2 + 1.45777958964519e+62)*cos(32*phi)

#@torch.jit.script
def Yl96_m33(theta, phi):
    return 3.49890604025733e-65*(1.0 - cos(theta)**2)**16.5*(2.2789629914079e+90*cos(theta)**63 - 2.3302694880731e+91*cos(theta)**61 + 1.12814633946396e+92*cos(theta)**59 - 3.44074578756299e+92*cos(theta)**57 + 7.42085172560883e+92*cos(theta)**55 - 1.20436773907422e+93*cos(theta)**53 + 1.52819405565771e+93*cos(theta)**51 - 1.55502587467165e+93*cos(theta)**49 + 1.29146216710019e+93*cos(theta)**47 - 8.8639403341924e+92*cos(theta)**45 + 5.0724282837286e+92*cos(theta)**43 - 2.43508917608024e+92*cos(theta)**41 + 9.84602132340135e+91*cos(theta)**39 - 3.36061805649028e+91*cos(theta)**37 + 9.68905465637458e+90*cos(theta)**35 - 2.3578681065615e+90*cos(theta)**33 + 4.83289736127513e+89*cos(theta)**31 - 8.31408536068418e+88*cos(theta)**29 + 1.19445104615633e+88*cos(theta)**27 - 1.42360718913708e+87*cos(theta)**25 + 1.39569332268341e+86*cos(theta)**23 - 1.11356168602619e+85*cos(theta)**21 + 7.13386070974677e+83*cos(theta)**19 - 3.60807507059065e+82*cos(theta)**17 + 1.41005232643772e+81*cos(theta)**15 - 4.14141242729961e+79*cos(theta)**13 + 8.81151580276512e+77*cos(theta)**11 - 1.29132259299782e+76*cos(theta)**9 + 1.21187730312621e+74*cos(theta)**7 - 6.50049128113677e+71*cos(theta)**5 + 1.62919580980871e+69*cos(theta)**3 - 1.20354282921107e+66*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl96_m34(theta, phi):
    return 3.86625352702393e-67*(1.0 - cos(theta)**2)**17*(1.43574668458698e+92*cos(theta)**62 - 1.42146438772459e+93*cos(theta)**60 + 6.65606340283737e+93*cos(theta)**58 - 1.96122509891091e+94*cos(theta)**56 + 4.08146844908486e+94*cos(theta)**54 - 6.38314901709337e+94*cos(theta)**52 + 7.79378968385433e+94*cos(theta)**50 - 7.61962678589111e+94*cos(theta)**48 + 6.06987218537088e+94*cos(theta)**46 - 3.98877315038658e+94*cos(theta)**44 + 2.1811441620033e+94*cos(theta)**42 - 9.98386562192897e+93*cos(theta)**40 + 3.83994831612653e+93*cos(theta)**38 - 1.2434286809014e+93*cos(theta)**36 + 3.3911691297311e+92*cos(theta)**34 - 7.78096475165296e+91*cos(theta)**32 + 1.49819818199529e+91*cos(theta)**30 - 2.41108475459841e+90*cos(theta)**28 + 3.22501782462208e+89*cos(theta)**26 - 3.5590179728427e+88*cos(theta)**24 + 3.21009464217185e+87*cos(theta)**22 - 2.33847954065499e+86*cos(theta)**20 + 1.35543353485189e+85*cos(theta)**18 - 6.1337276200041e+83*cos(theta)**16 + 2.11507848965659e+82*cos(theta)**14 - 5.38383615548949e+80*cos(theta)**12 + 9.69266738304164e+78*cos(theta)**10 - 1.16219033369804e+77*cos(theta)**8 + 8.48314112188349e+74*cos(theta)**6 - 3.25024564056839e+72*cos(theta)**4 + 4.88758742942614e+69*cos(theta)**2 - 1.20354282921107e+66)*cos(34*phi)

#@torch.jit.script
def Yl96_m35(theta, phi):
    return 4.29001525613128e-69*(1.0 - cos(theta)**2)**17.5*(8.90162944443925e+93*cos(theta)**61 - 8.52878632634755e+94*cos(theta)**59 + 3.86051677364568e+95*cos(theta)**57 - 1.09828605539011e+96*cos(theta)**55 + 2.20399296250582e+96*cos(theta)**53 - 3.31923748888855e+96*cos(theta)**51 + 3.89689484192717e+96*cos(theta)**49 - 3.65742085722773e+96*cos(theta)**47 + 2.79214120527061e+96*cos(theta)**45 - 1.75506018617009e+96*cos(theta)**43 + 9.16080548041385e+95*cos(theta)**41 - 3.99354624877159e+95*cos(theta)**39 + 1.45918036012808e+95*cos(theta)**37 - 4.47634325124505e+94*cos(theta)**35 + 1.15299750410857e+94*cos(theta)**33 - 2.48990872052895e+93*cos(theta)**31 + 4.49459454598587e+92*cos(theta)**29 - 6.75103731287556e+91*cos(theta)**27 + 8.38504634401741e+90*cos(theta)**25 - 8.54164313482249e+89*cos(theta)**23 + 7.06220821277807e+88*cos(theta)**21 - 4.67695908130998e+87*cos(theta)**19 + 2.43978036273339e+86*cos(theta)**17 - 9.81396419200656e+84*cos(theta)**15 + 2.96110988551922e+83*cos(theta)**13 - 6.46060338658739e+81*cos(theta)**11 + 9.69266738304164e+79*cos(theta)**9 - 9.2975226695843e+77*cos(theta)**7 + 5.08988467313009e+75*cos(theta)**5 - 1.30009825622735e+73*cos(theta)**3 + 9.77517485885229e+69*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl96_m36(theta, phi):
    return 4.78087020767889e-71*(1.0 - cos(theta)**2)**18*(5.42999396110794e+95*cos(theta)**60 - 5.03198393254505e+96*cos(theta)**58 + 2.20049456097804e+97*cos(theta)**56 - 6.04057330464559e+97*cos(theta)**54 + 1.16811627012809e+98*cos(theta)**52 - 1.69281111933316e+98*cos(theta)**50 + 1.90947847254431e+98*cos(theta)**48 - 1.71898780289703e+98*cos(theta)**46 + 1.25646354237177e+98*cos(theta)**44 - 7.54675880053141e+97*cos(theta)**42 + 3.75593024696968e+97*cos(theta)**40 - 1.55748303702092e+97*cos(theta)**38 + 5.39896733247389e+96*cos(theta)**36 - 1.56672013793577e+96*cos(theta)**34 + 3.8048917635583e+95*cos(theta)**32 - 7.71871703363973e+94*cos(theta)**30 + 1.3034324183359e+94*cos(theta)**28 - 1.8227800744764e+93*cos(theta)**26 + 2.09626158600435e+92*cos(theta)**24 - 1.96457792100917e+91*cos(theta)**22 + 1.48306372468339e+90*cos(theta)**20 - 8.88622225448896e+88*cos(theta)**18 + 4.14762661664677e+87*cos(theta)**16 - 1.47209462880098e+86*cos(theta)**14 + 3.84944285117499e+84*cos(theta)**12 - 7.10666372524613e+82*cos(theta)**10 + 8.72340064473747e+80*cos(theta)**8 - 6.50826586870901e+78*cos(theta)**6 + 2.54494233656505e+76*cos(theta)**4 - 3.90029476868206e+73*cos(theta)**2 + 9.77517485885229e+69)*cos(36*phi)

#@torch.jit.script
def Yl96_m37(theta, phi):
    return 5.35186941113327e-73*(1.0 - cos(theta)**2)**18.5*(3.25799637666476e+97*cos(theta)**59 - 2.91855068087613e+98*cos(theta)**57 + 1.2322769541477e+99*cos(theta)**55 - 3.26190958450862e+99*cos(theta)**53 + 6.07420460466605e+99*cos(theta)**51 - 8.4640555966658e+99*cos(theta)**49 + 9.16549666821269e+99*cos(theta)**47 - 7.90734389332635e+99*cos(theta)**45 + 5.5284395864358e+99*cos(theta)**43 - 3.16963869622319e+99*cos(theta)**41 + 1.50237209878787e+99*cos(theta)**39 - 5.91843554067949e+98*cos(theta)**37 + 1.9436282396906e+98*cos(theta)**35 - 5.32684846898161e+97*cos(theta)**33 + 1.21756536433865e+97*cos(theta)**31 - 2.31561511009192e+96*cos(theta)**29 + 3.64961077134053e+95*cos(theta)**27 - 4.73922819363864e+94*cos(theta)**25 + 5.03102780641045e+93*cos(theta)**23 - 4.32207142622018e+92*cos(theta)**21 + 2.96612744936679e+91*cos(theta)**19 - 1.59952000580801e+90*cos(theta)**17 + 6.63620258663483e+88*cos(theta)**15 - 2.06093248032138e+87*cos(theta)**13 + 4.61933142140998e+85*cos(theta)**11 - 7.10666372524613e+83*cos(theta)**9 + 6.97872051578998e+81*cos(theta)**7 - 3.90495952122541e+79*cos(theta)**5 + 1.01797693462602e+77*cos(theta)**3 - 7.80058953736413e+73*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl96_m38(theta, phi):
    return 6.01903824490719e-75*(1.0 - cos(theta)**2)**19*(1.92221786223221e+99*cos(theta)**58 - 1.66357388809939e+100*cos(theta)**56 + 6.77752324781235e+100*cos(theta)**54 - 1.72881207978957e+101*cos(theta)**52 + 3.09784434837968e+101*cos(theta)**50 - 4.14738724236624e+101*cos(theta)**48 + 4.30778343405997e+101*cos(theta)**46 - 3.55830475199686e+101*cos(theta)**44 + 2.37722902216739e+101*cos(theta)**42 - 1.29955186545151e+101*cos(theta)**40 + 5.8592511852727e+100*cos(theta)**38 - 2.18982115005141e+100*cos(theta)**36 + 6.80269883891711e+99*cos(theta)**34 - 1.75785999476393e+99*cos(theta)**32 + 3.77445262944983e+98*cos(theta)**30 - 6.71528381926657e+97*cos(theta)**28 + 9.85394908261942e+96*cos(theta)**26 - 1.18480704840966e+96*cos(theta)**24 + 1.1571363954744e+95*cos(theta)**22 - 9.07634999506238e+93*cos(theta)**20 + 5.6356421537969e+92*cos(theta)**18 - 2.71918400987362e+91*cos(theta)**16 + 9.95430387995225e+89*cos(theta)**14 - 2.67921222441779e+88*cos(theta)**12 + 5.08126456355098e+86*cos(theta)**10 - 6.39599735272151e+84*cos(theta)**8 + 4.88510436105298e+82*cos(theta)**6 - 1.9524797606127e+80*cos(theta)**4 + 3.05393080387806e+77*cos(theta)**2 - 7.80058953736413e+73)*cos(38*phi)

#@torch.jit.script
def Yl96_m39(theta, phi):
    return 6.80215026794904e-77*(1.0 - cos(theta)**2)**19.5*(1.11488636009468e+101*cos(theta)**57 - 9.31601377335661e+101*cos(theta)**55 + 3.65986255381867e+102*cos(theta)**53 - 8.98982281490575e+102*cos(theta)**51 + 1.54892217418984e+103*cos(theta)**49 - 1.9907458763358e+103*cos(theta)**47 + 1.98158037966758e+103*cos(theta)**45 - 1.56565409087862e+103*cos(theta)**43 + 9.98436189310305e+102*cos(theta)**41 - 5.19820746180603e+102*cos(theta)**39 + 2.22651545040362e+102*cos(theta)**37 - 7.88335614018508e+101*cos(theta)**35 + 2.31291760523182e+101*cos(theta)**33 - 5.62515198324458e+100*cos(theta)**31 + 1.13233578883495e+100*cos(theta)**29 - 1.88027946939464e+99*cos(theta)**27 + 2.56202676148105e+98*cos(theta)**25 - 2.84353691618318e+97*cos(theta)**23 + 2.54570007004369e+96*cos(theta)**21 - 1.81526999901248e+95*cos(theta)**19 + 1.01441558768344e+94*cos(theta)**17 - 4.3506944157978e+92*cos(theta)**15 + 1.39360254319332e+91*cos(theta)**13 - 3.21505466930135e+89*cos(theta)**11 + 5.08126456355098e+87*cos(theta)**9 - 5.11679788217721e+85*cos(theta)**7 + 2.93106261663179e+83*cos(theta)**5 - 7.80991904245081e+80*cos(theta)**3 + 6.10786160775611e+77*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl96_m40(theta, phi):
    return 7.72572668236375e-79*(1.0 - cos(theta)**2)**20*(6.35485225253969e+102*cos(theta)**56 - 5.12380757534614e+103*cos(theta)**54 + 1.93972715352389e+104*cos(theta)**52 - 4.58480963560193e+104*cos(theta)**50 + 7.58971865353023e+104*cos(theta)**48 - 9.35650561877825e+104*cos(theta)**46 + 8.91711170850413e+104*cos(theta)**44 - 6.73231259077806e+104*cos(theta)**42 + 4.09358837617225e+104*cos(theta)**40 - 2.02730091010435e+104*cos(theta)**38 + 8.23810716649341e+103*cos(theta)**36 - 2.75917464906478e+103*cos(theta)**34 + 7.63262809726499e+102*cos(theta)**32 - 1.74379711480582e+102*cos(theta)**30 + 3.28377378762135e+101*cos(theta)**28 - 5.07675456736553e+100*cos(theta)**26 + 6.40506690370262e+99*cos(theta)**24 - 6.54013490722132e+98*cos(theta)**22 + 5.34597014709174e+97*cos(theta)**20 - 3.4490129981237e+96*cos(theta)**18 + 1.72450649906185e+95*cos(theta)**16 - 6.52604162369669e+93*cos(theta)**14 + 1.81168330615131e+92*cos(theta)**12 - 3.53656013623148e+90*cos(theta)**10 + 4.57313810719588e+88*cos(theta)**8 - 3.58175851752405e+86*cos(theta)**6 + 1.4655313083159e+84*cos(theta)**4 - 2.34297571273524e+81*cos(theta)**2 + 6.10786160775611e+77)*cos(40*phi)

#@torch.jit.script
def Yl96_m41(theta, phi):
    return 8.8203342398957e-81*(1.0 - cos(theta)**2)**20.5*(3.55871726142223e+104*cos(theta)**55 - 2.76685609068691e+105*cos(theta)**53 + 1.00865811983243e+106*cos(theta)**51 - 2.29240481780097e+106*cos(theta)**49 + 3.64306495369451e+106*cos(theta)**47 - 4.30399258463799e+106*cos(theta)**45 + 3.92352915174182e+106*cos(theta)**43 - 2.82757128812678e+106*cos(theta)**41 + 1.6374353504689e+106*cos(theta)**39 - 7.70374345839654e+105*cos(theta)**37 + 2.96571857993763e+105*cos(theta)**35 - 9.38119380682025e+104*cos(theta)**33 + 2.4424409911248e+104*cos(theta)**31 - 5.23139134441746e+103*cos(theta)**29 + 9.19456660533978e+102*cos(theta)**27 - 1.31995618751504e+102*cos(theta)**25 + 1.53721605688863e+101*cos(theta)**23 - 1.43882967958869e+100*cos(theta)**21 + 1.06919402941835e+99*cos(theta)**19 - 6.20822339662267e+97*cos(theta)**17 + 2.75921039849896e+96*cos(theta)**15 - 9.13645827317537e+94*cos(theta)**13 + 2.17401996738157e+93*cos(theta)**11 - 3.53656013623148e+91*cos(theta)**9 + 3.65851048575671e+89*cos(theta)**7 - 2.14905511051443e+87*cos(theta)**5 + 5.86212523326358e+84*cos(theta)**3 - 4.68595142547049e+81*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl96_m42(theta, phi):
    return 1.01242801662482e-82*(1.0 - cos(theta)**2)**21*(1.95729449378222e+106*cos(theta)**54 - 1.46643372806406e+107*cos(theta)**52 + 5.14415641114537e+107*cos(theta)**50 - 1.12327836072247e+108*cos(theta)**48 + 1.71224052823642e+108*cos(theta)**46 - 1.9367966630871e+108*cos(theta)**44 + 1.68711753524898e+108*cos(theta)**42 - 1.15930422813198e+108*cos(theta)**40 + 6.38599786682871e+107*cos(theta)**38 - 2.85038507960672e+107*cos(theta)**36 + 1.03800150297817e+107*cos(theta)**34 - 3.09579395625068e+106*cos(theta)**32 + 7.57156707248687e+105*cos(theta)**30 - 1.51710348988106e+105*cos(theta)**28 + 2.48253298344174e+104*cos(theta)**26 - 3.29989046878759e+103*cos(theta)**24 + 3.53559693084385e+102*cos(theta)**22 - 3.02154232713625e+101*cos(theta)**20 + 2.03146865589486e+100*cos(theta)**18 - 1.05539797742585e+99*cos(theta)**16 + 4.13881559774844e+97*cos(theta)**14 - 1.1877395755128e+96*cos(theta)**12 + 2.39142196411973e+94*cos(theta)**10 - 3.18290412260833e+92*cos(theta)**8 + 2.56095734002969e+90*cos(theta)**6 - 1.07452755525721e+88*cos(theta)**4 + 1.75863756997907e+85*cos(theta)**2 - 4.68595142547049e+81)*cos(42*phi)

#@torch.jit.script
def Yl96_m43(theta, phi):
    return 1.16858383578193e-84*(1.0 - cos(theta)**2)**21.5*(1.0569390266424e+108*cos(theta)**53 - 7.62545538593313e+108*cos(theta)**51 + 2.57207820557268e+109*cos(theta)**49 - 5.39173613146787e+109*cos(theta)**47 + 7.87630642988753e+109*cos(theta)**45 - 8.52190531758323e+109*cos(theta)**43 + 7.08589364804572e+109*cos(theta)**41 - 4.63721691252793e+109*cos(theta)**39 + 2.42667918939491e+109*cos(theta)**37 - 1.02613862865842e+109*cos(theta)**35 + 3.52920511012578e+108*cos(theta)**33 - 9.90654066000218e+107*cos(theta)**31 + 2.27147012174606e+107*cos(theta)**29 - 4.24788977166698e+106*cos(theta)**27 + 6.45458575694853e+105*cos(theta)**25 - 7.91973712509022e+104*cos(theta)**23 + 7.77831324785646e+103*cos(theta)**21 - 6.0430846542725e+102*cos(theta)**19 + 3.65664358061075e+101*cos(theta)**17 - 1.68863676388137e+100*cos(theta)**15 + 5.79434183684782e+98*cos(theta)**13 - 1.42528749061536e+97*cos(theta)**11 + 2.39142196411973e+95*cos(theta)**9 - 2.54632329808667e+93*cos(theta)**7 + 1.53657440401782e+91*cos(theta)**5 - 4.29811022102886e+88*cos(theta)**3 + 3.51727513995815e+85*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl96_m44(theta, phi):
    return 1.35661908383044e-86*(1.0 - cos(theta)**2)**22*(5.60177684120473e+109*cos(theta)**52 - 3.8889822468259e+110*cos(theta)**50 + 1.26031832073062e+111*cos(theta)**48 - 2.5341159817899e+111*cos(theta)**46 + 3.54433789344939e+111*cos(theta)**44 - 3.66441928656079e+111*cos(theta)**42 + 2.90521639569875e+111*cos(theta)**40 - 1.80851459588589e+111*cos(theta)**38 + 8.97871300076117e+110*cos(theta)**36 - 3.59148520030447e+110*cos(theta)**34 + 1.16463768634151e+110*cos(theta)**32 - 3.07102760460068e+109*cos(theta)**30 + 6.58726335306358e+108*cos(theta)**28 - 1.14693023835008e+108*cos(theta)**26 + 1.61364643923713e+107*cos(theta)**24 - 1.82153953877075e+106*cos(theta)**22 + 1.63344578204986e+105*cos(theta)**20 - 1.14818608431178e+104*cos(theta)**18 + 6.21629408703828e+102*cos(theta)**16 - 2.53295514582205e+101*cos(theta)**14 + 7.53264438790217e+99*cos(theta)**12 - 1.56781623967689e+98*cos(theta)**10 + 2.15227976770776e+96*cos(theta)**8 - 1.78242630866067e+94*cos(theta)**6 + 7.68287202008908e+91*cos(theta)**4 - 1.28943306630866e+89*cos(theta)**2 + 3.51727513995815e+85)*cos(44*phi)

#@torch.jit.script
def Yl96_m45(theta, phi):
    return 1.58433382348208e-88*(1.0 - cos(theta)**2)**22.5*(2.91292395742646e+111*cos(theta)**51 - 1.94449112341295e+112*cos(theta)**49 + 6.04952793950695e+112*cos(theta)**47 - 1.16569335162335e+113*cos(theta)**45 + 1.55950867311773e+113*cos(theta)**43 - 1.53905610035553e+113*cos(theta)**41 + 1.1620865582795e+113*cos(theta)**39 - 6.87235546436639e+112*cos(theta)**37 + 3.23233668027402e+112*cos(theta)**35 - 1.22110496810352e+112*cos(theta)**33 + 3.72684059629282e+111*cos(theta)**31 - 9.21308281380203e+110*cos(theta)**29 + 1.8444337388578e+110*cos(theta)**27 - 2.98201861971022e+109*cos(theta)**25 + 3.87275145416912e+108*cos(theta)**23 - 4.00738698529565e+107*cos(theta)**21 + 3.26689156409972e+106*cos(theta)**19 - 2.0667349517612e+105*cos(theta)**17 + 9.94607053926124e+103*cos(theta)**15 - 3.54613720415087e+102*cos(theta)**13 + 9.0391732654826e+100*cos(theta)**11 - 1.56781623967689e+99*cos(theta)**9 + 1.7218238141662e+97*cos(theta)**7 - 1.0694557851964e+95*cos(theta)**5 + 3.07314880803563e+92*cos(theta)**3 - 2.57886613261731e+89*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl96_m46(theta, phi):
    return 1.86173315785279e-90*(1.0 - cos(theta)**2)**23*(1.48559121828749e+113*cos(theta)**50 - 9.52800650472345e+113*cos(theta)**48 + 2.84327813156827e+114*cos(theta)**46 - 5.24562008230509e+114*cos(theta)**44 + 6.70588729440624e+114*cos(theta)**42 - 6.31013001145768e+114*cos(theta)**40 + 4.53213757729004e+114*cos(theta)**38 - 2.54277152181556e+114*cos(theta)**36 + 1.13131783809591e+114*cos(theta)**34 - 4.02964639474161e+113*cos(theta)**32 + 1.15532058485077e+113*cos(theta)**30 - 2.67179401600259e+112*cos(theta)**28 + 4.97997109491607e+111*cos(theta)**26 - 7.45504654927555e+110*cos(theta)**24 + 8.90732834458897e+109*cos(theta)**22 - 8.41551266912087e+108*cos(theta)**20 + 6.20709397178946e+107*cos(theta)**18 - 3.51344941799403e+106*cos(theta)**16 + 1.49191058088919e+105*cos(theta)**14 - 4.60997836539613e+103*cos(theta)**12 + 9.94309059203086e+101*cos(theta)**10 - 1.4110346157092e+100*cos(theta)**8 + 1.20527666991634e+98*cos(theta)**6 - 5.347278925982e+95*cos(theta)**4 + 9.2194464241069e+92*cos(theta)**2 - 2.57886613261731e+89)*cos(46*phi)

#@torch.jit.script
def Yl96_m47(theta, phi):
    return 2.20173178852451e-92*(1.0 - cos(theta)**2)**23.5*(7.42795609143747e+114*cos(theta)**49 - 4.57344312226726e+115*cos(theta)**47 + 1.3079079405214e+116*cos(theta)**45 - 2.30807283621424e+116*cos(theta)**43 + 2.81647266365062e+116*cos(theta)**41 - 2.52405200458307e+116*cos(theta)**39 + 1.72221227937022e+116*cos(theta)**37 - 9.15397747853603e+115*cos(theta)**35 + 3.84648064952608e+115*cos(theta)**33 - 1.28948684631732e+115*cos(theta)**31 + 3.46596175455232e+114*cos(theta)**29 - 7.48102324480725e+113*cos(theta)**27 + 1.29479248467818e+113*cos(theta)**25 - 1.78921117182613e+112*cos(theta)**23 + 1.95961223580957e+111*cos(theta)**21 - 1.68310253382417e+110*cos(theta)**19 + 1.1172769149221e+109*cos(theta)**17 - 5.62151906879045e+107*cos(theta)**15 + 2.08867481324486e+106*cos(theta)**13 - 5.53197403847535e+104*cos(theta)**11 + 9.94309059203086e+102*cos(theta)**9 - 1.12882769256736e+101*cos(theta)**7 + 7.23166001949806e+98*cos(theta)**5 - 2.1389115703928e+96*cos(theta)**3 + 1.84388928482138e+93*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl96_m48(theta, phi):
    return 2.62110927205299e-94*(1.0 - cos(theta)**2)**24*(3.63969848480436e+116*cos(theta)**48 - 2.14951826746561e+117*cos(theta)**46 + 5.88558573234631e+117*cos(theta)**44 - 9.92471319572124e+117*cos(theta)**42 + 1.15475379209675e+118*cos(theta)**40 - 9.84380281787397e+117*cos(theta)**38 + 6.3721854336698e+117*cos(theta)**36 - 3.20389211748761e+117*cos(theta)**34 + 1.26933861434361e+117*cos(theta)**32 - 3.99740922358368e+116*cos(theta)**30 + 1.00512890882017e+116*cos(theta)**28 - 2.01987627609796e+115*cos(theta)**26 + 3.23698121169544e+114*cos(theta)**24 - 4.1151856952001e+113*cos(theta)**22 + 4.1151856952001e+112*cos(theta)**20 - 3.19789481426593e+111*cos(theta)**18 + 1.89937075536757e+110*cos(theta)**16 - 8.43227860318568e+108*cos(theta)**14 + 2.71527725721832e+107*cos(theta)**12 - 6.08517144232289e+105*cos(theta)**10 + 8.94878153282778e+103*cos(theta)**8 - 7.90179384797155e+101*cos(theta)**6 + 3.61583000974903e+99*cos(theta)**4 - 6.4167347111784e+96*cos(theta)**2 + 1.84388928482138e+93)*cos(48*phi)

#@torch.jit.script
def Yl96_m49(theta, phi):
    return 3.14181426283119e-96*(1.0 - cos(theta)**2)**24.5*(1.74705527270609e+118*cos(theta)**47 - 9.88778403034181e+118*cos(theta)**45 + 2.58965772223238e+119*cos(theta)**43 - 4.16837954220292e+119*cos(theta)**41 + 4.61901516838702e+119*cos(theta)**39 - 3.74064507079211e+119*cos(theta)**37 + 2.29398675612113e+119*cos(theta)**35 - 1.08932331994579e+119*cos(theta)**33 + 4.06188356589955e+118*cos(theta)**31 - 1.1992227670751e+118*cos(theta)**29 + 2.81436094469649e+117*cos(theta)**27 - 5.25167831785469e+116*cos(theta)**25 + 7.76875490806907e+115*cos(theta)**23 - 9.05340852944023e+114*cos(theta)**21 + 8.23037139040021e+113*cos(theta)**19 - 5.75621066567867e+112*cos(theta)**17 + 3.03899320858812e+111*cos(theta)**15 - 1.180519004446e+110*cos(theta)**13 + 3.25833270866198e+108*cos(theta)**11 - 6.08517144232289e+106*cos(theta)**9 + 7.15902522626222e+104*cos(theta)**7 - 4.74107630878293e+102*cos(theta)**5 + 1.44633200389961e+100*cos(theta)**3 - 1.28334694223568e+97*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl96_m50(theta, phi):
    return 3.79275814837856e-98*(1.0 - cos(theta)**2)**25*(8.21115978171863e+119*cos(theta)**46 - 4.44950281365381e+120*cos(theta)**44 + 1.11355282055992e+121*cos(theta)**42 - 1.7090356123032e+121*cos(theta)**40 + 1.80141591567094e+121*cos(theta)**38 - 1.38403867619308e+121*cos(theta)**36 + 8.02895364642395e+120*cos(theta)**34 - 3.5947669558211e+120*cos(theta)**32 + 1.25918390542886e+120*cos(theta)**30 - 3.4777460245178e+119*cos(theta)**28 + 7.59877455068051e+118*cos(theta)**26 - 1.31291957946367e+118*cos(theta)**24 + 1.78681362885589e+117*cos(theta)**22 - 1.90121579118245e+116*cos(theta)**20 + 1.56377056417604e+115*cos(theta)**18 - 9.78555813165374e+113*cos(theta)**16 + 4.55848981288218e+112*cos(theta)**14 - 1.53467470577979e+111*cos(theta)**12 + 3.58416597952818e+109*cos(theta)**10 - 5.4766542980906e+107*cos(theta)**8 + 5.01131765838355e+105*cos(theta)**6 - 2.37053815439146e+103*cos(theta)**4 + 4.33899601169884e+100*cos(theta)**2 - 1.28334694223568e+97)*cos(50*phi)

#@torch.jit.script
def Yl96_m51(theta, phi):
    return 4.61230020485101e-100*(1.0 - cos(theta)**2)**25.5*(3.77713349959057e+121*cos(theta)**45 - 1.95778123800768e+122*cos(theta)**43 + 4.67692184635168e+122*cos(theta)**41 - 6.83614244921279e+122*cos(theta)**39 + 6.84538047954956e+122*cos(theta)**37 - 4.98253923429509e+122*cos(theta)**35 + 2.72984423978414e+122*cos(theta)**33 - 1.15032542586275e+122*cos(theta)**31 + 3.77755171628658e+121*cos(theta)**29 - 9.73768886864984e+120*cos(theta)**27 + 1.97568138317693e+120*cos(theta)**25 - 3.15100699071281e+119*cos(theta)**23 + 3.93098998348295e+118*cos(theta)**21 - 3.8024315823649e+117*cos(theta)**19 + 2.81478701551687e+116*cos(theta)**17 - 1.5656893010646e+115*cos(theta)**15 + 6.38188573803505e+113*cos(theta)**13 - 1.84160964693575e+112*cos(theta)**11 + 3.58416597952818e+110*cos(theta)**9 - 4.38132343847248e+108*cos(theta)**7 + 3.00679059503013e+106*cos(theta)**5 - 9.48215261756586e+103*cos(theta)**3 + 8.67799202339767e+100*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl96_m52(theta, phi):
    return 5.65171758682122e-102*(1.0 - cos(theta)**2)**26*(1.69971007481576e+123*cos(theta)**44 - 8.41845932343302e+123*cos(theta)**42 + 1.91753795700419e+124*cos(theta)**40 - 2.66609555519299e+124*cos(theta)**38 + 2.53279077743334e+124*cos(theta)**36 - 1.74388873200328e+124*cos(theta)**34 + 9.00848599128767e+123*cos(theta)**32 - 3.56600882017453e+123*cos(theta)**30 + 1.09548999772311e+123*cos(theta)**28 - 2.62917599453546e+122*cos(theta)**26 + 4.93920345794233e+121*cos(theta)**24 - 7.24731607863947e+120*cos(theta)**22 + 8.25507896531419e+119*cos(theta)**20 - 7.2246200064933e+118*cos(theta)**18 + 4.78513792637868e+117*cos(theta)**16 - 2.3485339515969e+116*cos(theta)**14 + 8.29645145944557e+114*cos(theta)**12 - 2.02577061162933e+113*cos(theta)**10 + 3.22574938157536e+111*cos(theta)**8 - 3.06692640693074e+109*cos(theta)**6 + 1.50339529751507e+107*cos(theta)**4 - 2.84464578526976e+104*cos(theta)**2 + 8.67799202339767e+100)*cos(52*phi)

#@torch.jit.script
def Yl96_m53(theta, phi):
    return 6.98008931602214e-104*(1.0 - cos(theta)**2)**26.5*(7.47872432918933e+124*cos(theta)**43 - 3.53575291584187e+125*cos(theta)**41 + 7.67015182801675e+125*cos(theta)**39 - 1.01311631097334e+126*cos(theta)**37 + 9.11804679876002e+125*cos(theta)**35 - 5.92922168881116e+125*cos(theta)**33 + 2.88271551721205e+125*cos(theta)**31 - 1.06980264605236e+125*cos(theta)**29 + 3.0673719936247e+124*cos(theta)**27 - 6.83585758579219e+123*cos(theta)**25 + 1.18540882990616e+123*cos(theta)**23 - 1.59440953730068e+122*cos(theta)**21 + 1.65101579306284e+121*cos(theta)**19 - 1.30043160116879e+120*cos(theta)**17 + 7.65622068220589e+118*cos(theta)**15 - 3.28794753223566e+117*cos(theta)**13 + 9.95574175133468e+115*cos(theta)**11 - 2.02577061162933e+114*cos(theta)**9 + 2.58059950526029e+112*cos(theta)**7 - 1.84015584415844e+110*cos(theta)**5 + 6.01358119006027e+107*cos(theta)**3 - 5.68929157053951e+104*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl96_m54(theta, phi):
    return 8.69122758830419e-106*(1.0 - cos(theta)**2)**27*(3.21585146155141e+126*cos(theta)**42 - 1.44965869549517e+127*cos(theta)**40 + 2.99135921292653e+127*cos(theta)**38 - 3.74853035060134e+127*cos(theta)**36 + 3.19131637956601e+127*cos(theta)**34 - 1.95664315730768e+127*cos(theta)**32 + 8.93641810335737e+126*cos(theta)**30 - 3.10242767355184e+126*cos(theta)**28 + 8.28190438278669e+125*cos(theta)**26 - 1.70896439644805e+125*cos(theta)**24 + 2.72644030878417e+124*cos(theta)**22 - 3.34826002833143e+123*cos(theta)**20 + 3.13693000681939e+122*cos(theta)**18 - 2.21073372198695e+121*cos(theta)**16 + 1.14843310233088e+120*cos(theta)**14 - 4.27433179190635e+118*cos(theta)**12 + 1.09513159264681e+117*cos(theta)**10 - 1.82319355046639e+115*cos(theta)**8 + 1.8064196536822e+113*cos(theta)**6 - 9.20077922079221e+110*cos(theta)**4 + 1.80407435701808e+108*cos(theta)**2 - 5.68929157053951e+104)*cos(54*phi)

#@torch.jit.script
def Yl96_m55(theta, phi):
    return 1.0913599282954e-107*(1.0 - cos(theta)**2)**27.5*(1.35065761385159e+128*cos(theta)**41 - 5.79863478198066e+128*cos(theta)**39 + 1.13671650091208e+129*cos(theta)**37 - 1.34947092621648e+129*cos(theta)**35 + 1.08504756905244e+129*cos(theta)**33 - 6.26125810338458e+128*cos(theta)**31 + 2.68092543100721e+128*cos(theta)**29 - 8.68679748594515e+127*cos(theta)**27 + 2.15329513952454e+127*cos(theta)**25 - 4.10151455147531e+126*cos(theta)**23 + 5.99816867932517e+125*cos(theta)**21 - 6.69652005666287e+124*cos(theta)**19 + 5.6464740122749e+123*cos(theta)**17 - 3.53717395517912e+122*cos(theta)**15 + 1.60780634326324e+121*cos(theta)**13 - 5.12919815028763e+119*cos(theta)**11 + 1.09513159264681e+118*cos(theta)**9 - 1.45855484037312e+116*cos(theta)**7 + 1.08385179220932e+114*cos(theta)**5 - 3.68031168831688e+111*cos(theta)**3 + 3.60814871403616e+108*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl96_m56(theta, phi):
    return 1.38246543381318e-109*(1.0 - cos(theta)**2)**28*(5.53769621679153e+129*cos(theta)**40 - 2.26146756497246e+130*cos(theta)**38 + 4.2058510533747e+130*cos(theta)**36 - 4.72314824175769e+130*cos(theta)**34 + 3.58065697787306e+130*cos(theta)**32 - 1.94099001204922e+130*cos(theta)**30 + 7.77468374992091e+129*cos(theta)**28 - 2.34543532120519e+129*cos(theta)**26 + 5.38323784881135e+128*cos(theta)**24 - 9.43348346839322e+127*cos(theta)**22 + 1.25961542265829e+127*cos(theta)**20 - 1.27233881076595e+126*cos(theta)**18 + 9.59900582086734e+124*cos(theta)**16 - 5.30576093276868e+123*cos(theta)**14 + 2.09014824624221e+122*cos(theta)**12 - 5.64211796531639e+120*cos(theta)**10 + 9.85618433382133e+118*cos(theta)**8 - 1.02098838826118e+117*cos(theta)**6 + 5.41925896104661e+114*cos(theta)**4 - 1.10409350649506e+112*cos(theta)**2 + 3.60814871403616e+108)*cos(56*phi)

#@torch.jit.script
def Yl96_m57(theta, phi):
    return 1.76717097671067e-111*(1.0 - cos(theta)**2)**28.5*(2.21507848671661e+131*cos(theta)**39 - 8.59357674689534e+131*cos(theta)**37 + 1.51410637921489e+132*cos(theta)**35 - 1.60587040219761e+132*cos(theta)**33 + 1.14581023291938e+132*cos(theta)**31 - 5.82297003614766e+131*cos(theta)**29 + 2.17691144997786e+131*cos(theta)**27 - 6.0981318351335e+130*cos(theta)**25 + 1.29197708371472e+130*cos(theta)**23 - 2.07536636304651e+129*cos(theta)**21 + 2.51923084531657e+128*cos(theta)**19 - 2.2902098593787e+127*cos(theta)**17 + 1.53584093133877e+126*cos(theta)**15 - 7.42806530587615e+124*cos(theta)**13 + 2.50817789549065e+123*cos(theta)**11 - 5.64211796531639e+121*cos(theta)**9 + 7.88494746705706e+119*cos(theta)**7 - 6.12593032956709e+117*cos(theta)**5 + 2.16770358441864e+115*cos(theta)**3 - 2.20818701299013e+112*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl96_m58(theta, phi):
    return 2.28026807175571e-113*(1.0 - cos(theta)**2)**29*(8.63880609819479e+132*cos(theta)**38 - 3.17962339635128e+133*cos(theta)**36 + 5.29937232725213e+133*cos(theta)**34 - 5.29937232725213e+133*cos(theta)**32 + 3.55201172205007e+133*cos(theta)**30 - 1.68866131048282e+133*cos(theta)**28 + 5.87766091494021e+132*cos(theta)**26 - 1.52453295878337e+132*cos(theta)**24 + 2.97154729254387e+131*cos(theta)**22 - 4.35826936239767e+130*cos(theta)**20 + 4.78653860610149e+129*cos(theta)**18 - 3.89335676094379e+128*cos(theta)**16 + 2.30376139700816e+127*cos(theta)**14 - 9.656484897639e+125*cos(theta)**12 + 2.75899568503971e+124*cos(theta)**10 - 5.07790616878475e+122*cos(theta)**8 + 5.51946322693995e+120*cos(theta)**6 - 3.06296516478354e+118*cos(theta)**4 + 6.50311075325593e+115*cos(theta)**2 - 2.20818701299013e+112)*cos(58*phi)

#@torch.jit.script
def Yl96_m59(theta, phi):
    return 2.97117518296351e-115*(1.0 - cos(theta)**2)**29.5*(3.28274631731402e+134*cos(theta)**37 - 1.14466442268646e+135*cos(theta)**35 + 1.80178659126572e+135*cos(theta)**33 - 1.69579914472068e+135*cos(theta)**31 + 1.06560351661502e+135*cos(theta)**29 - 4.7282516693519e+134*cos(theta)**27 + 1.52819183788445e+134*cos(theta)**25 - 3.6588791010801e+133*cos(theta)**23 + 6.5374040435965e+132*cos(theta)**21 - 8.71653872479534e+131*cos(theta)**19 + 8.61576949098268e+130*cos(theta)**17 - 6.22937081751007e+129*cos(theta)**15 + 3.22526595581143e+128*cos(theta)**13 - 1.15877818771668e+127*cos(theta)**11 + 2.75899568503971e+125*cos(theta)**9 - 4.0623249350278e+123*cos(theta)**7 + 3.31167793616397e+121*cos(theta)**5 - 1.22518606591342e+119*cos(theta)**3 + 1.30062215065119e+116*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl96_m60(theta, phi):
    return 3.91079541827941e-117*(1.0 - cos(theta)**2)**30*(1.21461613740619e+136*cos(theta)**36 - 4.00632547940261e+136*cos(theta)**34 + 5.94589575117689e+136*cos(theta)**32 - 5.25697734863411e+136*cos(theta)**30 + 3.09025019818356e+136*cos(theta)**28 - 1.27662795072501e+136*cos(theta)**26 + 3.82047959471114e+135*cos(theta)**24 - 8.41542193248423e+134*cos(theta)**22 + 1.37285484915527e+134*cos(theta)**20 - 1.65614235771111e+133*cos(theta)**18 + 1.46468081346705e+132*cos(theta)**16 - 9.3440562262651e+130*cos(theta)**14 + 4.19284574255485e+129*cos(theta)**12 - 1.27465600648835e+128*cos(theta)**10 + 2.48309611653574e+126*cos(theta)**8 - 2.84362745451946e+124*cos(theta)**6 + 1.65583896808198e+122*cos(theta)**4 - 3.67555819774025e+119*cos(theta)**2 + 1.30062215065119e+116)*cos(60*phi)

#@torch.jit.script
def Yl96_m61(theta, phi):
    return 5.20192421860811e-119*(1.0 - cos(theta)**2)**30.5*(4.37261809466227e+137*cos(theta)**35 - 1.36215066299689e+138*cos(theta)**33 + 1.9026866403766e+138*cos(theta)**31 - 1.57709320459023e+138*cos(theta)**29 + 8.65270055491398e+137*cos(theta)**27 - 3.31923267188503e+137*cos(theta)**25 + 9.16915102730673e+136*cos(theta)**23 - 1.85139282514653e+136*cos(theta)**21 + 2.74570969831053e+135*cos(theta)**19 - 2.98105624388001e+134*cos(theta)**17 + 2.34348930154729e+133*cos(theta)**15 - 1.30816787167711e+132*cos(theta)**13 + 5.03141489106582e+130*cos(theta)**11 - 1.27465600648835e+129*cos(theta)**9 + 1.98647689322859e+127*cos(theta)**7 - 1.70617647271168e+125*cos(theta)**5 + 6.62335587232794e+122*cos(theta)**3 - 7.3511163954805e+119*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl96_m62(theta, phi):
    return 6.99522125388846e-121*(1.0 - cos(theta)**2)**31*(1.5304163331318e+139*cos(theta)**34 - 4.49509718788973e+139*cos(theta)**32 + 5.89832858516747e+139*cos(theta)**30 - 4.57357029331168e+139*cos(theta)**28 + 2.33622914982677e+139*cos(theta)**26 - 8.29808167971259e+138*cos(theta)**24 + 2.10890473628055e+138*cos(theta)**22 - 3.88792493280771e+137*cos(theta)**20 + 5.21684842679001e+136*cos(theta)**18 - 5.06779561459601e+135*cos(theta)**16 + 3.51523395232093e+134*cos(theta)**14 - 1.70061823318025e+133*cos(theta)**12 + 5.53455638017241e+131*cos(theta)**10 - 1.14719040583951e+130*cos(theta)**8 + 1.39053382526002e+128*cos(theta)**6 - 8.53088236355838e+125*cos(theta)**4 + 1.98700676169838e+123*cos(theta)**2 - 7.3511163954805e+119)*cos(62*phi)

#@torch.jit.script
def Yl96_m63(theta, phi):
    return 9.51400630272681e-123*(1.0 - cos(theta)**2)**31.5*(5.20341553264811e+140*cos(theta)**33 - 1.43843110012471e+141*cos(theta)**31 + 1.76949857555024e+141*cos(theta)**29 - 1.28059968212727e+141*cos(theta)**27 + 6.07419578954961e+140*cos(theta)**25 - 1.99153960313102e+140*cos(theta)**23 + 4.6395904198172e+139*cos(theta)**21 - 7.77584986561543e+138*cos(theta)**19 + 9.39032716822202e+137*cos(theta)**17 - 8.10847298335361e+136*cos(theta)**15 + 4.9213275332493e+135*cos(theta)**13 - 2.0407418798163e+134*cos(theta)**11 + 5.53455638017241e+132*cos(theta)**9 - 9.17752324671611e+130*cos(theta)**7 + 8.3432029515601e+128*cos(theta)**5 - 3.41235294542335e+126*cos(theta)**3 + 3.97401352339676e+123*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl96_m64(theta, phi):
    return 1.30932202506075e-124*(1.0 - cos(theta)**2)**32*(1.71712712577388e+142*cos(theta)**32 - 4.45913641038661e+142*cos(theta)**30 + 5.1315458690957e+142*cos(theta)**28 - 3.45761914174363e+142*cos(theta)**26 + 1.5185489473874e+142*cos(theta)**24 - 4.58054108720135e+141*cos(theta)**22 + 9.74313988161613e+140*cos(theta)**20 - 1.47741147446693e+140*cos(theta)**18 + 1.59635561859774e+139*cos(theta)**16 - 1.21627094750304e+138*cos(theta)**14 + 6.3977257932241e+136*cos(theta)**12 - 2.24481606779793e+135*cos(theta)**10 + 4.98110074215517e+133*cos(theta)**8 - 6.42426627270127e+131*cos(theta)**6 + 4.17160147578005e+129*cos(theta)**4 - 1.02370588362701e+127*cos(theta)**2 + 3.97401352339676e+123)*cos(64*phi)

#@torch.jit.script
def Yl96_m65(theta, phi):
    return 1.8241415945285e-126*(1.0 - cos(theta)**2)**32.5*(5.4948068024764e+143*cos(theta)**31 - 1.33774092311598e+144*cos(theta)**29 + 1.4368328433468e+144*cos(theta)**27 - 8.98980976853343e+143*cos(theta)**25 + 3.64451747372977e+143*cos(theta)**23 - 1.0077190391843e+143*cos(theta)**21 + 1.94862797632323e+142*cos(theta)**19 - 2.65934065404048e+141*cos(theta)**17 + 2.55416898975639e+140*cos(theta)**15 - 1.70277932650426e+139*cos(theta)**13 + 7.67727095186891e+137*cos(theta)**11 - 2.24481606779793e+136*cos(theta)**9 + 3.98488059372413e+134*cos(theta)**7 - 3.85455976362076e+132*cos(theta)**5 + 1.66864059031202e+130*cos(theta)**3 - 2.04741176725401e+127*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl96_m66(theta, phi):
    return 2.57406904634943e-128*(1.0 - cos(theta)**2)**33*(1.70339010876768e+145*cos(theta)**30 - 3.87944867703635e+145*cos(theta)**28 + 3.87944867703635e+145*cos(theta)**26 - 2.24745244213336e+145*cos(theta)**24 + 8.38239018957847e+144*cos(theta)**22 - 2.11620998228702e+144*cos(theta)**20 + 3.70239315501413e+143*cos(theta)**18 - 4.52087911186881e+142*cos(theta)**16 + 3.83125348463458e+141*cos(theta)**14 - 2.21361312445554e+140*cos(theta)**12 + 8.44499804705581e+138*cos(theta)**10 - 2.02033446101814e+137*cos(theta)**8 + 2.78941641560689e+135*cos(theta)**6 - 1.92727988181038e+133*cos(theta)**4 + 5.00592177093606e+130*cos(theta)**2 - 2.04741176725401e+127)*cos(66*phi)

#@torch.jit.script
def Yl96_m67(theta, phi):
    return 3.68099953510626e-130*(1.0 - cos(theta)**2)**33.5*(5.11017032630305e+146*cos(theta)**29 - 1.08624562957018e+147*cos(theta)**27 + 1.00865665602945e+147*cos(theta)**25 - 5.39388586112006e+146*cos(theta)**23 + 1.84412584170726e+146*cos(theta)**21 - 4.23241996457405e+145*cos(theta)**19 + 6.66430767902543e+144*cos(theta)**17 - 7.23340657899009e+143*cos(theta)**15 + 5.36375487848842e+142*cos(theta)**13 - 2.65633574934664e+141*cos(theta)**11 + 8.44499804705581e+139*cos(theta)**9 - 1.61626756881451e+138*cos(theta)**7 + 1.67364984936414e+136*cos(theta)**5 - 7.70911952724153e+133*cos(theta)**3 + 1.00118435418721e+131*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl96_m68(theta, phi):
    return 5.33758543606813e-132*(1.0 - cos(theta)**2)**34*(1.48194939462789e+148*cos(theta)**28 - 2.93286319983948e+148*cos(theta)**26 + 2.52164164007363e+148*cos(theta)**24 - 1.24059374805761e+148*cos(theta)**22 + 3.87266426758525e+147*cos(theta)**20 - 8.04159793269069e+146*cos(theta)**18 + 1.13293230543432e+146*cos(theta)**16 - 1.08501098684851e+145*cos(theta)**14 + 6.97288134203494e+143*cos(theta)**12 - 2.92196932428131e+142*cos(theta)**10 + 7.60049824235023e+140*cos(theta)**8 - 1.13138729817016e+139*cos(theta)**6 + 8.36824924682068e+136*cos(theta)**4 - 2.31273585817246e+134*cos(theta)**2 + 1.00118435418721e+131)*cos(68*phi)

#@torch.jit.script
def Yl96_m69(theta, phi):
    return 7.85278761645772e-134*(1.0 - cos(theta)**2)**34.5*(4.14945830495808e+149*cos(theta)**27 - 7.62544431958265e+149*cos(theta)**25 + 6.0519399361767e+149*cos(theta)**23 - 2.72930624572675e+149*cos(theta)**21 + 7.7453285351705e+148*cos(theta)**19 - 1.44748762788432e+148*cos(theta)**17 + 1.81269168869492e+147*cos(theta)**15 - 1.51901538158792e+146*cos(theta)**13 + 8.36745761044193e+144*cos(theta)**11 - 2.92196932428131e+143*cos(theta)**9 + 6.08039859388018e+141*cos(theta)**7 - 6.78832378902094e+139*cos(theta)**5 + 3.34729969872827e+137*cos(theta)**3 - 4.62547171634492e+134*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl96_m70(theta, phi):
    return 1.1729727577158e-135*(1.0 - cos(theta)**2)**35*(1.12035374233868e+151*cos(theta)**26 - 1.90636107989566e+151*cos(theta)**24 + 1.39194618532064e+151*cos(theta)**22 - 5.73154311602617e+150*cos(theta)**20 + 1.4716124216824e+150*cos(theta)**18 - 2.46072896740335e+149*cos(theta)**16 + 2.71903753304238e+148*cos(theta)**14 - 1.9747199960643e+147*cos(theta)**12 + 9.20420337148612e+145*cos(theta)**10 - 2.62977239185318e+144*cos(theta)**8 + 4.25627901571613e+142*cos(theta)**6 - 3.39416189451047e+140*cos(theta)**4 + 1.00418990961848e+138*cos(theta)**2 - 4.62547171634492e+134)*cos(70*phi)

#@torch.jit.script
def Yl96_m71(theta, phi):
    return 1.78009432721424e-137*(1.0 - cos(theta)**2)**35.5*(2.91291973008057e+152*cos(theta)**25 - 4.57526659174959e+152*cos(theta)**23 + 3.06228160770541e+152*cos(theta)**21 - 1.14630862320523e+152*cos(theta)**19 + 2.64890235902831e+151*cos(theta)**17 - 3.93716634784536e+150*cos(theta)**15 + 3.80665254625933e+149*cos(theta)**13 - 2.36966399527715e+148*cos(theta)**11 + 9.20420337148612e+146*cos(theta)**9 - 2.10381791348254e+145*cos(theta)**7 + 2.55376740942968e+143*cos(theta)**5 - 1.35766475780419e+141*cos(theta)**3 + 2.00837981923696e+138*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl96_m72(theta, phi):
    return 2.74674517937673e-139*(1.0 - cos(theta)**2)**36*(7.28229932520143e+153*cos(theta)**24 - 1.05231131610241e+154*cos(theta)**22 + 6.43079137618137e+153*cos(theta)**20 - 2.17798638408995e+153*cos(theta)**18 + 4.50313401034813e+152*cos(theta)**16 - 5.90574952176804e+151*cos(theta)**14 + 4.94864831013712e+150*cos(theta)**12 - 2.60663039480487e+149*cos(theta)**10 + 8.28378303433751e+147*cos(theta)**8 - 1.47267253943778e+146*cos(theta)**6 + 1.27688370471484e+144*cos(theta)**4 - 4.07299427341256e+141*cos(theta)**2 + 2.00837981923696e+138)*cos(72*phi)

#@torch.jit.script
def Yl96_m73(theta, phi):
    return 4.31290009161695e-141*(1.0 - cos(theta)**2)**36.5*(1.74775183804834e+155*cos(theta)**23 - 2.31508489542529e+155*cos(theta)**21 + 1.28615827523627e+155*cos(theta)**19 - 3.9203754913619e+154*cos(theta)**17 + 7.20501441655701e+153*cos(theta)**15 - 8.26804933047526e+152*cos(theta)**13 + 5.93837797216455e+151*cos(theta)**11 - 2.60663039480487e+150*cos(theta)**9 + 6.62702642747001e+148*cos(theta)**7 - 8.83603523662668e+146*cos(theta)**5 + 5.10753481885935e+144*cos(theta)**3 - 8.14598854682512e+141*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl96_m74(theta, phi):
    return 6.89733022227171e-143*(1.0 - cos(theta)**2)**37*(4.01982922751119e+156*cos(theta)**22 - 4.86167828039311e+156*cos(theta)**20 + 2.44370072294892e+156*cos(theta)**18 - 6.66463833531523e+155*cos(theta)**16 + 1.08075216248355e+155*cos(theta)**14 - 1.07484641296178e+154*cos(theta)**12 + 6.532215769381e+152*cos(theta)**10 - 2.34596735532438e+151*cos(theta)**8 + 4.63891849922901e+149*cos(theta)**6 - 4.41801761831334e+147*cos(theta)**4 + 1.53226044565781e+145*cos(theta)**2 - 8.14598854682512e+141)*cos(74*phi)

#@torch.jit.script
def Yl96_m75(theta, phi):
    return 1.12453149551192e-144*(1.0 - cos(theta)**2)**37.5*(8.84362430052461e+157*cos(theta)**21 - 9.72335656078623e+157*cos(theta)**19 + 4.39866130130805e+157*cos(theta)**17 - 1.06634213365044e+157*cos(theta)**15 + 1.51305302747697e+156*cos(theta)**13 - 1.28981569555414e+155*cos(theta)**11 + 6.532215769381e+153*cos(theta)**9 - 1.87677388425951e+152*cos(theta)**7 + 2.7833510995374e+150*cos(theta)**5 - 1.76720704732534e+148*cos(theta)**3 + 3.06452089131561e+145*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl96_m76(theta, phi):
    return 1.87110324820511e-146*(1.0 - cos(theta)**2)**38*(1.85716110311017e+159*cos(theta)**20 - 1.84743774654938e+159*cos(theta)**18 + 7.47772421222369e+158*cos(theta)**16 - 1.59951320047566e+158*cos(theta)**14 + 1.96696893572006e+157*cos(theta)**12 - 1.41879726510955e+156*cos(theta)**10 + 5.8789941924429e+154*cos(theta)**8 - 1.31374171898165e+153*cos(theta)**6 + 1.3916755497687e+151*cos(theta)**4 - 5.30162114197601e+148*cos(theta)**2 + 3.06452089131561e+145)*cos(76*phi)

#@torch.jit.script
def Yl96_m77(theta, phi):
    return 3.18097095250874e-148*(1.0 - cos(theta)**2)**38.5*(3.71432220622034e+160*cos(theta)**19 - 3.32538794378889e+160*cos(theta)**17 + 1.19643587395579e+160*cos(theta)**15 - 2.23931848066592e+159*cos(theta)**13 + 2.36036272286408e+158*cos(theta)**11 - 1.41879726510955e+157*cos(theta)**9 + 4.70319535395432e+155*cos(theta)**7 - 7.88245031388993e+153*cos(theta)**5 + 5.56670219907481e+151*cos(theta)**3 - 1.0603242283952e+149*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl96_m78(theta, phi):
    return 5.53233256153302e-150*(1.0 - cos(theta)**2)**39*(7.05721219181864e+161*cos(theta)**18 - 5.65315950444111e+161*cos(theta)**16 + 1.79465381093369e+161*cos(theta)**14 - 2.91111402486569e+160*cos(theta)**12 + 2.59639899515048e+159*cos(theta)**10 - 1.2769175385986e+158*cos(theta)**8 + 3.29223674776803e+156*cos(theta)**6 - 3.94122515694496e+154*cos(theta)**4 + 1.67001065972244e+152*cos(theta)**2 - 1.0603242283952e+149)*cos(78*phi)

#@torch.jit.script
def Yl96_m79(theta, phi):
    return 9.85718714045239e-152*(1.0 - cos(theta)**2)**39.5*(1.27029819452736e+163*cos(theta)**17 - 9.04505520710578e+162*cos(theta)**15 + 2.51251533530716e+162*cos(theta)**13 - 3.49333682983883e+161*cos(theta)**11 + 2.59639899515048e+160*cos(theta)**9 - 1.02153403087888e+159*cos(theta)**7 + 1.97534204866082e+157*cos(theta)**5 - 1.57649006277799e+155*cos(theta)**3 + 3.34002131944488e+152*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl96_m80(theta, phi):
    return 1.80207228381835e-153*(1.0 - cos(theta)**2)**40*(2.1595069306965e+164*cos(theta)**16 - 1.35675828106587e+164*cos(theta)**14 + 3.26626993589931e+163*cos(theta)**12 - 3.84267051282272e+162*cos(theta)**10 + 2.33675909563544e+161*cos(theta)**8 - 7.15073821615215e+159*cos(theta)**6 + 9.87671024330408e+157*cos(theta)**4 - 4.72947018833396e+155*cos(theta)**2 + 3.34002131944488e+152)*cos(80*phi)

#@torch.jit.script
def Yl96_m81(theta, phi):
    return 3.38630118576512e-155*(1.0 - cos(theta)**2)**40.5*(3.45521108911441e+165*cos(theta)**15 - 1.89946159349221e+165*cos(theta)**13 + 3.91952392307917e+164*cos(theta)**11 - 3.84267051282272e+163*cos(theta)**9 + 1.86940727650835e+162*cos(theta)**7 - 4.29044292969129e+160*cos(theta)**5 + 3.95068409732163e+158*cos(theta)**3 - 9.45894037666791e+155*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl96_m82(theta, phi):
    return 6.55344942213777e-157*(1.0 - cos(theta)**2)**41*(5.18281663367161e+166*cos(theta)**14 - 2.46930007153988e+166*cos(theta)**12 + 4.31147631538709e+165*cos(theta)**10 - 3.45840346154044e+164*cos(theta)**8 + 1.30858509355584e+163*cos(theta)**6 - 2.14522146484565e+161*cos(theta)**4 + 1.18520522919649e+159*cos(theta)**2 - 9.45894037666791e+155)*cos(82*phi)

#@torch.jit.script
def Yl96_m83(theta, phi):
    return 1.30911988200608e-158*(1.0 - cos(theta)**2)**41.5*(7.25594328714026e+167*cos(theta)**13 - 2.96316008584785e+167*cos(theta)**11 + 4.31147631538709e+166*cos(theta)**9 - 2.76672276923236e+165*cos(theta)**7 + 7.85151056133506e+163*cos(theta)**5 - 8.58088585938258e+161*cos(theta)**3 + 2.37041045839298e+159*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl96_m84(theta, phi):
    return 2.70627228516799e-160*(1.0 - cos(theta)**2)**42*(9.43272627328233e+168*cos(theta)**12 - 3.25947609443264e+168*cos(theta)**10 + 3.88032868384838e+167*cos(theta)**8 - 1.93670593846265e+166*cos(theta)**6 + 3.92575528066753e+164*cos(theta)**4 - 2.57426575781477e+162*cos(theta)**2 + 2.37041045839298e+159)*cos(84*phi)

#@torch.jit.script
def Yl96_m85(theta, phi):
    return 5.80686299422056e-162*(1.0 - cos(theta)**2)**42.5*(1.13192715279388e+170*cos(theta)**11 - 3.25947609443264e+169*cos(theta)**9 + 3.1042629470787e+168*cos(theta)**7 - 1.16202356307759e+167*cos(theta)**5 + 1.57030211226701e+165*cos(theta)**3 - 5.14853151562955e+162*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl96_m86(theta, phi):
    return 1.29780529860581e-163*(1.0 - cos(theta)**2)**43*(1.24511986807327e+171*cos(theta)**10 - 2.93352848498937e+170*cos(theta)**8 + 2.17298406295509e+169*cos(theta)**6 - 5.81011781538795e+167*cos(theta)**4 + 4.71090633680104e+165*cos(theta)**2 - 5.14853151562955e+162)*cos(86*phi)

#@torch.jit.script
def Yl96_m87(theta, phi):
    return 3.03377940011721e-165*(1.0 - cos(theta)**2)**43.5*(1.24511986807327e+172*cos(theta)**9 - 2.3468227879915e+171*cos(theta)**7 + 1.30379043777306e+170*cos(theta)**5 - 2.32404712615518e+168*cos(theta)**3 + 9.42181267360208e+165*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl96_m88(theta, phi):
    return 7.45510615492852e-167*(1.0 - cos(theta)**2)**44*(1.12060788126594e+173*cos(theta)**8 - 1.64277595159405e+172*cos(theta)**6 + 6.51895218886528e+170*cos(theta)**4 - 6.97214137846554e+168*cos(theta)**2 + 9.42181267360208e+165)*cos(88*phi)

#@torch.jit.script
def Yl96_m89(theta, phi):
    return 1.93786256906189e-168*(1.0 - cos(theta)**2)**44.5*(8.96486305012753e+173*cos(theta)**7 - 9.8566557095643e+172*cos(theta)**5 + 2.60758087554611e+171*cos(theta)**3 - 1.39442827569311e+169*cos(theta))*cos(89*phi)

#@torch.jit.script
def Yl96_m90(theta, phi):
    return 5.37053414416425e-170*(1.0 - cos(theta)**2)**45*(6.27540413508927e+174*cos(theta)**6 - 4.92832785478215e+173*cos(theta)**4 + 7.82274262663833e+171*cos(theta)**2 - 1.39442827569311e+169)*cos(90*phi)

#@torch.jit.script
def Yl96_m91(theta, phi):
    return 1.60332311414302e-171*(1.0 - cos(theta)**2)**45.5*(3.76524248105356e+175*cos(theta)**5 - 1.97133114191286e+174*cos(theta)**3 + 1.56454852532767e+172*cos(theta))*cos(91*phi)

#@torch.jit.script
def Yl96_m92(theta, phi):
    return 5.22946338765481e-173*(1.0 - cos(theta)**2)**46*(1.88262124052678e+176*cos(theta)**4 - 5.91399342573858e+174*cos(theta)**2 + 1.56454852532767e+172)*cos(92*phi)

#@torch.jit.script
def Yl96_m93(theta, phi):
    return 1.90193744586733e-174*(1.0 - cos(theta)**2)**46.5*(7.53048496210712e+176*cos(theta)**3 - 1.18279868514772e+175*cos(theta))*cos(93*phi)

#@torch.jit.script
def Yl96_m94(theta, phi):
    return 7.96633932527857e-176*(1.0 - cos(theta)**2)**47*(2.25914548863214e+177*cos(theta)**2 - 1.18279868514772e+175)*cos(94*phi)

#@torch.jit.script
def Yl96_m95(theta, phi):
    return 18.4162548281816*(1.0 - cos(theta)**2)**47.5*cos(95*phi)*cos(theta)

#@torch.jit.script
def Yl96_m96(theta, phi):
    return 1.32907871031442*(1.0 - cos(theta)**2)**48*cos(96*phi)

#@torch.jit.script
def Yl97_m_minus_97(theta, phi):
    return 1.33249976799509*(1.0 - cos(theta)**2)**48.5*sin(97*phi)

#@torch.jit.script
def Yl97_m_minus_96(theta, phi):
    return 18.5595741478934*(1.0 - cos(theta)**2)**48*sin(96*phi)*cos(theta)

#@torch.jit.script
def Yl97_m_minus_95(theta, phi):
    return 4.1814812564218e-178*(1.0 - cos(theta)**2)**47.5*(4.36015079306002e+179*cos(theta)**2 - 2.25914548863214e+177)*sin(95*phi)

#@torch.jit.script
def Yl97_m_minus_94(theta, phi):
    return 1.00355550154123e-176*(1.0 - cos(theta)**2)**47*(1.45338359768667e+179*cos(theta)**3 - 2.25914548863214e+177*cos(theta))*sin(94*phi)

#@torch.jit.script
def Yl97_m_minus_93(theta, phi):
    return 2.77388259400193e-175*(1.0 - cos(theta)**2)**46.5*(3.63345899421669e+178*cos(theta)**4 - 1.12957274431607e+177*cos(theta)**2 + 2.95699671286929e+174)*sin(93*phi)

#@torch.jit.script
def Yl97_m_minus_92(theta, phi):
    return 8.54968035252871e-174*(1.0 - cos(theta)**2)**46*(7.26691798843337e+177*cos(theta)**5 - 3.76524248105356e+176*cos(theta)**3 + 2.95699671286929e+174*cos(theta))*sin(92*phi)

#@torch.jit.script
def Yl97_m_minus_91(theta, phi):
    return 2.87909771810356e-172*(1.0 - cos(theta)**2)**45.5*(1.21115299807223e+177*cos(theta)**6 - 9.41310620263391e+175*cos(theta)**4 + 1.47849835643464e+174*cos(theta)**2 - 2.60758087554611e+171)*sin(91*phi)

#@torch.jit.script
def Yl97_m_minus_90(theta, phi):
    return 1.044442053454e-170*(1.0 - cos(theta)**2)**45*(1.73021856867461e+176*cos(theta)**7 - 1.88262124052678e+175*cos(theta)**5 + 4.92832785478215e+173*cos(theta)**3 - 2.60758087554611e+171*cos(theta))*sin(90*phi)

#@torch.jit.script
def Yl97_m_minus_89(theta, phi):
    return 4.03970960308129e-169*(1.0 - cos(theta)**2)**44.5*(2.16277321084327e+175*cos(theta)**8 - 3.13770206754463e+174*cos(theta)**6 + 1.23208196369554e+173*cos(theta)**4 - 1.30379043777306e+171*cos(theta)**2 + 1.74303534461638e+168)*sin(89*phi)

#@torch.jit.script
def Yl97_m_minus_88(theta, phi):
    return 1.65282880709644e-167*(1.0 - cos(theta)**2)**44*(2.40308134538141e+174*cos(theta)**9 - 4.48243152506376e+173*cos(theta)**7 + 2.46416392739107e+172*cos(theta)**5 - 4.34596812591018e+170*cos(theta)**3 + 1.74303534461638e+168*cos(theta))*sin(88*phi)

#@torch.jit.script
def Yl97_m_minus_87(theta, phi):
    return 7.10908550469079e-166*(1.0 - cos(theta)**2)**43.5*(2.40308134538141e+173*cos(theta)**10 - 5.60303940632971e+172*cos(theta)**8 + 4.10693987898512e+171*cos(theta)**6 - 1.08649203147755e+170*cos(theta)**4 + 8.71517672308192e+167*cos(theta)**2 - 9.42181267360208e+164)*sin(87*phi)

#@torch.jit.script
def Yl97_m_minus_86(theta, phi):
    return 3.19829848117904e-164*(1.0 - cos(theta)**2)**43*(2.18461940489219e+172*cos(theta)**11 - 6.22559934036634e+171*cos(theta)**9 + 5.86705696997875e+170*cos(theta)**7 - 2.17298406295509e+169*cos(theta)**5 + 2.90505890769397e+167*cos(theta)**3 - 9.42181267360208e+164*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl97_m_minus_85(theta, phi):
    return 1.49877058056488e-162*(1.0 - cos(theta)**2)**42.5*(1.82051617074349e+171*cos(theta)**12 - 6.22559934036634e+170*cos(theta)**10 + 7.33382121247344e+169*cos(theta)**8 - 3.62164010492515e+168*cos(theta)**6 + 7.26264726923493e+166*cos(theta)**4 - 4.71090633680104e+164*cos(theta)**2 + 4.29044292969129e+161)*sin(85*phi)

#@torch.jit.script
def Yl97_m_minus_84(theta, phi):
    return 7.29025181800508e-161*(1.0 - cos(theta)**2)**42*(1.40039705441807e+170*cos(theta)**13 - 5.6596357639694e+169*cos(theta)**11 + 8.1486902360816e+168*cos(theta)**9 - 5.17377157846451e+167*cos(theta)**7 + 1.45252945384699e+166*cos(theta)**5 - 1.57030211226701e+164*cos(theta)**3 + 4.29044292969129e+161*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl97_m_minus_83(theta, phi):
    return 3.66982905811965e-159*(1.0 - cos(theta)**2)**41.5*(1.00028361029862e+169*cos(theta)**14 - 4.71636313664117e+168*cos(theta)**12 + 8.1486902360816e+167*cos(theta)**10 - 6.46721447308063e+166*cos(theta)**8 + 2.42088242307831e+165*cos(theta)**6 - 3.92575528066753e+163*cos(theta)**4 + 2.14522146484565e+161*cos(theta)**2 - 1.69315032742356e+158)*sin(83*phi)

#@torch.jit.script
def Yl97_m_minus_82(theta, phi):
    return 1.90689911512676e-157*(1.0 - cos(theta)**2)**41*(6.66855740199081e+167*cos(theta)**15 - 3.62797164357013e+167*cos(theta)**13 + 7.40790021461963e+166*cos(theta)**11 - 7.18579385897848e+165*cos(theta)**9 + 3.45840346154044e+164*cos(theta)**7 - 7.85151056133506e+162*cos(theta)**5 + 7.15073821615215e+160*cos(theta)**3 - 1.69315032742356e+158*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl97_m_minus_81(theta, phi):
    return 1.02050285496008e-155*(1.0 - cos(theta)**2)**40.5*(4.16784837624425e+166*cos(theta)**16 - 2.59140831683581e+166*cos(theta)**14 + 6.17325017884969e+165*cos(theta)**12 - 7.18579385897848e+164*cos(theta)**10 + 4.32300432692556e+163*cos(theta)**8 - 1.30858509355584e+162*cos(theta)**6 + 1.78768455403804e+160*cos(theta)**4 - 8.46575163711778e+157*cos(theta)**2 + 5.91183773541744e+154)*sin(81*phi)

#@torch.jit.script
def Yl97_m_minus_80(theta, phi):
    return 5.61369335548937e-154*(1.0 - cos(theta)**2)**40*(2.4516755154378e+165*cos(theta)**17 - 1.7276055445572e+165*cos(theta)**15 + 4.74865398373053e+164*cos(theta)**13 - 6.53253987179862e+163*cos(theta)**11 + 4.8033381410284e+162*cos(theta)**9 - 1.86940727650835e+161*cos(theta)**7 + 3.57536910807608e+159*cos(theta)**5 - 2.82191721237259e+157*cos(theta)**3 + 5.91183773541744e+154*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl97_m_minus_79(theta, phi):
    return 3.16863030571629e-152*(1.0 - cos(theta)**2)**39.5*(1.362041953021e+164*cos(theta)**18 - 1.07975346534825e+164*cos(theta)**16 + 3.39189570266467e+163*cos(theta)**14 - 5.44378322649885e+162*cos(theta)**12 + 4.8033381410284e+161*cos(theta)**10 - 2.33675909563544e+160*cos(theta)**8 + 5.95894851346013e+158*cos(theta)**6 - 7.05479303093148e+156*cos(theta)**4 + 2.95591886770872e+154*cos(theta)**2 - 1.8555673996916e+151)*sin(79*phi)

#@torch.jit.script
def Yl97_m_minus_78(theta, phi):
    return 1.83233427735857e-150*(1.0 - cos(theta)**2)**39*(7.16864185800525e+162*cos(theta)**19 - 6.35149097263678e+162*cos(theta)**17 + 2.26126380177644e+162*cos(theta)**15 - 4.18752555884527e+161*cos(theta)**13 + 4.36667103729854e+160*cos(theta)**11 - 2.59639899515048e+159*cos(theta)**9 + 8.51278359065733e+157*cos(theta)**7 - 1.4109586061863e+156*cos(theta)**5 + 9.85306289236241e+153*cos(theta)**3 - 1.8555673996916e+151*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl97_m_minus_77(theta, phi):
    return 1.08402357741615e-148*(1.0 - cos(theta)**2)**38.5*(3.58432092900263e+161*cos(theta)**20 - 3.52860609590932e+161*cos(theta)**18 + 1.41328987611028e+161*cos(theta)**16 - 2.99108968488948e+160*cos(theta)**14 + 3.63889253108212e+159*cos(theta)**12 - 2.59639899515048e+158*cos(theta)**10 + 1.06409794883217e+157*cos(theta)**8 - 2.35159767697716e+155*cos(theta)**6 + 2.4632657230906e+153*cos(theta)**4 - 9.27783699845801e+150*cos(theta)**2 + 5.30162114197601e+147)*sin(77*phi)

#@torch.jit.script
def Yl97_m_minus_76(theta, phi):
    return 6.55274095574063e-147*(1.0 - cos(theta)**2)**38*(1.70681949000125e+160*cos(theta)**21 - 1.85716110311017e+160*cos(theta)**19 + 8.31346985947222e+159*cos(theta)**17 - 1.99405978992632e+159*cos(theta)**15 + 2.7991481008324e+158*cos(theta)**13 - 2.36036272286408e+157*cos(theta)**11 + 1.18233105425796e+156*cos(theta)**9 - 3.35942525282452e+154*cos(theta)**7 + 4.9265314461812e+152*cos(theta)**5 - 3.09261233281934e+150*cos(theta)**3 + 5.30162114197601e+147*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl97_m_minus_75(theta, phi):
    return 4.04256853757302e-145*(1.0 - cos(theta)**2)**37.5*(7.75827040909659e+158*cos(theta)**22 - 9.28580551555085e+158*cos(theta)**20 + 4.61859436637346e+158*cos(theta)**18 - 1.24628736870395e+158*cos(theta)**16 + 1.99939150059457e+157*cos(theta)**14 - 1.96696893572006e+156*cos(theta)**12 + 1.18233105425796e+155*cos(theta)**10 - 4.19928156603065e+153*cos(theta)**8 + 8.21088574363534e+151*cos(theta)**6 - 7.73153083204834e+149*cos(theta)**4 + 2.650810570988e+147*cos(theta)**2 - 1.3929640415071e+144)*sin(75*phi)

#@torch.jit.script
def Yl97_m_minus_74(theta, phi):
    return 2.54264385369124e-143*(1.0 - cos(theta)**2)**37*(3.3731610474333e+157*cos(theta)**23 - 4.42181215026231e+157*cos(theta)**21 + 2.43083914019656e+157*cos(theta)**19 - 7.33110216884676e+156*cos(theta)**17 + 1.33292766706305e+156*cos(theta)**15 - 1.51305302747697e+155*cos(theta)**13 + 1.07484641296178e+154*cos(theta)**11 - 4.66586840670072e+152*cos(theta)**9 + 1.17298367766219e+151*cos(theta)**7 - 1.54630616640967e+149*cos(theta)**5 + 8.83603523662668e+146*cos(theta)**3 - 1.3929640415071e+144*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl97_m_minus_73(theta, phi):
    return 1.62888044357447e-141*(1.0 - cos(theta)**2)**36.5*(1.40548376976388e+156*cos(theta)**24 - 2.00991461375559e+156*cos(theta)**22 + 1.21541957009828e+156*cos(theta)**20 - 4.0728345382482e+155*cos(theta)**18 + 8.33079791914404e+154*cos(theta)**16 - 1.08075216248355e+154*cos(theta)**14 + 8.9570534413482e+152*cos(theta)**12 - 4.66586840670072e+151*cos(theta)**10 + 1.46622959707774e+150*cos(theta)**8 - 2.57717694401611e+148*cos(theta)**6 + 2.20900880915667e+146*cos(theta)**4 - 6.96482020753548e+143*cos(theta)**2 + 3.39416189451047e+140)*sin(73*phi)

#@torch.jit.script
def Yl97_m_minus_72(theta, phi):
    return 1.06190013055382e-139*(1.0 - cos(theta)**2)**36*(5.6219350790555e+154*cos(theta)**25 - 8.73875919024171e+154*cos(theta)**23 + 5.78771223856323e+154*cos(theta)**21 - 2.14359712539379e+154*cos(theta)**19 + 4.90046936420238e+153*cos(theta)**17 - 7.20501441655701e+152*cos(theta)**15 + 6.89004110872938e+151*cos(theta)**13 - 4.24169855154611e+150*cos(theta)**11 + 1.62914399675304e+149*cos(theta)**9 - 3.68168134859445e+147*cos(theta)**7 + 4.41801761831334e+145*cos(theta)**5 - 2.32160673584516e+143*cos(theta)**3 + 3.39416189451047e+140*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl97_m_minus_71(theta, phi):
    return 7.03904433333486e-138*(1.0 - cos(theta)**2)**35.5*(2.16228272271365e+153*cos(theta)**26 - 3.64114966260071e+153*cos(theta)**24 + 2.63077829025601e+153*cos(theta)**22 - 1.07179856269689e+153*cos(theta)**20 + 2.72248298011243e+152*cos(theta)**18 - 4.50313401034813e+151*cos(theta)**16 + 4.9214579348067e+150*cos(theta)**14 - 3.53474879295509e+149*cos(theta)**12 + 1.62914399675304e+148*cos(theta)**10 - 4.60210168574306e+146*cos(theta)**8 + 7.3633626971889e+144*cos(theta)**6 - 5.8040168396129e+142*cos(theta)**4 + 1.69708094725523e+140*cos(theta)**2 - 7.72453776629601e+136)*sin(71*phi)

#@torch.jit.script
def Yl97_m_minus_70(theta, phi):
    return 4.7407846006173e-136*(1.0 - cos(theta)**2)**35*(8.00845452856909e+151*cos(theta)**27 - 1.45645986504029e+152*cos(theta)**25 + 1.1438166479374e+152*cos(theta)**23 - 5.10380267950902e+151*cos(theta)**21 + 1.43288577900654e+151*cos(theta)**19 - 2.64890235902831e+150*cos(theta)**17 + 3.2809719565378e+149*cos(theta)**15 - 2.71903753304238e+148*cos(theta)**13 + 1.48103999704822e+147*cos(theta)**11 - 5.11344631749229e+145*cos(theta)**9 + 1.05190895674127e+144*cos(theta)**7 - 1.16080336792258e+142*cos(theta)**5 + 5.65693649085078e+139*cos(theta)**3 - 7.72453776629601e+136*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl97_m_minus_69(theta, phi):
    return 3.24180938106035e-134*(1.0 - cos(theta)**2)**34.5*(2.86016233163182e+150*cos(theta)**28 - 5.60176871169341e+150*cos(theta)**26 + 4.76590269973915e+150*cos(theta)**24 - 2.31991030886774e+150*cos(theta)**22 + 7.16442889503272e+149*cos(theta)**20 - 1.4716124216824e+149*cos(theta)**18 + 2.05060747283613e+148*cos(theta)**16 - 1.94216966645884e+147*cos(theta)**14 + 1.23419999754018e+146*cos(theta)**12 - 5.11344631749229e+144*cos(theta)**10 + 1.31488619592659e+143*cos(theta)**8 - 1.93467227987097e+141*cos(theta)**6 + 1.41423412271269e+139*cos(theta)**4 - 3.86226888314801e+136*cos(theta)**2 + 1.6519541844089e+133)*sin(69*phi)

#@torch.jit.script
def Yl97_m_minus_68(theta, phi):
    return 2.249264441899e-132*(1.0 - cos(theta)**2)**34*(9.86262872976489e+148*cos(theta)**29 - 2.07472915247904e+149*cos(theta)**27 + 1.90636107989566e+149*cos(theta)**25 - 1.00865665602945e+149*cos(theta)**23 + 3.41163280715844e+148*cos(theta)**21 - 7.7453285351705e+147*cos(theta)**19 + 1.2062396899036e+147*cos(theta)**17 - 1.29477977763923e+146*cos(theta)**15 + 9.4938461349245e+144*cos(theta)**13 - 4.64858756135663e+143*cos(theta)**11 + 1.46098466214065e+142*cos(theta)**9 - 2.76381754267281e+140*cos(theta)**7 + 2.82846824542539e+138*cos(theta)**5 - 1.28742296104934e+136*cos(theta)**3 + 1.6519541844089e+133*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl97_m_minus_67(theta, phi):
    return 1.58249780794403e-130*(1.0 - cos(theta)**2)**33.5*(3.28754290992163e+147*cos(theta)**30 - 7.40974697313943e+147*cos(theta)**28 + 7.3321579995987e+147*cos(theta)**26 - 4.20273606678938e+147*cos(theta)**24 + 1.55074218507202e+147*cos(theta)**22 - 3.87266426758525e+146*cos(theta)**20 + 6.70133161057557e+145*cos(theta)**18 - 8.09237361024517e+144*cos(theta)**16 + 6.78131866780321e+143*cos(theta)**14 - 3.87382296779719e+142*cos(theta)**12 + 1.46098466214065e+141*cos(theta)**10 - 3.45477192834101e+139*cos(theta)**8 + 4.71411374237565e+137*cos(theta)**6 - 3.21855740262334e+135*cos(theta)**4 + 8.25977092204449e+132*cos(theta)**2 - 3.33728118062404e+129)*sin(67*phi)

#@torch.jit.script
def Yl97_m_minus_66(theta, phi):
    return 1.12835533866591e-128*(1.0 - cos(theta)**2)**33*(1.06049771287795e+146*cos(theta)**31 - 2.55508516315153e+146*cos(theta)**29 + 2.71561407392544e+146*cos(theta)**27 - 1.68109442671575e+146*cos(theta)**25 + 6.74235732640007e+145*cos(theta)**23 - 1.84412584170726e+145*cos(theta)**21 + 3.52701663714504e+144*cos(theta)**19 - 4.76021977073245e+143*cos(theta)**17 + 4.52087911186881e+142*cos(theta)**15 - 2.97986382138245e+141*cos(theta)**13 + 1.32816787467332e+140*cos(theta)**11 - 3.83863547593446e+138*cos(theta)**9 + 6.73444820339378e+136*cos(theta)**7 - 6.43711480524668e+134*cos(theta)**5 + 2.75325697401483e+132*cos(theta)**3 - 3.33728118062404e+129*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl97_m_minus_65(theta, phi):
    return 8.14919442513382e-127*(1.0 - cos(theta)**2)**32.5*(3.31405535274358e+144*cos(theta)**32 - 8.51695054383842e+144*cos(theta)**30 + 9.69862169259087e+144*cos(theta)**28 - 6.46574779506058e+144*cos(theta)**26 + 2.8093155526667e+144*cos(theta)**24 - 8.38239018957847e+143*cos(theta)**22 + 1.76350831857252e+143*cos(theta)**20 - 2.64456653929581e+142*cos(theta)**18 + 2.82554944491801e+141*cos(theta)**16 - 2.12847415813032e+140*cos(theta)**14 + 1.10680656222777e+139*cos(theta)**12 - 3.83863547593446e+137*cos(theta)**10 + 8.41806025424223e+135*cos(theta)**8 - 1.07285246754111e+134*cos(theta)**6 + 6.88314243503708e+131*cos(theta)**4 - 1.66864059031202e+129*cos(theta)**2 + 6.39816177266879e+125)*sin(65*phi)

#@torch.jit.script
def Yl97_m_minus_64(theta, phi):
    return 5.95839316289692e-125*(1.0 - cos(theta)**2)**32*(1.00425919780108e+143*cos(theta)**33 - 2.7474034012382e+143*cos(theta)**31 + 3.34435230778996e+143*cos(theta)**29 - 2.39472140557799e+143*cos(theta)**27 + 1.12372622106668e+143*cos(theta)**25 - 3.64451747372977e+142*cos(theta)**23 + 8.39765865986914e+141*cos(theta)**21 - 1.39187712594516e+141*cos(theta)**19 + 1.6620879087753e+140*cos(theta)**17 - 1.41898277208688e+139*cos(theta)**15 + 8.5138966325213e+137*cos(theta)**13 - 3.48966861448587e+136*cos(theta)**11 + 9.35340028249137e+134*cos(theta)**9 - 1.53264638220159e+133*cos(theta)**7 + 1.37662848700742e+131*cos(theta)**5 - 5.56213530104006e+128*cos(theta)**3 + 6.39816177266879e+125*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl97_m_minus_63(theta, phi):
    return 4.40840567874529e-123*(1.0 - cos(theta)**2)**31.5*(2.95370352294437e+141*cos(theta)**34 - 8.58563562886938e+141*cos(theta)**32 + 1.11478410259665e+142*cos(theta)**30 - 8.55257644849283e+141*cos(theta)**28 + 4.32202392717953e+141*cos(theta)**26 - 1.5185489473874e+141*cos(theta)**24 + 3.81711757266779e+140*cos(theta)**22 - 6.95938562972581e+139*cos(theta)**20 + 9.23382171541832e+138*cos(theta)**18 - 8.86864232554302e+137*cos(theta)**16 + 6.08135473751521e+136*cos(theta)**14 - 2.90805717873823e+135*cos(theta)**12 + 9.35340028249137e+133*cos(theta)**10 - 1.91580797775199e+132*cos(theta)**8 + 2.29438081167903e+130*cos(theta)**6 - 1.39053382526002e+128*cos(theta)**4 + 3.19908088633439e+125*cos(theta)**2 - 1.1688275068814e+122)*sin(63*phi)

#@torch.jit.script
def Yl97_m_minus_62(theta, phi):
    return 3.2989487343547e-121*(1.0 - cos(theta)**2)**31*(8.43915292269819e+139*cos(theta)**35 - 2.60170776632405e+140*cos(theta)**33 + 3.59607775031178e+140*cos(theta)**31 - 2.94916429258374e+140*cos(theta)**29 + 1.60074960265909e+140*cos(theta)**27 - 6.07419578954961e+139*cos(theta)**25 + 1.65961633594252e+139*cos(theta)**23 - 3.31399315701229e+138*cos(theta)**21 + 4.85990616600964e+137*cos(theta)**19 - 5.21684842679001e+136*cos(theta)**17 + 4.05423649167681e+135*cos(theta)**15 - 2.23696706056787e+134*cos(theta)**13 + 8.50309116590124e+132*cos(theta)**11 - 2.12867553083554e+131*cos(theta)**9 + 3.27768687382718e+129*cos(theta)**7 - 2.78106765052003e+127*cos(theta)**5 + 1.0663602954448e+125*cos(theta)**3 - 1.1688275068814e+122*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl97_m_minus_61(theta, phi):
    return 2.49588964483365e-119*(1.0 - cos(theta)**2)**30.5*(2.34420914519394e+138*cos(theta)**36 - 7.65208166565898e+138*cos(theta)**34 + 1.12377429697243e+139*cos(theta)**32 - 9.83054764194578e+138*cos(theta)**30 + 5.71696286663959e+138*cos(theta)**28 - 2.33622914982677e+138*cos(theta)**26 + 6.91506806642716e+137*cos(theta)**24 - 1.50636052591468e+137*cos(theta)**22 + 2.42995308300482e+136*cos(theta)**20 - 2.89824912599445e+135*cos(theta)**18 + 2.533897807298e+134*cos(theta)**16 - 1.59783361469133e+133*cos(theta)**14 + 7.0859093049177e+131*cos(theta)**12 - 2.12867553083554e+130*cos(theta)**10 + 4.09710859228398e+128*cos(theta)**8 - 4.63511275086672e+126*cos(theta)**6 + 2.66590073861199e+124*cos(theta)**4 - 5.844137534407e+121*cos(theta)**2 + 2.04197677652236e+118)*sin(61*phi)

#@torch.jit.script
def Yl97_m_minus_60(theta, phi):
    return 1.90833574317446e-117*(1.0 - cos(theta)**2)**30*(6.33570039241606e+136*cos(theta)**37 - 2.18630904733114e+137*cos(theta)**35 + 3.40537665749222e+137*cos(theta)**33 - 3.17114440062767e+137*cos(theta)**31 + 1.97136650573779e+137*cos(theta)**29 - 8.65270055491398e+136*cos(theta)**27 + 2.76602722657086e+136*cos(theta)**25 - 6.54939359093338e+135*cos(theta)**23 + 1.15712051571658e+135*cos(theta)**21 - 1.52539427683918e+134*cos(theta)**19 + 1.49052812194e+133*cos(theta)**17 - 1.06522240979422e+132*cos(theta)**15 + 5.45069946532131e+130*cos(theta)**13 - 1.93515957348686e+129*cos(theta)**11 + 4.55234288031553e+127*cos(theta)**9 - 6.62158964409531e+125*cos(theta)**7 + 5.33180147722399e+123*cos(theta)**5 - 1.94804584480233e+121*cos(theta)**3 + 2.04197677652236e+118*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl97_m_minus_59(theta, phi):
    return 1.47399635384787e-115*(1.0 - cos(theta)**2)**29.5*(1.66728957695159e+135*cos(theta)**38 - 6.07308068703094e+135*cos(theta)**36 + 1.00158136985065e+136*cos(theta)**34 - 9.90982625196148e+135*cos(theta)**32 + 6.57122168579264e+135*cos(theta)**30 - 3.09025019818356e+135*cos(theta)**28 + 1.06385662560418e+135*cos(theta)**26 - 2.72891399622224e+134*cos(theta)**24 + 5.25963870780264e+133*cos(theta)**22 - 7.62697138419592e+132*cos(theta)**20 + 8.28071178855557e+131*cos(theta)**18 - 6.65764006121389e+130*cos(theta)**16 + 3.89335676094379e+129*cos(theta)**14 - 1.61263297790571e+128*cos(theta)**12 + 4.55234288031553e+126*cos(theta)**10 - 8.27698705511914e+124*cos(theta)**8 + 8.88633579537331e+122*cos(theta)**6 - 4.87011461200583e+120*cos(theta)**4 + 1.02098838826118e+118*cos(theta)**2 - 3.4226898701347e+114)*sin(59*phi)

#@torch.jit.script
def Yl97_m_minus_58(theta, phi):
    return 1.14971715600134e-113*(1.0 - cos(theta)**2)**29*(4.27510147936306e+133*cos(theta)**39 - 1.64137315865701e+134*cos(theta)**37 + 2.86166105671615e+134*cos(theta)**35 - 3.00297765210954e+134*cos(theta)**33 + 2.11974893090085e+134*cos(theta)**31 - 1.06560351661502e+134*cos(theta)**29 + 3.94020972445992e+133*cos(theta)**27 - 1.0915655984889e+133*cos(theta)**25 + 2.28679943817506e+132*cos(theta)**23 - 3.63189113533139e+131*cos(theta)**21 + 4.35826936239767e+130*cos(theta)**19 - 3.91625885953758e+129*cos(theta)**17 + 2.59557117396253e+128*cos(theta)**15 - 1.24048690608132e+127*cos(theta)**13 + 4.13849352755957e+125*cos(theta)**11 - 9.19665228346571e+123*cos(theta)**9 + 1.26947654219619e+122*cos(theta)**7 - 9.74022922401167e+119*cos(theta)**5 + 3.40329462753727e+117*cos(theta)**3 - 3.4226898701347e+114*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl97_m_minus_57(theta, phi):
    return 9.05288193924102e-112*(1.0 - cos(theta)**2)**28.5*(1.06877536984077e+132*cos(theta)**40 - 4.31940304909739e+132*cos(theta)**38 + 7.94905849087819e+132*cos(theta)**36 - 8.83228721208688e+132*cos(theta)**34 + 6.62421540906516e+132*cos(theta)**32 - 3.55201172205007e+132*cos(theta)**30 + 1.40721775873569e+132*cos(theta)**28 - 4.19832922495729e+131*cos(theta)**26 + 9.52833099239609e+130*cos(theta)**24 - 1.65085960696881e+130*cos(theta)**22 + 2.17913468119883e+129*cos(theta)**20 - 2.17569936640977e+128*cos(theta)**18 + 1.62223198372658e+127*cos(theta)**16 - 8.8606207577237e+125*cos(theta)**14 + 3.44874460629964e+124*cos(theta)**12 - 9.19665228346571e+122*cos(theta)**10 + 1.58684567774523e+121*cos(theta)**8 - 1.62337153733528e+119*cos(theta)**6 + 8.50823656884318e+116*cos(theta)**4 - 1.71134493506735e+114*cos(theta)**2 + 5.52046753247532e+110)*sin(57*phi)

#@torch.jit.script
def Yl97_m_minus_56(theta, phi):
    return 7.19348173874411e-110*(1.0 - cos(theta)**2)**28*(2.60676919473357e+130*cos(theta)**41 - 1.10753924335831e+131*cos(theta)**39 + 2.14839418672384e+131*cos(theta)**37 - 2.52351063202482e+131*cos(theta)**35 + 2.00733800274702e+131*cos(theta)**33 - 1.14581023291938e+131*cos(theta)**31 + 4.85247503012305e+130*cos(theta)**29 - 1.55493674998418e+130*cos(theta)**27 + 3.81133239695844e+129*cos(theta)**25 - 7.1776504650818e+128*cos(theta)**23 + 1.03768318152325e+128*cos(theta)**21 - 1.14510492968935e+127*cos(theta)**19 + 9.54254108074459e+125*cos(theta)**17 - 5.90708050514913e+124*cos(theta)**15 + 2.65288046638434e+123*cos(theta)**13 - 8.36059298496883e+121*cos(theta)**11 + 1.76316186416137e+120*cos(theta)**9 - 2.31910219619325e+118*cos(theta)**7 + 1.70164731376864e+116*cos(theta)**5 - 5.70448311689117e+113*cos(theta)**3 + 5.52046753247532e+110*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl97_m_minus_55(theta, phi):
    return 5.76646295081998e-108*(1.0 - cos(theta)**2)**27.5*(6.20659332079423e+128*cos(theta)**42 - 2.76884810839577e+129*cos(theta)**40 + 5.65366891243115e+129*cos(theta)**38 - 7.00975175562451e+129*cos(theta)**36 + 5.90393530219711e+129*cos(theta)**34 - 3.58065697787306e+129*cos(theta)**32 + 1.61749167670768e+129*cos(theta)**30 - 5.55334553565779e+128*cos(theta)**28 + 1.46589707575324e+128*cos(theta)**26 - 2.99068769378408e+127*cos(theta)**24 + 4.71674173419661e+126*cos(theta)**22 - 5.72552464844675e+125*cos(theta)**20 + 5.30141171152477e+124*cos(theta)**18 - 3.69192531571821e+123*cos(theta)**16 + 1.89491461884596e+122*cos(theta)**14 - 6.96716082080736e+120*cos(theta)**12 + 1.76316186416137e+119*cos(theta)**10 - 2.89887774524157e+117*cos(theta)**8 + 2.83607885628106e+115*cos(theta)**6 - 1.42612077922279e+113*cos(theta)**4 + 2.76023376623766e+110*cos(theta)**2 - 8.59083027151467e+106)*sin(55*phi)

#@torch.jit.script
def Yl97_m_minus_54(theta, phi):
    return 4.66192763435192e-106*(1.0 - cos(theta)**2)**27*(1.44339379553354e+127*cos(theta)**43 - 6.75328806925797e+127*cos(theta)**41 + 1.44965869549517e+128*cos(theta)**39 - 1.89452750152014e+128*cos(theta)**37 + 1.6868386577706e+128*cos(theta)**35 - 1.08504756905244e+128*cos(theta)**33 + 5.21771508615382e+127*cos(theta)**31 - 1.91494673643372e+127*cos(theta)**29 + 5.42924842871572e+126*cos(theta)**27 - 1.19627507751363e+126*cos(theta)**25 + 2.05075727573766e+125*cos(theta)**23 - 2.72644030878417e+124*cos(theta)**21 + 2.7902166902762e+123*cos(theta)**19 - 2.17172077395189e+122*cos(theta)**17 + 1.26327641256397e+121*cos(theta)**15 - 5.35935447754412e+119*cos(theta)**13 + 1.60287442196488e+118*cos(theta)**11 - 3.22097527249063e+116*cos(theta)**9 + 4.05154122325866e+114*cos(theta)**7 - 2.85224155844558e+112*cos(theta)**5 + 9.20077922079221e+109*cos(theta)**3 - 8.59083027151467e+106*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl97_m_minus_53(theta, phi):
    return 3.79997150273728e-104*(1.0 - cos(theta)**2)**26.5*(3.28044044439441e+125*cos(theta)**44 - 1.60792573077571e+126*cos(theta)**42 + 3.62414673873791e+126*cos(theta)**40 - 4.98559868821089e+126*cos(theta)**38 + 4.68566293825168e+126*cos(theta)**36 - 3.19131637956601e+126*cos(theta)**34 + 1.63053596442307e+126*cos(theta)**32 - 6.38315578811241e+125*cos(theta)**30 + 1.9390172959699e+125*cos(theta)**28 - 4.60105799043705e+124*cos(theta)**26 + 8.54482198224024e+123*cos(theta)**24 - 1.23929104944735e+123*cos(theta)**22 + 1.3951083451381e+122*cos(theta)**20 - 1.20651154108438e+121*cos(theta)**18 + 7.89547757852482e+119*cos(theta)**16 - 3.82811034110294e+118*cos(theta)**14 + 1.33572868497074e+117*cos(theta)**12 - 3.22097527249063e+115*cos(theta)**10 + 5.06442652907332e+113*cos(theta)**8 - 4.75373593074264e+111*cos(theta)**6 + 2.30019480519805e+109*cos(theta)**4 - 4.29541513575733e+106*cos(theta)**2 + 1.29302081148625e+103)*sin(53*phi)

#@torch.jit.script
def Yl97_m_minus_52(theta, phi):
    return 3.12199516488902e-102*(1.0 - cos(theta)**2)**26*(7.2898676542098e+123*cos(theta)**45 - 3.73936216459467e+124*cos(theta)**43 + 8.83938228960467e+124*cos(theta)**41 - 1.27835863800279e+125*cos(theta)**39 + 1.26639538871667e+125*cos(theta)**37 - 9.11804679876002e+124*cos(theta)**35 + 4.9410180740093e+124*cos(theta)**33 - 2.05908251229432e+124*cos(theta)**31 + 6.68626653782724e+123*cos(theta)**29 - 1.70409555201372e+123*cos(theta)**27 + 3.4179287928961e+122*cos(theta)**25 - 5.38822195411891e+121*cos(theta)**23 + 6.64337307208618e+120*cos(theta)**21 - 6.35006074254938e+119*cos(theta)**19 + 4.64439857560284e+118*cos(theta)**17 - 2.5520735607353e+117*cos(theta)**15 + 1.02748360382364e+116*cos(theta)**13 - 2.92815933862785e+114*cos(theta)**11 + 5.62714058785924e+112*cos(theta)**9 - 6.79105132963234e+110*cos(theta)**7 + 4.6003896103961e+108*cos(theta)**5 - 1.43180504525244e+106*cos(theta)**3 + 1.29302081148625e+103*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl97_m_minus_51(theta, phi):
    return 2.58466508489848e-100*(1.0 - cos(theta)**2)**25.5*(1.5847538378717e+122*cos(theta)**46 - 8.49855037407878e+122*cos(theta)**44 + 2.10461483085825e+123*cos(theta)**42 - 3.19589659500698e+123*cos(theta)**40 + 3.33261944399123e+123*cos(theta)**38 - 2.53279077743334e+123*cos(theta)**36 + 1.45324061000273e+123*cos(theta)**34 - 6.43463285091977e+122*cos(theta)**32 + 2.22875551260908e+122*cos(theta)**30 - 6.08605554290615e+121*cos(theta)**28 + 1.31458799726773e+121*cos(theta)**26 - 2.24509248088288e+120*cos(theta)**24 + 3.01971503276645e+119*cos(theta)**22 - 3.17503037127469e+118*cos(theta)**20 + 2.58022143089047e+117*cos(theta)**18 - 1.59504597545956e+116*cos(theta)**16 + 7.33916859874031e+114*cos(theta)**14 - 2.44013278218987e+113*cos(theta)**12 + 5.62714058785924e+111*cos(theta)**10 - 8.48881416204043e+109*cos(theta)**8 + 7.66731601732684e+107*cos(theta)**6 - 3.57951261313111e+105*cos(theta)**4 + 6.46510405743126e+102*cos(theta)**2 - 1.88652000508645e+99)*sin(51*phi)

#@torch.jit.script
def Yl97_m_minus_50(theta, phi):
    return 2.15567886034086e-98*(1.0 - cos(theta)**2)**25*(3.37181667632276e+120*cos(theta)**47 - 1.88856674979529e+121*cos(theta)**45 + 4.8944530950192e+121*cos(theta)**43 - 7.79486974391946e+121*cos(theta)**41 + 8.54517806151599e+121*cos(theta)**39 - 6.84538047954956e+121*cos(theta)**37 + 4.15211602857924e+121*cos(theta)**35 - 1.94988874270296e+121*cos(theta)**33 + 7.1895339116422e+120*cos(theta)**31 - 2.09863984238143e+120*cos(theta)**29 + 4.86884443432492e+119*cos(theta)**27 - 8.98036992353152e+118*cos(theta)**25 + 1.31291957946367e+118*cos(theta)**23 - 1.51191922441652e+117*cos(theta)**21 + 1.35801127941603e+116*cos(theta)**19 - 9.38262338505624e+114*cos(theta)**17 + 4.89277906582687e+113*cos(theta)**15 - 1.87702521706913e+112*cos(theta)**13 + 5.11558235259931e+110*cos(theta)**11 - 9.43201573560048e+108*cos(theta)**9 + 1.09533085961812e+107*cos(theta)**7 - 7.15902522626222e+104*cos(theta)**5 + 2.15503468581042e+102*cos(theta)**3 - 1.88652000508645e+99*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl97_m_minus_49(theta, phi):
    return 1.81077024268632e-96*(1.0 - cos(theta)**2)**24.5*(7.02461807567241e+118*cos(theta)**48 - 4.10557989085932e+119*cos(theta)**46 + 1.11237570341345e+120*cos(theta)**44 - 1.85592136759987e+120*cos(theta)**42 + 2.136294515379e+120*cos(theta)**40 - 1.80141591567094e+120*cos(theta)**38 + 1.15336556349423e+120*cos(theta)**36 - 5.73496689030282e+119*cos(theta)**34 + 2.24672934738819e+119*cos(theta)**32 - 6.99546614127144e+118*cos(theta)**30 + 1.7388730122589e+118*cos(theta)**28 - 3.45398843212751e+117*cos(theta)**26 + 5.4704982477653e+116*cos(theta)**24 - 6.87236011098417e+115*cos(theta)**22 + 6.79005639708017e+114*cos(theta)**20 - 5.21256854725346e+113*cos(theta)**18 + 3.0579869161418e+112*cos(theta)**16 - 1.34073229790652e+111*cos(theta)**14 + 4.26298529383276e+109*cos(theta)**12 - 9.43201573560048e+107*cos(theta)**10 + 1.36916357452265e+106*cos(theta)**8 - 1.1931708710437e+104*cos(theta)**6 + 5.38758671452605e+101*cos(theta)**4 - 9.43260002543225e+98*cos(theta)**2 + 2.673639462991e+95)*sin(49*phi)

#@torch.jit.script
def Yl97_m_minus_48(theta, phi):
    return 1.53157340629971e-94*(1.0 - cos(theta)**2)**24*(1.43359552564743e+117*cos(theta)**49 - 8.73527636353046e+117*cos(theta)**47 + 2.47194600758545e+118*cos(theta)**45 - 4.31609620372063e+118*cos(theta)**43 + 5.21047442775365e+118*cos(theta)**41 - 4.61901516838702e+118*cos(theta)**39 + 3.11720422566009e+118*cos(theta)**37 - 1.63856196865795e+118*cos(theta)**35 + 6.80827074966117e+117*cos(theta)**33 - 2.2566019810553e+117*cos(theta)**31 + 5.99611383537552e+116*cos(theta)**29 - 1.27925497486204e+116*cos(theta)**27 + 2.18819929910612e+115*cos(theta)**25 - 2.98798265694964e+114*cos(theta)**23 + 3.2333601890858e+113*cos(theta)**21 - 2.7434571301334e+112*cos(theta)**19 + 1.79881583302459e+111*cos(theta)**17 - 8.93821531937682e+109*cos(theta)**15 + 3.27921945679443e+108*cos(theta)**13 - 8.5745597596368e+106*cos(theta)**11 + 1.52129286058072e+105*cos(theta)**9 - 1.70452981577672e+103*cos(theta)**7 + 1.07751734290521e+101*cos(theta)**5 - 3.14420000847742e+98*cos(theta)**3 + 2.673639462991e+95*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl97_m_minus_47(theta, phi):
    return 1.30408776418279e-92*(1.0 - cos(theta)**2)**23.5*(2.86719105129486e+115*cos(theta)**50 - 1.81984924240218e+116*cos(theta)**48 + 5.37379566866403e+116*cos(theta)**46 - 9.80930955391052e+116*cos(theta)**44 + 1.24058914946515e+117*cos(theta)**42 - 1.15475379209675e+117*cos(theta)**40 + 8.20316901489498e+116*cos(theta)**38 - 4.55156102404986e+116*cos(theta)**36 + 2.00243257342976e+116*cos(theta)**34 - 7.05188119079782e+115*cos(theta)**32 + 1.99870461179184e+115*cos(theta)**30 - 4.56876776736443e+114*cos(theta)**28 + 8.41615115040815e+113*cos(theta)**26 - 1.24499277372902e+113*cos(theta)**24 + 1.46970917685718e+112*cos(theta)**22 - 1.3717285650667e+111*cos(theta)**20 + 9.99342129458103e+109*cos(theta)**18 - 5.58638457461051e+108*cos(theta)**16 + 2.34229961199602e+107*cos(theta)**14 - 7.145466466364e+105*cos(theta)**12 + 1.52129286058072e+104*cos(theta)**10 - 2.1306622697209e+102*cos(theta)**8 + 1.79586223817535e+100*cos(theta)**6 - 7.86050002119354e+97*cos(theta)**4 + 1.3368197314955e+95*cos(theta)**2 - 3.68777856964276e+91)*sin(47*phi)

#@torch.jit.script
def Yl97_m_minus_46(theta, phi):
    return 1.11756593189398e-90*(1.0 - cos(theta)**2)**23*(5.62194323783306e+113*cos(theta)**51 - 3.71397804571873e+114*cos(theta)**49 + 1.14336078056681e+115*cos(theta)**47 - 2.17984656753567e+115*cos(theta)**45 + 2.8850910452678e+115*cos(theta)**43 - 2.81647266365062e+115*cos(theta)**41 + 2.10337667048589e+115*cos(theta)**39 - 1.23015162812158e+115*cos(theta)**37 + 5.72123592408502e+114*cos(theta)**35 - 2.13693369418116e+114*cos(theta)**33 + 6.44743423158658e+113*cos(theta)**31 - 1.57543716116015e+113*cos(theta)**29 + 3.11709301866969e+112*cos(theta)**27 - 4.97997109491607e+111*cos(theta)**25 + 6.39003989937904e+110*cos(theta)**23 - 6.53204078603191e+109*cos(theta)**21 + 5.25969541820054e+108*cos(theta)**19 - 3.2861085733003e+107*cos(theta)**17 + 1.56153307466401e+106*cos(theta)**15 - 5.49651266643384e+104*cos(theta)**13 + 1.38299350961884e+103*cos(theta)**11 - 2.36740252191211e+101*cos(theta)**9 + 2.56551748310764e+99*cos(theta)**7 - 1.57210000423871e+97*cos(theta)**5 + 4.45606577165167e+94*cos(theta)**3 - 3.68777856964276e+91*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl97_m_minus_45(theta, phi):
    return 9.63702187389815e-89*(1.0 - cos(theta)**2)**22.5*(1.08114293035251e+112*cos(theta)**52 - 7.42795609143747e+112*cos(theta)**50 + 2.38200162618086e+113*cos(theta)**48 - 4.73879688594711e+113*cos(theta)**46 + 6.55702510288137e+113*cos(theta)**44 - 6.70588729440624e+113*cos(theta)**42 + 5.25844167621473e+113*cos(theta)**40 - 3.23724112663575e+113*cos(theta)**38 + 1.58923220113473e+113*cos(theta)**36 - 6.28509910053282e+112*cos(theta)**34 + 2.01482319737081e+112*cos(theta)**32 - 5.25145720386716e+111*cos(theta)**30 + 1.11324750666775e+111*cos(theta)**28 - 1.91537349804464e+110*cos(theta)**26 + 2.66251662474127e+109*cos(theta)**24 - 2.96910944819632e+108*cos(theta)**22 + 2.62984770910027e+107*cos(theta)**20 - 1.82561587405572e+106*cos(theta)**18 + 9.75958171665009e+104*cos(theta)**16 - 3.92608047602417e+103*cos(theta)**14 + 1.15249459134903e+102*cos(theta)**12 - 2.36740252191211e+100*cos(theta)**10 + 3.20689685388456e+98*cos(theta)**8 - 2.62016667373118e+96*cos(theta)**6 + 1.11401644291292e+94*cos(theta)**4 - 1.84388928482138e+91*cos(theta)**2 + 4.95935794734099e+87)*sin(45*phi)

#@torch.jit.script
def Yl97_m_minus_44(theta, phi):
    return 8.36035948055156e-87*(1.0 - cos(theta)**2)**22*(2.03989232141983e+110*cos(theta)**53 - 1.45646197871323e+111*cos(theta)**51 + 4.86122780853237e+111*cos(theta)**49 - 1.00825465658449e+112*cos(theta)**47 + 1.45711668952919e+112*cos(theta)**45 - 1.55950867311773e+112*cos(theta)**43 + 1.28254675029628e+112*cos(theta)**41 - 8.30061827342499e+111*cos(theta)**39 + 4.29522216522899e+111*cos(theta)**37 - 1.79574260015223e+111*cos(theta)**35 + 6.1055248405176e+110*cos(theta)**33 - 1.69401845286037e+110*cos(theta)**31 + 3.83878450575085e+109*cos(theta)**29 - 7.09397591868386e+108*cos(theta)**27 + 1.06500664989651e+108*cos(theta)**25 - 1.29091715138971e+107*cos(theta)**23 + 1.25230843290489e+106*cos(theta)**21 - 9.60850460029328e+104*cos(theta)**19 + 5.74093042155888e+103*cos(theta)**17 - 2.61738698401612e+102*cos(theta)**15 + 8.86534301037717e+100*cos(theta)**13 - 2.15218411082919e+99*cos(theta)**11 + 3.5632187265384e+97*cos(theta)**9 - 3.7430952481874e+95*cos(theta)**7 + 2.22803288582583e+93*cos(theta)**5 - 6.14629761607127e+90*cos(theta)**3 + 4.95935794734099e+87*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl97_m_minus_43(theta, phi):
    return 7.2951023258333e-85*(1.0 - cos(theta)**2)**21.5*(3.77757837299969e+108*cos(theta)**54 - 2.80088842060236e+109*cos(theta)**52 + 9.72245561706475e+109*cos(theta)**50 - 2.10053053455103e+110*cos(theta)**48 + 3.16764497723737e+110*cos(theta)**46 - 3.54433789344939e+110*cos(theta)**44 + 3.05368273880066e+110*cos(theta)**42 - 2.07515456835625e+110*cos(theta)**40 + 1.13032162242868e+110*cos(theta)**38 - 4.98817388931176e+109*cos(theta)**36 + 1.79574260015223e+109*cos(theta)**34 - 5.29380766518867e+108*cos(theta)**32 + 1.27959483525028e+108*cos(theta)**30 - 2.53356282810138e+107*cos(theta)**28 + 4.09617942267887e+106*cos(theta)**26 - 5.37882146412377e+105*cos(theta)**24 + 5.69231105865859e+104*cos(theta)**22 - 4.80425230014664e+103*cos(theta)**20 + 3.18940578975493e+102*cos(theta)**18 - 1.63586686501007e+101*cos(theta)**16 + 6.33238786455512e+99*cos(theta)**14 - 1.79348675902433e+98*cos(theta)**12 + 3.5632187265384e+96*cos(theta)**10 - 4.67886906023425e+94*cos(theta)**8 + 3.71338814304306e+92*cos(theta)**6 - 1.53657440401782e+90*cos(theta)**4 + 2.47967897367049e+87*cos(theta)**2 - 6.51347248140398e+83)*sin(43*phi)

#@torch.jit.script
def Yl97_m_minus_42(theta, phi):
    return 6.40142631115686e-83*(1.0 - cos(theta)**2)**21*(6.8683243145449e+106*cos(theta)**55 - 5.28469513321201e+107*cos(theta)**53 + 1.90636384648328e+108*cos(theta)**51 - 4.28679700928781e+108*cos(theta)**49 + 6.73967016433484e+108*cos(theta)**47 - 7.87630642988753e+108*cos(theta)**45 + 7.10158776465269e+108*cos(theta)**43 - 5.06135260574694e+108*cos(theta)**41 + 2.89826057032995e+108*cos(theta)**39 - 1.34815510521939e+108*cos(theta)**37 + 5.1306931432921e+107*cos(theta)**35 - 1.60418414096626e+107*cos(theta)**33 + 4.12772527500091e+106*cos(theta)**31 - 8.73642354517716e+105*cos(theta)**29 + 1.51710348988106e+105*cos(theta)**27 - 2.15152858564951e+104*cos(theta)**25 + 2.47491785159069e+103*cos(theta)**23 - 2.28773919054602e+102*cos(theta)**21 + 1.67863462618681e+101*cos(theta)**19 - 9.62274626476513e+99*cos(theta)**17 + 4.22159190970341e+98*cos(theta)**15 - 1.37960519924948e+97*cos(theta)**13 + 3.23928975139854e+95*cos(theta)**11 - 5.19874340026028e+93*cos(theta)**9 + 5.30484020434722e+91*cos(theta)**7 - 3.07314880803563e+89*cos(theta)**5 + 8.26559657890165e+86*cos(theta)**3 - 6.51347248140398e+83*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl97_m_minus_41(theta, phi):
    return 5.64778511128798e-81*(1.0 - cos(theta)**2)**20.5*(1.22648648474016e+105*cos(theta)**56 - 9.78647246891112e+105*cos(theta)**54 + 3.66608432016016e+106*cos(theta)**52 - 8.57359401857561e+106*cos(theta)**50 + 1.40409795090309e+107*cos(theta)**48 - 1.71224052823642e+107*cos(theta)**46 + 1.61399721923925e+107*cos(theta)**44 - 1.20508395374927e+107*cos(theta)**42 + 7.24565142582488e+106*cos(theta)**40 - 3.54777659268262e+106*cos(theta)**38 + 1.42519253980336e+106*cos(theta)**36 - 4.71818864990077e+105*cos(theta)**34 + 1.28991414843778e+105*cos(theta)**32 - 2.91214118172572e+104*cos(theta)**30 + 5.41822674957523e+103*cos(theta)**28 - 8.27510994480581e+102*cos(theta)**26 + 1.03121577149612e+102*cos(theta)**24 - 1.03988145024819e+101*cos(theta)**22 + 8.39317313093403e+99*cos(theta)**20 - 5.34597014709174e+98*cos(theta)**18 + 2.63849494356463e+97*cos(theta)**16 - 9.85432285178201e+95*cos(theta)**14 + 2.69940812616545e+94*cos(theta)**12 - 5.19874340026028e+92*cos(theta)**10 + 6.63105025543403e+90*cos(theta)**8 - 5.12191468005939e+88*cos(theta)**6 + 2.06639914472541e+86*cos(theta)**4 - 3.25673624070199e+83*cos(theta)**2 + 8.36777040262587e+79)*sin(41*phi)

#@torch.jit.script
def Yl97_m_minus_40(theta, phi):
    return 5.00904732891804e-79*(1.0 - cos(theta)**2)**20*(2.15173067498274e+103*cos(theta)**57 - 1.77935863071111e+104*cos(theta)**55 + 6.91714022671728e+104*cos(theta)**53 - 1.68109686638738e+105*cos(theta)**51 + 2.86550602225121e+105*cos(theta)**49 - 3.64306495369451e+105*cos(theta)**47 + 3.58666048719833e+105*cos(theta)**45 - 2.80252082267273e+105*cos(theta)**43 + 1.76723205507924e+105*cos(theta)**41 - 9.09686305816056e+104*cos(theta)**39 + 3.85187172919827e+104*cos(theta)**37 - 1.34805389997165e+104*cos(theta)**35 + 3.90883075284177e+103*cos(theta)**33 - 9.39400381201845e+102*cos(theta)**31 + 1.86835405157767e+102*cos(theta)**29 - 3.06485553511326e+101*cos(theta)**27 + 4.12486308598449e+100*cos(theta)**25 - 4.52122369673126e+99*cos(theta)**23 + 3.99674910996859e+98*cos(theta)**21 - 2.81366849846934e+97*cos(theta)**19 + 1.55205584915567e+96*cos(theta)**17 - 6.56954856785467e+94*cos(theta)**15 + 2.07646778935804e+93*cos(theta)**13 - 4.72613036387298e+91*cos(theta)**11 + 7.36783361714892e+89*cos(theta)**9 - 7.31702097151341e+87*cos(theta)**7 + 4.13279828945082e+85*cos(theta)**5 - 1.08557874690066e+83*cos(theta)**3 + 8.36777040262587e+79*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl97_m_minus_39(theta, phi):
    return 4.4650817592625e-77*(1.0 - cos(theta)**2)**19.5*(3.70988047410817e+101*cos(theta)**58 - 3.17742612626984e+102*cos(theta)**56 + 1.28095189383653e+103*cos(theta)**54 - 3.23287858920649e+103*cos(theta)**52 + 5.73101204450242e+103*cos(theta)**50 - 7.58971865353023e+103*cos(theta)**48 + 7.79708801564854e+103*cos(theta)**46 - 6.36936550607438e+103*cos(theta)**44 + 4.20769536923629e+103*cos(theta)**42 - 2.27421576454014e+103*cos(theta)**40 + 1.01365045505218e+103*cos(theta)**38 - 3.74459416658791e+102*cos(theta)**36 + 1.14965610377699e+102*cos(theta)**34 - 2.93562619125577e+101*cos(theta)**32 + 6.22784683859222e+100*cos(theta)**30 - 1.09459126254045e+100*cos(theta)**28 + 1.58648580230173e+99*cos(theta)**26 - 1.88384320697136e+98*cos(theta)**24 + 1.81670414089481e+97*cos(theta)**22 - 1.40683424923467e+96*cos(theta)**20 + 8.62253249530926e+94*cos(theta)**18 - 4.10596785490917e+93*cos(theta)**16 + 1.48319127811289e+92*cos(theta)**14 - 3.93844196989415e+90*cos(theta)**12 + 7.36783361714892e+88*cos(theta)**10 - 9.14627621439177e+86*cos(theta)**8 + 6.88799714908471e+84*cos(theta)**6 - 2.71394686725166e+82*cos(theta)**4 + 4.18388520131294e+79*cos(theta)**2 - 1.05307958754416e+76)*sin(39*phi)

#@torch.jit.script
def Yl97_m_minus_38(theta, phi):
    return 3.99967658515029e-75*(1.0 - cos(theta)**2)**19*(6.28793300696299e+99*cos(theta)**59 - 5.57443180047341e+100*cos(theta)**57 + 2.32900344333915e+101*cos(theta)**55 - 6.09977092303112e+101*cos(theta)**53 + 1.12372785186322e+102*cos(theta)**51 - 1.54892217418984e+102*cos(theta)**49 + 1.6589548969465e+102*cos(theta)**47 - 1.41541455690542e+102*cos(theta)**45 + 9.78533806799136e+101*cos(theta)**43 - 5.54686771839058e+101*cos(theta)**41 + 2.59910373090302e+101*cos(theta)**39 - 1.01205247745619e+101*cos(theta)**37 + 3.28473172507712e+100*cos(theta)**35 - 8.89583694319929e+99*cos(theta)**33 + 2.00898285115878e+99*cos(theta)**31 - 3.77445262944983e+98*cos(theta)**29 + 5.87587334185825e+97*cos(theta)**27 - 7.53537282788544e+96*cos(theta)**25 + 7.8987136560644e+95*cos(theta)**23 - 6.69921071064128e+94*cos(theta)**21 + 4.53817499753119e+93*cos(theta)**19 - 2.4152752087701e+92*cos(theta)**17 + 9.8879418540859e+90*cos(theta)**15 - 3.02957074607242e+89*cos(theta)**13 + 6.69803056104448e+87*cos(theta)**11 - 1.0162529127102e+86*cos(theta)**9 + 9.83999592726387e+83*cos(theta)**7 - 5.42789373450332e+81*cos(theta)**5 + 1.39462840043765e+79*cos(theta)**3 - 1.05307958754416e+76*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl97_m_minus_37(theta, phi):
    return 3.59970892663526e-73*(1.0 - cos(theta)**2)**18.5*(1.04798883449383e+98*cos(theta)**60 - 9.61108931116105e+98*cos(theta)**58 + 4.15893472024849e+99*cos(theta)**56 - 1.12958720796872e+100*cos(theta)**54 + 2.16101509973696e+100*cos(theta)**52 - 3.09784434837968e+100*cos(theta)**50 + 3.4561560353052e+100*cos(theta)**48 - 3.07698816718569e+100*cos(theta)**46 + 2.22394046999804e+100*cos(theta)**44 - 1.320682790093e+100*cos(theta)**42 + 6.49775932725754e+99*cos(theta)**40 - 2.66329599330577e+99*cos(theta)**38 + 9.12425479188088e+98*cos(theta)**36 - 2.61642263035273e+98*cos(theta)**34 + 6.27807140987119e+97*cos(theta)**32 - 1.25815087648328e+97*cos(theta)**30 + 2.0985261935208e+96*cos(theta)**28 - 2.89822031841748e+95*cos(theta)**26 + 3.29113069002683e+94*cos(theta)**24 - 3.04509577756422e+93*cos(theta)**22 + 2.26908749876559e+92*cos(theta)**20 - 1.34181956042783e+91*cos(theta)**18 + 6.17996365880369e+89*cos(theta)**16 - 2.16397910433745e+88*cos(theta)**14 + 5.58169213420373e+86*cos(theta)**12 - 1.0162529127102e+85*cos(theta)**10 + 1.22999949090798e+83*cos(theta)**8 - 9.04648955750553e+80*cos(theta)**6 + 3.48657100109411e+78*cos(theta)**4 - 5.26539793772079e+75*cos(theta)**2 + 1.30009825622735e+72)*sin(37*phi)

#@torch.jit.script
def Yl97_m_minus_36(theta, phi):
    return 3.2545031911186e-71*(1.0 - cos(theta)**2)**18*(1.71801448277677e+96*cos(theta)**61 - 1.62899818833238e+97*cos(theta)**59 + 7.29637670219033e+97*cos(theta)**57 - 2.0537949235795e+98*cos(theta)**55 + 4.07738698063577e+98*cos(theta)**53 - 6.07420460466605e+98*cos(theta)**51 + 7.05337966388817e+98*cos(theta)**49 - 6.54678333443764e+98*cos(theta)**47 + 4.94208993332897e+98*cos(theta)**45 - 3.07135532579767e+98*cos(theta)**43 + 1.5848193481116e+98*cos(theta)**41 - 6.82896408539941e+97*cos(theta)**39 + 2.46601480861645e+97*cos(theta)**37 - 7.47549322957924e+96*cos(theta)**35 + 1.90244588177915e+96*cos(theta)**33 - 4.05855121446218e+95*cos(theta)**31 + 7.23629721903725e+94*cos(theta)**29 - 1.07341493274721e+94*cos(theta)**27 + 1.31645227601073e+93*cos(theta)**25 - 1.32395468589749e+92*cos(theta)**23 + 1.08051785655504e+91*cos(theta)**21 - 7.06220821277807e+89*cos(theta)**19 + 3.63527274047276e+88*cos(theta)**17 - 1.44265273622496e+87*cos(theta)**15 + 4.29360933400287e+85*cos(theta)**13 - 9.23866284281997e+83*cos(theta)**11 + 1.36666610100887e+82*cos(theta)**9 - 1.29235565107222e+80*cos(theta)**7 + 6.97314200218823e+77*cos(theta)**5 - 1.75513264590693e+75*cos(theta)**3 + 1.30009825622735e+72*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl97_m_minus_35(theta, phi):
    return 2.95533261679926e-69*(1.0 - cos(theta)**2)**17.5*(2.77099110125286e+94*cos(theta)**62 - 2.71499698055397e+95*cos(theta)**60 + 1.25799598313626e+96*cos(theta)**58 - 3.66749093496339e+96*cos(theta)**56 + 7.55071663080699e+96*cos(theta)**54 - 1.16811627012809e+97*cos(theta)**52 + 1.41067593277763e+97*cos(theta)**50 - 1.36391319467451e+97*cos(theta)**48 + 1.07436737681065e+97*cos(theta)**46 - 6.98035301317651e+96*cos(theta)**44 + 3.7733794002657e+96*cos(theta)**42 - 1.70724102134985e+96*cos(theta)**40 + 6.48951265425383e+95*cos(theta)**38 - 2.07652589710534e+95*cos(theta)**36 + 5.59542906405632e+94*cos(theta)**34 - 1.26829725451943e+94*cos(theta)**32 + 2.41209907301242e+93*cos(theta)**30 - 3.83362475981148e+92*cos(theta)**28 + 5.06327798465667e+91*cos(theta)**26 - 5.51647785790619e+90*cos(theta)**24 + 4.91144480252293e+89*cos(theta)**22 - 3.53110410638904e+88*cos(theta)**20 + 2.01959596692931e+87*cos(theta)**18 - 9.01657960140602e+85*cos(theta)**16 + 3.06686381000205e+84*cos(theta)**14 - 7.69888570234997e+82*cos(theta)**12 + 1.36666610100887e+81*cos(theta)**10 - 1.61544456384027e+79*cos(theta)**8 + 1.16219033369804e+77*cos(theta)**6 - 4.38783161476732e+74*cos(theta)**4 + 6.50049128113677e+71*cos(theta)**2 - 1.5766411062665e+68)*sin(35*phi)

#@torch.jit.script
def Yl97_m_minus_34(theta, phi):
    return 2.69503002068864e-67*(1.0 - cos(theta)**2)**17*(4.39839857341724e+92*cos(theta)**63 - 4.45081472221962e+93*cos(theta)**61 + 2.13219658158689e+94*cos(theta)**59 - 6.43419462274279e+94*cos(theta)**57 + 1.37285756923763e+95*cos(theta)**55 - 2.20399296250582e+95*cos(theta)**53 + 2.76603124074046e+95*cos(theta)**51 - 2.78349631566226e+95*cos(theta)**49 + 2.28588803576733e+95*cos(theta)**47 - 1.55118955848367e+95*cos(theta)**45 + 8.77530093085047e+94*cos(theta)**43 - 4.1640024910972e+94*cos(theta)**41 + 1.66397760365483e+94*cos(theta)**39 - 5.61223215433877e+93*cos(theta)**37 + 1.5986940183018e+93*cos(theta)**35 - 3.84332501369525e+92*cos(theta)**33 + 7.78096475165296e+91*cos(theta)**31 - 1.32193957234879e+91*cos(theta)**29 + 1.87528814246543e+90*cos(theta)**27 - 2.20659114316248e+89*cos(theta)**25 + 2.13541078370562e+88*cos(theta)**23 - 1.68147814589954e+87*cos(theta)**21 + 1.06294524575227e+86*cos(theta)**19 - 5.30387035376825e+84*cos(theta)**17 + 2.0445758733347e+83*cos(theta)**15 - 5.92221977103844e+81*cos(theta)**13 + 1.24242372818988e+80*cos(theta)**11 - 1.79493840426697e+78*cos(theta)**9 + 1.66027190528291e+76*cos(theta)**7 - 8.77566322953464e+73*cos(theta)**5 + 2.16683042704559e+71*cos(theta)**3 - 1.5766411062665e+68*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl97_m_minus_33(theta, phi):
    return 2.4676822776701e-65*(1.0 - cos(theta)**2)**16.5*(6.87249777096444e+90*cos(theta)**64 - 7.17873342293488e+91*cos(theta)**62 + 3.55366096931148e+92*cos(theta)**60 - 1.1093439004729e+93*cos(theta)**58 + 2.45153137363863e+93*cos(theta)**56 - 4.08146844908486e+93*cos(theta)**54 + 5.31929084757781e+93*cos(theta)**52 - 5.56699263132452e+93*cos(theta)**50 + 4.76226674118194e+93*cos(theta)**48 - 3.37215121409493e+93*cos(theta)**46 + 1.99438657519329e+93*cos(theta)**44 - 9.91429164546953e+92*cos(theta)**42 + 4.15994400913707e+92*cos(theta)**40 - 1.4769031985102e+92*cos(theta)**38 + 4.44081671750501e+91*cos(theta)**36 - 1.13038970991037e+91*cos(theta)**34 + 2.43155148489155e+90*cos(theta)**32 - 4.40646524116262e+89*cos(theta)**30 + 6.69745765166226e+88*cos(theta)**28 - 8.48688901216337e+87*cos(theta)**26 + 8.89754493210676e+86*cos(theta)**24 - 7.64308248136155e+85*cos(theta)**22 + 5.31472622876134e+84*cos(theta)**20 - 2.94659464098236e+83*cos(theta)**18 + 1.27785992083419e+82*cos(theta)**16 - 4.23015697931317e+80*cos(theta)**14 + 1.0353531068249e+79*cos(theta)**12 - 1.79493840426697e+77*cos(theta)**10 + 2.07533988160364e+75*cos(theta)**8 - 1.46261053825577e+73*cos(theta)**6 + 5.41707606761398e+70*cos(theta)**4 - 7.88320553133249e+67*cos(theta)**2 + 1.88053567064229e+64)*sin(33*phi)

#@torch.jit.script
def Yl97_m_minus_32(theta, phi):
    return 2.26838933406071e-63*(1.0 - cos(theta)**2)**16*(1.05730734937914e+89*cos(theta)**65 - 1.13948149570395e+90*cos(theta)**63 + 5.82567372018275e+90*cos(theta)**61 - 1.8802438991066e+91*cos(theta)**59 + 4.30093223445374e+91*cos(theta)**57 - 7.42085172560883e+91*cos(theta)**55 + 1.00363978256185e+92*cos(theta)**53 - 1.09156718261265e+92*cos(theta)**51 + 9.71891171669784e+91*cos(theta)**49 - 7.17478981722326e+91*cos(theta)**47 + 4.4319701670962e+91*cos(theta)**45 - 2.30564921987664e+91*cos(theta)**43 + 1.01462049003343e+91*cos(theta)**41 - 3.78693127823129e+90*cos(theta)**39 + 1.20022073446081e+90*cos(theta)**37 - 3.22968488545819e+89*cos(theta)**35 + 7.36833783300469e+88*cos(theta)**33 - 1.42144040037504e+88*cos(theta)**31 + 2.30946815574561e+87*cos(theta)**29 - 3.14329222672717e+86*cos(theta)**27 + 3.5590179728427e+85*cos(theta)**25 - 3.32307933972241e+84*cos(theta)**23 + 2.53082201369588e+83*cos(theta)**21 - 1.55083928472756e+82*cos(theta)**19 + 7.51682306373051e+80*cos(theta)**17 - 2.82010465287545e+79*cos(theta)**15 + 7.96425466788386e+77*cos(theta)**13 - 1.63176218569725e+76*cos(theta)**11 + 2.30593320178182e+74*cos(theta)**9 - 2.08944362607968e+72*cos(theta)**7 + 1.0834152135228e+70*cos(theta)**5 - 2.62773517711083e+67*cos(theta)**3 + 1.88053567064229e+64*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl97_m_minus_31(theta, phi):
    return 2.09307321216616e-61*(1.0 - cos(theta)**2)**15.5*(1.60198083239264e+87*cos(theta)**66 - 1.78043983703742e+88*cos(theta)**64 + 9.39624793577863e+88*cos(theta)**62 - 3.13373983184434e+89*cos(theta)**60 + 7.41540040423059e+89*cos(theta)**58 - 1.32515209385872e+90*cos(theta)**56 + 1.85859218992935e+90*cos(theta)**54 - 2.09916765887048e+90*cos(theta)**52 + 1.94378234333957e+90*cos(theta)**50 - 1.49474787858818e+90*cos(theta)**48 + 9.63471775455695e+89*cos(theta)**46 - 5.24011186335599e+89*cos(theta)**44 + 2.41576307150817e+89*cos(theta)**42 - 9.46732819557822e+88*cos(theta)**40 + 3.15847561700214e+88*cos(theta)**38 - 8.97134690405053e+87*cos(theta)**36 + 2.16715818617785e+87*cos(theta)**34 - 4.44200125117199e+86*cos(theta)**32 + 7.69822718581869e+85*cos(theta)**30 - 1.12260436668828e+85*cos(theta)**28 + 1.36885306647796e+84*cos(theta)**26 - 1.38461639155101e+83*cos(theta)**24 + 1.15037364258904e+82*cos(theta)**22 - 7.75419642363779e+80*cos(theta)**20 + 4.17601281318362e+79*cos(theta)**18 - 1.76256540804715e+78*cos(theta)**16 + 5.68875333420276e+76*cos(theta)**14 - 1.35980182141437e+75*cos(theta)**12 + 2.30593320178182e+73*cos(theta)**10 - 2.6118045325996e+71*cos(theta)**8 + 1.80569202253799e+69*cos(theta)**6 - 6.56933794277708e+66*cos(theta)**4 + 9.40267835321146e+63*cos(theta)**2 - 2.20875695400786e+60)*sin(31*phi)

#@torch.jit.script
def Yl97_m_minus_30(theta, phi):
    return 1.93832593037077e-59*(1.0 - cos(theta)**2)**15*(2.39101616775021e+85*cos(theta)**67 - 2.7391382108268e+86*cos(theta)**65 + 1.49146792631407e+87*cos(theta)**63 - 5.13727841285957e+87*cos(theta)**61 + 1.25684752614078e+88*cos(theta)**59 - 2.32482823483986e+88*cos(theta)**57 + 3.37925852714428e+88*cos(theta)**55 - 3.96069369598204e+88*cos(theta)**53 + 3.8113379281168e+88*cos(theta)**51 - 3.05050587466975e+88*cos(theta)**49 + 2.04993994777808e+88*cos(theta)**47 - 1.164469302968e+88*cos(theta)**45 + 5.61805365467016e+87*cos(theta)**43 - 2.30910443794591e+87*cos(theta)**41 + 8.09865542821062e+86*cos(theta)**39 - 2.42468835244609e+86*cos(theta)**37 + 6.19188053193672e+85*cos(theta)**35 - 1.34606098520363e+85*cos(theta)**33 + 2.48329909219958e+84*cos(theta)**31 - 3.8710495403044e+83*cos(theta)**29 + 5.0698261721406e+82*cos(theta)**27 - 5.53846556620402e+81*cos(theta)**25 + 5.0016245329958e+80*cos(theta)**23 - 3.69247448744657e+79*cos(theta)**21 + 2.19790148062296e+78*cos(theta)**19 - 1.03680318120421e+77*cos(theta)**17 + 3.79250222280184e+75*cos(theta)**15 - 1.04600140108798e+74*cos(theta)**13 + 2.09630291071075e+72*cos(theta)**11 - 2.90200503622177e+70*cos(theta)**9 + 2.57956003219713e+68*cos(theta)**7 - 1.31386758855542e+66*cos(theta)**5 + 3.13422611773715e+63*cos(theta)**3 - 2.20875695400786e+60*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl97_m_minus_29(theta, phi):
    return 1.80128786186537e-57*(1.0 - cos(theta)**2)**14.5*(3.51620024669149e+83*cos(theta)**68 - 4.15020941034364e+84*cos(theta)**66 + 2.33041863486573e+85*cos(theta)**64 - 8.28593292396705e+85*cos(theta)**62 + 2.0947458769013e+86*cos(theta)**60 - 4.00832454282734e+86*cos(theta)**58 + 6.03439022704335e+86*cos(theta)**56 - 7.3346179555223e+86*cos(theta)**54 + 7.32949601560923e+86*cos(theta)**52 - 6.10101174933951e+86*cos(theta)**50 + 4.27070822453766e+86*cos(theta)**48 - 2.53145500645217e+86*cos(theta)**46 + 1.2768303760614e+86*cos(theta)**44 - 5.49786770939502e+85*cos(theta)**42 + 2.02466385705266e+85*cos(theta)**40 - 6.38075882222655e+84*cos(theta)**38 + 1.71996681442687e+84*cos(theta)**36 - 3.95900289765775e+83*cos(theta)**34 + 7.76030966312368e+82*cos(theta)**32 - 1.29034984676813e+82*cos(theta)**30 + 1.81065220433593e+81*cos(theta)**28 - 2.13017906392462e+80*cos(theta)**26 + 2.08401022208159e+79*cos(theta)**24 - 1.67839749429389e+78*cos(theta)**22 + 1.09895074031148e+77*cos(theta)**20 - 5.76001767335671e+75*cos(theta)**18 + 2.37031388925115e+74*cos(theta)**16 - 7.47143857919984e+72*cos(theta)**14 + 1.74691909225896e+71*cos(theta)**12 - 2.90200503622177e+69*cos(theta)**10 + 3.22445004024641e+67*cos(theta)**8 - 2.18977931425903e+65*cos(theta)**6 + 7.83556529434289e+62*cos(theta)**4 - 1.10437847700393e+60*cos(theta)**2 + 2.55761574109294e+56)*sin(29*phi)

#@torch.jit.script
def Yl97_m_minus_28(theta, phi):
    return 1.6795500122227e-55*(1.0 - cos(theta)**2)**14*(5.09594238650941e+81*cos(theta)**69 - 6.19434240349796e+82*cos(theta)**67 + 3.58525943825497e+83*cos(theta)**65 - 1.31522744824874e+84*cos(theta)**63 + 3.43400963426442e+84*cos(theta)**61 - 6.79377041157177e+84*cos(theta)**59 + 1.05866495211287e+85*cos(theta)**57 - 1.33356690100406e+85*cos(theta)**55 + 1.38292377653004e+85*cos(theta)**53 - 1.19627681359598e+85*cos(theta)**51 + 8.71573107048501e+84*cos(theta)**49 - 5.38607448181312e+84*cos(theta)**47 + 2.837400835692e+84*cos(theta)**45 - 1.27857388590582e+84*cos(theta)**43 + 4.93820452939672e+83*cos(theta)**41 - 1.63609200569912e+83*cos(theta)**39 + 4.64855895791045e+82*cos(theta)**37 - 1.13114368504507e+82*cos(theta)**35 + 2.35160898882536e+81*cos(theta)**33 - 4.16241886054237e+80*cos(theta)**31 + 6.24362829081355e+79*cos(theta)**29 - 7.88955208860972e+78*cos(theta)**27 + 8.33604088832634e+77*cos(theta)**25 - 7.29738040997345e+76*cos(theta)**23 + 5.23309876338799e+75*cos(theta)**21 - 3.03158824913511e+74*cos(theta)**19 + 1.39430228779479e+73*cos(theta)**17 - 4.98095905279989e+71*cos(theta)**15 + 1.34378391712227e+70*cos(theta)**13 - 2.63818639656525e+68*cos(theta)**11 + 3.58272226694046e+66*cos(theta)**9 - 3.12825616322718e+64*cos(theta)**7 + 1.56711305886858e+62*cos(theta)**5 - 3.6812615900131e+59*cos(theta)**3 + 2.55761574109294e+56*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl97_m_minus_27(theta, phi):
    return 1.57107517742233e-53*(1.0 - cos(theta)**2)**13.5*(7.27991769501344e+79*cos(theta)**70 - 9.10932706396759e+80*cos(theta)**68 + 5.43221127008329e+81*cos(theta)**66 - 2.05504288788865e+82*cos(theta)**64 + 5.53872521655551e+82*cos(theta)**62 - 1.13229506859529e+83*cos(theta)**60 + 1.8252844001946e+83*cos(theta)**58 - 2.38136946607867e+83*cos(theta)**56 + 2.56096995653712e+83*cos(theta)**54 - 2.30053233383843e+83*cos(theta)**52 + 1.743146214097e+83*cos(theta)**50 - 1.12209885037773e+83*cos(theta)**48 + 6.16826268628696e+82*cos(theta)**46 - 2.90584974069504e+82*cos(theta)**44 + 1.1757629831897e+82*cos(theta)**42 - 4.09023001424779e+81*cos(theta)**40 + 1.2233049889238e+81*cos(theta)**38 - 3.14206579179186e+80*cos(theta)**36 + 6.91649702595693e+79*cos(theta)**34 - 1.30075589391949e+79*cos(theta)**32 + 2.08120943027118e+78*cos(theta)**30 - 2.81769717450347e+77*cos(theta)**28 + 3.20616957243321e+76*cos(theta)**26 - 3.04057517082227e+75*cos(theta)**24 + 2.37868125608545e+74*cos(theta)**22 - 1.51579412456756e+73*cos(theta)**20 + 7.74612382108219e+71*cos(theta)**18 - 3.11309940799993e+70*cos(theta)**16 + 9.59845655087338e+68*cos(theta)**14 - 2.19848866380437e+67*cos(theta)**12 + 3.58272226694046e+65*cos(theta)**10 - 3.91032020403397e+63*cos(theta)**8 + 2.6118550981143e+61*cos(theta)**6 - 9.20315397503275e+58*cos(theta)**4 + 1.27880787054647e+56*cos(theta)**2 - 2.92298941839193e+52)*sin(27*phi)

#@torch.jit.script
def Yl97_m_minus_26(theta, phi):
    return 1.47413407070875e-51*(1.0 - cos(theta)**2)**13*(1.02534052042443e+78*cos(theta)**71 - 1.32019232811125e+79*cos(theta)**69 + 8.10777801504969e+79*cos(theta)**67 - 3.16160444290562e+80*cos(theta)**65 + 8.7916273278659e+80*cos(theta)**63 - 1.85622142392671e+81*cos(theta)**61 + 3.09370237321119e+81*cos(theta)**59 - 4.17784116855907e+81*cos(theta)**57 + 4.65630901188567e+81*cos(theta)**55 - 4.34062704497817e+81*cos(theta)**53 + 3.41793375313138e+81*cos(theta)**51 - 2.28999765383211e+81*cos(theta)**49 + 1.31239631623127e+81*cos(theta)**47 - 6.4574438682112e+80*cos(theta)**45 + 2.7343325190458e+80*cos(theta)**43 - 9.97617076645802e+79*cos(theta)**41 + 3.13667945877898e+79*cos(theta)**39 - 8.49206970754558e+78*cos(theta)**37 + 1.97614200741627e+78*cos(theta)**35 - 3.94168452702876e+77*cos(theta)**33 + 6.7135788073264e+76*cos(theta)**31 - 9.71619715346024e+75*cos(theta)**29 + 1.1874702120123e+75*cos(theta)**27 - 1.21623006832891e+74*cos(theta)**25 + 1.03420924177628e+73*cos(theta)**23 - 7.21806725984551e+71*cos(theta)**21 + 4.07690727425378e+70*cos(theta)**19 - 1.83123494588231e+69*cos(theta)**17 + 6.39897103391559e+67*cos(theta)**15 - 1.69114512600336e+66*cos(theta)**13 + 3.25702024267315e+64*cos(theta)**11 - 4.34480022670442e+62*cos(theta)**9 + 3.73122156873471e+60*cos(theta)**7 - 1.84063079500655e+58*cos(theta)**5 + 4.26269290182156e+55*cos(theta)**3 - 2.92298941839193e+52*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl97_m_minus_25(theta, phi):
    return 1.38725336779573e-49*(1.0 - cos(theta)**2)**12.5*(1.42408405614504e+76*cos(theta)**72 - 1.88598904015892e+77*cos(theta)**70 + 1.19232029633084e+78*cos(theta)**68 - 4.79030976197821e+78*cos(theta)**66 + 1.37369176997905e+79*cos(theta)**64 - 2.99390552246244e+79*cos(theta)**62 + 5.15617062201865e+79*cos(theta)**60 - 7.20317442855012e+79*cos(theta)**58 + 8.31483752122441e+79*cos(theta)**56 - 8.03819823144105e+79*cos(theta)**54 + 6.57294952525265e+79*cos(theta)**52 - 4.57999530766422e+79*cos(theta)**50 + 2.73415899214848e+79*cos(theta)**48 - 1.4037921452633e+79*cos(theta)**46 + 6.21439208874046e+78*cos(theta)**44 - 2.37527875391858e+78*cos(theta)**42 + 7.84169864694745e+77*cos(theta)**40 - 2.2347551861962e+77*cos(theta)**38 + 5.48928335393407e+76*cos(theta)**36 - 1.15931897853787e+76*cos(theta)**34 + 2.0979933772895e+75*cos(theta)**32 - 3.23873238448675e+74*cos(theta)**30 + 4.24096504290107e+73*cos(theta)**28 - 4.67780795511119e+72*cos(theta)**26 + 4.30920517406785e+71*cos(theta)**24 - 3.28093966356614e+70*cos(theta)**22 + 2.03845363712689e+69*cos(theta)**20 - 1.0173527477124e+68*cos(theta)**18 + 3.99935689619724e+66*cos(theta)**16 - 1.20796080428812e+65*cos(theta)**14 + 2.71418353556096e+63*cos(theta)**12 - 4.34480022670442e+61*cos(theta)**10 + 4.66402696091838e+59*cos(theta)**8 - 3.06771799167758e+57*cos(theta)**6 + 1.06567322545539e+55*cos(theta)**4 - 1.46149470919596e+52*cos(theta)**2 + 3.30057522401979e+48)*sin(25*phi)

#@torch.jit.script
def Yl97_m_minus_24(theta, phi):
    return 1.30917328108001e-47*(1.0 - cos(theta)**2)**12*(1.95080007691101e+74*cos(theta)**73 - 2.65632259177313e+75*cos(theta)**71 + 1.72800042946498e+76*cos(theta)**69 - 7.14971606265405e+76*cos(theta)**67 + 2.11337195381392e+77*cos(theta)**65 - 4.75223098803562e+77*cos(theta)**63 + 8.45273872462073e+77*cos(theta)**61 - 1.22087702178816e+78*cos(theta)**59 + 1.45874342477621e+78*cos(theta)**57 - 1.46149058753474e+78*cos(theta)**55 + 1.24017915570805e+78*cos(theta)**53 - 8.98038295620436e+77*cos(theta)**51 + 5.57991631050709e+77*cos(theta)**49 - 2.98679179843256e+77*cos(theta)**47 + 1.3809760197201e+77*cos(theta)**45 - 5.52390407888041e+76*cos(theta)**43 + 1.91260942608474e+76*cos(theta)**41 - 5.73014150306719e+75*cos(theta)**39 + 1.48359009565786e+75*cos(theta)**37 - 3.31233993867963e+74*cos(theta)**35 + 6.35755568875606e+73*cos(theta)**33 - 1.0447523820925e+73*cos(theta)**31 + 1.4624017389314e+72*cos(theta)**29 - 1.732521464856e+71*cos(theta)**27 + 1.72368206962714e+70*cos(theta)**25 - 1.42649550589832e+69*cos(theta)**23 + 9.70692208155663e+67*cos(theta)**21 - 5.35448814585472e+66*cos(theta)**19 + 2.35256288011602e+65*cos(theta)**17 - 8.05307202858745e+63*cos(theta)**15 + 2.08783348889304e+62*cos(theta)**13 - 3.9498183879131e+60*cos(theta)**11 + 5.18225217879821e+58*cos(theta)**9 - 4.38245427382512e+56*cos(theta)**7 + 2.13134645091078e+54*cos(theta)**5 - 4.87164903065321e+51*cos(theta)**3 + 3.30057522401979e+48*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl97_m_minus_23(theta, phi):
    return 1.23881278342489e-45*(1.0 - cos(theta)**2)**11.5*(2.63621632015002e+72*cos(theta)**74 - 3.68933693301824e+73*cos(theta)**72 + 2.46857204209283e+74*cos(theta)**70 - 1.05142883274324e+75*cos(theta)**68 + 3.20207871789987e+75*cos(theta)**66 - 7.42536091880565e+75*cos(theta)**64 + 1.36334495558399e+76*cos(theta)**62 - 2.03479503631359e+76*cos(theta)**60 + 2.51507487030381e+76*cos(theta)**58 - 2.60980462059774e+76*cos(theta)**56 + 2.29662806612601e+76*cos(theta)**54 - 1.72699672234699e+76*cos(theta)**52 + 1.11598326210142e+76*cos(theta)**50 - 6.22248291340117e+75*cos(theta)**48 + 3.00212178200022e+75*cos(theta)**46 - 1.25543274520009e+75*cos(theta)**44 + 4.55383196686844e+74*cos(theta)**42 - 1.4325353757668e+74*cos(theta)**40 + 3.90418446225752e+73*cos(theta)**38 - 9.20094427411008e+72*cos(theta)**36 + 1.86986932022237e+72*cos(theta)**34 - 3.26485119403906e+71*cos(theta)**32 + 4.87467246310468e+70*cos(theta)**30 - 6.18757666019998e+69*cos(theta)**28 + 6.62954642164284e+68*cos(theta)**26 - 5.94373127457634e+67*cos(theta)**24 + 4.41223730979847e+66*cos(theta)**22 - 2.67724407292736e+65*cos(theta)**20 + 1.30697937784224e+64*cos(theta)**18 - 5.03317001786716e+62*cos(theta)**16 + 1.4913096349236e+61*cos(theta)**14 - 3.29151532326092e+59*cos(theta)**12 + 5.18225217879821e+57*cos(theta)**10 - 5.4780678422814e+55*cos(theta)**8 + 3.5522440848513e+53*cos(theta)**6 - 1.2179122576633e+51*cos(theta)**4 + 1.6502876120099e+48*cos(theta)**2 - 3.68614610679003e+44)*sin(23*phi)

#@torch.jit.script
def Yl97_m_minus_22(theta, phi):
    return 1.17524099704666e-43*(1.0 - cos(theta)**2)**11*(3.51495509353336e+70*cos(theta)**75 - 5.05388620961402e+71*cos(theta)**73 + 3.47686203111666e+72*cos(theta)**71 - 1.52380990252644e+73*cos(theta)**69 + 4.77922196701474e+73*cos(theta)**67 - 1.14236321827779e+74*cos(theta)**65 + 2.16403961203808e+74*cos(theta)**63 - 3.3357295677272e+74*cos(theta)**61 + 4.2628387632268e+74*cos(theta)**59 - 4.5786045975399e+74*cos(theta)**57 + 4.17568739295639e+74*cos(theta)**55 - 3.25848438178678e+74*cos(theta)**53 + 2.18820247470866e+74*cos(theta)**51 - 1.26989447212269e+74*cos(theta)**49 + 6.38749315319197e+73*cos(theta)**47 - 2.7898505448891e+73*cos(theta)**45 + 1.0590306899694e+73*cos(theta)**43 - 3.49398872138243e+72*cos(theta)**41 + 1.00107293904039e+72*cos(theta)**39 - 2.48674169570543e+71*cos(theta)**37 + 5.34248377206392e+70*cos(theta)**35 - 9.89348846678503e+69*cos(theta)**33 + 1.57247498809828e+69*cos(theta)**31 - 2.13364712420689e+68*cos(theta)**29 + 2.45538756357142e+67*cos(theta)**27 - 2.37749250983054e+66*cos(theta)**25 + 1.91836404773846e+65*cos(theta)**23 - 1.27487812996541e+64*cos(theta)**21 + 6.87883883074861e+62*cos(theta)**19 - 2.96068824580421e+61*cos(theta)**17 + 9.94206423282401e+59*cos(theta)**15 - 2.53193486404686e+58*cos(theta)**13 + 4.71113834436201e+56*cos(theta)**11 - 6.08674204697933e+54*cos(theta)**9 + 5.07463440693043e+52*cos(theta)**7 - 2.43582451532661e+50*cos(theta)**5 + 5.50095870669965e+47*cos(theta)**3 - 3.68614610679003e+44*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl97_m_minus_21(theta, phi):
    return 1.11765357029373e-41*(1.0 - cos(theta)**2)**10.5*(4.62494091254389e+68*cos(theta)**76 - 6.82957595893787e+69*cos(theta)**74 + 4.82897504321759e+70*cos(theta)**72 - 2.17687128932348e+71*cos(theta)**70 + 7.02826759855109e+71*cos(theta)**68 - 1.73085336102696e+72*cos(theta)**66 + 3.3813118938095e+72*cos(theta)**64 - 5.38020898020517e+72*cos(theta)**62 + 7.10473127204467e+72*cos(theta)**60 - 7.89414585782741e+72*cos(theta)**58 + 7.45658463027926e+72*cos(theta)**56 - 6.03423033664218e+72*cos(theta)**54 + 4.20808168213205e+72*cos(theta)**52 - 2.53978894424538e+72*cos(theta)**50 + 1.33072774024833e+72*cos(theta)**48 - 6.06489248888934e+71*cos(theta)**46 + 2.40688793174865e+71*cos(theta)**44 - 8.31902076519627e+70*cos(theta)**42 + 2.50268234760097e+70*cos(theta)**40 - 6.54405709396165e+69*cos(theta)**38 + 1.48402327001775e+69*cos(theta)**36 - 2.90984954905442e+68*cos(theta)**34 + 4.91398433780713e+67*cos(theta)**32 - 7.11215708068964e+66*cos(theta)**30 + 8.76924129846936e+65*cos(theta)**28 - 9.14420196088668e+64*cos(theta)**26 + 7.9931835322436e+63*cos(theta)**24 - 5.79490059075186e+62*cos(theta)**22 + 3.43941941537431e+61*cos(theta)**20 - 1.64482680322456e+60*cos(theta)**18 + 6.21379014551501e+58*cos(theta)**16 - 1.80852490289062e+57*cos(theta)**14 + 3.92594862030167e+55*cos(theta)**12 - 6.08674204697933e+53*cos(theta)**10 + 6.34329300866304e+51*cos(theta)**8 - 4.05970752554435e+49*cos(theta)**6 + 1.37523967667491e+47*cos(theta)**4 - 1.84307305339501e+44*cos(theta)**2 + 4.07579180317341e+40)*sin(21*phi)

#@torch.jit.script
def Yl97_m_minus_20(theta, phi):
    return 1.06535310512464e-39*(1.0 - cos(theta)**2)**10*(6.00641676953752e+66*cos(theta)**77 - 9.10610127858382e+67*cos(theta)**75 + 6.61503430577752e+68*cos(theta)**73 - 3.06601590045561e+69*cos(theta)**71 + 1.01858950703639e+70*cos(theta)**69 - 2.58336322541337e+70*cos(theta)**67 + 5.20201829816846e+70*cos(theta)**65 - 8.54001425429391e+70*cos(theta)**63 + 1.16471004459749e+71*cos(theta)**61 - 1.33799082336058e+71*cos(theta)**59 + 1.30817274215426e+71*cos(theta)**57 - 1.0971327884804e+71*cos(theta)**55 + 7.93977675873971e+70*cos(theta)**53 - 4.97997832204976e+70*cos(theta)**51 + 2.71577089846597e+70*cos(theta)**49 - 1.2904026572105e+70*cos(theta)**47 + 5.34863984833032e+69*cos(theta)**45 - 1.93465599190611e+69*cos(theta)**43 + 6.10410328683164e+68*cos(theta)**41 - 1.67796335742606e+68*cos(theta)**39 + 4.01087370275069e+67*cos(theta)**37 - 8.3138558544412e+66*cos(theta)**35 + 1.48908616297186e+66*cos(theta)**33 - 2.2942442195773e+65*cos(theta)**31 + 3.02387630981702e+64*cos(theta)**29 - 3.38674146699507e+63*cos(theta)**27 + 3.19727341289744e+62*cos(theta)**25 - 2.51952199597907e+61*cos(theta)**23 + 1.63781876922586e+60*cos(theta)**21 - 8.65698317486611e+58*cos(theta)**19 + 3.65517067383236e+57*cos(theta)**17 - 1.20568326859374e+56*cos(theta)**15 + 3.01996047715513e+54*cos(theta)**13 - 5.5334018608903e+52*cos(theta)**11 + 7.04810334295893e+50*cos(theta)**9 - 5.79958217934906e+48*cos(theta)**7 + 2.75047935334983e+46*cos(theta)**5 - 6.14357684465005e+43*cos(theta)**3 + 4.07579180317341e+40*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl97_m_minus_19(theta, phi):
    return 1.01773288634356e-37*(1.0 - cos(theta)**2)**9.5*(7.70053431991989e+64*cos(theta)**78 - 1.19817122086629e+66*cos(theta)**76 + 8.93923554834799e+66*cos(theta)**74 - 4.25835541729946e+67*cos(theta)**72 + 1.45512786719484e+68*cos(theta)**70 - 3.79906356678437e+68*cos(theta)**68 + 7.88184590631584e+68*cos(theta)**66 - 1.33437722723342e+69*cos(theta)**64 + 1.87856458806046e+69*cos(theta)**62 - 2.22998470560096e+69*cos(theta)**60 + 2.25547024509355e+69*cos(theta)**58 - 1.95916569371499e+69*cos(theta)**56 + 1.47032902939624e+69*cos(theta)**54 - 9.57688138855723e+68*cos(theta)**52 + 5.43154179693194e+68*cos(theta)**50 - 2.68833886918854e+68*cos(theta)**48 + 1.16274779311529e+68*cos(theta)**46 - 4.39694543615025e+67*cos(theta)**44 + 1.45335792543611e+67*cos(theta)**42 - 4.19490839356516e+66*cos(theta)**40 + 1.05549307967123e+66*cos(theta)**38 - 2.30940440401145e+65*cos(theta)**36 + 4.37966518521135e+64*cos(theta)**34 - 7.16951318617907e+63*cos(theta)**32 + 1.00795876993901e+63*cos(theta)**30 - 1.20955052392681e+62*cos(theta)**28 + 1.22972054342209e+61*cos(theta)**26 - 1.04980083165795e+60*cos(theta)**24 + 7.44463076920845e+58*cos(theta)**22 - 4.32849158743305e+57*cos(theta)**20 + 2.03065037435131e+56*cos(theta)**18 - 7.5355204287109e+54*cos(theta)**16 + 2.15711462653938e+53*cos(theta)**14 - 4.61116821740859e+51*cos(theta)**12 + 7.04810334295893e+49*cos(theta)**10 - 7.24947772418633e+47*cos(theta)**8 + 4.58413225558305e+45*cos(theta)**6 - 1.53589421116251e+43*cos(theta)**4 + 2.0378959015867e+40*cos(theta)**2 - 4.46613171507058e+36)*sin(19*phi)

#@torch.jit.script
def Yl97_m_minus_18(theta, phi):
    return 9.74263311886972e-36*(1.0 - cos(theta)**2)**9*(9.74751179736695e+62*cos(theta)**79 - 1.55606652060557e+64*cos(theta)**77 + 1.19189807311307e+65*cos(theta)**75 - 5.83336358534172e+65*cos(theta)**73 + 2.04947586928851e+66*cos(theta)**71 - 5.50588922722372e+66*cos(theta)**69 + 1.17639491139042e+67*cos(theta)**67 - 2.05288804189758e+67*cos(theta)**65 + 2.98184855247693e+67*cos(theta)**63 - 3.65571263213273e+67*cos(theta)**61 + 3.82283092388737e+67*cos(theta)**59 - 3.43713279599122e+67*cos(theta)**57 + 2.67332550799317e+67*cos(theta)**55 - 1.80695875255797e+67*cos(theta)**53 + 1.06500819547685e+67*cos(theta)**51 - 5.48640585548681e+66*cos(theta)**49 + 2.47393147471338e+66*cos(theta)**47 - 9.77098985811166e+65*cos(theta)**45 + 3.37990215217699e+65*cos(theta)**43 - 1.02314838867443e+65*cos(theta)**41 + 2.70639251197752e+64*cos(theta)**39 - 6.24163352435526e+63*cos(theta)**37 + 1.25133291006039e+63*cos(theta)**35 - 2.1725797533876e+62*cos(theta)**33 + 3.25147990302906e+61*cos(theta)**31 - 4.17086387560969e+60*cos(theta)**29 + 4.55452053119293e+59*cos(theta)**27 - 4.19920332663178e+58*cos(theta)**25 + 3.23679598661237e+57*cos(theta)**23 - 2.06118647020622e+56*cos(theta)**21 + 1.06876335492174e+55*cos(theta)**19 - 4.43265907571229e+53*cos(theta)**17 + 1.43807641769292e+52*cos(theta)**15 - 3.54705247492968e+50*cos(theta)**13 + 6.40736667541721e+48*cos(theta)**11 - 8.05497524909592e+46*cos(theta)**9 + 6.54876036511864e+44*cos(theta)**7 - 3.07178842232503e+42*cos(theta)**5 + 6.79298633862235e+39*cos(theta)**3 - 4.46613171507058e+36*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl97_m_minus_17(theta, phi):
    return 9.34480540630919e-34*(1.0 - cos(theta)**2)**8.5*(1.21843897467087e+61*cos(theta)**80 - 1.99495707769945e+62*cos(theta)**78 + 1.56828693830667e+63*cos(theta)**76 - 7.8829237639753e+63*cos(theta)**74 + 2.84649426290071e+64*cos(theta)**72 - 7.86555603889104e+64*cos(theta)**70 + 1.72999251675062e+65*cos(theta)**68 - 3.11043642711754e+65*cos(theta)**66 + 4.6591383632452e+65*cos(theta)**64 - 5.89631069698827e+65*cos(theta)**62 + 6.37138487314561e+65*cos(theta)**60 - 5.92609102757106e+65*cos(theta)**58 + 4.7737955499878e+65*cos(theta)**56 - 3.34621991214438e+65*cos(theta)**54 + 2.04809268360933e+65*cos(theta)**52 - 1.09728117109736e+65*cos(theta)**50 + 5.15402390565287e+64*cos(theta)**48 - 2.12412823002427e+64*cos(theta)**46 + 7.68159580040225e+63*cos(theta)**44 - 2.43606759208197e+63*cos(theta)**42 + 6.76598127994381e+62*cos(theta)**40 - 1.64253513798823e+62*cos(theta)**38 + 3.47592475016774e+61*cos(theta)**36 - 6.38994045113999e+60*cos(theta)**34 + 1.01608746969658e+60*cos(theta)**32 - 1.39028795853656e+59*cos(theta)**30 + 1.62661447542605e+58*cos(theta)**28 - 1.61507820255069e+57*cos(theta)**26 + 1.34866499442182e+56*cos(theta)**24 - 9.36902941002826e+54*cos(theta)**22 + 5.34381677460871e+53*cos(theta)**20 - 2.46258837539572e+52*cos(theta)**18 + 8.98797761058075e+50*cos(theta)**16 - 2.53360891066406e+49*cos(theta)**14 + 5.33947222951434e+47*cos(theta)**12 - 8.05497524909592e+45*cos(theta)**10 + 8.1859504563983e+43*cos(theta)**8 - 5.11964737054171e+41*cos(theta)**6 + 1.69824658465559e+39*cos(theta)**4 - 2.23306585753529e+36*cos(theta)**2 + 4.85449099464193e+32)*sin(17*phi)

#@torch.jit.script
def Yl97_m_minus_16(theta, phi):
    return 8.97976967158516e-32*(1.0 - cos(theta)**2)**8*(1.50424564774181e+59*cos(theta)**81 - 2.5252621236702e+60*cos(theta)**79 + 2.03673628351515e+61*cos(theta)**77 - 1.05105650186337e+62*cos(theta)**75 + 3.89930720945302e+62*cos(theta)**73 - 1.10782479421001e+63*cos(theta)**71 + 2.50723553152264e+63*cos(theta)**69 - 4.64244242853364e+63*cos(theta)**67 + 7.16790517422338e+63*cos(theta)**65 - 9.35922332855281e+63*cos(theta)**63 + 1.04448932346649e+64*cos(theta)**61 - 1.00442220806289e+64*cos(theta)**59 + 8.3750799122593e+63*cos(theta)**57 - 6.08403620389888e+63*cos(theta)**55 + 3.86432581813081e+63*cos(theta)**53 - 2.15153170803404e+63*cos(theta)**51 + 1.05184161339855e+63*cos(theta)**49 - 4.51942176600909e+62*cos(theta)**47 + 1.70702128897828e+62*cos(theta)**45 - 5.66527346995808e+61*cos(theta)**43 + 1.65023933657166e+61*cos(theta)**41 - 4.21162855894417e+60*cos(theta)**39 + 9.39439121666956e+59*cos(theta)**37 - 1.82569727175428e+59*cos(theta)**35 + 3.07905293847449e+58*cos(theta)**33 - 4.48479986624697e+57*cos(theta)**31 + 5.60901543250361e+56*cos(theta)**29 - 5.98177112055809e+55*cos(theta)**27 + 5.39465997768728e+54*cos(theta)**25 - 4.07349104783837e+53*cos(theta)**23 + 2.54467465457558e+52*cos(theta)**21 - 1.29609914494512e+51*cos(theta)**19 + 5.28704565328279e+49*cos(theta)**17 - 1.68907260710937e+48*cos(theta)**15 + 4.10728633039565e+46*cos(theta)**13 - 7.32270477190539e+44*cos(theta)**11 + 9.09550050710922e+42*cos(theta)**9 - 7.31378195791673e+40*cos(theta)**7 + 3.39649316931117e+38*cos(theta)**5 - 7.44355285845096e+35*cos(theta)**3 + 4.85449099464193e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl97_m_minus_15(theta, phi):
    return 8.64393206963614e-30*(1.0 - cos(theta)**2)**7.5*(1.83444591188026e+57*cos(theta)**82 - 3.15657765458774e+58*cos(theta)**80 + 2.61120036348096e+59*cos(theta)**78 - 1.38296908139918e+60*cos(theta)**76 + 5.26933406682841e+60*cos(theta)**74 - 1.5386455475139e+61*cos(theta)**72 + 3.58176504503235e+61*cos(theta)**70 - 6.82712121843182e+61*cos(theta)**68 + 1.08604623851869e+62*cos(theta)**66 - 1.46237864508638e+62*cos(theta)**64 + 1.68466019913951e+62*cos(theta)**62 - 1.67403701343815e+62*cos(theta)**60 + 1.44397929521712e+62*cos(theta)**58 - 1.08643503641051e+62*cos(theta)**56 + 7.15615892246447e+61*cos(theta)**54 - 4.13756097698855e+61*cos(theta)**52 + 2.10368322679709e+61*cos(theta)**50 - 9.41546201251895e+60*cos(theta)**48 + 3.71091584560495e+60*cos(theta)**46 - 1.2875621522632e+60*cos(theta)**44 + 3.92914127755157e+59*cos(theta)**42 - 1.05290713973604e+59*cos(theta)**40 + 2.47220821491304e+58*cos(theta)**38 - 5.07138131042856e+57*cos(theta)**36 + 9.05603805433672e+56*cos(theta)**34 - 1.40149995820218e+56*cos(theta)**32 + 1.86967181083454e+55*cos(theta)**30 - 2.13634682877075e+54*cos(theta)**28 + 2.07486922218742e+53*cos(theta)**26 - 1.69728793659932e+52*cos(theta)**24 + 1.15667029753435e+51*cos(theta)**22 - 6.48049572472557e+49*cos(theta)**20 + 2.93724758515711e+48*cos(theta)**18 - 1.05567037944336e+47*cos(theta)**16 + 2.93377595028261e+45*cos(theta)**14 - 6.10225397658782e+43*cos(theta)**12 + 9.09550050710922e+41*cos(theta)**10 - 9.14222744739591e+39*cos(theta)**8 + 5.66082194885196e+37*cos(theta)**6 - 1.86088821461274e+35*cos(theta)**4 + 2.42724549732097e+32*cos(theta)**2 - 5.23903625581905e+28)*sin(15*phi)

#@torch.jit.script
def Yl97_m_minus_14(theta, phi):
    return 8.33411334732858e-28*(1.0 - cos(theta)**2)**7*(2.2101757974461e+55*cos(theta)**83 - 3.89700945010833e+56*cos(theta)**81 + 3.30531691579869e+57*cos(theta)**79 - 1.79606374207685e+58*cos(theta)**77 + 7.02577875577121e+58*cos(theta)**75 - 2.10773362673136e+59*cos(theta)**73 + 5.04473950004556e+59*cos(theta)**71 - 9.89437857743743e+59*cos(theta)**69 + 1.62096453510253e+60*cos(theta)**67 - 2.24981330013289e+60*cos(theta)**65 + 2.67406380815795e+60*cos(theta)**63 - 2.74432297284943e+60*cos(theta)**61 + 2.44742253426631e+60*cos(theta)**59 - 1.90602637966757e+60*cos(theta)**57 + 1.30111980408445e+60*cos(theta)**55 - 7.80671882450669e+59*cos(theta)**53 + 4.12486907215116e+59*cos(theta)**51 - 1.92152285969774e+59*cos(theta)**49 + 7.89556562894671e+58*cos(theta)**47 - 2.86124922725155e+58*cos(theta)**45 + 9.1375378547711e+57*cos(theta)**43 - 2.56806619447815e+57*cos(theta)**41 + 6.33899542285395e+56*cos(theta)**39 - 1.37064359741313e+56*cos(theta)**37 + 2.58743944409621e+55*cos(theta)**35 - 4.24696957030963e+54*cos(theta)**33 + 6.03119938978883e+53*cos(theta)**31 - 7.36671320265775e+52*cos(theta)**29 + 7.68470082291636e+51*cos(theta)**27 - 6.78915174639729e+50*cos(theta)**25 + 5.02900129362762e+49*cos(theta)**23 - 3.08595034510742e+48*cos(theta)**21 + 1.54591978166164e+47*cos(theta)**19 - 6.20982576143152e+45*cos(theta)**17 + 1.95585063352174e+44*cos(theta)**15 - 4.69404152045217e+42*cos(theta)**13 + 8.26863682464474e+40*cos(theta)**11 - 1.01580304971066e+39*cos(theta)**9 + 8.08688849835994e+36*cos(theta)**7 - 3.72177642922548e+34*cos(theta)**5 + 8.09081832440322e+31*cos(theta)**3 - 5.23903625581905e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl97_m_minus_13(theta, phi):
    return 8.04749165795024e-26*(1.0 - cos(theta)**2)**6.5*(2.63116166362631e+53*cos(theta)**84 - 4.75245054891259e+54*cos(theta)**82 + 4.13164614474836e+55*cos(theta)**80 - 2.30264582317545e+56*cos(theta)**78 + 9.24444573127791e+56*cos(theta)**76 - 2.84828868477211e+57*cos(theta)**74 + 7.00658263895217e+57*cos(theta)**72 - 1.41348265391963e+58*cos(theta)**70 + 2.38377137515078e+58*cos(theta)**68 - 3.40880803050437e+58*cos(theta)**66 + 4.17822470024679e+58*cos(theta)**64 - 4.4263273755636e+58*cos(theta)**62 + 4.07903755711051e+58*cos(theta)**60 - 3.28625237873719e+58*cos(theta)**58 + 2.32342822157937e+58*cos(theta)**56 - 1.44568867120494e+58*cos(theta)**54 + 7.93244052336761e+57*cos(theta)**52 - 3.84304571939549e+57*cos(theta)**50 + 1.64490950603056e+57*cos(theta)**48 - 6.22010701576425e+56*cos(theta)**46 + 2.07671314881161e+56*cos(theta)**44 - 6.11444332018607e+55*cos(theta)**42 + 1.58474885571349e+55*cos(theta)**40 - 3.6069568352977e+54*cos(theta)**38 + 7.18733178915613e+53*cos(theta)**36 - 1.24910869714989e+53*cos(theta)**34 + 1.88474980930901e+52*cos(theta)**32 - 2.45557106755258e+51*cos(theta)**30 + 2.74453600818441e+50*cos(theta)**28 - 2.6112122101528e+49*cos(theta)**26 + 2.09541720567818e+48*cos(theta)**24 - 1.40270470232155e+47*cos(theta)**22 + 7.72959890830818e+45*cos(theta)**20 - 3.44990320079529e+44*cos(theta)**18 + 1.22240664595109e+43*cos(theta)**16 - 3.35288680032298e+41*cos(theta)**14 + 6.89053068720395e+39*cos(theta)**12 - 1.01580304971066e+38*cos(theta)**10 + 1.01086106229499e+36*cos(theta)**8 - 6.2029607153758e+33*cos(theta)**6 + 2.0227045811008e+31*cos(theta)**4 - 2.61951812790952e+28*cos(theta)**2 + 5.61887200323793e+24)*sin(13*phi)

#@torch.jit.script
def Yl97_m_minus_12(theta, phi):
    return 7.78155409001107e-24*(1.0 - cos(theta)**2)**6*(3.0954843101486e+51*cos(theta)**85 - 5.72584403483445e+52*cos(theta)**83 + 5.10079770956587e+53*cos(theta)**81 - 2.91474154832336e+54*cos(theta)**79 + 1.20057736769843e+55*cos(theta)**77 - 3.79771824636282e+55*cos(theta)**75 + 9.59805840952352e+55*cos(theta)**73 - 1.99082063932343e+56*cos(theta)**71 + 3.45474112340692e+56*cos(theta)**69 - 5.08777317985728e+56*cos(theta)**67 + 6.42803800037968e+56*cos(theta)**65 - 7.02591646914857e+56*cos(theta)**63 + 6.68694681493526e+56*cos(theta)**61 - 5.56991928599523e+56*cos(theta)**59 + 4.07618986241995e+56*cos(theta)**57 - 2.62852485673626e+56*cos(theta)**55 + 1.49668689120144e+56*cos(theta)**53 - 7.53538376352057e+55*cos(theta)**51 + 3.35695817557258e+55*cos(theta)**49 - 1.32342702463069e+55*cos(theta)**47 + 4.61491810847025e+54*cos(theta)**45 - 1.42196356283397e+54*cos(theta)**43 + 3.86524111149631e+53*cos(theta)**41 - 9.2486072699941e+52*cos(theta)**39 + 1.94252210517733e+52*cos(theta)**37 - 3.56888199185684e+51*cos(theta)**35 + 5.71136305851215e+50*cos(theta)**33 - 7.92119699210511e+49*cos(theta)**31 + 9.46391726960143e+48*cos(theta)**29 - 9.67115633389927e+47*cos(theta)**27 + 8.3816688227127e+46*cos(theta)**25 - 6.09871609705023e+45*cos(theta)**23 + 3.68076138490866e+44*cos(theta)**21 - 1.81573852673436e+43*cos(theta)**19 + 7.19062732912404e+41*cos(theta)**17 - 2.23525786688199e+40*cos(theta)**15 + 5.30040822092612e+38*cos(theta)**13 - 9.23457317918779e+36*cos(theta)**11 + 1.12317895810555e+35*cos(theta)**9 - 8.86137245053686e+32*cos(theta)**7 + 4.04540916220161e+30*cos(theta)**5 - 8.73172709303175e+27*cos(theta)**3 + 5.61887200323793e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl97_m_minus_11(theta, phi):
    return 7.53405550111472e-22*(1.0 - cos(theta)**2)**5.5*(3.5994003606379e+49*cos(theta)**86 - 6.81648099385054e+50*cos(theta)**84 + 6.2204850116657e+51*cos(theta)**82 - 3.64342693540419e+52*cos(theta)**80 + 1.53920175345953e+53*cos(theta)**78 - 4.99699769258266e+53*cos(theta)**76 + 1.29703492020588e+54*cos(theta)**74 - 2.76502866572698e+54*cos(theta)**72 + 4.93534446200989e+54*cos(theta)**70 - 7.48201938214305e+54*cos(theta)**68 + 9.73945151572678e+54*cos(theta)**66 - 1.09779944830446e+55*cos(theta)**64 + 1.07853980886053e+55*cos(theta)**62 - 9.28319880999206e+54*cos(theta)**60 + 7.02791355589647e+54*cos(theta)**58 - 4.69379438702903e+54*cos(theta)**56 + 2.77164239111377e+54*cos(theta)**54 - 1.44911226221549e+54*cos(theta)**52 + 6.71391635114516e+53*cos(theta)**50 - 2.75713963464727e+53*cos(theta)**48 + 1.00324306705875e+53*cos(theta)**46 - 3.23173537007721e+52*cos(theta)**44 + 9.20295502737218e+51*cos(theta)**42 - 2.31215181749852e+51*cos(theta)**40 + 5.11190027678245e+50*cos(theta)**38 - 9.91356108849121e+49*cos(theta)**36 + 1.67981266426828e+49*cos(theta)**34 - 2.47537406003285e+48*cos(theta)**32 + 3.15463908986714e+47*cos(theta)**30 - 3.45398440496402e+46*cos(theta)**28 + 3.22371877796642e+45*cos(theta)**26 - 2.54113170710426e+44*cos(theta)**24 + 1.67307335677666e+43*cos(theta)**22 - 9.07869263367181e+41*cos(theta)**20 + 3.99479296062446e+40*cos(theta)**18 - 1.39703616680124e+39*cos(theta)**16 + 3.78600587209008e+37*cos(theta)**14 - 7.69547764932316e+35*cos(theta)**12 + 1.12317895810555e+34*cos(theta)**10 - 1.10767155631711e+32*cos(theta)**8 + 6.74234860366935e+29*cos(theta)**6 - 2.18293177325794e+27*cos(theta)**4 + 2.80943600161897e+24*cos(theta)**2 - 5.99410284109018e+20)*sin(11*phi)

#@torch.jit.script
def Yl97_m_minus_10(theta, phi):
    return 7.3029834971282e-20*(1.0 - cos(theta)**2)**5*(4.13724179383667e+47*cos(theta)**87 - 8.01938940453004e+48*cos(theta)**85 + 7.49456025501891e+49*cos(theta)**83 - 4.49805794494345e+50*cos(theta)**81 + 1.94835664994877e+51*cos(theta)**79 - 6.48960739296449e+51*cos(theta)**77 + 1.72937989360784e+52*cos(theta)**75 - 3.78771050099586e+52*cos(theta)**73 + 6.95118938311252e+52*cos(theta)**71 - 1.0843506350932e+53*cos(theta)**69 + 1.45364947995922e+53*cos(theta)**67 - 1.68892222816071e+53*cos(theta)**65 + 1.71196795057226e+53*cos(theta)**63 - 1.5218358704905e+53*cos(theta)**61 + 1.19117178913499e+53*cos(theta)**59 - 8.23472699478778e+52*cos(theta)**57 + 5.03934980202504e+52*cos(theta)**55 - 2.73417407965187e+52*cos(theta)**53 + 1.31645418649905e+52*cos(theta)**51 - 5.6268155809128e+51*cos(theta)**49 + 2.13455971714628e+51*cos(theta)**47 - 7.18163415572712e+50*cos(theta)**45 + 2.14022209938888e+50*cos(theta)**43 - 5.63939467682567e+49*cos(theta)**41 + 1.31074366071345e+49*cos(theta)**39 - 2.67934083472735e+48*cos(theta)**37 + 4.79946475505223e+47*cos(theta)**35 - 7.50113351525105e+46*cos(theta)**33 + 1.01762551286037e+46*cos(theta)**31 - 1.19102910516001e+45*cos(theta)**29 + 1.19396991776534e+44*cos(theta)**27 - 1.01645268284171e+43*cos(theta)**25 + 7.27423198598549e+41*cos(theta)**23 - 4.32318696841515e+40*cos(theta)**21 + 2.10252261085498e+39*cos(theta)**19 - 8.21785980471318e+37*cos(theta)**17 + 2.52400391472672e+36*cos(theta)**15 - 5.91959819178704e+34*cos(theta)**13 + 1.02107178009595e+33*cos(theta)**11 - 1.23074617368567e+31*cos(theta)**9 + 9.6319265766705e+28*cos(theta)**7 - 4.36586354651587e+26*cos(theta)**5 + 9.36478667206322e+23*cos(theta)**3 - 5.99410284109018e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl97_m_minus_9(theta, phi):
    return 7.08652859942738e-18*(1.0 - cos(theta)**2)**4.5*(4.70141112935985e+45*cos(theta)**88 - 9.32487140061633e+46*cos(theta)**86 + 8.92209554168918e+47*cos(theta)**84 - 5.48543651822372e+48*cos(theta)**82 + 2.43544581243596e+49*cos(theta)**80 - 8.3200094781596e+49*cos(theta)**78 + 2.27549986001032e+50*cos(theta)**76 - 5.11852770404846e+50*cos(theta)**74 + 9.65442969876739e+50*cos(theta)**72 - 1.54907233584742e+51*cos(theta)**70 + 2.13771982346944e+51*cos(theta)**68 - 2.55897307297078e+51*cos(theta)**66 + 2.67494992276916e+51*cos(theta)**64 - 2.4545739846621e+51*cos(theta)**62 + 1.98528631522499e+51*cos(theta)**60 - 1.41978051634272e+51*cos(theta)**58 + 8.99883893218757e+50*cos(theta)**56 - 5.06328533268866e+50*cos(theta)**54 + 2.53164266634433e+50*cos(theta)**52 - 1.12536311618256e+50*cos(theta)**50 + 4.44699941072141e+49*cos(theta)**48 - 1.56122481646242e+49*cos(theta)**46 + 4.86414113497472e+48*cos(theta)**44 - 1.34271301829183e+48*cos(theta)**42 + 3.27685915178362e+47*cos(theta)**40 - 7.05089693349304e+46*cos(theta)**38 + 1.33318465418117e+46*cos(theta)**36 - 2.20621573977972e+45*cos(theta)**34 + 3.18007972768865e+44*cos(theta)**32 - 3.97009701720003e+43*cos(theta)**30 + 4.26417827773336e+42*cos(theta)**28 - 3.90943339554502e+41*cos(theta)**26 + 3.03092999416062e+40*cos(theta)**24 - 1.96508498564325e+39*cos(theta)**22 + 1.05126130542749e+38*cos(theta)**20 - 4.5654776692851e+36*cos(theta)**18 + 1.5775024467042e+35*cos(theta)**16 - 4.22828442270503e+33*cos(theta)**14 + 8.5089315007996e+31*cos(theta)**12 - 1.23074617368567e+30*cos(theta)**10 + 1.20399082208381e+28*cos(theta)**8 - 7.27643924419312e+25*cos(theta)**6 + 2.34119666801581e+23*cos(theta)**4 - 2.99705142054509e+20*cos(theta)**2 + 6.36586962732602e+16)*sin(9*phi)

#@torch.jit.script
def Yl97_m_minus_8(theta, phi):
    return 6.88305880789055e-16*(1.0 - cos(theta)**2)**4*(5.28248441501107e+43*cos(theta)**89 - 1.07182429892142e+45*cos(theta)**87 + 1.04965829902226e+46*cos(theta)**85 - 6.60895966051051e+46*cos(theta)**83 + 3.00672322522958e+47*cos(theta)**81 - 1.05316575672906e+48*cos(theta)**79 + 2.95519462339002e+48*cos(theta)**77 - 6.82470360539795e+48*cos(theta)**75 + 1.32252461626951e+49*cos(theta)**73 - 2.18179202232031e+49*cos(theta)**71 + 3.09814467169485e+49*cos(theta)**69 - 3.81936279547877e+49*cos(theta)**67 + 4.11530757349102e+49*cos(theta)**65 - 3.89614918200333e+49*cos(theta)**63 + 3.25456772987703e+49*cos(theta)**61 - 2.40640765481817e+49*cos(theta)**59 + 1.57874367231361e+49*cos(theta)**57 - 9.20597333216119e+48*cos(theta)**55 + 4.77668427612137e+48*cos(theta)**53 - 2.206594345456e+48*cos(theta)**51 + 9.07550900147226e+47*cos(theta)**49 - 3.32175492864344e+47*cos(theta)**47 + 1.08092025221661e+47*cos(theta)**45 - 3.12258841463215e+46*cos(theta)**43 + 7.9923393945942e+45*cos(theta)**41 - 1.80792229063924e+45*cos(theta)**39 + 3.60320176805723e+44*cos(theta)**37 - 6.30347354222777e+43*cos(theta)**35 + 9.63660523542016e+42*cos(theta)**33 - 1.2806764571613e+42*cos(theta)**31 + 1.47040630266668e+41*cos(theta)**29 - 1.4479382946463e+40*cos(theta)**27 + 1.21237199766425e+39*cos(theta)**25 - 8.5438477636663e+37*cos(theta)**23 + 5.00600621632138e+36*cos(theta)**21 - 2.40288298383426e+35*cos(theta)**19 + 9.27942615708354e+33*cos(theta)**17 - 2.81885628180335e+32*cos(theta)**15 + 6.545331923692e+30*cos(theta)**13 - 1.11886015789607e+29*cos(theta)**11 + 1.33776758009312e+27*cos(theta)**9 - 1.03949132059902e+25*cos(theta)**7 + 4.68239333603161e+22*cos(theta)**5 - 9.99017140181696e+19*cos(theta)**3 + 6.36586962732602e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl97_m_minus_7(theta, phi):
    return 6.69109790187465e-14*(1.0 - cos(theta)**2)**3.5*(5.86942712779008e+41*cos(theta)**90 - 1.21798215786525e+43*cos(theta)**88 + 1.22053290583983e+44*cos(theta)**86 - 7.86780911965536e+44*cos(theta)**84 + 3.66673564052388e+45*cos(theta)**82 - 1.31645719591133e+46*cos(theta)**80 + 3.78871105562823e+46*cos(theta)**78 - 8.9798731649973e+46*cos(theta)**76 + 1.78719542739122e+47*cos(theta)**74 - 3.0302666976671e+47*cos(theta)**72 + 4.42592095956406e+47*cos(theta)**70 - 5.61670999335114e+47*cos(theta)**68 + 6.23531450528942e+47*cos(theta)**66 - 6.0877330968802e+47*cos(theta)**64 + 5.24930279012425e+47*cos(theta)**62 - 4.01067942469695e+47*cos(theta)**60 + 2.72197184881657e+47*cos(theta)**58 - 1.6439238093145e+47*cos(theta)**56 + 8.84571162244699e+46*cos(theta)**54 - 4.24345066433846e+46*cos(theta)**52 + 1.81510180029445e+46*cos(theta)**50 - 6.92032276800717e+45*cos(theta)**48 + 2.34982663525349e+45*cos(theta)**46 - 7.09679185143671e+44*cos(theta)**44 + 1.90293795109386e+44*cos(theta)**42 - 4.5198057265981e+43*cos(theta)**40 + 9.48210991594007e+42*cos(theta)**38 - 1.75096487284105e+42*cos(theta)**36 + 2.83429565747652e+41*cos(theta)**34 - 4.00211392862906e+40*cos(theta)**32 + 4.90135434222226e+39*cos(theta)**30 - 5.17120819516537e+38*cos(theta)**28 + 4.66296922178557e+37*cos(theta)**26 - 3.55993656819429e+36*cos(theta)**24 + 2.27545737105517e+35*cos(theta)**22 - 1.20144149191713e+34*cos(theta)**20 + 5.1552367539353e+32*cos(theta)**18 - 1.7617851761271e+31*cos(theta)**16 + 4.67523708835143e+29*cos(theta)**14 - 9.3238346491339e+27*cos(theta)**12 + 1.33776758009312e+26*cos(theta)**10 - 1.29936415074877e+24*cos(theta)**8 + 7.80398889338602e+21*cos(theta)**6 - 2.49754285045424e+19*cos(theta)**4 + 3.18293481366301e+16*cos(theta)**2 - 6736369976006.37)*sin(7*phi)

#@torch.jit.script
def Yl97_m_minus_6(theta, phi):
    return 6.50930693144599e-12*(1.0 - cos(theta)**2)**3*(6.44991992064844e+39*cos(theta)**91 - 1.36851927850028e+41*cos(theta)**89 + 1.4029113860228e+42*cos(theta)**87 - 9.25624602312396e+42*cos(theta)**85 + 4.41775378376371e+43*cos(theta)**83 - 1.62525579742139e+44*cos(theta)**81 + 4.79583677927624e+44*cos(theta)**79 - 1.16621729415549e+45*cos(theta)**77 + 2.38292723652163e+45*cos(theta)**75 - 4.15105027077685e+45*cos(theta)**73 + 6.23369149234375e+45*cos(theta)**71 - 8.14015941065382e+45*cos(theta)**69 + 9.30643956013346e+45*cos(theta)**67 - 9.36574322596955e+45*cos(theta)**65 + 8.33222665099087e+45*cos(theta)**63 - 6.57488430278189e+45*cos(theta)**61 + 4.61351160816367e+45*cos(theta)**59 - 2.88407685844649e+45*cos(theta)**57 + 1.60831120408127e+45*cos(theta)**55 - 8.00651068743107e+44*cos(theta)**53 + 3.55902313783226e+44*cos(theta)**51 - 1.41231076898106e+44*cos(theta)**49 + 4.99963113883721e+43*cos(theta)**47 - 1.57706485587483e+43*cos(theta)**45 + 4.42543709556711e+42*cos(theta)**43 - 1.10239164063368e+42*cos(theta)**41 + 2.43131023485643e+41*cos(theta)**39 - 4.732337494165e+40*cos(theta)**37 + 8.09798759279005e+39*cos(theta)**35 - 1.21276179655426e+39*cos(theta)**33 + 1.58108204587815e+38*cos(theta)**31 - 1.7831752397122e+37*cos(theta)**29 + 1.72702563769836e+36*cos(theta)**27 - 1.42397462727772e+35*cos(theta)**25 + 9.89329291763119e+33*cos(theta)**23 - 5.72114996151015e+32*cos(theta)**21 + 2.71328250207121e+31*cos(theta)**19 - 1.03634422125123e+30*cos(theta)**17 + 3.11682472556762e+28*cos(theta)**15 - 7.17218049933377e+26*cos(theta)**13 + 1.2161523455392e+25*cos(theta)**11 - 1.44373794527641e+23*cos(theta)**9 + 1.114855556198e+21*cos(theta)**7 - 4.99508570090848e+18*cos(theta)**5 + 1.060978271221e+16*cos(theta)**3 - 6736369976006.37*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl97_m_minus_5(theta, phi):
    return 6.33646844127197e-10*(1.0 - cos(theta)**2)**2.5*(7.01078252244395e+37*cos(theta)**92 - 1.52057697611142e+39*cos(theta)**90 + 1.59421748411681e+40*cos(theta)**88 - 1.07630767710744e+41*cos(theta)**86 + 5.25923069495679e+41*cos(theta)**84 - 1.98201926514804e+42*cos(theta)**82 + 5.99479597409531e+42*cos(theta)**80 - 1.49515037712243e+43*cos(theta)**78 + 3.13543057437057e+43*cos(theta)**76 - 5.60952739294169e+43*cos(theta)**74 + 8.65790485047744e+43*cos(theta)**72 - 1.16287991580769e+44*cos(theta)**70 + 1.3685940529608e+44*cos(theta)**68 - 1.41905200393478e+44*cos(theta)**66 + 1.30191041421732e+44*cos(theta)**64 - 1.06046521012611e+44*cos(theta)**62 + 7.68918601360612e+43*cos(theta)**60 - 4.97254630766636e+43*cos(theta)**58 + 2.87198429300227e+43*cos(theta)**56 - 1.48268716433909e+43*cos(theta)**54 + 6.84427526506204e+42*cos(theta)**52 - 2.82462153796211e+42*cos(theta)**50 + 1.04158982059109e+42*cos(theta)**48 - 3.42840186059745e+41*cos(theta)**46 + 1.00578115808343e+41*cos(theta)**44 - 2.62474200150877e+40*cos(theta)**42 + 6.07827558714107e+39*cos(theta)**40 - 1.24535197214868e+39*cos(theta)**38 + 2.24944099799724e+38*cos(theta)**36 - 3.56694646045371e+37*cos(theta)**34 + 4.94088139336921e+36*cos(theta)**32 - 5.94391746570732e+35*cos(theta)**30 + 6.16794870606557e+34*cos(theta)**28 - 5.47682548952968e+33*cos(theta)**26 + 4.12220538234633e+32*cos(theta)**24 - 2.60052270977734e+31*cos(theta)**22 + 1.35664125103561e+30*cos(theta)**20 - 5.75746789584018e+28*cos(theta)**18 + 1.94801545347976e+27*cos(theta)**16 - 5.12298607095269e+25*cos(theta)**14 + 1.01346028794934e+24*cos(theta)**12 - 1.44373794527641e+22*cos(theta)**10 + 1.3935694452475e+20*cos(theta)**8 - 8.32514283484747e+17*cos(theta)**6 + 2.65244567805251e+15*cos(theta)**4 - 3368184988003.18*cos(theta)**2 + 710887502.744446)*sin(5*phi)

#@torch.jit.script
def Yl97_m_minus_4(theta, phi):
    return 6.17147304349972e-8*(1.0 - cos(theta)**2)**2*(7.5384758305849e+35*cos(theta)**93 - 1.67096371001255e+37*cos(theta)**91 + 1.79125560013125e+38*cos(theta)**89 - 1.23713526104303e+39*cos(theta)**87 + 6.18733022936093e+39*cos(theta)**85 - 2.38797501825065e+40*cos(theta)**83 + 7.40098268406828e+40*cos(theta)**81 - 1.89259541407902e+41*cos(theta)**79 + 4.07198775892281e+41*cos(theta)**77 - 7.47936985725559e+41*cos(theta)**75 + 1.1860143630791e+42*cos(theta)**73 - 1.63785903634886e+42*cos(theta)**71 + 1.98346964197218e+42*cos(theta)**69 - 2.1179880655743e+42*cos(theta)**67 + 2.00293909879588e+42*cos(theta)**65 - 1.68327811131129e+42*cos(theta)**63 + 1.26052229731248e+42*cos(theta)**61 - 8.42804458926502e+41*cos(theta)**59 + 5.0385689350917e+41*cos(theta)**57 - 2.69579484425288e+41*cos(theta)**55 + 1.29137269152114e+41*cos(theta)**53 - 5.53847360384728e+40*cos(theta)**51 + 2.12569351141038e+40*cos(theta)**49 - 7.29447204382435e+39*cos(theta)**47 + 2.23506924018541e+39*cos(theta)**45 - 6.10405116629946e+38*cos(theta)**43 + 1.48250624076612e+38*cos(theta)**41 - 3.19321018499662e+37*cos(theta)**39 + 6.07957026485739e+36*cos(theta)**37 - 1.01912756012963e+36*cos(theta)**35 + 1.49723678586946e+35*cos(theta)**33 - 1.91739273087333e+34*cos(theta)**31 + 2.12687886416054e+33*cos(theta)**29 - 2.02845388501099e+32*cos(theta)**27 + 1.64888215293853e+31*cos(theta)**25 - 1.13066204772928e+30*cos(theta)**23 + 6.46019643350288e+28*cos(theta)**21 - 3.03024626096852e+27*cos(theta)**19 + 1.14589144322339e+26*cos(theta)**17 - 3.41532404730179e+24*cos(theta)**15 + 7.79584836884105e+22*cos(theta)**13 - 1.31248904116038e+21*cos(theta)**11 + 1.54841049471945e+19*cos(theta)**9 - 1.18930611926392e+17*cos(theta)**7 + 530489135610502.0*cos(theta)**5 - 1122728329334.39*cos(theta)**3 + 710887502.744446*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl97_m_minus_3(theta, phi):
    return 6.01330801660746e-6*(1.0 - cos(theta)**2)**1.5*(8.0196551389201e+33*cos(theta)**94 - 1.81626490218755e+35*cos(theta)**92 + 1.99028400014584e+36*cos(theta)**90 - 1.40583552391254e+37*cos(theta)**88 + 7.19457003414062e+37*cos(theta)**86 - 2.84282740267935e+38*cos(theta)**84 + 9.02558863910766e+38*cos(theta)**82 - 2.36574426759878e+39*cos(theta)**80 + 5.22049712682412e+39*cos(theta)**78 - 9.84127612796788e+39*cos(theta)**76 + 1.60272211226906e+40*cos(theta)**74 - 2.27480421715119e+40*cos(theta)**72 + 2.83352805996026e+40*cos(theta)**70 - 3.11468833172691e+40*cos(theta)**68 + 3.03475621029679e+40*cos(theta)**66 - 2.63012204892389e+40*cos(theta)**64 + 2.03310047953626e+40*cos(theta)**62 - 1.40467409821084e+40*cos(theta)**60 + 8.68718781912362e+39*cos(theta)**58 - 4.81391936473729e+39*cos(theta)**56 + 2.39143091022433e+39*cos(theta)**54 - 1.06509107766294e+39*cos(theta)**52 + 4.25138702282076e+38*cos(theta)**50 - 1.51968167579674e+38*cos(theta)**48 + 4.85884617431611e+37*cos(theta)**46 - 1.38728435597715e+37*cos(theta)**44 + 3.52977676372885e+36*cos(theta)**42 - 7.98302546249156e+35*cos(theta)**40 + 1.59988691180458e+35*cos(theta)**38 - 2.83090988924898e+34*cos(theta)**36 + 4.40363760549841e+33*cos(theta)**34 - 5.99185228397916e+32*cos(theta)**32 + 7.08959621386847e+31*cos(theta)**30 - 7.24447816075354e+30*cos(theta)**28 + 6.34185443437897e+29*cos(theta)**26 - 4.71109186553866e+28*cos(theta)**24 + 2.93645292431949e+27*cos(theta)**22 - 1.51512313048426e+26*cos(theta)**20 + 6.36606357346327e+24*cos(theta)**18 - 2.13457752956362e+23*cos(theta)**16 + 5.56846312060075e+21*cos(theta)**14 - 1.09374086763365e+20*cos(theta)**12 + 1.54841049471945e+18*cos(theta)**10 - 1.48663264907991e+16*cos(theta)**8 + 88414855935083.6*cos(theta)**6 - 280682082333.599*cos(theta)**4 + 355443751.372223*cos(theta)**2 - 74877.5545338578)*sin(3*phi)

#@torch.jit.script
def Yl97_m_minus_2(theta, phi):
    return 0.00058610476569864*(1.0 - cos(theta)**2)*(8.44174225149484e+31*cos(theta)**95 - 1.9529730131049e+33*cos(theta)**93 + 2.18712527488553e+34*cos(theta)**91 - 1.57959047630622e+35*cos(theta)**89 + 8.26962072889727e+35*cos(theta)**87 - 3.34450282668159e+36*cos(theta)**85 + 1.08742031796478e+37*cos(theta)**83 - 2.92067193530713e+37*cos(theta)**81 + 6.60822421116977e+37*cos(theta)**79 - 1.278087808827e+38*cos(theta)**77 + 2.13696281635874e+38*cos(theta)**75 - 3.11617016048108e+38*cos(theta)**73 + 3.99088459149332e+38*cos(theta)**71 - 4.51404106047378e+38*cos(theta)**69 + 4.52948688103999e+38*cos(theta)**67 - 4.04634161372906e+38*cos(theta)**65 + 3.22714361831152e+38*cos(theta)**63 - 2.30274442329645e+38*cos(theta)**61 + 1.4724047151057e+38*cos(theta)**59 - 8.44547256971455e+37*cos(theta)**57 + 4.34805620040788e+37*cos(theta)**55 - 2.0096058069112e+37*cos(theta)**53 + 8.33605298592306e+36*cos(theta)**51 - 3.10139117509539e+36*cos(theta)**49 + 1.03379705836513e+36*cos(theta)**47 - 3.08285412439367e+35*cos(theta)**45 + 8.20878317146243e+34*cos(theta)**43 - 1.9470793810955e+34*cos(theta)**41 + 4.10227413283225e+33*cos(theta)**39 - 7.65110780878101e+32*cos(theta)**37 + 1.25818217299954e+32*cos(theta)**35 - 1.81571281332702e+31*cos(theta)**33 + 2.28696652060273e+30*cos(theta)**31 - 2.49809591750122e+29*cos(theta)**29 + 2.34883497569591e+28*cos(theta)**27 - 1.88443674621547e+27*cos(theta)**25 + 1.27671866274761e+26*cos(theta)**23 - 7.21487204992504e+24*cos(theta)**21 + 3.35055977550699e+23*cos(theta)**19 - 1.25563384091978e+22*cos(theta)**17 + 3.71230874706717e+20*cos(theta)**15 - 8.41339128948959e+18*cos(theta)**13 + 1.40764590429041e+17*cos(theta)**11 - 1.65181405453323e+15*cos(theta)**9 + 12630693705011.9*cos(theta)**7 - 56136416466.7197*cos(theta)**5 + 118481250.457408*cos(theta)**3 - 74877.5545338578*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl97_m_minus_1(theta, phi):
    return 0.057138451508111*(1.0 - cos(theta)**2)**0.5*(8.7934815119738e+29*cos(theta)**96 - 2.07763086500521e+31*cos(theta)**94 + 2.37731008139732e+32*cos(theta)**92 - 1.75510052922913e+33*cos(theta)**90 + 9.3972962828378e+33*cos(theta)**88 - 3.88895677521115e+34*cos(theta)**86 + 1.29454799757712e+35*cos(theta)**84 - 3.56179504305748e+35*cos(theta)**82 + 8.26028026396222e+35*cos(theta)**80 - 1.63857411388077e+36*cos(theta)**78 + 2.81179317941939e+36*cos(theta)**76 - 4.21104075740687e+36*cos(theta)**74 + 5.54289526596294e+36*cos(theta)**72 - 6.44863008639112e+36*cos(theta)**70 + 6.66101011917645e+36*cos(theta)**68 - 6.13082062686221e+36*cos(theta)**66 + 5.04241190361174e+36*cos(theta)**64 - 3.71410390854267e+36*cos(theta)**62 + 2.4540078585095e+36*cos(theta)**60 - 1.45611596029561e+36*cos(theta)**58 + 7.76438607215692e+35*cos(theta)**56 - 3.72149223502075e+35*cos(theta)**54 + 1.60308711267751e+35*cos(theta)**52 - 6.20278235019078e+34*cos(theta)**50 + 2.15374387159402e+34*cos(theta)**48 - 6.70185679216015e+33*cos(theta)**46 + 1.86563253896873e+33*cos(theta)**44 - 4.63590328832262e+32*cos(theta)**42 + 1.02556853320806e+32*cos(theta)**40 - 2.01344942336342e+31*cos(theta)**38 + 3.49495048055429e+30*cos(theta)**36 - 5.34033180390299e+29*cos(theta)**34 + 7.14677037688353e+28*cos(theta)**32 - 8.32698639167074e+27*cos(theta)**30 + 8.38869634177112e+26*cos(theta)**28 - 7.24783363929025e+25*cos(theta)**26 + 5.31966109478169e+24*cos(theta)**24 - 3.27948729542047e+23*cos(theta)**22 + 1.67527988775349e+22*cos(theta)**20 - 6.97574356066543e+20*cos(theta)**18 + 2.32019296691698e+19*cos(theta)**16 - 6.00956520677828e+17*cos(theta)**14 + 1.17303825357534e+16*cos(theta)**12 - 165181405453323.0*cos(theta)**10 + 1578836713126.49*cos(theta)**8 - 9356069411.11996*cos(theta)**6 + 29620312.6143519*cos(theta)**4 - 37438.7772669289*cos(theta)**2 + 7.87853056963992)*sin(phi)

#@torch.jit.script
def Yl97_m0(theta, phi):
    return 1.12189281571367e+29*cos(theta)**97 - 2.70649375645742e+30*cos(theta)**95 + 3.16348026769173e+31*cos(theta)**93 - 2.38683749297799e+32*cos(theta)**91 + 1.30669779862899e+33*cos(theta)**89 - 5.53192278857421e+33*cos(theta)**87 + 1.88478352933116e+34*cos(theta)**85 - 5.31071602187232e+34*cos(theta)**83 + 1.26203677530946e+35*cos(theta)**81 - 2.56685445825653e+35*cos(theta)**79 + 4.51913062050765e+35*cos(theta)**77 - 6.94848985580945e+35*cos(theta)**75 + 9.39671508278324e+35*cos(theta)**73 - 1.12401307408076e+36*cos(theta)**71 + 1.19468455478644e+36*cos(theta)**69 - 1.13241614768848e+36*cos(theta)**67 + 9.60035315390809e+35*cos(theta)**65 - 7.2958474826923e+35*cos(theta)**63 + 4.97861290485606e+35*cos(theta)**61 - 3.05426135296232e+35*cos(theta)**59 + 1.68575521771565e+35*cos(theta)**57 - 8.37368604878364e+34*cos(theta)**55 + 3.74320402842977e+34*cos(theta)**53 - 1.50514594431755e+34*cos(theta)**51 + 5.43951553005916e+33*cos(theta)**49 - 1.7646538657516e+33*cos(theta)**47 + 5.13069077159087e+32*cos(theta)**45 - 1.33422218646571e+32*cos(theta)**43 + 3.09558744701577e+31*cos(theta)**41 - 6.38908056016343e+30*cos(theta)**39 + 1.16896510989657e+30*cos(theta)**37 - 1.88826282607595e+29*cos(theta)**35 + 2.68014403987402e+28*cos(theta)**33 - 3.32420966185925e+27*cos(theta)**31 + 3.57979965901934e+26*cos(theta)**29 - 3.32205408356995e+25*cos(theta)**27 + 2.63333555404935e+24*cos(theta)**25 - 1.76457597993032e+23*cos(theta)**23 + 9.87257237776142e+21*cos(theta)**21 - 4.54359018042932e+20*cos(theta)**19 + 1.68903026272481e+19*cos(theta)**17 - 4.95808581330832e+17*cos(theta)**15 + 1.11668599398836e+16*cos(theta)**13 - 185836371946004.0*cos(theta)**11 + 2170985653574.81*cos(theta)**9 - 16540843074.8557*cos(theta)**7 + 73313149.9729781*cos(theta)**5 - 154441.015321209*cos(theta)**3 + 97.500640985612*cos(theta)

#@torch.jit.script
def Yl97_m1(theta, phi):
    return 0.057138451508111*(1.0 - cos(theta)**2)**0.5*(8.7934815119738e+29*cos(theta)**96 - 2.07763086500521e+31*cos(theta)**94 + 2.37731008139732e+32*cos(theta)**92 - 1.75510052922913e+33*cos(theta)**90 + 9.3972962828378e+33*cos(theta)**88 - 3.88895677521115e+34*cos(theta)**86 + 1.29454799757712e+35*cos(theta)**84 - 3.56179504305748e+35*cos(theta)**82 + 8.26028026396222e+35*cos(theta)**80 - 1.63857411388077e+36*cos(theta)**78 + 2.81179317941939e+36*cos(theta)**76 - 4.21104075740687e+36*cos(theta)**74 + 5.54289526596294e+36*cos(theta)**72 - 6.44863008639112e+36*cos(theta)**70 + 6.66101011917645e+36*cos(theta)**68 - 6.13082062686221e+36*cos(theta)**66 + 5.04241190361174e+36*cos(theta)**64 - 3.71410390854267e+36*cos(theta)**62 + 2.4540078585095e+36*cos(theta)**60 - 1.45611596029561e+36*cos(theta)**58 + 7.76438607215692e+35*cos(theta)**56 - 3.72149223502075e+35*cos(theta)**54 + 1.60308711267751e+35*cos(theta)**52 - 6.20278235019078e+34*cos(theta)**50 + 2.15374387159402e+34*cos(theta)**48 - 6.70185679216015e+33*cos(theta)**46 + 1.86563253896873e+33*cos(theta)**44 - 4.63590328832262e+32*cos(theta)**42 + 1.02556853320806e+32*cos(theta)**40 - 2.01344942336342e+31*cos(theta)**38 + 3.49495048055429e+30*cos(theta)**36 - 5.34033180390299e+29*cos(theta)**34 + 7.14677037688353e+28*cos(theta)**32 - 8.32698639167074e+27*cos(theta)**30 + 8.38869634177112e+26*cos(theta)**28 - 7.24783363929025e+25*cos(theta)**26 + 5.31966109478169e+24*cos(theta)**24 - 3.27948729542047e+23*cos(theta)**22 + 1.67527988775349e+22*cos(theta)**20 - 6.97574356066543e+20*cos(theta)**18 + 2.32019296691698e+19*cos(theta)**16 - 6.00956520677828e+17*cos(theta)**14 + 1.17303825357534e+16*cos(theta)**12 - 165181405453323.0*cos(theta)**10 + 1578836713126.49*cos(theta)**8 - 9356069411.11996*cos(theta)**6 + 29620312.6143519*cos(theta)**4 - 37438.7772669289*cos(theta)**2 + 7.87853056963992)*cos(phi)

#@torch.jit.script
def Yl97_m2(theta, phi):
    return 0.00058610476569864*(1.0 - cos(theta)**2)*(8.44174225149484e+31*cos(theta)**95 - 1.9529730131049e+33*cos(theta)**93 + 2.18712527488553e+34*cos(theta)**91 - 1.57959047630622e+35*cos(theta)**89 + 8.26962072889727e+35*cos(theta)**87 - 3.34450282668159e+36*cos(theta)**85 + 1.08742031796478e+37*cos(theta)**83 - 2.92067193530713e+37*cos(theta)**81 + 6.60822421116977e+37*cos(theta)**79 - 1.278087808827e+38*cos(theta)**77 + 2.13696281635874e+38*cos(theta)**75 - 3.11617016048108e+38*cos(theta)**73 + 3.99088459149332e+38*cos(theta)**71 - 4.51404106047378e+38*cos(theta)**69 + 4.52948688103999e+38*cos(theta)**67 - 4.04634161372906e+38*cos(theta)**65 + 3.22714361831152e+38*cos(theta)**63 - 2.30274442329645e+38*cos(theta)**61 + 1.4724047151057e+38*cos(theta)**59 - 8.44547256971455e+37*cos(theta)**57 + 4.34805620040788e+37*cos(theta)**55 - 2.0096058069112e+37*cos(theta)**53 + 8.33605298592306e+36*cos(theta)**51 - 3.10139117509539e+36*cos(theta)**49 + 1.03379705836513e+36*cos(theta)**47 - 3.08285412439367e+35*cos(theta)**45 + 8.20878317146243e+34*cos(theta)**43 - 1.9470793810955e+34*cos(theta)**41 + 4.10227413283225e+33*cos(theta)**39 - 7.65110780878101e+32*cos(theta)**37 + 1.25818217299954e+32*cos(theta)**35 - 1.81571281332702e+31*cos(theta)**33 + 2.28696652060273e+30*cos(theta)**31 - 2.49809591750122e+29*cos(theta)**29 + 2.34883497569591e+28*cos(theta)**27 - 1.88443674621547e+27*cos(theta)**25 + 1.27671866274761e+26*cos(theta)**23 - 7.21487204992504e+24*cos(theta)**21 + 3.35055977550699e+23*cos(theta)**19 - 1.25563384091978e+22*cos(theta)**17 + 3.71230874706717e+20*cos(theta)**15 - 8.41339128948959e+18*cos(theta)**13 + 1.40764590429041e+17*cos(theta)**11 - 1.65181405453323e+15*cos(theta)**9 + 12630693705011.9*cos(theta)**7 - 56136416466.7197*cos(theta)**5 + 118481250.457408*cos(theta)**3 - 74877.5545338578*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl97_m3(theta, phi):
    return 6.01330801660746e-6*(1.0 - cos(theta)**2)**1.5*(8.0196551389201e+33*cos(theta)**94 - 1.81626490218755e+35*cos(theta)**92 + 1.99028400014584e+36*cos(theta)**90 - 1.40583552391254e+37*cos(theta)**88 + 7.19457003414062e+37*cos(theta)**86 - 2.84282740267935e+38*cos(theta)**84 + 9.02558863910766e+38*cos(theta)**82 - 2.36574426759878e+39*cos(theta)**80 + 5.22049712682412e+39*cos(theta)**78 - 9.84127612796788e+39*cos(theta)**76 + 1.60272211226906e+40*cos(theta)**74 - 2.27480421715119e+40*cos(theta)**72 + 2.83352805996026e+40*cos(theta)**70 - 3.11468833172691e+40*cos(theta)**68 + 3.03475621029679e+40*cos(theta)**66 - 2.63012204892389e+40*cos(theta)**64 + 2.03310047953626e+40*cos(theta)**62 - 1.40467409821084e+40*cos(theta)**60 + 8.68718781912362e+39*cos(theta)**58 - 4.81391936473729e+39*cos(theta)**56 + 2.39143091022433e+39*cos(theta)**54 - 1.06509107766294e+39*cos(theta)**52 + 4.25138702282076e+38*cos(theta)**50 - 1.51968167579674e+38*cos(theta)**48 + 4.85884617431611e+37*cos(theta)**46 - 1.38728435597715e+37*cos(theta)**44 + 3.52977676372885e+36*cos(theta)**42 - 7.98302546249156e+35*cos(theta)**40 + 1.59988691180458e+35*cos(theta)**38 - 2.83090988924898e+34*cos(theta)**36 + 4.40363760549841e+33*cos(theta)**34 - 5.99185228397916e+32*cos(theta)**32 + 7.08959621386847e+31*cos(theta)**30 - 7.24447816075354e+30*cos(theta)**28 + 6.34185443437897e+29*cos(theta)**26 - 4.71109186553866e+28*cos(theta)**24 + 2.93645292431949e+27*cos(theta)**22 - 1.51512313048426e+26*cos(theta)**20 + 6.36606357346327e+24*cos(theta)**18 - 2.13457752956362e+23*cos(theta)**16 + 5.56846312060075e+21*cos(theta)**14 - 1.09374086763365e+20*cos(theta)**12 + 1.54841049471945e+18*cos(theta)**10 - 1.48663264907991e+16*cos(theta)**8 + 88414855935083.6*cos(theta)**6 - 280682082333.599*cos(theta)**4 + 355443751.372223*cos(theta)**2 - 74877.5545338578)*cos(3*phi)

#@torch.jit.script
def Yl97_m4(theta, phi):
    return 6.17147304349972e-8*(1.0 - cos(theta)**2)**2*(7.5384758305849e+35*cos(theta)**93 - 1.67096371001255e+37*cos(theta)**91 + 1.79125560013125e+38*cos(theta)**89 - 1.23713526104303e+39*cos(theta)**87 + 6.18733022936093e+39*cos(theta)**85 - 2.38797501825065e+40*cos(theta)**83 + 7.40098268406828e+40*cos(theta)**81 - 1.89259541407902e+41*cos(theta)**79 + 4.07198775892281e+41*cos(theta)**77 - 7.47936985725559e+41*cos(theta)**75 + 1.1860143630791e+42*cos(theta)**73 - 1.63785903634886e+42*cos(theta)**71 + 1.98346964197218e+42*cos(theta)**69 - 2.1179880655743e+42*cos(theta)**67 + 2.00293909879588e+42*cos(theta)**65 - 1.68327811131129e+42*cos(theta)**63 + 1.26052229731248e+42*cos(theta)**61 - 8.42804458926502e+41*cos(theta)**59 + 5.0385689350917e+41*cos(theta)**57 - 2.69579484425288e+41*cos(theta)**55 + 1.29137269152114e+41*cos(theta)**53 - 5.53847360384728e+40*cos(theta)**51 + 2.12569351141038e+40*cos(theta)**49 - 7.29447204382435e+39*cos(theta)**47 + 2.23506924018541e+39*cos(theta)**45 - 6.10405116629946e+38*cos(theta)**43 + 1.48250624076612e+38*cos(theta)**41 - 3.19321018499662e+37*cos(theta)**39 + 6.07957026485739e+36*cos(theta)**37 - 1.01912756012963e+36*cos(theta)**35 + 1.49723678586946e+35*cos(theta)**33 - 1.91739273087333e+34*cos(theta)**31 + 2.12687886416054e+33*cos(theta)**29 - 2.02845388501099e+32*cos(theta)**27 + 1.64888215293853e+31*cos(theta)**25 - 1.13066204772928e+30*cos(theta)**23 + 6.46019643350288e+28*cos(theta)**21 - 3.03024626096852e+27*cos(theta)**19 + 1.14589144322339e+26*cos(theta)**17 - 3.41532404730179e+24*cos(theta)**15 + 7.79584836884105e+22*cos(theta)**13 - 1.31248904116038e+21*cos(theta)**11 + 1.54841049471945e+19*cos(theta)**9 - 1.18930611926392e+17*cos(theta)**7 + 530489135610502.0*cos(theta)**5 - 1122728329334.39*cos(theta)**3 + 710887502.744446*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl97_m5(theta, phi):
    return 6.33646844127197e-10*(1.0 - cos(theta)**2)**2.5*(7.01078252244395e+37*cos(theta)**92 - 1.52057697611142e+39*cos(theta)**90 + 1.59421748411681e+40*cos(theta)**88 - 1.07630767710744e+41*cos(theta)**86 + 5.25923069495679e+41*cos(theta)**84 - 1.98201926514804e+42*cos(theta)**82 + 5.99479597409531e+42*cos(theta)**80 - 1.49515037712243e+43*cos(theta)**78 + 3.13543057437057e+43*cos(theta)**76 - 5.60952739294169e+43*cos(theta)**74 + 8.65790485047744e+43*cos(theta)**72 - 1.16287991580769e+44*cos(theta)**70 + 1.3685940529608e+44*cos(theta)**68 - 1.41905200393478e+44*cos(theta)**66 + 1.30191041421732e+44*cos(theta)**64 - 1.06046521012611e+44*cos(theta)**62 + 7.68918601360612e+43*cos(theta)**60 - 4.97254630766636e+43*cos(theta)**58 + 2.87198429300227e+43*cos(theta)**56 - 1.48268716433909e+43*cos(theta)**54 + 6.84427526506204e+42*cos(theta)**52 - 2.82462153796211e+42*cos(theta)**50 + 1.04158982059109e+42*cos(theta)**48 - 3.42840186059745e+41*cos(theta)**46 + 1.00578115808343e+41*cos(theta)**44 - 2.62474200150877e+40*cos(theta)**42 + 6.07827558714107e+39*cos(theta)**40 - 1.24535197214868e+39*cos(theta)**38 + 2.24944099799724e+38*cos(theta)**36 - 3.56694646045371e+37*cos(theta)**34 + 4.94088139336921e+36*cos(theta)**32 - 5.94391746570732e+35*cos(theta)**30 + 6.16794870606557e+34*cos(theta)**28 - 5.47682548952968e+33*cos(theta)**26 + 4.12220538234633e+32*cos(theta)**24 - 2.60052270977734e+31*cos(theta)**22 + 1.35664125103561e+30*cos(theta)**20 - 5.75746789584018e+28*cos(theta)**18 + 1.94801545347976e+27*cos(theta)**16 - 5.12298607095269e+25*cos(theta)**14 + 1.01346028794934e+24*cos(theta)**12 - 1.44373794527641e+22*cos(theta)**10 + 1.3935694452475e+20*cos(theta)**8 - 8.32514283484747e+17*cos(theta)**6 + 2.65244567805251e+15*cos(theta)**4 - 3368184988003.18*cos(theta)**2 + 710887502.744446)*cos(5*phi)

#@torch.jit.script
def Yl97_m6(theta, phi):
    return 6.50930693144599e-12*(1.0 - cos(theta)**2)**3*(6.44991992064844e+39*cos(theta)**91 - 1.36851927850028e+41*cos(theta)**89 + 1.4029113860228e+42*cos(theta)**87 - 9.25624602312396e+42*cos(theta)**85 + 4.41775378376371e+43*cos(theta)**83 - 1.62525579742139e+44*cos(theta)**81 + 4.79583677927624e+44*cos(theta)**79 - 1.16621729415549e+45*cos(theta)**77 + 2.38292723652163e+45*cos(theta)**75 - 4.15105027077685e+45*cos(theta)**73 + 6.23369149234375e+45*cos(theta)**71 - 8.14015941065382e+45*cos(theta)**69 + 9.30643956013346e+45*cos(theta)**67 - 9.36574322596955e+45*cos(theta)**65 + 8.33222665099087e+45*cos(theta)**63 - 6.57488430278189e+45*cos(theta)**61 + 4.61351160816367e+45*cos(theta)**59 - 2.88407685844649e+45*cos(theta)**57 + 1.60831120408127e+45*cos(theta)**55 - 8.00651068743107e+44*cos(theta)**53 + 3.55902313783226e+44*cos(theta)**51 - 1.41231076898106e+44*cos(theta)**49 + 4.99963113883721e+43*cos(theta)**47 - 1.57706485587483e+43*cos(theta)**45 + 4.42543709556711e+42*cos(theta)**43 - 1.10239164063368e+42*cos(theta)**41 + 2.43131023485643e+41*cos(theta)**39 - 4.732337494165e+40*cos(theta)**37 + 8.09798759279005e+39*cos(theta)**35 - 1.21276179655426e+39*cos(theta)**33 + 1.58108204587815e+38*cos(theta)**31 - 1.7831752397122e+37*cos(theta)**29 + 1.72702563769836e+36*cos(theta)**27 - 1.42397462727772e+35*cos(theta)**25 + 9.89329291763119e+33*cos(theta)**23 - 5.72114996151015e+32*cos(theta)**21 + 2.71328250207121e+31*cos(theta)**19 - 1.03634422125123e+30*cos(theta)**17 + 3.11682472556762e+28*cos(theta)**15 - 7.17218049933377e+26*cos(theta)**13 + 1.2161523455392e+25*cos(theta)**11 - 1.44373794527641e+23*cos(theta)**9 + 1.114855556198e+21*cos(theta)**7 - 4.99508570090848e+18*cos(theta)**5 + 1.060978271221e+16*cos(theta)**3 - 6736369976006.37*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl97_m7(theta, phi):
    return 6.69109790187465e-14*(1.0 - cos(theta)**2)**3.5*(5.86942712779008e+41*cos(theta)**90 - 1.21798215786525e+43*cos(theta)**88 + 1.22053290583983e+44*cos(theta)**86 - 7.86780911965536e+44*cos(theta)**84 + 3.66673564052388e+45*cos(theta)**82 - 1.31645719591133e+46*cos(theta)**80 + 3.78871105562823e+46*cos(theta)**78 - 8.9798731649973e+46*cos(theta)**76 + 1.78719542739122e+47*cos(theta)**74 - 3.0302666976671e+47*cos(theta)**72 + 4.42592095956406e+47*cos(theta)**70 - 5.61670999335114e+47*cos(theta)**68 + 6.23531450528942e+47*cos(theta)**66 - 6.0877330968802e+47*cos(theta)**64 + 5.24930279012425e+47*cos(theta)**62 - 4.01067942469695e+47*cos(theta)**60 + 2.72197184881657e+47*cos(theta)**58 - 1.6439238093145e+47*cos(theta)**56 + 8.84571162244699e+46*cos(theta)**54 - 4.24345066433846e+46*cos(theta)**52 + 1.81510180029445e+46*cos(theta)**50 - 6.92032276800717e+45*cos(theta)**48 + 2.34982663525349e+45*cos(theta)**46 - 7.09679185143671e+44*cos(theta)**44 + 1.90293795109386e+44*cos(theta)**42 - 4.5198057265981e+43*cos(theta)**40 + 9.48210991594007e+42*cos(theta)**38 - 1.75096487284105e+42*cos(theta)**36 + 2.83429565747652e+41*cos(theta)**34 - 4.00211392862906e+40*cos(theta)**32 + 4.90135434222226e+39*cos(theta)**30 - 5.17120819516537e+38*cos(theta)**28 + 4.66296922178557e+37*cos(theta)**26 - 3.55993656819429e+36*cos(theta)**24 + 2.27545737105517e+35*cos(theta)**22 - 1.20144149191713e+34*cos(theta)**20 + 5.1552367539353e+32*cos(theta)**18 - 1.7617851761271e+31*cos(theta)**16 + 4.67523708835143e+29*cos(theta)**14 - 9.3238346491339e+27*cos(theta)**12 + 1.33776758009312e+26*cos(theta)**10 - 1.29936415074877e+24*cos(theta)**8 + 7.80398889338602e+21*cos(theta)**6 - 2.49754285045424e+19*cos(theta)**4 + 3.18293481366301e+16*cos(theta)**2 - 6736369976006.37)*cos(7*phi)

#@torch.jit.script
def Yl97_m8(theta, phi):
    return 6.88305880789055e-16*(1.0 - cos(theta)**2)**4*(5.28248441501107e+43*cos(theta)**89 - 1.07182429892142e+45*cos(theta)**87 + 1.04965829902226e+46*cos(theta)**85 - 6.60895966051051e+46*cos(theta)**83 + 3.00672322522958e+47*cos(theta)**81 - 1.05316575672906e+48*cos(theta)**79 + 2.95519462339002e+48*cos(theta)**77 - 6.82470360539795e+48*cos(theta)**75 + 1.32252461626951e+49*cos(theta)**73 - 2.18179202232031e+49*cos(theta)**71 + 3.09814467169485e+49*cos(theta)**69 - 3.81936279547877e+49*cos(theta)**67 + 4.11530757349102e+49*cos(theta)**65 - 3.89614918200333e+49*cos(theta)**63 + 3.25456772987703e+49*cos(theta)**61 - 2.40640765481817e+49*cos(theta)**59 + 1.57874367231361e+49*cos(theta)**57 - 9.20597333216119e+48*cos(theta)**55 + 4.77668427612137e+48*cos(theta)**53 - 2.206594345456e+48*cos(theta)**51 + 9.07550900147226e+47*cos(theta)**49 - 3.32175492864344e+47*cos(theta)**47 + 1.08092025221661e+47*cos(theta)**45 - 3.12258841463215e+46*cos(theta)**43 + 7.9923393945942e+45*cos(theta)**41 - 1.80792229063924e+45*cos(theta)**39 + 3.60320176805723e+44*cos(theta)**37 - 6.30347354222777e+43*cos(theta)**35 + 9.63660523542016e+42*cos(theta)**33 - 1.2806764571613e+42*cos(theta)**31 + 1.47040630266668e+41*cos(theta)**29 - 1.4479382946463e+40*cos(theta)**27 + 1.21237199766425e+39*cos(theta)**25 - 8.5438477636663e+37*cos(theta)**23 + 5.00600621632138e+36*cos(theta)**21 - 2.40288298383426e+35*cos(theta)**19 + 9.27942615708354e+33*cos(theta)**17 - 2.81885628180335e+32*cos(theta)**15 + 6.545331923692e+30*cos(theta)**13 - 1.11886015789607e+29*cos(theta)**11 + 1.33776758009312e+27*cos(theta)**9 - 1.03949132059902e+25*cos(theta)**7 + 4.68239333603161e+22*cos(theta)**5 - 9.99017140181696e+19*cos(theta)**3 + 6.36586962732602e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl97_m9(theta, phi):
    return 7.08652859942738e-18*(1.0 - cos(theta)**2)**4.5*(4.70141112935985e+45*cos(theta)**88 - 9.32487140061633e+46*cos(theta)**86 + 8.92209554168918e+47*cos(theta)**84 - 5.48543651822372e+48*cos(theta)**82 + 2.43544581243596e+49*cos(theta)**80 - 8.3200094781596e+49*cos(theta)**78 + 2.27549986001032e+50*cos(theta)**76 - 5.11852770404846e+50*cos(theta)**74 + 9.65442969876739e+50*cos(theta)**72 - 1.54907233584742e+51*cos(theta)**70 + 2.13771982346944e+51*cos(theta)**68 - 2.55897307297078e+51*cos(theta)**66 + 2.67494992276916e+51*cos(theta)**64 - 2.4545739846621e+51*cos(theta)**62 + 1.98528631522499e+51*cos(theta)**60 - 1.41978051634272e+51*cos(theta)**58 + 8.99883893218757e+50*cos(theta)**56 - 5.06328533268866e+50*cos(theta)**54 + 2.53164266634433e+50*cos(theta)**52 - 1.12536311618256e+50*cos(theta)**50 + 4.44699941072141e+49*cos(theta)**48 - 1.56122481646242e+49*cos(theta)**46 + 4.86414113497472e+48*cos(theta)**44 - 1.34271301829183e+48*cos(theta)**42 + 3.27685915178362e+47*cos(theta)**40 - 7.05089693349304e+46*cos(theta)**38 + 1.33318465418117e+46*cos(theta)**36 - 2.20621573977972e+45*cos(theta)**34 + 3.18007972768865e+44*cos(theta)**32 - 3.97009701720003e+43*cos(theta)**30 + 4.26417827773336e+42*cos(theta)**28 - 3.90943339554502e+41*cos(theta)**26 + 3.03092999416062e+40*cos(theta)**24 - 1.96508498564325e+39*cos(theta)**22 + 1.05126130542749e+38*cos(theta)**20 - 4.5654776692851e+36*cos(theta)**18 + 1.5775024467042e+35*cos(theta)**16 - 4.22828442270503e+33*cos(theta)**14 + 8.5089315007996e+31*cos(theta)**12 - 1.23074617368567e+30*cos(theta)**10 + 1.20399082208381e+28*cos(theta)**8 - 7.27643924419312e+25*cos(theta)**6 + 2.34119666801581e+23*cos(theta)**4 - 2.99705142054509e+20*cos(theta)**2 + 6.36586962732602e+16)*cos(9*phi)

#@torch.jit.script
def Yl97_m10(theta, phi):
    return 7.3029834971282e-20*(1.0 - cos(theta)**2)**5*(4.13724179383667e+47*cos(theta)**87 - 8.01938940453004e+48*cos(theta)**85 + 7.49456025501891e+49*cos(theta)**83 - 4.49805794494345e+50*cos(theta)**81 + 1.94835664994877e+51*cos(theta)**79 - 6.48960739296449e+51*cos(theta)**77 + 1.72937989360784e+52*cos(theta)**75 - 3.78771050099586e+52*cos(theta)**73 + 6.95118938311252e+52*cos(theta)**71 - 1.0843506350932e+53*cos(theta)**69 + 1.45364947995922e+53*cos(theta)**67 - 1.68892222816071e+53*cos(theta)**65 + 1.71196795057226e+53*cos(theta)**63 - 1.5218358704905e+53*cos(theta)**61 + 1.19117178913499e+53*cos(theta)**59 - 8.23472699478778e+52*cos(theta)**57 + 5.03934980202504e+52*cos(theta)**55 - 2.73417407965187e+52*cos(theta)**53 + 1.31645418649905e+52*cos(theta)**51 - 5.6268155809128e+51*cos(theta)**49 + 2.13455971714628e+51*cos(theta)**47 - 7.18163415572712e+50*cos(theta)**45 + 2.14022209938888e+50*cos(theta)**43 - 5.63939467682567e+49*cos(theta)**41 + 1.31074366071345e+49*cos(theta)**39 - 2.67934083472735e+48*cos(theta)**37 + 4.79946475505223e+47*cos(theta)**35 - 7.50113351525105e+46*cos(theta)**33 + 1.01762551286037e+46*cos(theta)**31 - 1.19102910516001e+45*cos(theta)**29 + 1.19396991776534e+44*cos(theta)**27 - 1.01645268284171e+43*cos(theta)**25 + 7.27423198598549e+41*cos(theta)**23 - 4.32318696841515e+40*cos(theta)**21 + 2.10252261085498e+39*cos(theta)**19 - 8.21785980471318e+37*cos(theta)**17 + 2.52400391472672e+36*cos(theta)**15 - 5.91959819178704e+34*cos(theta)**13 + 1.02107178009595e+33*cos(theta)**11 - 1.23074617368567e+31*cos(theta)**9 + 9.6319265766705e+28*cos(theta)**7 - 4.36586354651587e+26*cos(theta)**5 + 9.36478667206322e+23*cos(theta)**3 - 5.99410284109018e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl97_m11(theta, phi):
    return 7.53405550111472e-22*(1.0 - cos(theta)**2)**5.5*(3.5994003606379e+49*cos(theta)**86 - 6.81648099385054e+50*cos(theta)**84 + 6.2204850116657e+51*cos(theta)**82 - 3.64342693540419e+52*cos(theta)**80 + 1.53920175345953e+53*cos(theta)**78 - 4.99699769258266e+53*cos(theta)**76 + 1.29703492020588e+54*cos(theta)**74 - 2.76502866572698e+54*cos(theta)**72 + 4.93534446200989e+54*cos(theta)**70 - 7.48201938214305e+54*cos(theta)**68 + 9.73945151572678e+54*cos(theta)**66 - 1.09779944830446e+55*cos(theta)**64 + 1.07853980886053e+55*cos(theta)**62 - 9.28319880999206e+54*cos(theta)**60 + 7.02791355589647e+54*cos(theta)**58 - 4.69379438702903e+54*cos(theta)**56 + 2.77164239111377e+54*cos(theta)**54 - 1.44911226221549e+54*cos(theta)**52 + 6.71391635114516e+53*cos(theta)**50 - 2.75713963464727e+53*cos(theta)**48 + 1.00324306705875e+53*cos(theta)**46 - 3.23173537007721e+52*cos(theta)**44 + 9.20295502737218e+51*cos(theta)**42 - 2.31215181749852e+51*cos(theta)**40 + 5.11190027678245e+50*cos(theta)**38 - 9.91356108849121e+49*cos(theta)**36 + 1.67981266426828e+49*cos(theta)**34 - 2.47537406003285e+48*cos(theta)**32 + 3.15463908986714e+47*cos(theta)**30 - 3.45398440496402e+46*cos(theta)**28 + 3.22371877796642e+45*cos(theta)**26 - 2.54113170710426e+44*cos(theta)**24 + 1.67307335677666e+43*cos(theta)**22 - 9.07869263367181e+41*cos(theta)**20 + 3.99479296062446e+40*cos(theta)**18 - 1.39703616680124e+39*cos(theta)**16 + 3.78600587209008e+37*cos(theta)**14 - 7.69547764932316e+35*cos(theta)**12 + 1.12317895810555e+34*cos(theta)**10 - 1.10767155631711e+32*cos(theta)**8 + 6.74234860366935e+29*cos(theta)**6 - 2.18293177325794e+27*cos(theta)**4 + 2.80943600161897e+24*cos(theta)**2 - 5.99410284109018e+20)*cos(11*phi)

#@torch.jit.script
def Yl97_m12(theta, phi):
    return 7.78155409001107e-24*(1.0 - cos(theta)**2)**6*(3.0954843101486e+51*cos(theta)**85 - 5.72584403483445e+52*cos(theta)**83 + 5.10079770956587e+53*cos(theta)**81 - 2.91474154832336e+54*cos(theta)**79 + 1.20057736769843e+55*cos(theta)**77 - 3.79771824636282e+55*cos(theta)**75 + 9.59805840952352e+55*cos(theta)**73 - 1.99082063932343e+56*cos(theta)**71 + 3.45474112340692e+56*cos(theta)**69 - 5.08777317985728e+56*cos(theta)**67 + 6.42803800037968e+56*cos(theta)**65 - 7.02591646914857e+56*cos(theta)**63 + 6.68694681493526e+56*cos(theta)**61 - 5.56991928599523e+56*cos(theta)**59 + 4.07618986241995e+56*cos(theta)**57 - 2.62852485673626e+56*cos(theta)**55 + 1.49668689120144e+56*cos(theta)**53 - 7.53538376352057e+55*cos(theta)**51 + 3.35695817557258e+55*cos(theta)**49 - 1.32342702463069e+55*cos(theta)**47 + 4.61491810847025e+54*cos(theta)**45 - 1.42196356283397e+54*cos(theta)**43 + 3.86524111149631e+53*cos(theta)**41 - 9.2486072699941e+52*cos(theta)**39 + 1.94252210517733e+52*cos(theta)**37 - 3.56888199185684e+51*cos(theta)**35 + 5.71136305851215e+50*cos(theta)**33 - 7.92119699210511e+49*cos(theta)**31 + 9.46391726960143e+48*cos(theta)**29 - 9.67115633389927e+47*cos(theta)**27 + 8.3816688227127e+46*cos(theta)**25 - 6.09871609705023e+45*cos(theta)**23 + 3.68076138490866e+44*cos(theta)**21 - 1.81573852673436e+43*cos(theta)**19 + 7.19062732912404e+41*cos(theta)**17 - 2.23525786688199e+40*cos(theta)**15 + 5.30040822092612e+38*cos(theta)**13 - 9.23457317918779e+36*cos(theta)**11 + 1.12317895810555e+35*cos(theta)**9 - 8.86137245053686e+32*cos(theta)**7 + 4.04540916220161e+30*cos(theta)**5 - 8.73172709303175e+27*cos(theta)**3 + 5.61887200323793e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl97_m13(theta, phi):
    return 8.04749165795024e-26*(1.0 - cos(theta)**2)**6.5*(2.63116166362631e+53*cos(theta)**84 - 4.75245054891259e+54*cos(theta)**82 + 4.13164614474836e+55*cos(theta)**80 - 2.30264582317545e+56*cos(theta)**78 + 9.24444573127791e+56*cos(theta)**76 - 2.84828868477211e+57*cos(theta)**74 + 7.00658263895217e+57*cos(theta)**72 - 1.41348265391963e+58*cos(theta)**70 + 2.38377137515078e+58*cos(theta)**68 - 3.40880803050437e+58*cos(theta)**66 + 4.17822470024679e+58*cos(theta)**64 - 4.4263273755636e+58*cos(theta)**62 + 4.07903755711051e+58*cos(theta)**60 - 3.28625237873719e+58*cos(theta)**58 + 2.32342822157937e+58*cos(theta)**56 - 1.44568867120494e+58*cos(theta)**54 + 7.93244052336761e+57*cos(theta)**52 - 3.84304571939549e+57*cos(theta)**50 + 1.64490950603056e+57*cos(theta)**48 - 6.22010701576425e+56*cos(theta)**46 + 2.07671314881161e+56*cos(theta)**44 - 6.11444332018607e+55*cos(theta)**42 + 1.58474885571349e+55*cos(theta)**40 - 3.6069568352977e+54*cos(theta)**38 + 7.18733178915613e+53*cos(theta)**36 - 1.24910869714989e+53*cos(theta)**34 + 1.88474980930901e+52*cos(theta)**32 - 2.45557106755258e+51*cos(theta)**30 + 2.74453600818441e+50*cos(theta)**28 - 2.6112122101528e+49*cos(theta)**26 + 2.09541720567818e+48*cos(theta)**24 - 1.40270470232155e+47*cos(theta)**22 + 7.72959890830818e+45*cos(theta)**20 - 3.44990320079529e+44*cos(theta)**18 + 1.22240664595109e+43*cos(theta)**16 - 3.35288680032298e+41*cos(theta)**14 + 6.89053068720395e+39*cos(theta)**12 - 1.01580304971066e+38*cos(theta)**10 + 1.01086106229499e+36*cos(theta)**8 - 6.2029607153758e+33*cos(theta)**6 + 2.0227045811008e+31*cos(theta)**4 - 2.61951812790952e+28*cos(theta)**2 + 5.61887200323793e+24)*cos(13*phi)

#@torch.jit.script
def Yl97_m14(theta, phi):
    return 8.33411334732858e-28*(1.0 - cos(theta)**2)**7*(2.2101757974461e+55*cos(theta)**83 - 3.89700945010833e+56*cos(theta)**81 + 3.30531691579869e+57*cos(theta)**79 - 1.79606374207685e+58*cos(theta)**77 + 7.02577875577121e+58*cos(theta)**75 - 2.10773362673136e+59*cos(theta)**73 + 5.04473950004556e+59*cos(theta)**71 - 9.89437857743743e+59*cos(theta)**69 + 1.62096453510253e+60*cos(theta)**67 - 2.24981330013289e+60*cos(theta)**65 + 2.67406380815795e+60*cos(theta)**63 - 2.74432297284943e+60*cos(theta)**61 + 2.44742253426631e+60*cos(theta)**59 - 1.90602637966757e+60*cos(theta)**57 + 1.30111980408445e+60*cos(theta)**55 - 7.80671882450669e+59*cos(theta)**53 + 4.12486907215116e+59*cos(theta)**51 - 1.92152285969774e+59*cos(theta)**49 + 7.89556562894671e+58*cos(theta)**47 - 2.86124922725155e+58*cos(theta)**45 + 9.1375378547711e+57*cos(theta)**43 - 2.56806619447815e+57*cos(theta)**41 + 6.33899542285395e+56*cos(theta)**39 - 1.37064359741313e+56*cos(theta)**37 + 2.58743944409621e+55*cos(theta)**35 - 4.24696957030963e+54*cos(theta)**33 + 6.03119938978883e+53*cos(theta)**31 - 7.36671320265775e+52*cos(theta)**29 + 7.68470082291636e+51*cos(theta)**27 - 6.78915174639729e+50*cos(theta)**25 + 5.02900129362762e+49*cos(theta)**23 - 3.08595034510742e+48*cos(theta)**21 + 1.54591978166164e+47*cos(theta)**19 - 6.20982576143152e+45*cos(theta)**17 + 1.95585063352174e+44*cos(theta)**15 - 4.69404152045217e+42*cos(theta)**13 + 8.26863682464474e+40*cos(theta)**11 - 1.01580304971066e+39*cos(theta)**9 + 8.08688849835994e+36*cos(theta)**7 - 3.72177642922548e+34*cos(theta)**5 + 8.09081832440322e+31*cos(theta)**3 - 5.23903625581905e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl97_m15(theta, phi):
    return 8.64393206963614e-30*(1.0 - cos(theta)**2)**7.5*(1.83444591188026e+57*cos(theta)**82 - 3.15657765458774e+58*cos(theta)**80 + 2.61120036348096e+59*cos(theta)**78 - 1.38296908139918e+60*cos(theta)**76 + 5.26933406682841e+60*cos(theta)**74 - 1.5386455475139e+61*cos(theta)**72 + 3.58176504503235e+61*cos(theta)**70 - 6.82712121843182e+61*cos(theta)**68 + 1.08604623851869e+62*cos(theta)**66 - 1.46237864508638e+62*cos(theta)**64 + 1.68466019913951e+62*cos(theta)**62 - 1.67403701343815e+62*cos(theta)**60 + 1.44397929521712e+62*cos(theta)**58 - 1.08643503641051e+62*cos(theta)**56 + 7.15615892246447e+61*cos(theta)**54 - 4.13756097698855e+61*cos(theta)**52 + 2.10368322679709e+61*cos(theta)**50 - 9.41546201251895e+60*cos(theta)**48 + 3.71091584560495e+60*cos(theta)**46 - 1.2875621522632e+60*cos(theta)**44 + 3.92914127755157e+59*cos(theta)**42 - 1.05290713973604e+59*cos(theta)**40 + 2.47220821491304e+58*cos(theta)**38 - 5.07138131042856e+57*cos(theta)**36 + 9.05603805433672e+56*cos(theta)**34 - 1.40149995820218e+56*cos(theta)**32 + 1.86967181083454e+55*cos(theta)**30 - 2.13634682877075e+54*cos(theta)**28 + 2.07486922218742e+53*cos(theta)**26 - 1.69728793659932e+52*cos(theta)**24 + 1.15667029753435e+51*cos(theta)**22 - 6.48049572472557e+49*cos(theta)**20 + 2.93724758515711e+48*cos(theta)**18 - 1.05567037944336e+47*cos(theta)**16 + 2.93377595028261e+45*cos(theta)**14 - 6.10225397658782e+43*cos(theta)**12 + 9.09550050710922e+41*cos(theta)**10 - 9.14222744739591e+39*cos(theta)**8 + 5.66082194885196e+37*cos(theta)**6 - 1.86088821461274e+35*cos(theta)**4 + 2.42724549732097e+32*cos(theta)**2 - 5.23903625581905e+28)*cos(15*phi)

#@torch.jit.script
def Yl97_m16(theta, phi):
    return 8.97976967158516e-32*(1.0 - cos(theta)**2)**8*(1.50424564774181e+59*cos(theta)**81 - 2.5252621236702e+60*cos(theta)**79 + 2.03673628351515e+61*cos(theta)**77 - 1.05105650186337e+62*cos(theta)**75 + 3.89930720945302e+62*cos(theta)**73 - 1.10782479421001e+63*cos(theta)**71 + 2.50723553152264e+63*cos(theta)**69 - 4.64244242853364e+63*cos(theta)**67 + 7.16790517422338e+63*cos(theta)**65 - 9.35922332855281e+63*cos(theta)**63 + 1.04448932346649e+64*cos(theta)**61 - 1.00442220806289e+64*cos(theta)**59 + 8.3750799122593e+63*cos(theta)**57 - 6.08403620389888e+63*cos(theta)**55 + 3.86432581813081e+63*cos(theta)**53 - 2.15153170803404e+63*cos(theta)**51 + 1.05184161339855e+63*cos(theta)**49 - 4.51942176600909e+62*cos(theta)**47 + 1.70702128897828e+62*cos(theta)**45 - 5.66527346995808e+61*cos(theta)**43 + 1.65023933657166e+61*cos(theta)**41 - 4.21162855894417e+60*cos(theta)**39 + 9.39439121666956e+59*cos(theta)**37 - 1.82569727175428e+59*cos(theta)**35 + 3.07905293847449e+58*cos(theta)**33 - 4.48479986624697e+57*cos(theta)**31 + 5.60901543250361e+56*cos(theta)**29 - 5.98177112055809e+55*cos(theta)**27 + 5.39465997768728e+54*cos(theta)**25 - 4.07349104783837e+53*cos(theta)**23 + 2.54467465457558e+52*cos(theta)**21 - 1.29609914494512e+51*cos(theta)**19 + 5.28704565328279e+49*cos(theta)**17 - 1.68907260710937e+48*cos(theta)**15 + 4.10728633039565e+46*cos(theta)**13 - 7.32270477190539e+44*cos(theta)**11 + 9.09550050710922e+42*cos(theta)**9 - 7.31378195791673e+40*cos(theta)**7 + 3.39649316931117e+38*cos(theta)**5 - 7.44355285845096e+35*cos(theta)**3 + 4.85449099464193e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl97_m17(theta, phi):
    return 9.34480540630919e-34*(1.0 - cos(theta)**2)**8.5*(1.21843897467087e+61*cos(theta)**80 - 1.99495707769945e+62*cos(theta)**78 + 1.56828693830667e+63*cos(theta)**76 - 7.8829237639753e+63*cos(theta)**74 + 2.84649426290071e+64*cos(theta)**72 - 7.86555603889104e+64*cos(theta)**70 + 1.72999251675062e+65*cos(theta)**68 - 3.11043642711754e+65*cos(theta)**66 + 4.6591383632452e+65*cos(theta)**64 - 5.89631069698827e+65*cos(theta)**62 + 6.37138487314561e+65*cos(theta)**60 - 5.92609102757106e+65*cos(theta)**58 + 4.7737955499878e+65*cos(theta)**56 - 3.34621991214438e+65*cos(theta)**54 + 2.04809268360933e+65*cos(theta)**52 - 1.09728117109736e+65*cos(theta)**50 + 5.15402390565287e+64*cos(theta)**48 - 2.12412823002427e+64*cos(theta)**46 + 7.68159580040225e+63*cos(theta)**44 - 2.43606759208197e+63*cos(theta)**42 + 6.76598127994381e+62*cos(theta)**40 - 1.64253513798823e+62*cos(theta)**38 + 3.47592475016774e+61*cos(theta)**36 - 6.38994045113999e+60*cos(theta)**34 + 1.01608746969658e+60*cos(theta)**32 - 1.39028795853656e+59*cos(theta)**30 + 1.62661447542605e+58*cos(theta)**28 - 1.61507820255069e+57*cos(theta)**26 + 1.34866499442182e+56*cos(theta)**24 - 9.36902941002826e+54*cos(theta)**22 + 5.34381677460871e+53*cos(theta)**20 - 2.46258837539572e+52*cos(theta)**18 + 8.98797761058075e+50*cos(theta)**16 - 2.53360891066406e+49*cos(theta)**14 + 5.33947222951434e+47*cos(theta)**12 - 8.05497524909592e+45*cos(theta)**10 + 8.1859504563983e+43*cos(theta)**8 - 5.11964737054171e+41*cos(theta)**6 + 1.69824658465559e+39*cos(theta)**4 - 2.23306585753529e+36*cos(theta)**2 + 4.85449099464193e+32)*cos(17*phi)

#@torch.jit.script
def Yl97_m18(theta, phi):
    return 9.74263311886972e-36*(1.0 - cos(theta)**2)**9*(9.74751179736695e+62*cos(theta)**79 - 1.55606652060557e+64*cos(theta)**77 + 1.19189807311307e+65*cos(theta)**75 - 5.83336358534172e+65*cos(theta)**73 + 2.04947586928851e+66*cos(theta)**71 - 5.50588922722372e+66*cos(theta)**69 + 1.17639491139042e+67*cos(theta)**67 - 2.05288804189758e+67*cos(theta)**65 + 2.98184855247693e+67*cos(theta)**63 - 3.65571263213273e+67*cos(theta)**61 + 3.82283092388737e+67*cos(theta)**59 - 3.43713279599122e+67*cos(theta)**57 + 2.67332550799317e+67*cos(theta)**55 - 1.80695875255797e+67*cos(theta)**53 + 1.06500819547685e+67*cos(theta)**51 - 5.48640585548681e+66*cos(theta)**49 + 2.47393147471338e+66*cos(theta)**47 - 9.77098985811166e+65*cos(theta)**45 + 3.37990215217699e+65*cos(theta)**43 - 1.02314838867443e+65*cos(theta)**41 + 2.70639251197752e+64*cos(theta)**39 - 6.24163352435526e+63*cos(theta)**37 + 1.25133291006039e+63*cos(theta)**35 - 2.1725797533876e+62*cos(theta)**33 + 3.25147990302906e+61*cos(theta)**31 - 4.17086387560969e+60*cos(theta)**29 + 4.55452053119293e+59*cos(theta)**27 - 4.19920332663178e+58*cos(theta)**25 + 3.23679598661237e+57*cos(theta)**23 - 2.06118647020622e+56*cos(theta)**21 + 1.06876335492174e+55*cos(theta)**19 - 4.43265907571229e+53*cos(theta)**17 + 1.43807641769292e+52*cos(theta)**15 - 3.54705247492968e+50*cos(theta)**13 + 6.40736667541721e+48*cos(theta)**11 - 8.05497524909592e+46*cos(theta)**9 + 6.54876036511864e+44*cos(theta)**7 - 3.07178842232503e+42*cos(theta)**5 + 6.79298633862235e+39*cos(theta)**3 - 4.46613171507058e+36*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl97_m19(theta, phi):
    return 1.01773288634356e-37*(1.0 - cos(theta)**2)**9.5*(7.70053431991989e+64*cos(theta)**78 - 1.19817122086629e+66*cos(theta)**76 + 8.93923554834799e+66*cos(theta)**74 - 4.25835541729946e+67*cos(theta)**72 + 1.45512786719484e+68*cos(theta)**70 - 3.79906356678437e+68*cos(theta)**68 + 7.88184590631584e+68*cos(theta)**66 - 1.33437722723342e+69*cos(theta)**64 + 1.87856458806046e+69*cos(theta)**62 - 2.22998470560096e+69*cos(theta)**60 + 2.25547024509355e+69*cos(theta)**58 - 1.95916569371499e+69*cos(theta)**56 + 1.47032902939624e+69*cos(theta)**54 - 9.57688138855723e+68*cos(theta)**52 + 5.43154179693194e+68*cos(theta)**50 - 2.68833886918854e+68*cos(theta)**48 + 1.16274779311529e+68*cos(theta)**46 - 4.39694543615025e+67*cos(theta)**44 + 1.45335792543611e+67*cos(theta)**42 - 4.19490839356516e+66*cos(theta)**40 + 1.05549307967123e+66*cos(theta)**38 - 2.30940440401145e+65*cos(theta)**36 + 4.37966518521135e+64*cos(theta)**34 - 7.16951318617907e+63*cos(theta)**32 + 1.00795876993901e+63*cos(theta)**30 - 1.20955052392681e+62*cos(theta)**28 + 1.22972054342209e+61*cos(theta)**26 - 1.04980083165795e+60*cos(theta)**24 + 7.44463076920845e+58*cos(theta)**22 - 4.32849158743305e+57*cos(theta)**20 + 2.03065037435131e+56*cos(theta)**18 - 7.5355204287109e+54*cos(theta)**16 + 2.15711462653938e+53*cos(theta)**14 - 4.61116821740859e+51*cos(theta)**12 + 7.04810334295893e+49*cos(theta)**10 - 7.24947772418633e+47*cos(theta)**8 + 4.58413225558305e+45*cos(theta)**6 - 1.53589421116251e+43*cos(theta)**4 + 2.0378959015867e+40*cos(theta)**2 - 4.46613171507058e+36)*cos(19*phi)

#@torch.jit.script
def Yl97_m20(theta, phi):
    return 1.06535310512464e-39*(1.0 - cos(theta)**2)**10*(6.00641676953752e+66*cos(theta)**77 - 9.10610127858382e+67*cos(theta)**75 + 6.61503430577752e+68*cos(theta)**73 - 3.06601590045561e+69*cos(theta)**71 + 1.01858950703639e+70*cos(theta)**69 - 2.58336322541337e+70*cos(theta)**67 + 5.20201829816846e+70*cos(theta)**65 - 8.54001425429391e+70*cos(theta)**63 + 1.16471004459749e+71*cos(theta)**61 - 1.33799082336058e+71*cos(theta)**59 + 1.30817274215426e+71*cos(theta)**57 - 1.0971327884804e+71*cos(theta)**55 + 7.93977675873971e+70*cos(theta)**53 - 4.97997832204976e+70*cos(theta)**51 + 2.71577089846597e+70*cos(theta)**49 - 1.2904026572105e+70*cos(theta)**47 + 5.34863984833032e+69*cos(theta)**45 - 1.93465599190611e+69*cos(theta)**43 + 6.10410328683164e+68*cos(theta)**41 - 1.67796335742606e+68*cos(theta)**39 + 4.01087370275069e+67*cos(theta)**37 - 8.3138558544412e+66*cos(theta)**35 + 1.48908616297186e+66*cos(theta)**33 - 2.2942442195773e+65*cos(theta)**31 + 3.02387630981702e+64*cos(theta)**29 - 3.38674146699507e+63*cos(theta)**27 + 3.19727341289744e+62*cos(theta)**25 - 2.51952199597907e+61*cos(theta)**23 + 1.63781876922586e+60*cos(theta)**21 - 8.65698317486611e+58*cos(theta)**19 + 3.65517067383236e+57*cos(theta)**17 - 1.20568326859374e+56*cos(theta)**15 + 3.01996047715513e+54*cos(theta)**13 - 5.5334018608903e+52*cos(theta)**11 + 7.04810334295893e+50*cos(theta)**9 - 5.79958217934906e+48*cos(theta)**7 + 2.75047935334983e+46*cos(theta)**5 - 6.14357684465005e+43*cos(theta)**3 + 4.07579180317341e+40*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl97_m21(theta, phi):
    return 1.11765357029373e-41*(1.0 - cos(theta)**2)**10.5*(4.62494091254389e+68*cos(theta)**76 - 6.82957595893787e+69*cos(theta)**74 + 4.82897504321759e+70*cos(theta)**72 - 2.17687128932348e+71*cos(theta)**70 + 7.02826759855109e+71*cos(theta)**68 - 1.73085336102696e+72*cos(theta)**66 + 3.3813118938095e+72*cos(theta)**64 - 5.38020898020517e+72*cos(theta)**62 + 7.10473127204467e+72*cos(theta)**60 - 7.89414585782741e+72*cos(theta)**58 + 7.45658463027926e+72*cos(theta)**56 - 6.03423033664218e+72*cos(theta)**54 + 4.20808168213205e+72*cos(theta)**52 - 2.53978894424538e+72*cos(theta)**50 + 1.33072774024833e+72*cos(theta)**48 - 6.06489248888934e+71*cos(theta)**46 + 2.40688793174865e+71*cos(theta)**44 - 8.31902076519627e+70*cos(theta)**42 + 2.50268234760097e+70*cos(theta)**40 - 6.54405709396165e+69*cos(theta)**38 + 1.48402327001775e+69*cos(theta)**36 - 2.90984954905442e+68*cos(theta)**34 + 4.91398433780713e+67*cos(theta)**32 - 7.11215708068964e+66*cos(theta)**30 + 8.76924129846936e+65*cos(theta)**28 - 9.14420196088668e+64*cos(theta)**26 + 7.9931835322436e+63*cos(theta)**24 - 5.79490059075186e+62*cos(theta)**22 + 3.43941941537431e+61*cos(theta)**20 - 1.64482680322456e+60*cos(theta)**18 + 6.21379014551501e+58*cos(theta)**16 - 1.80852490289062e+57*cos(theta)**14 + 3.92594862030167e+55*cos(theta)**12 - 6.08674204697933e+53*cos(theta)**10 + 6.34329300866304e+51*cos(theta)**8 - 4.05970752554435e+49*cos(theta)**6 + 1.37523967667491e+47*cos(theta)**4 - 1.84307305339501e+44*cos(theta)**2 + 4.07579180317341e+40)*cos(21*phi)

#@torch.jit.script
def Yl97_m22(theta, phi):
    return 1.17524099704666e-43*(1.0 - cos(theta)**2)**11*(3.51495509353336e+70*cos(theta)**75 - 5.05388620961402e+71*cos(theta)**73 + 3.47686203111666e+72*cos(theta)**71 - 1.52380990252644e+73*cos(theta)**69 + 4.77922196701474e+73*cos(theta)**67 - 1.14236321827779e+74*cos(theta)**65 + 2.16403961203808e+74*cos(theta)**63 - 3.3357295677272e+74*cos(theta)**61 + 4.2628387632268e+74*cos(theta)**59 - 4.5786045975399e+74*cos(theta)**57 + 4.17568739295639e+74*cos(theta)**55 - 3.25848438178678e+74*cos(theta)**53 + 2.18820247470866e+74*cos(theta)**51 - 1.26989447212269e+74*cos(theta)**49 + 6.38749315319197e+73*cos(theta)**47 - 2.7898505448891e+73*cos(theta)**45 + 1.0590306899694e+73*cos(theta)**43 - 3.49398872138243e+72*cos(theta)**41 + 1.00107293904039e+72*cos(theta)**39 - 2.48674169570543e+71*cos(theta)**37 + 5.34248377206392e+70*cos(theta)**35 - 9.89348846678503e+69*cos(theta)**33 + 1.57247498809828e+69*cos(theta)**31 - 2.13364712420689e+68*cos(theta)**29 + 2.45538756357142e+67*cos(theta)**27 - 2.37749250983054e+66*cos(theta)**25 + 1.91836404773846e+65*cos(theta)**23 - 1.27487812996541e+64*cos(theta)**21 + 6.87883883074861e+62*cos(theta)**19 - 2.96068824580421e+61*cos(theta)**17 + 9.94206423282401e+59*cos(theta)**15 - 2.53193486404686e+58*cos(theta)**13 + 4.71113834436201e+56*cos(theta)**11 - 6.08674204697933e+54*cos(theta)**9 + 5.07463440693043e+52*cos(theta)**7 - 2.43582451532661e+50*cos(theta)**5 + 5.50095870669965e+47*cos(theta)**3 - 3.68614610679003e+44*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl97_m23(theta, phi):
    return 1.23881278342489e-45*(1.0 - cos(theta)**2)**11.5*(2.63621632015002e+72*cos(theta)**74 - 3.68933693301824e+73*cos(theta)**72 + 2.46857204209283e+74*cos(theta)**70 - 1.05142883274324e+75*cos(theta)**68 + 3.20207871789987e+75*cos(theta)**66 - 7.42536091880565e+75*cos(theta)**64 + 1.36334495558399e+76*cos(theta)**62 - 2.03479503631359e+76*cos(theta)**60 + 2.51507487030381e+76*cos(theta)**58 - 2.60980462059774e+76*cos(theta)**56 + 2.29662806612601e+76*cos(theta)**54 - 1.72699672234699e+76*cos(theta)**52 + 1.11598326210142e+76*cos(theta)**50 - 6.22248291340117e+75*cos(theta)**48 + 3.00212178200022e+75*cos(theta)**46 - 1.25543274520009e+75*cos(theta)**44 + 4.55383196686844e+74*cos(theta)**42 - 1.4325353757668e+74*cos(theta)**40 + 3.90418446225752e+73*cos(theta)**38 - 9.20094427411008e+72*cos(theta)**36 + 1.86986932022237e+72*cos(theta)**34 - 3.26485119403906e+71*cos(theta)**32 + 4.87467246310468e+70*cos(theta)**30 - 6.18757666019998e+69*cos(theta)**28 + 6.62954642164284e+68*cos(theta)**26 - 5.94373127457634e+67*cos(theta)**24 + 4.41223730979847e+66*cos(theta)**22 - 2.67724407292736e+65*cos(theta)**20 + 1.30697937784224e+64*cos(theta)**18 - 5.03317001786716e+62*cos(theta)**16 + 1.4913096349236e+61*cos(theta)**14 - 3.29151532326092e+59*cos(theta)**12 + 5.18225217879821e+57*cos(theta)**10 - 5.4780678422814e+55*cos(theta)**8 + 3.5522440848513e+53*cos(theta)**6 - 1.2179122576633e+51*cos(theta)**4 + 1.6502876120099e+48*cos(theta)**2 - 3.68614610679003e+44)*cos(23*phi)

#@torch.jit.script
def Yl97_m24(theta, phi):
    return 1.30917328108001e-47*(1.0 - cos(theta)**2)**12*(1.95080007691101e+74*cos(theta)**73 - 2.65632259177313e+75*cos(theta)**71 + 1.72800042946498e+76*cos(theta)**69 - 7.14971606265405e+76*cos(theta)**67 + 2.11337195381392e+77*cos(theta)**65 - 4.75223098803562e+77*cos(theta)**63 + 8.45273872462073e+77*cos(theta)**61 - 1.22087702178816e+78*cos(theta)**59 + 1.45874342477621e+78*cos(theta)**57 - 1.46149058753474e+78*cos(theta)**55 + 1.24017915570805e+78*cos(theta)**53 - 8.98038295620436e+77*cos(theta)**51 + 5.57991631050709e+77*cos(theta)**49 - 2.98679179843256e+77*cos(theta)**47 + 1.3809760197201e+77*cos(theta)**45 - 5.52390407888041e+76*cos(theta)**43 + 1.91260942608474e+76*cos(theta)**41 - 5.73014150306719e+75*cos(theta)**39 + 1.48359009565786e+75*cos(theta)**37 - 3.31233993867963e+74*cos(theta)**35 + 6.35755568875606e+73*cos(theta)**33 - 1.0447523820925e+73*cos(theta)**31 + 1.4624017389314e+72*cos(theta)**29 - 1.732521464856e+71*cos(theta)**27 + 1.72368206962714e+70*cos(theta)**25 - 1.42649550589832e+69*cos(theta)**23 + 9.70692208155663e+67*cos(theta)**21 - 5.35448814585472e+66*cos(theta)**19 + 2.35256288011602e+65*cos(theta)**17 - 8.05307202858745e+63*cos(theta)**15 + 2.08783348889304e+62*cos(theta)**13 - 3.9498183879131e+60*cos(theta)**11 + 5.18225217879821e+58*cos(theta)**9 - 4.38245427382512e+56*cos(theta)**7 + 2.13134645091078e+54*cos(theta)**5 - 4.87164903065321e+51*cos(theta)**3 + 3.30057522401979e+48*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl97_m25(theta, phi):
    return 1.38725336779573e-49*(1.0 - cos(theta)**2)**12.5*(1.42408405614504e+76*cos(theta)**72 - 1.88598904015892e+77*cos(theta)**70 + 1.19232029633084e+78*cos(theta)**68 - 4.79030976197821e+78*cos(theta)**66 + 1.37369176997905e+79*cos(theta)**64 - 2.99390552246244e+79*cos(theta)**62 + 5.15617062201865e+79*cos(theta)**60 - 7.20317442855012e+79*cos(theta)**58 + 8.31483752122441e+79*cos(theta)**56 - 8.03819823144105e+79*cos(theta)**54 + 6.57294952525265e+79*cos(theta)**52 - 4.57999530766422e+79*cos(theta)**50 + 2.73415899214848e+79*cos(theta)**48 - 1.4037921452633e+79*cos(theta)**46 + 6.21439208874046e+78*cos(theta)**44 - 2.37527875391858e+78*cos(theta)**42 + 7.84169864694745e+77*cos(theta)**40 - 2.2347551861962e+77*cos(theta)**38 + 5.48928335393407e+76*cos(theta)**36 - 1.15931897853787e+76*cos(theta)**34 + 2.0979933772895e+75*cos(theta)**32 - 3.23873238448675e+74*cos(theta)**30 + 4.24096504290107e+73*cos(theta)**28 - 4.67780795511119e+72*cos(theta)**26 + 4.30920517406785e+71*cos(theta)**24 - 3.28093966356614e+70*cos(theta)**22 + 2.03845363712689e+69*cos(theta)**20 - 1.0173527477124e+68*cos(theta)**18 + 3.99935689619724e+66*cos(theta)**16 - 1.20796080428812e+65*cos(theta)**14 + 2.71418353556096e+63*cos(theta)**12 - 4.34480022670442e+61*cos(theta)**10 + 4.66402696091838e+59*cos(theta)**8 - 3.06771799167758e+57*cos(theta)**6 + 1.06567322545539e+55*cos(theta)**4 - 1.46149470919596e+52*cos(theta)**2 + 3.30057522401979e+48)*cos(25*phi)

#@torch.jit.script
def Yl97_m26(theta, phi):
    return 1.47413407070875e-51*(1.0 - cos(theta)**2)**13*(1.02534052042443e+78*cos(theta)**71 - 1.32019232811125e+79*cos(theta)**69 + 8.10777801504969e+79*cos(theta)**67 - 3.16160444290562e+80*cos(theta)**65 + 8.7916273278659e+80*cos(theta)**63 - 1.85622142392671e+81*cos(theta)**61 + 3.09370237321119e+81*cos(theta)**59 - 4.17784116855907e+81*cos(theta)**57 + 4.65630901188567e+81*cos(theta)**55 - 4.34062704497817e+81*cos(theta)**53 + 3.41793375313138e+81*cos(theta)**51 - 2.28999765383211e+81*cos(theta)**49 + 1.31239631623127e+81*cos(theta)**47 - 6.4574438682112e+80*cos(theta)**45 + 2.7343325190458e+80*cos(theta)**43 - 9.97617076645802e+79*cos(theta)**41 + 3.13667945877898e+79*cos(theta)**39 - 8.49206970754558e+78*cos(theta)**37 + 1.97614200741627e+78*cos(theta)**35 - 3.94168452702876e+77*cos(theta)**33 + 6.7135788073264e+76*cos(theta)**31 - 9.71619715346024e+75*cos(theta)**29 + 1.1874702120123e+75*cos(theta)**27 - 1.21623006832891e+74*cos(theta)**25 + 1.03420924177628e+73*cos(theta)**23 - 7.21806725984551e+71*cos(theta)**21 + 4.07690727425378e+70*cos(theta)**19 - 1.83123494588231e+69*cos(theta)**17 + 6.39897103391559e+67*cos(theta)**15 - 1.69114512600336e+66*cos(theta)**13 + 3.25702024267315e+64*cos(theta)**11 - 4.34480022670442e+62*cos(theta)**9 + 3.73122156873471e+60*cos(theta)**7 - 1.84063079500655e+58*cos(theta)**5 + 4.26269290182156e+55*cos(theta)**3 - 2.92298941839193e+52*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl97_m27(theta, phi):
    return 1.57107517742233e-53*(1.0 - cos(theta)**2)**13.5*(7.27991769501344e+79*cos(theta)**70 - 9.10932706396759e+80*cos(theta)**68 + 5.43221127008329e+81*cos(theta)**66 - 2.05504288788865e+82*cos(theta)**64 + 5.53872521655551e+82*cos(theta)**62 - 1.13229506859529e+83*cos(theta)**60 + 1.8252844001946e+83*cos(theta)**58 - 2.38136946607867e+83*cos(theta)**56 + 2.56096995653712e+83*cos(theta)**54 - 2.30053233383843e+83*cos(theta)**52 + 1.743146214097e+83*cos(theta)**50 - 1.12209885037773e+83*cos(theta)**48 + 6.16826268628696e+82*cos(theta)**46 - 2.90584974069504e+82*cos(theta)**44 + 1.1757629831897e+82*cos(theta)**42 - 4.09023001424779e+81*cos(theta)**40 + 1.2233049889238e+81*cos(theta)**38 - 3.14206579179186e+80*cos(theta)**36 + 6.91649702595693e+79*cos(theta)**34 - 1.30075589391949e+79*cos(theta)**32 + 2.08120943027118e+78*cos(theta)**30 - 2.81769717450347e+77*cos(theta)**28 + 3.20616957243321e+76*cos(theta)**26 - 3.04057517082227e+75*cos(theta)**24 + 2.37868125608545e+74*cos(theta)**22 - 1.51579412456756e+73*cos(theta)**20 + 7.74612382108219e+71*cos(theta)**18 - 3.11309940799993e+70*cos(theta)**16 + 9.59845655087338e+68*cos(theta)**14 - 2.19848866380437e+67*cos(theta)**12 + 3.58272226694046e+65*cos(theta)**10 - 3.91032020403397e+63*cos(theta)**8 + 2.6118550981143e+61*cos(theta)**6 - 9.20315397503275e+58*cos(theta)**4 + 1.27880787054647e+56*cos(theta)**2 - 2.92298941839193e+52)*cos(27*phi)

#@torch.jit.script
def Yl97_m28(theta, phi):
    return 1.6795500122227e-55*(1.0 - cos(theta)**2)**14*(5.09594238650941e+81*cos(theta)**69 - 6.19434240349796e+82*cos(theta)**67 + 3.58525943825497e+83*cos(theta)**65 - 1.31522744824874e+84*cos(theta)**63 + 3.43400963426442e+84*cos(theta)**61 - 6.79377041157177e+84*cos(theta)**59 + 1.05866495211287e+85*cos(theta)**57 - 1.33356690100406e+85*cos(theta)**55 + 1.38292377653004e+85*cos(theta)**53 - 1.19627681359598e+85*cos(theta)**51 + 8.71573107048501e+84*cos(theta)**49 - 5.38607448181312e+84*cos(theta)**47 + 2.837400835692e+84*cos(theta)**45 - 1.27857388590582e+84*cos(theta)**43 + 4.93820452939672e+83*cos(theta)**41 - 1.63609200569912e+83*cos(theta)**39 + 4.64855895791045e+82*cos(theta)**37 - 1.13114368504507e+82*cos(theta)**35 + 2.35160898882536e+81*cos(theta)**33 - 4.16241886054237e+80*cos(theta)**31 + 6.24362829081355e+79*cos(theta)**29 - 7.88955208860972e+78*cos(theta)**27 + 8.33604088832634e+77*cos(theta)**25 - 7.29738040997345e+76*cos(theta)**23 + 5.23309876338799e+75*cos(theta)**21 - 3.03158824913511e+74*cos(theta)**19 + 1.39430228779479e+73*cos(theta)**17 - 4.98095905279989e+71*cos(theta)**15 + 1.34378391712227e+70*cos(theta)**13 - 2.63818639656525e+68*cos(theta)**11 + 3.58272226694046e+66*cos(theta)**9 - 3.12825616322718e+64*cos(theta)**7 + 1.56711305886858e+62*cos(theta)**5 - 3.6812615900131e+59*cos(theta)**3 + 2.55761574109294e+56*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl97_m29(theta, phi):
    return 1.80128786186537e-57*(1.0 - cos(theta)**2)**14.5*(3.51620024669149e+83*cos(theta)**68 - 4.15020941034364e+84*cos(theta)**66 + 2.33041863486573e+85*cos(theta)**64 - 8.28593292396705e+85*cos(theta)**62 + 2.0947458769013e+86*cos(theta)**60 - 4.00832454282734e+86*cos(theta)**58 + 6.03439022704335e+86*cos(theta)**56 - 7.3346179555223e+86*cos(theta)**54 + 7.32949601560923e+86*cos(theta)**52 - 6.10101174933951e+86*cos(theta)**50 + 4.27070822453766e+86*cos(theta)**48 - 2.53145500645217e+86*cos(theta)**46 + 1.2768303760614e+86*cos(theta)**44 - 5.49786770939502e+85*cos(theta)**42 + 2.02466385705266e+85*cos(theta)**40 - 6.38075882222655e+84*cos(theta)**38 + 1.71996681442687e+84*cos(theta)**36 - 3.95900289765775e+83*cos(theta)**34 + 7.76030966312368e+82*cos(theta)**32 - 1.29034984676813e+82*cos(theta)**30 + 1.81065220433593e+81*cos(theta)**28 - 2.13017906392462e+80*cos(theta)**26 + 2.08401022208159e+79*cos(theta)**24 - 1.67839749429389e+78*cos(theta)**22 + 1.09895074031148e+77*cos(theta)**20 - 5.76001767335671e+75*cos(theta)**18 + 2.37031388925115e+74*cos(theta)**16 - 7.47143857919984e+72*cos(theta)**14 + 1.74691909225896e+71*cos(theta)**12 - 2.90200503622177e+69*cos(theta)**10 + 3.22445004024641e+67*cos(theta)**8 - 2.18977931425903e+65*cos(theta)**6 + 7.83556529434289e+62*cos(theta)**4 - 1.10437847700393e+60*cos(theta)**2 + 2.55761574109294e+56)*cos(29*phi)

#@torch.jit.script
def Yl97_m30(theta, phi):
    return 1.93832593037077e-59*(1.0 - cos(theta)**2)**15*(2.39101616775021e+85*cos(theta)**67 - 2.7391382108268e+86*cos(theta)**65 + 1.49146792631407e+87*cos(theta)**63 - 5.13727841285957e+87*cos(theta)**61 + 1.25684752614078e+88*cos(theta)**59 - 2.32482823483986e+88*cos(theta)**57 + 3.37925852714428e+88*cos(theta)**55 - 3.96069369598204e+88*cos(theta)**53 + 3.8113379281168e+88*cos(theta)**51 - 3.05050587466975e+88*cos(theta)**49 + 2.04993994777808e+88*cos(theta)**47 - 1.164469302968e+88*cos(theta)**45 + 5.61805365467016e+87*cos(theta)**43 - 2.30910443794591e+87*cos(theta)**41 + 8.09865542821062e+86*cos(theta)**39 - 2.42468835244609e+86*cos(theta)**37 + 6.19188053193672e+85*cos(theta)**35 - 1.34606098520363e+85*cos(theta)**33 + 2.48329909219958e+84*cos(theta)**31 - 3.8710495403044e+83*cos(theta)**29 + 5.0698261721406e+82*cos(theta)**27 - 5.53846556620402e+81*cos(theta)**25 + 5.0016245329958e+80*cos(theta)**23 - 3.69247448744657e+79*cos(theta)**21 + 2.19790148062296e+78*cos(theta)**19 - 1.03680318120421e+77*cos(theta)**17 + 3.79250222280184e+75*cos(theta)**15 - 1.04600140108798e+74*cos(theta)**13 + 2.09630291071075e+72*cos(theta)**11 - 2.90200503622177e+70*cos(theta)**9 + 2.57956003219713e+68*cos(theta)**7 - 1.31386758855542e+66*cos(theta)**5 + 3.13422611773715e+63*cos(theta)**3 - 2.20875695400786e+60*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl97_m31(theta, phi):
    return 2.09307321216616e-61*(1.0 - cos(theta)**2)**15.5*(1.60198083239264e+87*cos(theta)**66 - 1.78043983703742e+88*cos(theta)**64 + 9.39624793577863e+88*cos(theta)**62 - 3.13373983184434e+89*cos(theta)**60 + 7.41540040423059e+89*cos(theta)**58 - 1.32515209385872e+90*cos(theta)**56 + 1.85859218992935e+90*cos(theta)**54 - 2.09916765887048e+90*cos(theta)**52 + 1.94378234333957e+90*cos(theta)**50 - 1.49474787858818e+90*cos(theta)**48 + 9.63471775455695e+89*cos(theta)**46 - 5.24011186335599e+89*cos(theta)**44 + 2.41576307150817e+89*cos(theta)**42 - 9.46732819557822e+88*cos(theta)**40 + 3.15847561700214e+88*cos(theta)**38 - 8.97134690405053e+87*cos(theta)**36 + 2.16715818617785e+87*cos(theta)**34 - 4.44200125117199e+86*cos(theta)**32 + 7.69822718581869e+85*cos(theta)**30 - 1.12260436668828e+85*cos(theta)**28 + 1.36885306647796e+84*cos(theta)**26 - 1.38461639155101e+83*cos(theta)**24 + 1.15037364258904e+82*cos(theta)**22 - 7.75419642363779e+80*cos(theta)**20 + 4.17601281318362e+79*cos(theta)**18 - 1.76256540804715e+78*cos(theta)**16 + 5.68875333420276e+76*cos(theta)**14 - 1.35980182141437e+75*cos(theta)**12 + 2.30593320178182e+73*cos(theta)**10 - 2.6118045325996e+71*cos(theta)**8 + 1.80569202253799e+69*cos(theta)**6 - 6.56933794277708e+66*cos(theta)**4 + 9.40267835321146e+63*cos(theta)**2 - 2.20875695400786e+60)*cos(31*phi)

#@torch.jit.script
def Yl97_m32(theta, phi):
    return 2.26838933406071e-63*(1.0 - cos(theta)**2)**16*(1.05730734937914e+89*cos(theta)**65 - 1.13948149570395e+90*cos(theta)**63 + 5.82567372018275e+90*cos(theta)**61 - 1.8802438991066e+91*cos(theta)**59 + 4.30093223445374e+91*cos(theta)**57 - 7.42085172560883e+91*cos(theta)**55 + 1.00363978256185e+92*cos(theta)**53 - 1.09156718261265e+92*cos(theta)**51 + 9.71891171669784e+91*cos(theta)**49 - 7.17478981722326e+91*cos(theta)**47 + 4.4319701670962e+91*cos(theta)**45 - 2.30564921987664e+91*cos(theta)**43 + 1.01462049003343e+91*cos(theta)**41 - 3.78693127823129e+90*cos(theta)**39 + 1.20022073446081e+90*cos(theta)**37 - 3.22968488545819e+89*cos(theta)**35 + 7.36833783300469e+88*cos(theta)**33 - 1.42144040037504e+88*cos(theta)**31 + 2.30946815574561e+87*cos(theta)**29 - 3.14329222672717e+86*cos(theta)**27 + 3.5590179728427e+85*cos(theta)**25 - 3.32307933972241e+84*cos(theta)**23 + 2.53082201369588e+83*cos(theta)**21 - 1.55083928472756e+82*cos(theta)**19 + 7.51682306373051e+80*cos(theta)**17 - 2.82010465287545e+79*cos(theta)**15 + 7.96425466788386e+77*cos(theta)**13 - 1.63176218569725e+76*cos(theta)**11 + 2.30593320178182e+74*cos(theta)**9 - 2.08944362607968e+72*cos(theta)**7 + 1.0834152135228e+70*cos(theta)**5 - 2.62773517711083e+67*cos(theta)**3 + 1.88053567064229e+64*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl97_m33(theta, phi):
    return 2.4676822776701e-65*(1.0 - cos(theta)**2)**16.5*(6.87249777096444e+90*cos(theta)**64 - 7.17873342293488e+91*cos(theta)**62 + 3.55366096931148e+92*cos(theta)**60 - 1.1093439004729e+93*cos(theta)**58 + 2.45153137363863e+93*cos(theta)**56 - 4.08146844908486e+93*cos(theta)**54 + 5.31929084757781e+93*cos(theta)**52 - 5.56699263132452e+93*cos(theta)**50 + 4.76226674118194e+93*cos(theta)**48 - 3.37215121409493e+93*cos(theta)**46 + 1.99438657519329e+93*cos(theta)**44 - 9.91429164546953e+92*cos(theta)**42 + 4.15994400913707e+92*cos(theta)**40 - 1.4769031985102e+92*cos(theta)**38 + 4.44081671750501e+91*cos(theta)**36 - 1.13038970991037e+91*cos(theta)**34 + 2.43155148489155e+90*cos(theta)**32 - 4.40646524116262e+89*cos(theta)**30 + 6.69745765166226e+88*cos(theta)**28 - 8.48688901216337e+87*cos(theta)**26 + 8.89754493210676e+86*cos(theta)**24 - 7.64308248136155e+85*cos(theta)**22 + 5.31472622876134e+84*cos(theta)**20 - 2.94659464098236e+83*cos(theta)**18 + 1.27785992083419e+82*cos(theta)**16 - 4.23015697931317e+80*cos(theta)**14 + 1.0353531068249e+79*cos(theta)**12 - 1.79493840426697e+77*cos(theta)**10 + 2.07533988160364e+75*cos(theta)**8 - 1.46261053825577e+73*cos(theta)**6 + 5.41707606761398e+70*cos(theta)**4 - 7.88320553133249e+67*cos(theta)**2 + 1.88053567064229e+64)*cos(33*phi)

#@torch.jit.script
def Yl97_m34(theta, phi):
    return 2.69503002068864e-67*(1.0 - cos(theta)**2)**17*(4.39839857341724e+92*cos(theta)**63 - 4.45081472221962e+93*cos(theta)**61 + 2.13219658158689e+94*cos(theta)**59 - 6.43419462274279e+94*cos(theta)**57 + 1.37285756923763e+95*cos(theta)**55 - 2.20399296250582e+95*cos(theta)**53 + 2.76603124074046e+95*cos(theta)**51 - 2.78349631566226e+95*cos(theta)**49 + 2.28588803576733e+95*cos(theta)**47 - 1.55118955848367e+95*cos(theta)**45 + 8.77530093085047e+94*cos(theta)**43 - 4.1640024910972e+94*cos(theta)**41 + 1.66397760365483e+94*cos(theta)**39 - 5.61223215433877e+93*cos(theta)**37 + 1.5986940183018e+93*cos(theta)**35 - 3.84332501369525e+92*cos(theta)**33 + 7.78096475165296e+91*cos(theta)**31 - 1.32193957234879e+91*cos(theta)**29 + 1.87528814246543e+90*cos(theta)**27 - 2.20659114316248e+89*cos(theta)**25 + 2.13541078370562e+88*cos(theta)**23 - 1.68147814589954e+87*cos(theta)**21 + 1.06294524575227e+86*cos(theta)**19 - 5.30387035376825e+84*cos(theta)**17 + 2.0445758733347e+83*cos(theta)**15 - 5.92221977103844e+81*cos(theta)**13 + 1.24242372818988e+80*cos(theta)**11 - 1.79493840426697e+78*cos(theta)**9 + 1.66027190528291e+76*cos(theta)**7 - 8.77566322953464e+73*cos(theta)**5 + 2.16683042704559e+71*cos(theta)**3 - 1.5766411062665e+68*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl97_m35(theta, phi):
    return 2.95533261679926e-69*(1.0 - cos(theta)**2)**17.5*(2.77099110125286e+94*cos(theta)**62 - 2.71499698055397e+95*cos(theta)**60 + 1.25799598313626e+96*cos(theta)**58 - 3.66749093496339e+96*cos(theta)**56 + 7.55071663080699e+96*cos(theta)**54 - 1.16811627012809e+97*cos(theta)**52 + 1.41067593277763e+97*cos(theta)**50 - 1.36391319467451e+97*cos(theta)**48 + 1.07436737681065e+97*cos(theta)**46 - 6.98035301317651e+96*cos(theta)**44 + 3.7733794002657e+96*cos(theta)**42 - 1.70724102134985e+96*cos(theta)**40 + 6.48951265425383e+95*cos(theta)**38 - 2.07652589710534e+95*cos(theta)**36 + 5.59542906405632e+94*cos(theta)**34 - 1.26829725451943e+94*cos(theta)**32 + 2.41209907301242e+93*cos(theta)**30 - 3.83362475981148e+92*cos(theta)**28 + 5.06327798465667e+91*cos(theta)**26 - 5.51647785790619e+90*cos(theta)**24 + 4.91144480252293e+89*cos(theta)**22 - 3.53110410638904e+88*cos(theta)**20 + 2.01959596692931e+87*cos(theta)**18 - 9.01657960140602e+85*cos(theta)**16 + 3.06686381000205e+84*cos(theta)**14 - 7.69888570234997e+82*cos(theta)**12 + 1.36666610100887e+81*cos(theta)**10 - 1.61544456384027e+79*cos(theta)**8 + 1.16219033369804e+77*cos(theta)**6 - 4.38783161476732e+74*cos(theta)**4 + 6.50049128113677e+71*cos(theta)**2 - 1.5766411062665e+68)*cos(35*phi)

#@torch.jit.script
def Yl97_m36(theta, phi):
    return 3.2545031911186e-71*(1.0 - cos(theta)**2)**18*(1.71801448277677e+96*cos(theta)**61 - 1.62899818833238e+97*cos(theta)**59 + 7.29637670219033e+97*cos(theta)**57 - 2.0537949235795e+98*cos(theta)**55 + 4.07738698063577e+98*cos(theta)**53 - 6.07420460466605e+98*cos(theta)**51 + 7.05337966388817e+98*cos(theta)**49 - 6.54678333443764e+98*cos(theta)**47 + 4.94208993332897e+98*cos(theta)**45 - 3.07135532579767e+98*cos(theta)**43 + 1.5848193481116e+98*cos(theta)**41 - 6.82896408539941e+97*cos(theta)**39 + 2.46601480861645e+97*cos(theta)**37 - 7.47549322957924e+96*cos(theta)**35 + 1.90244588177915e+96*cos(theta)**33 - 4.05855121446218e+95*cos(theta)**31 + 7.23629721903725e+94*cos(theta)**29 - 1.07341493274721e+94*cos(theta)**27 + 1.31645227601073e+93*cos(theta)**25 - 1.32395468589749e+92*cos(theta)**23 + 1.08051785655504e+91*cos(theta)**21 - 7.06220821277807e+89*cos(theta)**19 + 3.63527274047276e+88*cos(theta)**17 - 1.44265273622496e+87*cos(theta)**15 + 4.29360933400287e+85*cos(theta)**13 - 9.23866284281997e+83*cos(theta)**11 + 1.36666610100887e+82*cos(theta)**9 - 1.29235565107222e+80*cos(theta)**7 + 6.97314200218823e+77*cos(theta)**5 - 1.75513264590693e+75*cos(theta)**3 + 1.30009825622735e+72*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl97_m37(theta, phi):
    return 3.59970892663526e-73*(1.0 - cos(theta)**2)**18.5*(1.04798883449383e+98*cos(theta)**60 - 9.61108931116105e+98*cos(theta)**58 + 4.15893472024849e+99*cos(theta)**56 - 1.12958720796872e+100*cos(theta)**54 + 2.16101509973696e+100*cos(theta)**52 - 3.09784434837968e+100*cos(theta)**50 + 3.4561560353052e+100*cos(theta)**48 - 3.07698816718569e+100*cos(theta)**46 + 2.22394046999804e+100*cos(theta)**44 - 1.320682790093e+100*cos(theta)**42 + 6.49775932725754e+99*cos(theta)**40 - 2.66329599330577e+99*cos(theta)**38 + 9.12425479188088e+98*cos(theta)**36 - 2.61642263035273e+98*cos(theta)**34 + 6.27807140987119e+97*cos(theta)**32 - 1.25815087648328e+97*cos(theta)**30 + 2.0985261935208e+96*cos(theta)**28 - 2.89822031841748e+95*cos(theta)**26 + 3.29113069002683e+94*cos(theta)**24 - 3.04509577756422e+93*cos(theta)**22 + 2.26908749876559e+92*cos(theta)**20 - 1.34181956042783e+91*cos(theta)**18 + 6.17996365880369e+89*cos(theta)**16 - 2.16397910433745e+88*cos(theta)**14 + 5.58169213420373e+86*cos(theta)**12 - 1.0162529127102e+85*cos(theta)**10 + 1.22999949090798e+83*cos(theta)**8 - 9.04648955750553e+80*cos(theta)**6 + 3.48657100109411e+78*cos(theta)**4 - 5.26539793772079e+75*cos(theta)**2 + 1.30009825622735e+72)*cos(37*phi)

#@torch.jit.script
def Yl97_m38(theta, phi):
    return 3.99967658515029e-75*(1.0 - cos(theta)**2)**19*(6.28793300696299e+99*cos(theta)**59 - 5.57443180047341e+100*cos(theta)**57 + 2.32900344333915e+101*cos(theta)**55 - 6.09977092303112e+101*cos(theta)**53 + 1.12372785186322e+102*cos(theta)**51 - 1.54892217418984e+102*cos(theta)**49 + 1.6589548969465e+102*cos(theta)**47 - 1.41541455690542e+102*cos(theta)**45 + 9.78533806799136e+101*cos(theta)**43 - 5.54686771839058e+101*cos(theta)**41 + 2.59910373090302e+101*cos(theta)**39 - 1.01205247745619e+101*cos(theta)**37 + 3.28473172507712e+100*cos(theta)**35 - 8.89583694319929e+99*cos(theta)**33 + 2.00898285115878e+99*cos(theta)**31 - 3.77445262944983e+98*cos(theta)**29 + 5.87587334185825e+97*cos(theta)**27 - 7.53537282788544e+96*cos(theta)**25 + 7.8987136560644e+95*cos(theta)**23 - 6.69921071064128e+94*cos(theta)**21 + 4.53817499753119e+93*cos(theta)**19 - 2.4152752087701e+92*cos(theta)**17 + 9.8879418540859e+90*cos(theta)**15 - 3.02957074607242e+89*cos(theta)**13 + 6.69803056104448e+87*cos(theta)**11 - 1.0162529127102e+86*cos(theta)**9 + 9.83999592726387e+83*cos(theta)**7 - 5.42789373450332e+81*cos(theta)**5 + 1.39462840043765e+79*cos(theta)**3 - 1.05307958754416e+76*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl97_m39(theta, phi):
    return 4.4650817592625e-77*(1.0 - cos(theta)**2)**19.5*(3.70988047410817e+101*cos(theta)**58 - 3.17742612626984e+102*cos(theta)**56 + 1.28095189383653e+103*cos(theta)**54 - 3.23287858920649e+103*cos(theta)**52 + 5.73101204450242e+103*cos(theta)**50 - 7.58971865353023e+103*cos(theta)**48 + 7.79708801564854e+103*cos(theta)**46 - 6.36936550607438e+103*cos(theta)**44 + 4.20769536923629e+103*cos(theta)**42 - 2.27421576454014e+103*cos(theta)**40 + 1.01365045505218e+103*cos(theta)**38 - 3.74459416658791e+102*cos(theta)**36 + 1.14965610377699e+102*cos(theta)**34 - 2.93562619125577e+101*cos(theta)**32 + 6.22784683859222e+100*cos(theta)**30 - 1.09459126254045e+100*cos(theta)**28 + 1.58648580230173e+99*cos(theta)**26 - 1.88384320697136e+98*cos(theta)**24 + 1.81670414089481e+97*cos(theta)**22 - 1.40683424923467e+96*cos(theta)**20 + 8.62253249530926e+94*cos(theta)**18 - 4.10596785490917e+93*cos(theta)**16 + 1.48319127811289e+92*cos(theta)**14 - 3.93844196989415e+90*cos(theta)**12 + 7.36783361714892e+88*cos(theta)**10 - 9.14627621439177e+86*cos(theta)**8 + 6.88799714908471e+84*cos(theta)**6 - 2.71394686725166e+82*cos(theta)**4 + 4.18388520131294e+79*cos(theta)**2 - 1.05307958754416e+76)*cos(39*phi)

#@torch.jit.script
def Yl97_m40(theta, phi):
    return 5.00904732891804e-79*(1.0 - cos(theta)**2)**20*(2.15173067498274e+103*cos(theta)**57 - 1.77935863071111e+104*cos(theta)**55 + 6.91714022671728e+104*cos(theta)**53 - 1.68109686638738e+105*cos(theta)**51 + 2.86550602225121e+105*cos(theta)**49 - 3.64306495369451e+105*cos(theta)**47 + 3.58666048719833e+105*cos(theta)**45 - 2.80252082267273e+105*cos(theta)**43 + 1.76723205507924e+105*cos(theta)**41 - 9.09686305816056e+104*cos(theta)**39 + 3.85187172919827e+104*cos(theta)**37 - 1.34805389997165e+104*cos(theta)**35 + 3.90883075284177e+103*cos(theta)**33 - 9.39400381201845e+102*cos(theta)**31 + 1.86835405157767e+102*cos(theta)**29 - 3.06485553511326e+101*cos(theta)**27 + 4.12486308598449e+100*cos(theta)**25 - 4.52122369673126e+99*cos(theta)**23 + 3.99674910996859e+98*cos(theta)**21 - 2.81366849846934e+97*cos(theta)**19 + 1.55205584915567e+96*cos(theta)**17 - 6.56954856785467e+94*cos(theta)**15 + 2.07646778935804e+93*cos(theta)**13 - 4.72613036387298e+91*cos(theta)**11 + 7.36783361714892e+89*cos(theta)**9 - 7.31702097151341e+87*cos(theta)**7 + 4.13279828945082e+85*cos(theta)**5 - 1.08557874690066e+83*cos(theta)**3 + 8.36777040262587e+79*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl97_m41(theta, phi):
    return 5.64778511128798e-81*(1.0 - cos(theta)**2)**20.5*(1.22648648474016e+105*cos(theta)**56 - 9.78647246891112e+105*cos(theta)**54 + 3.66608432016016e+106*cos(theta)**52 - 8.57359401857561e+106*cos(theta)**50 + 1.40409795090309e+107*cos(theta)**48 - 1.71224052823642e+107*cos(theta)**46 + 1.61399721923925e+107*cos(theta)**44 - 1.20508395374927e+107*cos(theta)**42 + 7.24565142582488e+106*cos(theta)**40 - 3.54777659268262e+106*cos(theta)**38 + 1.42519253980336e+106*cos(theta)**36 - 4.71818864990077e+105*cos(theta)**34 + 1.28991414843778e+105*cos(theta)**32 - 2.91214118172572e+104*cos(theta)**30 + 5.41822674957523e+103*cos(theta)**28 - 8.27510994480581e+102*cos(theta)**26 + 1.03121577149612e+102*cos(theta)**24 - 1.03988145024819e+101*cos(theta)**22 + 8.39317313093403e+99*cos(theta)**20 - 5.34597014709174e+98*cos(theta)**18 + 2.63849494356463e+97*cos(theta)**16 - 9.85432285178201e+95*cos(theta)**14 + 2.69940812616545e+94*cos(theta)**12 - 5.19874340026028e+92*cos(theta)**10 + 6.63105025543403e+90*cos(theta)**8 - 5.12191468005939e+88*cos(theta)**6 + 2.06639914472541e+86*cos(theta)**4 - 3.25673624070199e+83*cos(theta)**2 + 8.36777040262587e+79)*cos(41*phi)

#@torch.jit.script
def Yl97_m42(theta, phi):
    return 6.40142631115686e-83*(1.0 - cos(theta)**2)**21*(6.8683243145449e+106*cos(theta)**55 - 5.28469513321201e+107*cos(theta)**53 + 1.90636384648328e+108*cos(theta)**51 - 4.28679700928781e+108*cos(theta)**49 + 6.73967016433484e+108*cos(theta)**47 - 7.87630642988753e+108*cos(theta)**45 + 7.10158776465269e+108*cos(theta)**43 - 5.06135260574694e+108*cos(theta)**41 + 2.89826057032995e+108*cos(theta)**39 - 1.34815510521939e+108*cos(theta)**37 + 5.1306931432921e+107*cos(theta)**35 - 1.60418414096626e+107*cos(theta)**33 + 4.12772527500091e+106*cos(theta)**31 - 8.73642354517716e+105*cos(theta)**29 + 1.51710348988106e+105*cos(theta)**27 - 2.15152858564951e+104*cos(theta)**25 + 2.47491785159069e+103*cos(theta)**23 - 2.28773919054602e+102*cos(theta)**21 + 1.67863462618681e+101*cos(theta)**19 - 9.62274626476513e+99*cos(theta)**17 + 4.22159190970341e+98*cos(theta)**15 - 1.37960519924948e+97*cos(theta)**13 + 3.23928975139854e+95*cos(theta)**11 - 5.19874340026028e+93*cos(theta)**9 + 5.30484020434722e+91*cos(theta)**7 - 3.07314880803563e+89*cos(theta)**5 + 8.26559657890165e+86*cos(theta)**3 - 6.51347248140398e+83*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl97_m43(theta, phi):
    return 7.2951023258333e-85*(1.0 - cos(theta)**2)**21.5*(3.77757837299969e+108*cos(theta)**54 - 2.80088842060236e+109*cos(theta)**52 + 9.72245561706475e+109*cos(theta)**50 - 2.10053053455103e+110*cos(theta)**48 + 3.16764497723737e+110*cos(theta)**46 - 3.54433789344939e+110*cos(theta)**44 + 3.05368273880066e+110*cos(theta)**42 - 2.07515456835625e+110*cos(theta)**40 + 1.13032162242868e+110*cos(theta)**38 - 4.98817388931176e+109*cos(theta)**36 + 1.79574260015223e+109*cos(theta)**34 - 5.29380766518867e+108*cos(theta)**32 + 1.27959483525028e+108*cos(theta)**30 - 2.53356282810138e+107*cos(theta)**28 + 4.09617942267887e+106*cos(theta)**26 - 5.37882146412377e+105*cos(theta)**24 + 5.69231105865859e+104*cos(theta)**22 - 4.80425230014664e+103*cos(theta)**20 + 3.18940578975493e+102*cos(theta)**18 - 1.63586686501007e+101*cos(theta)**16 + 6.33238786455512e+99*cos(theta)**14 - 1.79348675902433e+98*cos(theta)**12 + 3.5632187265384e+96*cos(theta)**10 - 4.67886906023425e+94*cos(theta)**8 + 3.71338814304306e+92*cos(theta)**6 - 1.53657440401782e+90*cos(theta)**4 + 2.47967897367049e+87*cos(theta)**2 - 6.51347248140398e+83)*cos(43*phi)

#@torch.jit.script
def Yl97_m44(theta, phi):
    return 8.36035948055156e-87*(1.0 - cos(theta)**2)**22*(2.03989232141983e+110*cos(theta)**53 - 1.45646197871323e+111*cos(theta)**51 + 4.86122780853237e+111*cos(theta)**49 - 1.00825465658449e+112*cos(theta)**47 + 1.45711668952919e+112*cos(theta)**45 - 1.55950867311773e+112*cos(theta)**43 + 1.28254675029628e+112*cos(theta)**41 - 8.30061827342499e+111*cos(theta)**39 + 4.29522216522899e+111*cos(theta)**37 - 1.79574260015223e+111*cos(theta)**35 + 6.1055248405176e+110*cos(theta)**33 - 1.69401845286037e+110*cos(theta)**31 + 3.83878450575085e+109*cos(theta)**29 - 7.09397591868386e+108*cos(theta)**27 + 1.06500664989651e+108*cos(theta)**25 - 1.29091715138971e+107*cos(theta)**23 + 1.25230843290489e+106*cos(theta)**21 - 9.60850460029328e+104*cos(theta)**19 + 5.74093042155888e+103*cos(theta)**17 - 2.61738698401612e+102*cos(theta)**15 + 8.86534301037717e+100*cos(theta)**13 - 2.15218411082919e+99*cos(theta)**11 + 3.5632187265384e+97*cos(theta)**9 - 3.7430952481874e+95*cos(theta)**7 + 2.22803288582583e+93*cos(theta)**5 - 6.14629761607127e+90*cos(theta)**3 + 4.95935794734099e+87*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl97_m45(theta, phi):
    return 9.63702187389815e-89*(1.0 - cos(theta)**2)**22.5*(1.08114293035251e+112*cos(theta)**52 - 7.42795609143747e+112*cos(theta)**50 + 2.38200162618086e+113*cos(theta)**48 - 4.73879688594711e+113*cos(theta)**46 + 6.55702510288137e+113*cos(theta)**44 - 6.70588729440624e+113*cos(theta)**42 + 5.25844167621473e+113*cos(theta)**40 - 3.23724112663575e+113*cos(theta)**38 + 1.58923220113473e+113*cos(theta)**36 - 6.28509910053282e+112*cos(theta)**34 + 2.01482319737081e+112*cos(theta)**32 - 5.25145720386716e+111*cos(theta)**30 + 1.11324750666775e+111*cos(theta)**28 - 1.91537349804464e+110*cos(theta)**26 + 2.66251662474127e+109*cos(theta)**24 - 2.96910944819632e+108*cos(theta)**22 + 2.62984770910027e+107*cos(theta)**20 - 1.82561587405572e+106*cos(theta)**18 + 9.75958171665009e+104*cos(theta)**16 - 3.92608047602417e+103*cos(theta)**14 + 1.15249459134903e+102*cos(theta)**12 - 2.36740252191211e+100*cos(theta)**10 + 3.20689685388456e+98*cos(theta)**8 - 2.62016667373118e+96*cos(theta)**6 + 1.11401644291292e+94*cos(theta)**4 - 1.84388928482138e+91*cos(theta)**2 + 4.95935794734099e+87)*cos(45*phi)

#@torch.jit.script
def Yl97_m46(theta, phi):
    return 1.11756593189398e-90*(1.0 - cos(theta)**2)**23*(5.62194323783306e+113*cos(theta)**51 - 3.71397804571873e+114*cos(theta)**49 + 1.14336078056681e+115*cos(theta)**47 - 2.17984656753567e+115*cos(theta)**45 + 2.8850910452678e+115*cos(theta)**43 - 2.81647266365062e+115*cos(theta)**41 + 2.10337667048589e+115*cos(theta)**39 - 1.23015162812158e+115*cos(theta)**37 + 5.72123592408502e+114*cos(theta)**35 - 2.13693369418116e+114*cos(theta)**33 + 6.44743423158658e+113*cos(theta)**31 - 1.57543716116015e+113*cos(theta)**29 + 3.11709301866969e+112*cos(theta)**27 - 4.97997109491607e+111*cos(theta)**25 + 6.39003989937904e+110*cos(theta)**23 - 6.53204078603191e+109*cos(theta)**21 + 5.25969541820054e+108*cos(theta)**19 - 3.2861085733003e+107*cos(theta)**17 + 1.56153307466401e+106*cos(theta)**15 - 5.49651266643384e+104*cos(theta)**13 + 1.38299350961884e+103*cos(theta)**11 - 2.36740252191211e+101*cos(theta)**9 + 2.56551748310764e+99*cos(theta)**7 - 1.57210000423871e+97*cos(theta)**5 + 4.45606577165167e+94*cos(theta)**3 - 3.68777856964276e+91*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl97_m47(theta, phi):
    return 1.30408776418279e-92*(1.0 - cos(theta)**2)**23.5*(2.86719105129486e+115*cos(theta)**50 - 1.81984924240218e+116*cos(theta)**48 + 5.37379566866403e+116*cos(theta)**46 - 9.80930955391052e+116*cos(theta)**44 + 1.24058914946515e+117*cos(theta)**42 - 1.15475379209675e+117*cos(theta)**40 + 8.20316901489498e+116*cos(theta)**38 - 4.55156102404986e+116*cos(theta)**36 + 2.00243257342976e+116*cos(theta)**34 - 7.05188119079782e+115*cos(theta)**32 + 1.99870461179184e+115*cos(theta)**30 - 4.56876776736443e+114*cos(theta)**28 + 8.41615115040815e+113*cos(theta)**26 - 1.24499277372902e+113*cos(theta)**24 + 1.46970917685718e+112*cos(theta)**22 - 1.3717285650667e+111*cos(theta)**20 + 9.99342129458103e+109*cos(theta)**18 - 5.58638457461051e+108*cos(theta)**16 + 2.34229961199602e+107*cos(theta)**14 - 7.145466466364e+105*cos(theta)**12 + 1.52129286058072e+104*cos(theta)**10 - 2.1306622697209e+102*cos(theta)**8 + 1.79586223817535e+100*cos(theta)**6 - 7.86050002119354e+97*cos(theta)**4 + 1.3368197314955e+95*cos(theta)**2 - 3.68777856964276e+91)*cos(47*phi)

#@torch.jit.script
def Yl97_m48(theta, phi):
    return 1.53157340629971e-94*(1.0 - cos(theta)**2)**24*(1.43359552564743e+117*cos(theta)**49 - 8.73527636353046e+117*cos(theta)**47 + 2.47194600758545e+118*cos(theta)**45 - 4.31609620372063e+118*cos(theta)**43 + 5.21047442775365e+118*cos(theta)**41 - 4.61901516838702e+118*cos(theta)**39 + 3.11720422566009e+118*cos(theta)**37 - 1.63856196865795e+118*cos(theta)**35 + 6.80827074966117e+117*cos(theta)**33 - 2.2566019810553e+117*cos(theta)**31 + 5.99611383537552e+116*cos(theta)**29 - 1.27925497486204e+116*cos(theta)**27 + 2.18819929910612e+115*cos(theta)**25 - 2.98798265694964e+114*cos(theta)**23 + 3.2333601890858e+113*cos(theta)**21 - 2.7434571301334e+112*cos(theta)**19 + 1.79881583302459e+111*cos(theta)**17 - 8.93821531937682e+109*cos(theta)**15 + 3.27921945679443e+108*cos(theta)**13 - 8.5745597596368e+106*cos(theta)**11 + 1.52129286058072e+105*cos(theta)**9 - 1.70452981577672e+103*cos(theta)**7 + 1.07751734290521e+101*cos(theta)**5 - 3.14420000847742e+98*cos(theta)**3 + 2.673639462991e+95*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl97_m49(theta, phi):
    return 1.81077024268632e-96*(1.0 - cos(theta)**2)**24.5*(7.02461807567241e+118*cos(theta)**48 - 4.10557989085932e+119*cos(theta)**46 + 1.11237570341345e+120*cos(theta)**44 - 1.85592136759987e+120*cos(theta)**42 + 2.136294515379e+120*cos(theta)**40 - 1.80141591567094e+120*cos(theta)**38 + 1.15336556349423e+120*cos(theta)**36 - 5.73496689030282e+119*cos(theta)**34 + 2.24672934738819e+119*cos(theta)**32 - 6.99546614127144e+118*cos(theta)**30 + 1.7388730122589e+118*cos(theta)**28 - 3.45398843212751e+117*cos(theta)**26 + 5.4704982477653e+116*cos(theta)**24 - 6.87236011098417e+115*cos(theta)**22 + 6.79005639708017e+114*cos(theta)**20 - 5.21256854725346e+113*cos(theta)**18 + 3.0579869161418e+112*cos(theta)**16 - 1.34073229790652e+111*cos(theta)**14 + 4.26298529383276e+109*cos(theta)**12 - 9.43201573560048e+107*cos(theta)**10 + 1.36916357452265e+106*cos(theta)**8 - 1.1931708710437e+104*cos(theta)**6 + 5.38758671452605e+101*cos(theta)**4 - 9.43260002543225e+98*cos(theta)**2 + 2.673639462991e+95)*cos(49*phi)

#@torch.jit.script
def Yl97_m50(theta, phi):
    return 2.15567886034086e-98*(1.0 - cos(theta)**2)**25*(3.37181667632276e+120*cos(theta)**47 - 1.88856674979529e+121*cos(theta)**45 + 4.8944530950192e+121*cos(theta)**43 - 7.79486974391946e+121*cos(theta)**41 + 8.54517806151599e+121*cos(theta)**39 - 6.84538047954956e+121*cos(theta)**37 + 4.15211602857924e+121*cos(theta)**35 - 1.94988874270296e+121*cos(theta)**33 + 7.1895339116422e+120*cos(theta)**31 - 2.09863984238143e+120*cos(theta)**29 + 4.86884443432492e+119*cos(theta)**27 - 8.98036992353152e+118*cos(theta)**25 + 1.31291957946367e+118*cos(theta)**23 - 1.51191922441652e+117*cos(theta)**21 + 1.35801127941603e+116*cos(theta)**19 - 9.38262338505624e+114*cos(theta)**17 + 4.89277906582687e+113*cos(theta)**15 - 1.87702521706913e+112*cos(theta)**13 + 5.11558235259931e+110*cos(theta)**11 - 9.43201573560048e+108*cos(theta)**9 + 1.09533085961812e+107*cos(theta)**7 - 7.15902522626222e+104*cos(theta)**5 + 2.15503468581042e+102*cos(theta)**3 - 1.88652000508645e+99*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl97_m51(theta, phi):
    return 2.58466508489848e-100*(1.0 - cos(theta)**2)**25.5*(1.5847538378717e+122*cos(theta)**46 - 8.49855037407878e+122*cos(theta)**44 + 2.10461483085825e+123*cos(theta)**42 - 3.19589659500698e+123*cos(theta)**40 + 3.33261944399123e+123*cos(theta)**38 - 2.53279077743334e+123*cos(theta)**36 + 1.45324061000273e+123*cos(theta)**34 - 6.43463285091977e+122*cos(theta)**32 + 2.22875551260908e+122*cos(theta)**30 - 6.08605554290615e+121*cos(theta)**28 + 1.31458799726773e+121*cos(theta)**26 - 2.24509248088288e+120*cos(theta)**24 + 3.01971503276645e+119*cos(theta)**22 - 3.17503037127469e+118*cos(theta)**20 + 2.58022143089047e+117*cos(theta)**18 - 1.59504597545956e+116*cos(theta)**16 + 7.33916859874031e+114*cos(theta)**14 - 2.44013278218987e+113*cos(theta)**12 + 5.62714058785924e+111*cos(theta)**10 - 8.48881416204043e+109*cos(theta)**8 + 7.66731601732684e+107*cos(theta)**6 - 3.57951261313111e+105*cos(theta)**4 + 6.46510405743126e+102*cos(theta)**2 - 1.88652000508645e+99)*cos(51*phi)

#@torch.jit.script
def Yl97_m52(theta, phi):
    return 3.12199516488902e-102*(1.0 - cos(theta)**2)**26*(7.2898676542098e+123*cos(theta)**45 - 3.73936216459467e+124*cos(theta)**43 + 8.83938228960467e+124*cos(theta)**41 - 1.27835863800279e+125*cos(theta)**39 + 1.26639538871667e+125*cos(theta)**37 - 9.11804679876002e+124*cos(theta)**35 + 4.9410180740093e+124*cos(theta)**33 - 2.05908251229432e+124*cos(theta)**31 + 6.68626653782724e+123*cos(theta)**29 - 1.70409555201372e+123*cos(theta)**27 + 3.4179287928961e+122*cos(theta)**25 - 5.38822195411891e+121*cos(theta)**23 + 6.64337307208618e+120*cos(theta)**21 - 6.35006074254938e+119*cos(theta)**19 + 4.64439857560284e+118*cos(theta)**17 - 2.5520735607353e+117*cos(theta)**15 + 1.02748360382364e+116*cos(theta)**13 - 2.92815933862785e+114*cos(theta)**11 + 5.62714058785924e+112*cos(theta)**9 - 6.79105132963234e+110*cos(theta)**7 + 4.6003896103961e+108*cos(theta)**5 - 1.43180504525244e+106*cos(theta)**3 + 1.29302081148625e+103*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl97_m53(theta, phi):
    return 3.79997150273728e-104*(1.0 - cos(theta)**2)**26.5*(3.28044044439441e+125*cos(theta)**44 - 1.60792573077571e+126*cos(theta)**42 + 3.62414673873791e+126*cos(theta)**40 - 4.98559868821089e+126*cos(theta)**38 + 4.68566293825168e+126*cos(theta)**36 - 3.19131637956601e+126*cos(theta)**34 + 1.63053596442307e+126*cos(theta)**32 - 6.38315578811241e+125*cos(theta)**30 + 1.9390172959699e+125*cos(theta)**28 - 4.60105799043705e+124*cos(theta)**26 + 8.54482198224024e+123*cos(theta)**24 - 1.23929104944735e+123*cos(theta)**22 + 1.3951083451381e+122*cos(theta)**20 - 1.20651154108438e+121*cos(theta)**18 + 7.89547757852482e+119*cos(theta)**16 - 3.82811034110294e+118*cos(theta)**14 + 1.33572868497074e+117*cos(theta)**12 - 3.22097527249063e+115*cos(theta)**10 + 5.06442652907332e+113*cos(theta)**8 - 4.75373593074264e+111*cos(theta)**6 + 2.30019480519805e+109*cos(theta)**4 - 4.29541513575733e+106*cos(theta)**2 + 1.29302081148625e+103)*cos(53*phi)

#@torch.jit.script
def Yl97_m54(theta, phi):
    return 4.66192763435192e-106*(1.0 - cos(theta)**2)**27*(1.44339379553354e+127*cos(theta)**43 - 6.75328806925797e+127*cos(theta)**41 + 1.44965869549517e+128*cos(theta)**39 - 1.89452750152014e+128*cos(theta)**37 + 1.6868386577706e+128*cos(theta)**35 - 1.08504756905244e+128*cos(theta)**33 + 5.21771508615382e+127*cos(theta)**31 - 1.91494673643372e+127*cos(theta)**29 + 5.42924842871572e+126*cos(theta)**27 - 1.19627507751363e+126*cos(theta)**25 + 2.05075727573766e+125*cos(theta)**23 - 2.72644030878417e+124*cos(theta)**21 + 2.7902166902762e+123*cos(theta)**19 - 2.17172077395189e+122*cos(theta)**17 + 1.26327641256397e+121*cos(theta)**15 - 5.35935447754412e+119*cos(theta)**13 + 1.60287442196488e+118*cos(theta)**11 - 3.22097527249063e+116*cos(theta)**9 + 4.05154122325866e+114*cos(theta)**7 - 2.85224155844558e+112*cos(theta)**5 + 9.20077922079221e+109*cos(theta)**3 - 8.59083027151467e+106*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl97_m55(theta, phi):
    return 5.76646295081998e-108*(1.0 - cos(theta)**2)**27.5*(6.20659332079423e+128*cos(theta)**42 - 2.76884810839577e+129*cos(theta)**40 + 5.65366891243115e+129*cos(theta)**38 - 7.00975175562451e+129*cos(theta)**36 + 5.90393530219711e+129*cos(theta)**34 - 3.58065697787306e+129*cos(theta)**32 + 1.61749167670768e+129*cos(theta)**30 - 5.55334553565779e+128*cos(theta)**28 + 1.46589707575324e+128*cos(theta)**26 - 2.99068769378408e+127*cos(theta)**24 + 4.71674173419661e+126*cos(theta)**22 - 5.72552464844675e+125*cos(theta)**20 + 5.30141171152477e+124*cos(theta)**18 - 3.69192531571821e+123*cos(theta)**16 + 1.89491461884596e+122*cos(theta)**14 - 6.96716082080736e+120*cos(theta)**12 + 1.76316186416137e+119*cos(theta)**10 - 2.89887774524157e+117*cos(theta)**8 + 2.83607885628106e+115*cos(theta)**6 - 1.42612077922279e+113*cos(theta)**4 + 2.76023376623766e+110*cos(theta)**2 - 8.59083027151467e+106)*cos(55*phi)

#@torch.jit.script
def Yl97_m56(theta, phi):
    return 7.19348173874411e-110*(1.0 - cos(theta)**2)**28*(2.60676919473357e+130*cos(theta)**41 - 1.10753924335831e+131*cos(theta)**39 + 2.14839418672384e+131*cos(theta)**37 - 2.52351063202482e+131*cos(theta)**35 + 2.00733800274702e+131*cos(theta)**33 - 1.14581023291938e+131*cos(theta)**31 + 4.85247503012305e+130*cos(theta)**29 - 1.55493674998418e+130*cos(theta)**27 + 3.81133239695844e+129*cos(theta)**25 - 7.1776504650818e+128*cos(theta)**23 + 1.03768318152325e+128*cos(theta)**21 - 1.14510492968935e+127*cos(theta)**19 + 9.54254108074459e+125*cos(theta)**17 - 5.90708050514913e+124*cos(theta)**15 + 2.65288046638434e+123*cos(theta)**13 - 8.36059298496883e+121*cos(theta)**11 + 1.76316186416137e+120*cos(theta)**9 - 2.31910219619325e+118*cos(theta)**7 + 1.70164731376864e+116*cos(theta)**5 - 5.70448311689117e+113*cos(theta)**3 + 5.52046753247532e+110*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl97_m57(theta, phi):
    return 9.05288193924102e-112*(1.0 - cos(theta)**2)**28.5*(1.06877536984077e+132*cos(theta)**40 - 4.31940304909739e+132*cos(theta)**38 + 7.94905849087819e+132*cos(theta)**36 - 8.83228721208688e+132*cos(theta)**34 + 6.62421540906516e+132*cos(theta)**32 - 3.55201172205007e+132*cos(theta)**30 + 1.40721775873569e+132*cos(theta)**28 - 4.19832922495729e+131*cos(theta)**26 + 9.52833099239609e+130*cos(theta)**24 - 1.65085960696881e+130*cos(theta)**22 + 2.17913468119883e+129*cos(theta)**20 - 2.17569936640977e+128*cos(theta)**18 + 1.62223198372658e+127*cos(theta)**16 - 8.8606207577237e+125*cos(theta)**14 + 3.44874460629964e+124*cos(theta)**12 - 9.19665228346571e+122*cos(theta)**10 + 1.58684567774523e+121*cos(theta)**8 - 1.62337153733528e+119*cos(theta)**6 + 8.50823656884318e+116*cos(theta)**4 - 1.71134493506735e+114*cos(theta)**2 + 5.52046753247532e+110)*cos(57*phi)

#@torch.jit.script
def Yl97_m58(theta, phi):
    return 1.14971715600134e-113*(1.0 - cos(theta)**2)**29*(4.27510147936306e+133*cos(theta)**39 - 1.64137315865701e+134*cos(theta)**37 + 2.86166105671615e+134*cos(theta)**35 - 3.00297765210954e+134*cos(theta)**33 + 2.11974893090085e+134*cos(theta)**31 - 1.06560351661502e+134*cos(theta)**29 + 3.94020972445992e+133*cos(theta)**27 - 1.0915655984889e+133*cos(theta)**25 + 2.28679943817506e+132*cos(theta)**23 - 3.63189113533139e+131*cos(theta)**21 + 4.35826936239767e+130*cos(theta)**19 - 3.91625885953758e+129*cos(theta)**17 + 2.59557117396253e+128*cos(theta)**15 - 1.24048690608132e+127*cos(theta)**13 + 4.13849352755957e+125*cos(theta)**11 - 9.19665228346571e+123*cos(theta)**9 + 1.26947654219619e+122*cos(theta)**7 - 9.74022922401167e+119*cos(theta)**5 + 3.40329462753727e+117*cos(theta)**3 - 3.4226898701347e+114*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl97_m59(theta, phi):
    return 1.47399635384787e-115*(1.0 - cos(theta)**2)**29.5*(1.66728957695159e+135*cos(theta)**38 - 6.07308068703094e+135*cos(theta)**36 + 1.00158136985065e+136*cos(theta)**34 - 9.90982625196148e+135*cos(theta)**32 + 6.57122168579264e+135*cos(theta)**30 - 3.09025019818356e+135*cos(theta)**28 + 1.06385662560418e+135*cos(theta)**26 - 2.72891399622224e+134*cos(theta)**24 + 5.25963870780264e+133*cos(theta)**22 - 7.62697138419592e+132*cos(theta)**20 + 8.28071178855557e+131*cos(theta)**18 - 6.65764006121389e+130*cos(theta)**16 + 3.89335676094379e+129*cos(theta)**14 - 1.61263297790571e+128*cos(theta)**12 + 4.55234288031553e+126*cos(theta)**10 - 8.27698705511914e+124*cos(theta)**8 + 8.88633579537331e+122*cos(theta)**6 - 4.87011461200583e+120*cos(theta)**4 + 1.02098838826118e+118*cos(theta)**2 - 3.4226898701347e+114)*cos(59*phi)

#@torch.jit.script
def Yl97_m60(theta, phi):
    return 1.90833574317446e-117*(1.0 - cos(theta)**2)**30*(6.33570039241606e+136*cos(theta)**37 - 2.18630904733114e+137*cos(theta)**35 + 3.40537665749222e+137*cos(theta)**33 - 3.17114440062767e+137*cos(theta)**31 + 1.97136650573779e+137*cos(theta)**29 - 8.65270055491398e+136*cos(theta)**27 + 2.76602722657086e+136*cos(theta)**25 - 6.54939359093338e+135*cos(theta)**23 + 1.15712051571658e+135*cos(theta)**21 - 1.52539427683918e+134*cos(theta)**19 + 1.49052812194e+133*cos(theta)**17 - 1.06522240979422e+132*cos(theta)**15 + 5.45069946532131e+130*cos(theta)**13 - 1.93515957348686e+129*cos(theta)**11 + 4.55234288031553e+127*cos(theta)**9 - 6.62158964409531e+125*cos(theta)**7 + 5.33180147722399e+123*cos(theta)**5 - 1.94804584480233e+121*cos(theta)**3 + 2.04197677652236e+118*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl97_m61(theta, phi):
    return 2.49588964483365e-119*(1.0 - cos(theta)**2)**30.5*(2.34420914519394e+138*cos(theta)**36 - 7.65208166565898e+138*cos(theta)**34 + 1.12377429697243e+139*cos(theta)**32 - 9.83054764194578e+138*cos(theta)**30 + 5.71696286663959e+138*cos(theta)**28 - 2.33622914982677e+138*cos(theta)**26 + 6.91506806642716e+137*cos(theta)**24 - 1.50636052591468e+137*cos(theta)**22 + 2.42995308300482e+136*cos(theta)**20 - 2.89824912599445e+135*cos(theta)**18 + 2.533897807298e+134*cos(theta)**16 - 1.59783361469133e+133*cos(theta)**14 + 7.0859093049177e+131*cos(theta)**12 - 2.12867553083554e+130*cos(theta)**10 + 4.09710859228398e+128*cos(theta)**8 - 4.63511275086672e+126*cos(theta)**6 + 2.66590073861199e+124*cos(theta)**4 - 5.844137534407e+121*cos(theta)**2 + 2.04197677652236e+118)*cos(61*phi)

#@torch.jit.script
def Yl97_m62(theta, phi):
    return 3.2989487343547e-121*(1.0 - cos(theta)**2)**31*(8.43915292269819e+139*cos(theta)**35 - 2.60170776632405e+140*cos(theta)**33 + 3.59607775031178e+140*cos(theta)**31 - 2.94916429258374e+140*cos(theta)**29 + 1.60074960265909e+140*cos(theta)**27 - 6.07419578954961e+139*cos(theta)**25 + 1.65961633594252e+139*cos(theta)**23 - 3.31399315701229e+138*cos(theta)**21 + 4.85990616600964e+137*cos(theta)**19 - 5.21684842679001e+136*cos(theta)**17 + 4.05423649167681e+135*cos(theta)**15 - 2.23696706056787e+134*cos(theta)**13 + 8.50309116590124e+132*cos(theta)**11 - 2.12867553083554e+131*cos(theta)**9 + 3.27768687382718e+129*cos(theta)**7 - 2.78106765052003e+127*cos(theta)**5 + 1.0663602954448e+125*cos(theta)**3 - 1.1688275068814e+122*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl97_m63(theta, phi):
    return 4.40840567874529e-123*(1.0 - cos(theta)**2)**31.5*(2.95370352294437e+141*cos(theta)**34 - 8.58563562886938e+141*cos(theta)**32 + 1.11478410259665e+142*cos(theta)**30 - 8.55257644849283e+141*cos(theta)**28 + 4.32202392717953e+141*cos(theta)**26 - 1.5185489473874e+141*cos(theta)**24 + 3.81711757266779e+140*cos(theta)**22 - 6.95938562972581e+139*cos(theta)**20 + 9.23382171541832e+138*cos(theta)**18 - 8.86864232554302e+137*cos(theta)**16 + 6.08135473751521e+136*cos(theta)**14 - 2.90805717873823e+135*cos(theta)**12 + 9.35340028249137e+133*cos(theta)**10 - 1.91580797775199e+132*cos(theta)**8 + 2.29438081167903e+130*cos(theta)**6 - 1.39053382526002e+128*cos(theta)**4 + 3.19908088633439e+125*cos(theta)**2 - 1.1688275068814e+122)*cos(63*phi)

#@torch.jit.script
def Yl97_m64(theta, phi):
    return 5.95839316289692e-125*(1.0 - cos(theta)**2)**32*(1.00425919780108e+143*cos(theta)**33 - 2.7474034012382e+143*cos(theta)**31 + 3.34435230778996e+143*cos(theta)**29 - 2.39472140557799e+143*cos(theta)**27 + 1.12372622106668e+143*cos(theta)**25 - 3.64451747372977e+142*cos(theta)**23 + 8.39765865986914e+141*cos(theta)**21 - 1.39187712594516e+141*cos(theta)**19 + 1.6620879087753e+140*cos(theta)**17 - 1.41898277208688e+139*cos(theta)**15 + 8.5138966325213e+137*cos(theta)**13 - 3.48966861448587e+136*cos(theta)**11 + 9.35340028249137e+134*cos(theta)**9 - 1.53264638220159e+133*cos(theta)**7 + 1.37662848700742e+131*cos(theta)**5 - 5.56213530104006e+128*cos(theta)**3 + 6.39816177266879e+125*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl97_m65(theta, phi):
    return 8.14919442513382e-127*(1.0 - cos(theta)**2)**32.5*(3.31405535274358e+144*cos(theta)**32 - 8.51695054383842e+144*cos(theta)**30 + 9.69862169259087e+144*cos(theta)**28 - 6.46574779506058e+144*cos(theta)**26 + 2.8093155526667e+144*cos(theta)**24 - 8.38239018957847e+143*cos(theta)**22 + 1.76350831857252e+143*cos(theta)**20 - 2.64456653929581e+142*cos(theta)**18 + 2.82554944491801e+141*cos(theta)**16 - 2.12847415813032e+140*cos(theta)**14 + 1.10680656222777e+139*cos(theta)**12 - 3.83863547593446e+137*cos(theta)**10 + 8.41806025424223e+135*cos(theta)**8 - 1.07285246754111e+134*cos(theta)**6 + 6.88314243503708e+131*cos(theta)**4 - 1.66864059031202e+129*cos(theta)**2 + 6.39816177266879e+125)*cos(65*phi)

#@torch.jit.script
def Yl97_m66(theta, phi):
    return 1.12835533866591e-128*(1.0 - cos(theta)**2)**33*(1.06049771287795e+146*cos(theta)**31 - 2.55508516315153e+146*cos(theta)**29 + 2.71561407392544e+146*cos(theta)**27 - 1.68109442671575e+146*cos(theta)**25 + 6.74235732640007e+145*cos(theta)**23 - 1.84412584170726e+145*cos(theta)**21 + 3.52701663714504e+144*cos(theta)**19 - 4.76021977073245e+143*cos(theta)**17 + 4.52087911186881e+142*cos(theta)**15 - 2.97986382138245e+141*cos(theta)**13 + 1.32816787467332e+140*cos(theta)**11 - 3.83863547593446e+138*cos(theta)**9 + 6.73444820339378e+136*cos(theta)**7 - 6.43711480524668e+134*cos(theta)**5 + 2.75325697401483e+132*cos(theta)**3 - 3.33728118062404e+129*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl97_m67(theta, phi):
    return 1.58249780794403e-130*(1.0 - cos(theta)**2)**33.5*(3.28754290992163e+147*cos(theta)**30 - 7.40974697313943e+147*cos(theta)**28 + 7.3321579995987e+147*cos(theta)**26 - 4.20273606678938e+147*cos(theta)**24 + 1.55074218507202e+147*cos(theta)**22 - 3.87266426758525e+146*cos(theta)**20 + 6.70133161057557e+145*cos(theta)**18 - 8.09237361024517e+144*cos(theta)**16 + 6.78131866780321e+143*cos(theta)**14 - 3.87382296779719e+142*cos(theta)**12 + 1.46098466214065e+141*cos(theta)**10 - 3.45477192834101e+139*cos(theta)**8 + 4.71411374237565e+137*cos(theta)**6 - 3.21855740262334e+135*cos(theta)**4 + 8.25977092204449e+132*cos(theta)**2 - 3.33728118062404e+129)*cos(67*phi)

#@torch.jit.script
def Yl97_m68(theta, phi):
    return 2.249264441899e-132*(1.0 - cos(theta)**2)**34*(9.86262872976489e+148*cos(theta)**29 - 2.07472915247904e+149*cos(theta)**27 + 1.90636107989566e+149*cos(theta)**25 - 1.00865665602945e+149*cos(theta)**23 + 3.41163280715844e+148*cos(theta)**21 - 7.7453285351705e+147*cos(theta)**19 + 1.2062396899036e+147*cos(theta)**17 - 1.29477977763923e+146*cos(theta)**15 + 9.4938461349245e+144*cos(theta)**13 - 4.64858756135663e+143*cos(theta)**11 + 1.46098466214065e+142*cos(theta)**9 - 2.76381754267281e+140*cos(theta)**7 + 2.82846824542539e+138*cos(theta)**5 - 1.28742296104934e+136*cos(theta)**3 + 1.6519541844089e+133*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl97_m69(theta, phi):
    return 3.24180938106035e-134*(1.0 - cos(theta)**2)**34.5*(2.86016233163182e+150*cos(theta)**28 - 5.60176871169341e+150*cos(theta)**26 + 4.76590269973915e+150*cos(theta)**24 - 2.31991030886774e+150*cos(theta)**22 + 7.16442889503272e+149*cos(theta)**20 - 1.4716124216824e+149*cos(theta)**18 + 2.05060747283613e+148*cos(theta)**16 - 1.94216966645884e+147*cos(theta)**14 + 1.23419999754018e+146*cos(theta)**12 - 5.11344631749229e+144*cos(theta)**10 + 1.31488619592659e+143*cos(theta)**8 - 1.93467227987097e+141*cos(theta)**6 + 1.41423412271269e+139*cos(theta)**4 - 3.86226888314801e+136*cos(theta)**2 + 1.6519541844089e+133)*cos(69*phi)

#@torch.jit.script
def Yl97_m70(theta, phi):
    return 4.7407846006173e-136*(1.0 - cos(theta)**2)**35*(8.00845452856909e+151*cos(theta)**27 - 1.45645986504029e+152*cos(theta)**25 + 1.1438166479374e+152*cos(theta)**23 - 5.10380267950902e+151*cos(theta)**21 + 1.43288577900654e+151*cos(theta)**19 - 2.64890235902831e+150*cos(theta)**17 + 3.2809719565378e+149*cos(theta)**15 - 2.71903753304238e+148*cos(theta)**13 + 1.48103999704822e+147*cos(theta)**11 - 5.11344631749229e+145*cos(theta)**9 + 1.05190895674127e+144*cos(theta)**7 - 1.16080336792258e+142*cos(theta)**5 + 5.65693649085078e+139*cos(theta)**3 - 7.72453776629601e+136*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl97_m71(theta, phi):
    return 7.03904433333486e-138*(1.0 - cos(theta)**2)**35.5*(2.16228272271365e+153*cos(theta)**26 - 3.64114966260071e+153*cos(theta)**24 + 2.63077829025601e+153*cos(theta)**22 - 1.07179856269689e+153*cos(theta)**20 + 2.72248298011243e+152*cos(theta)**18 - 4.50313401034813e+151*cos(theta)**16 + 4.9214579348067e+150*cos(theta)**14 - 3.53474879295509e+149*cos(theta)**12 + 1.62914399675304e+148*cos(theta)**10 - 4.60210168574306e+146*cos(theta)**8 + 7.3633626971889e+144*cos(theta)**6 - 5.8040168396129e+142*cos(theta)**4 + 1.69708094725523e+140*cos(theta)**2 - 7.72453776629601e+136)*cos(71*phi)

#@torch.jit.script
def Yl97_m72(theta, phi):
    return 1.06190013055382e-139*(1.0 - cos(theta)**2)**36*(5.6219350790555e+154*cos(theta)**25 - 8.73875919024171e+154*cos(theta)**23 + 5.78771223856323e+154*cos(theta)**21 - 2.14359712539379e+154*cos(theta)**19 + 4.90046936420238e+153*cos(theta)**17 - 7.20501441655701e+152*cos(theta)**15 + 6.89004110872938e+151*cos(theta)**13 - 4.24169855154611e+150*cos(theta)**11 + 1.62914399675304e+149*cos(theta)**9 - 3.68168134859445e+147*cos(theta)**7 + 4.41801761831334e+145*cos(theta)**5 - 2.32160673584516e+143*cos(theta)**3 + 3.39416189451047e+140*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl97_m73(theta, phi):
    return 1.62888044357447e-141*(1.0 - cos(theta)**2)**36.5*(1.40548376976388e+156*cos(theta)**24 - 2.00991461375559e+156*cos(theta)**22 + 1.21541957009828e+156*cos(theta)**20 - 4.0728345382482e+155*cos(theta)**18 + 8.33079791914404e+154*cos(theta)**16 - 1.08075216248355e+154*cos(theta)**14 + 8.9570534413482e+152*cos(theta)**12 - 4.66586840670072e+151*cos(theta)**10 + 1.46622959707774e+150*cos(theta)**8 - 2.57717694401611e+148*cos(theta)**6 + 2.20900880915667e+146*cos(theta)**4 - 6.96482020753548e+143*cos(theta)**2 + 3.39416189451047e+140)*cos(73*phi)

#@torch.jit.script
def Yl97_m74(theta, phi):
    return 2.54264385369124e-143*(1.0 - cos(theta)**2)**37*(3.3731610474333e+157*cos(theta)**23 - 4.42181215026231e+157*cos(theta)**21 + 2.43083914019656e+157*cos(theta)**19 - 7.33110216884676e+156*cos(theta)**17 + 1.33292766706305e+156*cos(theta)**15 - 1.51305302747697e+155*cos(theta)**13 + 1.07484641296178e+154*cos(theta)**11 - 4.66586840670072e+152*cos(theta)**9 + 1.17298367766219e+151*cos(theta)**7 - 1.54630616640967e+149*cos(theta)**5 + 8.83603523662668e+146*cos(theta)**3 - 1.3929640415071e+144*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl97_m75(theta, phi):
    return 4.04256853757302e-145*(1.0 - cos(theta)**2)**37.5*(7.75827040909659e+158*cos(theta)**22 - 9.28580551555085e+158*cos(theta)**20 + 4.61859436637346e+158*cos(theta)**18 - 1.24628736870395e+158*cos(theta)**16 + 1.99939150059457e+157*cos(theta)**14 - 1.96696893572006e+156*cos(theta)**12 + 1.18233105425796e+155*cos(theta)**10 - 4.19928156603065e+153*cos(theta)**8 + 8.21088574363534e+151*cos(theta)**6 - 7.73153083204834e+149*cos(theta)**4 + 2.650810570988e+147*cos(theta)**2 - 1.3929640415071e+144)*cos(75*phi)

#@torch.jit.script
def Yl97_m76(theta, phi):
    return 6.55274095574063e-147*(1.0 - cos(theta)**2)**38*(1.70681949000125e+160*cos(theta)**21 - 1.85716110311017e+160*cos(theta)**19 + 8.31346985947222e+159*cos(theta)**17 - 1.99405978992632e+159*cos(theta)**15 + 2.7991481008324e+158*cos(theta)**13 - 2.36036272286408e+157*cos(theta)**11 + 1.18233105425796e+156*cos(theta)**9 - 3.35942525282452e+154*cos(theta)**7 + 4.9265314461812e+152*cos(theta)**5 - 3.09261233281934e+150*cos(theta)**3 + 5.30162114197601e+147*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl97_m77(theta, phi):
    return 1.08402357741615e-148*(1.0 - cos(theta)**2)**38.5*(3.58432092900263e+161*cos(theta)**20 - 3.52860609590932e+161*cos(theta)**18 + 1.41328987611028e+161*cos(theta)**16 - 2.99108968488948e+160*cos(theta)**14 + 3.63889253108212e+159*cos(theta)**12 - 2.59639899515048e+158*cos(theta)**10 + 1.06409794883217e+157*cos(theta)**8 - 2.35159767697716e+155*cos(theta)**6 + 2.4632657230906e+153*cos(theta)**4 - 9.27783699845801e+150*cos(theta)**2 + 5.30162114197601e+147)*cos(77*phi)

#@torch.jit.script
def Yl97_m78(theta, phi):
    return 1.83233427735857e-150*(1.0 - cos(theta)**2)**39*(7.16864185800525e+162*cos(theta)**19 - 6.35149097263678e+162*cos(theta)**17 + 2.26126380177644e+162*cos(theta)**15 - 4.18752555884527e+161*cos(theta)**13 + 4.36667103729854e+160*cos(theta)**11 - 2.59639899515048e+159*cos(theta)**9 + 8.51278359065733e+157*cos(theta)**7 - 1.4109586061863e+156*cos(theta)**5 + 9.85306289236241e+153*cos(theta)**3 - 1.8555673996916e+151*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl97_m79(theta, phi):
    return 3.16863030571629e-152*(1.0 - cos(theta)**2)**39.5*(1.362041953021e+164*cos(theta)**18 - 1.07975346534825e+164*cos(theta)**16 + 3.39189570266467e+163*cos(theta)**14 - 5.44378322649885e+162*cos(theta)**12 + 4.8033381410284e+161*cos(theta)**10 - 2.33675909563544e+160*cos(theta)**8 + 5.95894851346013e+158*cos(theta)**6 - 7.05479303093148e+156*cos(theta)**4 + 2.95591886770872e+154*cos(theta)**2 - 1.8555673996916e+151)*cos(79*phi)

#@torch.jit.script
def Yl97_m80(theta, phi):
    return 5.61369335548937e-154*(1.0 - cos(theta)**2)**40*(2.4516755154378e+165*cos(theta)**17 - 1.7276055445572e+165*cos(theta)**15 + 4.74865398373053e+164*cos(theta)**13 - 6.53253987179862e+163*cos(theta)**11 + 4.8033381410284e+162*cos(theta)**9 - 1.86940727650835e+161*cos(theta)**7 + 3.57536910807608e+159*cos(theta)**5 - 2.82191721237259e+157*cos(theta)**3 + 5.91183773541744e+154*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl97_m81(theta, phi):
    return 1.02050285496008e-155*(1.0 - cos(theta)**2)**40.5*(4.16784837624425e+166*cos(theta)**16 - 2.59140831683581e+166*cos(theta)**14 + 6.17325017884969e+165*cos(theta)**12 - 7.18579385897848e+164*cos(theta)**10 + 4.32300432692556e+163*cos(theta)**8 - 1.30858509355584e+162*cos(theta)**6 + 1.78768455403804e+160*cos(theta)**4 - 8.46575163711778e+157*cos(theta)**2 + 5.91183773541744e+154)*cos(81*phi)

#@torch.jit.script
def Yl97_m82(theta, phi):
    return 1.90689911512676e-157*(1.0 - cos(theta)**2)**41*(6.66855740199081e+167*cos(theta)**15 - 3.62797164357013e+167*cos(theta)**13 + 7.40790021461963e+166*cos(theta)**11 - 7.18579385897848e+165*cos(theta)**9 + 3.45840346154044e+164*cos(theta)**7 - 7.85151056133506e+162*cos(theta)**5 + 7.15073821615215e+160*cos(theta)**3 - 1.69315032742356e+158*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl97_m83(theta, phi):
    return 3.66982905811965e-159*(1.0 - cos(theta)**2)**41.5*(1.00028361029862e+169*cos(theta)**14 - 4.71636313664117e+168*cos(theta)**12 + 8.1486902360816e+167*cos(theta)**10 - 6.46721447308063e+166*cos(theta)**8 + 2.42088242307831e+165*cos(theta)**6 - 3.92575528066753e+163*cos(theta)**4 + 2.14522146484565e+161*cos(theta)**2 - 1.69315032742356e+158)*cos(83*phi)

#@torch.jit.script
def Yl97_m84(theta, phi):
    return 7.29025181800508e-161*(1.0 - cos(theta)**2)**42*(1.40039705441807e+170*cos(theta)**13 - 5.6596357639694e+169*cos(theta)**11 + 8.1486902360816e+168*cos(theta)**9 - 5.17377157846451e+167*cos(theta)**7 + 1.45252945384699e+166*cos(theta)**5 - 1.57030211226701e+164*cos(theta)**3 + 4.29044292969129e+161*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl97_m85(theta, phi):
    return 1.49877058056488e-162*(1.0 - cos(theta)**2)**42.5*(1.82051617074349e+171*cos(theta)**12 - 6.22559934036634e+170*cos(theta)**10 + 7.33382121247344e+169*cos(theta)**8 - 3.62164010492515e+168*cos(theta)**6 + 7.26264726923493e+166*cos(theta)**4 - 4.71090633680104e+164*cos(theta)**2 + 4.29044292969129e+161)*cos(85*phi)

#@torch.jit.script
def Yl97_m86(theta, phi):
    return 3.19829848117904e-164*(1.0 - cos(theta)**2)**43*(2.18461940489219e+172*cos(theta)**11 - 6.22559934036634e+171*cos(theta)**9 + 5.86705696997875e+170*cos(theta)**7 - 2.17298406295509e+169*cos(theta)**5 + 2.90505890769397e+167*cos(theta)**3 - 9.42181267360208e+164*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl97_m87(theta, phi):
    return 7.10908550469079e-166*(1.0 - cos(theta)**2)**43.5*(2.40308134538141e+173*cos(theta)**10 - 5.60303940632971e+172*cos(theta)**8 + 4.10693987898512e+171*cos(theta)**6 - 1.08649203147755e+170*cos(theta)**4 + 8.71517672308192e+167*cos(theta)**2 - 9.42181267360208e+164)*cos(87*phi)

#@torch.jit.script
def Yl97_m88(theta, phi):
    return 1.65282880709644e-167*(1.0 - cos(theta)**2)**44*(2.40308134538141e+174*cos(theta)**9 - 4.48243152506376e+173*cos(theta)**7 + 2.46416392739107e+172*cos(theta)**5 - 4.34596812591018e+170*cos(theta)**3 + 1.74303534461638e+168*cos(theta))*cos(88*phi)

#@torch.jit.script
def Yl97_m89(theta, phi):
    return 4.03970960308129e-169*(1.0 - cos(theta)**2)**44.5*(2.16277321084327e+175*cos(theta)**8 - 3.13770206754463e+174*cos(theta)**6 + 1.23208196369554e+173*cos(theta)**4 - 1.30379043777306e+171*cos(theta)**2 + 1.74303534461638e+168)*cos(89*phi)

#@torch.jit.script
def Yl97_m90(theta, phi):
    return 1.044442053454e-170*(1.0 - cos(theta)**2)**45*(1.73021856867461e+176*cos(theta)**7 - 1.88262124052678e+175*cos(theta)**5 + 4.92832785478215e+173*cos(theta)**3 - 2.60758087554611e+171*cos(theta))*cos(90*phi)

#@torch.jit.script
def Yl97_m91(theta, phi):
    return 2.87909771810356e-172*(1.0 - cos(theta)**2)**45.5*(1.21115299807223e+177*cos(theta)**6 - 9.41310620263391e+175*cos(theta)**4 + 1.47849835643464e+174*cos(theta)**2 - 2.60758087554611e+171)*cos(91*phi)

#@torch.jit.script
def Yl97_m92(theta, phi):
    return 8.54968035252871e-174*(1.0 - cos(theta)**2)**46*(7.26691798843337e+177*cos(theta)**5 - 3.76524248105356e+176*cos(theta)**3 + 2.95699671286929e+174*cos(theta))*cos(92*phi)

#@torch.jit.script
def Yl97_m93(theta, phi):
    return 2.77388259400193e-175*(1.0 - cos(theta)**2)**46.5*(3.63345899421669e+178*cos(theta)**4 - 1.12957274431607e+177*cos(theta)**2 + 2.95699671286929e+174)*cos(93*phi)

#@torch.jit.script
def Yl97_m94(theta, phi):
    return 1.00355550154123e-176*(1.0 - cos(theta)**2)**47*(1.45338359768667e+179*cos(theta)**3 - 2.25914548863214e+177*cos(theta))*cos(94*phi)

#@torch.jit.script
def Yl97_m95(theta, phi):
    return 4.1814812564218e-178*(1.0 - cos(theta)**2)**47.5*(4.36015079306002e+179*cos(theta)**2 - 2.25914548863214e+177)*cos(95*phi)

#@torch.jit.script
def Yl97_m96(theta, phi):
    return 18.5595741478934*(1.0 - cos(theta)**2)**48*cos(96*phi)*cos(theta)

#@torch.jit.script
def Yl97_m97(theta, phi):
    return 1.33249976799509*(1.0 - cos(theta)**2)**48.5*cos(97*phi)

#@torch.jit.script
def Yl98_m_minus_98(theta, phi):
    return 1.3358946773648*(1.0 - cos(theta)**2)**49*sin(98*phi)

#@torch.jit.script
def Yl98_m_minus_97(theta, phi):
    return 18.7025254831072*(1.0 - cos(theta)**2)**48.5*sin(97*phi)*cos(theta)

#@torch.jit.script
def Yl98_m_minus_96(theta, phi):
    return 2.17203311531976e-180*(1.0 - cos(theta)**2)**48*(8.50229404646705e+181*cos(theta)**2 - 4.36015079306002e+179)*sin(96*phi)

#@torch.jit.script
def Yl98_m_minus_95(theta, phi):
    return 5.23995955237687e-179*(1.0 - cos(theta)**2)**47.5*(2.83409801548902e+181*cos(theta)**3 - 4.36015079306002e+179*cos(theta))*sin(95*phi)

#@torch.jit.script
def Yl98_m_minus_94(theta, phi):
    return 1.45591689176756e-177*(1.0 - cos(theta)**2)**47*(7.08524503872254e+180*cos(theta)**4 - 2.18007539653001e+179*cos(theta)**2 + 5.64786372158034e+176)*sin(94*phi)

#@torch.jit.script
def Yl98_m_minus_93(theta, phi):
    return 4.51099350022227e-176*(1.0 - cos(theta)**2)**46.5*(1.41704900774451e+180*cos(theta)**5 - 7.26691798843337e+178*cos(theta)**3 + 5.64786372158034e+176*cos(theta))*sin(93*phi)

#@torch.jit.script
def Yl98_m_minus_92(theta, phi):
    return 1.52708956723136e-174*(1.0 - cos(theta)**2)**46*(2.36174834624085e+179*cos(theta)**6 - 1.81672949710834e+178*cos(theta)**4 + 2.82393186079017e+176*cos(theta)**2 - 4.92832785478215e+173)*sin(92*phi)

#@torch.jit.script
def Yl98_m_minus_91(theta, phi):
    return 5.56916814851313e-173*(1.0 - cos(theta)**2)**45.5*(3.3739262089155e+178*cos(theta)**7 - 3.63345899421669e+177*cos(theta)**5 + 9.41310620263391e+175*cos(theta)**3 - 4.92832785478215e+173*cos(theta))*sin(91*phi)

#@torch.jit.script
def Yl98_m_minus_90(theta, phi):
    return 2.16554008058075e-171*(1.0 - cos(theta)**2)**45*(4.21740776114437e+177*cos(theta)**8 - 6.05576499036115e+176*cos(theta)**6 + 2.35327655065848e+175*cos(theta)**4 - 2.46416392739107e+173*cos(theta)**2 + 3.25947609443264e+170)*sin(90*phi)

#@torch.jit.script
def Yl98_m_minus_89(theta, phi):
    return 8.90771688947175e-170*(1.0 - cos(theta)**2)**44.5*(4.68600862349374e+176*cos(theta)**9 - 8.65109284337306e+175*cos(theta)**7 + 4.70655310131695e+174*cos(theta)**5 - 8.21387975797025e+172*cos(theta)**3 + 3.25947609443264e+170*cos(theta))*sin(89*phi)

#@torch.jit.script
def Yl98_m_minus_88(theta, phi):
    return 3.85200825209621e-168*(1.0 - cos(theta)**2)**44*(4.68600862349374e+175*cos(theta)**10 - 1.08138660542163e+175*cos(theta)**8 + 7.84425516886159e+173*cos(theta)**6 - 2.05346993949256e+172*cos(theta)**4 + 1.62973804721632e+170*cos(theta)**2 - 1.74303534461638e+167)*sin(88*phi)

#@torch.jit.script
def Yl98_m_minus_87(theta, phi):
    return 1.74236855047515e-166*(1.0 - cos(theta)**2)**43.5*(4.26000783953977e+174*cos(theta)**11 - 1.2015406726907e+174*cos(theta)**9 + 1.12060788126594e+173*cos(theta)**7 - 4.10693987898512e+171*cos(theta)**5 + 5.43246015738773e+169*cos(theta)**3 - 1.74303534461638e+167*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl98_m_minus_86(theta, phi):
    return 8.20949628650893e-165*(1.0 - cos(theta)**2)**43*(3.55000653294981e+173*cos(theta)**12 - 1.2015406726907e+173*cos(theta)**10 + 1.40075985158243e+172*cos(theta)**8 - 6.84489979830854e+170*cos(theta)**6 + 1.35811503934693e+169*cos(theta)**4 - 8.71517672308192e+166*cos(theta)**2 + 7.85151056133506e+163)*sin(86*phi)

#@torch.jit.script
def Yl98_m_minus_85(theta, phi):
    return 4.01510676861106e-163*(1.0 - cos(theta)**2)**42.5*(2.73077425611524e+172*cos(theta)**13 - 1.09230970244609e+172*cos(theta)**11 + 1.55639983509158e+171*cos(theta)**9 - 9.77842828329791e+169*cos(theta)**7 + 2.71623007869387e+168*cos(theta)**5 - 2.90505890769397e+166*cos(theta)**3 + 7.85151056133506e+163*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl98_m_minus_84(theta, phi):
    return 2.03229459023276e-161*(1.0 - cos(theta)**2)**42*(1.95055304008231e+171*cos(theta)**14 - 9.10258085371745e+170*cos(theta)**12 + 1.55639983509158e+170*cos(theta)**10 - 1.22230353541224e+169*cos(theta)**8 + 4.52705013115644e+167*cos(theta)**6 - 7.26264726923493e+165*cos(theta)**4 + 3.92575528066753e+163*cos(theta)**2 - 3.06460209263664e+160)*sin(84*phi)

#@torch.jit.script
def Yl98_m_minus_83(theta, phi):
    return 1.0618617684551e-159*(1.0 - cos(theta)**2)**41.5*(1.30036869338821e+170*cos(theta)**15 - 7.00198527209035e+169*cos(theta)**13 + 1.41490894099235e+169*cos(theta)**11 - 1.35811503934693e+168*cos(theta)**9 + 6.46721447308063e+166*cos(theta)**7 - 1.45252945384699e+165*cos(theta)**5 + 1.30858509355584e+163*cos(theta)**3 - 3.06460209263664e+160*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl98_m_minus_82(theta, phi):
    return 5.71435560910229e-158*(1.0 - cos(theta)**2)**41*(8.12730433367629e+168*cos(theta)**16 - 5.0014180514931e+168*cos(theta)**14 + 1.17909078416029e+168*cos(theta)**12 - 1.35811503934693e+167*cos(theta)**10 + 8.08401809135079e+165*cos(theta)**8 - 2.42088242307831e+164*cos(theta)**6 + 3.27146273388961e+162*cos(theta)**4 - 1.53230104631832e+160*cos(theta)**2 + 1.05821895463972e+157)*sin(82*phi)

#@torch.jit.script
def Yl98_m_minus_81(theta, phi):
    return 3.16102533497397e-156*(1.0 - cos(theta)**2)**40.5*(4.7807672551037e+167*cos(theta)**17 - 3.3342787009954e+167*cos(theta)**15 + 9.06992910892532e+166*cos(theta)**13 - 1.23465003576994e+166*cos(theta)**11 + 8.9822423237231e+164*cos(theta)**9 - 3.45840346154044e+163*cos(theta)**7 + 6.54292546777922e+161*cos(theta)**5 - 5.10767015439439e+159*cos(theta)**3 + 1.05821895463972e+157*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl98_m_minus_80(theta, phi):
    return 1.79428218305859e-154*(1.0 - cos(theta)**2)**40*(2.65598180839095e+166*cos(theta)**18 - 2.08392418812213e+166*cos(theta)**16 + 6.47852079208951e+165*cos(theta)**14 - 1.02887502980828e+165*cos(theta)**12 + 8.9822423237231e+163*cos(theta)**10 - 4.32300432692556e+162*cos(theta)**8 + 1.0904875779632e+161*cos(theta)**6 - 1.2769175385986e+159*cos(theta)**4 + 5.29109477319861e+156*cos(theta)**2 - 3.28435429745414e+153)*sin(80*phi)

#@torch.jit.script
def Yl98_m_minus_79(theta, phi):
    return 1.04346418263193e-152*(1.0 - cos(theta)**2)**39.5*(1.39788516231102e+165*cos(theta)**19 - 1.2258377577189e+165*cos(theta)**17 + 4.31901386139301e+164*cos(theta)**15 - 7.91442330621756e+163*cos(theta)**13 + 8.16567483974827e+162*cos(theta)**11 - 4.8033381410284e+161*cos(theta)**9 + 1.55783939709029e+160*cos(theta)**7 - 2.5538350771972e+158*cos(theta)**5 + 1.76369825773287e+156*cos(theta)**3 - 3.28435429745414e+153*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl98_m_minus_78(theta, phi):
    return 6.20839266762537e-151*(1.0 - cos(theta)**2)**39*(6.98942581155512e+163*cos(theta)**20 - 6.81020976510499e+163*cos(theta)**18 + 2.69938366337063e+163*cos(theta)**16 - 5.65315950444111e+162*cos(theta)**14 + 6.80472903312356e+161*cos(theta)**12 - 4.8033381410284e+160*cos(theta)**10 + 1.94729924636286e+159*cos(theta)**8 - 4.25639179532866e+157*cos(theta)**6 + 4.40924564433218e+155*cos(theta)**4 - 1.64217714872707e+153*cos(theta)**2 + 9.27783699845801e+149)*sin(78*phi)

#@torch.jit.script
def Yl98_m_minus_77(theta, phi):
    return 3.77437597026328e-149*(1.0 - cos(theta)**2)**38.5*(3.32829800550244e+162*cos(theta)**21 - 3.58432092900263e+162*cos(theta)**19 + 1.58787274315919e+162*cos(theta)**17 - 3.76877300296074e+161*cos(theta)**15 + 5.23440694855658e+160*cos(theta)**13 - 4.36667103729854e+159*cos(theta)**11 + 2.16366582929207e+158*cos(theta)**9 - 6.08055970761237e+156*cos(theta)**7 + 8.81849128866436e+154*cos(theta)**5 - 5.47392382909023e+152*cos(theta)**3 + 9.27783699845801e+149*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl98_m_minus_76(theta, phi):
    return 2.34193870041187e-147*(1.0 - cos(theta)**2)**38*(1.51286272977384e+161*cos(theta)**22 - 1.79216046450131e+161*cos(theta)**20 + 8.8215152397733e+160*cos(theta)**18 - 2.35548312685046e+160*cos(theta)**16 + 3.73886210611185e+159*cos(theta)**14 - 3.63889253108212e+158*cos(theta)**12 + 2.16366582929207e+157*cos(theta)**10 - 7.60069963451547e+155*cos(theta)**8 + 1.46974854811073e+154*cos(theta)**6 - 1.36848095727256e+152*cos(theta)**4 + 4.63891849922901e+149*cos(theta)**2 - 2.40982779180728e+146)*sin(76*phi)

#@torch.jit.script
def Yl98_m_minus_75(theta, phi):
    return 1.48154233350587e-145*(1.0 - cos(theta)**2)**37.5*(6.57766404249494e+159*cos(theta)**23 - 8.53409745000625e+159*cos(theta)**21 + 4.64290275777542e+159*cos(theta)**19 - 1.38557830991204e+159*cos(theta)**17 + 2.4925747374079e+158*cos(theta)**15 - 2.7991481008324e+157*cos(theta)**13 + 1.96696893572006e+156*cos(theta)**11 - 8.4452218161283e+154*cos(theta)**9 + 2.09964078301532e+153*cos(theta)**7 - 2.73696191454511e+151*cos(theta)**5 + 1.54630616640967e+149*cos(theta)**3 - 2.40982779180728e+146*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl98_m_minus_74(theta, phi):
    return 9.54646836906066e-144*(1.0 - cos(theta)**2)**37*(2.74069335103956e+158*cos(theta)**24 - 3.8791352045483e+158*cos(theta)**22 + 2.32145137888771e+158*cos(theta)**20 - 7.69765727728909e+157*cos(theta)**18 + 1.55785921087994e+157*cos(theta)**16 - 1.99939150059457e+156*cos(theta)**14 + 1.63914077976672e+155*cos(theta)**12 - 8.4452218161283e+153*cos(theta)**10 + 2.62455097876915e+152*cos(theta)**8 - 4.56160319090852e+150*cos(theta)**6 + 3.86576541602417e+148*cos(theta)**4 - 1.20491389590364e+146*cos(theta)**2 + 5.8040168396129e+142)*sin(74*phi)

#@torch.jit.script
def Yl98_m_minus_73(theta, phi):
    return 6.26003794543089e-142*(1.0 - cos(theta)**2)**36.5*(1.09627734041582e+157*cos(theta)**25 - 1.68658052371665e+157*cos(theta)**23 + 1.10545303756558e+157*cos(theta)**21 - 4.05139856699426e+156*cos(theta)**19 + 9.16387771105845e+155*cos(theta)**17 - 1.33292766706305e+155*cos(theta)**15 + 1.26087752289748e+154*cos(theta)**13 - 7.67747437829845e+152*cos(theta)**11 + 2.91616775418795e+151*cos(theta)**9 - 6.51657598701217e+149*cos(theta)**7 + 7.73153083204834e+147*cos(theta)**5 - 4.01637965301213e+145*cos(theta)**3 + 5.8040168396129e+142*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl98_m_minus_72(theta, phi):
    return 4.17408890415419e-140*(1.0 - cos(theta)**2)**36*(4.21645130929163e+155*cos(theta)**26 - 7.02741884881938e+155*cos(theta)**24 + 5.02478653438899e+155*cos(theta)**22 - 2.02569928349713e+155*cos(theta)**20 + 5.09104317281025e+154*cos(theta)**18 - 8.33079791914404e+153*cos(theta)**16 + 9.00626802069626e+152*cos(theta)**14 - 6.39789531524871e+151*cos(theta)**12 + 2.91616775418795e+150*cos(theta)**10 - 8.14571998376522e+148*cos(theta)**8 + 1.28858847200806e+147*cos(theta)**6 - 1.00409491325303e+145*cos(theta)**4 + 2.90200841980645e+142*cos(theta)**2 - 1.30544688250403e+139)*sin(72*phi)

#@torch.jit.script
def Yl98_m_minus_71(theta, phi):
    return 2.82792597932132e-138*(1.0 - cos(theta)**2)**35.5*(1.56164863307097e+154*cos(theta)**27 - 2.81096753952775e+154*cos(theta)**25 + 2.18468979756043e+154*cos(theta)**23 - 9.64618706427205e+153*cos(theta)**21 + 2.67949640674224e+153*cos(theta)**19 - 4.90046936420238e+152*cos(theta)**17 + 6.00417868046417e+151*cos(theta)**15 - 4.9214579348067e+150*cos(theta)**13 + 2.65106159471632e+149*cos(theta)**11 - 9.05079998196135e+147*cos(theta)**9 + 1.84084067429722e+146*cos(theta)**7 - 2.00818982650606e+144*cos(theta)**5 + 9.67336139935483e+141*cos(theta)**3 - 1.30544688250403e+139*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl98_m_minus_70(theta, phi):
    return 1.94531710551958e-136*(1.0 - cos(theta)**2)**35*(5.57731654668205e+152*cos(theta)**28 - 1.08114136135683e+153*cos(theta)**26 + 9.10287415650179e+152*cos(theta)**24 - 4.38463048376002e+152*cos(theta)**22 + 1.33974820337112e+152*cos(theta)**20 - 2.72248298011243e+151*cos(theta)**18 + 3.75261167529011e+150*cos(theta)**16 - 3.5153270962905e+149*cos(theta)**14 + 2.20921799559693e+148*cos(theta)**12 - 9.05079998196135e+146*cos(theta)**10 + 2.30105084287153e+145*cos(theta)**8 - 3.34698304417677e+143*cos(theta)**6 + 2.41834034983871e+141*cos(theta)**4 - 6.52723441252013e+138*cos(theta)**2 + 2.75876348796286e+135)*sin(70*phi)

#@torch.jit.script
def Yl98_m_minus_69(theta, phi):
    return 1.35782576566671e-134*(1.0 - cos(theta)**2)**34.5*(1.92321260230415e+151*cos(theta)**29 - 4.00422726428455e+151*cos(theta)**27 + 3.64114966260071e+151*cos(theta)**25 - 1.90636107989566e+151*cos(theta)**23 + 6.37975334938628e+150*cos(theta)**21 - 1.43288577900654e+150*cos(theta)**19 + 2.20741863252359e+149*cos(theta)**17 - 2.343551397527e+148*cos(theta)**15 + 1.69939845815148e+147*cos(theta)**13 - 8.22799998360123e+145*cos(theta)**11 + 2.55672315874615e+144*cos(theta)**9 - 4.78140434882396e+142*cos(theta)**7 + 4.83668069967742e+140*cos(theta)**5 - 2.17574480417338e+138*cos(theta)**3 + 2.75876348796286e+135*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl98_m_minus_68(theta, phi):
    return 9.61087454794881e-133*(1.0 - cos(theta)**2)**34*(6.41070867434718e+149*cos(theta)**30 - 1.43008116581591e+150*cos(theta)**28 + 1.40044217792335e+150*cos(theta)**26 - 7.94317116623192e+149*cos(theta)**24 + 2.89988788608467e+149*cos(theta)**22 - 7.16442889503272e+148*cos(theta)**20 + 1.22634368473533e+148*cos(theta)**18 - 1.46471962345438e+147*cos(theta)**16 + 1.21385604153678e+146*cos(theta)**14 - 6.85666665300103e+144*cos(theta)**12 + 2.55672315874615e+143*cos(theta)**10 - 5.97675543602995e+141*cos(theta)**8 + 8.06113449946236e+139*cos(theta)**6 - 5.43936201043344e+137*cos(theta)**4 + 1.37938174398143e+135*cos(theta)**2 - 5.50651394802966e+131)*sin(68*phi)

#@torch.jit.script
def Yl98_m_minus_67(theta, phi):
    return 6.89442099585025e-131*(1.0 - cos(theta)**2)**33.5*(2.06797054011199e+148*cos(theta)**31 - 4.93131436488245e+148*cos(theta)**29 + 5.1868228811976e+148*cos(theta)**27 - 3.17726846649277e+148*cos(theta)**25 + 1.26082082003681e+148*cos(theta)**23 - 3.41163280715844e+147*cos(theta)**21 + 6.45444044597542e+146*cos(theta)**19 - 8.61599778502574e+145*cos(theta)**17 + 8.09237361024517e+144*cos(theta)**15 - 5.27435896384694e+143*cos(theta)**13 + 2.32429378067831e+142*cos(theta)**11 - 6.64083937336661e+140*cos(theta)**9 + 1.15159064278034e+139*cos(theta)**7 - 1.08787240208669e+137*cos(theta)**5 + 4.59793914660477e+134*cos(theta)**3 - 5.50651394802966e+131*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl98_m_minus_66(theta, phi):
    return 5.00973508065196e-129*(1.0 - cos(theta)**2)**33*(6.46240793784998e+146*cos(theta)**32 - 1.64377145496082e+147*cos(theta)**30 + 1.85243674328486e+147*cos(theta)**28 - 1.22202633326645e+147*cos(theta)**26 + 5.25342008348672e+146*cos(theta)**24 - 1.55074218507202e+146*cos(theta)**22 + 3.22722022298771e+145*cos(theta)**20 - 4.78666543612541e+144*cos(theta)**18 + 5.05773350640323e+143*cos(theta)**16 - 3.76739925989067e+142*cos(theta)**14 + 1.93691148389859e+141*cos(theta)**12 - 6.64083937336661e+139*cos(theta)**10 + 1.43948830347542e+138*cos(theta)**8 - 1.81312067014448e+136*cos(theta)**6 + 1.14948478665119e+134*cos(theta)**4 - 2.75325697401483e+131*cos(theta)**2 + 1.04290036894501e+128)*sin(66*phi)

#@torch.jit.script
def Yl98_m_minus_65(theta, phi):
    return 3.6854765698596e-127*(1.0 - cos(theta)**2)**32.5*(1.95830543571212e+145*cos(theta)**33 - 5.30248856438973e+145*cos(theta)**31 + 6.38771290787882e+145*cos(theta)**29 - 4.52602345654241e+145*cos(theta)**27 + 2.10136803339469e+145*cos(theta)**25 - 6.74235732640007e+144*cos(theta)**23 + 1.53677153475605e+144*cos(theta)**21 - 2.51929759796074e+143*cos(theta)**19 + 2.97513735670778e+142*cos(theta)**17 - 2.51159950659378e+141*cos(theta)**15 + 1.48993191069123e+140*cos(theta)**13 - 6.03712670306055e+138*cos(theta)**11 + 1.59943144830602e+137*cos(theta)**9 - 2.59017238592069e+135*cos(theta)**7 + 2.29896957330238e+133*cos(theta)**5 - 9.17752324671611e+130*cos(theta)**3 + 1.04290036894501e+128*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl98_m_minus_64(theta, phi):
    return 2.74363866945678e-125*(1.0 - cos(theta)**2)**32*(5.75972186974151e+143*cos(theta)**34 - 1.65702767637179e+144*cos(theta)**32 + 2.12923763595961e+144*cos(theta)**30 - 1.61643694876515e+144*cos(theta)**28 + 8.08218474382573e+143*cos(theta)**26 - 2.8093155526667e+143*cos(theta)**24 + 6.98532515798206e+142*cos(theta)**22 - 1.25964879898037e+142*cos(theta)**20 + 1.65285408705988e+141*cos(theta)**18 - 1.56974969162111e+140*cos(theta)**16 + 1.06423707906516e+139*cos(theta)**14 - 5.03093891921713e+137*cos(theta)**12 + 1.59943144830602e+136*cos(theta)**10 - 3.23771548240086e+134*cos(theta)**8 + 3.83161595550397e+132*cos(theta)**6 - 2.29438081167903e+130*cos(theta)**4 + 5.21450184472506e+127*cos(theta)**2 - 1.88181228607905e+124)*sin(64*phi)

#@torch.jit.script
def Yl98_m_minus_63(theta, phi):
    return 2.06594352178886e-123*(1.0 - cos(theta)**2)**31.5*(1.64563481992615e+142*cos(theta)**35 - 5.02129598900542e+142*cos(theta)**33 + 6.8685085030955e+142*cos(theta)**31 - 5.57392051298326e+142*cos(theta)**29 + 2.99340175697249e+142*cos(theta)**27 - 1.12372622106668e+142*cos(theta)**25 + 3.03709789477481e+141*cos(theta)**23 - 5.99832761419224e+140*cos(theta)**21 + 8.69923203715726e+139*cos(theta)**19 - 9.23382171541832e+138*cos(theta)**17 + 7.09491386043441e+137*cos(theta)**15 - 3.86995301478241e+136*cos(theta)**13 + 1.45402858936911e+135*cos(theta)**11 - 3.59746164711206e+133*cos(theta)**9 + 5.47373707929139e+131*cos(theta)**7 - 4.58876162335805e+129*cos(theta)**5 + 1.73816728157502e+127*cos(theta)**3 - 1.88181228607905e+124*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl98_m_minus_62(theta, phi):
    return 1.57283307422444e-121*(1.0 - cos(theta)**2)**31*(4.57120783312819e+140*cos(theta)**36 - 1.47685176147218e+141*cos(theta)**34 + 2.14640890721734e+141*cos(theta)**32 - 1.85797350432775e+141*cos(theta)**30 + 1.0690720560616e+141*cos(theta)**28 - 4.32202392717953e+140*cos(theta)**26 + 1.26545745615617e+140*cos(theta)**24 - 2.72651255190556e+139*cos(theta)**22 + 4.34961601857863e+138*cos(theta)**20 - 5.12990095301018e+137*cos(theta)**18 + 4.43432116277151e+136*cos(theta)**16 - 2.76425215341601e+135*cos(theta)**14 + 1.21169049114093e+134*cos(theta)**12 - 3.59746164711206e+132*cos(theta)**10 + 6.84217134911424e+130*cos(theta)**8 - 7.64793603893009e+128*cos(theta)**6 + 4.34541820393755e+126*cos(theta)**4 - 9.40906143039527e+123*cos(theta)**2 + 3.24674307467056e+120)*sin(62*phi)

#@torch.jit.script
def Yl98_m_minus_61(theta, phi):
    return 1.21016192990425e-119*(1.0 - cos(theta)**2)**30.5*(1.23546157652113e+139*cos(theta)**37 - 4.2195764613491e+139*cos(theta)**35 + 6.50426941581013e+139*cos(theta)**33 - 5.9934629171863e+139*cos(theta)**31 + 3.68645536572967e+139*cos(theta)**29 - 1.60074960265909e+139*cos(theta)**27 + 5.06182982462468e+138*cos(theta)**25 - 1.18544023995894e+138*cos(theta)**23 + 2.07124572313268e+137*cos(theta)**21 - 2.69994787000536e+136*cos(theta)**19 + 2.608424213395e+135*cos(theta)**17 - 1.842834768944e+134*cos(theta)**15 + 9.32069608569944e+132*cos(theta)**13 - 3.27041967919279e+131*cos(theta)**11 + 7.60241261012693e+129*cos(theta)**9 - 1.09256229127573e+128*cos(theta)**7 + 8.6908364078751e+125*cos(theta)**5 - 3.13635381013176e+123*cos(theta)**3 + 3.24674307467056e+120*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl98_m_minus_60(theta, phi):
    return 9.40662534557122e-118*(1.0 - cos(theta)**2)**30*(3.25121467505561e+137*cos(theta)**38 - 1.17210457259697e+138*cos(theta)**36 + 1.91302041641475e+138*cos(theta)**34 - 1.87295716162072e+138*cos(theta)**32 + 1.22881845524322e+138*cos(theta)**30 - 5.71696286663959e+137*cos(theta)**28 + 1.94685762485565e+137*cos(theta)**26 - 4.93933433316225e+136*cos(theta)**24 + 9.41475328696673e+135*cos(theta)**22 - 1.34997393500268e+135*cos(theta)**20 + 1.44912456299722e+134*cos(theta)**18 - 1.15177173059e+133*cos(theta)**16 + 6.65764006121389e+131*cos(theta)**14 - 2.72534973266066e+130*cos(theta)**12 + 7.60241261012693e+128*cos(theta)**10 - 1.36570286409466e+127*cos(theta)**8 + 1.44847273464585e+125*cos(theta)**6 - 7.84088452532939e+122*cos(theta)**4 + 1.62337153733528e+120*cos(theta)**2 - 5.37362309611148e+116)*sin(60*phi)

#@torch.jit.script
def Yl98_m_minus_59(theta, phi):
    return 7.38405110772638e-116*(1.0 - cos(theta)**2)**29.5*(8.33644788475797e+135*cos(theta)**39 - 3.16785019620803e+136*cos(theta)**37 + 5.46577261832784e+136*cos(theta)**35 - 5.67562776248703e+136*cos(theta)**33 + 3.96393050078459e+136*cos(theta)**31 - 1.97136650573779e+136*cos(theta)**29 + 7.21058379576165e+135*cos(theta)**27 - 1.9757337332649e+135*cos(theta)**25 + 4.09337099433336e+134*cos(theta)**23 - 6.42844730953656e+133*cos(theta)**21 + 7.62697138419592e+132*cos(theta)**19 - 6.77512782700001e+131*cos(theta)**17 + 4.43842670747592e+130*cos(theta)**15 - 2.09642287127743e+129*cos(theta)**13 + 6.91128419102448e+127*cos(theta)**11 - 1.51744762677184e+126*cos(theta)**9 + 2.06924676377979e+124*cos(theta)**7 - 1.56817690506588e+122*cos(theta)**5 + 5.41123845778426e+119*cos(theta)**3 - 5.37362309611148e+116*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl98_m_minus_58(theta, phi):
    return 5.85159844471846e-114*(1.0 - cos(theta)**2)**29*(2.08411197118949e+134*cos(theta)**40 - 8.33644788475797e+134*cos(theta)**38 + 1.51827017175773e+135*cos(theta)**36 - 1.66930228308442e+135*cos(theta)**34 + 1.23872828149518e+135*cos(theta)**32 - 6.57122168579264e+134*cos(theta)**30 + 2.5752084984863e+134*cos(theta)**28 - 7.5989758971727e+133*cos(theta)**26 + 1.7055712476389e+133*cos(theta)**24 - 2.9220215043348e+132*cos(theta)**22 + 3.81348569209796e+131*cos(theta)**20 - 3.7639599038889e+130*cos(theta)**18 + 2.77401669217245e+129*cos(theta)**16 - 1.4974449080553e+128*cos(theta)**14 + 5.7594034925204e+126*cos(theta)**12 - 1.51744762677184e+125*cos(theta)**10 + 2.58655845472473e+123*cos(theta)**8 - 2.6136281751098e+121*cos(theta)**6 + 1.35280961444607e+119*cos(theta)**4 - 2.68681154805574e+116*cos(theta)**2 + 8.55672467533675e+112)*sin(58*phi)

#@torch.jit.script
def Yl98_m_minus_57(theta, phi):
    return 4.67981562751407e-112*(1.0 - cos(theta)**2)**28.5*(5.08319992973047e+132*cos(theta)**41 - 2.13755073968153e+133*cos(theta)**39 + 4.10343289664252e+133*cos(theta)**37 - 4.76943509452691e+133*cos(theta)**35 + 3.75372206513692e+133*cos(theta)**33 - 2.11974893090085e+133*cos(theta)**31 + 8.88002930512519e+132*cos(theta)**29 - 2.81443551747137e+132*cos(theta)**27 + 6.8222849905556e+131*cos(theta)**25 - 1.27044413231948e+131*cos(theta)**23 + 1.8159455676657e+130*cos(theta)**21 - 1.98103152836258e+129*cos(theta)**19 + 1.63177452480732e+128*cos(theta)**17 - 9.98296605370203e+126*cos(theta)**15 + 4.43031037886185e+125*cos(theta)**13 - 1.37949784251986e+124*cos(theta)**11 + 2.87395383858304e+122*cos(theta)**9 - 3.73375453587114e+120*cos(theta)**7 + 2.70561922889213e+118*cos(theta)**5 - 8.95603849351913e+115*cos(theta)**3 + 8.55672467533675e+112*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl98_m_minus_56(theta, phi):
    return 3.77588916338903e-110*(1.0 - cos(theta)**2)**28*(1.21028569755487e+131*cos(theta)**42 - 5.34387684920383e+131*cos(theta)**40 + 1.07985076227435e+132*cos(theta)**38 - 1.32484308181303e+132*cos(theta)**36 + 1.10403590151086e+132*cos(theta)**34 - 6.62421540906516e+131*cos(theta)**32 + 2.96000976837506e+131*cos(theta)**30 - 1.00515554195406e+131*cos(theta)**28 + 2.62395576559831e+130*cos(theta)**26 - 5.29351721799783e+129*cos(theta)**24 + 8.25429803484407e+128*cos(theta)**22 - 9.90515764181288e+127*cos(theta)**20 + 9.06541402670736e+126*cos(theta)**18 - 6.23935378356377e+125*cos(theta)**16 + 3.16450741347275e+124*cos(theta)**14 - 1.14958153543321e+123*cos(theta)**12 + 2.87395383858304e+121*cos(theta)**10 - 4.66719316983892e+119*cos(theta)**8 + 4.50936538148688e+117*cos(theta)**6 - 2.23900962337978e+115*cos(theta)**4 + 4.27836233766838e+112*cos(theta)**2 - 1.31439703154174e+109)*sin(56*phi)

#@torch.jit.script
def Yl98_m_minus_55(theta, phi):
    return 3.07265518220226e-108*(1.0 - cos(theta)**2)**27.5*(2.8146179012904e+129*cos(theta)**43 - 1.30338459736679e+130*cos(theta)**41 + 2.76884810839577e+130*cos(theta)**39 - 3.58065697787306e+130*cos(theta)**37 + 3.15438829003103e+130*cos(theta)**35 - 2.00733800274702e+130*cos(theta)**33 + 9.54841860766149e+129*cos(theta)**31 - 3.46605359294504e+129*cos(theta)**29 + 9.71835468740114e+128*cos(theta)**27 - 2.11740688719913e+128*cos(theta)**25 + 3.5888252325409e+127*cos(theta)**23 - 4.71674173419661e+126*cos(theta)**21 + 4.77127054037229e+125*cos(theta)**19 - 3.67020810797869e+124*cos(theta)**17 + 2.10967160898183e+123*cos(theta)**15 - 8.8429348879478e+121*cos(theta)**13 + 2.61268530780276e+120*cos(theta)**11 - 5.18577018870992e+118*cos(theta)**9 + 6.44195054498126e+116*cos(theta)**7 - 4.47801924675957e+114*cos(theta)**5 + 1.42612077922279e+112*cos(theta)**3 - 1.31439703154174e+109*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl98_m_minus_54(theta, phi):
    return 2.52107566003453e-106*(1.0 - cos(theta)**2)**27*(6.3968588665691e+127*cos(theta)**44 - 3.10329666039711e+128*cos(theta)**42 + 6.92212027098941e+128*cos(theta)**40 - 9.42278152071857e+128*cos(theta)**38 + 8.76218969453063e+128*cos(theta)**36 - 5.90393530219711e+128*cos(theta)**34 + 2.98388081489422e+128*cos(theta)**32 - 1.15535119764835e+128*cos(theta)**30 + 3.47084095978612e+127*cos(theta)**28 - 8.14387264307358e+126*cos(theta)**26 + 1.49534384689204e+126*cos(theta)**24 - 2.14397351554391e+125*cos(theta)**22 + 2.38563527018615e+124*cos(theta)**20 - 2.0390045044326e+123*cos(theta)**18 + 1.31854475561365e+122*cos(theta)**16 - 6.31638206281986e+120*cos(theta)**14 + 2.1772377565023e+119*cos(theta)**12 - 5.18577018870992e+117*cos(theta)**10 + 8.05243818122658e+115*cos(theta)**8 - 7.46336541126594e+113*cos(theta)**6 + 3.56530194805698e+111*cos(theta)**4 - 6.57198515770872e+108*cos(theta)**2 + 1.95246142534424e+105)*sin(54*phi)

#@torch.jit.script
def Yl98_m_minus_53(theta, phi):
    return 2.08503778833744e-104*(1.0 - cos(theta)**2)**26.5*(1.42152419257091e+126*cos(theta)**45 - 7.2169689776677e+126*cos(theta)**43 + 1.68832201731449e+127*cos(theta)**41 - 2.41609782582528e+127*cos(theta)**39 + 2.36815937690017e+127*cos(theta)**37 - 1.6868386577706e+127*cos(theta)**35 + 9.04206307543702e+126*cos(theta)**33 - 3.72693934725273e+126*cos(theta)**31 + 1.19684171027108e+126*cos(theta)**29 - 3.01624912706429e+125*cos(theta)**27 + 5.98137538756817e+124*cos(theta)**25 - 9.32162398062571e+123*cos(theta)**23 + 1.13601679532674e+123*cos(theta)**21 - 1.07316026549084e+122*cos(theta)**19 + 7.75614562125674e+120*cos(theta)**17 - 4.21092137521324e+119*cos(theta)**15 + 1.67479827423254e+118*cos(theta)**13 - 4.71433653519083e+116*cos(theta)**11 + 8.9471535346962e+114*cos(theta)**9 - 1.06619505875228e+113*cos(theta)**7 + 7.13060389611396e+110*cos(theta)**5 - 2.19066171923624e+108*cos(theta)**3 + 1.95246142534424e+105*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl98_m_minus_52(theta, phi):
    return 1.73772608291153e-102*(1.0 - cos(theta)**2)**26*(3.09026998384981e+124*cos(theta)**46 - 1.64022022219721e+125*cos(theta)**44 + 4.01981432693926e+125*cos(theta)**42 - 6.04024456456319e+125*cos(theta)**40 + 6.23199836026361e+125*cos(theta)**38 - 4.68566293825168e+125*cos(theta)**36 + 2.659430316305e+125*cos(theta)**34 - 1.16466854601648e+125*cos(theta)**32 + 3.98947236757025e+124*cos(theta)**30 - 1.07723183109439e+124*cos(theta)**28 + 2.30052899521853e+123*cos(theta)**26 - 3.88400999192738e+122*cos(theta)**24 + 5.16371270603062e+121*cos(theta)**22 - 5.36580132745422e+120*cos(theta)**20 + 4.30896978958708e+119*cos(theta)**18 - 2.63182585950827e+118*cos(theta)**16 + 1.19628448159467e+117*cos(theta)**14 - 3.92861377932569e+115*cos(theta)**12 + 8.9471535346962e+113*cos(theta)**10 - 1.33274382344035e+112*cos(theta)**8 + 1.18843398268566e+110*cos(theta)**6 - 5.4766542980906e+107*cos(theta)**4 + 9.76230712672121e+104*cos(theta)**2 - 2.81091480757881e+101)*sin(52*phi)

#@torch.jit.script
def Yl98_m_minus_51(theta, phi):
    return 1.45906916119761e-100*(1.0 - cos(theta)**2)**25.5*(6.57504251882938e+122*cos(theta)**47 - 3.6449338271049e+123*cos(theta)**45 + 9.34840541148666e+123*cos(theta)**43 - 1.47323038160078e+124*cos(theta)**41 + 1.59794829750349e+124*cos(theta)**39 - 1.26639538871667e+124*cos(theta)**37 + 7.59837233230001e+123*cos(theta)**35 - 3.52929862429236e+123*cos(theta)**33 + 1.28692657018395e+123*cos(theta)**31 - 3.71459252101513e+122*cos(theta)**29 + 8.52047776006861e+121*cos(theta)**27 - 1.55360399677095e+121*cos(theta)**25 + 2.24509248088288e+120*cos(theta)**23 - 2.55514348926392e+119*cos(theta)**21 + 2.26787883662478e+118*cos(theta)**19 - 1.54813285853428e+117*cos(theta)**17 + 7.9752298772978e+115*cos(theta)**15 - 3.0220105994813e+114*cos(theta)**13 + 8.13377594063291e+112*cos(theta)**11 - 1.48082647048927e+111*cos(theta)**9 + 1.69776283240809e+109*cos(theta)**7 - 1.09533085961812e+107*cos(theta)**5 + 3.25410237557374e+104*cos(theta)**3 - 2.81091480757881e+101*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl98_m_minus_50(theta, phi):
    return 1.23392746579016e-98*(1.0 - cos(theta)**2)**25*(1.36980052475612e+121*cos(theta)**48 - 7.92376918935848e+121*cos(theta)**46 + 2.1246375935197e+122*cos(theta)**44 - 3.50769138476376e+122*cos(theta)**42 + 3.99487074375872e+122*cos(theta)**40 - 3.33261944399123e+122*cos(theta)**38 + 2.11065898119445e+122*cos(theta)**36 - 1.03802900714481e+122*cos(theta)**34 + 4.02164553182485e+121*cos(theta)**32 - 1.23819750700504e+121*cos(theta)**30 + 3.04302777145308e+120*cos(theta)**28 - 5.97539998758059e+119*cos(theta)**26 + 9.35455200367866e+118*cos(theta)**24 - 1.16142885875633e+118*cos(theta)**22 + 1.13393941831239e+117*cos(theta)**20 - 8.60073810296822e+115*cos(theta)**18 + 4.98451867331113e+114*cos(theta)**16 - 2.1585789996295e+113*cos(theta)**14 + 6.77814661719409e+111*cos(theta)**12 - 1.48082647048927e+110*cos(theta)**10 + 2.12220354051011e+108*cos(theta)**8 - 1.82555143269687e+106*cos(theta)**6 + 8.13525593893434e+103*cos(theta)**4 - 1.40545740378941e+101*cos(theta)**2 + 3.93025001059677e+97)*sin(50*phi)

#@torch.jit.script
def Yl98_m_minus_49(theta, phi):
    return 1.05079628556199e-96*(1.0 - cos(theta)**2)**24.5*(2.79551127501249e+119*cos(theta)**49 - 1.68590833816138e+120*cos(theta)**47 + 4.72141687448821e+120*cos(theta)**45 - 8.15742182503199e+120*cos(theta)**43 + 9.74358717989932e+120*cos(theta)**41 - 8.54517806151598e+120*cos(theta)**39 + 5.70448373295797e+120*cos(theta)**37 - 2.96579716327089e+120*cos(theta)**35 + 1.21868046418935e+120*cos(theta)**33 - 3.99418550646789e+119*cos(theta)**31 + 1.04931992119072e+119*cos(theta)**29 - 2.21311110651133e+118*cos(theta)**27 + 3.74182080147147e+117*cos(theta)**25 - 5.04969069024489e+116*cos(theta)**23 + 5.39971151577328e+115*cos(theta)**21 - 4.52670426472011e+114*cos(theta)**19 + 2.93206980783007e+113*cos(theta)**17 - 1.43905266641967e+112*cos(theta)**15 + 5.21395893630315e+110*cos(theta)**13 - 1.34620588226298e+109*cos(theta)**11 + 2.35800393390012e+107*cos(theta)**9 - 2.60793061813838e+105*cos(theta)**7 + 1.62705118778687e+103*cos(theta)**5 - 4.68485801263135e+100*cos(theta)**3 + 3.93025001059677e+97*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl98_m_minus_48(theta, phi):
    return 9.00870153133566e-95*(1.0 - cos(theta)**2)**24*(5.59102255002498e+117*cos(theta)**50 - 3.51230903783621e+118*cos(theta)**48 + 1.02639497271483e+119*cos(theta)**46 - 1.85395950568909e+119*cos(theta)**44 + 2.31990170949984e+119*cos(theta)**42 - 2.136294515379e+119*cos(theta)**40 + 1.50117992972578e+119*cos(theta)**38 - 8.23832545353024e+118*cos(theta)**36 + 3.58435430643926e+118*cos(theta)**34 - 1.24818297077121e+118*cos(theta)**32 + 3.49773307063572e+117*cos(theta)**30 - 7.90396823754046e+116*cos(theta)**28 + 1.43916184671979e+116*cos(theta)**26 - 2.10403778760204e+115*cos(theta)**24 + 2.45441432535149e+114*cos(theta)**22 - 2.26335213236006e+113*cos(theta)**20 + 1.62892767101671e+112*cos(theta)**18 - 8.99407916512293e+110*cos(theta)**16 + 3.72425638307368e+109*cos(theta)**14 - 1.12183823521915e+108*cos(theta)**12 + 2.35800393390012e+106*cos(theta)**10 - 3.25991327267298e+104*cos(theta)**8 + 2.71175197964478e+102*cos(theta)**6 - 1.17121450315784e+100*cos(theta)**4 + 1.96512500529839e+97*cos(theta)**2 - 5.347278925982e+93)*sin(48*phi)

#@torch.jit.script
def Yl98_m_minus_47(theta, phi):
    return 7.77362729122006e-93*(1.0 - cos(theta)**2)**23.5*(1.09627893137745e+116*cos(theta)**51 - 7.16797762823715e+116*cos(theta)**49 + 2.18381909088261e+117*cos(theta)**47 - 4.11991001264242e+117*cos(theta)**45 + 5.39512025465079e+117*cos(theta)**43 - 5.21047442775365e+117*cos(theta)**41 + 3.84917930698918e+117*cos(theta)**39 - 2.22657444690007e+117*cos(theta)**37 + 1.02410123041122e+117*cos(theta)**35 - 3.78237263870065e+116*cos(theta)**33 + 1.12830099052765e+116*cos(theta)**31 - 2.72550628880705e+115*cos(theta)**29 + 5.33022906192516e+114*cos(theta)**27 - 8.41615115040815e+113*cos(theta)**25 + 1.0671366631963e+113*cos(theta)**23 - 1.07778672969527e+112*cos(theta)**21 + 8.57330353166688e+110*cos(theta)**19 - 5.29063480301349e+109*cos(theta)**17 + 2.48283758871578e+108*cos(theta)**15 - 8.62952488630113e+106*cos(theta)**13 + 2.1436399399092e+105*cos(theta)**11 - 3.62212585852553e+103*cos(theta)**9 + 3.87393139949254e+101*cos(theta)**7 - 2.34242900631568e+99*cos(theta)**5 + 6.55041668432795e+96*cos(theta)**3 - 5.347278925982e+93*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl98_m_minus_46(theta, phi):
    return 6.75008726403979e-91*(1.0 - cos(theta)**2)**23*(2.1082287141874e+114*cos(theta)**52 - 1.43359552564743e+115*cos(theta)**50 + 4.54962310600545e+115*cos(theta)**48 - 8.95632611444004e+115*cos(theta)**46 + 1.22616369423882e+116*cos(theta)**44 - 1.24058914946515e+116*cos(theta)**42 + 9.62294826747296e+115*cos(theta)**40 - 5.8594064392107e+115*cos(theta)**38 + 2.84472564003116e+115*cos(theta)**36 - 1.11246254079431e+115*cos(theta)**34 + 3.52594059539891e+114*cos(theta)**32 - 9.08502096269018e+113*cos(theta)**30 + 1.90365323640184e+113*cos(theta)**28 - 3.23698121169544e+112*cos(theta)**26 + 4.44640276331792e+111*cos(theta)**24 - 4.89903058952393e+110*cos(theta)**22 + 4.28665176583344e+109*cos(theta)**20 - 2.93924155722971e+108*cos(theta)**18 + 1.55177349294736e+107*cos(theta)**16 - 6.16394634735795e+105*cos(theta)**14 + 1.786366616591e+104*cos(theta)**12 - 3.62212585852553e+102*cos(theta)**10 + 4.84241424936568e+100*cos(theta)**8 - 3.90404834385946e+98*cos(theta)**6 + 1.63760417108199e+96*cos(theta)**4 - 2.673639462991e+93*cos(theta)**2 + 7.09188186469761e+89)*sin(46*phi)

#@torch.jit.script
def Yl98_m_minus_45(theta, phi):
    return 5.89696524533311e-89*(1.0 - cos(theta)**2)**22.5*(3.97779002676868e+112*cos(theta)**53 - 2.81097161891653e+113*cos(theta)**51 + 9.28494511429683e+113*cos(theta)**49 - 1.90560130094469e+114*cos(theta)**47 + 2.72480820941959e+114*cos(theta)**45 - 2.8850910452678e+114*cos(theta)**43 + 2.34706055304218e+114*cos(theta)**41 - 1.50241190748992e+114*cos(theta)**39 + 7.6884476757599e+113*cos(theta)**37 - 3.17846440226945e+113*cos(theta)**35 + 1.06846684709058e+113*cos(theta)**33 - 2.93065192344845e+112*cos(theta)**31 + 6.56432150483395e+111*cos(theta)**29 - 1.19888193025757e+111*cos(theta)**27 + 1.77856110532717e+110*cos(theta)**25 - 2.13001329979301e+109*cos(theta)**23 + 2.04126274563497e+108*cos(theta)**21 - 1.54696924064722e+107*cos(theta)**19 + 9.12807937027862e+105*cos(theta)**17 - 4.1092975649053e+104*cos(theta)**15 + 1.37412816660846e+103*cos(theta)**13 - 3.29284168956866e+101*cos(theta)**11 + 5.38046027707298e+99*cos(theta)**9 - 5.57721191979923e+97*cos(theta)**7 + 3.27520834216398e+95*cos(theta)**5 - 8.91213154330334e+92*cos(theta)**3 + 7.09188186469761e+89*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl98_m_minus_44(theta, phi):
    return 5.1819529666549e-87*(1.0 - cos(theta)**2)**22*(7.3662778273494e+110*cos(theta)**54 - 5.40571465176256e+111*cos(theta)**52 + 1.85698902285937e+112*cos(theta)**50 - 3.97000271030144e+112*cos(theta)**48 + 5.92349610743389e+112*cos(theta)**46 - 6.55702510288137e+112*cos(theta)**44 + 5.5882394120052e+112*cos(theta)**42 - 3.75602976872481e+112*cos(theta)**40 + 2.02327570414734e+112*cos(theta)**38 - 8.82906778408182e+111*cos(theta)**36 + 3.14254955026641e+111*cos(theta)**34 - 9.15828726077639e+110*cos(theta)**32 + 2.18810716827798e+110*cos(theta)**30 - 4.28172117949133e+109*cos(theta)**28 + 6.84061963587372e+108*cos(theta)**26 - 8.87505541580423e+107*cos(theta)**24 + 9.27846702561351e+106*cos(theta)**22 - 7.73484620323609e+105*cos(theta)**20 + 5.07115520571034e+104*cos(theta)**18 - 2.56831097806581e+103*cos(theta)**16 + 9.81520119006043e+101*cos(theta)**14 - 2.74403474130722e+100*cos(theta)**12 + 5.38046027707298e+98*cos(theta)**10 - 6.97151489974903e+96*cos(theta)**8 + 5.45868057027329e+94*cos(theta)**6 - 2.22803288582583e+92*cos(theta)**4 + 3.54594093234881e+89*cos(theta)**2 - 9.18399619877961e+85)*sin(44*phi)

#@torch.jit.script
def Yl98_m_minus_43(theta, phi):
    return 4.5795097056863e-85*(1.0 - cos(theta)**2)**21.5*(1.33932324133625e+109*cos(theta)**55 - 1.01994616070992e+110*cos(theta)**53 + 3.64115494678307e+110*cos(theta)**51 - 8.10204634755396e+110*cos(theta)**49 + 1.26031832073062e+111*cos(theta)**47 - 1.45711668952919e+111*cos(theta)**45 + 1.29959056093144e+111*cos(theta)**43 - 9.16104821640197e+110*cos(theta)**41 + 5.18788642089062e+110*cos(theta)**39 - 2.38623453623833e+110*cos(theta)**37 + 8.97871300076117e+109*cos(theta)**35 - 2.77523856387163e+109*cos(theta)**33 + 7.05841022025156e+108*cos(theta)**31 - 1.47645557913494e+108*cos(theta)**29 + 2.53356282810138e+107*cos(theta)**27 - 3.55002216632169e+106*cos(theta)**25 + 4.03411609809283e+105*cos(theta)**23 - 3.68326009677909e+104*cos(theta)**21 + 2.66902905563702e+103*cos(theta)**19 - 1.51077116356813e+102*cos(theta)**17 + 6.54346746004029e+100*cos(theta)**15 - 2.11079595485171e+99*cos(theta)**13 + 4.8913275246118e+97*cos(theta)**11 - 7.74612766638782e+95*cos(theta)**9 + 7.79811510039042e+93*cos(theta)**7 - 4.45606577165167e+91*cos(theta)**5 + 1.18198031078294e+89*cos(theta)**3 - 9.18399619877961e+85*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl98_m_minus_42(theta, phi):
    return 4.06932665934764e-83*(1.0 - cos(theta)**2)**21*(2.39164864524331e+107*cos(theta)**56 - 1.88878918649985e+108*cos(theta)**54 + 7.00222105150591e+108*cos(theta)**52 - 1.62040926951079e+109*cos(theta)**50 + 2.62566316818878e+109*cos(theta)**48 - 3.16764497723738e+109*cos(theta)**46 + 2.95361491120782e+109*cos(theta)**44 - 2.18120195628618e+109*cos(theta)**42 + 1.29697160522265e+109*cos(theta)**40 - 6.27956456904823e+108*cos(theta)**38 + 2.49408694465588e+108*cos(theta)**36 - 8.16246636432834e+107*cos(theta)**34 + 2.20575319382861e+107*cos(theta)**32 - 4.92151859711647e+106*cos(theta)**30 + 9.04843867179063e+105*cos(theta)**28 - 1.36539314089296e+105*cos(theta)**26 + 1.68088170753868e+104*cos(theta)**24 - 1.67420913489959e+103*cos(theta)**22 + 1.33451452781851e+102*cos(theta)**20 - 8.39317313093403e+100*cos(theta)**18 + 4.08966716252518e+99*cos(theta)**16 - 1.50771139632265e+98*cos(theta)**14 + 4.07610627050983e+96*cos(theta)**12 - 7.74612766638782e+94*cos(theta)**10 + 9.74764387548802e+92*cos(theta)**8 - 7.42677628608611e+90*cos(theta)**6 + 2.95495077695734e+88*cos(theta)**4 - 4.59199809938981e+85*cos(theta)**2 + 1.163120085965e+82)*sin(42*phi)

#@torch.jit.script
def Yl98_m_minus_41(theta, phi):
    return 3.63516392057649e-81*(1.0 - cos(theta)**2)**20.5*(4.19587481621634e+105*cos(theta)**57 - 3.43416215727245e+106*cos(theta)**55 + 1.321173783303e+107*cos(theta)**53 - 3.17727307747214e+107*cos(theta)**51 + 5.35849626160976e+107*cos(theta)**49 - 6.73967016433484e+107*cos(theta)**47 + 6.56358869157294e+107*cos(theta)**45 - 5.07256268903764e+107*cos(theta)**43 + 3.16334537859184e+107*cos(theta)**41 - 1.61014476129442e+107*cos(theta)**39 + 6.74077552609697e+106*cos(theta)**37 - 2.33213324695095e+106*cos(theta)**35 + 6.68410058735943e+105*cos(theta)**33 - 1.58758664423112e+105*cos(theta)**31 + 3.1201512661347e+104*cos(theta)**29 - 5.05701163293688e+103*cos(theta)**27 + 6.72352683015472e+102*cos(theta)**25 - 7.27917015173733e+101*cos(theta)**23 + 6.35483108485005e+100*cos(theta)**21 - 4.41745954259686e+99*cos(theta)**19 + 2.40568656619128e+98*cos(theta)**17 - 1.00514093088176e+97*cos(theta)**15 + 3.13546636193064e+95*cos(theta)**13 - 7.04193424217074e+93*cos(theta)**11 + 1.08307154172089e+92*cos(theta)**9 - 1.06096804086944e+90*cos(theta)**7 + 5.90990155391468e+87*cos(theta)**5 - 1.53066603312994e+85*cos(theta)**3 + 1.163120085965e+82*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl98_m_minus_40(theta, phi):
    return 3.26396427175474e-79*(1.0 - cos(theta)**2)**20*(7.23426692451092e+103*cos(theta)**58 - 6.1324324237008e+104*cos(theta)**56 + 2.44661811722778e+105*cos(theta)**54 - 6.11014053360027e+105*cos(theta)**52 + 1.07169925232195e+106*cos(theta)**50 - 1.40409795090309e+106*cos(theta)**48 + 1.42686710686368e+106*cos(theta)**46 - 1.15285515659946e+106*cos(theta)**44 + 7.53177471093295e+105*cos(theta)**42 - 4.02536190323605e+105*cos(theta)**40 + 1.77388829634131e+105*cos(theta)**38 - 6.47814790819709e+104*cos(theta)**36 + 1.96591193745866e+104*cos(theta)**34 - 4.96120826322225e+103*cos(theta)**32 + 1.0400504220449e+103*cos(theta)**30 - 1.80607558319174e+102*cos(theta)**28 + 2.58597185775181e+101*cos(theta)**26 - 3.03298756322389e+100*cos(theta)**24 + 2.88855958402275e+99*cos(theta)**22 - 2.20872977129843e+98*cos(theta)**20 + 1.33649253677294e+97*cos(theta)**18 - 6.28213081801103e+95*cos(theta)**16 + 2.23961882995046e+94*cos(theta)**14 - 5.86827853514228e+92*cos(theta)**12 + 1.08307154172089e+91*cos(theta)**10 - 1.32621005108681e+89*cos(theta)**8 + 9.84983592319113e+86*cos(theta)**6 - 3.82666508282484e+84*cos(theta)**4 + 5.81560042982498e+81*cos(theta)**2 - 1.4427190349355e+78)*sin(40*phi)

#@torch.jit.script
def Yl98_m_minus_39(theta, phi):
    return 2.94517391424152e-77*(1.0 - cos(theta)**2)**19.5*(1.22614693635778e+102*cos(theta)**59 - 1.07586533749137e+103*cos(theta)**57 + 4.44839657677778e+103*cos(theta)**55 - 1.15285670445288e+104*cos(theta)**53 + 2.10137108298422e+104*cos(theta)**51 - 2.86550602225121e+104*cos(theta)**49 + 3.03588746141209e+104*cos(theta)**47 - 2.56190034799881e+104*cos(theta)**45 + 1.75157551417045e+104*cos(theta)**43 - 9.81795586155133e+103*cos(theta)**41 + 4.54843152908028e+103*cos(theta)**39 - 1.75085078599921e+103*cos(theta)**37 + 5.61689124988187e+102*cos(theta)**35 - 1.50339644340068e+102*cos(theta)**33 + 3.35500136143516e+101*cos(theta)**31 - 6.22784683859222e+100*cos(theta)**29 + 9.57767354722894e+99*cos(theta)**27 - 1.21319502528956e+99*cos(theta)**25 + 1.25589547131424e+98*cos(theta)**23 - 1.05177608157068e+97*cos(theta)**21 + 7.03417124617334e+95*cos(theta)**19 - 3.69537106941825e+94*cos(theta)**17 + 1.49307921996697e+93*cos(theta)**15 - 4.51406041164791e+91*cos(theta)**13 + 9.84610492473538e+89*cos(theta)**11 - 1.47356672342978e+88*cos(theta)**9 + 1.40711941759873e+86*cos(theta)**7 - 7.65333016564967e+83*cos(theta)**5 + 1.93853347660833e+81*cos(theta)**3 - 1.4427190349355e+78*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl98_m_minus_38(theta, phi):
    return 2.6702188289681e-75*(1.0 - cos(theta)**2)**19*(2.04357822726297e+100*cos(theta)**60 - 1.85494023705408e+101*cos(theta)**58 + 7.94356531567461e+101*cos(theta)**56 - 2.13491982306089e+102*cos(theta)**54 + 4.04109823650811e+102*cos(theta)**52 - 5.73101204450242e+102*cos(theta)**50 + 6.32476554460852e+102*cos(theta)**48 - 5.5693485826061e+102*cos(theta)**46 + 3.98085344129649e+102*cos(theta)**44 - 2.3376085384646e+102*cos(theta)**42 + 1.13710788227007e+102*cos(theta)**40 - 4.60750206841898e+101*cos(theta)**38 + 1.56024756941163e+101*cos(theta)**36 - 4.42175424529612e+100*cos(theta)**34 + 1.04843792544849e+100*cos(theta)**32 - 2.07594894619741e+99*cos(theta)**30 + 3.42059769543891e+98*cos(theta)**28 - 4.66613471265214e+97*cos(theta)**26 + 5.23289779714267e+96*cos(theta)**24 - 4.78080037077582e+95*cos(theta)**22 + 3.51708562308667e+94*cos(theta)**20 - 2.05298392745459e+93*cos(theta)**18 + 9.33174512479357e+91*cos(theta)**16 - 3.22432886546279e+90*cos(theta)**14 + 8.20508743727948e+88*cos(theta)**12 - 1.47356672342978e+87*cos(theta)**10 + 1.75889927199842e+85*cos(theta)**8 - 1.27555502760828e+83*cos(theta)**6 + 4.84633369152082e+80*cos(theta)**4 - 7.21359517467748e+77*cos(theta)**2 + 1.75513264590693e+74)*sin(38*phi)

#@torch.jit.script
def Yl98_m_minus_37(theta, phi):
    return 2.43209886847967e-73*(1.0 - cos(theta)**2)**18.5*(3.35012824141471e+98*cos(theta)**61 - 3.1439665034815e+99*cos(theta)**59 + 1.39360795011835e+100*cos(theta)**57 - 3.88167240556525e+100*cos(theta)**55 + 7.62471365378889e+100*cos(theta)**53 - 1.12372785186322e+101*cos(theta)**51 + 1.29076847849154e+101*cos(theta)**49 - 1.18496778353321e+101*cos(theta)**47 + 8.84634098065886e+100*cos(theta)**45 - 5.43629892666187e+100*cos(theta)**43 + 2.77343385919529e+100*cos(theta)**41 - 1.1814107867741e+100*cos(theta)**39 + 4.21688532273414e+99*cos(theta)**37 - 1.26335835579889e+99*cos(theta)**35 + 3.17708462257118e+98*cos(theta)**33 - 6.6966095038626e+97*cos(theta)**31 + 1.17951644670307e+97*cos(theta)**29 - 1.72819804172301e+96*cos(theta)**27 + 2.09315911885707e+95*cos(theta)**25 - 2.07860885685905e+94*cos(theta)**23 + 1.67480267766032e+93*cos(theta)**21 - 1.08051785655504e+92*cos(theta)**19 + 5.48926183811386e+90*cos(theta)**17 - 2.1495525769752e+89*cos(theta)**15 + 6.31160572098422e+87*cos(theta)**13 - 1.3396061122089e+86*cos(theta)**11 + 1.95433252444268e+84*cos(theta)**9 - 1.82222146801183e+82*cos(theta)**7 + 9.69266738304164e+79*cos(theta)**5 - 2.40453172489249e+77*cos(theta)**3 + 1.75513264590693e+74*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl98_m_minus_36(theta, phi):
    return 2.22507141601619e-71*(1.0 - cos(theta)**2)**18*(5.40343264744308e+96*cos(theta)**62 - 5.23994417246916e+97*cos(theta)**60 + 2.40277232779026e+98*cos(theta)**58 - 6.93155786708081e+98*cos(theta)**56 + 1.41198400996091e+99*cos(theta)**54 - 2.16101509973696e+99*cos(theta)**52 + 2.58153695698307e+99*cos(theta)**50 - 2.46868288236086e+99*cos(theta)**48 + 1.92311760449106e+99*cos(theta)**46 - 1.23552248333224e+99*cos(theta)**44 + 6.60341395046498e+98*cos(theta)**42 - 2.95352696693525e+98*cos(theta)**40 + 1.1097066638774e+98*cos(theta)**38 - 3.50932876610803e+97*cos(theta)**36 + 9.34436653697405e+96*cos(theta)**34 - 2.09269046995706e+96*cos(theta)**32 + 3.93172148901024e+95*cos(theta)**30 - 6.17213586329648e+94*cos(theta)**28 + 8.0506119956041e+93*cos(theta)**26 - 8.66087023691272e+92*cos(theta)**24 + 7.61273944391054e+91*cos(theta)**22 - 5.40258928277522e+90*cos(theta)**20 + 3.04958991006326e+89*cos(theta)**18 - 1.3434703606095e+88*cos(theta)**16 + 4.50828980070301e+86*cos(theta)**14 - 1.11633842684075e+85*cos(theta)**12 + 1.95433252444268e+83*cos(theta)**10 - 2.27777683501478e+81*cos(theta)**8 + 1.61544456384027e+79*cos(theta)**6 - 6.01132931223123e+76*cos(theta)**4 + 8.77566322953464e+73*cos(theta)**2 - 2.09693267133444e+70)*sin(36*phi)

#@torch.jit.script
def Yl98_m_minus_35(theta, phi):
    return 2.04440356024428e-69*(1.0 - cos(theta)**2)**17.5*(8.57687721816362e+94*cos(theta)**63 - 8.59007241388387e+95*cos(theta)**61 + 4.07249547083095e+96*cos(theta)**59 - 1.21606278369839e+97*cos(theta)**57 + 2.56724365447437e+97*cos(theta)**55 - 4.07738698063577e+97*cos(theta)**53 + 5.06183717055504e+97*cos(theta)**51 - 5.03812833134869e+97*cos(theta)**49 + 4.09173958402352e+97*cos(theta)**47 - 2.7456055185161e+97*cos(theta)**45 + 1.53567766289883e+97*cos(theta)**43 - 7.20372430959816e+96*cos(theta)**41 + 2.84540170224976e+96*cos(theta)**39 - 9.48467234083252e+95*cos(theta)**37 + 2.66981901056401e+95*cos(theta)**35 - 6.34148627259716e+94*cos(theta)**33 + 1.26829725451943e+94*cos(theta)**31 - 2.12832271148154e+93*cos(theta)**29 + 2.98170814652004e+92*cos(theta)**27 - 3.46434809476509e+91*cos(theta)**25 + 3.30988671474371e+90*cos(theta)**23 - 2.5726615632263e+89*cos(theta)**21 + 1.60504732108593e+88*cos(theta)**19 - 7.90276682711469e+86*cos(theta)**17 + 3.00552653380201e+85*cos(theta)**15 - 8.58721866800574e+83*cos(theta)**13 + 1.77666593131153e+82*cos(theta)**11 - 2.53086315001643e+80*cos(theta)**9 + 2.30777794834325e+78*cos(theta)**7 - 1.20226586244625e+76*cos(theta)**5 + 2.92522107651155e+73*cos(theta)**3 - 2.09693267133444e+70*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl98_m_minus_34(theta, phi):
    return 1.8861769621828e-67*(1.0 - cos(theta)**2)**17*(1.34013706533807e+93*cos(theta)**64 - 1.38549555062643e+94*cos(theta)**62 + 6.78749245138493e+94*cos(theta)**60 - 2.09665997189377e+95*cos(theta)**58 + 4.58436366870424e+95*cos(theta)**56 - 7.55071663080698e+95*cos(theta)**54 + 9.73430225106738e+95*cos(theta)**52 - 1.00762566626974e+96*cos(theta)**50 + 8.52445746671567e+95*cos(theta)**48 - 5.96870764894803e+95*cos(theta)**46 + 3.49017650658826e+95*cos(theta)**44 - 1.71517245466623e+95*cos(theta)**42 + 7.11350425562439e+94*cos(theta)**40 - 2.49596640548224e+94*cos(theta)**38 + 7.41616391823337e+93*cos(theta)**36 - 1.86514302135211e+93*cos(theta)**34 + 3.96342892037322e+92*cos(theta)**32 - 7.09440903827181e+91*cos(theta)**30 + 1.0648957666143e+91*cos(theta)**28 - 1.33244157490965e+90*cos(theta)**26 + 1.37911946447655e+89*cos(theta)**24 - 1.16939161964832e+88*cos(theta)**22 + 8.02523660542963e+86*cos(theta)**20 - 4.39042601506372e+85*cos(theta)**18 + 1.87845408362625e+84*cos(theta)**16 - 6.1337276200041e+82*cos(theta)**14 + 1.48055494275961e+81*cos(theta)**12 - 2.53086315001643e+79*cos(theta)**10 + 2.88472243542906e+77*cos(theta)**8 - 2.00377643741041e+75*cos(theta)**6 + 7.31305269127887e+72*cos(theta)**4 - 1.04846633566722e+70*cos(theta)**2 + 2.4635017285414e+66)*sin(34*phi)

#@torch.jit.script
def Yl98_m_minus_33(theta, phi):
    return 1.74713345541493e-65*(1.0 - cos(theta)**2)**16.5*(2.06174933128933e+91*cos(theta)**65 - 2.19919928670862e+92*cos(theta)**63 + 1.11270368055491e+93*cos(theta)**61 - 3.55366096931148e+93*cos(theta)**59 + 8.04274327842849e+93*cos(theta)**57 - 1.37285756923763e+94*cos(theta)**55 + 1.83666080208819e+94*cos(theta)**53 - 1.9757366005289e+94*cos(theta)**51 + 1.73968519728891e+94*cos(theta)**49 - 1.26993779764852e+94*cos(theta)**47 + 7.75594779241835e+93*cos(theta)**45 - 3.98877315038658e+93*cos(theta)**43 + 1.73500103795717e+93*cos(theta)**41 - 6.39991386021088e+92*cos(theta)**39 + 2.00436862654956e+92*cos(theta)**37 - 5.32898006100602e+91*cos(theta)**35 + 1.20103906677976e+91*cos(theta)**33 - 2.28851904460381e+90*cos(theta)**31 + 3.67205436763551e+89*cos(theta)**29 - 4.93496879596166e+88*cos(theta)**27 + 5.51647785790619e+87*cos(theta)**25 - 5.08431138977529e+86*cos(theta)**23 + 3.82154124068077e+85*cos(theta)**21 - 2.31075053424406e+84*cos(theta)**19 + 1.10497299036839e+83*cos(theta)**17 - 4.0891517466694e+81*cos(theta)**15 + 1.13888841750739e+80*cos(theta)**13 - 2.30078468183312e+78*cos(theta)**11 + 3.20524715047673e+76*cos(theta)**9 - 2.86253776772916e+74*cos(theta)**7 + 1.46261053825577e+72*cos(theta)**5 - 3.4948877855574e+69*cos(theta)**3 + 2.4635017285414e+66*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl98_m_minus_32(theta, phi):
    return 1.62455229337705e-63*(1.0 - cos(theta)**2)**16*(3.12386262316565e+89*cos(theta)**66 - 3.43624888548222e+90*cos(theta)**64 + 1.79468335573372e+91*cos(theta)**62 - 5.9227682821858e+91*cos(theta)**60 + 1.38667987559112e+92*cos(theta)**58 - 2.45153137363863e+92*cos(theta)**56 + 3.40122370757071e+92*cos(theta)**54 - 3.79949346255558e+92*cos(theta)**52 + 3.47937039457783e+92*cos(theta)**50 - 2.64570374510108e+92*cos(theta)**48 + 1.68607560704747e+92*cos(theta)**46 - 9.06539352360586e+91*cos(theta)**44 + 4.13095485227897e+91*cos(theta)**42 - 1.59997846505272e+91*cos(theta)**40 + 5.27465428039358e+90*cos(theta)**38 - 1.48027223916834e+90*cos(theta)**36 + 3.5324678434699e+89*cos(theta)**34 - 7.15162201438691e+88*cos(theta)**32 + 1.22401812254517e+88*cos(theta)**30 - 1.76248885570059e+87*cos(theta)**28 + 2.12172225304084e+86*cos(theta)**26 - 2.11846307907304e+85*cos(theta)**24 + 1.73706420030944e+84*cos(theta)**22 - 1.15537526712203e+83*cos(theta)**20 + 6.13873883537992e+81*cos(theta)**18 - 2.55571984166837e+80*cos(theta)**16 + 8.13491726790994e+78*cos(theta)**14 - 1.91732056819426e+77*cos(theta)**12 + 3.20524715047673e+75*cos(theta)**10 - 3.57817220966145e+73*cos(theta)**8 + 2.43768423042629e+71*cos(theta)**6 - 8.73721946389351e+68*cos(theta)**4 + 1.2317508642707e+66*cos(theta)**2 - 2.84929647067014e+62)*sin(32*phi)

#@torch.jit.script
def Yl98_m_minus_31(theta, phi):
    return 1.51615210452691e-61*(1.0 - cos(theta)**2)**15.5*(4.66248152711292e+87*cos(theta)**67 - 5.28653674689572e+88*cos(theta)**65 + 2.84870373925987e+89*cos(theta)**63 - 9.70945620030459e+89*cos(theta)**61 + 2.35030487388325e+90*cos(theta)**59 - 4.30093223445374e+90*cos(theta)**57 + 6.18404310467403e+90*cos(theta)**55 - 7.1688555897275e+90*cos(theta)**53 + 6.82229489132907e+90*cos(theta)**51 - 5.39939539816547e+90*cos(theta)**49 + 3.58739490861163e+90*cos(theta)**47 - 2.01453189413464e+90*cos(theta)**45 + 9.60687174948598e+89*cos(theta)**43 - 3.90238650012858e+89*cos(theta)**41 + 1.35247545651117e+89*cos(theta)**39 - 4.00073578153605e+88*cos(theta)**37 + 1.00927652670568e+88*cos(theta)**35 - 2.16715818617785e+87*cos(theta)**33 + 3.94844555659733e+86*cos(theta)**31 - 6.07754777827791e+85*cos(theta)**29 + 7.85823056681794e+84*cos(theta)**27 - 8.47385231629215e+83*cos(theta)**25 + 7.55245304482366e+82*cos(theta)**23 - 5.50178698629538e+81*cos(theta)**21 + 3.23091517651575e+80*cos(theta)**19 - 1.5033646127461e+79*cos(theta)**17 + 5.42327817860663e+77*cos(theta)**15 - 1.47486197553405e+76*cos(theta)**13 + 2.91386104588794e+74*cos(theta)**11 - 3.97574689962383e+72*cos(theta)**9 + 3.48240604346613e+70*cos(theta)**7 - 1.7474438927787e+68*cos(theta)**5 + 4.10583621423567e+65*cos(theta)**3 - 2.84929647067014e+62*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl98_m_minus_30(theta, phi):
    return 1.42001222931447e-59*(1.0 - cos(theta)**2)**15*(6.85659048104841e+85*cos(theta)**68 - 8.00990416196322e+86*cos(theta)**66 + 4.45109959259355e+87*cos(theta)**64 - 1.56604132262977e+88*cos(theta)**62 + 3.91717478980542e+88*cos(theta)**60 - 7.41540040423059e+88*cos(theta)**58 + 1.10429341154893e+89*cos(theta)**56 - 1.32756584994954e+89*cos(theta)**54 + 1.31197978679405e+89*cos(theta)**52 - 1.07987907963309e+89*cos(theta)**50 + 7.4737393929409e+88*cos(theta)**48 - 4.37941716116225e+88*cos(theta)**46 + 2.183379943065e+88*cos(theta)**44 - 9.29139642887758e+87*cos(theta)**42 + 3.38118864127794e+87*cos(theta)**40 - 1.05282520566738e+87*cos(theta)**38 + 2.80354590751579e+86*cos(theta)**36 - 6.37399466522897e+85*cos(theta)**34 + 1.23388923643666e+85*cos(theta)**32 - 2.02584925942597e+84*cos(theta)**30 + 2.80651091672069e+83*cos(theta)**28 - 3.25917396780467e+82*cos(theta)**26 + 3.14685543534319e+81*cos(theta)**24 - 2.5008122664979e+80*cos(theta)**22 + 1.61545758825787e+79*cos(theta)**20 - 8.35202562636724e+77*cos(theta)**18 + 3.38954886162914e+76*cos(theta)**16 - 1.05347283966718e+75*cos(theta)**14 + 2.42821753823995e+73*cos(theta)**12 - 3.97574689962383e+71*cos(theta)**10 + 4.35300755433266e+69*cos(theta)**8 - 2.9124064879645e+67*cos(theta)**6 + 1.02645905355892e+65*cos(theta)**4 - 1.42464823533507e+62*cos(theta)**2 + 3.24817199118803e+58)*sin(30*phi)

#@torch.jit.script
def Yl98_m_minus_29(theta, phi):
    return 1.3345093310932e-57*(1.0 - cos(theta)**2)**14.5*(9.93708765369334e+83*cos(theta)**69 - 1.19550808387511e+85*cos(theta)**67 + 6.847845527067e+85*cos(theta)**65 - 2.48577987719011e+86*cos(theta)**63 + 6.42159801607446e+86*cos(theta)**61 - 1.25684752614078e+87*cos(theta)**59 + 1.93735686236655e+87*cos(theta)**57 - 2.41375609081734e+87*cos(theta)**55 + 2.47543355998878e+87*cos(theta)**53 - 2.11740996006489e+87*cos(theta)**51 + 1.52525293733488e+87*cos(theta)**49 - 9.31790885353671e+86*cos(theta)**47 + 4.85195542903332e+86*cos(theta)**45 - 2.16078986718083e+86*cos(theta)**43 + 8.24680156409252e+85*cos(theta)**41 - 2.69955180940354e+85*cos(theta)**39 + 7.57715110139403e+84*cos(theta)**37 - 1.82114133292256e+84*cos(theta)**35 + 3.73905829223232e+83*cos(theta)**33 - 6.53499761105152e+82*cos(theta)**31 + 9.677623850761e+81*cos(theta)**29 - 1.20710146955729e+81*cos(theta)**27 + 1.25874217413728e+80*cos(theta)**25 - 1.08730968108604e+79*cos(theta)**23 + 7.69265518218035e+77*cos(theta)**21 - 4.39580296124591e+76*cos(theta)**19 + 1.99385227154655e+75*cos(theta)**17 - 7.02315226444785e+73*cos(theta)**15 + 1.86785964479996e+72*cos(theta)**13 - 3.61431536329439e+70*cos(theta)**11 + 4.83667506036962e+68*cos(theta)**9 - 4.16058069709215e+66*cos(theta)**7 + 2.05291810711784e+64*cos(theta)**5 - 4.7488274511169e+61*cos(theta)**3 + 3.24817199118803e+58*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl98_m_minus_28(theta, phi):
    return 1.25826609768952e-55*(1.0 - cos(theta)**2)**14*(1.41958395052762e+82*cos(theta)**70 - 1.75810012334575e+83*cos(theta)**68 + 1.03755235258591e+84*cos(theta)**66 - 3.88403105810955e+84*cos(theta)**64 + 1.03574161549588e+85*cos(theta)**62 - 2.0947458769013e+85*cos(theta)**60 + 3.34027045235612e+85*cos(theta)**58 - 4.31027873360239e+85*cos(theta)**56 + 4.58413622220144e+85*cos(theta)**54 - 4.07194223089402e+85*cos(theta)**52 + 3.05050587466975e+85*cos(theta)**50 - 1.94123101115348e+85*cos(theta)**48 + 1.05477291935507e+85*cos(theta)**46 - 4.91088606177462e+84*cos(theta)**44 + 1.96352418192679e+84*cos(theta)**42 - 6.74887952350885e+83*cos(theta)**40 + 1.9939871319458e+83*cos(theta)**38 - 5.0587259247849e+82*cos(theta)**36 + 1.09972302712715e+82*cos(theta)**34 - 2.0421867534536e+81*cos(theta)**32 + 3.22587461692034e+80*cos(theta)**30 - 4.31107667699031e+79*cos(theta)**28 + 4.84131605437414e+78*cos(theta)**26 - 4.53045700452519e+77*cos(theta)**24 + 3.49666144644561e+76*cos(theta)**22 - 2.19790148062296e+75*cos(theta)**20 + 1.10769570641475e+74*cos(theta)**18 - 4.38947016527991e+72*cos(theta)**16 + 1.3341854605714e+71*cos(theta)**14 - 3.01192946941199e+69*cos(theta)**12 + 4.83667506036962e+67*cos(theta)**10 - 5.20072587136518e+65*cos(theta)**8 + 3.42153017852973e+63*cos(theta)**6 - 1.18720686277923e+61*cos(theta)**4 + 1.62408599559402e+58*cos(theta)**2 - 3.65373677298991e+54)*sin(28*phi)

#@torch.jit.script
def Yl98_m_minus_27(theta, phi):
    return 1.19010955547938e-53*(1.0 - cos(theta)**2)**13.5*(1.99941401482763e+80*cos(theta)**71 - 2.5479711932547e+81*cos(theta)**69 + 1.54858560087449e+82*cos(theta)**67 - 5.97543239709162e+82*cos(theta)**65 + 1.64403431031092e+83*cos(theta)**63 - 3.43400963426442e+83*cos(theta)**61 + 5.66147534297647e+83*cos(theta)**59 - 7.56189251509192e+83*cos(theta)**57 + 8.33479313127535e+83*cos(theta)**55 - 7.68290986961135e+83*cos(theta)**53 + 5.98138406797991e+83*cos(theta)**51 - 3.96169594112955e+83*cos(theta)**49 + 2.24419770075547e+83*cos(theta)**47 - 1.09130801372769e+83*cos(theta)**45 + 4.56633530680649e+82*cos(theta)**43 - 1.64606817646557e+82*cos(theta)**41 + 5.11278751780974e+81*cos(theta)**39 - 1.36722322291484e+81*cos(theta)**37 + 3.14206579179186e+80*cos(theta)**35 - 6.18844470743515e+79*cos(theta)**33 + 1.04060471513559e+79*cos(theta)**31 - 1.48657816447942e+78*cos(theta)**29 + 1.79308002013857e+77*cos(theta)**27 - 1.81218280181007e+76*cos(theta)**25 + 1.52028758541114e+75*cos(theta)**23 - 1.0466197526776e+74*cos(theta)**21 + 5.82997740218291e+72*cos(theta)**19 - 2.58204127369406e+71*cos(theta)**17 + 8.89456973714267e+69*cos(theta)**15 - 2.31686882262461e+68*cos(theta)**13 + 4.39697732760875e+66*cos(theta)**11 - 5.77858430151687e+64*cos(theta)**9 + 4.88790025504247e+62*cos(theta)**7 - 2.37441372555845e+60*cos(theta)**5 + 5.41361998531338e+57*cos(theta)**3 - 3.65373677298991e+54*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl98_m_minus_26(theta, phi):
    return 1.12903705813361e-51*(1.0 - cos(theta)**2)**13*(2.77696390948283e+78*cos(theta)**72 - 3.63995884750672e+79*cos(theta)**70 + 2.2773317659919e+80*cos(theta)**68 - 9.05368545013882e+80*cos(theta)**66 + 2.56880360986082e+81*cos(theta)**64 - 5.53872521655551e+81*cos(theta)**62 + 9.43579223829412e+81*cos(theta)**60 - 1.30377457156757e+82*cos(theta)**58 + 1.48835591629917e+82*cos(theta)**56 - 1.42276108696507e+82*cos(theta)**54 + 1.15026616691921e+82*cos(theta)**52 - 7.9233918822591e+81*cos(theta)**50 + 4.67541187657389e+81*cos(theta)**48 - 2.37240872549499e+81*cos(theta)**46 + 1.03780347881966e+81*cos(theta)**44 - 3.91920994396565e+80*cos(theta)**42 + 1.27819687945243e+80*cos(theta)**40 - 3.59795584977589e+79*cos(theta)**38 + 8.72796053275517e+78*cos(theta)**36 - 1.82013079630446e+78*cos(theta)**34 + 3.25188973479872e+77*cos(theta)**32 - 4.95526054826472e+76*cos(theta)**30 + 6.40385721478061e+75*cos(theta)**28 - 6.96993385311567e+74*cos(theta)**26 + 6.33453160587973e+73*cos(theta)**24 - 4.7573625121709e+72*cos(theta)**22 + 2.91498870109145e+71*cos(theta)**20 - 1.43446737427448e+70*cos(theta)**18 + 5.55910608571417e+68*cos(theta)**16 - 1.65490630187472e+67*cos(theta)**14 + 3.66414777300729e+65*cos(theta)**12 - 5.77858430151687e+63*cos(theta)**10 + 6.10987531880308e+61*cos(theta)**8 - 3.95735620926408e+59*cos(theta)**6 + 1.35340499632835e+57*cos(theta)**4 - 1.82686838649496e+54*cos(theta)**2 + 4.05970752554435e+50)*sin(26*phi)

#@torch.jit.script
def Yl98_m_minus_25(theta, phi):
    return 1.07418842811865e-49*(1.0 - cos(theta)**2)**12.5*(3.80406014997647e+76*cos(theta)**73 - 5.12670260212214e+77*cos(theta)**71 + 3.30048082027811e+78*cos(theta)**69 - 1.35129633584162e+79*cos(theta)**67 + 3.95200555363202e+79*cos(theta)**65 - 8.7916273278659e+79*cos(theta)**63 + 1.54685118660559e+80*cos(theta)**61 - 2.20978740943656e+80*cos(theta)**59 + 2.61115073034942e+80*cos(theta)**57 - 2.58683833993648e+80*cos(theta)**55 + 2.17031352248908e+80*cos(theta)**53 - 1.55360625142335e+80*cos(theta)**51 + 9.54165689096713e+79*cos(theta)**49 - 5.04767813935103e+79*cos(theta)**47 + 2.30622995293257e+79*cos(theta)**45 - 9.11444173015268e+78*cos(theta)**43 + 3.11755336451813e+78*cos(theta)**41 - 9.22552781993818e+77*cos(theta)**39 + 2.35890825209599e+77*cos(theta)**37 - 5.20037370372702e+76*cos(theta)**35 + 9.85421131757189e+75*cos(theta)**33 - 1.59847114460152e+75*cos(theta)**31 + 2.20822662578642e+74*cos(theta)**29 - 2.58145698263543e+73*cos(theta)**27 + 2.53381264235189e+72*cos(theta)**25 - 2.06841848355257e+71*cos(theta)**23 + 1.3880898576626e+70*cos(theta)**21 - 7.54982828565515e+68*cos(theta)**19 + 3.27006240336127e+67*cos(theta)**17 - 1.10327086791648e+66*cos(theta)**15 + 2.81857521000561e+64*cos(theta)**13 - 5.25325845592443e+62*cos(theta)**11 + 6.78875035422565e+60*cos(theta)**9 - 5.65336601323441e+58*cos(theta)**7 + 2.70680999265669e+56*cos(theta)**5 - 6.08956128831652e+53*cos(theta)**3 + 4.05970752554435e+50*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl98_m_minus_24(theta, phi):
    return 1.02482305064849e-47*(1.0 - cos(theta)**2)**12*(5.14062182429253e+74*cos(theta)**74 - 7.12042028072519e+75*cos(theta)**72 + 4.7149726003973e+76*cos(theta)**70 - 1.98720049388473e+77*cos(theta)**68 + 5.98788720247277e+77*cos(theta)**66 - 1.37369176997905e+78*cos(theta)**64 + 2.4949212687187e+78*cos(theta)**62 - 3.6829790157276e+78*cos(theta)**60 + 4.50198401784383e+78*cos(theta)**58 - 4.619354178458e+78*cos(theta)**56 + 4.01909911572052e+78*cos(theta)**54 - 2.9877043296603e+78*cos(theta)**52 + 1.90833137819343e+78*cos(theta)**50 - 1.0515996123648e+78*cos(theta)**48 + 5.01354337594037e+77*cos(theta)**46 - 2.07146402958015e+77*cos(theta)**44 + 7.42274610599555e+76*cos(theta)**42 - 2.30638195498454e+76*cos(theta)**40 + 6.20765329498946e+75*cos(theta)**38 - 1.44454825103528e+75*cos(theta)**36 + 2.89829744634467e+74*cos(theta)**34 - 4.99522232687976e+73*cos(theta)**32 + 7.36075541928806e+72*cos(theta)**30 - 9.21948922369798e+71*cos(theta)**28 + 9.74543323981497e+70*cos(theta)**26 - 8.61841034813569e+69*cos(theta)**24 + 6.30949935301181e+68*cos(theta)**22 - 3.77491414282758e+67*cos(theta)**20 + 1.81670133520071e+66*cos(theta)**18 - 6.895442924478e+64*cos(theta)**16 + 2.01326800714686e+63*cos(theta)**14 - 4.37771537993702e+61*cos(theta)**12 + 6.78875035422565e+59*cos(theta)**10 - 7.06670751654301e+57*cos(theta)**8 + 4.51134998776115e+55*cos(theta)**6 - 1.52239032207913e+53*cos(theta)**4 + 2.02985376277217e+50*cos(theta)**2 - 4.46023678921594e+46)*sin(24*phi)

#@torch.jit.script
def Yl98_m_minus_23(theta, phi):
    return 9.8030096955146e-46*(1.0 - cos(theta)**2)**11.5*(6.85416243239004e+72*cos(theta)**75 - 9.75400038455506e+73*cos(theta)**73 + 6.64080647943282e+74*cos(theta)**71 - 2.88000071577497e+75*cos(theta)**69 + 8.93714507831756e+75*cos(theta)**67 - 2.11337195381392e+76*cos(theta)**65 + 3.96019249002968e+76*cos(theta)**63 - 6.03767051758624e+76*cos(theta)**61 + 7.63048138617598e+76*cos(theta)**59 - 8.10413013764562e+76*cos(theta)**57 + 7.30745293767368e+76*cos(theta)**55 - 5.63717798049112e+76*cos(theta)**53 + 3.74182623175182e+76*cos(theta)**51 - 2.14612165788734e+76*cos(theta)**49 + 1.06671135658306e+76*cos(theta)**47 - 4.60325339906701e+75*cos(theta)**45 + 1.72622002465013e+75*cos(theta)**43 - 5.62532184142572e+74*cos(theta)**41 + 1.59170597307422e+74*cos(theta)**39 - 3.90418446225752e+73*cos(theta)**37 + 8.28084984669907e+72*cos(theta)**35 - 1.51370373541811e+72*cos(theta)**33 + 2.37443723202841e+71*cos(theta)**31 - 3.17913421506827e+70*cos(theta)**29 + 3.60941971844999e+69*cos(theta)**27 - 3.44736413925428e+68*cos(theta)**25 + 2.743260588266e+67*cos(theta)**23 - 1.79757816325123e+66*cos(theta)**21 + 9.56158597474057e+64*cos(theta)**19 - 4.05614289675177e+63*cos(theta)**17 + 1.34217867143124e+62*cos(theta)**15 - 3.36747336918233e+60*cos(theta)**13 + 6.17159123111423e+58*cos(theta)**11 - 7.85189724060334e+56*cos(theta)**9 + 6.44478569680165e+54*cos(theta)**7 - 3.04478064415826e+52*cos(theta)**5 + 6.76617920924057e+49*cos(theta)**3 - 4.46023678921594e+46*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl98_m_minus_22(theta, phi):
    return 9.40067229316547e-44*(1.0 - cos(theta)**2)**11*(9.01863477946058e+70*cos(theta)**76 - 1.31810816007501e+72*cos(theta)**74 + 9.22334233254559e+72*cos(theta)**72 - 4.11428673682138e+73*cos(theta)**70 + 1.31428604092905e+74*cos(theta)**68 - 3.20207871789987e+74*cos(theta)**66 + 6.18780076567138e+74*cos(theta)**64 - 9.73817825417135e+74*cos(theta)**62 + 1.271746897696e+75*cos(theta)**60 - 1.39726381683545e+75*cos(theta)**58 + 1.30490231029887e+75*cos(theta)**56 - 1.0439218482391e+75*cos(theta)**54 + 7.1958196764458e+74*cos(theta)**52 - 4.29224331577469e+74*cos(theta)**50 + 2.2223153262147e+74*cos(theta)**48 - 1.00070726066674e+74*cos(theta)**46 + 3.92322732875029e+73*cos(theta)**44 - 1.3393623431966e+73*cos(theta)**42 + 3.97926493268555e+72*cos(theta)**40 - 1.02741696375198e+72*cos(theta)**38 + 2.30023606852752e+71*cos(theta)**36 - 4.45206981005326e+70*cos(theta)**34 + 7.42011635008877e+69*cos(theta)**32 - 1.05971140502276e+69*cos(theta)**30 + 1.289078470875e+68*cos(theta)**28 - 1.32590928432857e+67*cos(theta)**26 + 1.14302524511083e+66*cos(theta)**24 - 8.17080983296012e+64*cos(theta)**22 + 4.78079298737028e+63*cos(theta)**20 - 2.25341272041765e+62*cos(theta)**18 + 8.38861669644526e+60*cos(theta)**16 - 2.40533812084452e+59*cos(theta)**14 + 5.14299269259519e+57*cos(theta)**12 - 7.85189724060334e+55*cos(theta)**10 + 8.05598212100206e+53*cos(theta)**8 - 5.07463440693043e+51*cos(theta)**6 + 1.69154480231014e+49*cos(theta)**4 - 2.23011839460797e+46*cos(theta)**2 + 4.85019224577636e+42)*sin(22*phi)

#@torch.jit.script
def Yl98_m_minus_21(theta, phi):
    return 9.03638860146374e-42*(1.0 - cos(theta)**2)**10.5*(1.17125127005982e+69*cos(theta)**77 - 1.75747754676668e+70*cos(theta)**75 + 1.26347155240351e+71*cos(theta)**73 - 5.7947700518611e+71*cos(theta)**71 + 1.90476237815805e+72*cos(theta)**69 - 4.77922196701474e+72*cos(theta)**67 + 9.51969348564828e+72*cos(theta)**65 - 1.5457425800272e+73*cos(theta)**63 + 2.0848309798295e+73*cos(theta)**61 - 2.36824375734822e+73*cos(theta)**59 + 2.28930229876995e+73*cos(theta)**57 - 1.89803972407109e+73*cos(theta)**55 + 1.35770182574449e+73*cos(theta)**53 - 8.41616336426409e+72*cos(theta)**51 + 4.53533740043817e+72*cos(theta)**49 - 2.12916438439732e+72*cos(theta)**47 + 8.71828295277843e+71*cos(theta)**45 - 3.11479614696884e+71*cos(theta)**43 + 9.70552422606231e+70*cos(theta)**41 - 2.63440247115892e+70*cos(theta)**39 + 6.21685423926357e+69*cos(theta)**37 - 1.2720199457295e+69*cos(theta)**35 + 2.24852010608751e+68*cos(theta)**33 - 3.41842388717018e+67*cos(theta)**31 + 4.44509817543102e+66*cos(theta)**29 - 4.91077512714284e+65*cos(theta)**27 + 4.57210098044334e+64*cos(theta)**25 - 3.55252601433049e+63*cos(theta)**23 + 2.27656808922394e+62*cos(theta)**21 - 1.18600669495666e+61*cos(theta)**19 + 4.93448040967368e+59*cos(theta)**17 - 1.60355874722968e+58*cos(theta)**15 + 3.95614822507322e+56*cos(theta)**13 - 7.13808840054849e+54*cos(theta)**11 + 8.95109124555785e+52*cos(theta)**9 - 7.24947772418633e+50*cos(theta)**7 + 3.38308960462029e+48*cos(theta)**5 - 7.43372798202656e+45*cos(theta)**3 + 4.85019224577636e+42*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl98_m_minus_20(theta, phi):
    return 8.70594022811869e-40*(1.0 - cos(theta)**2)**10*(1.50160419238438e+67*cos(theta)**78 - 2.31247045627194e+68*cos(theta)**76 + 1.70739398973447e+69*cos(theta)**74 - 8.04829173869598e+69*cos(theta)**72 + 2.72108911165435e+70*cos(theta)**70 - 7.02826759855109e+70*cos(theta)**68 + 1.4423778008558e+71*cos(theta)**66 - 2.4152227812925e+71*cos(theta)**64 + 3.36263061262823e+71*cos(theta)**62 - 3.94707292891371e+71*cos(theta)**60 + 3.94707292891371e+71*cos(theta)**58 - 3.38935665012694e+71*cos(theta)**56 + 2.51426264026757e+71*cos(theta)**54 - 1.61849295466617e+71*cos(theta)**52 + 9.07067480087635e+70*cos(theta)**50 - 4.43575913416109e+70*cos(theta)**48 + 1.89527890277792e+70*cos(theta)**46 - 7.0790821522019e+69*cos(theta)**44 + 2.31083910144341e+69*cos(theta)**42 - 6.5860061778973e+68*cos(theta)**40 + 1.63601427349041e+68*cos(theta)**38 - 3.53338873813751e+67*cos(theta)**36 + 6.61329442966914e+66*cos(theta)**34 - 1.06825746474068e+66*cos(theta)**32 + 1.48169939181034e+65*cos(theta)**30 - 1.75384825969387e+64*cos(theta)**28 + 1.75850037709359e+63*cos(theta)**26 - 1.4802191726377e+62*cos(theta)**24 + 1.03480367691997e+61*cos(theta)**22 - 5.93003347478329e+59*cos(theta)**20 + 2.74137800537427e+58*cos(theta)**18 - 1.00222421701855e+57*cos(theta)**16 + 2.82582016076659e+55*cos(theta)**14 - 5.94840700045708e+53*cos(theta)**12 + 8.95109124555784e+51*cos(theta)**10 - 9.06184715523291e+49*cos(theta)**8 + 5.63848267436715e+47*cos(theta)**6 - 1.85843199550664e+45*cos(theta)**4 + 2.42509612288818e+42*cos(theta)**2 - 5.22537410663257e+38)*sin(20*phi)

#@torch.jit.script
def Yl98_m_minus_19(theta, phi):
    return 8.40562924814361e-38*(1.0 - cos(theta)**2)**9.5*(1.90076480048656e+65*cos(theta)**79 - 3.00320838476876e+66*cos(theta)**77 + 2.27652531964596e+67*cos(theta)**75 - 1.10250571762959e+68*cos(theta)**73 + 3.83251987556951e+68*cos(theta)**71 - 1.01858950703639e+69*cos(theta)**69 + 2.15280268784448e+69*cos(theta)**67 - 3.71572735583461e+69*cos(theta)**65 + 5.3375089089337e+69*cos(theta)**63 - 6.47061135887493e+69*cos(theta)**61 + 6.68995411680289e+69*cos(theta)**59 - 5.9462397370648e+69*cos(theta)**57 + 4.57138661866832e+69*cos(theta)**55 - 3.05376029182297e+69*cos(theta)**53 + 1.77856368644634e+69*cos(theta)**51 - 9.05256966155324e+68*cos(theta)**49 + 4.03250830378281e+68*cos(theta)**47 - 1.57312936715598e+68*cos(theta)**45 + 5.37404442196141e+67*cos(theta)**43 - 1.60634297021885e+67*cos(theta)**41 + 4.19490839356516e+66*cos(theta)**39 - 9.54969929226354e+65*cos(theta)**37 + 1.88951269419118e+65*cos(theta)**35 - 3.23714383254752e+64*cos(theta)**33 + 4.77967545745271e+63*cos(theta)**31 - 6.04775261963405e+62*cos(theta)**29 + 6.51296435960589e+61*cos(theta)**27 - 5.92087669055081e+60*cos(theta)**25 + 4.4991464213912e+59*cos(theta)**23 - 2.82382546418252e+58*cos(theta)**21 + 1.44283052914435e+57*cos(theta)**19 - 5.89543657069735e+55*cos(theta)**17 + 1.88388010717772e+54*cos(theta)**15 - 4.57569769265929e+52*cos(theta)**13 + 8.13735567777986e+50*cos(theta)**11 - 1.00687190613699e+49*cos(theta)**9 + 8.05497524909592e+46*cos(theta)**7 - 3.71686399101328e+44*cos(theta)**5 + 8.08365374296059e+41*cos(theta)**3 - 5.22537410663257e+38*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl98_m_minus_18(theta, phi):
    return 8.13220194422049e-36*(1.0 - cos(theta)**2)**9*(2.3759560006082e+63*cos(theta)**80 - 3.85026715995995e+64*cos(theta)**78 + 2.99542805216573e+65*cos(theta)**76 - 1.48987259139133e+66*cos(theta)**74 + 5.32294427162432e+66*cos(theta)**72 - 1.45512786719484e+67*cos(theta)**70 + 3.16588630565364e+67*cos(theta)**68 - 5.62988993308274e+67*cos(theta)**66 + 8.3398576702089e+67*cos(theta)**64 - 1.04364699336692e+68*cos(theta)**62 + 1.11499235280048e+68*cos(theta)**60 - 1.02521374776979e+68*cos(theta)**58 + 8.16319039047914e+67*cos(theta)**56 - 5.65511165152401e+67*cos(theta)**54 + 3.42031478162758e+67*cos(theta)**52 - 1.81051393231065e+67*cos(theta)**50 + 8.40105896621418e+66*cos(theta)**48 - 3.41984645033908e+66*cos(theta)**46 + 1.22137373226396e+66*cos(theta)**44 - 3.8246261195687e+65*cos(theta)**42 + 1.04872709839129e+65*cos(theta)**40 - 2.51307876112198e+64*cos(theta)**38 + 5.24864637275328e+63*cos(theta)**36 - 9.52101127219859e+62*cos(theta)**34 + 1.49364858045397e+62*cos(theta)**32 - 2.01591753987802e+61*cos(theta)**30 + 2.32605869985925e+60*cos(theta)**28 - 2.27726026559647e+59*cos(theta)**26 + 1.87464434224633e+58*cos(theta)**24 - 1.28355702917387e+57*cos(theta)**22 + 7.21415264572176e+55*cos(theta)**20 - 3.27524253927631e+54*cos(theta)**18 + 1.17742506698608e+53*cos(theta)**16 - 3.26835549475664e+51*cos(theta)**14 + 6.78112973148322e+49*cos(theta)**12 - 1.00687190613699e+48*cos(theta)**10 + 1.00687190613699e+46*cos(theta)**8 - 6.19477331835547e+43*cos(theta)**6 + 2.02091343574015e+41*cos(theta)**4 - 2.61268705331629e+38*cos(theta)**2 + 5.58266464383822e+34)*sin(18*phi)

#@torch.jit.script
def Yl98_m_minus_17(theta, phi):
    return 7.88278458861485e-34*(1.0 - cos(theta)**2)**8.5*(2.93327901309654e+61*cos(theta)**81 - 4.87375589868348e+62*cos(theta)**79 + 3.89016630151394e+63*cos(theta)**77 - 1.98649678852178e+64*cos(theta)**75 + 7.29170448167715e+64*cos(theta)**73 - 2.04947586928851e+65*cos(theta)**71 + 4.58824102268644e+65*cos(theta)**69 - 8.40282079564589e+65*cos(theta)**67 + 1.28305502618598e+66*cos(theta)**65 - 1.65658252915385e+66*cos(theta)**63 + 1.82785631606636e+66*cos(theta)**61 - 1.7376504199488e+66*cos(theta)**59 + 1.43213866499634e+66*cos(theta)**57 - 1.02820211845891e+66*cos(theta)**55 + 6.45342411627846e+65*cos(theta)**53 - 3.55002731825617e+65*cos(theta)**51 + 1.71450182983963e+65*cos(theta)**49 - 7.27626904327464e+64*cos(theta)**47 + 2.71416384947546e+64*cos(theta)**45 - 8.89447934783418e+63*cos(theta)**43 + 2.55787097168607e+63*cos(theta)**41 - 6.44379169518458e+62*cos(theta)**39 + 1.4185530737171e+62*cos(theta)**37 - 2.72028893491388e+61*cos(theta)**35 + 4.52620781955749e+60*cos(theta)**33 - 6.50295980605811e+59*cos(theta)**31 + 8.02089206848017e+58*cos(theta)**29 - 8.43429727998691e+57*cos(theta)**27 + 7.49857736898533e+56*cos(theta)**25 - 5.58068273553857e+55*cos(theta)**23 + 3.43531078367703e+54*cos(theta)**21 - 1.723811862777e+53*cos(theta)**19 + 6.92602980580046e+51*cos(theta)**17 - 2.17890366317109e+50*cos(theta)**15 + 5.21625363960247e+48*cos(theta)**13 - 9.15338096488173e+46*cos(theta)**11 + 1.11874656237443e+45*cos(theta)**9 - 8.84967616907924e+42*cos(theta)**7 + 4.0418268714803e+40*cos(theta)**5 - 8.70895684438762e+37*cos(theta)**3 + 5.58266464383822e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl98_m_minus_16(theta, phi):
    return 7.65482920625177e-32*(1.0 - cos(theta)**2)**8*(3.57716952816651e+59*cos(theta)**82 - 6.09219487335435e+60*cos(theta)**80 + 4.98739269424864e+61*cos(theta)**78 - 2.61381156384444e+62*cos(theta)**76 + 9.85365470496913e+62*cos(theta)**74 - 2.84649426290071e+63*cos(theta)**72 + 6.5546300324092e+63*cos(theta)**70 - 1.23570894053616e+64*cos(theta)**68 + 1.94402276694846e+64*cos(theta)**66 - 2.58841020180289e+64*cos(theta)**64 + 2.94815534849414e+64*cos(theta)**62 - 2.896084033248e+64*cos(theta)**60 + 2.46920459482128e+64*cos(theta)**58 - 1.83607521153377e+64*cos(theta)**56 + 1.19507854005157e+64*cos(theta)**54 - 6.8269756120311e+63*cos(theta)**52 + 3.42900365967926e+63*cos(theta)**50 - 1.51588938401555e+63*cos(theta)**48 + 5.90035619451187e+62*cos(theta)**46 - 2.02147257905322e+62*cos(theta)**44 + 6.09016898020494e+61*cos(theta)**42 - 1.61094792379614e+61*cos(theta)**40 + 3.73303440451869e+60*cos(theta)**38 - 7.55635815253856e+59*cos(theta)**36 + 1.3312375939875e+59*cos(theta)**34 - 2.03217493939316e+58*cos(theta)**32 + 2.67363068949339e+57*cos(theta)**30 - 3.01224902856675e+56*cos(theta)**28 + 2.88406821884051e+55*cos(theta)**26 - 2.32528447314107e+54*cos(theta)**24 + 1.56150490167138e+53*cos(theta)**22 - 8.61905931388501e+51*cos(theta)**20 + 3.84779433655581e+50*cos(theta)**18 - 1.36181478948193e+49*cos(theta)**16 + 3.72589545685891e+47*cos(theta)**14 - 7.62781747073478e+45*cos(theta)**12 + 1.11874656237443e+44*cos(theta)**10 - 1.1062095211349e+42*cos(theta)**8 + 6.73637811913383e+39*cos(theta)**6 - 2.17723921109691e+37*cos(theta)**4 + 2.79133232191911e+34*cos(theta)**2 - 5.92011096907553e+30)*sin(16*phi)

#@torch.jit.script
def Yl98_m_minus_15(theta, phi):
    return 7.44606764066569e-30*(1.0 - cos(theta)**2)**7.5*(4.30984280501989e+57*cos(theta)**83 - 7.52122823870907e+58*cos(theta)**81 + 6.31315530917549e+59*cos(theta)**79 - 3.39456047252525e+60*cos(theta)**77 + 1.31382062732922e+61*cos(theta)**75 - 3.89930720945302e+61*cos(theta)**73 + 9.23187328508338e+61*cos(theta)**71 - 1.79088252251617e+62*cos(theta)**69 + 2.90152651783352e+62*cos(theta)**67 - 3.98216954123521e+62*cos(theta)**65 + 4.67961166427641e+62*cos(theta)**63 - 4.74767874302952e+62*cos(theta)**61 + 4.18509253359538e+62*cos(theta)**59 - 3.22118458163819e+62*cos(theta)**57 + 2.17287007282103e+62*cos(theta)**55 - 1.2881086060436e+62*cos(theta)**53 + 6.72353658760639e+61*cos(theta)**51 - 3.09365180411337e+61*cos(theta)**49 + 1.25539493500253e+61*cos(theta)**47 - 4.49216128678494e+60*cos(theta)**45 + 1.41631836748952e+60*cos(theta)**43 - 3.92914127755157e+59*cos(theta)**41 + 9.57188308850947e+58*cos(theta)**39 - 2.04225896014556e+58*cos(theta)**37 + 3.80353598282142e+57*cos(theta)**35 - 6.15810587694897e+56*cos(theta)**33 + 8.62461512739803e+55*cos(theta)**31 - 1.03870656157474e+55*cos(theta)**29 + 1.06817341438537e+54*cos(theta)**27 - 9.30113789256428e+52*cos(theta)**25 + 6.78915174639729e+51*cos(theta)**23 - 4.10431395899286e+50*cos(theta)**21 + 2.02515491397674e+49*cos(theta)**19 - 8.01067523224666e+47*cos(theta)**17 + 2.48393030457261e+46*cos(theta)**15 - 5.86755190056521e+44*cos(theta)**13 + 1.0170423294313e+43*cos(theta)**11 - 1.22912169014989e+41*cos(theta)**9 + 9.62339731304832e+38*cos(theta)**7 - 4.35447842219381e+36*cos(theta)**5 + 9.3044410730637e+33*cos(theta)**3 - 5.92011096907553e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl98_m_minus_14(theta, phi):
    return 7.25447255182986e-28*(1.0 - cos(theta)**2)**7*(5.1307652440713e+55*cos(theta)**84 - 9.17222955940131e+56*cos(theta)**82 + 7.89144413646936e+57*cos(theta)**80 - 4.3520006058016e+58*cos(theta)**78 + 1.72871135174897e+59*cos(theta)**76 - 5.26933406682841e+59*cos(theta)**74 + 1.28220462292825e+60*cos(theta)**72 - 2.55840360359453e+60*cos(theta)**70 + 4.26695076151989e+60*cos(theta)**68 - 6.03359021399274e+60*cos(theta)**66 + 7.31189322543188e+60*cos(theta)**64 - 7.65754635972503e+60*cos(theta)**62 + 6.97515422265897e+60*cos(theta)**60 - 5.55376652006585e+60*cos(theta)**58 + 3.88012513003755e+60*cos(theta)**56 - 2.38538630748816e+60*cos(theta)**54 + 1.29298780530892e+60*cos(theta)**52 - 6.18730360822674e+59*cos(theta)**50 + 2.6154061145886e+59*cos(theta)**48 - 9.76556801474987e+58*cos(theta)**46 + 3.218905380658e+58*cos(theta)**44 - 9.35509827988469e+57*cos(theta)**42 + 2.39297077212737e+57*cos(theta)**40 - 5.37436568459357e+56*cos(theta)**38 + 1.05653777300595e+56*cos(theta)**36 - 1.81120761086734e+55*cos(theta)**34 + 2.69519222731188e+54*cos(theta)**32 - 3.46235520524914e+53*cos(theta)**30 + 3.81490505137634e+52*cos(theta)**28 - 3.57736072790934e+51*cos(theta)**26 + 2.82881322766554e+50*cos(theta)**24 - 1.86559725408767e+49*cos(theta)**22 + 1.01257745698837e+48*cos(theta)**20 - 4.45037512902592e+46*cos(theta)**18 + 1.55245644035788e+45*cos(theta)**16 - 4.19110850040372e+43*cos(theta)**14 + 8.47535274526086e+41*cos(theta)**12 - 1.22912169014989e+40*cos(theta)**10 + 1.20292466413104e+38*cos(theta)**8 - 7.25746403698969e+35*cos(theta)**6 + 2.32611026826593e+33*cos(theta)**4 - 2.96005548453776e+30*cos(theta)**2 + 6.23694792359411e+26)*sin(14*phi)

#@torch.jit.script
def Yl98_m_minus_13(theta, phi):
    return 7.07822422285425e-26*(1.0 - cos(theta)**2)**6.5*(6.03619440478976e+53*cos(theta)**85 - 1.10508789872305e+55*cos(theta)**83 + 9.74252362527082e+55*cos(theta)**81 - 5.50886152633114e+56*cos(theta)**79 + 2.24507967759606e+57*cos(theta)**77 - 7.02577875577121e+57*cos(theta)**75 + 1.7564446889428e+58*cos(theta)**73 - 3.6033853571754e+58*cos(theta)**71 + 6.18398661089839e+58*cos(theta)**69 - 9.00535852834738e+58*cos(theta)**67 + 1.12490665006644e+59*cos(theta)**65 - 1.2154835491627e+59*cos(theta)**63 + 1.14346790535393e+59*cos(theta)**61 - 9.41316359333195e+58*cos(theta)**59 + 6.80723707024132e+58*cos(theta)**57 - 4.33706601361483e+58*cos(theta)**55 + 2.43959963265834e+58*cos(theta)**53 - 1.21319678592681e+58*cos(theta)**51 + 5.3375634991604e+57*cos(theta)**49 - 2.07778042867019e+57*cos(theta)**47 + 7.15312306812889e+56*cos(theta)**45 - 2.17560425113598e+56*cos(theta)**43 + 5.83651407835943e+55*cos(theta)**41 - 1.37804248322912e+55*cos(theta)**39 + 2.85550749461068e+54*cos(theta)**37 - 5.17487888819241e+53*cos(theta)**35 + 8.16724917367237e+52*cos(theta)**33 - 1.11688877588682e+52*cos(theta)**31 + 1.3154845004746e+51*cos(theta)**29 - 1.3249484177442e+50*cos(theta)**27 + 1.13152529106621e+49*cos(theta)**25 - 8.11129240907681e+47*cos(theta)**23 + 4.82179741423034e+46*cos(theta)**21 - 2.34230269948733e+45*cos(theta)**19 + 9.13209670798752e+43*cos(theta)**17 - 2.79407233360248e+42*cos(theta)**15 + 6.51950211173912e+40*cos(theta)**13 - 1.11738335468172e+39*cos(theta)**11 + 1.3365829601456e+37*cos(theta)**9 - 1.03678057671281e+35*cos(theta)**7 + 4.65222053653185e+32*cos(theta)**5 - 9.86685161512588e+29*cos(theta)**3 + 6.23694792359411e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl98_m_minus_12(theta, phi):
    return 6.9156822533309e-24*(1.0 - cos(theta)**2)**6*(7.01883070324391e+51*cos(theta)**86 - 1.31558083181315e+53*cos(theta)**84 + 1.18811263722815e+54*cos(theta)**82 - 6.88607690791393e+54*cos(theta)**80 + 2.87830727896931e+55*cos(theta)**78 - 9.24444573127791e+55*cos(theta)**76 + 2.37357390397676e+56*cos(theta)**74 - 5.00470188496583e+56*cos(theta)**72 + 8.8342665869977e+56*cos(theta)**70 - 1.32431743063932e+57*cos(theta)**68 + 1.70440401525219e+57*cos(theta)**66 - 1.89919304556672e+57*cos(theta)**64 + 1.8443030731515e+57*cos(theta)**62 - 1.56886059888866e+57*cos(theta)**60 + 1.17366156383471e+57*cos(theta)**58 - 7.74476073859791e+56*cos(theta)**56 + 4.51777709751545e+56*cos(theta)**54 - 2.33307074216694e+56*cos(theta)**52 + 1.06751269983208e+56*cos(theta)**50 - 4.32870922639622e+55*cos(theta)**48 + 1.55502675394106e+55*cos(theta)**46 - 4.94455511621813e+54*cos(theta)**44 + 1.3896462091332e+54*cos(theta)**42 - 3.4451062080728e+53*cos(theta)**40 + 7.51449340687021e+52*cos(theta)**38 - 1.43746635783123e+52*cos(theta)**36 + 2.40213210990364e+51*cos(theta)**34 - 3.49027742464631e+50*cos(theta)**32 + 4.38494833491533e+49*cos(theta)**30 - 4.73195863480071e+48*cos(theta)**28 + 4.35202035025467e+47*cos(theta)**26 - 3.37970517044867e+46*cos(theta)**24 + 2.19172609737743e+45*cos(theta)**22 - 1.17115134974366e+44*cos(theta)**20 + 5.07338705999307e+42*cos(theta)**18 - 1.74629520850155e+41*cos(theta)**16 + 4.6567872226708e+39*cos(theta)**14 - 9.31152795568102e+37*cos(theta)**12 + 1.3365829601456e+36*cos(theta)**10 - 1.29597572089102e+34*cos(theta)**8 + 7.75370089421975e+31*cos(theta)**6 - 2.46671290378147e+29*cos(theta)**4 + 3.11847396179705e+26*cos(theta)**2 - 6.53357209678829e+22)*sin(12*phi)

#@torch.jit.script
def Yl98_m_minus_11(theta, phi):
    return 6.76536138020634e-22*(1.0 - cos(theta)**2)**5.5*(8.06762149798151e+49*cos(theta)**87 - 1.5477421550743e+51*cos(theta)**85 + 1.43146100870861e+52*cos(theta)**83 - 8.50132951594312e+52*cos(theta)**81 + 3.64342693540419e+53*cos(theta)**79 - 1.20057736769843e+54*cos(theta)**77 + 3.16476520530235e+54*cos(theta)**75 - 6.85575600680251e+54*cos(theta)**73 + 1.24426289957714e+55*cos(theta)**71 - 1.91930062411496e+55*cos(theta)**69 + 2.54388658992864e+55*cos(theta)**67 - 2.92183545471803e+55*cos(theta)**65 + 2.92746519547857e+55*cos(theta)**63 - 2.57190262112895e+55*cos(theta)**61 + 1.98925688785544e+55*cos(theta)**59 - 1.35872995413998e+55*cos(theta)**57 + 8.21414017730081e+54*cos(theta)**55 - 4.40202026823952e+54*cos(theta)**53 + 2.09316215653349e+54*cos(theta)**51 - 8.8341004620331e+53*cos(theta)**49 + 3.30856756157673e+53*cos(theta)**47 - 1.09879002582625e+53*cos(theta)**45 + 3.23173537007721e+52*cos(theta)**43 - 8.40269806847025e+51*cos(theta)**41 + 1.92679318124877e+51*cos(theta)**39 - 3.88504421035466e+50*cos(theta)**37 + 6.86323459972468e+49*cos(theta)**35 - 1.0576598256504e+49*cos(theta)**33 + 1.41449946287591e+48*cos(theta)**31 - 1.63170987406921e+47*cos(theta)**29 + 1.61185938898321e+46*cos(theta)**27 - 1.35188206817947e+45*cos(theta)**25 + 9.52924390164099e+43*cos(theta)**23 - 5.57691118925554e+42*cos(theta)**21 + 2.67020371578583e+41*cos(theta)**19 - 1.02723247558915e+40*cos(theta)**17 + 3.10452481511387e+38*cos(theta)**15 - 7.16271381206232e+36*cos(theta)**13 + 1.21507541831418e+35*cos(theta)**11 - 1.43997302321224e+33*cos(theta)**9 + 1.10767155631711e+31*cos(theta)**7 - 4.93342580756294e+28*cos(theta)**5 + 1.03949132059902e+26*cos(theta)**3 - 6.53357209678829e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl98_m_minus_10(theta, phi):
    return 6.62591079995136e-20*(1.0 - cos(theta)**2)**5*(9.16775170225171e+47*cos(theta)**88 - 1.79970018031895e+49*cos(theta)**86 + 1.70412024846263e+50*cos(theta)**84 - 1.03674750194428e+51*cos(theta)**82 + 4.55428366925524e+51*cos(theta)**80 - 1.53920175345953e+52*cos(theta)**78 + 4.16416474381888e+52*cos(theta)**76 - 9.26453514432772e+52*cos(theta)**74 + 1.72814291607936e+53*cos(theta)**72 - 2.74185803444994e+53*cos(theta)**70 + 3.74100969107153e+53*cos(theta)**68 - 4.42702341623945e+53*cos(theta)**66 + 4.57416436793527e+53*cos(theta)**64 - 4.14823003407895e+53*cos(theta)**62 + 3.31542814642573e+53*cos(theta)**60 - 2.34263785196549e+53*cos(theta)**58 + 1.46681074594657e+53*cos(theta)**56 - 8.15188938562874e+52*cos(theta)**54 + 4.02531183948748e+52*cos(theta)**52 - 1.76682009240662e+52*cos(theta)**50 + 6.89284908661818e+51*cos(theta)**48 - 2.3886739691875e+51*cos(theta)**46 + 7.34485311381183e+50*cos(theta)**44 - 2.00064239725482e+50*cos(theta)**42 + 4.81698295312193e+49*cos(theta)**40 - 1.02238005535649e+49*cos(theta)**38 + 1.90645405547908e+48*cos(theta)**36 - 3.11076419308941e+47*cos(theta)**34 + 4.42031082148723e+46*cos(theta)**32 - 5.43903291356404e+45*cos(theta)**30 + 5.75664067494004e+44*cos(theta)**28 - 5.19954641607488e+43*cos(theta)**26 + 3.97051829235041e+42*cos(theta)**24 - 2.53495963147979e+41*cos(theta)**22 + 1.33510185789291e+40*cos(theta)**20 - 5.70684708660638e+38*cos(theta)**18 + 1.94032800944617e+37*cos(theta)**16 - 5.11622415147309e+35*cos(theta)**14 + 1.01256284859515e+34*cos(theta)**12 - 1.43997302321224e+32*cos(theta)**10 + 1.38458944539638e+30*cos(theta)**8 - 8.22237634593823e+27*cos(theta)**6 + 2.59872830149754e+25*cos(theta)**4 - 3.26678604839415e+22*cos(theta)**2 + 6.81148050123884e+18)*sin(10*phi)

#@torch.jit.script
def Yl98_m_minus_9(theta, phi):
    return 6.49609647438139e-18*(1.0 - cos(theta)**2)**4.5*(1.03008446092716e+46*cos(theta)**89 - 2.06862089691833e+47*cos(theta)**87 + 2.00484735113251e+48*cos(theta)**85 - 1.24909337583649e+49*cos(theta)**83 + 5.62257243117931e+49*cos(theta)**81 - 1.94835664994877e+50*cos(theta)**79 + 5.40800616080374e+50*cos(theta)**77 - 1.23527135257703e+51*cos(theta)**75 + 2.36731906312241e+51*cos(theta)**73 - 3.86177187950696e+51*cos(theta)**71 + 5.42175317546598e+51*cos(theta)**69 - 6.60749763617828e+51*cos(theta)**67 + 7.03717595066964e+51*cos(theta)**65 - 6.58449211758563e+51*cos(theta)**63 + 5.43512810889465e+51*cos(theta)**61 - 3.97057263044998e+51*cos(theta)**59 + 2.57335218587118e+51*cos(theta)**57 - 1.48216170647795e+51*cos(theta)**55 + 7.59492799903298e+50*cos(theta)**53 - 3.46435312236592e+50*cos(theta)**51 + 1.4067038952282e+50*cos(theta)**49 - 5.08228504082447e+49*cos(theta)**47 + 1.63218958084707e+49*cos(theta)**45 - 4.65265673780191e+48*cos(theta)**43 + 1.17487389100535e+48*cos(theta)**41 - 2.6214873214269e+47*cos(theta)**39 + 5.15257852832184e+46*cos(theta)**37 - 8.88789769454116e+45*cos(theta)**35 + 1.3394881277234e+45*cos(theta)**33 - 1.75452674631098e+44*cos(theta)**31 + 1.98504850860001e+43*cos(theta)**29 - 1.92575793187958e+42*cos(theta)**27 + 1.58820731694016e+41*cos(theta)**25 - 1.10215636151295e+40*cos(theta)**23 + 6.35762789472816e+38*cos(theta)**21 - 3.00360372979283e+37*cos(theta)**19 + 1.14136941732128e+36*cos(theta)**17 - 3.41081610098206e+34*cos(theta)**15 + 7.78894498919348e+32*cos(theta)**13 - 1.3090663847384e+31*cos(theta)**11 + 1.53843271710709e+29*cos(theta)**9 - 1.17462519227689e+27*cos(theta)**7 + 5.19745660299509e+24*cos(theta)**5 - 1.08892868279805e+22*cos(theta)**3 + 6.81148050123884e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl98_m_minus_8(theta, phi):
    return 6.37478599142786e-16*(1.0 - cos(theta)**2)**4*(1.14453828991907e+44*cos(theta)**90 - 2.35070556467993e+45*cos(theta)**88 + 2.33121785015408e+46*cos(theta)**86 - 1.48701592361486e+47*cos(theta)**84 + 6.85679564777965e+47*cos(theta)**82 - 2.43544581243596e+48*cos(theta)**80 + 6.93334123179967e+48*cos(theta)**78 - 1.62535704286451e+49*cos(theta)**76 + 3.19907981503029e+49*cos(theta)**74 - 5.36357205487077e+49*cos(theta)**72 + 7.74536167923711e+49*cos(theta)**70 - 9.71690828849747e+49*cos(theta)**68 + 1.06623878040449e+50*cos(theta)**66 - 1.02882689337275e+50*cos(theta)**64 + 8.76633565950749e+49*cos(theta)**62 - 6.61762105074997e+49*cos(theta)**60 + 4.436814113571e+49*cos(theta)**58 - 2.64671733299634e+49*cos(theta)**56 + 1.40646814796907e+49*cos(theta)**54 - 6.66221754301139e+48*cos(theta)**52 + 2.8134077904564e+48*cos(theta)**50 - 1.0588093835051e+48*cos(theta)**48 + 3.54823821923277e+47*cos(theta)**46 - 1.05742198586407e+47*cos(theta)**44 + 2.79731878810797e+46*cos(theta)**42 - 6.55371830356725e+45*cos(theta)**40 + 1.35594171797943e+45*cos(theta)**38 - 2.46886047070588e+44*cos(theta)**36 + 3.93967096389236e+43*cos(theta)**34 - 5.48289608222181e+42*cos(theta)**32 + 6.61682836200005e+41*cos(theta)**30 - 6.87770689956994e+40*cos(theta)**28 + 6.10848968053909e+39*cos(theta)**26 - 4.59231817297063e+38*cos(theta)**24 + 2.88983086124007e+37*cos(theta)**22 - 1.50180186489641e+36*cos(theta)**20 + 6.34094120734042e+34*cos(theta)**18 - 2.13176006311379e+33*cos(theta)**16 + 5.5635321351382e+31*cos(theta)**14 - 1.09088865394867e+30*cos(theta)**12 + 1.53843271710709e+28*cos(theta)**10 - 1.46828149034611e+26*cos(theta)**8 + 8.66242767165848e+23*cos(theta)**6 - 2.72232170699512e+21*cos(theta)**4 + 3.40574025061942e+18*cos(theta)**2 - 707318847480669.0)*sin(8*phi)

#@torch.jit.script
def Yl98_m_minus_7(theta, phi):
    return 6.26093562518037e-14*(1.0 - cos(theta)**2)**3.5*(1.25773438452644e+42*cos(theta)**91 - 2.64124220750553e+43*cos(theta)**89 + 2.67956074730354e+44*cos(theta)**87 - 1.74943049837043e+45*cos(theta)**85 + 8.26119957563813e+45*cos(theta)**83 - 3.00672322522958e+46*cos(theta)**81 + 8.77638130607553e+46*cos(theta)**79 - 2.11085330242144e+47*cos(theta)**77 + 4.26543975337372e+47*cos(theta)**75 - 7.34735897927503e+47*cos(theta)**73 + 1.09089601116016e+48*cos(theta)**71 - 1.40824757804311e+48*cos(theta)**69 + 1.59140116478282e+48*cos(theta)**67 - 1.58281060518885e+48*cos(theta)**65 + 1.39148185071548e+48*cos(theta)**63 - 1.08485590995901e+48*cos(theta)**61 + 7.52002392130678e+47*cos(theta)**59 - 4.64336374209885e+47*cos(theta)**57 + 2.55721481448922e+47*cos(theta)**55 - 1.25702217792668e+47*cos(theta)**53 + 5.51648586364e+46*cos(theta)**51 - 2.16083547654102e+46*cos(theta)**49 + 7.54944301964419e+45*cos(theta)**47 - 2.34982663525349e+45*cos(theta)**45 + 6.50539253048365e+44*cos(theta)**43 - 1.59846787891884e+44*cos(theta)**41 + 3.47677363584469e+43*cos(theta)**39 - 6.67259586677264e+42*cos(theta)**37 + 1.12562027539782e+42*cos(theta)**35 - 1.66148366127934e+41*cos(theta)**33 + 2.1344607619355e+40*cos(theta)**31 - 2.37162306881722e+39*cos(theta)**29 + 2.26240358538485e+38*cos(theta)**27 - 1.83692726918825e+37*cos(theta)**25 + 1.25644820053916e+36*cos(theta)**23 - 7.15143745188769e+34*cos(theta)**21 + 3.33733747754759e+33*cos(theta)**19 - 1.25397650771399e+32*cos(theta)**17 + 3.70902142342546e+30*cos(theta)**15 - 8.39145118422051e+28*cos(theta)**13 + 1.39857519737008e+27*cos(theta)**11 - 1.63142387816235e+25*cos(theta)**9 + 1.23748966737978e+23*cos(theta)**7 - 5.44464341399025e+20*cos(theta)**5 + 1.13524675020647e+18*cos(theta)**3 - 707318847480669.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl98_m_minus_6(theta, phi):
    return 6.15357929955912e-12*(1.0 - cos(theta)**2)**3*(1.36710259187657e+40*cos(theta)**92 - 2.93471356389504e+41*cos(theta)**90 + 3.04495539466312e+42*cos(theta)**88 - 2.03422150973306e+43*cos(theta)**86 + 9.83476139956921e+43*cos(theta)**84 - 3.66673564052388e+44*cos(theta)**82 + 1.09704766325944e+45*cos(theta)**80 - 2.7062221825916e+45*cos(theta)**78 + 5.61242072812332e+45*cos(theta)**76 - 9.9288634855068e+45*cos(theta)**74 + 1.51513334883355e+46*cos(theta)**72 - 2.0117822543473e+46*cos(theta)**70 + 2.34029583056297e+46*cos(theta)**68 - 2.39819788664978e+46*cos(theta)**66 + 2.17419039174293e+46*cos(theta)**64 - 1.74976759670808e+46*cos(theta)**62 + 1.2533373202178e+46*cos(theta)**60 - 8.00579955534284e+45*cos(theta)**58 + 4.56645502587361e+45*cos(theta)**56 - 2.32781884801237e+45*cos(theta)**54 + 1.06086266608462e+45*cos(theta)**52 - 4.32167095308203e+44*cos(theta)**50 + 1.57280062909254e+44*cos(theta)**48 - 5.10831877229019e+43*cos(theta)**46 + 1.47849830238265e+43*cos(theta)**44 - 3.80587590218772e+42*cos(theta)**42 + 8.69193408961173e+41*cos(theta)**40 - 1.75594628072964e+41*cos(theta)**38 + 3.12672298721616e+40*cos(theta)**36 - 4.88671665082158e+39*cos(theta)**34 + 6.67018988104843e+38*cos(theta)**32 - 7.90541022939074e+37*cos(theta)**30 + 8.08001280494589e+36*cos(theta)**28 - 7.06510488149328e+35*cos(theta)**26 + 5.23520083557984e+34*cos(theta)**24 - 3.25065338722168e+33*cos(theta)**22 + 1.66866873877379e+32*cos(theta)**20 - 6.96653615396662e+30*cos(theta)**18 + 2.31813838964092e+29*cos(theta)**16 - 5.99389370301465e+27*cos(theta)**14 + 1.16547933114174e+26*cos(theta)**12 - 1.63142387816235e+24*cos(theta)**10 + 1.54686208422473e+22*cos(theta)**8 - 9.07440568998374e+19*cos(theta)**6 + 2.83811687551618e+17*cos(theta)**4 - 353659423740334.0*cos(theta)**2 + 73221412782.6779)*sin(6*phi)

#@torch.jit.script
def Yl98_m_minus_5(theta, phi):
    return 6.05181920938943e-10*(1.0 - cos(theta)**2)**2.5*(1.47000278696405e+38*cos(theta)**93 - 3.22495996032422e+39*cos(theta)**91 + 3.42129819625069e+40*cos(theta)**89 - 2.33818564337133e+41*cos(theta)**87 + 1.15703075289049e+42*cos(theta)**85 - 4.41775378376371e+42*cos(theta)**83 + 1.35437983118449e+43*cos(theta)**81 - 3.42559769948303e+43*cos(theta)**79 + 7.28885808847184e+43*cos(theta)**77 - 1.32384846473424e+44*cos(theta)**75 + 2.07552513538843e+44*cos(theta)**73 - 2.83349613288352e+44*cos(theta)**71 + 3.39173308777243e+44*cos(theta)**69 - 3.57939983082056e+44*cos(theta)**67 + 3.34490829498912e+44*cos(theta)**65 - 2.77740888366362e+44*cos(theta)**63 + 2.05465134461934e+44*cos(theta)**61 - 1.35691517887167e+44*cos(theta)**59 + 8.0113246067958e+43*cos(theta)**57 - 4.23239790547703e+43*cos(theta)**55 + 2.00162767185777e+43*cos(theta)**53 - 8.47386461388633e+42*cos(theta)**51 + 3.20979720222967e+42*cos(theta)**49 - 1.08687633452983e+42*cos(theta)**47 + 3.28555178307255e+41*cos(theta)**45 - 8.85087419113422e+40*cos(theta)**43 + 2.11998392429554e+40*cos(theta)**41 - 4.50242636084524e+39*cos(theta)**39 + 8.45060266815178e+38*cos(theta)**37 - 1.39620475737759e+38*cos(theta)**35 + 2.02126966092377e+37*cos(theta)**33 - 2.55013233206153e+36*cos(theta)**31 + 2.78621131205031e+35*cos(theta)**29 - 2.61670551166418e+34*cos(theta)**27 + 2.09408033423194e+33*cos(theta)**25 - 1.4133275596616e+32*cos(theta)**23 + 7.94604161320854e+30*cos(theta)**21 - 3.66659797577191e+29*cos(theta)**19 + 1.36361081743583e+28*cos(theta)**17 - 3.9959291353431e+26*cos(theta)**15 + 8.96522562416721e+24*cos(theta)**13 - 1.48311261651122e+23*cos(theta)**11 + 1.71873564913859e+21*cos(theta)**9 - 1.29634366999768e+19*cos(theta)**7 + 5.67623375103237e+16*cos(theta)**5 - 117886474580111.0*cos(theta)**3 + 73221412782.6779*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl98_m_minus_4(theta, phi):
    return 5.95481789331153e-8*(1.0 - cos(theta)**2)**2*(1.56383275208942e+36*cos(theta)**94 - 3.50539126122198e+37*cos(theta)**92 + 3.80144244027855e+38*cos(theta)**90 - 2.65702914019469e+39*cos(theta)**88 + 1.3453845963843e+40*cos(theta)**86 - 5.25923069495679e+40*cos(theta)**84 + 1.6516827209567e+41*cos(theta)**82 - 4.28199712435379e+41*cos(theta)**80 + 9.34468985701518e+41*cos(theta)**78 - 1.74190587465031e+42*cos(theta)**76 + 2.80476369647085e+42*cos(theta)**74 - 3.93541129567156e+42*cos(theta)**72 + 4.84533298253204e+42*cos(theta)**70 - 5.26382328061848e+42*cos(theta)**68 + 5.06804287119564e+42*cos(theta)**66 - 4.33970138072441e+42*cos(theta)**64 + 3.3139537816441e+42*cos(theta)**62 - 2.26152529811945e+42*cos(theta)**60 + 1.38126286324066e+42*cos(theta)**58 - 7.55785340263755e+41*cos(theta)**56 + 3.70671791084772e+41*cos(theta)**54 - 1.6295893488243e+41*cos(theta)**52 + 6.41959440445934e+40*cos(theta)**50 - 2.26432569693714e+40*cos(theta)**48 + 7.14250387624468e+39*cos(theta)**46 - 2.01156231616687e+39*cos(theta)**44 + 5.04758077213225e+38*cos(theta)**42 - 1.12560659021131e+38*cos(theta)**40 + 2.22384280740836e+37*cos(theta)**38 - 3.8783465482711e+36*cos(theta)**36 + 5.94491076742285e+35*cos(theta)**34 - 7.96916353769228e+34*cos(theta)**32 + 9.28737104016769e+33*cos(theta)**30 - 9.34537682737207e+32*cos(theta)**28 + 8.05415513166129e+31*cos(theta)**26 - 5.88886483192333e+30*cos(theta)**24 + 3.61183709691297e+29*cos(theta)**22 - 1.83329898788595e+28*cos(theta)**20 + 7.57561565242129e+26*cos(theta)**18 - 2.49745570958944e+25*cos(theta)**16 + 6.40373258869086e+23*cos(theta)**14 - 1.23592718042602e+22*cos(theta)**12 + 1.71873564913859e+20*cos(theta)**10 - 1.6204295874971e+18*cos(theta)**8 + 9.46038958505394e+15*cos(theta)**6 - 29471618645027.9*cos(theta)**4 + 36610706391.339*cos(theta)**2 - 7562633.00791964)*sin(4*phi)

#@torch.jit.script
def Yl98_m_minus_3(theta, phi):
    return 5.86179158637405e-6*(1.0 - cos(theta)**2)**1.5*(1.64613973904149e+34*cos(theta)**95 - 3.76923791529245e+35*cos(theta)**93 + 4.17740927503137e+36*cos(theta)**91 - 2.98542600021875e+37*cos(theta)**89 + 1.54641907630379e+38*cos(theta)**87 - 6.18733022936093e+38*cos(theta)**85 + 1.98997918187554e+39*cos(theta)**83 - 5.28641620290591e+39*cos(theta)**81 + 1.18287213379939e+40*cos(theta)**79 - 2.26221542162379e+40*cos(theta)**77 + 3.7396849286278e+40*cos(theta)**75 - 5.39097437763228e+40*cos(theta)**73 + 6.82441265145358e+40*cos(theta)**71 - 7.62872939220069e+40*cos(theta)**69 + 7.56424309133678e+40*cos(theta)**67 - 6.67646366265294e+40*cos(theta)**65 + 5.26024409784777e+40*cos(theta)**63 - 3.70741852150729e+40*cos(theta)**61 + 2.34112349701806e+40*cos(theta)**59 - 1.32593919344518e+40*cos(theta)**57 + 6.73948711063221e+39*cos(theta)**55 - 3.07469688457414e+39*cos(theta)**53 + 1.25874400087438e+39*cos(theta)**51 - 4.62107285089213e+38*cos(theta)**49 + 1.51968167579674e+38*cos(theta)**47 - 4.47013848037082e+37*cos(theta)**45 + 1.17385599351913e+37*cos(theta)**43 - 2.74538192734466e+36*cos(theta)**41 + 5.70216104463683e+35*cos(theta)**39 - 1.048201769803e+35*cos(theta)**37 + 1.69854593354939e+34*cos(theta)**35 - 2.41489804172493e+33*cos(theta)**33 + 2.99592614198958e+32*cos(theta)**31 - 3.22254373357658e+31*cos(theta)**29 + 2.98302041913381e+30*cos(theta)**27 - 2.35554593276933e+29*cos(theta)**25 + 1.57036395517955e+28*cos(theta)**23 - 8.7299951804093e+26*cos(theta)**21 + 3.98716613285331e+25*cos(theta)**19 - 1.46909159387614e+24*cos(theta)**17 + 4.26915505912724e+22*cos(theta)**15 - 9.50713215712323e+20*cos(theta)**13 + 1.56248695376235e+19*cos(theta)**11 - 1.80047731944122e+17*cos(theta)**9 + 1.35148422643628e+15*cos(theta)**7 - 5894323729005.57*cos(theta)**5 + 12203568797.113*cos(theta)**3 - 7562633.00791964*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl98_m_minus_2(theta, phi):
    return 0.000577200470753292*(1.0 - cos(theta)**2)*(1.71472889483489e+32*cos(theta)**96 - 4.00982756946005e+33*cos(theta)**94 + 4.54066225546888e+34*cos(theta)**92 - 3.31714000024306e+35*cos(theta)**90 + 1.75729440489067e+36*cos(theta)**88 - 7.19457003414062e+36*cos(theta)**86 + 2.36902283556612e+37*cos(theta)**84 - 6.44684902793404e+37*cos(theta)**82 + 1.47859016724924e+38*cos(theta)**80 - 2.90027618156896e+38*cos(theta)**78 + 4.92063806398394e+38*cos(theta)**76 - 7.28510051031389e+38*cos(theta)**74 + 9.47835090479663e+38*cos(theta)**72 - 1.0898184846001e+39*cos(theta)**70 + 1.11238868990247e+39*cos(theta)**68 - 1.01158540343226e+39*cos(theta)**66 + 8.21913140288714e+38*cos(theta)**64 - 5.97970729275369e+38*cos(theta)**62 + 3.9018724950301e+38*cos(theta)**60 - 2.28610205766411e+38*cos(theta)**58 + 1.20347984118432e+38*cos(theta)**56 - 5.69388311958174e+37*cos(theta)**54 + 2.42066154014304e+37*cos(theta)**52 - 9.24214570178426e+36*cos(theta)**50 + 3.16600349124321e+36*cos(theta)**48 - 9.71769234863222e+35*cos(theta)**46 + 2.66785453072529e+35*cos(theta)**44 - 6.5366236365349e+34*cos(theta)**42 + 1.42554026115921e+34*cos(theta)**40 - 2.75842571000789e+33*cos(theta)**38 + 4.71818314874829e+32*cos(theta)**36 - 7.10264129919098e+31*cos(theta)**34 + 9.36226919371743e+30*cos(theta)**32 - 1.07418124452553e+30*cos(theta)**30 + 1.06536443540493e+29*cos(theta)**28 - 9.05979204911281e+27*cos(theta)**26 + 6.54318314658148e+26*cos(theta)**24 - 3.96817962745877e+25*cos(theta)**22 + 1.99358306642666e+24*cos(theta)**20 - 8.16161996597855e+22*cos(theta)**18 + 2.66822191195453e+21*cos(theta)**16 - 6.79080868365945e+19*cos(theta)**14 + 1.30207246146863e+18*cos(theta)**12 - 1.80047731944122e+16*cos(theta)**10 + 168935528304535.0*cos(theta)**8 - 982387288167.595*cos(theta)**6 + 3050892199.27825*cos(theta)**4 - 3781316.50395982*cos(theta)**2 + 779.974526394352)*sin(2*phi)

#@torch.jit.script
def Yl98_m_minus_1(theta, phi):
    return 0.0568476535957895*(1.0 - cos(theta)**2)**0.5*(1.76776174725246e+30*cos(theta)**97 - 4.22087112574742e+31*cos(theta)**95 + 4.88243253276224e+32*cos(theta)**93 - 3.64520879147589e+33*cos(theta)**91 + 1.97448809538277e+34*cos(theta)**89 - 8.26962072889727e+34*cos(theta)**87 + 2.78708568890132e+35*cos(theta)**85 - 7.7672879854627e+35*cos(theta)**83 + 1.82541995956696e+36*cos(theta)**81 - 3.6712356728721e+36*cos(theta)**79 + 6.39043904413499e+36*cos(theta)**77 - 9.71346734708518e+36*cos(theta)**75 + 1.29840423353379e+37*cos(theta)**73 - 1.53495561211281e+37*cos(theta)**71 + 1.61215752159778e+37*cos(theta)**69 - 1.50982896034666e+37*cos(theta)**67 + 1.26448175429033e+37*cos(theta)**65 - 9.49159887738681e+36*cos(theta)**63 + 6.39651228693459e+36*cos(theta)**61 - 3.87474925027815e+36*cos(theta)**59 + 2.11136814242864e+36*cos(theta)**57 - 1.03525147628759e+36*cos(theta)**55 + 4.56728592479819e+35*cos(theta)**53 - 1.8121854317224e+35*cos(theta)**51 + 6.46123161478206e+34*cos(theta)**49 - 2.06759411673026e+34*cos(theta)**47 + 5.92856562383398e+33*cos(theta)**45 - 1.5201450317523e+33*cos(theta)**43 + 3.47692746624197e+32*cos(theta)**41 - 7.07288643591767e+31*cos(theta)**39 + 1.27518463479684e+31*cos(theta)**37 - 2.02932608548314e+30*cos(theta)**35 + 2.83705127082346e+29*cos(theta)**33 - 3.46510078879202e+28*cos(theta)**31 + 3.67367046691356e+27*cos(theta)**29 - 3.35547853670845e+26*cos(theta)**27 + 2.61727325863259e+25*cos(theta)**25 - 1.72529549019947e+24*cos(theta)**23 + 9.49325269726979e+22*cos(theta)**21 - 4.29558945577819e+21*cos(theta)**19 + 1.56954230114972e+20*cos(theta)**17 - 4.5272057891063e+18*cos(theta)**15 + 1.00159420112971e+17*cos(theta)**13 - 1.63679756312838e+15*cos(theta)**11 + 18770614256059.4*cos(theta)**9 - 140341041166.799*cos(theta)**7 + 610178439.855649*cos(theta)**5 - 1260438.83465327*cos(theta)**3 + 779.974526394352*cos(theta))*sin(phi)

#@torch.jit.script
def Yl98_m0(theta, phi):
    return 2.24375642744678e+29*cos(theta)**98 - 5.46901246136131e+30*cos(theta)**96 + 6.46080228596052e+31*cos(theta)**94 - 4.92847587991857e+32*cos(theta)**92 + 2.72891534832528e+33*cos(theta)**90 - 1.16890972941634e+34*cos(theta)**88 + 4.03115895874391e+34*cos(theta)**86 - 1.15018626028173e+35*cos(theta)**84 + 2.7690257619766e+35*cos(theta)**82 - 5.70821511826461e+35*cos(theta)**80 + 1.01909377252634e+36*cos(theta)**78 - 1.58978628514109e+36*cos(theta)**76 + 2.18251007353184e+36*cos(theta)**74 - 2.65180373756613e+36*cos(theta)**72 + 2.86475500981362e+36*cos(theta)**70 - 2.76182968011971e+36*cos(theta)**68 + 2.38312424670936e+36*cos(theta)**66 - 1.84474973265665e+36*cos(theta)**64 + 1.2833041618481e+36*cos(theta)**62 - 8.03286385321008e+35*cos(theta)**60 + 4.5280793057904e+35*cos(theta)**58 - 2.29951308524471e+35*cos(theta)**56 + 1.05206481024268e+35*cos(theta)**54 - 4.33488264744391e+34*cos(theta)**52 + 1.60739776020991e+34*cos(theta)**50 - 5.35799253403302e+33*cos(theta)**48 + 1.60313410567354e+33*cos(theta)**46 - 4.29744573781952e+32*cos(theta)**44 + 1.02973243869738e+32*cos(theta)**42 - 2.19945331113482e+31*cos(theta)**40 + 4.17414497003688e+30*cos(theta)**38 - 7.01176562469756e+29*cos(theta)**36 + 1.03792583260326e+29*cos(theta)**34 - 1.34692665299659e+28*cos(theta)**32 + 1.52320022773897e+27*cos(theta)**30 - 1.49064589216299e+26*cos(theta)**28 + 1.25214254941691e+25*cos(theta)**26 - 8.94191009801136e+23*cos(theta)**24 + 5.36747974565275e+22*cos(theta)**22 - 2.67159625349232e+21*cos(theta)**20 + 1.08462241060586e+20*cos(theta)**18 - 3.51955946601688e+18*cos(theta)**16 + 8.89901255630059e+16*cos(theta)**14 - 1.69664810941411e+15*cos(theta)**12 + 23348368478175.8*cos(theta)**10 - 218209051197.905*cos(theta)**8 + 1264980006.94437*cos(theta)**6 - 3919582.75235811*cos(theta)**4 + 4850.96875291845*cos(theta)**2 - 0.999993558630891

#@torch.jit.script
def Yl98_m1(theta, phi):
    return 0.0568476535957895*(1.0 - cos(theta)**2)**0.5*(1.76776174725246e+30*cos(theta)**97 - 4.22087112574742e+31*cos(theta)**95 + 4.88243253276224e+32*cos(theta)**93 - 3.64520879147589e+33*cos(theta)**91 + 1.97448809538277e+34*cos(theta)**89 - 8.26962072889727e+34*cos(theta)**87 + 2.78708568890132e+35*cos(theta)**85 - 7.7672879854627e+35*cos(theta)**83 + 1.82541995956696e+36*cos(theta)**81 - 3.6712356728721e+36*cos(theta)**79 + 6.39043904413499e+36*cos(theta)**77 - 9.71346734708518e+36*cos(theta)**75 + 1.29840423353379e+37*cos(theta)**73 - 1.53495561211281e+37*cos(theta)**71 + 1.61215752159778e+37*cos(theta)**69 - 1.50982896034666e+37*cos(theta)**67 + 1.26448175429033e+37*cos(theta)**65 - 9.49159887738681e+36*cos(theta)**63 + 6.39651228693459e+36*cos(theta)**61 - 3.87474925027815e+36*cos(theta)**59 + 2.11136814242864e+36*cos(theta)**57 - 1.03525147628759e+36*cos(theta)**55 + 4.56728592479819e+35*cos(theta)**53 - 1.8121854317224e+35*cos(theta)**51 + 6.46123161478206e+34*cos(theta)**49 - 2.06759411673026e+34*cos(theta)**47 + 5.92856562383398e+33*cos(theta)**45 - 1.5201450317523e+33*cos(theta)**43 + 3.47692746624197e+32*cos(theta)**41 - 7.07288643591767e+31*cos(theta)**39 + 1.27518463479684e+31*cos(theta)**37 - 2.02932608548314e+30*cos(theta)**35 + 2.83705127082346e+29*cos(theta)**33 - 3.46510078879202e+28*cos(theta)**31 + 3.67367046691356e+27*cos(theta)**29 - 3.35547853670845e+26*cos(theta)**27 + 2.61727325863259e+25*cos(theta)**25 - 1.72529549019947e+24*cos(theta)**23 + 9.49325269726979e+22*cos(theta)**21 - 4.29558945577819e+21*cos(theta)**19 + 1.56954230114972e+20*cos(theta)**17 - 4.5272057891063e+18*cos(theta)**15 + 1.00159420112971e+17*cos(theta)**13 - 1.63679756312838e+15*cos(theta)**11 + 18770614256059.4*cos(theta)**9 - 140341041166.799*cos(theta)**7 + 610178439.855649*cos(theta)**5 - 1260438.83465327*cos(theta)**3 + 779.974526394352*cos(theta))*cos(phi)

#@torch.jit.script
def Yl98_m2(theta, phi):
    return 0.000577200470753292*(1.0 - cos(theta)**2)*(1.71472889483489e+32*cos(theta)**96 - 4.00982756946005e+33*cos(theta)**94 + 4.54066225546888e+34*cos(theta)**92 - 3.31714000024306e+35*cos(theta)**90 + 1.75729440489067e+36*cos(theta)**88 - 7.19457003414062e+36*cos(theta)**86 + 2.36902283556612e+37*cos(theta)**84 - 6.44684902793404e+37*cos(theta)**82 + 1.47859016724924e+38*cos(theta)**80 - 2.90027618156896e+38*cos(theta)**78 + 4.92063806398394e+38*cos(theta)**76 - 7.28510051031389e+38*cos(theta)**74 + 9.47835090479663e+38*cos(theta)**72 - 1.0898184846001e+39*cos(theta)**70 + 1.11238868990247e+39*cos(theta)**68 - 1.01158540343226e+39*cos(theta)**66 + 8.21913140288714e+38*cos(theta)**64 - 5.97970729275369e+38*cos(theta)**62 + 3.9018724950301e+38*cos(theta)**60 - 2.28610205766411e+38*cos(theta)**58 + 1.20347984118432e+38*cos(theta)**56 - 5.69388311958174e+37*cos(theta)**54 + 2.42066154014304e+37*cos(theta)**52 - 9.24214570178426e+36*cos(theta)**50 + 3.16600349124321e+36*cos(theta)**48 - 9.71769234863222e+35*cos(theta)**46 + 2.66785453072529e+35*cos(theta)**44 - 6.5366236365349e+34*cos(theta)**42 + 1.42554026115921e+34*cos(theta)**40 - 2.75842571000789e+33*cos(theta)**38 + 4.71818314874829e+32*cos(theta)**36 - 7.10264129919098e+31*cos(theta)**34 + 9.36226919371743e+30*cos(theta)**32 - 1.07418124452553e+30*cos(theta)**30 + 1.06536443540493e+29*cos(theta)**28 - 9.05979204911281e+27*cos(theta)**26 + 6.54318314658148e+26*cos(theta)**24 - 3.96817962745877e+25*cos(theta)**22 + 1.99358306642666e+24*cos(theta)**20 - 8.16161996597855e+22*cos(theta)**18 + 2.66822191195453e+21*cos(theta)**16 - 6.79080868365945e+19*cos(theta)**14 + 1.30207246146863e+18*cos(theta)**12 - 1.80047731944122e+16*cos(theta)**10 + 168935528304535.0*cos(theta)**8 - 982387288167.595*cos(theta)**6 + 3050892199.27825*cos(theta)**4 - 3781316.50395982*cos(theta)**2 + 779.974526394352)*cos(2*phi)

#@torch.jit.script
def Yl98_m3(theta, phi):
    return 5.86179158637405e-6*(1.0 - cos(theta)**2)**1.5*(1.64613973904149e+34*cos(theta)**95 - 3.76923791529245e+35*cos(theta)**93 + 4.17740927503137e+36*cos(theta)**91 - 2.98542600021875e+37*cos(theta)**89 + 1.54641907630379e+38*cos(theta)**87 - 6.18733022936093e+38*cos(theta)**85 + 1.98997918187554e+39*cos(theta)**83 - 5.28641620290591e+39*cos(theta)**81 + 1.18287213379939e+40*cos(theta)**79 - 2.26221542162379e+40*cos(theta)**77 + 3.7396849286278e+40*cos(theta)**75 - 5.39097437763228e+40*cos(theta)**73 + 6.82441265145358e+40*cos(theta)**71 - 7.62872939220069e+40*cos(theta)**69 + 7.56424309133678e+40*cos(theta)**67 - 6.67646366265294e+40*cos(theta)**65 + 5.26024409784777e+40*cos(theta)**63 - 3.70741852150729e+40*cos(theta)**61 + 2.34112349701806e+40*cos(theta)**59 - 1.32593919344518e+40*cos(theta)**57 + 6.73948711063221e+39*cos(theta)**55 - 3.07469688457414e+39*cos(theta)**53 + 1.25874400087438e+39*cos(theta)**51 - 4.62107285089213e+38*cos(theta)**49 + 1.51968167579674e+38*cos(theta)**47 - 4.47013848037082e+37*cos(theta)**45 + 1.17385599351913e+37*cos(theta)**43 - 2.74538192734466e+36*cos(theta)**41 + 5.70216104463683e+35*cos(theta)**39 - 1.048201769803e+35*cos(theta)**37 + 1.69854593354939e+34*cos(theta)**35 - 2.41489804172493e+33*cos(theta)**33 + 2.99592614198958e+32*cos(theta)**31 - 3.22254373357658e+31*cos(theta)**29 + 2.98302041913381e+30*cos(theta)**27 - 2.35554593276933e+29*cos(theta)**25 + 1.57036395517955e+28*cos(theta)**23 - 8.7299951804093e+26*cos(theta)**21 + 3.98716613285331e+25*cos(theta)**19 - 1.46909159387614e+24*cos(theta)**17 + 4.26915505912724e+22*cos(theta)**15 - 9.50713215712323e+20*cos(theta)**13 + 1.56248695376235e+19*cos(theta)**11 - 1.80047731944122e+17*cos(theta)**9 + 1.35148422643628e+15*cos(theta)**7 - 5894323729005.57*cos(theta)**5 + 12203568797.113*cos(theta)**3 - 7562633.00791964*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl98_m4(theta, phi):
    return 5.95481789331153e-8*(1.0 - cos(theta)**2)**2*(1.56383275208942e+36*cos(theta)**94 - 3.50539126122198e+37*cos(theta)**92 + 3.80144244027855e+38*cos(theta)**90 - 2.65702914019469e+39*cos(theta)**88 + 1.3453845963843e+40*cos(theta)**86 - 5.25923069495679e+40*cos(theta)**84 + 1.6516827209567e+41*cos(theta)**82 - 4.28199712435379e+41*cos(theta)**80 + 9.34468985701518e+41*cos(theta)**78 - 1.74190587465031e+42*cos(theta)**76 + 2.80476369647085e+42*cos(theta)**74 - 3.93541129567156e+42*cos(theta)**72 + 4.84533298253204e+42*cos(theta)**70 - 5.26382328061848e+42*cos(theta)**68 + 5.06804287119564e+42*cos(theta)**66 - 4.33970138072441e+42*cos(theta)**64 + 3.3139537816441e+42*cos(theta)**62 - 2.26152529811945e+42*cos(theta)**60 + 1.38126286324066e+42*cos(theta)**58 - 7.55785340263755e+41*cos(theta)**56 + 3.70671791084772e+41*cos(theta)**54 - 1.6295893488243e+41*cos(theta)**52 + 6.41959440445934e+40*cos(theta)**50 - 2.26432569693714e+40*cos(theta)**48 + 7.14250387624468e+39*cos(theta)**46 - 2.01156231616687e+39*cos(theta)**44 + 5.04758077213225e+38*cos(theta)**42 - 1.12560659021131e+38*cos(theta)**40 + 2.22384280740836e+37*cos(theta)**38 - 3.8783465482711e+36*cos(theta)**36 + 5.94491076742285e+35*cos(theta)**34 - 7.96916353769228e+34*cos(theta)**32 + 9.28737104016769e+33*cos(theta)**30 - 9.34537682737207e+32*cos(theta)**28 + 8.05415513166129e+31*cos(theta)**26 - 5.88886483192333e+30*cos(theta)**24 + 3.61183709691297e+29*cos(theta)**22 - 1.83329898788595e+28*cos(theta)**20 + 7.57561565242129e+26*cos(theta)**18 - 2.49745570958944e+25*cos(theta)**16 + 6.40373258869086e+23*cos(theta)**14 - 1.23592718042602e+22*cos(theta)**12 + 1.71873564913859e+20*cos(theta)**10 - 1.6204295874971e+18*cos(theta)**8 + 9.46038958505394e+15*cos(theta)**6 - 29471618645027.9*cos(theta)**4 + 36610706391.339*cos(theta)**2 - 7562633.00791964)*cos(4*phi)

#@torch.jit.script
def Yl98_m5(theta, phi):
    return 6.05181920938943e-10*(1.0 - cos(theta)**2)**2.5*(1.47000278696405e+38*cos(theta)**93 - 3.22495996032422e+39*cos(theta)**91 + 3.42129819625069e+40*cos(theta)**89 - 2.33818564337133e+41*cos(theta)**87 + 1.15703075289049e+42*cos(theta)**85 - 4.41775378376371e+42*cos(theta)**83 + 1.35437983118449e+43*cos(theta)**81 - 3.42559769948303e+43*cos(theta)**79 + 7.28885808847184e+43*cos(theta)**77 - 1.32384846473424e+44*cos(theta)**75 + 2.07552513538843e+44*cos(theta)**73 - 2.83349613288352e+44*cos(theta)**71 + 3.39173308777243e+44*cos(theta)**69 - 3.57939983082056e+44*cos(theta)**67 + 3.34490829498912e+44*cos(theta)**65 - 2.77740888366362e+44*cos(theta)**63 + 2.05465134461934e+44*cos(theta)**61 - 1.35691517887167e+44*cos(theta)**59 + 8.0113246067958e+43*cos(theta)**57 - 4.23239790547703e+43*cos(theta)**55 + 2.00162767185777e+43*cos(theta)**53 - 8.47386461388633e+42*cos(theta)**51 + 3.20979720222967e+42*cos(theta)**49 - 1.08687633452983e+42*cos(theta)**47 + 3.28555178307255e+41*cos(theta)**45 - 8.85087419113422e+40*cos(theta)**43 + 2.11998392429554e+40*cos(theta)**41 - 4.50242636084524e+39*cos(theta)**39 + 8.45060266815178e+38*cos(theta)**37 - 1.39620475737759e+38*cos(theta)**35 + 2.02126966092377e+37*cos(theta)**33 - 2.55013233206153e+36*cos(theta)**31 + 2.78621131205031e+35*cos(theta)**29 - 2.61670551166418e+34*cos(theta)**27 + 2.09408033423194e+33*cos(theta)**25 - 1.4133275596616e+32*cos(theta)**23 + 7.94604161320854e+30*cos(theta)**21 - 3.66659797577191e+29*cos(theta)**19 + 1.36361081743583e+28*cos(theta)**17 - 3.9959291353431e+26*cos(theta)**15 + 8.96522562416721e+24*cos(theta)**13 - 1.48311261651122e+23*cos(theta)**11 + 1.71873564913859e+21*cos(theta)**9 - 1.29634366999768e+19*cos(theta)**7 + 5.67623375103237e+16*cos(theta)**5 - 117886474580111.0*cos(theta)**3 + 73221412782.6779*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl98_m6(theta, phi):
    return 6.15357929955912e-12*(1.0 - cos(theta)**2)**3*(1.36710259187657e+40*cos(theta)**92 - 2.93471356389504e+41*cos(theta)**90 + 3.04495539466312e+42*cos(theta)**88 - 2.03422150973306e+43*cos(theta)**86 + 9.83476139956921e+43*cos(theta)**84 - 3.66673564052388e+44*cos(theta)**82 + 1.09704766325944e+45*cos(theta)**80 - 2.7062221825916e+45*cos(theta)**78 + 5.61242072812332e+45*cos(theta)**76 - 9.9288634855068e+45*cos(theta)**74 + 1.51513334883355e+46*cos(theta)**72 - 2.0117822543473e+46*cos(theta)**70 + 2.34029583056297e+46*cos(theta)**68 - 2.39819788664978e+46*cos(theta)**66 + 2.17419039174293e+46*cos(theta)**64 - 1.74976759670808e+46*cos(theta)**62 + 1.2533373202178e+46*cos(theta)**60 - 8.00579955534284e+45*cos(theta)**58 + 4.56645502587361e+45*cos(theta)**56 - 2.32781884801237e+45*cos(theta)**54 + 1.06086266608462e+45*cos(theta)**52 - 4.32167095308203e+44*cos(theta)**50 + 1.57280062909254e+44*cos(theta)**48 - 5.10831877229019e+43*cos(theta)**46 + 1.47849830238265e+43*cos(theta)**44 - 3.80587590218772e+42*cos(theta)**42 + 8.69193408961173e+41*cos(theta)**40 - 1.75594628072964e+41*cos(theta)**38 + 3.12672298721616e+40*cos(theta)**36 - 4.88671665082158e+39*cos(theta)**34 + 6.67018988104843e+38*cos(theta)**32 - 7.90541022939074e+37*cos(theta)**30 + 8.08001280494589e+36*cos(theta)**28 - 7.06510488149328e+35*cos(theta)**26 + 5.23520083557984e+34*cos(theta)**24 - 3.25065338722168e+33*cos(theta)**22 + 1.66866873877379e+32*cos(theta)**20 - 6.96653615396662e+30*cos(theta)**18 + 2.31813838964092e+29*cos(theta)**16 - 5.99389370301465e+27*cos(theta)**14 + 1.16547933114174e+26*cos(theta)**12 - 1.63142387816235e+24*cos(theta)**10 + 1.54686208422473e+22*cos(theta)**8 - 9.07440568998374e+19*cos(theta)**6 + 2.83811687551618e+17*cos(theta)**4 - 353659423740334.0*cos(theta)**2 + 73221412782.6779)*cos(6*phi)

#@torch.jit.script
def Yl98_m7(theta, phi):
    return 6.26093562518037e-14*(1.0 - cos(theta)**2)**3.5*(1.25773438452644e+42*cos(theta)**91 - 2.64124220750553e+43*cos(theta)**89 + 2.67956074730354e+44*cos(theta)**87 - 1.74943049837043e+45*cos(theta)**85 + 8.26119957563813e+45*cos(theta)**83 - 3.00672322522958e+46*cos(theta)**81 + 8.77638130607553e+46*cos(theta)**79 - 2.11085330242144e+47*cos(theta)**77 + 4.26543975337372e+47*cos(theta)**75 - 7.34735897927503e+47*cos(theta)**73 + 1.09089601116016e+48*cos(theta)**71 - 1.40824757804311e+48*cos(theta)**69 + 1.59140116478282e+48*cos(theta)**67 - 1.58281060518885e+48*cos(theta)**65 + 1.39148185071548e+48*cos(theta)**63 - 1.08485590995901e+48*cos(theta)**61 + 7.52002392130678e+47*cos(theta)**59 - 4.64336374209885e+47*cos(theta)**57 + 2.55721481448922e+47*cos(theta)**55 - 1.25702217792668e+47*cos(theta)**53 + 5.51648586364e+46*cos(theta)**51 - 2.16083547654102e+46*cos(theta)**49 + 7.54944301964419e+45*cos(theta)**47 - 2.34982663525349e+45*cos(theta)**45 + 6.50539253048365e+44*cos(theta)**43 - 1.59846787891884e+44*cos(theta)**41 + 3.47677363584469e+43*cos(theta)**39 - 6.67259586677264e+42*cos(theta)**37 + 1.12562027539782e+42*cos(theta)**35 - 1.66148366127934e+41*cos(theta)**33 + 2.1344607619355e+40*cos(theta)**31 - 2.37162306881722e+39*cos(theta)**29 + 2.26240358538485e+38*cos(theta)**27 - 1.83692726918825e+37*cos(theta)**25 + 1.25644820053916e+36*cos(theta)**23 - 7.15143745188769e+34*cos(theta)**21 + 3.33733747754759e+33*cos(theta)**19 - 1.25397650771399e+32*cos(theta)**17 + 3.70902142342546e+30*cos(theta)**15 - 8.39145118422051e+28*cos(theta)**13 + 1.39857519737008e+27*cos(theta)**11 - 1.63142387816235e+25*cos(theta)**9 + 1.23748966737978e+23*cos(theta)**7 - 5.44464341399025e+20*cos(theta)**5 + 1.13524675020647e+18*cos(theta)**3 - 707318847480669.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl98_m8(theta, phi):
    return 6.37478599142786e-16*(1.0 - cos(theta)**2)**4*(1.14453828991907e+44*cos(theta)**90 - 2.35070556467993e+45*cos(theta)**88 + 2.33121785015408e+46*cos(theta)**86 - 1.48701592361486e+47*cos(theta)**84 + 6.85679564777965e+47*cos(theta)**82 - 2.43544581243596e+48*cos(theta)**80 + 6.93334123179967e+48*cos(theta)**78 - 1.62535704286451e+49*cos(theta)**76 + 3.19907981503029e+49*cos(theta)**74 - 5.36357205487077e+49*cos(theta)**72 + 7.74536167923711e+49*cos(theta)**70 - 9.71690828849747e+49*cos(theta)**68 + 1.06623878040449e+50*cos(theta)**66 - 1.02882689337275e+50*cos(theta)**64 + 8.76633565950749e+49*cos(theta)**62 - 6.61762105074997e+49*cos(theta)**60 + 4.436814113571e+49*cos(theta)**58 - 2.64671733299634e+49*cos(theta)**56 + 1.40646814796907e+49*cos(theta)**54 - 6.66221754301139e+48*cos(theta)**52 + 2.8134077904564e+48*cos(theta)**50 - 1.0588093835051e+48*cos(theta)**48 + 3.54823821923277e+47*cos(theta)**46 - 1.05742198586407e+47*cos(theta)**44 + 2.79731878810797e+46*cos(theta)**42 - 6.55371830356725e+45*cos(theta)**40 + 1.35594171797943e+45*cos(theta)**38 - 2.46886047070588e+44*cos(theta)**36 + 3.93967096389236e+43*cos(theta)**34 - 5.48289608222181e+42*cos(theta)**32 + 6.61682836200005e+41*cos(theta)**30 - 6.87770689956994e+40*cos(theta)**28 + 6.10848968053909e+39*cos(theta)**26 - 4.59231817297063e+38*cos(theta)**24 + 2.88983086124007e+37*cos(theta)**22 - 1.50180186489641e+36*cos(theta)**20 + 6.34094120734042e+34*cos(theta)**18 - 2.13176006311379e+33*cos(theta)**16 + 5.5635321351382e+31*cos(theta)**14 - 1.09088865394867e+30*cos(theta)**12 + 1.53843271710709e+28*cos(theta)**10 - 1.46828149034611e+26*cos(theta)**8 + 8.66242767165848e+23*cos(theta)**6 - 2.72232170699512e+21*cos(theta)**4 + 3.40574025061942e+18*cos(theta)**2 - 707318847480669.0)*cos(8*phi)

#@torch.jit.script
def Yl98_m9(theta, phi):
    return 6.49609647438139e-18*(1.0 - cos(theta)**2)**4.5*(1.03008446092716e+46*cos(theta)**89 - 2.06862089691833e+47*cos(theta)**87 + 2.00484735113251e+48*cos(theta)**85 - 1.24909337583649e+49*cos(theta)**83 + 5.62257243117931e+49*cos(theta)**81 - 1.94835664994877e+50*cos(theta)**79 + 5.40800616080374e+50*cos(theta)**77 - 1.23527135257703e+51*cos(theta)**75 + 2.36731906312241e+51*cos(theta)**73 - 3.86177187950696e+51*cos(theta)**71 + 5.42175317546598e+51*cos(theta)**69 - 6.60749763617828e+51*cos(theta)**67 + 7.03717595066964e+51*cos(theta)**65 - 6.58449211758563e+51*cos(theta)**63 + 5.43512810889465e+51*cos(theta)**61 - 3.97057263044998e+51*cos(theta)**59 + 2.57335218587118e+51*cos(theta)**57 - 1.48216170647795e+51*cos(theta)**55 + 7.59492799903298e+50*cos(theta)**53 - 3.46435312236592e+50*cos(theta)**51 + 1.4067038952282e+50*cos(theta)**49 - 5.08228504082447e+49*cos(theta)**47 + 1.63218958084707e+49*cos(theta)**45 - 4.65265673780191e+48*cos(theta)**43 + 1.17487389100535e+48*cos(theta)**41 - 2.6214873214269e+47*cos(theta)**39 + 5.15257852832184e+46*cos(theta)**37 - 8.88789769454116e+45*cos(theta)**35 + 1.3394881277234e+45*cos(theta)**33 - 1.75452674631098e+44*cos(theta)**31 + 1.98504850860001e+43*cos(theta)**29 - 1.92575793187958e+42*cos(theta)**27 + 1.58820731694016e+41*cos(theta)**25 - 1.10215636151295e+40*cos(theta)**23 + 6.35762789472816e+38*cos(theta)**21 - 3.00360372979283e+37*cos(theta)**19 + 1.14136941732128e+36*cos(theta)**17 - 3.41081610098206e+34*cos(theta)**15 + 7.78894498919348e+32*cos(theta)**13 - 1.3090663847384e+31*cos(theta)**11 + 1.53843271710709e+29*cos(theta)**9 - 1.17462519227689e+27*cos(theta)**7 + 5.19745660299509e+24*cos(theta)**5 - 1.08892868279805e+22*cos(theta)**3 + 6.81148050123884e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl98_m10(theta, phi):
    return 6.62591079995136e-20*(1.0 - cos(theta)**2)**5*(9.16775170225171e+47*cos(theta)**88 - 1.79970018031895e+49*cos(theta)**86 + 1.70412024846263e+50*cos(theta)**84 - 1.03674750194428e+51*cos(theta)**82 + 4.55428366925524e+51*cos(theta)**80 - 1.53920175345953e+52*cos(theta)**78 + 4.16416474381888e+52*cos(theta)**76 - 9.26453514432772e+52*cos(theta)**74 + 1.72814291607936e+53*cos(theta)**72 - 2.74185803444994e+53*cos(theta)**70 + 3.74100969107153e+53*cos(theta)**68 - 4.42702341623945e+53*cos(theta)**66 + 4.57416436793527e+53*cos(theta)**64 - 4.14823003407895e+53*cos(theta)**62 + 3.31542814642573e+53*cos(theta)**60 - 2.34263785196549e+53*cos(theta)**58 + 1.46681074594657e+53*cos(theta)**56 - 8.15188938562874e+52*cos(theta)**54 + 4.02531183948748e+52*cos(theta)**52 - 1.76682009240662e+52*cos(theta)**50 + 6.89284908661818e+51*cos(theta)**48 - 2.3886739691875e+51*cos(theta)**46 + 7.34485311381183e+50*cos(theta)**44 - 2.00064239725482e+50*cos(theta)**42 + 4.81698295312193e+49*cos(theta)**40 - 1.02238005535649e+49*cos(theta)**38 + 1.90645405547908e+48*cos(theta)**36 - 3.11076419308941e+47*cos(theta)**34 + 4.42031082148723e+46*cos(theta)**32 - 5.43903291356404e+45*cos(theta)**30 + 5.75664067494004e+44*cos(theta)**28 - 5.19954641607488e+43*cos(theta)**26 + 3.97051829235041e+42*cos(theta)**24 - 2.53495963147979e+41*cos(theta)**22 + 1.33510185789291e+40*cos(theta)**20 - 5.70684708660638e+38*cos(theta)**18 + 1.94032800944617e+37*cos(theta)**16 - 5.11622415147309e+35*cos(theta)**14 + 1.01256284859515e+34*cos(theta)**12 - 1.43997302321224e+32*cos(theta)**10 + 1.38458944539638e+30*cos(theta)**8 - 8.22237634593823e+27*cos(theta)**6 + 2.59872830149754e+25*cos(theta)**4 - 3.26678604839415e+22*cos(theta)**2 + 6.81148050123884e+18)*cos(10*phi)

#@torch.jit.script
def Yl98_m11(theta, phi):
    return 6.76536138020634e-22*(1.0 - cos(theta)**2)**5.5*(8.06762149798151e+49*cos(theta)**87 - 1.5477421550743e+51*cos(theta)**85 + 1.43146100870861e+52*cos(theta)**83 - 8.50132951594312e+52*cos(theta)**81 + 3.64342693540419e+53*cos(theta)**79 - 1.20057736769843e+54*cos(theta)**77 + 3.16476520530235e+54*cos(theta)**75 - 6.85575600680251e+54*cos(theta)**73 + 1.24426289957714e+55*cos(theta)**71 - 1.91930062411496e+55*cos(theta)**69 + 2.54388658992864e+55*cos(theta)**67 - 2.92183545471803e+55*cos(theta)**65 + 2.92746519547857e+55*cos(theta)**63 - 2.57190262112895e+55*cos(theta)**61 + 1.98925688785544e+55*cos(theta)**59 - 1.35872995413998e+55*cos(theta)**57 + 8.21414017730081e+54*cos(theta)**55 - 4.40202026823952e+54*cos(theta)**53 + 2.09316215653349e+54*cos(theta)**51 - 8.8341004620331e+53*cos(theta)**49 + 3.30856756157673e+53*cos(theta)**47 - 1.09879002582625e+53*cos(theta)**45 + 3.23173537007721e+52*cos(theta)**43 - 8.40269806847025e+51*cos(theta)**41 + 1.92679318124877e+51*cos(theta)**39 - 3.88504421035466e+50*cos(theta)**37 + 6.86323459972468e+49*cos(theta)**35 - 1.0576598256504e+49*cos(theta)**33 + 1.41449946287591e+48*cos(theta)**31 - 1.63170987406921e+47*cos(theta)**29 + 1.61185938898321e+46*cos(theta)**27 - 1.35188206817947e+45*cos(theta)**25 + 9.52924390164099e+43*cos(theta)**23 - 5.57691118925554e+42*cos(theta)**21 + 2.67020371578583e+41*cos(theta)**19 - 1.02723247558915e+40*cos(theta)**17 + 3.10452481511387e+38*cos(theta)**15 - 7.16271381206232e+36*cos(theta)**13 + 1.21507541831418e+35*cos(theta)**11 - 1.43997302321224e+33*cos(theta)**9 + 1.10767155631711e+31*cos(theta)**7 - 4.93342580756294e+28*cos(theta)**5 + 1.03949132059902e+26*cos(theta)**3 - 6.53357209678829e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl98_m12(theta, phi):
    return 6.9156822533309e-24*(1.0 - cos(theta)**2)**6*(7.01883070324391e+51*cos(theta)**86 - 1.31558083181315e+53*cos(theta)**84 + 1.18811263722815e+54*cos(theta)**82 - 6.88607690791393e+54*cos(theta)**80 + 2.87830727896931e+55*cos(theta)**78 - 9.24444573127791e+55*cos(theta)**76 + 2.37357390397676e+56*cos(theta)**74 - 5.00470188496583e+56*cos(theta)**72 + 8.8342665869977e+56*cos(theta)**70 - 1.32431743063932e+57*cos(theta)**68 + 1.70440401525219e+57*cos(theta)**66 - 1.89919304556672e+57*cos(theta)**64 + 1.8443030731515e+57*cos(theta)**62 - 1.56886059888866e+57*cos(theta)**60 + 1.17366156383471e+57*cos(theta)**58 - 7.74476073859791e+56*cos(theta)**56 + 4.51777709751545e+56*cos(theta)**54 - 2.33307074216694e+56*cos(theta)**52 + 1.06751269983208e+56*cos(theta)**50 - 4.32870922639622e+55*cos(theta)**48 + 1.55502675394106e+55*cos(theta)**46 - 4.94455511621813e+54*cos(theta)**44 + 1.3896462091332e+54*cos(theta)**42 - 3.4451062080728e+53*cos(theta)**40 + 7.51449340687021e+52*cos(theta)**38 - 1.43746635783123e+52*cos(theta)**36 + 2.40213210990364e+51*cos(theta)**34 - 3.49027742464631e+50*cos(theta)**32 + 4.38494833491533e+49*cos(theta)**30 - 4.73195863480071e+48*cos(theta)**28 + 4.35202035025467e+47*cos(theta)**26 - 3.37970517044867e+46*cos(theta)**24 + 2.19172609737743e+45*cos(theta)**22 - 1.17115134974366e+44*cos(theta)**20 + 5.07338705999307e+42*cos(theta)**18 - 1.74629520850155e+41*cos(theta)**16 + 4.6567872226708e+39*cos(theta)**14 - 9.31152795568102e+37*cos(theta)**12 + 1.3365829601456e+36*cos(theta)**10 - 1.29597572089102e+34*cos(theta)**8 + 7.75370089421975e+31*cos(theta)**6 - 2.46671290378147e+29*cos(theta)**4 + 3.11847396179705e+26*cos(theta)**2 - 6.53357209678829e+22)*cos(12*phi)

#@torch.jit.script
def Yl98_m13(theta, phi):
    return 7.07822422285425e-26*(1.0 - cos(theta)**2)**6.5*(6.03619440478976e+53*cos(theta)**85 - 1.10508789872305e+55*cos(theta)**83 + 9.74252362527082e+55*cos(theta)**81 - 5.50886152633114e+56*cos(theta)**79 + 2.24507967759606e+57*cos(theta)**77 - 7.02577875577121e+57*cos(theta)**75 + 1.7564446889428e+58*cos(theta)**73 - 3.6033853571754e+58*cos(theta)**71 + 6.18398661089839e+58*cos(theta)**69 - 9.00535852834738e+58*cos(theta)**67 + 1.12490665006644e+59*cos(theta)**65 - 1.2154835491627e+59*cos(theta)**63 + 1.14346790535393e+59*cos(theta)**61 - 9.41316359333195e+58*cos(theta)**59 + 6.80723707024132e+58*cos(theta)**57 - 4.33706601361483e+58*cos(theta)**55 + 2.43959963265834e+58*cos(theta)**53 - 1.21319678592681e+58*cos(theta)**51 + 5.3375634991604e+57*cos(theta)**49 - 2.07778042867019e+57*cos(theta)**47 + 7.15312306812889e+56*cos(theta)**45 - 2.17560425113598e+56*cos(theta)**43 + 5.83651407835943e+55*cos(theta)**41 - 1.37804248322912e+55*cos(theta)**39 + 2.85550749461068e+54*cos(theta)**37 - 5.17487888819241e+53*cos(theta)**35 + 8.16724917367237e+52*cos(theta)**33 - 1.11688877588682e+52*cos(theta)**31 + 1.3154845004746e+51*cos(theta)**29 - 1.3249484177442e+50*cos(theta)**27 + 1.13152529106621e+49*cos(theta)**25 - 8.11129240907681e+47*cos(theta)**23 + 4.82179741423034e+46*cos(theta)**21 - 2.34230269948733e+45*cos(theta)**19 + 9.13209670798752e+43*cos(theta)**17 - 2.79407233360248e+42*cos(theta)**15 + 6.51950211173912e+40*cos(theta)**13 - 1.11738335468172e+39*cos(theta)**11 + 1.3365829601456e+37*cos(theta)**9 - 1.03678057671281e+35*cos(theta)**7 + 4.65222053653185e+32*cos(theta)**5 - 9.86685161512588e+29*cos(theta)**3 + 6.23694792359411e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl98_m14(theta, phi):
    return 7.25447255182986e-28*(1.0 - cos(theta)**2)**7*(5.1307652440713e+55*cos(theta)**84 - 9.17222955940131e+56*cos(theta)**82 + 7.89144413646936e+57*cos(theta)**80 - 4.3520006058016e+58*cos(theta)**78 + 1.72871135174897e+59*cos(theta)**76 - 5.26933406682841e+59*cos(theta)**74 + 1.28220462292825e+60*cos(theta)**72 - 2.55840360359453e+60*cos(theta)**70 + 4.26695076151989e+60*cos(theta)**68 - 6.03359021399274e+60*cos(theta)**66 + 7.31189322543188e+60*cos(theta)**64 - 7.65754635972503e+60*cos(theta)**62 + 6.97515422265897e+60*cos(theta)**60 - 5.55376652006585e+60*cos(theta)**58 + 3.88012513003755e+60*cos(theta)**56 - 2.38538630748816e+60*cos(theta)**54 + 1.29298780530892e+60*cos(theta)**52 - 6.18730360822674e+59*cos(theta)**50 + 2.6154061145886e+59*cos(theta)**48 - 9.76556801474987e+58*cos(theta)**46 + 3.218905380658e+58*cos(theta)**44 - 9.35509827988469e+57*cos(theta)**42 + 2.39297077212737e+57*cos(theta)**40 - 5.37436568459357e+56*cos(theta)**38 + 1.05653777300595e+56*cos(theta)**36 - 1.81120761086734e+55*cos(theta)**34 + 2.69519222731188e+54*cos(theta)**32 - 3.46235520524914e+53*cos(theta)**30 + 3.81490505137634e+52*cos(theta)**28 - 3.57736072790934e+51*cos(theta)**26 + 2.82881322766554e+50*cos(theta)**24 - 1.86559725408767e+49*cos(theta)**22 + 1.01257745698837e+48*cos(theta)**20 - 4.45037512902592e+46*cos(theta)**18 + 1.55245644035788e+45*cos(theta)**16 - 4.19110850040372e+43*cos(theta)**14 + 8.47535274526086e+41*cos(theta)**12 - 1.22912169014989e+40*cos(theta)**10 + 1.20292466413104e+38*cos(theta)**8 - 7.25746403698969e+35*cos(theta)**6 + 2.32611026826593e+33*cos(theta)**4 - 2.96005548453776e+30*cos(theta)**2 + 6.23694792359411e+26)*cos(14*phi)

#@torch.jit.script
def Yl98_m15(theta, phi):
    return 7.44606764066569e-30*(1.0 - cos(theta)**2)**7.5*(4.30984280501989e+57*cos(theta)**83 - 7.52122823870907e+58*cos(theta)**81 + 6.31315530917549e+59*cos(theta)**79 - 3.39456047252525e+60*cos(theta)**77 + 1.31382062732922e+61*cos(theta)**75 - 3.89930720945302e+61*cos(theta)**73 + 9.23187328508338e+61*cos(theta)**71 - 1.79088252251617e+62*cos(theta)**69 + 2.90152651783352e+62*cos(theta)**67 - 3.98216954123521e+62*cos(theta)**65 + 4.67961166427641e+62*cos(theta)**63 - 4.74767874302952e+62*cos(theta)**61 + 4.18509253359538e+62*cos(theta)**59 - 3.22118458163819e+62*cos(theta)**57 + 2.17287007282103e+62*cos(theta)**55 - 1.2881086060436e+62*cos(theta)**53 + 6.72353658760639e+61*cos(theta)**51 - 3.09365180411337e+61*cos(theta)**49 + 1.25539493500253e+61*cos(theta)**47 - 4.49216128678494e+60*cos(theta)**45 + 1.41631836748952e+60*cos(theta)**43 - 3.92914127755157e+59*cos(theta)**41 + 9.57188308850947e+58*cos(theta)**39 - 2.04225896014556e+58*cos(theta)**37 + 3.80353598282142e+57*cos(theta)**35 - 6.15810587694897e+56*cos(theta)**33 + 8.62461512739803e+55*cos(theta)**31 - 1.03870656157474e+55*cos(theta)**29 + 1.06817341438537e+54*cos(theta)**27 - 9.30113789256428e+52*cos(theta)**25 + 6.78915174639729e+51*cos(theta)**23 - 4.10431395899286e+50*cos(theta)**21 + 2.02515491397674e+49*cos(theta)**19 - 8.01067523224666e+47*cos(theta)**17 + 2.48393030457261e+46*cos(theta)**15 - 5.86755190056521e+44*cos(theta)**13 + 1.0170423294313e+43*cos(theta)**11 - 1.22912169014989e+41*cos(theta)**9 + 9.62339731304832e+38*cos(theta)**7 - 4.35447842219381e+36*cos(theta)**5 + 9.3044410730637e+33*cos(theta)**3 - 5.92011096907553e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl98_m16(theta, phi):
    return 7.65482920625177e-32*(1.0 - cos(theta)**2)**8*(3.57716952816651e+59*cos(theta)**82 - 6.09219487335435e+60*cos(theta)**80 + 4.98739269424864e+61*cos(theta)**78 - 2.61381156384444e+62*cos(theta)**76 + 9.85365470496913e+62*cos(theta)**74 - 2.84649426290071e+63*cos(theta)**72 + 6.5546300324092e+63*cos(theta)**70 - 1.23570894053616e+64*cos(theta)**68 + 1.94402276694846e+64*cos(theta)**66 - 2.58841020180289e+64*cos(theta)**64 + 2.94815534849414e+64*cos(theta)**62 - 2.896084033248e+64*cos(theta)**60 + 2.46920459482128e+64*cos(theta)**58 - 1.83607521153377e+64*cos(theta)**56 + 1.19507854005157e+64*cos(theta)**54 - 6.8269756120311e+63*cos(theta)**52 + 3.42900365967926e+63*cos(theta)**50 - 1.51588938401555e+63*cos(theta)**48 + 5.90035619451187e+62*cos(theta)**46 - 2.02147257905322e+62*cos(theta)**44 + 6.09016898020494e+61*cos(theta)**42 - 1.61094792379614e+61*cos(theta)**40 + 3.73303440451869e+60*cos(theta)**38 - 7.55635815253856e+59*cos(theta)**36 + 1.3312375939875e+59*cos(theta)**34 - 2.03217493939316e+58*cos(theta)**32 + 2.67363068949339e+57*cos(theta)**30 - 3.01224902856675e+56*cos(theta)**28 + 2.88406821884051e+55*cos(theta)**26 - 2.32528447314107e+54*cos(theta)**24 + 1.56150490167138e+53*cos(theta)**22 - 8.61905931388501e+51*cos(theta)**20 + 3.84779433655581e+50*cos(theta)**18 - 1.36181478948193e+49*cos(theta)**16 + 3.72589545685891e+47*cos(theta)**14 - 7.62781747073478e+45*cos(theta)**12 + 1.11874656237443e+44*cos(theta)**10 - 1.1062095211349e+42*cos(theta)**8 + 6.73637811913383e+39*cos(theta)**6 - 2.17723921109691e+37*cos(theta)**4 + 2.79133232191911e+34*cos(theta)**2 - 5.92011096907553e+30)*cos(16*phi)

#@torch.jit.script
def Yl98_m17(theta, phi):
    return 7.88278458861485e-34*(1.0 - cos(theta)**2)**8.5*(2.93327901309654e+61*cos(theta)**81 - 4.87375589868348e+62*cos(theta)**79 + 3.89016630151394e+63*cos(theta)**77 - 1.98649678852178e+64*cos(theta)**75 + 7.29170448167715e+64*cos(theta)**73 - 2.04947586928851e+65*cos(theta)**71 + 4.58824102268644e+65*cos(theta)**69 - 8.40282079564589e+65*cos(theta)**67 + 1.28305502618598e+66*cos(theta)**65 - 1.65658252915385e+66*cos(theta)**63 + 1.82785631606636e+66*cos(theta)**61 - 1.7376504199488e+66*cos(theta)**59 + 1.43213866499634e+66*cos(theta)**57 - 1.02820211845891e+66*cos(theta)**55 + 6.45342411627846e+65*cos(theta)**53 - 3.55002731825617e+65*cos(theta)**51 + 1.71450182983963e+65*cos(theta)**49 - 7.27626904327464e+64*cos(theta)**47 + 2.71416384947546e+64*cos(theta)**45 - 8.89447934783418e+63*cos(theta)**43 + 2.55787097168607e+63*cos(theta)**41 - 6.44379169518458e+62*cos(theta)**39 + 1.4185530737171e+62*cos(theta)**37 - 2.72028893491388e+61*cos(theta)**35 + 4.52620781955749e+60*cos(theta)**33 - 6.50295980605811e+59*cos(theta)**31 + 8.02089206848017e+58*cos(theta)**29 - 8.43429727998691e+57*cos(theta)**27 + 7.49857736898533e+56*cos(theta)**25 - 5.58068273553857e+55*cos(theta)**23 + 3.43531078367703e+54*cos(theta)**21 - 1.723811862777e+53*cos(theta)**19 + 6.92602980580046e+51*cos(theta)**17 - 2.17890366317109e+50*cos(theta)**15 + 5.21625363960247e+48*cos(theta)**13 - 9.15338096488173e+46*cos(theta)**11 + 1.11874656237443e+45*cos(theta)**9 - 8.84967616907924e+42*cos(theta)**7 + 4.0418268714803e+40*cos(theta)**5 - 8.70895684438762e+37*cos(theta)**3 + 5.58266464383822e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl98_m18(theta, phi):
    return 8.13220194422049e-36*(1.0 - cos(theta)**2)**9*(2.3759560006082e+63*cos(theta)**80 - 3.85026715995995e+64*cos(theta)**78 + 2.99542805216573e+65*cos(theta)**76 - 1.48987259139133e+66*cos(theta)**74 + 5.32294427162432e+66*cos(theta)**72 - 1.45512786719484e+67*cos(theta)**70 + 3.16588630565364e+67*cos(theta)**68 - 5.62988993308274e+67*cos(theta)**66 + 8.3398576702089e+67*cos(theta)**64 - 1.04364699336692e+68*cos(theta)**62 + 1.11499235280048e+68*cos(theta)**60 - 1.02521374776979e+68*cos(theta)**58 + 8.16319039047914e+67*cos(theta)**56 - 5.65511165152401e+67*cos(theta)**54 + 3.42031478162758e+67*cos(theta)**52 - 1.81051393231065e+67*cos(theta)**50 + 8.40105896621418e+66*cos(theta)**48 - 3.41984645033908e+66*cos(theta)**46 + 1.22137373226396e+66*cos(theta)**44 - 3.8246261195687e+65*cos(theta)**42 + 1.04872709839129e+65*cos(theta)**40 - 2.51307876112198e+64*cos(theta)**38 + 5.24864637275328e+63*cos(theta)**36 - 9.52101127219859e+62*cos(theta)**34 + 1.49364858045397e+62*cos(theta)**32 - 2.01591753987802e+61*cos(theta)**30 + 2.32605869985925e+60*cos(theta)**28 - 2.27726026559647e+59*cos(theta)**26 + 1.87464434224633e+58*cos(theta)**24 - 1.28355702917387e+57*cos(theta)**22 + 7.21415264572176e+55*cos(theta)**20 - 3.27524253927631e+54*cos(theta)**18 + 1.17742506698608e+53*cos(theta)**16 - 3.26835549475664e+51*cos(theta)**14 + 6.78112973148322e+49*cos(theta)**12 - 1.00687190613699e+48*cos(theta)**10 + 1.00687190613699e+46*cos(theta)**8 - 6.19477331835547e+43*cos(theta)**6 + 2.02091343574015e+41*cos(theta)**4 - 2.61268705331629e+38*cos(theta)**2 + 5.58266464383822e+34)*cos(18*phi)

#@torch.jit.script
def Yl98_m19(theta, phi):
    return 8.40562924814361e-38*(1.0 - cos(theta)**2)**9.5*(1.90076480048656e+65*cos(theta)**79 - 3.00320838476876e+66*cos(theta)**77 + 2.27652531964596e+67*cos(theta)**75 - 1.10250571762959e+68*cos(theta)**73 + 3.83251987556951e+68*cos(theta)**71 - 1.01858950703639e+69*cos(theta)**69 + 2.15280268784448e+69*cos(theta)**67 - 3.71572735583461e+69*cos(theta)**65 + 5.3375089089337e+69*cos(theta)**63 - 6.47061135887493e+69*cos(theta)**61 + 6.68995411680289e+69*cos(theta)**59 - 5.9462397370648e+69*cos(theta)**57 + 4.57138661866832e+69*cos(theta)**55 - 3.05376029182297e+69*cos(theta)**53 + 1.77856368644634e+69*cos(theta)**51 - 9.05256966155324e+68*cos(theta)**49 + 4.03250830378281e+68*cos(theta)**47 - 1.57312936715598e+68*cos(theta)**45 + 5.37404442196141e+67*cos(theta)**43 - 1.60634297021885e+67*cos(theta)**41 + 4.19490839356516e+66*cos(theta)**39 - 9.54969929226354e+65*cos(theta)**37 + 1.88951269419118e+65*cos(theta)**35 - 3.23714383254752e+64*cos(theta)**33 + 4.77967545745271e+63*cos(theta)**31 - 6.04775261963405e+62*cos(theta)**29 + 6.51296435960589e+61*cos(theta)**27 - 5.92087669055081e+60*cos(theta)**25 + 4.4991464213912e+59*cos(theta)**23 - 2.82382546418252e+58*cos(theta)**21 + 1.44283052914435e+57*cos(theta)**19 - 5.89543657069735e+55*cos(theta)**17 + 1.88388010717772e+54*cos(theta)**15 - 4.57569769265929e+52*cos(theta)**13 + 8.13735567777986e+50*cos(theta)**11 - 1.00687190613699e+49*cos(theta)**9 + 8.05497524909592e+46*cos(theta)**7 - 3.71686399101328e+44*cos(theta)**5 + 8.08365374296059e+41*cos(theta)**3 - 5.22537410663257e+38*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl98_m20(theta, phi):
    return 8.70594022811869e-40*(1.0 - cos(theta)**2)**10*(1.50160419238438e+67*cos(theta)**78 - 2.31247045627194e+68*cos(theta)**76 + 1.70739398973447e+69*cos(theta)**74 - 8.04829173869598e+69*cos(theta)**72 + 2.72108911165435e+70*cos(theta)**70 - 7.02826759855109e+70*cos(theta)**68 + 1.4423778008558e+71*cos(theta)**66 - 2.4152227812925e+71*cos(theta)**64 + 3.36263061262823e+71*cos(theta)**62 - 3.94707292891371e+71*cos(theta)**60 + 3.94707292891371e+71*cos(theta)**58 - 3.38935665012694e+71*cos(theta)**56 + 2.51426264026757e+71*cos(theta)**54 - 1.61849295466617e+71*cos(theta)**52 + 9.07067480087635e+70*cos(theta)**50 - 4.43575913416109e+70*cos(theta)**48 + 1.89527890277792e+70*cos(theta)**46 - 7.0790821522019e+69*cos(theta)**44 + 2.31083910144341e+69*cos(theta)**42 - 6.5860061778973e+68*cos(theta)**40 + 1.63601427349041e+68*cos(theta)**38 - 3.53338873813751e+67*cos(theta)**36 + 6.61329442966914e+66*cos(theta)**34 - 1.06825746474068e+66*cos(theta)**32 + 1.48169939181034e+65*cos(theta)**30 - 1.75384825969387e+64*cos(theta)**28 + 1.75850037709359e+63*cos(theta)**26 - 1.4802191726377e+62*cos(theta)**24 + 1.03480367691997e+61*cos(theta)**22 - 5.93003347478329e+59*cos(theta)**20 + 2.74137800537427e+58*cos(theta)**18 - 1.00222421701855e+57*cos(theta)**16 + 2.82582016076659e+55*cos(theta)**14 - 5.94840700045708e+53*cos(theta)**12 + 8.95109124555784e+51*cos(theta)**10 - 9.06184715523291e+49*cos(theta)**8 + 5.63848267436715e+47*cos(theta)**6 - 1.85843199550664e+45*cos(theta)**4 + 2.42509612288818e+42*cos(theta)**2 - 5.22537410663257e+38)*cos(20*phi)

#@torch.jit.script
def Yl98_m21(theta, phi):
    return 9.03638860146374e-42*(1.0 - cos(theta)**2)**10.5*(1.17125127005982e+69*cos(theta)**77 - 1.75747754676668e+70*cos(theta)**75 + 1.26347155240351e+71*cos(theta)**73 - 5.7947700518611e+71*cos(theta)**71 + 1.90476237815805e+72*cos(theta)**69 - 4.77922196701474e+72*cos(theta)**67 + 9.51969348564828e+72*cos(theta)**65 - 1.5457425800272e+73*cos(theta)**63 + 2.0848309798295e+73*cos(theta)**61 - 2.36824375734822e+73*cos(theta)**59 + 2.28930229876995e+73*cos(theta)**57 - 1.89803972407109e+73*cos(theta)**55 + 1.35770182574449e+73*cos(theta)**53 - 8.41616336426409e+72*cos(theta)**51 + 4.53533740043817e+72*cos(theta)**49 - 2.12916438439732e+72*cos(theta)**47 + 8.71828295277843e+71*cos(theta)**45 - 3.11479614696884e+71*cos(theta)**43 + 9.70552422606231e+70*cos(theta)**41 - 2.63440247115892e+70*cos(theta)**39 + 6.21685423926357e+69*cos(theta)**37 - 1.2720199457295e+69*cos(theta)**35 + 2.24852010608751e+68*cos(theta)**33 - 3.41842388717018e+67*cos(theta)**31 + 4.44509817543102e+66*cos(theta)**29 - 4.91077512714284e+65*cos(theta)**27 + 4.57210098044334e+64*cos(theta)**25 - 3.55252601433049e+63*cos(theta)**23 + 2.27656808922394e+62*cos(theta)**21 - 1.18600669495666e+61*cos(theta)**19 + 4.93448040967368e+59*cos(theta)**17 - 1.60355874722968e+58*cos(theta)**15 + 3.95614822507322e+56*cos(theta)**13 - 7.13808840054849e+54*cos(theta)**11 + 8.95109124555785e+52*cos(theta)**9 - 7.24947772418633e+50*cos(theta)**7 + 3.38308960462029e+48*cos(theta)**5 - 7.43372798202656e+45*cos(theta)**3 + 4.85019224577636e+42*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl98_m22(theta, phi):
    return 9.40067229316547e-44*(1.0 - cos(theta)**2)**11*(9.01863477946058e+70*cos(theta)**76 - 1.31810816007501e+72*cos(theta)**74 + 9.22334233254559e+72*cos(theta)**72 - 4.11428673682138e+73*cos(theta)**70 + 1.31428604092905e+74*cos(theta)**68 - 3.20207871789987e+74*cos(theta)**66 + 6.18780076567138e+74*cos(theta)**64 - 9.73817825417135e+74*cos(theta)**62 + 1.271746897696e+75*cos(theta)**60 - 1.39726381683545e+75*cos(theta)**58 + 1.30490231029887e+75*cos(theta)**56 - 1.0439218482391e+75*cos(theta)**54 + 7.1958196764458e+74*cos(theta)**52 - 4.29224331577469e+74*cos(theta)**50 + 2.2223153262147e+74*cos(theta)**48 - 1.00070726066674e+74*cos(theta)**46 + 3.92322732875029e+73*cos(theta)**44 - 1.3393623431966e+73*cos(theta)**42 + 3.97926493268555e+72*cos(theta)**40 - 1.02741696375198e+72*cos(theta)**38 + 2.30023606852752e+71*cos(theta)**36 - 4.45206981005326e+70*cos(theta)**34 + 7.42011635008877e+69*cos(theta)**32 - 1.05971140502276e+69*cos(theta)**30 + 1.289078470875e+68*cos(theta)**28 - 1.32590928432857e+67*cos(theta)**26 + 1.14302524511083e+66*cos(theta)**24 - 8.17080983296012e+64*cos(theta)**22 + 4.78079298737028e+63*cos(theta)**20 - 2.25341272041765e+62*cos(theta)**18 + 8.38861669644526e+60*cos(theta)**16 - 2.40533812084452e+59*cos(theta)**14 + 5.14299269259519e+57*cos(theta)**12 - 7.85189724060334e+55*cos(theta)**10 + 8.05598212100206e+53*cos(theta)**8 - 5.07463440693043e+51*cos(theta)**6 + 1.69154480231014e+49*cos(theta)**4 - 2.23011839460797e+46*cos(theta)**2 + 4.85019224577636e+42)*cos(22*phi)

#@torch.jit.script
def Yl98_m23(theta, phi):
    return 9.8030096955146e-46*(1.0 - cos(theta)**2)**11.5*(6.85416243239004e+72*cos(theta)**75 - 9.75400038455506e+73*cos(theta)**73 + 6.64080647943282e+74*cos(theta)**71 - 2.88000071577497e+75*cos(theta)**69 + 8.93714507831756e+75*cos(theta)**67 - 2.11337195381392e+76*cos(theta)**65 + 3.96019249002968e+76*cos(theta)**63 - 6.03767051758624e+76*cos(theta)**61 + 7.63048138617598e+76*cos(theta)**59 - 8.10413013764562e+76*cos(theta)**57 + 7.30745293767368e+76*cos(theta)**55 - 5.63717798049112e+76*cos(theta)**53 + 3.74182623175182e+76*cos(theta)**51 - 2.14612165788734e+76*cos(theta)**49 + 1.06671135658306e+76*cos(theta)**47 - 4.60325339906701e+75*cos(theta)**45 + 1.72622002465013e+75*cos(theta)**43 - 5.62532184142572e+74*cos(theta)**41 + 1.59170597307422e+74*cos(theta)**39 - 3.90418446225752e+73*cos(theta)**37 + 8.28084984669907e+72*cos(theta)**35 - 1.51370373541811e+72*cos(theta)**33 + 2.37443723202841e+71*cos(theta)**31 - 3.17913421506827e+70*cos(theta)**29 + 3.60941971844999e+69*cos(theta)**27 - 3.44736413925428e+68*cos(theta)**25 + 2.743260588266e+67*cos(theta)**23 - 1.79757816325123e+66*cos(theta)**21 + 9.56158597474057e+64*cos(theta)**19 - 4.05614289675177e+63*cos(theta)**17 + 1.34217867143124e+62*cos(theta)**15 - 3.36747336918233e+60*cos(theta)**13 + 6.17159123111423e+58*cos(theta)**11 - 7.85189724060334e+56*cos(theta)**9 + 6.44478569680165e+54*cos(theta)**7 - 3.04478064415826e+52*cos(theta)**5 + 6.76617920924057e+49*cos(theta)**3 - 4.46023678921594e+46*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl98_m24(theta, phi):
    return 1.02482305064849e-47*(1.0 - cos(theta)**2)**12*(5.14062182429253e+74*cos(theta)**74 - 7.12042028072519e+75*cos(theta)**72 + 4.7149726003973e+76*cos(theta)**70 - 1.98720049388473e+77*cos(theta)**68 + 5.98788720247277e+77*cos(theta)**66 - 1.37369176997905e+78*cos(theta)**64 + 2.4949212687187e+78*cos(theta)**62 - 3.6829790157276e+78*cos(theta)**60 + 4.50198401784383e+78*cos(theta)**58 - 4.619354178458e+78*cos(theta)**56 + 4.01909911572052e+78*cos(theta)**54 - 2.9877043296603e+78*cos(theta)**52 + 1.90833137819343e+78*cos(theta)**50 - 1.0515996123648e+78*cos(theta)**48 + 5.01354337594037e+77*cos(theta)**46 - 2.07146402958015e+77*cos(theta)**44 + 7.42274610599555e+76*cos(theta)**42 - 2.30638195498454e+76*cos(theta)**40 + 6.20765329498946e+75*cos(theta)**38 - 1.44454825103528e+75*cos(theta)**36 + 2.89829744634467e+74*cos(theta)**34 - 4.99522232687976e+73*cos(theta)**32 + 7.36075541928806e+72*cos(theta)**30 - 9.21948922369798e+71*cos(theta)**28 + 9.74543323981497e+70*cos(theta)**26 - 8.61841034813569e+69*cos(theta)**24 + 6.30949935301181e+68*cos(theta)**22 - 3.77491414282758e+67*cos(theta)**20 + 1.81670133520071e+66*cos(theta)**18 - 6.895442924478e+64*cos(theta)**16 + 2.01326800714686e+63*cos(theta)**14 - 4.37771537993702e+61*cos(theta)**12 + 6.78875035422565e+59*cos(theta)**10 - 7.06670751654301e+57*cos(theta)**8 + 4.51134998776115e+55*cos(theta)**6 - 1.52239032207913e+53*cos(theta)**4 + 2.02985376277217e+50*cos(theta)**2 - 4.46023678921594e+46)*cos(24*phi)

#@torch.jit.script
def Yl98_m25(theta, phi):
    return 1.07418842811865e-49*(1.0 - cos(theta)**2)**12.5*(3.80406014997647e+76*cos(theta)**73 - 5.12670260212214e+77*cos(theta)**71 + 3.30048082027811e+78*cos(theta)**69 - 1.35129633584162e+79*cos(theta)**67 + 3.95200555363202e+79*cos(theta)**65 - 8.7916273278659e+79*cos(theta)**63 + 1.54685118660559e+80*cos(theta)**61 - 2.20978740943656e+80*cos(theta)**59 + 2.61115073034942e+80*cos(theta)**57 - 2.58683833993648e+80*cos(theta)**55 + 2.17031352248908e+80*cos(theta)**53 - 1.55360625142335e+80*cos(theta)**51 + 9.54165689096713e+79*cos(theta)**49 - 5.04767813935103e+79*cos(theta)**47 + 2.30622995293257e+79*cos(theta)**45 - 9.11444173015268e+78*cos(theta)**43 + 3.11755336451813e+78*cos(theta)**41 - 9.22552781993818e+77*cos(theta)**39 + 2.35890825209599e+77*cos(theta)**37 - 5.20037370372702e+76*cos(theta)**35 + 9.85421131757189e+75*cos(theta)**33 - 1.59847114460152e+75*cos(theta)**31 + 2.20822662578642e+74*cos(theta)**29 - 2.58145698263543e+73*cos(theta)**27 + 2.53381264235189e+72*cos(theta)**25 - 2.06841848355257e+71*cos(theta)**23 + 1.3880898576626e+70*cos(theta)**21 - 7.54982828565515e+68*cos(theta)**19 + 3.27006240336127e+67*cos(theta)**17 - 1.10327086791648e+66*cos(theta)**15 + 2.81857521000561e+64*cos(theta)**13 - 5.25325845592443e+62*cos(theta)**11 + 6.78875035422565e+60*cos(theta)**9 - 5.65336601323441e+58*cos(theta)**7 + 2.70680999265669e+56*cos(theta)**5 - 6.08956128831652e+53*cos(theta)**3 + 4.05970752554435e+50*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl98_m26(theta, phi):
    return 1.12903705813361e-51*(1.0 - cos(theta)**2)**13*(2.77696390948283e+78*cos(theta)**72 - 3.63995884750672e+79*cos(theta)**70 + 2.2773317659919e+80*cos(theta)**68 - 9.05368545013882e+80*cos(theta)**66 + 2.56880360986082e+81*cos(theta)**64 - 5.53872521655551e+81*cos(theta)**62 + 9.43579223829412e+81*cos(theta)**60 - 1.30377457156757e+82*cos(theta)**58 + 1.48835591629917e+82*cos(theta)**56 - 1.42276108696507e+82*cos(theta)**54 + 1.15026616691921e+82*cos(theta)**52 - 7.9233918822591e+81*cos(theta)**50 + 4.67541187657389e+81*cos(theta)**48 - 2.37240872549499e+81*cos(theta)**46 + 1.03780347881966e+81*cos(theta)**44 - 3.91920994396565e+80*cos(theta)**42 + 1.27819687945243e+80*cos(theta)**40 - 3.59795584977589e+79*cos(theta)**38 + 8.72796053275517e+78*cos(theta)**36 - 1.82013079630446e+78*cos(theta)**34 + 3.25188973479872e+77*cos(theta)**32 - 4.95526054826472e+76*cos(theta)**30 + 6.40385721478061e+75*cos(theta)**28 - 6.96993385311567e+74*cos(theta)**26 + 6.33453160587973e+73*cos(theta)**24 - 4.7573625121709e+72*cos(theta)**22 + 2.91498870109145e+71*cos(theta)**20 - 1.43446737427448e+70*cos(theta)**18 + 5.55910608571417e+68*cos(theta)**16 - 1.65490630187472e+67*cos(theta)**14 + 3.66414777300729e+65*cos(theta)**12 - 5.77858430151687e+63*cos(theta)**10 + 6.10987531880308e+61*cos(theta)**8 - 3.95735620926408e+59*cos(theta)**6 + 1.35340499632835e+57*cos(theta)**4 - 1.82686838649496e+54*cos(theta)**2 + 4.05970752554435e+50)*cos(26*phi)

#@torch.jit.script
def Yl98_m27(theta, phi):
    return 1.19010955547938e-53*(1.0 - cos(theta)**2)**13.5*(1.99941401482763e+80*cos(theta)**71 - 2.5479711932547e+81*cos(theta)**69 + 1.54858560087449e+82*cos(theta)**67 - 5.97543239709162e+82*cos(theta)**65 + 1.64403431031092e+83*cos(theta)**63 - 3.43400963426442e+83*cos(theta)**61 + 5.66147534297647e+83*cos(theta)**59 - 7.56189251509192e+83*cos(theta)**57 + 8.33479313127535e+83*cos(theta)**55 - 7.68290986961135e+83*cos(theta)**53 + 5.98138406797991e+83*cos(theta)**51 - 3.96169594112955e+83*cos(theta)**49 + 2.24419770075547e+83*cos(theta)**47 - 1.09130801372769e+83*cos(theta)**45 + 4.56633530680649e+82*cos(theta)**43 - 1.64606817646557e+82*cos(theta)**41 + 5.11278751780974e+81*cos(theta)**39 - 1.36722322291484e+81*cos(theta)**37 + 3.14206579179186e+80*cos(theta)**35 - 6.18844470743515e+79*cos(theta)**33 + 1.04060471513559e+79*cos(theta)**31 - 1.48657816447942e+78*cos(theta)**29 + 1.79308002013857e+77*cos(theta)**27 - 1.81218280181007e+76*cos(theta)**25 + 1.52028758541114e+75*cos(theta)**23 - 1.0466197526776e+74*cos(theta)**21 + 5.82997740218291e+72*cos(theta)**19 - 2.58204127369406e+71*cos(theta)**17 + 8.89456973714267e+69*cos(theta)**15 - 2.31686882262461e+68*cos(theta)**13 + 4.39697732760875e+66*cos(theta)**11 - 5.77858430151687e+64*cos(theta)**9 + 4.88790025504247e+62*cos(theta)**7 - 2.37441372555845e+60*cos(theta)**5 + 5.41361998531338e+57*cos(theta)**3 - 3.65373677298991e+54*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl98_m28(theta, phi):
    return 1.25826609768952e-55*(1.0 - cos(theta)**2)**14*(1.41958395052762e+82*cos(theta)**70 - 1.75810012334575e+83*cos(theta)**68 + 1.03755235258591e+84*cos(theta)**66 - 3.88403105810955e+84*cos(theta)**64 + 1.03574161549588e+85*cos(theta)**62 - 2.0947458769013e+85*cos(theta)**60 + 3.34027045235612e+85*cos(theta)**58 - 4.31027873360239e+85*cos(theta)**56 + 4.58413622220144e+85*cos(theta)**54 - 4.07194223089402e+85*cos(theta)**52 + 3.05050587466975e+85*cos(theta)**50 - 1.94123101115348e+85*cos(theta)**48 + 1.05477291935507e+85*cos(theta)**46 - 4.91088606177462e+84*cos(theta)**44 + 1.96352418192679e+84*cos(theta)**42 - 6.74887952350885e+83*cos(theta)**40 + 1.9939871319458e+83*cos(theta)**38 - 5.0587259247849e+82*cos(theta)**36 + 1.09972302712715e+82*cos(theta)**34 - 2.0421867534536e+81*cos(theta)**32 + 3.22587461692034e+80*cos(theta)**30 - 4.31107667699031e+79*cos(theta)**28 + 4.84131605437414e+78*cos(theta)**26 - 4.53045700452519e+77*cos(theta)**24 + 3.49666144644561e+76*cos(theta)**22 - 2.19790148062296e+75*cos(theta)**20 + 1.10769570641475e+74*cos(theta)**18 - 4.38947016527991e+72*cos(theta)**16 + 1.3341854605714e+71*cos(theta)**14 - 3.01192946941199e+69*cos(theta)**12 + 4.83667506036962e+67*cos(theta)**10 - 5.20072587136518e+65*cos(theta)**8 + 3.42153017852973e+63*cos(theta)**6 - 1.18720686277923e+61*cos(theta)**4 + 1.62408599559402e+58*cos(theta)**2 - 3.65373677298991e+54)*cos(28*phi)

#@torch.jit.script
def Yl98_m29(theta, phi):
    return 1.3345093310932e-57*(1.0 - cos(theta)**2)**14.5*(9.93708765369334e+83*cos(theta)**69 - 1.19550808387511e+85*cos(theta)**67 + 6.847845527067e+85*cos(theta)**65 - 2.48577987719011e+86*cos(theta)**63 + 6.42159801607446e+86*cos(theta)**61 - 1.25684752614078e+87*cos(theta)**59 + 1.93735686236655e+87*cos(theta)**57 - 2.41375609081734e+87*cos(theta)**55 + 2.47543355998878e+87*cos(theta)**53 - 2.11740996006489e+87*cos(theta)**51 + 1.52525293733488e+87*cos(theta)**49 - 9.31790885353671e+86*cos(theta)**47 + 4.85195542903332e+86*cos(theta)**45 - 2.16078986718083e+86*cos(theta)**43 + 8.24680156409252e+85*cos(theta)**41 - 2.69955180940354e+85*cos(theta)**39 + 7.57715110139403e+84*cos(theta)**37 - 1.82114133292256e+84*cos(theta)**35 + 3.73905829223232e+83*cos(theta)**33 - 6.53499761105152e+82*cos(theta)**31 + 9.677623850761e+81*cos(theta)**29 - 1.20710146955729e+81*cos(theta)**27 + 1.25874217413728e+80*cos(theta)**25 - 1.08730968108604e+79*cos(theta)**23 + 7.69265518218035e+77*cos(theta)**21 - 4.39580296124591e+76*cos(theta)**19 + 1.99385227154655e+75*cos(theta)**17 - 7.02315226444785e+73*cos(theta)**15 + 1.86785964479996e+72*cos(theta)**13 - 3.61431536329439e+70*cos(theta)**11 + 4.83667506036962e+68*cos(theta)**9 - 4.16058069709215e+66*cos(theta)**7 + 2.05291810711784e+64*cos(theta)**5 - 4.7488274511169e+61*cos(theta)**3 + 3.24817199118803e+58*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl98_m30(theta, phi):
    return 1.42001222931447e-59*(1.0 - cos(theta)**2)**15*(6.85659048104841e+85*cos(theta)**68 - 8.00990416196322e+86*cos(theta)**66 + 4.45109959259355e+87*cos(theta)**64 - 1.56604132262977e+88*cos(theta)**62 + 3.91717478980542e+88*cos(theta)**60 - 7.41540040423059e+88*cos(theta)**58 + 1.10429341154893e+89*cos(theta)**56 - 1.32756584994954e+89*cos(theta)**54 + 1.31197978679405e+89*cos(theta)**52 - 1.07987907963309e+89*cos(theta)**50 + 7.4737393929409e+88*cos(theta)**48 - 4.37941716116225e+88*cos(theta)**46 + 2.183379943065e+88*cos(theta)**44 - 9.29139642887758e+87*cos(theta)**42 + 3.38118864127794e+87*cos(theta)**40 - 1.05282520566738e+87*cos(theta)**38 + 2.80354590751579e+86*cos(theta)**36 - 6.37399466522897e+85*cos(theta)**34 + 1.23388923643666e+85*cos(theta)**32 - 2.02584925942597e+84*cos(theta)**30 + 2.80651091672069e+83*cos(theta)**28 - 3.25917396780467e+82*cos(theta)**26 + 3.14685543534319e+81*cos(theta)**24 - 2.5008122664979e+80*cos(theta)**22 + 1.61545758825787e+79*cos(theta)**20 - 8.35202562636724e+77*cos(theta)**18 + 3.38954886162914e+76*cos(theta)**16 - 1.05347283966718e+75*cos(theta)**14 + 2.42821753823995e+73*cos(theta)**12 - 3.97574689962383e+71*cos(theta)**10 + 4.35300755433266e+69*cos(theta)**8 - 2.9124064879645e+67*cos(theta)**6 + 1.02645905355892e+65*cos(theta)**4 - 1.42464823533507e+62*cos(theta)**2 + 3.24817199118803e+58)*cos(30*phi)

#@torch.jit.script
def Yl98_m31(theta, phi):
    return 1.51615210452691e-61*(1.0 - cos(theta)**2)**15.5*(4.66248152711292e+87*cos(theta)**67 - 5.28653674689572e+88*cos(theta)**65 + 2.84870373925987e+89*cos(theta)**63 - 9.70945620030459e+89*cos(theta)**61 + 2.35030487388325e+90*cos(theta)**59 - 4.30093223445374e+90*cos(theta)**57 + 6.18404310467403e+90*cos(theta)**55 - 7.1688555897275e+90*cos(theta)**53 + 6.82229489132907e+90*cos(theta)**51 - 5.39939539816547e+90*cos(theta)**49 + 3.58739490861163e+90*cos(theta)**47 - 2.01453189413464e+90*cos(theta)**45 + 9.60687174948598e+89*cos(theta)**43 - 3.90238650012858e+89*cos(theta)**41 + 1.35247545651117e+89*cos(theta)**39 - 4.00073578153605e+88*cos(theta)**37 + 1.00927652670568e+88*cos(theta)**35 - 2.16715818617785e+87*cos(theta)**33 + 3.94844555659733e+86*cos(theta)**31 - 6.07754777827791e+85*cos(theta)**29 + 7.85823056681794e+84*cos(theta)**27 - 8.47385231629215e+83*cos(theta)**25 + 7.55245304482366e+82*cos(theta)**23 - 5.50178698629538e+81*cos(theta)**21 + 3.23091517651575e+80*cos(theta)**19 - 1.5033646127461e+79*cos(theta)**17 + 5.42327817860663e+77*cos(theta)**15 - 1.47486197553405e+76*cos(theta)**13 + 2.91386104588794e+74*cos(theta)**11 - 3.97574689962383e+72*cos(theta)**9 + 3.48240604346613e+70*cos(theta)**7 - 1.7474438927787e+68*cos(theta)**5 + 4.10583621423567e+65*cos(theta)**3 - 2.84929647067014e+62*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl98_m32(theta, phi):
    return 1.62455229337705e-63*(1.0 - cos(theta)**2)**16*(3.12386262316565e+89*cos(theta)**66 - 3.43624888548222e+90*cos(theta)**64 + 1.79468335573372e+91*cos(theta)**62 - 5.9227682821858e+91*cos(theta)**60 + 1.38667987559112e+92*cos(theta)**58 - 2.45153137363863e+92*cos(theta)**56 + 3.40122370757071e+92*cos(theta)**54 - 3.79949346255558e+92*cos(theta)**52 + 3.47937039457783e+92*cos(theta)**50 - 2.64570374510108e+92*cos(theta)**48 + 1.68607560704747e+92*cos(theta)**46 - 9.06539352360586e+91*cos(theta)**44 + 4.13095485227897e+91*cos(theta)**42 - 1.59997846505272e+91*cos(theta)**40 + 5.27465428039358e+90*cos(theta)**38 - 1.48027223916834e+90*cos(theta)**36 + 3.5324678434699e+89*cos(theta)**34 - 7.15162201438691e+88*cos(theta)**32 + 1.22401812254517e+88*cos(theta)**30 - 1.76248885570059e+87*cos(theta)**28 + 2.12172225304084e+86*cos(theta)**26 - 2.11846307907304e+85*cos(theta)**24 + 1.73706420030944e+84*cos(theta)**22 - 1.15537526712203e+83*cos(theta)**20 + 6.13873883537992e+81*cos(theta)**18 - 2.55571984166837e+80*cos(theta)**16 + 8.13491726790994e+78*cos(theta)**14 - 1.91732056819426e+77*cos(theta)**12 + 3.20524715047673e+75*cos(theta)**10 - 3.57817220966145e+73*cos(theta)**8 + 2.43768423042629e+71*cos(theta)**6 - 8.73721946389351e+68*cos(theta)**4 + 1.2317508642707e+66*cos(theta)**2 - 2.84929647067014e+62)*cos(32*phi)

#@torch.jit.script
def Yl98_m33(theta, phi):
    return 1.74713345541493e-65*(1.0 - cos(theta)**2)**16.5*(2.06174933128933e+91*cos(theta)**65 - 2.19919928670862e+92*cos(theta)**63 + 1.11270368055491e+93*cos(theta)**61 - 3.55366096931148e+93*cos(theta)**59 + 8.04274327842849e+93*cos(theta)**57 - 1.37285756923763e+94*cos(theta)**55 + 1.83666080208819e+94*cos(theta)**53 - 1.9757366005289e+94*cos(theta)**51 + 1.73968519728891e+94*cos(theta)**49 - 1.26993779764852e+94*cos(theta)**47 + 7.75594779241835e+93*cos(theta)**45 - 3.98877315038658e+93*cos(theta)**43 + 1.73500103795717e+93*cos(theta)**41 - 6.39991386021088e+92*cos(theta)**39 + 2.00436862654956e+92*cos(theta)**37 - 5.32898006100602e+91*cos(theta)**35 + 1.20103906677976e+91*cos(theta)**33 - 2.28851904460381e+90*cos(theta)**31 + 3.67205436763551e+89*cos(theta)**29 - 4.93496879596166e+88*cos(theta)**27 + 5.51647785790619e+87*cos(theta)**25 - 5.08431138977529e+86*cos(theta)**23 + 3.82154124068077e+85*cos(theta)**21 - 2.31075053424406e+84*cos(theta)**19 + 1.10497299036839e+83*cos(theta)**17 - 4.0891517466694e+81*cos(theta)**15 + 1.13888841750739e+80*cos(theta)**13 - 2.30078468183312e+78*cos(theta)**11 + 3.20524715047673e+76*cos(theta)**9 - 2.86253776772916e+74*cos(theta)**7 + 1.46261053825577e+72*cos(theta)**5 - 3.4948877855574e+69*cos(theta)**3 + 2.4635017285414e+66*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl98_m34(theta, phi):
    return 1.8861769621828e-67*(1.0 - cos(theta)**2)**17*(1.34013706533807e+93*cos(theta)**64 - 1.38549555062643e+94*cos(theta)**62 + 6.78749245138493e+94*cos(theta)**60 - 2.09665997189377e+95*cos(theta)**58 + 4.58436366870424e+95*cos(theta)**56 - 7.55071663080698e+95*cos(theta)**54 + 9.73430225106738e+95*cos(theta)**52 - 1.00762566626974e+96*cos(theta)**50 + 8.52445746671567e+95*cos(theta)**48 - 5.96870764894803e+95*cos(theta)**46 + 3.49017650658826e+95*cos(theta)**44 - 1.71517245466623e+95*cos(theta)**42 + 7.11350425562439e+94*cos(theta)**40 - 2.49596640548224e+94*cos(theta)**38 + 7.41616391823337e+93*cos(theta)**36 - 1.86514302135211e+93*cos(theta)**34 + 3.96342892037322e+92*cos(theta)**32 - 7.09440903827181e+91*cos(theta)**30 + 1.0648957666143e+91*cos(theta)**28 - 1.33244157490965e+90*cos(theta)**26 + 1.37911946447655e+89*cos(theta)**24 - 1.16939161964832e+88*cos(theta)**22 + 8.02523660542963e+86*cos(theta)**20 - 4.39042601506372e+85*cos(theta)**18 + 1.87845408362625e+84*cos(theta)**16 - 6.1337276200041e+82*cos(theta)**14 + 1.48055494275961e+81*cos(theta)**12 - 2.53086315001643e+79*cos(theta)**10 + 2.88472243542906e+77*cos(theta)**8 - 2.00377643741041e+75*cos(theta)**6 + 7.31305269127887e+72*cos(theta)**4 - 1.04846633566722e+70*cos(theta)**2 + 2.4635017285414e+66)*cos(34*phi)

#@torch.jit.script
def Yl98_m35(theta, phi):
    return 2.04440356024428e-69*(1.0 - cos(theta)**2)**17.5*(8.57687721816362e+94*cos(theta)**63 - 8.59007241388387e+95*cos(theta)**61 + 4.07249547083095e+96*cos(theta)**59 - 1.21606278369839e+97*cos(theta)**57 + 2.56724365447437e+97*cos(theta)**55 - 4.07738698063577e+97*cos(theta)**53 + 5.06183717055504e+97*cos(theta)**51 - 5.03812833134869e+97*cos(theta)**49 + 4.09173958402352e+97*cos(theta)**47 - 2.7456055185161e+97*cos(theta)**45 + 1.53567766289883e+97*cos(theta)**43 - 7.20372430959816e+96*cos(theta)**41 + 2.84540170224976e+96*cos(theta)**39 - 9.48467234083252e+95*cos(theta)**37 + 2.66981901056401e+95*cos(theta)**35 - 6.34148627259716e+94*cos(theta)**33 + 1.26829725451943e+94*cos(theta)**31 - 2.12832271148154e+93*cos(theta)**29 + 2.98170814652004e+92*cos(theta)**27 - 3.46434809476509e+91*cos(theta)**25 + 3.30988671474371e+90*cos(theta)**23 - 2.5726615632263e+89*cos(theta)**21 + 1.60504732108593e+88*cos(theta)**19 - 7.90276682711469e+86*cos(theta)**17 + 3.00552653380201e+85*cos(theta)**15 - 8.58721866800574e+83*cos(theta)**13 + 1.77666593131153e+82*cos(theta)**11 - 2.53086315001643e+80*cos(theta)**9 + 2.30777794834325e+78*cos(theta)**7 - 1.20226586244625e+76*cos(theta)**5 + 2.92522107651155e+73*cos(theta)**3 - 2.09693267133444e+70*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl98_m36(theta, phi):
    return 2.22507141601619e-71*(1.0 - cos(theta)**2)**18*(5.40343264744308e+96*cos(theta)**62 - 5.23994417246916e+97*cos(theta)**60 + 2.40277232779026e+98*cos(theta)**58 - 6.93155786708081e+98*cos(theta)**56 + 1.41198400996091e+99*cos(theta)**54 - 2.16101509973696e+99*cos(theta)**52 + 2.58153695698307e+99*cos(theta)**50 - 2.46868288236086e+99*cos(theta)**48 + 1.92311760449106e+99*cos(theta)**46 - 1.23552248333224e+99*cos(theta)**44 + 6.60341395046498e+98*cos(theta)**42 - 2.95352696693525e+98*cos(theta)**40 + 1.1097066638774e+98*cos(theta)**38 - 3.50932876610803e+97*cos(theta)**36 + 9.34436653697405e+96*cos(theta)**34 - 2.09269046995706e+96*cos(theta)**32 + 3.93172148901024e+95*cos(theta)**30 - 6.17213586329648e+94*cos(theta)**28 + 8.0506119956041e+93*cos(theta)**26 - 8.66087023691272e+92*cos(theta)**24 + 7.61273944391054e+91*cos(theta)**22 - 5.40258928277522e+90*cos(theta)**20 + 3.04958991006326e+89*cos(theta)**18 - 1.3434703606095e+88*cos(theta)**16 + 4.50828980070301e+86*cos(theta)**14 - 1.11633842684075e+85*cos(theta)**12 + 1.95433252444268e+83*cos(theta)**10 - 2.27777683501478e+81*cos(theta)**8 + 1.61544456384027e+79*cos(theta)**6 - 6.01132931223123e+76*cos(theta)**4 + 8.77566322953464e+73*cos(theta)**2 - 2.09693267133444e+70)*cos(36*phi)

#@torch.jit.script
def Yl98_m37(theta, phi):
    return 2.43209886847967e-73*(1.0 - cos(theta)**2)**18.5*(3.35012824141471e+98*cos(theta)**61 - 3.1439665034815e+99*cos(theta)**59 + 1.39360795011835e+100*cos(theta)**57 - 3.88167240556525e+100*cos(theta)**55 + 7.62471365378889e+100*cos(theta)**53 - 1.12372785186322e+101*cos(theta)**51 + 1.29076847849154e+101*cos(theta)**49 - 1.18496778353321e+101*cos(theta)**47 + 8.84634098065886e+100*cos(theta)**45 - 5.43629892666187e+100*cos(theta)**43 + 2.77343385919529e+100*cos(theta)**41 - 1.1814107867741e+100*cos(theta)**39 + 4.21688532273414e+99*cos(theta)**37 - 1.26335835579889e+99*cos(theta)**35 + 3.17708462257118e+98*cos(theta)**33 - 6.6966095038626e+97*cos(theta)**31 + 1.17951644670307e+97*cos(theta)**29 - 1.72819804172301e+96*cos(theta)**27 + 2.09315911885707e+95*cos(theta)**25 - 2.07860885685905e+94*cos(theta)**23 + 1.67480267766032e+93*cos(theta)**21 - 1.08051785655504e+92*cos(theta)**19 + 5.48926183811386e+90*cos(theta)**17 - 2.1495525769752e+89*cos(theta)**15 + 6.31160572098422e+87*cos(theta)**13 - 1.3396061122089e+86*cos(theta)**11 + 1.95433252444268e+84*cos(theta)**9 - 1.82222146801183e+82*cos(theta)**7 + 9.69266738304164e+79*cos(theta)**5 - 2.40453172489249e+77*cos(theta)**3 + 1.75513264590693e+74*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl98_m38(theta, phi):
    return 2.6702188289681e-75*(1.0 - cos(theta)**2)**19*(2.04357822726297e+100*cos(theta)**60 - 1.85494023705408e+101*cos(theta)**58 + 7.94356531567461e+101*cos(theta)**56 - 2.13491982306089e+102*cos(theta)**54 + 4.04109823650811e+102*cos(theta)**52 - 5.73101204450242e+102*cos(theta)**50 + 6.32476554460852e+102*cos(theta)**48 - 5.5693485826061e+102*cos(theta)**46 + 3.98085344129649e+102*cos(theta)**44 - 2.3376085384646e+102*cos(theta)**42 + 1.13710788227007e+102*cos(theta)**40 - 4.60750206841898e+101*cos(theta)**38 + 1.56024756941163e+101*cos(theta)**36 - 4.42175424529612e+100*cos(theta)**34 + 1.04843792544849e+100*cos(theta)**32 - 2.07594894619741e+99*cos(theta)**30 + 3.42059769543891e+98*cos(theta)**28 - 4.66613471265214e+97*cos(theta)**26 + 5.23289779714267e+96*cos(theta)**24 - 4.78080037077582e+95*cos(theta)**22 + 3.51708562308667e+94*cos(theta)**20 - 2.05298392745459e+93*cos(theta)**18 + 9.33174512479357e+91*cos(theta)**16 - 3.22432886546279e+90*cos(theta)**14 + 8.20508743727948e+88*cos(theta)**12 - 1.47356672342978e+87*cos(theta)**10 + 1.75889927199842e+85*cos(theta)**8 - 1.27555502760828e+83*cos(theta)**6 + 4.84633369152082e+80*cos(theta)**4 - 7.21359517467748e+77*cos(theta)**2 + 1.75513264590693e+74)*cos(38*phi)

#@torch.jit.script
def Yl98_m39(theta, phi):
    return 2.94517391424152e-77*(1.0 - cos(theta)**2)**19.5*(1.22614693635778e+102*cos(theta)**59 - 1.07586533749137e+103*cos(theta)**57 + 4.44839657677778e+103*cos(theta)**55 - 1.15285670445288e+104*cos(theta)**53 + 2.10137108298422e+104*cos(theta)**51 - 2.86550602225121e+104*cos(theta)**49 + 3.03588746141209e+104*cos(theta)**47 - 2.56190034799881e+104*cos(theta)**45 + 1.75157551417045e+104*cos(theta)**43 - 9.81795586155133e+103*cos(theta)**41 + 4.54843152908028e+103*cos(theta)**39 - 1.75085078599921e+103*cos(theta)**37 + 5.61689124988187e+102*cos(theta)**35 - 1.50339644340068e+102*cos(theta)**33 + 3.35500136143516e+101*cos(theta)**31 - 6.22784683859222e+100*cos(theta)**29 + 9.57767354722894e+99*cos(theta)**27 - 1.21319502528956e+99*cos(theta)**25 + 1.25589547131424e+98*cos(theta)**23 - 1.05177608157068e+97*cos(theta)**21 + 7.03417124617334e+95*cos(theta)**19 - 3.69537106941825e+94*cos(theta)**17 + 1.49307921996697e+93*cos(theta)**15 - 4.51406041164791e+91*cos(theta)**13 + 9.84610492473538e+89*cos(theta)**11 - 1.47356672342978e+88*cos(theta)**9 + 1.40711941759873e+86*cos(theta)**7 - 7.65333016564967e+83*cos(theta)**5 + 1.93853347660833e+81*cos(theta)**3 - 1.4427190349355e+78*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl98_m40(theta, phi):
    return 3.26396427175474e-79*(1.0 - cos(theta)**2)**20*(7.23426692451092e+103*cos(theta)**58 - 6.1324324237008e+104*cos(theta)**56 + 2.44661811722778e+105*cos(theta)**54 - 6.11014053360027e+105*cos(theta)**52 + 1.07169925232195e+106*cos(theta)**50 - 1.40409795090309e+106*cos(theta)**48 + 1.42686710686368e+106*cos(theta)**46 - 1.15285515659946e+106*cos(theta)**44 + 7.53177471093295e+105*cos(theta)**42 - 4.02536190323605e+105*cos(theta)**40 + 1.77388829634131e+105*cos(theta)**38 - 6.47814790819709e+104*cos(theta)**36 + 1.96591193745866e+104*cos(theta)**34 - 4.96120826322225e+103*cos(theta)**32 + 1.0400504220449e+103*cos(theta)**30 - 1.80607558319174e+102*cos(theta)**28 + 2.58597185775181e+101*cos(theta)**26 - 3.03298756322389e+100*cos(theta)**24 + 2.88855958402275e+99*cos(theta)**22 - 2.20872977129843e+98*cos(theta)**20 + 1.33649253677294e+97*cos(theta)**18 - 6.28213081801103e+95*cos(theta)**16 + 2.23961882995046e+94*cos(theta)**14 - 5.86827853514228e+92*cos(theta)**12 + 1.08307154172089e+91*cos(theta)**10 - 1.32621005108681e+89*cos(theta)**8 + 9.84983592319113e+86*cos(theta)**6 - 3.82666508282484e+84*cos(theta)**4 + 5.81560042982498e+81*cos(theta)**2 - 1.4427190349355e+78)*cos(40*phi)

#@torch.jit.script
def Yl98_m41(theta, phi):
    return 3.63516392057649e-81*(1.0 - cos(theta)**2)**20.5*(4.19587481621634e+105*cos(theta)**57 - 3.43416215727245e+106*cos(theta)**55 + 1.321173783303e+107*cos(theta)**53 - 3.17727307747214e+107*cos(theta)**51 + 5.35849626160976e+107*cos(theta)**49 - 6.73967016433484e+107*cos(theta)**47 + 6.56358869157294e+107*cos(theta)**45 - 5.07256268903764e+107*cos(theta)**43 + 3.16334537859184e+107*cos(theta)**41 - 1.61014476129442e+107*cos(theta)**39 + 6.74077552609697e+106*cos(theta)**37 - 2.33213324695095e+106*cos(theta)**35 + 6.68410058735943e+105*cos(theta)**33 - 1.58758664423112e+105*cos(theta)**31 + 3.1201512661347e+104*cos(theta)**29 - 5.05701163293688e+103*cos(theta)**27 + 6.72352683015472e+102*cos(theta)**25 - 7.27917015173733e+101*cos(theta)**23 + 6.35483108485005e+100*cos(theta)**21 - 4.41745954259686e+99*cos(theta)**19 + 2.40568656619128e+98*cos(theta)**17 - 1.00514093088176e+97*cos(theta)**15 + 3.13546636193064e+95*cos(theta)**13 - 7.04193424217074e+93*cos(theta)**11 + 1.08307154172089e+92*cos(theta)**9 - 1.06096804086944e+90*cos(theta)**7 + 5.90990155391468e+87*cos(theta)**5 - 1.53066603312994e+85*cos(theta)**3 + 1.163120085965e+82*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl98_m42(theta, phi):
    return 4.06932665934764e-83*(1.0 - cos(theta)**2)**21*(2.39164864524331e+107*cos(theta)**56 - 1.88878918649985e+108*cos(theta)**54 + 7.00222105150591e+108*cos(theta)**52 - 1.62040926951079e+109*cos(theta)**50 + 2.62566316818878e+109*cos(theta)**48 - 3.16764497723738e+109*cos(theta)**46 + 2.95361491120782e+109*cos(theta)**44 - 2.18120195628618e+109*cos(theta)**42 + 1.29697160522265e+109*cos(theta)**40 - 6.27956456904823e+108*cos(theta)**38 + 2.49408694465588e+108*cos(theta)**36 - 8.16246636432834e+107*cos(theta)**34 + 2.20575319382861e+107*cos(theta)**32 - 4.92151859711647e+106*cos(theta)**30 + 9.04843867179063e+105*cos(theta)**28 - 1.36539314089296e+105*cos(theta)**26 + 1.68088170753868e+104*cos(theta)**24 - 1.67420913489959e+103*cos(theta)**22 + 1.33451452781851e+102*cos(theta)**20 - 8.39317313093403e+100*cos(theta)**18 + 4.08966716252518e+99*cos(theta)**16 - 1.50771139632265e+98*cos(theta)**14 + 4.07610627050983e+96*cos(theta)**12 - 7.74612766638782e+94*cos(theta)**10 + 9.74764387548802e+92*cos(theta)**8 - 7.42677628608611e+90*cos(theta)**6 + 2.95495077695734e+88*cos(theta)**4 - 4.59199809938981e+85*cos(theta)**2 + 1.163120085965e+82)*cos(42*phi)

#@torch.jit.script
def Yl98_m43(theta, phi):
    return 4.5795097056863e-85*(1.0 - cos(theta)**2)**21.5*(1.33932324133625e+109*cos(theta)**55 - 1.01994616070992e+110*cos(theta)**53 + 3.64115494678307e+110*cos(theta)**51 - 8.10204634755396e+110*cos(theta)**49 + 1.26031832073062e+111*cos(theta)**47 - 1.45711668952919e+111*cos(theta)**45 + 1.29959056093144e+111*cos(theta)**43 - 9.16104821640197e+110*cos(theta)**41 + 5.18788642089062e+110*cos(theta)**39 - 2.38623453623833e+110*cos(theta)**37 + 8.97871300076117e+109*cos(theta)**35 - 2.77523856387163e+109*cos(theta)**33 + 7.05841022025156e+108*cos(theta)**31 - 1.47645557913494e+108*cos(theta)**29 + 2.53356282810138e+107*cos(theta)**27 - 3.55002216632169e+106*cos(theta)**25 + 4.03411609809283e+105*cos(theta)**23 - 3.68326009677909e+104*cos(theta)**21 + 2.66902905563702e+103*cos(theta)**19 - 1.51077116356813e+102*cos(theta)**17 + 6.54346746004029e+100*cos(theta)**15 - 2.11079595485171e+99*cos(theta)**13 + 4.8913275246118e+97*cos(theta)**11 - 7.74612766638782e+95*cos(theta)**9 + 7.79811510039042e+93*cos(theta)**7 - 4.45606577165167e+91*cos(theta)**5 + 1.18198031078294e+89*cos(theta)**3 - 9.18399619877961e+85*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl98_m44(theta, phi):
    return 5.1819529666549e-87*(1.0 - cos(theta)**2)**22*(7.3662778273494e+110*cos(theta)**54 - 5.40571465176256e+111*cos(theta)**52 + 1.85698902285937e+112*cos(theta)**50 - 3.97000271030144e+112*cos(theta)**48 + 5.92349610743389e+112*cos(theta)**46 - 6.55702510288137e+112*cos(theta)**44 + 5.5882394120052e+112*cos(theta)**42 - 3.75602976872481e+112*cos(theta)**40 + 2.02327570414734e+112*cos(theta)**38 - 8.82906778408182e+111*cos(theta)**36 + 3.14254955026641e+111*cos(theta)**34 - 9.15828726077639e+110*cos(theta)**32 + 2.18810716827798e+110*cos(theta)**30 - 4.28172117949133e+109*cos(theta)**28 + 6.84061963587372e+108*cos(theta)**26 - 8.87505541580423e+107*cos(theta)**24 + 9.27846702561351e+106*cos(theta)**22 - 7.73484620323609e+105*cos(theta)**20 + 5.07115520571034e+104*cos(theta)**18 - 2.56831097806581e+103*cos(theta)**16 + 9.81520119006043e+101*cos(theta)**14 - 2.74403474130722e+100*cos(theta)**12 + 5.38046027707298e+98*cos(theta)**10 - 6.97151489974903e+96*cos(theta)**8 + 5.45868057027329e+94*cos(theta)**6 - 2.22803288582583e+92*cos(theta)**4 + 3.54594093234881e+89*cos(theta)**2 - 9.18399619877961e+85)*cos(44*phi)

#@torch.jit.script
def Yl98_m45(theta, phi):
    return 5.89696524533311e-89*(1.0 - cos(theta)**2)**22.5*(3.97779002676868e+112*cos(theta)**53 - 2.81097161891653e+113*cos(theta)**51 + 9.28494511429683e+113*cos(theta)**49 - 1.90560130094469e+114*cos(theta)**47 + 2.72480820941959e+114*cos(theta)**45 - 2.8850910452678e+114*cos(theta)**43 + 2.34706055304218e+114*cos(theta)**41 - 1.50241190748992e+114*cos(theta)**39 + 7.6884476757599e+113*cos(theta)**37 - 3.17846440226945e+113*cos(theta)**35 + 1.06846684709058e+113*cos(theta)**33 - 2.93065192344845e+112*cos(theta)**31 + 6.56432150483395e+111*cos(theta)**29 - 1.19888193025757e+111*cos(theta)**27 + 1.77856110532717e+110*cos(theta)**25 - 2.13001329979301e+109*cos(theta)**23 + 2.04126274563497e+108*cos(theta)**21 - 1.54696924064722e+107*cos(theta)**19 + 9.12807937027862e+105*cos(theta)**17 - 4.1092975649053e+104*cos(theta)**15 + 1.37412816660846e+103*cos(theta)**13 - 3.29284168956866e+101*cos(theta)**11 + 5.38046027707298e+99*cos(theta)**9 - 5.57721191979923e+97*cos(theta)**7 + 3.27520834216398e+95*cos(theta)**5 - 8.91213154330334e+92*cos(theta)**3 + 7.09188186469761e+89*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl98_m46(theta, phi):
    return 6.75008726403979e-91*(1.0 - cos(theta)**2)**23*(2.1082287141874e+114*cos(theta)**52 - 1.43359552564743e+115*cos(theta)**50 + 4.54962310600545e+115*cos(theta)**48 - 8.95632611444004e+115*cos(theta)**46 + 1.22616369423882e+116*cos(theta)**44 - 1.24058914946515e+116*cos(theta)**42 + 9.62294826747296e+115*cos(theta)**40 - 5.8594064392107e+115*cos(theta)**38 + 2.84472564003116e+115*cos(theta)**36 - 1.11246254079431e+115*cos(theta)**34 + 3.52594059539891e+114*cos(theta)**32 - 9.08502096269018e+113*cos(theta)**30 + 1.90365323640184e+113*cos(theta)**28 - 3.23698121169544e+112*cos(theta)**26 + 4.44640276331792e+111*cos(theta)**24 - 4.89903058952393e+110*cos(theta)**22 + 4.28665176583344e+109*cos(theta)**20 - 2.93924155722971e+108*cos(theta)**18 + 1.55177349294736e+107*cos(theta)**16 - 6.16394634735795e+105*cos(theta)**14 + 1.786366616591e+104*cos(theta)**12 - 3.62212585852553e+102*cos(theta)**10 + 4.84241424936568e+100*cos(theta)**8 - 3.90404834385946e+98*cos(theta)**6 + 1.63760417108199e+96*cos(theta)**4 - 2.673639462991e+93*cos(theta)**2 + 7.09188186469761e+89)*cos(46*phi)

#@torch.jit.script
def Yl98_m47(theta, phi):
    return 7.77362729122006e-93*(1.0 - cos(theta)**2)**23.5*(1.09627893137745e+116*cos(theta)**51 - 7.16797762823715e+116*cos(theta)**49 + 2.18381909088261e+117*cos(theta)**47 - 4.11991001264242e+117*cos(theta)**45 + 5.39512025465079e+117*cos(theta)**43 - 5.21047442775365e+117*cos(theta)**41 + 3.84917930698918e+117*cos(theta)**39 - 2.22657444690007e+117*cos(theta)**37 + 1.02410123041122e+117*cos(theta)**35 - 3.78237263870065e+116*cos(theta)**33 + 1.12830099052765e+116*cos(theta)**31 - 2.72550628880705e+115*cos(theta)**29 + 5.33022906192516e+114*cos(theta)**27 - 8.41615115040815e+113*cos(theta)**25 + 1.0671366631963e+113*cos(theta)**23 - 1.07778672969527e+112*cos(theta)**21 + 8.57330353166688e+110*cos(theta)**19 - 5.29063480301349e+109*cos(theta)**17 + 2.48283758871578e+108*cos(theta)**15 - 8.62952488630113e+106*cos(theta)**13 + 2.1436399399092e+105*cos(theta)**11 - 3.62212585852553e+103*cos(theta)**9 + 3.87393139949254e+101*cos(theta)**7 - 2.34242900631568e+99*cos(theta)**5 + 6.55041668432795e+96*cos(theta)**3 - 5.347278925982e+93*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl98_m48(theta, phi):
    return 9.00870153133566e-95*(1.0 - cos(theta)**2)**24*(5.59102255002498e+117*cos(theta)**50 - 3.51230903783621e+118*cos(theta)**48 + 1.02639497271483e+119*cos(theta)**46 - 1.85395950568909e+119*cos(theta)**44 + 2.31990170949984e+119*cos(theta)**42 - 2.136294515379e+119*cos(theta)**40 + 1.50117992972578e+119*cos(theta)**38 - 8.23832545353024e+118*cos(theta)**36 + 3.58435430643926e+118*cos(theta)**34 - 1.24818297077121e+118*cos(theta)**32 + 3.49773307063572e+117*cos(theta)**30 - 7.90396823754046e+116*cos(theta)**28 + 1.43916184671979e+116*cos(theta)**26 - 2.10403778760204e+115*cos(theta)**24 + 2.45441432535149e+114*cos(theta)**22 - 2.26335213236006e+113*cos(theta)**20 + 1.62892767101671e+112*cos(theta)**18 - 8.99407916512293e+110*cos(theta)**16 + 3.72425638307368e+109*cos(theta)**14 - 1.12183823521915e+108*cos(theta)**12 + 2.35800393390012e+106*cos(theta)**10 - 3.25991327267298e+104*cos(theta)**8 + 2.71175197964478e+102*cos(theta)**6 - 1.17121450315784e+100*cos(theta)**4 + 1.96512500529839e+97*cos(theta)**2 - 5.347278925982e+93)*cos(48*phi)

#@torch.jit.script
def Yl98_m49(theta, phi):
    return 1.05079628556199e-96*(1.0 - cos(theta)**2)**24.5*(2.79551127501249e+119*cos(theta)**49 - 1.68590833816138e+120*cos(theta)**47 + 4.72141687448821e+120*cos(theta)**45 - 8.15742182503199e+120*cos(theta)**43 + 9.74358717989932e+120*cos(theta)**41 - 8.54517806151598e+120*cos(theta)**39 + 5.70448373295797e+120*cos(theta)**37 - 2.96579716327089e+120*cos(theta)**35 + 1.21868046418935e+120*cos(theta)**33 - 3.99418550646789e+119*cos(theta)**31 + 1.04931992119072e+119*cos(theta)**29 - 2.21311110651133e+118*cos(theta)**27 + 3.74182080147147e+117*cos(theta)**25 - 5.04969069024489e+116*cos(theta)**23 + 5.39971151577328e+115*cos(theta)**21 - 4.52670426472011e+114*cos(theta)**19 + 2.93206980783007e+113*cos(theta)**17 - 1.43905266641967e+112*cos(theta)**15 + 5.21395893630315e+110*cos(theta)**13 - 1.34620588226298e+109*cos(theta)**11 + 2.35800393390012e+107*cos(theta)**9 - 2.60793061813838e+105*cos(theta)**7 + 1.62705118778687e+103*cos(theta)**5 - 4.68485801263135e+100*cos(theta)**3 + 3.93025001059677e+97*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl98_m50(theta, phi):
    return 1.23392746579016e-98*(1.0 - cos(theta)**2)**25*(1.36980052475612e+121*cos(theta)**48 - 7.92376918935848e+121*cos(theta)**46 + 2.1246375935197e+122*cos(theta)**44 - 3.50769138476376e+122*cos(theta)**42 + 3.99487074375872e+122*cos(theta)**40 - 3.33261944399123e+122*cos(theta)**38 + 2.11065898119445e+122*cos(theta)**36 - 1.03802900714481e+122*cos(theta)**34 + 4.02164553182485e+121*cos(theta)**32 - 1.23819750700504e+121*cos(theta)**30 + 3.04302777145308e+120*cos(theta)**28 - 5.97539998758059e+119*cos(theta)**26 + 9.35455200367866e+118*cos(theta)**24 - 1.16142885875633e+118*cos(theta)**22 + 1.13393941831239e+117*cos(theta)**20 - 8.60073810296822e+115*cos(theta)**18 + 4.98451867331113e+114*cos(theta)**16 - 2.1585789996295e+113*cos(theta)**14 + 6.77814661719409e+111*cos(theta)**12 - 1.48082647048927e+110*cos(theta)**10 + 2.12220354051011e+108*cos(theta)**8 - 1.82555143269687e+106*cos(theta)**6 + 8.13525593893434e+103*cos(theta)**4 - 1.40545740378941e+101*cos(theta)**2 + 3.93025001059677e+97)*cos(50*phi)

#@torch.jit.script
def Yl98_m51(theta, phi):
    return 1.45906916119761e-100*(1.0 - cos(theta)**2)**25.5*(6.57504251882938e+122*cos(theta)**47 - 3.6449338271049e+123*cos(theta)**45 + 9.34840541148666e+123*cos(theta)**43 - 1.47323038160078e+124*cos(theta)**41 + 1.59794829750349e+124*cos(theta)**39 - 1.26639538871667e+124*cos(theta)**37 + 7.59837233230001e+123*cos(theta)**35 - 3.52929862429236e+123*cos(theta)**33 + 1.28692657018395e+123*cos(theta)**31 - 3.71459252101513e+122*cos(theta)**29 + 8.52047776006861e+121*cos(theta)**27 - 1.55360399677095e+121*cos(theta)**25 + 2.24509248088288e+120*cos(theta)**23 - 2.55514348926392e+119*cos(theta)**21 + 2.26787883662478e+118*cos(theta)**19 - 1.54813285853428e+117*cos(theta)**17 + 7.9752298772978e+115*cos(theta)**15 - 3.0220105994813e+114*cos(theta)**13 + 8.13377594063291e+112*cos(theta)**11 - 1.48082647048927e+111*cos(theta)**9 + 1.69776283240809e+109*cos(theta)**7 - 1.09533085961812e+107*cos(theta)**5 + 3.25410237557374e+104*cos(theta)**3 - 2.81091480757881e+101*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl98_m52(theta, phi):
    return 1.73772608291153e-102*(1.0 - cos(theta)**2)**26*(3.09026998384981e+124*cos(theta)**46 - 1.64022022219721e+125*cos(theta)**44 + 4.01981432693926e+125*cos(theta)**42 - 6.04024456456319e+125*cos(theta)**40 + 6.23199836026361e+125*cos(theta)**38 - 4.68566293825168e+125*cos(theta)**36 + 2.659430316305e+125*cos(theta)**34 - 1.16466854601648e+125*cos(theta)**32 + 3.98947236757025e+124*cos(theta)**30 - 1.07723183109439e+124*cos(theta)**28 + 2.30052899521853e+123*cos(theta)**26 - 3.88400999192738e+122*cos(theta)**24 + 5.16371270603062e+121*cos(theta)**22 - 5.36580132745422e+120*cos(theta)**20 + 4.30896978958708e+119*cos(theta)**18 - 2.63182585950827e+118*cos(theta)**16 + 1.19628448159467e+117*cos(theta)**14 - 3.92861377932569e+115*cos(theta)**12 + 8.9471535346962e+113*cos(theta)**10 - 1.33274382344035e+112*cos(theta)**8 + 1.18843398268566e+110*cos(theta)**6 - 5.4766542980906e+107*cos(theta)**4 + 9.76230712672121e+104*cos(theta)**2 - 2.81091480757881e+101)*cos(52*phi)

#@torch.jit.script
def Yl98_m53(theta, phi):
    return 2.08503778833744e-104*(1.0 - cos(theta)**2)**26.5*(1.42152419257091e+126*cos(theta)**45 - 7.2169689776677e+126*cos(theta)**43 + 1.68832201731449e+127*cos(theta)**41 - 2.41609782582528e+127*cos(theta)**39 + 2.36815937690017e+127*cos(theta)**37 - 1.6868386577706e+127*cos(theta)**35 + 9.04206307543702e+126*cos(theta)**33 - 3.72693934725273e+126*cos(theta)**31 + 1.19684171027108e+126*cos(theta)**29 - 3.01624912706429e+125*cos(theta)**27 + 5.98137538756817e+124*cos(theta)**25 - 9.32162398062571e+123*cos(theta)**23 + 1.13601679532674e+123*cos(theta)**21 - 1.07316026549084e+122*cos(theta)**19 + 7.75614562125674e+120*cos(theta)**17 - 4.21092137521324e+119*cos(theta)**15 + 1.67479827423254e+118*cos(theta)**13 - 4.71433653519083e+116*cos(theta)**11 + 8.9471535346962e+114*cos(theta)**9 - 1.06619505875228e+113*cos(theta)**7 + 7.13060389611396e+110*cos(theta)**5 - 2.19066171923624e+108*cos(theta)**3 + 1.95246142534424e+105*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl98_m54(theta, phi):
    return 2.52107566003453e-106*(1.0 - cos(theta)**2)**27*(6.3968588665691e+127*cos(theta)**44 - 3.10329666039711e+128*cos(theta)**42 + 6.92212027098941e+128*cos(theta)**40 - 9.42278152071857e+128*cos(theta)**38 + 8.76218969453063e+128*cos(theta)**36 - 5.90393530219711e+128*cos(theta)**34 + 2.98388081489422e+128*cos(theta)**32 - 1.15535119764835e+128*cos(theta)**30 + 3.47084095978612e+127*cos(theta)**28 - 8.14387264307358e+126*cos(theta)**26 + 1.49534384689204e+126*cos(theta)**24 - 2.14397351554391e+125*cos(theta)**22 + 2.38563527018615e+124*cos(theta)**20 - 2.0390045044326e+123*cos(theta)**18 + 1.31854475561365e+122*cos(theta)**16 - 6.31638206281986e+120*cos(theta)**14 + 2.1772377565023e+119*cos(theta)**12 - 5.18577018870992e+117*cos(theta)**10 + 8.05243818122658e+115*cos(theta)**8 - 7.46336541126594e+113*cos(theta)**6 + 3.56530194805698e+111*cos(theta)**4 - 6.57198515770872e+108*cos(theta)**2 + 1.95246142534424e+105)*cos(54*phi)

#@torch.jit.script
def Yl98_m55(theta, phi):
    return 3.07265518220226e-108*(1.0 - cos(theta)**2)**27.5*(2.8146179012904e+129*cos(theta)**43 - 1.30338459736679e+130*cos(theta)**41 + 2.76884810839577e+130*cos(theta)**39 - 3.58065697787306e+130*cos(theta)**37 + 3.15438829003103e+130*cos(theta)**35 - 2.00733800274702e+130*cos(theta)**33 + 9.54841860766149e+129*cos(theta)**31 - 3.46605359294504e+129*cos(theta)**29 + 9.71835468740114e+128*cos(theta)**27 - 2.11740688719913e+128*cos(theta)**25 + 3.5888252325409e+127*cos(theta)**23 - 4.71674173419661e+126*cos(theta)**21 + 4.77127054037229e+125*cos(theta)**19 - 3.67020810797869e+124*cos(theta)**17 + 2.10967160898183e+123*cos(theta)**15 - 8.8429348879478e+121*cos(theta)**13 + 2.61268530780276e+120*cos(theta)**11 - 5.18577018870992e+118*cos(theta)**9 + 6.44195054498126e+116*cos(theta)**7 - 4.47801924675957e+114*cos(theta)**5 + 1.42612077922279e+112*cos(theta)**3 - 1.31439703154174e+109*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl98_m56(theta, phi):
    return 3.77588916338903e-110*(1.0 - cos(theta)**2)**28*(1.21028569755487e+131*cos(theta)**42 - 5.34387684920383e+131*cos(theta)**40 + 1.07985076227435e+132*cos(theta)**38 - 1.32484308181303e+132*cos(theta)**36 + 1.10403590151086e+132*cos(theta)**34 - 6.62421540906516e+131*cos(theta)**32 + 2.96000976837506e+131*cos(theta)**30 - 1.00515554195406e+131*cos(theta)**28 + 2.62395576559831e+130*cos(theta)**26 - 5.29351721799783e+129*cos(theta)**24 + 8.25429803484407e+128*cos(theta)**22 - 9.90515764181288e+127*cos(theta)**20 + 9.06541402670736e+126*cos(theta)**18 - 6.23935378356377e+125*cos(theta)**16 + 3.16450741347275e+124*cos(theta)**14 - 1.14958153543321e+123*cos(theta)**12 + 2.87395383858304e+121*cos(theta)**10 - 4.66719316983892e+119*cos(theta)**8 + 4.50936538148688e+117*cos(theta)**6 - 2.23900962337978e+115*cos(theta)**4 + 4.27836233766838e+112*cos(theta)**2 - 1.31439703154174e+109)*cos(56*phi)

#@torch.jit.script
def Yl98_m57(theta, phi):
    return 4.67981562751407e-112*(1.0 - cos(theta)**2)**28.5*(5.08319992973047e+132*cos(theta)**41 - 2.13755073968153e+133*cos(theta)**39 + 4.10343289664252e+133*cos(theta)**37 - 4.76943509452691e+133*cos(theta)**35 + 3.75372206513692e+133*cos(theta)**33 - 2.11974893090085e+133*cos(theta)**31 + 8.88002930512519e+132*cos(theta)**29 - 2.81443551747137e+132*cos(theta)**27 + 6.8222849905556e+131*cos(theta)**25 - 1.27044413231948e+131*cos(theta)**23 + 1.8159455676657e+130*cos(theta)**21 - 1.98103152836258e+129*cos(theta)**19 + 1.63177452480732e+128*cos(theta)**17 - 9.98296605370203e+126*cos(theta)**15 + 4.43031037886185e+125*cos(theta)**13 - 1.37949784251986e+124*cos(theta)**11 + 2.87395383858304e+122*cos(theta)**9 - 3.73375453587114e+120*cos(theta)**7 + 2.70561922889213e+118*cos(theta)**5 - 8.95603849351913e+115*cos(theta)**3 + 8.55672467533675e+112*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl98_m58(theta, phi):
    return 5.85159844471846e-114*(1.0 - cos(theta)**2)**29*(2.08411197118949e+134*cos(theta)**40 - 8.33644788475797e+134*cos(theta)**38 + 1.51827017175773e+135*cos(theta)**36 - 1.66930228308442e+135*cos(theta)**34 + 1.23872828149518e+135*cos(theta)**32 - 6.57122168579264e+134*cos(theta)**30 + 2.5752084984863e+134*cos(theta)**28 - 7.5989758971727e+133*cos(theta)**26 + 1.7055712476389e+133*cos(theta)**24 - 2.9220215043348e+132*cos(theta)**22 + 3.81348569209796e+131*cos(theta)**20 - 3.7639599038889e+130*cos(theta)**18 + 2.77401669217245e+129*cos(theta)**16 - 1.4974449080553e+128*cos(theta)**14 + 5.7594034925204e+126*cos(theta)**12 - 1.51744762677184e+125*cos(theta)**10 + 2.58655845472473e+123*cos(theta)**8 - 2.6136281751098e+121*cos(theta)**6 + 1.35280961444607e+119*cos(theta)**4 - 2.68681154805574e+116*cos(theta)**2 + 8.55672467533675e+112)*cos(58*phi)

#@torch.jit.script
def Yl98_m59(theta, phi):
    return 7.38405110772638e-116*(1.0 - cos(theta)**2)**29.5*(8.33644788475797e+135*cos(theta)**39 - 3.16785019620803e+136*cos(theta)**37 + 5.46577261832784e+136*cos(theta)**35 - 5.67562776248703e+136*cos(theta)**33 + 3.96393050078459e+136*cos(theta)**31 - 1.97136650573779e+136*cos(theta)**29 + 7.21058379576165e+135*cos(theta)**27 - 1.9757337332649e+135*cos(theta)**25 + 4.09337099433336e+134*cos(theta)**23 - 6.42844730953656e+133*cos(theta)**21 + 7.62697138419592e+132*cos(theta)**19 - 6.77512782700001e+131*cos(theta)**17 + 4.43842670747592e+130*cos(theta)**15 - 2.09642287127743e+129*cos(theta)**13 + 6.91128419102448e+127*cos(theta)**11 - 1.51744762677184e+126*cos(theta)**9 + 2.06924676377979e+124*cos(theta)**7 - 1.56817690506588e+122*cos(theta)**5 + 5.41123845778426e+119*cos(theta)**3 - 5.37362309611148e+116*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl98_m60(theta, phi):
    return 9.40662534557122e-118*(1.0 - cos(theta)**2)**30*(3.25121467505561e+137*cos(theta)**38 - 1.17210457259697e+138*cos(theta)**36 + 1.91302041641475e+138*cos(theta)**34 - 1.87295716162072e+138*cos(theta)**32 + 1.22881845524322e+138*cos(theta)**30 - 5.71696286663959e+137*cos(theta)**28 + 1.94685762485565e+137*cos(theta)**26 - 4.93933433316225e+136*cos(theta)**24 + 9.41475328696673e+135*cos(theta)**22 - 1.34997393500268e+135*cos(theta)**20 + 1.44912456299722e+134*cos(theta)**18 - 1.15177173059e+133*cos(theta)**16 + 6.65764006121389e+131*cos(theta)**14 - 2.72534973266066e+130*cos(theta)**12 + 7.60241261012693e+128*cos(theta)**10 - 1.36570286409466e+127*cos(theta)**8 + 1.44847273464585e+125*cos(theta)**6 - 7.84088452532939e+122*cos(theta)**4 + 1.62337153733528e+120*cos(theta)**2 - 5.37362309611148e+116)*cos(60*phi)

#@torch.jit.script
def Yl98_m61(theta, phi):
    return 1.21016192990425e-119*(1.0 - cos(theta)**2)**30.5*(1.23546157652113e+139*cos(theta)**37 - 4.2195764613491e+139*cos(theta)**35 + 6.50426941581013e+139*cos(theta)**33 - 5.9934629171863e+139*cos(theta)**31 + 3.68645536572967e+139*cos(theta)**29 - 1.60074960265909e+139*cos(theta)**27 + 5.06182982462468e+138*cos(theta)**25 - 1.18544023995894e+138*cos(theta)**23 + 2.07124572313268e+137*cos(theta)**21 - 2.69994787000536e+136*cos(theta)**19 + 2.608424213395e+135*cos(theta)**17 - 1.842834768944e+134*cos(theta)**15 + 9.32069608569944e+132*cos(theta)**13 - 3.27041967919279e+131*cos(theta)**11 + 7.60241261012693e+129*cos(theta)**9 - 1.09256229127573e+128*cos(theta)**7 + 8.6908364078751e+125*cos(theta)**5 - 3.13635381013176e+123*cos(theta)**3 + 3.24674307467056e+120*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl98_m62(theta, phi):
    return 1.57283307422444e-121*(1.0 - cos(theta)**2)**31*(4.57120783312819e+140*cos(theta)**36 - 1.47685176147218e+141*cos(theta)**34 + 2.14640890721734e+141*cos(theta)**32 - 1.85797350432775e+141*cos(theta)**30 + 1.0690720560616e+141*cos(theta)**28 - 4.32202392717953e+140*cos(theta)**26 + 1.26545745615617e+140*cos(theta)**24 - 2.72651255190556e+139*cos(theta)**22 + 4.34961601857863e+138*cos(theta)**20 - 5.12990095301018e+137*cos(theta)**18 + 4.43432116277151e+136*cos(theta)**16 - 2.76425215341601e+135*cos(theta)**14 + 1.21169049114093e+134*cos(theta)**12 - 3.59746164711206e+132*cos(theta)**10 + 6.84217134911424e+130*cos(theta)**8 - 7.64793603893009e+128*cos(theta)**6 + 4.34541820393755e+126*cos(theta)**4 - 9.40906143039527e+123*cos(theta)**2 + 3.24674307467056e+120)*cos(62*phi)

#@torch.jit.script
def Yl98_m63(theta, phi):
    return 2.06594352178886e-123*(1.0 - cos(theta)**2)**31.5*(1.64563481992615e+142*cos(theta)**35 - 5.02129598900542e+142*cos(theta)**33 + 6.8685085030955e+142*cos(theta)**31 - 5.57392051298326e+142*cos(theta)**29 + 2.99340175697249e+142*cos(theta)**27 - 1.12372622106668e+142*cos(theta)**25 + 3.03709789477481e+141*cos(theta)**23 - 5.99832761419224e+140*cos(theta)**21 + 8.69923203715726e+139*cos(theta)**19 - 9.23382171541832e+138*cos(theta)**17 + 7.09491386043441e+137*cos(theta)**15 - 3.86995301478241e+136*cos(theta)**13 + 1.45402858936911e+135*cos(theta)**11 - 3.59746164711206e+133*cos(theta)**9 + 5.47373707929139e+131*cos(theta)**7 - 4.58876162335805e+129*cos(theta)**5 + 1.73816728157502e+127*cos(theta)**3 - 1.88181228607905e+124*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl98_m64(theta, phi):
    return 2.74363866945678e-125*(1.0 - cos(theta)**2)**32*(5.75972186974151e+143*cos(theta)**34 - 1.65702767637179e+144*cos(theta)**32 + 2.12923763595961e+144*cos(theta)**30 - 1.61643694876515e+144*cos(theta)**28 + 8.08218474382573e+143*cos(theta)**26 - 2.8093155526667e+143*cos(theta)**24 + 6.98532515798206e+142*cos(theta)**22 - 1.25964879898037e+142*cos(theta)**20 + 1.65285408705988e+141*cos(theta)**18 - 1.56974969162111e+140*cos(theta)**16 + 1.06423707906516e+139*cos(theta)**14 - 5.03093891921713e+137*cos(theta)**12 + 1.59943144830602e+136*cos(theta)**10 - 3.23771548240086e+134*cos(theta)**8 + 3.83161595550397e+132*cos(theta)**6 - 2.29438081167903e+130*cos(theta)**4 + 5.21450184472506e+127*cos(theta)**2 - 1.88181228607905e+124)*cos(64*phi)

#@torch.jit.script
def Yl98_m65(theta, phi):
    return 3.6854765698596e-127*(1.0 - cos(theta)**2)**32.5*(1.95830543571212e+145*cos(theta)**33 - 5.30248856438973e+145*cos(theta)**31 + 6.38771290787882e+145*cos(theta)**29 - 4.52602345654241e+145*cos(theta)**27 + 2.10136803339469e+145*cos(theta)**25 - 6.74235732640007e+144*cos(theta)**23 + 1.53677153475605e+144*cos(theta)**21 - 2.51929759796074e+143*cos(theta)**19 + 2.97513735670778e+142*cos(theta)**17 - 2.51159950659378e+141*cos(theta)**15 + 1.48993191069123e+140*cos(theta)**13 - 6.03712670306055e+138*cos(theta)**11 + 1.59943144830602e+137*cos(theta)**9 - 2.59017238592069e+135*cos(theta)**7 + 2.29896957330238e+133*cos(theta)**5 - 9.17752324671611e+130*cos(theta)**3 + 1.04290036894501e+128*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl98_m66(theta, phi):
    return 5.00973508065196e-129*(1.0 - cos(theta)**2)**33*(6.46240793784998e+146*cos(theta)**32 - 1.64377145496082e+147*cos(theta)**30 + 1.85243674328486e+147*cos(theta)**28 - 1.22202633326645e+147*cos(theta)**26 + 5.25342008348672e+146*cos(theta)**24 - 1.55074218507202e+146*cos(theta)**22 + 3.22722022298771e+145*cos(theta)**20 - 4.78666543612541e+144*cos(theta)**18 + 5.05773350640323e+143*cos(theta)**16 - 3.76739925989067e+142*cos(theta)**14 + 1.93691148389859e+141*cos(theta)**12 - 6.64083937336661e+139*cos(theta)**10 + 1.43948830347542e+138*cos(theta)**8 - 1.81312067014448e+136*cos(theta)**6 + 1.14948478665119e+134*cos(theta)**4 - 2.75325697401483e+131*cos(theta)**2 + 1.04290036894501e+128)*cos(66*phi)

#@torch.jit.script
def Yl98_m67(theta, phi):
    return 6.89442099585025e-131*(1.0 - cos(theta)**2)**33.5*(2.06797054011199e+148*cos(theta)**31 - 4.93131436488245e+148*cos(theta)**29 + 5.1868228811976e+148*cos(theta)**27 - 3.17726846649277e+148*cos(theta)**25 + 1.26082082003681e+148*cos(theta)**23 - 3.41163280715844e+147*cos(theta)**21 + 6.45444044597542e+146*cos(theta)**19 - 8.61599778502574e+145*cos(theta)**17 + 8.09237361024517e+144*cos(theta)**15 - 5.27435896384694e+143*cos(theta)**13 + 2.32429378067831e+142*cos(theta)**11 - 6.64083937336661e+140*cos(theta)**9 + 1.15159064278034e+139*cos(theta)**7 - 1.08787240208669e+137*cos(theta)**5 + 4.59793914660477e+134*cos(theta)**3 - 5.50651394802966e+131*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl98_m68(theta, phi):
    return 9.61087454794881e-133*(1.0 - cos(theta)**2)**34*(6.41070867434718e+149*cos(theta)**30 - 1.43008116581591e+150*cos(theta)**28 + 1.40044217792335e+150*cos(theta)**26 - 7.94317116623192e+149*cos(theta)**24 + 2.89988788608467e+149*cos(theta)**22 - 7.16442889503272e+148*cos(theta)**20 + 1.22634368473533e+148*cos(theta)**18 - 1.46471962345438e+147*cos(theta)**16 + 1.21385604153678e+146*cos(theta)**14 - 6.85666665300103e+144*cos(theta)**12 + 2.55672315874615e+143*cos(theta)**10 - 5.97675543602995e+141*cos(theta)**8 + 8.06113449946236e+139*cos(theta)**6 - 5.43936201043344e+137*cos(theta)**4 + 1.37938174398143e+135*cos(theta)**2 - 5.50651394802966e+131)*cos(68*phi)

#@torch.jit.script
def Yl98_m69(theta, phi):
    return 1.35782576566671e-134*(1.0 - cos(theta)**2)**34.5*(1.92321260230415e+151*cos(theta)**29 - 4.00422726428455e+151*cos(theta)**27 + 3.64114966260071e+151*cos(theta)**25 - 1.90636107989566e+151*cos(theta)**23 + 6.37975334938628e+150*cos(theta)**21 - 1.43288577900654e+150*cos(theta)**19 + 2.20741863252359e+149*cos(theta)**17 - 2.343551397527e+148*cos(theta)**15 + 1.69939845815148e+147*cos(theta)**13 - 8.22799998360123e+145*cos(theta)**11 + 2.55672315874615e+144*cos(theta)**9 - 4.78140434882396e+142*cos(theta)**7 + 4.83668069967742e+140*cos(theta)**5 - 2.17574480417338e+138*cos(theta)**3 + 2.75876348796286e+135*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl98_m70(theta, phi):
    return 1.94531710551958e-136*(1.0 - cos(theta)**2)**35*(5.57731654668205e+152*cos(theta)**28 - 1.08114136135683e+153*cos(theta)**26 + 9.10287415650179e+152*cos(theta)**24 - 4.38463048376002e+152*cos(theta)**22 + 1.33974820337112e+152*cos(theta)**20 - 2.72248298011243e+151*cos(theta)**18 + 3.75261167529011e+150*cos(theta)**16 - 3.5153270962905e+149*cos(theta)**14 + 2.20921799559693e+148*cos(theta)**12 - 9.05079998196135e+146*cos(theta)**10 + 2.30105084287153e+145*cos(theta)**8 - 3.34698304417677e+143*cos(theta)**6 + 2.41834034983871e+141*cos(theta)**4 - 6.52723441252013e+138*cos(theta)**2 + 2.75876348796286e+135)*cos(70*phi)

#@torch.jit.script
def Yl98_m71(theta, phi):
    return 2.82792597932132e-138*(1.0 - cos(theta)**2)**35.5*(1.56164863307097e+154*cos(theta)**27 - 2.81096753952775e+154*cos(theta)**25 + 2.18468979756043e+154*cos(theta)**23 - 9.64618706427205e+153*cos(theta)**21 + 2.67949640674224e+153*cos(theta)**19 - 4.90046936420238e+152*cos(theta)**17 + 6.00417868046417e+151*cos(theta)**15 - 4.9214579348067e+150*cos(theta)**13 + 2.65106159471632e+149*cos(theta)**11 - 9.05079998196135e+147*cos(theta)**9 + 1.84084067429722e+146*cos(theta)**7 - 2.00818982650606e+144*cos(theta)**5 + 9.67336139935483e+141*cos(theta)**3 - 1.30544688250403e+139*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl98_m72(theta, phi):
    return 4.17408890415419e-140*(1.0 - cos(theta)**2)**36*(4.21645130929163e+155*cos(theta)**26 - 7.02741884881938e+155*cos(theta)**24 + 5.02478653438899e+155*cos(theta)**22 - 2.02569928349713e+155*cos(theta)**20 + 5.09104317281025e+154*cos(theta)**18 - 8.33079791914404e+153*cos(theta)**16 + 9.00626802069626e+152*cos(theta)**14 - 6.39789531524871e+151*cos(theta)**12 + 2.91616775418795e+150*cos(theta)**10 - 8.14571998376522e+148*cos(theta)**8 + 1.28858847200806e+147*cos(theta)**6 - 1.00409491325303e+145*cos(theta)**4 + 2.90200841980645e+142*cos(theta)**2 - 1.30544688250403e+139)*cos(72*phi)

#@torch.jit.script
def Yl98_m73(theta, phi):
    return 6.26003794543089e-142*(1.0 - cos(theta)**2)**36.5*(1.09627734041582e+157*cos(theta)**25 - 1.68658052371665e+157*cos(theta)**23 + 1.10545303756558e+157*cos(theta)**21 - 4.05139856699426e+156*cos(theta)**19 + 9.16387771105845e+155*cos(theta)**17 - 1.33292766706305e+155*cos(theta)**15 + 1.26087752289748e+154*cos(theta)**13 - 7.67747437829845e+152*cos(theta)**11 + 2.91616775418795e+151*cos(theta)**9 - 6.51657598701217e+149*cos(theta)**7 + 7.73153083204834e+147*cos(theta)**5 - 4.01637965301213e+145*cos(theta)**3 + 5.8040168396129e+142*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl98_m74(theta, phi):
    return 9.54646836906066e-144*(1.0 - cos(theta)**2)**37*(2.74069335103956e+158*cos(theta)**24 - 3.8791352045483e+158*cos(theta)**22 + 2.32145137888771e+158*cos(theta)**20 - 7.69765727728909e+157*cos(theta)**18 + 1.55785921087994e+157*cos(theta)**16 - 1.99939150059457e+156*cos(theta)**14 + 1.63914077976672e+155*cos(theta)**12 - 8.4452218161283e+153*cos(theta)**10 + 2.62455097876915e+152*cos(theta)**8 - 4.56160319090852e+150*cos(theta)**6 + 3.86576541602417e+148*cos(theta)**4 - 1.20491389590364e+146*cos(theta)**2 + 5.8040168396129e+142)*cos(74*phi)

#@torch.jit.script
def Yl98_m75(theta, phi):
    return 1.48154233350587e-145*(1.0 - cos(theta)**2)**37.5*(6.57766404249494e+159*cos(theta)**23 - 8.53409745000625e+159*cos(theta)**21 + 4.64290275777542e+159*cos(theta)**19 - 1.38557830991204e+159*cos(theta)**17 + 2.4925747374079e+158*cos(theta)**15 - 2.7991481008324e+157*cos(theta)**13 + 1.96696893572006e+156*cos(theta)**11 - 8.4452218161283e+154*cos(theta)**9 + 2.09964078301532e+153*cos(theta)**7 - 2.73696191454511e+151*cos(theta)**5 + 1.54630616640967e+149*cos(theta)**3 - 2.40982779180728e+146*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl98_m76(theta, phi):
    return 2.34193870041187e-147*(1.0 - cos(theta)**2)**38*(1.51286272977384e+161*cos(theta)**22 - 1.79216046450131e+161*cos(theta)**20 + 8.8215152397733e+160*cos(theta)**18 - 2.35548312685046e+160*cos(theta)**16 + 3.73886210611185e+159*cos(theta)**14 - 3.63889253108212e+158*cos(theta)**12 + 2.16366582929207e+157*cos(theta)**10 - 7.60069963451547e+155*cos(theta)**8 + 1.46974854811073e+154*cos(theta)**6 - 1.36848095727256e+152*cos(theta)**4 + 4.63891849922901e+149*cos(theta)**2 - 2.40982779180728e+146)*cos(76*phi)

#@torch.jit.script
def Yl98_m77(theta, phi):
    return 3.77437597026328e-149*(1.0 - cos(theta)**2)**38.5*(3.32829800550244e+162*cos(theta)**21 - 3.58432092900263e+162*cos(theta)**19 + 1.58787274315919e+162*cos(theta)**17 - 3.76877300296074e+161*cos(theta)**15 + 5.23440694855658e+160*cos(theta)**13 - 4.36667103729854e+159*cos(theta)**11 + 2.16366582929207e+158*cos(theta)**9 - 6.08055970761237e+156*cos(theta)**7 + 8.81849128866436e+154*cos(theta)**5 - 5.47392382909023e+152*cos(theta)**3 + 9.27783699845801e+149*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl98_m78(theta, phi):
    return 6.20839266762537e-151*(1.0 - cos(theta)**2)**39*(6.98942581155512e+163*cos(theta)**20 - 6.81020976510499e+163*cos(theta)**18 + 2.69938366337063e+163*cos(theta)**16 - 5.65315950444111e+162*cos(theta)**14 + 6.80472903312356e+161*cos(theta)**12 - 4.8033381410284e+160*cos(theta)**10 + 1.94729924636286e+159*cos(theta)**8 - 4.25639179532866e+157*cos(theta)**6 + 4.40924564433218e+155*cos(theta)**4 - 1.64217714872707e+153*cos(theta)**2 + 9.27783699845801e+149)*cos(78*phi)

#@torch.jit.script
def Yl98_m79(theta, phi):
    return 1.04346418263193e-152*(1.0 - cos(theta)**2)**39.5*(1.39788516231102e+165*cos(theta)**19 - 1.2258377577189e+165*cos(theta)**17 + 4.31901386139301e+164*cos(theta)**15 - 7.91442330621756e+163*cos(theta)**13 + 8.16567483974827e+162*cos(theta)**11 - 4.8033381410284e+161*cos(theta)**9 + 1.55783939709029e+160*cos(theta)**7 - 2.5538350771972e+158*cos(theta)**5 + 1.76369825773287e+156*cos(theta)**3 - 3.28435429745414e+153*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl98_m80(theta, phi):
    return 1.79428218305859e-154*(1.0 - cos(theta)**2)**40*(2.65598180839095e+166*cos(theta)**18 - 2.08392418812213e+166*cos(theta)**16 + 6.47852079208951e+165*cos(theta)**14 - 1.02887502980828e+165*cos(theta)**12 + 8.9822423237231e+163*cos(theta)**10 - 4.32300432692556e+162*cos(theta)**8 + 1.0904875779632e+161*cos(theta)**6 - 1.2769175385986e+159*cos(theta)**4 + 5.29109477319861e+156*cos(theta)**2 - 3.28435429745414e+153)*cos(80*phi)

#@torch.jit.script
def Yl98_m81(theta, phi):
    return 3.16102533497397e-156*(1.0 - cos(theta)**2)**40.5*(4.7807672551037e+167*cos(theta)**17 - 3.3342787009954e+167*cos(theta)**15 + 9.06992910892532e+166*cos(theta)**13 - 1.23465003576994e+166*cos(theta)**11 + 8.9822423237231e+164*cos(theta)**9 - 3.45840346154044e+163*cos(theta)**7 + 6.54292546777922e+161*cos(theta)**5 - 5.10767015439439e+159*cos(theta)**3 + 1.05821895463972e+157*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl98_m82(theta, phi):
    return 5.71435560910229e-158*(1.0 - cos(theta)**2)**41*(8.12730433367629e+168*cos(theta)**16 - 5.0014180514931e+168*cos(theta)**14 + 1.17909078416029e+168*cos(theta)**12 - 1.35811503934693e+167*cos(theta)**10 + 8.08401809135079e+165*cos(theta)**8 - 2.42088242307831e+164*cos(theta)**6 + 3.27146273388961e+162*cos(theta)**4 - 1.53230104631832e+160*cos(theta)**2 + 1.05821895463972e+157)*cos(82*phi)

#@torch.jit.script
def Yl98_m83(theta, phi):
    return 1.0618617684551e-159*(1.0 - cos(theta)**2)**41.5*(1.30036869338821e+170*cos(theta)**15 - 7.00198527209035e+169*cos(theta)**13 + 1.41490894099235e+169*cos(theta)**11 - 1.35811503934693e+168*cos(theta)**9 + 6.46721447308063e+166*cos(theta)**7 - 1.45252945384699e+165*cos(theta)**5 + 1.30858509355584e+163*cos(theta)**3 - 3.06460209263664e+160*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl98_m84(theta, phi):
    return 2.03229459023276e-161*(1.0 - cos(theta)**2)**42*(1.95055304008231e+171*cos(theta)**14 - 9.10258085371745e+170*cos(theta)**12 + 1.55639983509158e+170*cos(theta)**10 - 1.22230353541224e+169*cos(theta)**8 + 4.52705013115644e+167*cos(theta)**6 - 7.26264726923493e+165*cos(theta)**4 + 3.92575528066753e+163*cos(theta)**2 - 3.06460209263664e+160)*cos(84*phi)

#@torch.jit.script
def Yl98_m85(theta, phi):
    return 4.01510676861106e-163*(1.0 - cos(theta)**2)**42.5*(2.73077425611524e+172*cos(theta)**13 - 1.09230970244609e+172*cos(theta)**11 + 1.55639983509158e+171*cos(theta)**9 - 9.77842828329791e+169*cos(theta)**7 + 2.71623007869387e+168*cos(theta)**5 - 2.90505890769397e+166*cos(theta)**3 + 7.85151056133506e+163*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl98_m86(theta, phi):
    return 8.20949628650893e-165*(1.0 - cos(theta)**2)**43*(3.55000653294981e+173*cos(theta)**12 - 1.2015406726907e+173*cos(theta)**10 + 1.40075985158243e+172*cos(theta)**8 - 6.84489979830854e+170*cos(theta)**6 + 1.35811503934693e+169*cos(theta)**4 - 8.71517672308192e+166*cos(theta)**2 + 7.85151056133506e+163)*cos(86*phi)

#@torch.jit.script
def Yl98_m87(theta, phi):
    return 1.74236855047515e-166*(1.0 - cos(theta)**2)**43.5*(4.26000783953977e+174*cos(theta)**11 - 1.2015406726907e+174*cos(theta)**9 + 1.12060788126594e+173*cos(theta)**7 - 4.10693987898512e+171*cos(theta)**5 + 5.43246015738773e+169*cos(theta)**3 - 1.74303534461638e+167*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl98_m88(theta, phi):
    return 3.85200825209621e-168*(1.0 - cos(theta)**2)**44*(4.68600862349374e+175*cos(theta)**10 - 1.08138660542163e+175*cos(theta)**8 + 7.84425516886159e+173*cos(theta)**6 - 2.05346993949256e+172*cos(theta)**4 + 1.62973804721632e+170*cos(theta)**2 - 1.74303534461638e+167)*cos(88*phi)

#@torch.jit.script
def Yl98_m89(theta, phi):
    return 8.90771688947175e-170*(1.0 - cos(theta)**2)**44.5*(4.68600862349374e+176*cos(theta)**9 - 8.65109284337306e+175*cos(theta)**7 + 4.70655310131695e+174*cos(theta)**5 - 8.21387975797025e+172*cos(theta)**3 + 3.25947609443264e+170*cos(theta))*cos(89*phi)

#@torch.jit.script
def Yl98_m90(theta, phi):
    return 2.16554008058075e-171*(1.0 - cos(theta)**2)**45*(4.21740776114437e+177*cos(theta)**8 - 6.05576499036115e+176*cos(theta)**6 + 2.35327655065848e+175*cos(theta)**4 - 2.46416392739107e+173*cos(theta)**2 + 3.25947609443264e+170)*cos(90*phi)

#@torch.jit.script
def Yl98_m91(theta, phi):
    return 5.56916814851313e-173*(1.0 - cos(theta)**2)**45.5*(3.3739262089155e+178*cos(theta)**7 - 3.63345899421669e+177*cos(theta)**5 + 9.41310620263391e+175*cos(theta)**3 - 4.92832785478215e+173*cos(theta))*cos(91*phi)

#@torch.jit.script
def Yl98_m92(theta, phi):
    return 1.52708956723136e-174*(1.0 - cos(theta)**2)**46*(2.36174834624085e+179*cos(theta)**6 - 1.81672949710834e+178*cos(theta)**4 + 2.82393186079017e+176*cos(theta)**2 - 4.92832785478215e+173)*cos(92*phi)

#@torch.jit.script
def Yl98_m93(theta, phi):
    return 4.51099350022227e-176*(1.0 - cos(theta)**2)**46.5*(1.41704900774451e+180*cos(theta)**5 - 7.26691798843337e+178*cos(theta)**3 + 5.64786372158034e+176*cos(theta))*cos(93*phi)

#@torch.jit.script
def Yl98_m94(theta, phi):
    return 1.45591689176756e-177*(1.0 - cos(theta)**2)**47*(7.08524503872254e+180*cos(theta)**4 - 2.18007539653001e+179*cos(theta)**2 + 5.64786372158034e+176)*cos(94*phi)

#@torch.jit.script
def Yl98_m95(theta, phi):
    return 5.23995955237687e-179*(1.0 - cos(theta)**2)**47.5*(2.83409801548902e+181*cos(theta)**3 - 4.36015079306002e+179*cos(theta))*cos(95*phi)

#@torch.jit.script
def Yl98_m96(theta, phi):
    return 2.17203311531976e-180*(1.0 - cos(theta)**2)**48*(8.50229404646705e+181*cos(theta)**2 - 4.36015079306002e+179)*cos(96*phi)

#@torch.jit.script
def Yl98_m97(theta, phi):
    return 18.7025254831072*(1.0 - cos(theta)**2)**48.5*cos(97*phi)*cos(theta)

#@torch.jit.script
def Yl98_m98(theta, phi):
    return 1.3358946773648*(1.0 - cos(theta)**2)**49*cos(98*phi)

#@torch.jit.script
def Yl99_m_minus_99(theta, phi):
    return 1.339263900061*(1.0 - cos(theta)**2)**49.5*sin(99*phi)

#@torch.jit.script
def Yl99_m_minus_98(theta, phi):
    return 18.8451135102262*(1.0 - cos(theta)**2)**49*sin(98*phi)*cos(theta)

#@torch.jit.script
def Yl99_m_minus_97(theta, phi):
    return 1.11664345848169e-182*(1.0 - cos(theta)**2)**48.5*(1.67495192715401e+184*cos(theta)**2 - 8.50229404646705e+181)*sin(97*phi)

#@torch.jit.script
def Yl99_m_minus_96(theta, phi):
    return 2.70771648564159e-181*(1.0 - cos(theta)**2)**48*(5.58317309051336e+183*cos(theta)**3 - 8.50229404646705e+181*cos(theta))*sin(96*phi)

#@torch.jit.script
def Yl99_m_minus_95(theta, phi):
    return 7.56224059519393e-180*(1.0 - cos(theta)**2)**47.5*(1.39579327262834e+183*cos(theta)**4 - 4.25114702323352e+181*cos(theta)**2 + 1.09003769826501e+179)*sin(95*phi)

#@torch.jit.script
def Yl99_m_minus_94(theta, phi):
    return 2.35524644856989e-178*(1.0 - cos(theta)**2)**47*(2.79158654525668e+182*cos(theta)**5 - 1.41704900774451e+181*cos(theta)**3 + 1.09003769826501e+179*cos(theta))*sin(94*phi)

#@torch.jit.script
def Yl99_m_minus_93(theta, phi):
    return 8.01476212697188e-177*(1.0 - cos(theta)**2)**46.5*(4.65264424209447e+181*cos(theta)**6 - 3.54262251936127e+180*cos(theta)**4 + 5.45018849132503e+178*cos(theta)**2 - 9.41310620263391e+175)*sin(93*phi)

#@torch.jit.script
def Yl99_m_minus_92(theta, phi):
    return 2.93826032991311e-175*(1.0 - cos(theta)**2)**46*(6.64663463156353e+180*cos(theta)**7 - 7.08524503872254e+179*cos(theta)**5 + 1.81672949710834e+178*cos(theta)**3 - 9.41310620263391e+175*cos(theta))*sin(92*phi)

#@torch.jit.script
def Yl99_m_minus_91(theta, phi):
    return 1.1485554020146e-173*(1.0 - cos(theta)**2)**45.5*(8.30829328945441e+179*cos(theta)**8 - 1.18087417312042e+179*cos(theta)**6 + 4.54182374277086e+177*cos(theta)**4 - 4.70655310131695e+175*cos(theta)**2 + 6.16040981847769e+172)*sin(91*phi)

#@torch.jit.script
def Yl99_m_minus_90(theta, phi):
    return 4.74952309675375e-172*(1.0 - cos(theta)**2)**45*(9.23143698828267e+178*cos(theta)**9 - 1.68696310445775e+178*cos(theta)**7 + 9.08364748554172e+176*cos(theta)**5 - 1.56885103377232e+175*cos(theta)**3 + 6.16040981847769e+172*cos(theta))*sin(90*phi)

#@torch.jit.script
def Yl99_m_minus_89(theta, phi):
    return 2.06481385679361e-170*(1.0 - cos(theta)**2)**44.5*(9.23143698828267e+177*cos(theta)**10 - 2.10870388057218e+177*cos(theta)**8 + 1.51394124759029e+176*cos(theta)**6 - 3.92212758443079e+174*cos(theta)**4 + 3.08020490923884e+172*cos(theta)**2 - 3.25947609443264e+169)*sin(89*phi)

#@torch.jit.script
def Yl99_m_minus_88(theta, phi):
    return 9.38979635152534e-169*(1.0 - cos(theta)**2)**44*(8.39221544389334e+176*cos(theta)**11 - 2.34300431174687e+176*cos(theta)**9 + 2.16277321084327e+175*cos(theta)**7 - 7.84425516886159e+173*cos(theta)**5 + 1.02673496974628e+172*cos(theta)**3 - 3.25947609443264e+169*cos(theta))*sin(88*phi)

#@torch.jit.script
def Yl99_m_minus_87(theta, phi):
    return 4.44802889237332e-167*(1.0 - cos(theta)**2)**43.5*(6.99351286991112e+175*cos(theta)**12 - 2.34300431174687e+175*cos(theta)**10 + 2.70346651355408e+174*cos(theta)**8 - 1.30737586147693e+173*cos(theta)**6 + 2.5668374243657e+171*cos(theta)**4 - 1.62973804721632e+169*cos(theta)**2 + 1.45252945384699e+166)*sin(87*phi)

#@torch.jit.script
def Yl99_m_minus_86(theta, phi):
    return 2.18723651588537e-165*(1.0 - cos(theta)**2)**43*(5.37962528454701e+174*cos(theta)**13 - 2.13000391976988e+174*cos(theta)**11 + 3.00385168172676e+173*cos(theta)**9 - 1.8676798021099e+172*cos(theta)**7 + 5.13367484873141e+170*cos(theta)**5 - 5.43246015738773e+168*cos(theta)**3 + 1.45252945384699e+166*cos(theta))*sin(86*phi)

#@torch.jit.script
def Yl99_m_minus_85(theta, phi):
    return 1.11312933942709e-163*(1.0 - cos(theta)**2)**42.5*(3.84258948896215e+173*cos(theta)**14 - 1.7750032664749e+173*cos(theta)**12 + 3.00385168172676e+172*cos(theta)**10 - 2.33459975263738e+171*cos(theta)**8 + 8.55612474788568e+169*cos(theta)**6 - 1.35811503934693e+168*cos(theta)**4 + 7.26264726923493e+165*cos(theta)**2 - 5.60822182952505e+162)*sin(85*phi)

#@torch.jit.script
def Yl99_m_minus_84(theta, phi):
    return 5.84790314263991e-162*(1.0 - cos(theta)**2)**42*(2.56172632597477e+172*cos(theta)**15 - 1.36538712805762e+172*cos(theta)**13 + 2.73077425611524e+171*cos(theta)**11 - 2.59399972515264e+170*cos(theta)**9 + 1.22230353541224e+169*cos(theta)**7 - 2.71623007869387e+167*cos(theta)**5 + 2.42088242307831e+165*cos(theta)**3 - 5.60822182952505e+162*cos(theta))*sin(84*phi)

#@torch.jit.script
def Yl99_m_minus_83(theta, phi):
    return 3.16435869605775e-160*(1.0 - cos(theta)**2)**41.5*(1.60107895373423e+171*cos(theta)**16 - 9.75276520041155e+170*cos(theta)**14 + 2.27564521342936e+170*cos(theta)**12 - 2.59399972515264e+169*cos(theta)**10 + 1.5278794192653e+168*cos(theta)**8 - 4.52705013115644e+166*cos(theta)**6 + 6.05220605769578e+164*cos(theta)**4 - 2.80411091476252e+162*cos(theta)**2 + 1.9153763078979e+159)*sin(83*phi)

#@torch.jit.script
def Yl99_m_minus_82(theta, phi):
    return 1.76013452531153e-158*(1.0 - cos(theta)**2)**41*(9.41811149255429e+169*cos(theta)**17 - 6.50184346694104e+169*cos(theta)**15 + 1.75049631802259e+169*cos(theta)**13 - 2.35818156832058e+168*cos(theta)**11 + 1.69764379918367e+167*cos(theta)**9 - 6.46721447308063e+165*cos(theta)**7 + 1.21044121153916e+164*cos(theta)**5 - 9.34703638254174e+161*cos(theta)**3 + 1.9153763078979e+159*cos(theta))*sin(82*phi)

#@torch.jit.script
def Yl99_m_minus_81(theta, phi):
    return 1.00466529833358e-156*(1.0 - cos(theta)**2)**40.5*(5.23228416253016e+168*cos(theta)**18 - 4.06365216683815e+168*cos(theta)**16 + 1.25035451287328e+168*cos(theta)**14 - 1.96515130693382e+167*cos(theta)**12 + 1.69764379918367e+166*cos(theta)**10 - 8.08401809135079e+164*cos(theta)**8 + 2.01740201923193e+163*cos(theta)**6 - 2.33675909563544e+161*cos(theta)**4 + 9.57688153948949e+158*cos(theta)**2 - 5.8789941924429e+155)*sin(81*phi)

#@torch.jit.script
def Yl99_m_minus_80(theta, phi):
    return 5.87535962893411e-155*(1.0 - cos(theta)**2)**40*(2.75383376975272e+167*cos(theta)**19 - 2.39038362755185e+167*cos(theta)**17 + 8.33569675248851e+166*cos(theta)**15 - 1.51165485148755e+166*cos(theta)**13 + 1.54331254471242e+165*cos(theta)**11 - 8.9822423237231e+163*cos(theta)**9 + 2.88200288461704e+162*cos(theta)**7 - 4.67351819127087e+160*cos(theta)**5 + 3.1922938464965e+158*cos(theta)**3 - 5.8789941924429e+155*cos(theta))*sin(80*phi)

#@torch.jit.script
def Yl99_m_minus_79(theta, phi):
    return 3.51540987303224e-153*(1.0 - cos(theta)**2)**39.5*(1.37691688487636e+166*cos(theta)**20 - 1.32799090419547e+166*cos(theta)**18 + 5.20981047030532e+165*cos(theta)**16 - 1.07975346534825e+165*cos(theta)**14 + 1.28609378726035e+164*cos(theta)**12 - 8.9822423237231e+162*cos(theta)**10 + 3.6025036057713e+161*cos(theta)**8 - 7.78919698545145e+159*cos(theta)**6 + 7.98073461624124e+157*cos(theta)**4 - 2.93949709622145e+155*cos(theta)**2 + 1.64217714872707e+152)*sin(79*phi)

#@torch.jit.script
def Yl99_m_minus_78(theta, phi):
    return 2.14929296232254e-151*(1.0 - cos(theta)**2)**39*(6.5567470708398e+164*cos(theta)**21 - 6.98942581155512e+164*cos(theta)**19 + 3.06459439429725e+164*cos(theta)**17 - 7.19835643565502e+163*cos(theta)**15 + 9.89302913277194e+162*cos(theta)**13 - 8.16567483974827e+161*cos(theta)**11 + 4.00278178419033e+160*cos(theta)**9 - 1.11274242649306e+159*cos(theta)**7 + 1.59614692324825e+157*cos(theta)**5 - 9.79832365407151e+154*cos(theta)**3 + 1.64217714872707e+152*cos(theta))*sin(78*phi)

#@torch.jit.script
def Yl99_m_minus_77(theta, phi):
    return 1.34120014040935e-149*(1.0 - cos(theta)**2)**38.5*(2.98033957765446e+163*cos(theta)**22 - 3.49471290577756e+163*cos(theta)**20 + 1.70255244127625e+163*cos(theta)**18 - 4.49897277228438e+162*cos(theta)**16 + 7.06644938055139e+161*cos(theta)**14 - 6.80472903312356e+160*cos(theta)**12 + 4.00278178419033e+159*cos(theta)**10 - 1.39092803311633e+158*cos(theta)**8 + 2.66024487208041e+156*cos(theta)**6 - 2.44958091351788e+154*cos(theta)**4 + 8.21088574363534e+151*cos(theta)**2 - 4.21719863566273e+148)*sin(77*phi)

#@torch.jit.script
def Yl99_m_minus_76(theta, phi):
    return 8.53323767495941e-148*(1.0 - cos(theta)**2)**38*(1.2957998163715e+162*cos(theta)**23 - 1.66414900275122e+162*cos(theta)**21 + 8.96080232250657e+161*cos(theta)**19 - 2.64645457193199e+161*cos(theta)**17 + 4.71096625370093e+160*cos(theta)**15 - 5.23440694855658e+159*cos(theta)**13 + 3.63889253108212e+158*cos(theta)**11 - 1.54547559235148e+157*cos(theta)**9 + 3.80034981725773e+155*cos(theta)**7 - 4.89916182703575e+153*cos(theta)**5 + 2.73696191454511e+151*cos(theta)**3 - 4.21719863566273e+148*cos(theta))*sin(76*phi)

#@torch.jit.script
def Yl99_m_minus_75(theta, phi):
    return 5.53017006892967e-146*(1.0 - cos(theta)**2)**37.5*(5.39916590154793e+160*cos(theta)**24 - 7.56431364886918e+160*cos(theta)**22 + 4.48040116125328e+160*cos(theta)**20 - 1.47025253996222e+160*cos(theta)**18 + 2.94435390856308e+159*cos(theta)**16 - 3.73886210611185e+158*cos(theta)**14 + 3.03241044256843e+157*cos(theta)**12 - 1.54547559235148e+156*cos(theta)**10 + 4.75043727157217e+154*cos(theta)**8 - 8.16526971172625e+152*cos(theta)**6 + 6.84240478636278e+150*cos(theta)**4 - 2.10859931783137e+148*cos(theta)**2 + 1.00409491325303e+145)*sin(75*phi)

#@torch.jit.script
def Yl99_m_minus_74(theta, phi):
    return 3.64739766562535e-144*(1.0 - cos(theta)**2)**37*(2.15966636061917e+159*cos(theta)**25 - 3.28883202124747e+159*cos(theta)**23 + 2.13352436250156e+159*cos(theta)**21 - 7.73817126295904e+158*cos(theta)**19 + 1.73197288739005e+158*cos(theta)**17 - 2.4925747374079e+157*cos(theta)**15 + 2.33262341736033e+156*cos(theta)**13 - 1.40497781122862e+155*cos(theta)**11 + 5.27826363508019e+153*cos(theta)**9 - 1.16646710167518e+152*cos(theta)**7 + 1.36848095727256e+150*cos(theta)**5 - 7.02866439277122e+147*cos(theta)**3 + 1.00409491325303e+145*cos(theta))*sin(74*phi)

#@torch.jit.script
def Yl99_m_minus_73(theta, phi):
    return 2.4462049540253e-142*(1.0 - cos(theta)**2)**36.5*(8.30640907930451e+157*cos(theta)**26 - 1.37034667551978e+158*cos(theta)**24 + 9.69783801137074e+157*cos(theta)**22 - 3.86908563147952e+157*cos(theta)**20 + 9.62207159661137e+156*cos(theta)**18 - 1.55785921087994e+156*cos(theta)**16 + 1.66615958382881e+155*cos(theta)**14 - 1.17081484269051e+154*cos(theta)**12 + 5.27826363508019e+152*cos(theta)**10 - 1.45808387709397e+151*cos(theta)**8 + 2.28080159545426e+149*cos(theta)**6 - 1.75716609819281e+147*cos(theta)**4 + 5.02047456626516e+144*cos(theta)**2 - 2.23231416908188e+141)*sin(73*phi)

#@torch.jit.script
def Yl99_m_minus_72(theta, phi):
    return 1.66701284747427e-140*(1.0 - cos(theta)**2)**36*(3.07644780714982e+156*cos(theta)**27 - 5.48138670207912e+156*cos(theta)**25 + 4.21645130929163e+156*cos(theta)**23 - 1.84242172927596e+156*cos(theta)**21 + 5.06424820874283e+155*cos(theta)**19 - 9.16387771105845e+154*cos(theta)**17 + 1.11077305588587e+154*cos(theta)**15 - 9.00626802069626e+152*cos(theta)**13 + 4.79842148643653e+151*cos(theta)**11 - 1.62009319677108e+150*cos(theta)**9 + 3.25828799350609e+148*cos(theta)**7 - 3.51433219638561e+146*cos(theta)**5 + 1.67349152208839e+144*cos(theta)**3 - 2.23231416908188e+141*cos(theta))*sin(72*phi)

#@torch.jit.script
def Yl99_m_minus_71(theta, phi):
    return 1.15349580057704e-138*(1.0 - cos(theta)**2)**35.5*(1.09873135969636e+155*cos(theta)**28 - 2.10822565464581e+155*cos(theta)**26 + 1.75685471220484e+155*cos(theta)**24 - 8.37464422398164e+154*cos(theta)**22 + 2.53212410437141e+154*cos(theta)**20 - 5.09104317281025e+153*cos(theta)**18 + 6.9423315992867e+152*cos(theta)**16 - 6.43304858621162e+151*cos(theta)**14 + 3.99868457203044e+150*cos(theta)**12 - 1.62009319677108e+149*cos(theta)**10 + 4.07285999188261e+147*cos(theta)**8 - 5.85722032730935e+145*cos(theta)**6 + 4.18372880522096e+143*cos(theta)**4 - 1.11615708454094e+141*cos(theta)**2 + 4.66231029465724e+137)*sin(71*phi)

#@torch.jit.script
def Yl99_m_minus_70(theta, phi):
    return 8.09915065325245e-137*(1.0 - cos(theta)**2)**35*(3.78872882653918e+153*cos(theta)**29 - 7.80824316535486e+153*cos(theta)**27 + 7.02741884881938e+153*cos(theta)**25 - 3.64114966260071e+153*cos(theta)**23 + 1.20577338303401e+153*cos(theta)**21 - 2.67949640674224e+152*cos(theta)**19 + 4.08372447016865e+151*cos(theta)**17 - 4.28869905747441e+150*cos(theta)**15 + 3.07591120925419e+149*cos(theta)**13 - 1.47281199706462e+148*cos(theta)**11 + 4.52539999098068e+146*cos(theta)**9 - 8.36745761044193e+144*cos(theta)**7 + 8.36745761044193e+142*cos(theta)**5 - 3.72052361513647e+140*cos(theta)**3 + 4.66231029465724e+137*cos(theta))*sin(70*phi)

#@torch.jit.script
def Yl99_m_minus_69(theta, phi):
    return 5.76691376224479e-135*(1.0 - cos(theta)**2)**34.5*(1.26290960884639e+152*cos(theta)**30 - 2.78865827334102e+152*cos(theta)**28 + 2.70285340339207e+152*cos(theta)**26 - 1.5171456927503e+152*cos(theta)**24 + 5.48078810470003e+151*cos(theta)**22 - 1.33974820337112e+151*cos(theta)**20 + 2.26873581676036e+150*cos(theta)**18 - 2.68043691092151e+149*cos(theta)**16 + 2.19707943518156e+148*cos(theta)**14 - 1.22734333088718e+147*cos(theta)**12 + 4.52539999098068e+145*cos(theta)**10 - 1.04593220130524e+144*cos(theta)**8 + 1.39457626840699e+142*cos(theta)**6 - 9.30130903784118e+139*cos(theta)**4 + 2.33115514732862e+137*cos(theta)**2 - 9.19587829320954e+133)*sin(69*phi)

#@torch.jit.script
def Yl99_m_minus_68(theta, phi):
    return 4.16177833298225e-133*(1.0 - cos(theta)**2)**34*(4.07390196402063e+150*cos(theta)**31 - 9.61606301152077e+150*cos(theta)**29 + 1.00105681607114e+151*cos(theta)**27 - 6.06858277100119e+150*cos(theta)**25 + 2.38295134986958e+150*cos(theta)**23 - 6.37975334938628e+149*cos(theta)**21 + 1.19407148250545e+149*cos(theta)**19 - 1.57672759465971e+148*cos(theta)**17 + 1.46471962345438e+147*cos(theta)**15 - 9.44110254528603e+145*cos(theta)**13 + 4.11399999180062e+144*cos(theta)**11 - 1.16214689033916e+143*cos(theta)**9 + 1.99225181200998e+141*cos(theta)**7 - 1.86026180756824e+139*cos(theta)**5 + 7.77051715776206e+136*cos(theta)**3 - 9.19587829320954e+133*cos(theta))*sin(68*phi)

#@torch.jit.script
def Yl99_m_minus_67(theta, phi):
    return 3.0423709780951e-131*(1.0 - cos(theta)**2)**33.5*(1.27309436375645e+149*cos(theta)**32 - 3.20535433717359e+149*cos(theta)**30 + 3.57520291453977e+149*cos(theta)**28 - 2.33407029653892e+149*cos(theta)**26 + 9.92896395778991e+148*cos(theta)**24 - 2.89988788608467e+148*cos(theta)**22 + 5.97035741252726e+147*cos(theta)**20 - 8.7595977481095e+146*cos(theta)**18 + 9.15449764658984e+145*cos(theta)**16 - 6.74364467520431e+144*cos(theta)**14 + 3.42833332650051e+143*cos(theta)**12 - 1.16214689033916e+142*cos(theta)**10 + 2.49031476501248e+140*cos(theta)**8 - 3.10043634594706e+138*cos(theta)**6 + 1.94262928944051e+136*cos(theta)**4 - 4.59793914660477e+133*cos(theta)**2 + 1.72078560875927e+130)*sin(67*phi)

#@torch.jit.script
def Yl99_m_minus_66(theta, phi):
    return 2.25176561747111e-129*(1.0 - cos(theta)**2)**33*(3.85786170835287e+147*cos(theta)**33 - 1.033985270056e+148*cos(theta)**31 + 1.23282859122061e+148*cos(theta)**29 - 8.644704801996e+147*cos(theta)**27 + 3.97158558311596e+147*cos(theta)**25 - 1.26082082003681e+147*cos(theta)**23 + 2.8430273392987e+146*cos(theta)**21 - 4.61031460426816e+145*cos(theta)**19 + 5.38499861564109e+144*cos(theta)**17 - 4.49576311680287e+143*cos(theta)**15 + 2.63717948192347e+142*cos(theta)**13 - 1.0564971730356e+141*cos(theta)**11 + 2.76701640556942e+139*cos(theta)**9 - 4.42919477992437e+137*cos(theta)**7 + 3.88525857888103e+135*cos(theta)**5 - 1.53264638220159e+133*cos(theta)**3 + 1.72078560875927e+130*cos(theta))*sin(66*phi)

#@torch.jit.script
def Yl99_m_minus_65(theta, phi):
    return 1.68657094430387e-127*(1.0 - cos(theta)**2)**32.5*(1.13466520833908e+146*cos(theta)**34 - 3.23120396892499e+146*cos(theta)**32 + 4.10942863740204e+146*cos(theta)**30 - 3.08739457214143e+146*cos(theta)**28 + 1.52753291658306e+146*cos(theta)**26 - 5.25342008348672e+145*cos(theta)**24 + 1.29228515422668e+145*cos(theta)**22 - 2.30515730213408e+144*cos(theta)**20 + 2.99166589757838e+143*cos(theta)**18 - 2.80985194800179e+142*cos(theta)**16 + 1.88369962994534e+141*cos(theta)**14 - 8.80414310862998e+139*cos(theta)**12 + 2.76701640556942e+138*cos(theta)**10 - 5.53649347490547e+136*cos(theta)**8 + 6.47543096480172e+134*cos(theta)**6 - 3.83161595550397e+132*cos(theta)**4 + 8.60392804379635e+129*cos(theta)**2 - 3.06735402630886e+126)*sin(65*phi)

#@torch.jit.script
def Yl99_m_minus_64(theta, phi):
    return 1.27779316393445e-125*(1.0 - cos(theta)**2)**32*(3.24190059525451e+144*cos(theta)**35 - 9.79152717856058e+144*cos(theta)**33 + 1.32562214109743e+145*cos(theta)**31 - 1.0646188179798e+145*cos(theta)**29 + 5.65752932067801e+144*cos(theta)**27 - 2.10136803339469e+144*cos(theta)**25 + 5.61863110533339e+143*cos(theta)**23 - 1.09769395339718e+143*cos(theta)**21 + 1.57456099872546e+142*cos(theta)**19 - 1.65285408705988e+141*cos(theta)**17 + 1.25579975329689e+140*cos(theta)**15 - 6.77241777586921e+138*cos(theta)**13 + 2.51546945960856e+137*cos(theta)**11 - 6.15165941656163e+135*cos(theta)**9 + 9.25061566400245e+133*cos(theta)**7 - 7.66323191100795e+131*cos(theta)**5 + 2.86797601459878e+129*cos(theta)**3 - 3.06735402630886e+126*cos(theta))*sin(64*phi)

#@torch.jit.script
def Yl99_m_minus_63(theta, phi):
    return 9.78826261906186e-124*(1.0 - cos(theta)**2)**31.5*(9.00527943126253e+142*cos(theta)**36 - 2.87986093487076e+143*cos(theta)**34 + 4.14256919092947e+143*cos(theta)**32 - 3.54872939326601e+143*cos(theta)**30 + 2.02054618595643e+143*cos(theta)**28 - 8.08218474382573e+142*cos(theta)**26 + 2.34109629388891e+142*cos(theta)**24 - 4.98951796998718e+141*cos(theta)**22 + 7.87280499362732e+140*cos(theta)**20 - 9.18252270588822e+139*cos(theta)**18 + 7.84874845810557e+138*cos(theta)**16 - 4.83744126847801e+137*cos(theta)**14 + 2.0962245496738e+136*cos(theta)**12 - 6.15165941656163e+134*cos(theta)**10 + 1.15632695800031e+133*cos(theta)**8 - 1.27720531850132e+131*cos(theta)**6 + 7.16994003649696e+128*cos(theta)**4 - 1.53367701315443e+126*cos(theta)**2 + 5.2272563502196e+122)*sin(63*phi)

#@torch.jit.script
def Yl99_m_minus_62(theta, phi):
    return 7.57816369635642e-122*(1.0 - cos(theta)**2)**31*(2.43385930574663e+141*cos(theta)**37 - 8.22817409963074e+141*cos(theta)**35 + 1.25532399725136e+142*cos(theta)**33 - 1.14475141718258e+142*cos(theta)**31 + 6.96740064122908e+141*cos(theta)**29 - 2.99340175697249e+141*cos(theta)**27 + 9.36438517555566e+140*cos(theta)**25 - 2.16935563912486e+140*cos(theta)**23 + 3.74895475887015e+139*cos(theta)**21 - 4.83290668730959e+138*cos(theta)**19 + 4.61691085770916e+137*cos(theta)**17 - 3.22496084565201e+136*cos(theta)**15 + 1.612480422826e+135*cos(theta)**13 - 5.59241765141966e+133*cos(theta)**11 + 1.28480773111145e+132*cos(theta)**9 - 1.82457902643046e+130*cos(theta)**7 + 1.43398800729939e+128*cos(theta)**5 - 5.11225671051476e+125*cos(theta)**3 + 5.2272563502196e+122*cos(theta))*sin(62*phi)

#@torch.jit.script
def Yl99_m_minus_61(theta, phi):
    return 5.92746118269603e-120*(1.0 - cos(theta)**2)**30.5*(6.40489290985955e+139*cos(theta)**38 - 2.28560391656409e+140*cos(theta)**36 + 3.69212940368046e+140*cos(theta)**34 - 3.57734817869557e+140*cos(theta)**32 + 2.32246688040969e+140*cos(theta)**30 - 1.0690720560616e+140*cos(theta)**28 + 3.60168660598294e+139*cos(theta)**26 - 9.03898182968693e+138*cos(theta)**24 + 1.70407034494098e+138*cos(theta)**22 - 2.41645334365479e+137*cos(theta)**20 + 2.56495047650509e+136*cos(theta)**18 - 2.0156005285325e+135*cos(theta)**16 + 1.15177173059e+134*cos(theta)**14 - 4.66034804284972e+132*cos(theta)**12 + 1.28480773111145e+131*cos(theta)**10 - 2.28072378303808e+129*cos(theta)**8 + 2.38998001216565e+127*cos(theta)**6 - 1.27806417762869e+125*cos(theta)**4 + 2.6136281751098e+122*cos(theta)**2 - 8.54406072281725e+118)*sin(61*phi)

#@torch.jit.script
def Yl99_m_minus_60(theta, phi):
    return 4.68231916352973e-118*(1.0 - cos(theta)**2)**30*(1.64228023329732e+138*cos(theta)**39 - 6.17730788260566e+138*cos(theta)**37 + 1.05489411533727e+139*cos(theta)**35 - 1.08404490263502e+139*cos(theta)**33 + 7.49182864648288e+138*cos(theta)**31 - 3.68645536572967e+138*cos(theta)**29 + 1.33395800221591e+138*cos(theta)**27 - 3.61559273187477e+137*cos(theta)**25 + 7.40900149974338e+136*cos(theta)**23 - 1.15069206840704e+136*cos(theta)**21 + 1.34997393500268e+135*cos(theta)**19 - 1.185647369725e+134*cos(theta)**17 + 7.67847820393335e+132*cos(theta)**15 - 3.5848831098844e+131*cos(theta)**13 + 1.16800702828314e+130*cos(theta)**11 - 2.53413753670898e+128*cos(theta)**9 + 3.41425716023665e+126*cos(theta)**7 - 2.55612835525738e+124*cos(theta)**5 + 8.71209391703266e+121*cos(theta)**3 - 8.54406072281725e+118*cos(theta))*sin(60*phi)

#@torch.jit.script
def Yl99_m_minus_59(theta, phi):
    return 3.73413118522426e-116*(1.0 - cos(theta)**2)**29.5*(4.1057005832433e+136*cos(theta)**40 - 1.6256073375278e+137*cos(theta)**38 + 2.93026143149243e+137*cos(theta)**36 - 3.18836736069124e+137*cos(theta)**34 + 2.3411964520259e+137*cos(theta)**32 - 1.22881845524322e+137*cos(theta)**30 + 4.76413572219966e+136*cos(theta)**28 - 1.3906125891826e+136*cos(theta)**26 + 3.08708395822641e+135*cos(theta)**24 - 5.23041849275929e+134*cos(theta)**22 + 6.74986967501339e+133*cos(theta)**20 - 6.58692983180557e+132*cos(theta)**18 + 4.79904887745834e+131*cos(theta)**16 - 2.56063079277457e+130*cos(theta)**14 + 9.73339190235948e+128*cos(theta)**12 - 2.53413753670898e+127*cos(theta)**10 + 4.26782145029581e+125*cos(theta)**8 - 4.26021392542897e+123*cos(theta)**6 + 2.17802347925816e+121*cos(theta)**4 - 4.27203036140863e+118*cos(theta)**2 + 1.34340577402787e+115)*sin(59*phi)

#@torch.jit.script
def Yl99_m_minus_58(theta, phi):
    return 3.0054537081684e-114*(1.0 - cos(theta)**2)**29*(1.0013903861569e+135*cos(theta)**41 - 4.16822394237899e+135*cos(theta)**39 + 7.91962549052007e+135*cos(theta)**37 - 9.10962103054641e+135*cos(theta)**35 + 7.09453470310878e+135*cos(theta)**33 - 3.96393050078459e+135*cos(theta)**31 + 1.64280542144816e+135*cos(theta)**29 - 5.15041699697261e+134*cos(theta)**27 + 1.23483358329056e+134*cos(theta)**25 - 2.27409499685187e+133*cos(theta)**23 + 3.21422365476828e+132*cos(theta)**21 - 3.46680517463451e+131*cos(theta)**19 + 2.82296992791667e+130*cos(theta)**17 - 1.70708719518305e+129*cos(theta)**15 + 7.48722454027652e+127*cos(theta)**13 - 2.30376139700816e+126*cos(theta)**11 + 4.74202383366201e+124*cos(theta)**9 - 6.08601989346996e+122*cos(theta)**7 + 4.35604695851633e+120*cos(theta)**5 - 1.42401012046954e+118*cos(theta)**3 + 1.34340577402787e+115*cos(theta))*sin(58*phi)

#@torch.jit.script
def Yl99_m_minus_57(theta, phi):
    return 2.44053204516707e-112*(1.0 - cos(theta)**2)**28.5*(2.3842628241831e+133*cos(theta)**42 - 1.04205598559475e+134*cos(theta)**40 + 2.08411197118949e+134*cos(theta)**38 - 2.53045028626289e+134*cos(theta)**36 + 2.08662785385552e+134*cos(theta)**34 - 1.23872828149518e+134*cos(theta)**32 + 5.47601807149386e+133*cos(theta)**30 - 1.83943464177593e+133*cos(theta)**28 + 4.74935993573294e+132*cos(theta)**26 - 9.47539582021611e+131*cos(theta)**24 + 1.4610107521674e+131*cos(theta)**22 - 1.73340258731725e+130*cos(theta)**20 + 1.56831662662037e+129*cos(theta)**18 - 1.0669294969894e+128*cos(theta)**16 + 5.34801752876895e+126*cos(theta)**14 - 1.91980116417347e+125*cos(theta)**12 + 4.74202383366201e+123*cos(theta)**10 - 7.60752486683745e+121*cos(theta)**8 + 7.26007826419388e+119*cos(theta)**6 - 3.56002530117386e+117*cos(theta)**4 + 6.71702887013935e+114*cos(theta)**2 - 2.0373153988897e+111)*sin(57*phi)

#@torch.jit.script
def Yl99_m_minus_56(theta, phi):
    return 1.99885385205305e-110*(1.0 - cos(theta)**2)**28*(5.5447972655421e+131*cos(theta)**43 - 2.54159996486524e+132*cos(theta)**41 + 5.34387684920383e+132*cos(theta)**39 - 6.83905482773754e+132*cos(theta)**37 + 5.96179386815864e+132*cos(theta)**35 - 3.75372206513692e+132*cos(theta)**33 + 1.76645744241738e+132*cos(theta)**31 - 6.34287807508942e+131*cos(theta)**29 + 1.75902219841961e+131*cos(theta)**27 - 3.79015832808644e+130*cos(theta)**25 + 6.35222066159739e+129*cos(theta)**23 - 8.25429803484407e+128*cos(theta)**21 + 8.25429803484407e+127*cos(theta)**19 - 6.27605586464356e+126*cos(theta)**17 + 3.5653450191793e+125*cos(theta)**15 - 1.47677012628728e+124*cos(theta)**13 + 4.31093075787455e+122*cos(theta)**11 - 8.45280540759716e+120*cos(theta)**9 + 1.03715403774198e+119*cos(theta)**7 - 7.12005060234771e+116*cos(theta)**5 + 2.23900962337978e+114*cos(theta)**3 - 2.0373153988897e+111*cos(theta))*sin(56*phi)

#@torch.jit.script
def Yl99_m_minus_55(theta, phi):
    return 1.65071929906738e-108*(1.0 - cos(theta)**2)**27.5*(1.26018119671411e+130*cos(theta)**44 - 6.05142848777437e+130*cos(theta)**42 + 1.33596921230096e+131*cos(theta)**40 - 1.79975127045725e+131*cos(theta)**38 + 1.65605385226629e+131*cos(theta)**36 - 1.10403590151086e+131*cos(theta)**34 + 5.5201795075543e+130*cos(theta)**32 - 2.11429269169647e+130*cos(theta)**30 + 6.28222213721288e+129*cos(theta)**28 - 1.45775320311017e+129*cos(theta)**26 + 2.64675860899891e+128*cos(theta)**24 - 3.75195365220185e+127*cos(theta)**22 + 4.12714901742204e+126*cos(theta)**20 - 3.48669770257975e+125*cos(theta)**18 + 2.22834063698706e+124*cos(theta)**16 - 1.05483580449092e+123*cos(theta)**14 + 3.59244229822879e+121*cos(theta)**12 - 8.45280540759716e+119*cos(theta)**10 + 1.29644254717748e+118*cos(theta)**8 - 1.18667510039129e+116*cos(theta)**6 + 5.59752405844946e+113*cos(theta)**4 - 1.01865769944485e+111*cos(theta)**2 + 2.98726598077669e+107)*sin(55*phi)

#@torch.jit.script
def Yl99_m_minus_54(theta, phi):
    return 1.37416804779811e-106*(1.0 - cos(theta)**2)**27*(2.8004026593647e+128*cos(theta)**45 - 1.4073089506452e+129*cos(theta)**43 + 3.25846149341697e+129*cos(theta)**41 - 4.61474684732628e+129*cos(theta)**39 + 4.47582122234132e+129*cos(theta)**37 - 3.15438829003103e+129*cos(theta)**35 + 1.67278166895585e+129*cos(theta)**33 - 6.82029900547249e+128*cos(theta)**31 + 2.16628349559065e+128*cos(theta)**29 - 5.39908593744508e+127*cos(theta)**27 + 1.05870344359957e+127*cos(theta)**25 - 1.6312841966095e+126*cos(theta)**23 + 1.96530905591525e+125*cos(theta)**21 - 1.83510405398934e+124*cos(theta)**19 + 1.31078860999239e+123*cos(theta)**17 - 7.03223869660611e+121*cos(theta)**15 + 2.76341715248369e+120*cos(theta)**13 - 7.68436855236106e+118*cos(theta)**11 + 1.44049171908609e+117*cos(theta)**9 - 1.69525014341612e+115*cos(theta)**7 + 1.11950481168989e+113*cos(theta)**5 - 3.39552566481617e+110*cos(theta)**3 + 2.98726598077669e+107*cos(theta))*sin(54*phi)

#@torch.jit.script
def Yl99_m_minus_53(theta, phi):
    return 1.15282789706101e-104*(1.0 - cos(theta)**2)**26.5*(6.08783186818412e+126*cos(theta)**46 - 3.19842943328455e+127*cos(theta)**44 + 7.75824165099278e+127*cos(theta)**42 - 1.15368671183157e+128*cos(theta)**40 + 1.17784769008982e+128*cos(theta)**38 - 8.76218969453063e+127*cos(theta)**36 + 4.91994608516426e+127*cos(theta)**34 - 2.13134343921015e+127*cos(theta)**32 + 7.22094498530216e+126*cos(theta)**30 - 1.92824497765896e+126*cos(theta)**28 + 4.07193632153679e+125*cos(theta)**26 - 6.79701748587292e+124*cos(theta)**24 + 8.93322298143298e+123*cos(theta)**22 - 9.17552026994672e+122*cos(theta)**20 + 7.28215894440216e+121*cos(theta)**18 - 4.39514918537882e+120*cos(theta)**16 + 1.97386939463121e+119*cos(theta)**14 - 6.40364046030088e+117*cos(theta)**12 + 1.44049171908609e+116*cos(theta)**10 - 2.11906267927015e+114*cos(theta)**8 + 1.86584135281649e+112*cos(theta)**6 - 8.48881416204043e+109*cos(theta)**4 + 1.49363299038834e+107*cos(theta)**2 - 4.244481359444e+103)*sin(53*phi)

#@torch.jit.script
def Yl99_m_minus_52(theta, phi):
    return 9.74395344445452e-103*(1.0 - cos(theta)**2)**26*(1.29528337620939e+125*cos(theta)**47 - 7.10762096285456e+125*cos(theta)**45 + 1.80424224441693e+126*cos(theta)**43 - 2.81387002885749e+126*cos(theta)**41 + 3.02012228228159e+126*cos(theta)**39 - 2.36815937690017e+126*cos(theta)**37 + 1.4056988814755e+126*cos(theta)**35 - 6.45861648245501e+125*cos(theta)**33 + 2.32933709203296e+125*cos(theta)**31 - 6.64912061261709e+124*cos(theta)**29 + 1.50812456353214e+124*cos(theta)**27 - 2.71880699434917e+123*cos(theta)**25 + 3.88400999192738e+122*cos(theta)**23 - 4.3692953666413e+121*cos(theta)**21 + 3.83271523389587e+120*cos(theta)**19 - 2.58538187375225e+119*cos(theta)**17 + 1.31591292975414e+118*cos(theta)**15 - 4.92587727715452e+116*cos(theta)**13 + 1.3095379264419e+115*cos(theta)**11 - 2.35451408807795e+113*cos(theta)**9 + 2.66548764688069e+111*cos(theta)**7 - 1.69776283240809e+109*cos(theta)**5 + 4.97877663462782e+106*cos(theta)**3 - 4.244481359444e+103*cos(theta))*sin(52*phi)

#@torch.jit.script
def Yl99_m_minus_51(theta, phi):
    return 8.29553294863174e-101*(1.0 - cos(theta)**2)**25.5*(2.69850703376956e+123*cos(theta)**48 - 1.5451349919249e+124*cos(theta)**46 + 4.10055055549301e+124*cos(theta)**44 - 6.69969054489877e+124*cos(theta)**42 + 7.55030570570399e+124*cos(theta)**40 - 6.23199836026361e+124*cos(theta)**38 + 3.90471911520973e+124*cos(theta)**36 - 1.899593083075e+124*cos(theta)**34 + 7.27917841260298e+123*cos(theta)**32 - 2.21637353753903e+123*cos(theta)**30 + 5.38615915547195e+122*cos(theta)**28 - 1.0456949978266e+122*cos(theta)**26 + 1.61833749663641e+121*cos(theta)**24 - 1.98604334847332e+120*cos(theta)**22 + 1.91635761694794e+119*cos(theta)**20 - 1.43632326319569e+118*cos(theta)**18 + 8.22445581096336e+116*cos(theta)**16 - 3.51848376939609e+115*cos(theta)**14 + 1.09128160536825e+114*cos(theta)**12 - 2.35451408807795e+112*cos(theta)**10 + 3.33185955860087e+110*cos(theta)**8 - 2.82960472068014e+108*cos(theta)**6 + 1.24469415865695e+106*cos(theta)**4 - 2.122240679722e+103*cos(theta)**2 + 5.85607251578919e+99)*sin(51*phi)

#@torch.jit.script
def Yl99_m_minus_50(theta, phi):
    return 7.11193800400767e-99*(1.0 - cos(theta)**2)**25*(5.50715721177461e+121*cos(theta)**49 - 3.28752125941469e+122*cos(theta)**47 + 9.11233456776225e+122*cos(theta)**45 - 1.55806756858111e+123*cos(theta)**43 + 1.84153797700097e+123*cos(theta)**41 - 1.59794829750349e+123*cos(theta)**39 + 1.05532949059722e+123*cos(theta)**37 - 5.42740880878572e+122*cos(theta)**35 + 2.20581164018272e+122*cos(theta)**33 - 7.14959205657752e+121*cos(theta)**31 + 1.85729626050757e+121*cos(theta)**29 - 3.87294443639482e+120*cos(theta)**27 + 6.47334998654564e+119*cos(theta)**25 - 8.63497108031877e+118*cos(theta)**23 + 9.12551246165684e+117*cos(theta)**21 - 7.55959612208259e+116*cos(theta)**19 + 4.83791518291962e+115*cos(theta)**17 - 2.34565584626406e+114*cos(theta)**15 + 8.39447388744806e+112*cos(theta)**13 - 2.14046735279813e+111*cos(theta)**11 + 3.70206617622319e+109*cos(theta)**9 - 4.04229245811449e+107*cos(theta)**7 + 2.48938831731391e+105*cos(theta)**5 - 7.07413559907334e+102*cos(theta)**3 + 5.85607251578919e+99*cos(theta))*sin(50*phi)

#@torch.jit.script
def Yl99_m_minus_49(theta, phi):
    return 6.13855425314236e-97*(1.0 - cos(theta)**2)**24.5*(1.10143144235492e+120*cos(theta)**50 - 6.8490026237806e+120*cos(theta)**48 + 1.98094229733962e+121*cos(theta)**46 - 3.54106265586616e+121*cos(theta)**44 + 4.3846142309547e+121*cos(theta)**42 - 3.99487074375872e+121*cos(theta)**40 + 2.7771828699927e+121*cos(theta)**38 - 1.50761355799603e+121*cos(theta)**36 + 6.48768129465507e+120*cos(theta)**34 - 2.23424751768047e+120*cos(theta)**32 + 6.19098753502522e+119*cos(theta)**30 - 1.38319444156958e+119*cos(theta)**28 + 2.48974999482524e+118*cos(theta)**26 - 3.59790461679949e+117*cos(theta)**24 + 4.14796020984402e+116*cos(theta)**22 - 3.7797980610413e+115*cos(theta)**20 + 2.68773065717757e+114*cos(theta)**18 - 1.46603490391504e+113*cos(theta)**16 + 5.99605277674862e+111*cos(theta)**14 - 1.78372279399844e+110*cos(theta)**12 + 3.70206617622319e+108*cos(theta)**10 - 5.05286557264311e+106*cos(theta)**8 + 4.14898052885651e+104*cos(theta)**6 - 1.76853389976834e+102*cos(theta)**4 + 2.92803625789459e+99*cos(theta)**2 - 7.86050002119354e+95)*sin(49*phi)

#@torch.jit.script
def Yl99_m_minus_48(theta, phi):
    return 5.33312845438859e-95*(1.0 - cos(theta)**2)**24*(2.15966949481357e+118*cos(theta)**51 - 1.39775563750625e+119*cos(theta)**49 + 4.21477084540345e+119*cos(theta)**47 - 7.86902812414702e+119*cos(theta)**45 + 1.019677728129e+120*cos(theta)**43 - 9.74358717989932e+119*cos(theta)**41 + 7.12098171792999e+119*cos(theta)**39 - 4.07463123782712e+119*cos(theta)**37 + 1.8536232270443e+119*cos(theta)**35 - 6.77044702327416e+118*cos(theta)**33 + 1.99709275323394e+118*cos(theta)**31 - 4.76963600541235e+117*cos(theta)**29 + 9.22129627713053e+116*cos(theta)**27 - 1.43916184671979e+116*cos(theta)**25 + 1.80346096080175e+115*cos(theta)**23 - 1.79990383859109e+114*cos(theta)**21 + 1.41459508272504e+113*cos(theta)**19 - 8.62373472891198e+111*cos(theta)**17 + 3.99736851783241e+110*cos(theta)**15 - 1.37209445692188e+109*cos(theta)**13 + 3.36551470565744e+107*cos(theta)**11 - 5.61429508071457e+105*cos(theta)**9 + 5.92711504122359e+103*cos(theta)**7 - 3.53706779953667e+101*cos(theta)**5 + 9.76012085964865e+98*cos(theta)**3 - 7.86050002119354e+95*cos(theta))*sin(48*phi)

#@torch.jit.script
def Yl99_m_minus_47(theta, phi):
    return 4.66275271320016e-93*(1.0 - cos(theta)**2)**23.5*(4.15321056694918e+116*cos(theta)**52 - 2.79551127501249e+117*cos(theta)**50 + 8.78077259459052e+117*cos(theta)**48 - 1.71065828785805e+118*cos(theta)**46 + 2.31744938211136e+118*cos(theta)**44 - 2.31990170949984e+118*cos(theta)**42 + 1.7802454294825e+118*cos(theta)**40 - 1.07227137837556e+118*cos(theta)**38 + 5.1489534084564e+117*cos(theta)**36 - 1.99130794802181e+117*cos(theta)**34 + 6.24091485385607e+116*cos(theta)**32 - 1.58987866847078e+116*cos(theta)**30 + 3.29332009897519e+115*cos(theta)**28 - 5.53523787199921e+114*cos(theta)**26 + 7.51442067000728e+113*cos(theta)**24 - 8.18138108450497e+112*cos(theta)**22 + 7.07297541362518e+111*cos(theta)**20 - 4.79096373828443e+110*cos(theta)**18 + 2.49835532364526e+109*cos(theta)**16 - 9.80067469229915e+107*cos(theta)**14 + 2.80459558804787e+106*cos(theta)**12 - 5.61429508071457e+104*cos(theta)**10 + 7.40889380152949e+102*cos(theta)**8 - 5.89511299922778e+100*cos(theta)**6 + 2.44003021491216e+98*cos(theta)**4 - 3.93025001059677e+95*cos(theta)**2 + 1.02832287038115e+92)*sin(47*phi)

#@torch.jit.script
def Yl99_m_minus_46(theta, phi):
    return 4.10163250481021e-91*(1.0 - cos(theta)**2)**23*(7.83624635273429e+114*cos(theta)**53 - 5.48139465688724e+115*cos(theta)**51 + 1.79199440705929e+116*cos(theta)**49 - 3.63969848480436e+116*cos(theta)**47 + 5.14988751580303e+116*cos(theta)**45 - 5.39512025465079e+116*cos(theta)**43 + 4.34206202312804e+116*cos(theta)**41 - 2.74941379070656e+116*cos(theta)**39 + 1.39160902931254e+116*cos(theta)**37 - 5.68945128006232e+115*cos(theta)**35 + 1.89118631935033e+115*cos(theta)**33 - 5.12864086603478e+114*cos(theta)**31 + 1.13562762033627e+114*cos(theta)**29 - 2.05008810074045e+113*cos(theta)**27 + 3.00576826800291e+112*cos(theta)**25 - 3.55712221065433e+111*cos(theta)**23 + 3.3680835302977e+110*cos(theta)**21 - 2.52155986225497e+109*cos(theta)**19 + 1.46962077861486e+108*cos(theta)**17 - 6.53378312819943e+106*cos(theta)**15 + 2.15738122157528e+105*cos(theta)**13 - 5.10390461883143e+103*cos(theta)**11 + 8.23210422392166e+101*cos(theta)**9 - 8.42158999889683e+99*cos(theta)**7 + 4.88006042982432e+97*cos(theta)**5 - 1.31008333686559e+95*cos(theta)**3 + 1.02832287038115e+92*cos(theta))*sin(46*phi)

#@torch.jit.script
def Yl99_m_minus_45(theta, phi):
    return 3.62942333534347e-89*(1.0 - cos(theta)**2)**22.5*(1.45115673198783e+113*cos(theta)**54 - 1.0541143570937e+114*cos(theta)**52 + 3.58398881411858e+114*cos(theta)**50 - 7.58270517667575e+114*cos(theta)**48 + 1.11954076430501e+115*cos(theta)**46 - 1.22616369423882e+115*cos(theta)**44 + 1.03382429122096e+115*cos(theta)**42 - 6.8735344767664e+114*cos(theta)**40 + 3.66212902450669e+114*cos(theta)**38 - 1.58040313335065e+114*cos(theta)**36 + 5.56231270397154e+113*cos(theta)**34 - 1.60270027063587e+113*cos(theta)**32 + 3.78542540112091e+112*cos(theta)**30 - 7.32174321693017e+111*cos(theta)**28 + 1.15606471846266e+111*cos(theta)**26 - 1.48213425443931e+110*cos(theta)**24 + 1.53094705922623e+109*cos(theta)**22 - 1.26077993112748e+108*cos(theta)**20 + 8.16455988119365e+106*cos(theta)**18 - 4.08361445512464e+105*cos(theta)**16 + 1.54098658683949e+104*cos(theta)**14 - 4.25325384902619e+102*cos(theta)**12 + 8.23210422392166e+100*cos(theta)**10 - 1.0526987498621e+99*cos(theta)**8 + 8.13343404970721e+96*cos(theta)**6 - 3.27520834216398e+94*cos(theta)**4 + 5.14161435190577e+91*cos(theta)**2 - 1.31331145642548e+88)*sin(45*phi)

#@torch.jit.script
def Yl99_m_minus_44(theta, phi):
    return 3.22998286183248e-87*(1.0 - cos(theta)**2)**22*(2.63846678543242e+111*cos(theta)**55 - 1.98889501338434e+112*cos(theta)**53 + 7.02742904729133e+112*cos(theta)**51 - 1.54749085238281e+113*cos(theta)**49 + 2.38200162618086e+113*cos(theta)**47 - 2.72480820941959e+113*cos(theta)**45 + 2.40424253772317e+113*cos(theta)**43 - 1.67647182360156e+113*cos(theta)**41 + 9.39007442181202e+112*cos(theta)**39 - 4.27135981986661e+112*cos(theta)**37 + 1.58923220113473e+112*cos(theta)**35 - 4.85666748677536e+111*cos(theta)**33 + 1.22110496810352e+111*cos(theta)**31 - 2.52473904032075e+110*cos(theta)**29 + 4.28172117949133e+109*cos(theta)**27 - 5.92853701775722e+108*cos(theta)**25 + 6.65629156185317e+107*cos(theta)**23 - 6.00371395774992e+106*cos(theta)**21 + 4.29713677957561e+105*cos(theta)**19 - 2.40212615007332e+104*cos(theta)**17 + 1.02732439122633e+103*cos(theta)**15 - 3.27173373002015e+101*cos(theta)**13 + 7.48373111265605e+99*cos(theta)**11 - 1.16966527762456e+98*cos(theta)**9 + 1.16191914995817e+96*cos(theta)**7 - 6.55041668432795e+93*cos(theta)**5 + 1.71387145063526e+91*cos(theta)**3 - 1.31331145642548e+88*cos(theta))*sin(44*phi)

#@torch.jit.script
def Yl99_m_minus_43(theta, phi):
    return 2.89042862939312e-85*(1.0 - cos(theta)**2)**21.5*(4.71154783112932e+109*cos(theta)**56 - 3.6831389136747e+110*cos(theta)**54 + 1.35142866294064e+111*cos(theta)**52 - 3.09498170476561e+111*cos(theta)**50 + 4.9625033878768e+111*cos(theta)**48 - 5.92349610743389e+111*cos(theta)**46 + 5.46418758573447e+111*cos(theta)**44 - 3.99159958000372e+111*cos(theta)**42 + 2.347518605453e+111*cos(theta)**40 - 1.12404205785963e+111*cos(theta)**38 + 4.41453389204091e+110*cos(theta)**36 - 1.42843161375746e+110*cos(theta)**34 + 3.8159530253235e+109*cos(theta)**32 - 8.41579680106916e+108*cos(theta)**30 + 1.52918613553262e+108*cos(theta)**28 - 2.28020654529124e+107*cos(theta)**26 + 2.77345481743882e+106*cos(theta)**24 - 2.72896088988633e+105*cos(theta)**22 + 2.1485683897878e+104*cos(theta)**20 - 1.33451452781851e+103*cos(theta)**18 + 6.42077744516454e+101*cos(theta)**16 - 2.3369526643001e+100*cos(theta)**14 + 6.23644259388004e+98*cos(theta)**12 - 1.16966527762456e+97*cos(theta)**10 + 1.45239893744772e+95*cos(theta)**8 - 1.09173611405466e+93*cos(theta)**6 + 4.28467862658814e+90*cos(theta)**4 - 6.56655728212742e+87*cos(theta)**2 + 1.63999932121064e+84)*sin(43*phi)

#@torch.jit.script
def Yl99_m_minus_42(theta, phi):
    return 2.60042211175638e-83*(1.0 - cos(theta)**2)**21*(8.26587338794618e+107*cos(theta)**57 - 6.69661620668127e+108*cos(theta)**55 + 2.54986540177479e+109*cos(theta)**53 - 6.06859157797179e+109*cos(theta)**51 + 1.01275579344424e+110*cos(theta)**49 - 1.26031832073062e+110*cos(theta)**47 + 1.21426390794099e+110*cos(theta)**45 - 9.28278972093887e+109*cos(theta)**43 + 5.72565513525123e+109*cos(theta)**41 - 2.88215912271701e+109*cos(theta)**39 + 1.19311726811916e+109*cos(theta)**37 - 4.08123318216417e+108*cos(theta)**35 + 1.15634940161318e+108*cos(theta)**33 - 2.71477316163521e+107*cos(theta)**31 + 5.27305563976764e+106*cos(theta)**29 - 8.44520942700459e+105*cos(theta)**27 + 1.10938192697553e+105*cos(theta)**25 - 1.18650473473319e+104*cos(theta)**23 + 1.02312780466086e+103*cos(theta)**21 - 7.02376067272901e+101*cos(theta)**19 + 3.77692790892031e+100*cos(theta)**17 - 1.55796844286674e+99*cos(theta)**15 + 4.79726353375388e+97*cos(theta)**13 - 1.06333207056778e+96*cos(theta)**11 + 1.61377659716413e+94*cos(theta)**9 - 1.55962302007808e+92*cos(theta)**7 + 8.56935725317628e+89*cos(theta)**5 - 2.18885242737581e+87*cos(theta)**3 + 1.63999932121064e+84*cos(theta))*sin(42*phi)

#@torch.jit.script
def Yl99_m_minus_41(theta, phi):
    return 2.35162139837282e-81*(1.0 - cos(theta)**2)**20.5*(1.42515058412865e+106*cos(theta)**58 - 1.19582432262166e+107*cos(theta)**56 + 4.72197296624962e+107*cos(theta)**54 - 1.16703684191765e+108*cos(theta)**52 + 2.02551158688849e+108*cos(theta)**50 - 2.62566316818878e+108*cos(theta)**48 + 2.63970414769781e+108*cos(theta)**46 - 2.10972493657702e+108*cos(theta)**44 + 1.36325122267886e+108*cos(theta)**42 - 7.20539780679252e+107*cos(theta)**40 + 3.13978228452412e+107*cos(theta)**38 - 1.13367588393449e+107*cos(theta)**36 + 3.40102765180347e+106*cos(theta)**34 - 8.48366613011004e+105*cos(theta)**32 + 1.75768521325588e+105*cos(theta)**30 - 3.01614622393021e+104*cos(theta)**28 + 4.26685356529049e+103*cos(theta)**26 - 4.94376972805494e+102*cos(theta)**24 + 4.65058093027663e+101*cos(theta)**22 - 3.5118803363645e+100*cos(theta)**20 + 2.09829328273351e+99*cos(theta)**18 - 9.7373027679171e+97*cos(theta)**16 + 3.4266168098242e+96*cos(theta)**14 - 8.86110058806485e+94*cos(theta)**12 + 1.61377659716413e+93*cos(theta)**10 - 1.9495287750976e+91*cos(theta)**8 + 1.42822620886271e+89*cos(theta)**6 - 5.47213106843952e+86*cos(theta)**4 + 8.19999660605322e+83*cos(theta)**2 - 2.00537945856034e+80)*sin(41*phi)

#@torch.jit.script
def Yl99_m_minus_40(theta, phi):
    return 2.13726034077774e-79*(1.0 - cos(theta)**2)**20*(2.41550946462483e+104*cos(theta)**59 - 2.09793740810817e+105*cos(theta)**57 + 8.58540539318112e+105*cos(theta)**55 - 2.201956305505e+106*cos(theta)**53 + 3.97159134684017e+106*cos(theta)**51 - 5.35849626160976e+106*cos(theta)**49 + 5.61639180361237e+106*cos(theta)**47 - 4.68827763683781e+106*cos(theta)**45 + 3.17035168064852e+106*cos(theta)**43 - 1.75741409921769e+106*cos(theta)**41 + 8.05072380647209e+105*cos(theta)**39 - 3.06398887549862e+105*cos(theta)**37 + 9.71722186229564e+104*cos(theta)**35 - 2.57080791821516e+104*cos(theta)**33 + 5.66995230082542e+103*cos(theta)**31 - 1.0400504220449e+103*cos(theta)**29 + 1.58031613529278e+102*cos(theta)**27 - 1.97750789122198e+101*cos(theta)**25 + 2.02199170881593e+100*cos(theta)**23 - 1.67232396969738e+99*cos(theta)**21 + 1.10436488564921e+98*cos(theta)**19 - 5.72782515759829e+96*cos(theta)**17 + 2.28441120654947e+95*cos(theta)**15 - 6.81623122158835e+93*cos(theta)**13 + 1.46706963378557e+92*cos(theta)**11 - 2.16614308344178e+90*cos(theta)**9 + 2.04032315551816e+88*cos(theta)**7 - 1.0944262136879e+86*cos(theta)**5 + 2.73333220201774e+83*cos(theta)**3 - 2.00537945856034e+80*cos(theta))*sin(40*phi)

#@torch.jit.script
def Yl99_m_minus_39(theta, phi):
    return 1.95182309428749e-77*(1.0 - cos(theta)**2)**19.5*(4.02584910770806e+102*cos(theta)**60 - 3.61713346225546e+103*cos(theta)**58 + 1.5331081059252e+104*cos(theta)**56 - 4.0776968620463e+104*cos(theta)**54 + 7.63767566700034e+104*cos(theta)**52 - 1.07169925232195e+105*cos(theta)**50 + 1.17008162575258e+105*cos(theta)**48 - 1.01919079061692e+105*cos(theta)**46 + 7.20534472874664e+104*cos(theta)**44 - 4.18431928385164e+104*cos(theta)**42 + 2.01268095161802e+104*cos(theta)**40 - 8.06312861973322e+103*cos(theta)**38 + 2.69922829508212e+103*cos(theta)**36 - 7.56119975945637e+102*cos(theta)**34 + 1.77186009400795e+102*cos(theta)**32 - 3.46683474014967e+101*cos(theta)**30 + 5.6439861974742e+100*cos(theta)**28 - 7.60579958162298e+99*cos(theta)**26 + 8.42496545339969e+98*cos(theta)**24 - 7.60147258953356e+97*cos(theta)**22 + 5.52182442824607e+96*cos(theta)**20 - 3.18212508755461e+95*cos(theta)**18 + 1.42775700409342e+94*cos(theta)**16 - 4.86873658684882e+92*cos(theta)**14 + 1.22255802815464e+91*cos(theta)**12 - 2.16614308344178e+89*cos(theta)**10 + 2.5504039443977e+87*cos(theta)**8 - 1.82404368947984e+85*cos(theta)**6 + 6.83333050504435e+82*cos(theta)**4 - 1.00268972928017e+80*cos(theta)**2 + 2.40453172489249e+76)*sin(39*phi)

#@torch.jit.script
def Yl99_m_minus_38(theta, phi):
    return 1.79079104109761e-75*(1.0 - cos(theta)**2)**19*(6.59975263558698e+100*cos(theta)**61 - 6.13073468178892e+101*cos(theta)**59 + 2.68966334372842e+102*cos(theta)**57 - 7.41399429462964e+102*cos(theta)**55 + 1.4410708805661e+103*cos(theta)**53 - 2.10137108298422e+103*cos(theta)**51 + 2.38792168520934e+103*cos(theta)**49 - 2.16849104386578e+103*cos(theta)**47 + 1.60118771749925e+103*cos(theta)**45 - 9.73097507872474e+102*cos(theta)**43 + 4.90897793077567e+102*cos(theta)**41 - 2.06746887685467e+102*cos(theta)**39 + 7.29521160833006e+101*cos(theta)**37 - 2.1603427884161e+101*cos(theta)**35 + 5.36927301214529e+100*cos(theta)**33 - 1.11833378714505e+100*cos(theta)**31 + 1.94620213706007e+99*cos(theta)**29 - 2.81696280800851e+98*cos(theta)**27 + 3.36998618135988e+97*cos(theta)**25 - 3.30498808240589e+96*cos(theta)**23 + 2.6294402039267e+95*cos(theta)**21 - 1.67480267766032e+94*cos(theta)**19 + 8.39857061231421e+92*cos(theta)**17 - 3.24582439123255e+91*cos(theta)**15 + 9.40429252426648e+89*cos(theta)**13 - 1.96922098494708e+88*cos(theta)**11 + 2.83378216044189e+86*cos(theta)**9 - 2.60577669925691e+84*cos(theta)**7 + 1.36666610100887e+82*cos(theta)**5 - 3.34229909760056e+79*cos(theta)**3 + 2.40453172489249e+76*cos(theta))*sin(38*phi)

#@torch.jit.script
def Yl99_m_minus_37(theta, phi):
    return 1.65044494316303e-73*(1.0 - cos(theta)**2)**18.5*(1.06447623154629e+99*cos(theta)**62 - 1.02178911363149e+100*cos(theta)**60 + 4.63735059263521e+100*cos(theta)**58 - 1.32392755261244e+101*cos(theta)**56 + 2.66864977882611e+101*cos(theta)**54 - 4.04109823650811e+101*cos(theta)**52 + 4.77584337041868e+101*cos(theta)**50 - 4.51768967472037e+101*cos(theta)**48 + 3.48084286412881e+101*cos(theta)**46 - 2.21158524516471e+101*cos(theta)**44 + 1.1688042692323e+101*cos(theta)**42 - 5.16867219213668e+100*cos(theta)**40 + 1.91979252850791e+100*cos(theta)**38 - 6.00095219004473e+99*cos(theta)**36 + 1.57919794474861e+99*cos(theta)**34 - 3.49479308482829e+98*cos(theta)**32 + 6.48734045686689e+97*cos(theta)**30 - 1.00605814571733e+97*cos(theta)**28 + 1.29614853129226e+96*cos(theta)**26 - 1.37707836766912e+95*cos(theta)**24 + 1.19520009269396e+94*cos(theta)**22 - 8.3740133883016e+92*cos(theta)**20 + 4.66587256239678e+91*cos(theta)**18 - 2.02864024452034e+90*cos(theta)**16 + 6.71735180304749e+88*cos(theta)**14 - 1.6410174874559e+87*cos(theta)**12 + 2.83378216044189e+85*cos(theta)**10 - 3.25722087407114e+83*cos(theta)**8 + 2.27777683501478e+81*cos(theta)**6 - 8.35574774400141e+78*cos(theta)**4 + 1.20226586244625e+76*cos(theta)**2 - 2.8308591063015e+72)*sin(37*phi)

#@torch.jit.script
def Yl99_m_minus_36(theta, phi):
    return 1.52770946836149e-71*(1.0 - cos(theta)**2)**18*(1.68964481197823e+97*cos(theta)**63 - 1.67506412070736e+98*cos(theta)**61 + 7.85991625870374e+98*cos(theta)**59 - 2.32267991686392e+99*cos(theta)**57 + 4.85209050695657e+99*cos(theta)**55 - 7.62471365378889e+99*cos(theta)**53 + 9.36439876552682e+99*cos(theta)**51 - 9.21977484636811e+99*cos(theta)**49 + 7.40604864708258e+99*cos(theta)**47 - 4.91463387814381e+99*cos(theta)**45 + 2.71814946333093e+99*cos(theta)**43 - 1.26065175417968e+99*cos(theta)**41 + 4.92254494489208e+98*cos(theta)**39 - 1.62187897028236e+98*cos(theta)**37 + 4.51199412785318e+97*cos(theta)**35 - 1.05902820752373e+97*cos(theta)**33 + 2.09269046995706e+96*cos(theta)**31 - 3.46916601971492e+95*cos(theta)**29 + 4.80055011589726e+94*cos(theta)**27 - 5.50831347067649e+93*cos(theta)**25 + 5.19652214214763e+92*cos(theta)**23 - 3.98762542300076e+91*cos(theta)**21 + 2.45572240126147e+90*cos(theta)**19 - 1.19331779089432e+89*cos(theta)**17 + 4.47823453536499e+87*cos(theta)**15 - 1.26232114419684e+86*cos(theta)**13 + 2.57616560040172e+84*cos(theta)**11 - 3.61913430452349e+82*cos(theta)**9 + 3.25396690716398e+80*cos(theta)**7 - 1.67114954880028e+78*cos(theta)**5 + 4.00755287482082e+75*cos(theta)**3 - 2.8308591063015e+72*cos(theta))*sin(36*phi)

#@torch.jit.script
def Yl99_m_minus_35(theta, phi):
    return 1.42003039891379e-69*(1.0 - cos(theta)**2)**17.5*(2.64007001871599e+95*cos(theta)**64 - 2.70171632372154e+96*cos(theta)**62 + 1.30998604311729e+97*cos(theta)**60 - 4.00462054631711e+97*cos(theta)**58 + 8.66444733385101e+97*cos(theta)**56 - 1.41198400996091e+98*cos(theta)**54 + 1.80084591644747e+98*cos(theta)**52 - 1.84395496927362e+98*cos(theta)**50 + 1.54292680147554e+98*cos(theta)**48 - 1.0683986691617e+98*cos(theta)**46 + 6.17761241666121e+97*cos(theta)**44 - 3.0015517956659e+97*cos(theta)**42 + 1.23063623622302e+97*cos(theta)**40 - 4.26810255337463e+96*cos(theta)**38 + 1.25333170218144e+96*cos(theta)**36 - 3.11478884565802e+95*cos(theta)**34 + 6.53965771861582e+94*cos(theta)**32 - 1.15638867323831e+94*cos(theta)**30 + 1.71448218424902e+93*cos(theta)**28 - 2.11858210410634e+92*cos(theta)**26 + 2.16521755922818e+91*cos(theta)**24 - 1.81255701045489e+90*cos(theta)**22 + 1.22786120063073e+89*cos(theta)**20 - 6.62954328274621e+87*cos(theta)**18 + 2.79889658460312e+86*cos(theta)**16 - 9.01657960140602e+84*cos(theta)**14 + 2.14680466700143e+83*cos(theta)**12 - 3.61913430452349e+81*cos(theta)**10 + 4.06745863395497e+79*cos(theta)**8 - 2.78524924800047e+77*cos(theta)**6 + 1.00188821870521e+75*cos(theta)**4 - 1.41542955315075e+72*cos(theta)**2 + 3.27645729896007e+68)*sin(35*phi)

#@torch.jit.script
def Yl99_m_minus_34(theta, phi):
    return 1.32527717733838e-67*(1.0 - cos(theta)**2)**17*(4.06164618263998e+93*cos(theta)**65 - 4.28843860908181e+94*cos(theta)**63 + 2.14751810347097e+95*cos(theta)**61 - 6.78749245138493e+95*cos(theta)**59 + 1.52007847962299e+96*cos(theta)**57 - 2.56724365447438e+96*cos(theta)**55 + 3.39782248386314e+96*cos(theta)**53 - 3.61559797896789e+96*cos(theta)**51 + 3.14883020709293e+96*cos(theta)**49 - 2.27318865779085e+96*cos(theta)**47 + 1.37280275925805e+96*cos(theta)**45 - 6.98035301317651e+95*cos(theta)**43 + 3.0015517956659e+95*cos(theta)**41 - 1.09438527009606e+95*cos(theta)**39 + 3.38738297886876e+94*cos(theta)**37 - 8.89939670188005e+93*cos(theta)**35 + 1.98171446018661e+93*cos(theta)**33 - 3.73028604270421e+92*cos(theta)**31 + 5.91200753189318e+91*cos(theta)**29 - 7.84660038557905e+90*cos(theta)**27 + 8.66087023691272e+89*cos(theta)**25 - 7.8806826541517e+88*cos(theta)**23 + 5.84695809824159e+87*cos(theta)**21 - 3.48923330670853e+86*cos(theta)**19 + 1.64640975564889e+85*cos(theta)**17 - 6.01105306760402e+83*cos(theta)**15 + 1.65138820538572e+82*cos(theta)**13 - 3.29012209502136e+80*cos(theta)**11 + 4.51939848217219e+78*cos(theta)**9 - 3.97892749714353e+76*cos(theta)**7 + 2.00377643741041e+74*cos(theta)**5 - 4.7180985105025e+71*cos(theta)**3 + 3.27645729896007e+68*cos(theta))*sin(34*phi)

#@torch.jit.script
def Yl99_m_minus_33(theta, phi):
    return 1.24166519402301e-65*(1.0 - cos(theta)**2)**16.5*(6.15400936763634e+91*cos(theta)**66 - 6.70068532669033e+92*cos(theta)**64 + 3.46373887656608e+93*cos(theta)**62 - 1.13124874189749e+94*cos(theta)**60 + 2.62082496486722e+94*cos(theta)**58 - 4.58436366870424e+94*cos(theta)**56 + 6.29226385900582e+94*cos(theta)**54 - 6.9530730364767e+94*cos(theta)**52 + 6.29766041418587e+94*cos(theta)**50 - 4.73580970373093e+94*cos(theta)**48 + 2.98435382447402e+94*cos(theta)**46 - 1.58644386663103e+94*cos(theta)**44 + 7.14655189444262e+93*cos(theta)**42 - 2.73596317524015e+93*cos(theta)**40 + 8.91416573386515e+92*cos(theta)**38 - 2.47205463941112e+92*cos(theta)**36 + 5.82857194172533e+91*cos(theta)**34 - 1.16571438834507e+91*cos(theta)**32 + 1.97066917729773e+90*cos(theta)**30 - 2.80235728056394e+89*cos(theta)**28 + 3.33110393727412e+88*cos(theta)**26 - 3.28361777256321e+87*cos(theta)**24 + 2.65770822647345e+86*cos(theta)**22 - 1.74461665335427e+85*cos(theta)**20 + 9.14672086471608e+83*cos(theta)**18 - 3.75690816725251e+82*cos(theta)**16 + 1.17956300384694e+81*cos(theta)**14 - 2.7417684125178e+79*cos(theta)**12 + 4.51939848217219e+77*cos(theta)**10 - 4.97365937142941e+75*cos(theta)**8 + 3.33962739568402e+73*cos(theta)**6 - 1.17952462762562e+71*cos(theta)**4 + 1.63822864948003e+68*cos(theta)**2 - 3.73257837657788e+64)*sin(33*phi)

#@torch.jit.script
def Yl99_m_minus_32(theta, phi):
    return 1.16769353100899e-63*(1.0 - cos(theta)**2)**16*(9.18508860841245e+89*cos(theta)**67 - 1.03087466564467e+91*cos(theta)**65 + 5.49799821677155e+91*cos(theta)**63 - 1.85450613425818e+92*cos(theta)**61 + 4.44207621163935e+92*cos(theta)**59 - 8.04274327842849e+92*cos(theta)**57 + 1.14404797436469e+93*cos(theta)**55 - 1.31190057292013e+93*cos(theta)**53 + 1.23483537533056e+93*cos(theta)**51 - 9.66491776271618e+92*cos(theta)**49 + 6.34968898824259e+92*cos(theta)**47 - 3.52543081473561e+92*cos(theta)**45 + 1.66198881266107e+92*cos(theta)**43 - 6.67308091521988e+91*cos(theta)**41 + 2.28568352150388e+91*cos(theta)**39 - 6.6812287551652e+90*cos(theta)**37 + 1.66530626906438e+90*cos(theta)**35 - 3.5324678434699e+89*cos(theta)**33 + 6.3569973461217e+88*cos(theta)**31 - 9.66330096746188e+87*cos(theta)**29 + 1.23374219899042e+87*cos(theta)**27 - 1.31344710902528e+86*cos(theta)**25 + 1.15552531585802e+85*cos(theta)**23 - 8.30769834930603e+83*cos(theta)**21 + 4.81406361300846e+82*cos(theta)**19 - 2.20994598073677e+81*cos(theta)**17 + 7.86375335897961e+79*cos(theta)**15 - 2.10905262501369e+78*cos(theta)**13 + 4.10854407470199e+76*cos(theta)**11 - 5.52628819047712e+74*cos(theta)**9 + 4.77089627954859e+72*cos(theta)**7 - 2.35904925525125e+70*cos(theta)**5 + 5.46076216493344e+67*cos(theta)**3 - 3.73257837657788e+64*cos(theta))*sin(32*phi)

#@torch.jit.script
def Yl99_m_minus_31(theta, phi):
    return 1.10209486381459e-61*(1.0 - cos(theta)**2)**15.5*(1.35074832476654e+88*cos(theta)**68 - 1.56193131158283e+89*cos(theta)**66 + 8.59062221370555e+89*cos(theta)**64 - 2.99113892622286e+90*cos(theta)**62 + 7.40346035273225e+90*cos(theta)**60 - 1.38667987559112e+91*cos(theta)**58 + 2.04294281136553e+91*cos(theta)**56 - 2.42944550540765e+91*cos(theta)**54 + 2.37468341409723e+91*cos(theta)**52 - 1.93298355254324e+91*cos(theta)**50 + 1.32285187255054e+91*cos(theta)**48 - 7.66398003203394e+90*cos(theta)**46 + 3.77724730150244e+90*cos(theta)**44 - 1.58882878933807e+90*cos(theta)**42 + 5.71420880375971e+89*cos(theta)**40 - 1.75821809346453e+89*cos(theta)**38 + 4.62585074740106e+88*cos(theta)**36 - 1.03896113043232e+88*cos(theta)**34 + 1.98656167066303e+87*cos(theta)**32 - 3.22110032248729e+86*cos(theta)**30 + 4.40622213925149e+85*cos(theta)**28 - 5.05171965009725e+84*cos(theta)**26 + 4.81468881607509e+83*cos(theta)**24 - 3.77622652241183e+82*cos(theta)**22 + 2.40703180650423e+81*cos(theta)**20 - 1.22774776707598e+80*cos(theta)**18 + 4.91484584936226e+78*cos(theta)**16 - 1.50646616072406e+77*cos(theta)**14 + 3.42378672891833e+75*cos(theta)**12 - 5.52628819047712e+73*cos(theta)**10 + 5.96362034943574e+71*cos(theta)**8 - 3.93174875875208e+69*cos(theta)**6 + 1.36519054123336e+67*cos(theta)**4 - 1.86628918828894e+64*cos(theta)**2 + 4.19014186863256e+60)*sin(31*phi)

#@torch.jit.script
def Yl99_m_minus_30(theta, phi):
    return 1.04379497062177e-59*(1.0 - cos(theta)**2)**15*(1.95760626777759e+86*cos(theta)**69 - 2.33124076355646e+87*cos(theta)**67 + 1.32163418672393e+88*cos(theta)**65 - 4.74783956543312e+88*cos(theta)**63 + 1.21368202503807e+89*cos(theta)**61 - 2.35030487388325e+89*cos(theta)**59 + 3.58411019537812e+89*cos(theta)**57 - 4.41717364619573e+89*cos(theta)**55 + 4.48053474357969e+89*cos(theta)**53 - 3.79016382851615e+89*cos(theta)**51 + 2.69969769908273e+89*cos(theta)**49 - 1.63063404936892e+89*cos(theta)**47 + 8.39388289222765e+88*cos(theta)**45 - 3.69495067287922e+88*cos(theta)**43 + 1.39370946433164e+88*cos(theta)**41 - 4.50825152170391e+87*cos(theta)**39 + 1.25022993173002e+87*cos(theta)**37 - 2.96846037266378e+86*cos(theta)**35 + 6.01988385049403e+85*cos(theta)**33 - 1.03906462015719e+85*cos(theta)**31 + 1.51938694456948e+84*cos(theta)**29 - 1.87100727781379e+83*cos(theta)**27 + 1.92587552643003e+82*cos(theta)**25 - 1.64183761843993e+81*cos(theta)**23 + 1.14620562214487e+80*cos(theta)**21 - 6.46183035303149e+78*cos(theta)**19 + 2.8910857937425e+77*cos(theta)**17 - 1.00431077381604e+76*cos(theta)**15 + 2.63368209916794e+74*cos(theta)**13 - 5.0238983549792e+72*cos(theta)**11 + 6.62624483270638e+70*cos(theta)**9 - 5.6167839410744e+68*cos(theta)**7 + 2.73038108246672e+66*cos(theta)**5 - 6.22096396096314e+63*cos(theta)**3 + 4.19014186863256e+60*cos(theta))*sin(30*phi)

#@torch.jit.script
def Yl99_m_minus_29(theta, phi):
    return 9.91879866943503e-58*(1.0 - cos(theta)**2)**14.5*(2.79658038253941e+84*cos(theta)**70 - 3.4282952405242e+85*cos(theta)**68 + 2.0024760404908e+86*cos(theta)**66 - 7.41849932098925e+86*cos(theta)**64 + 1.95755165328722e+87*cos(theta)**62 - 3.91717478980542e+87*cos(theta)**60 + 6.17950033685882e+87*cos(theta)**58 - 7.88781008249238e+87*cos(theta)**56 + 8.29728656218461e+87*cos(theta)**54 - 7.28877659330029e+87*cos(theta)**52 + 5.39939539816547e+87*cos(theta)**50 - 3.39715426951859e+87*cos(theta)**48 + 1.82475715048427e+87*cos(theta)**46 - 8.3976151656346e+86*cos(theta)**44 + 3.31835586745628e+86*cos(theta)**42 - 1.12706288042598e+86*cos(theta)**40 + 3.29007876771057e+85*cos(theta)**38 - 8.24572325739939e+84*cos(theta)**36 + 1.77055407367471e+84*cos(theta)**34 - 3.24707693799122e+83*cos(theta)**32 + 5.06462314856493e+82*cos(theta)**30 - 6.68216884933498e+81*cos(theta)**28 + 7.40721356319244e+80*cos(theta)**26 - 6.84099007683303e+79*cos(theta)**24 + 5.21002555520396e+78*cos(theta)**22 - 3.23091517651575e+77*cos(theta)**20 + 1.60615877430139e+76*cos(theta)**18 - 6.27694233635027e+74*cos(theta)**16 + 1.88120149940567e+73*cos(theta)**14 - 4.18658196248267e+71*cos(theta)**12 + 6.62624483270638e+69*cos(theta)**10 - 7.020979926343e+67*cos(theta)**8 + 4.55063513744454e+65*cos(theta)**6 - 1.55524099024079e+63*cos(theta)**4 + 2.09507093431628e+60*cos(theta)**2 - 4.64024570169719e+56)*sin(29*phi)

#@torch.jit.script
def Yl99_m_minus_28(theta, phi):
    return 9.45569018793983e-56*(1.0 - cos(theta)**2)**14*(3.93884560921044e+82*cos(theta)**71 - 4.96854382684667e+83*cos(theta)**69 + 2.98877020968777e+84*cos(theta)**67 - 1.1413075878445e+85*cos(theta)**65 + 3.10722484648764e+85*cos(theta)**63 - 6.42159801607446e+85*cos(theta)**61 + 1.04737293845065e+86*cos(theta)**59 - 1.38382633026182e+86*cos(theta)**57 + 1.50859755676084e+86*cos(theta)**55 - 1.37524086666043e+86*cos(theta)**53 + 1.05870498003244e+86*cos(theta)**51 - 6.93296789697672e+85*cos(theta)**49 + 3.88246202230696e+85*cos(theta)**47 - 1.86613670347436e+85*cos(theta)**45 + 7.71710666850297e+84*cos(theta)**43 - 2.74893385469751e+84*cos(theta)**41 + 8.43609940438607e+83*cos(theta)**39 - 2.22857385335119e+83*cos(theta)**37 + 5.0587259247849e+82*cos(theta)**35 - 9.83962708482189e+81*cos(theta)**33 + 1.63374940276288e+81*cos(theta)**31 - 2.3041961549431e+80*cos(theta)**29 + 2.74341243081202e+79*cos(theta)**27 - 2.73639603073321e+78*cos(theta)**25 + 2.26522850226259e+77*cos(theta)**23 - 1.53853103643607e+76*cos(theta)**21 + 8.45346723316522e+74*cos(theta)**19 - 3.69231902138251e+73*cos(theta)**17 + 1.25413433293712e+72*cos(theta)**15 - 3.22044766344821e+70*cos(theta)**13 + 6.02385893882398e+68*cos(theta)**11 - 7.80108880704778e+66*cos(theta)**9 + 6.50090733920648e+64*cos(theta)**7 - 3.11048198048157e+62*cos(theta)**5 + 6.98356978105427e+59*cos(theta)**3 - 4.64024570169719e+56*cos(theta))*sin(28*phi)

#@torch.jit.script
def Yl99_m_minus_27(theta, phi):
    return 9.04193421481642e-54*(1.0 - cos(theta)**2)**13.5*(5.47061890168117e+80*cos(theta)**72 - 7.0979197526381e+81*cos(theta)**70 + 4.39525030836436e+82*cos(theta)**68 - 1.72925392097651e+83*cos(theta)**66 + 4.85503882263694e+83*cos(theta)**64 - 1.03574161549588e+84*cos(theta)**62 + 1.74562156408441e+84*cos(theta)**60 - 2.38590746596866e+84*cos(theta)**58 + 2.6939242085015e+84*cos(theta)**56 - 2.54674234566747e+84*cos(theta)**54 + 2.03597111544701e+84*cos(theta)**52 - 1.38659357939534e+84*cos(theta)**50 + 8.08846254647284e+83*cos(theta)**48 - 4.05681892059642e+83*cos(theta)**46 + 1.75388787920522e+83*cos(theta)**44 - 6.54508060642264e+82*cos(theta)**42 + 2.10902485109652e+82*cos(theta)**40 - 5.8646680351347e+81*cos(theta)**38 + 1.40520164577358e+81*cos(theta)**36 - 2.89400796612408e+80*cos(theta)**34 + 5.105466883634e+79*cos(theta)**32 - 7.68065384981032e+78*cos(theta)**30 + 9.79790153861434e+77*cos(theta)**28 - 1.05246001182047e+77*cos(theta)**26 + 9.4384520927608e+75*cos(theta)**24 - 6.99332289289123e+74*cos(theta)**22 + 4.22673361658261e+73*cos(theta)**20 - 2.0512883452125e+72*cos(theta)**18 + 7.83833958085697e+70*cos(theta)**16 - 2.30031975960586e+69*cos(theta)**14 + 5.01988244901999e+67*cos(theta)**12 - 7.80108880704778e+65*cos(theta)**10 + 8.1261341740081e+63*cos(theta)**8 - 5.18413663413595e+61*cos(theta)**6 + 1.74589244526357e+59*cos(theta)**4 - 2.32012285084859e+56*cos(theta)**2 + 5.07463440693043e+52)*sin(27*phi)

#@torch.jit.script
def Yl99_m_minus_26(theta, phi):
    return 8.67177588978136e-52*(1.0 - cos(theta)**2)**13*(7.49399849545365e+78*cos(theta)**73 - 9.99707007413817e+79*cos(theta)**71 + 6.36992798313676e+80*cos(theta)**69 - 2.58097600145748e+81*cos(theta)**67 + 7.46929049636453e+81*cos(theta)**65 - 1.64403431031092e+82*cos(theta)**63 + 2.86167469522035e+82*cos(theta)**61 - 4.04391095926891e+82*cos(theta)**59 + 4.72618282193245e+82*cos(theta)**57 - 4.6304406284863e+82*cos(theta)**55 + 3.84145493480568e+82*cos(theta)**53 - 2.71881093999087e+82*cos(theta)**51 + 1.65070664213731e+82*cos(theta)**49 - 8.63152961829026e+81*cos(theta)**47 + 3.89752862045605e+81*cos(theta)**45 - 1.5221117689355e+81*cos(theta)**43 + 5.14396305145492e+80*cos(theta)**41 - 1.50376103464992e+80*cos(theta)**39 + 3.79784228587455e+79*cos(theta)**37 - 8.26859418892596e+78*cos(theta)**35 + 1.54711117685879e+78*cos(theta)**33 - 2.47763027413236e+77*cos(theta)**31 + 3.37858673745322e+76*cos(theta)**29 - 3.8980000437795e+75*cos(theta)**27 + 3.77538083710432e+74*cos(theta)**25 - 3.04057517082227e+73*cos(theta)**23 + 2.01273029361077e+72*cos(theta)**21 - 1.07962544484869e+71*cos(theta)**19 + 4.6107879887394e+69*cos(theta)**17 - 1.53354650640391e+68*cos(theta)**15 + 3.86144803770768e+66*cos(theta)**13 - 7.09189891549798e+64*cos(theta)**11 + 9.02903797112011e+62*cos(theta)**9 - 7.40590947733707e+60*cos(theta)**7 + 3.49178489052713e+58*cos(theta)**5 - 7.73374283616198e+55*cos(theta)**3 + 5.07463440693043e+52*cos(theta))*sin(26*phi)

#@torch.jit.script
def Yl99_m_minus_25(theta, phi):
    return 8.34024698683431e-50*(1.0 - cos(theta)**2)**12.5*(1.01270249938563e+77*cos(theta)**74 - 1.38848195474141e+78*cos(theta)**72 + 9.0998971187668e+78*cos(theta)**70 - 3.79555294331983e+79*cos(theta)**68 + 1.13171068126735e+80*cos(theta)**66 - 2.56880360986082e+80*cos(theta)**64 + 4.61560434712959e+80*cos(theta)**62 - 6.73985159878152e+80*cos(theta)**60 + 8.14859107229733e+80*cos(theta)**58 - 8.26864397943983e+80*cos(theta)**56 + 7.11380543482533e+80*cos(theta)**54 - 5.22848257690552e+80*cos(theta)**52 + 3.30141328427463e+80*cos(theta)**50 - 1.79823533714381e+80*cos(theta)**48 + 8.47288830533923e+79*cos(theta)**46 - 3.45934492939886e+79*cos(theta)**44 + 1.22475310748927e+79*cos(theta)**42 - 3.75940258662481e+78*cos(theta)**40 + 9.99432180493302e+77*cos(theta)**38 - 2.2968317191461e+77*cos(theta)**36 + 4.55032699076114e+76*cos(theta)**34 - 7.74259460666363e+75*cos(theta)**32 + 1.12619557915107e+75*cos(theta)**30 - 1.39214287277839e+74*cos(theta)**28 + 1.45206955273243e+73*cos(theta)**26 - 1.26690632117595e+72*cos(theta)**24 + 9.14877406186712e+70*cos(theta)**22 - 5.39812722424343e+69*cos(theta)**20 + 2.561548882633e+68*cos(theta)**18 - 9.58466566502442e+66*cos(theta)**16 + 2.7581771697912e+65*cos(theta)**14 - 5.90991576291498e+63*cos(theta)**12 + 9.02903797112011e+61*cos(theta)**10 - 9.25738684667134e+59*cos(theta)**8 + 5.81964148421189e+57*cos(theta)**6 - 1.93343570904049e+55*cos(theta)**4 + 2.53731720346522e+52*cos(theta)**2 - 5.4860912507356e+48)*sin(25*phi)

#@torch.jit.script
def Yl99_m_minus_24(theta, phi):
    return 8.04304292014539e-48*(1.0 - cos(theta)**2)**12*(1.35026999918084e+75*cos(theta)**75 - 1.90203007498824e+76*cos(theta)**73 + 1.28167565053054e+77*cos(theta)**71 - 5.50080136713019e+77*cos(theta)**69 + 1.68912041980202e+78*cos(theta)**67 - 3.95200555363202e+78*cos(theta)**65 + 7.32635610655491e+78*cos(theta)**63 - 1.10489370471828e+79*cos(theta)**61 + 1.38111713089785e+79*cos(theta)**59 - 1.45063929463857e+79*cos(theta)**57 + 1.29341916996824e+79*cos(theta)**55 - 9.86506146585947e+78*cos(theta)**53 + 6.47335938093064e+78*cos(theta)**51 - 3.66986803498736e+78*cos(theta)**49 + 1.80274219262537e+78*cos(theta)**47 - 7.68743317644191e+77*cos(theta)**45 + 2.84826304067271e+77*cos(theta)**43 - 9.16927460152392e+76*cos(theta)**41 + 2.56264661664949e+76*cos(theta)**39 - 6.20765329498946e+75*cos(theta)**37 + 1.30009342593175e+75*cos(theta)**35 - 2.34624078989807e+74*cos(theta)**33 + 3.63288896500346e+73*cos(theta)**31 - 4.80049266475308e+72*cos(theta)**29 + 5.37803538049049e+71*cos(theta)**27 - 5.06762528470379e+70*cos(theta)**25 + 3.9777278529857e+69*cos(theta)**23 - 2.57053677344925e+68*cos(theta)**21 + 1.34818362243842e+67*cos(theta)**19 - 5.63803862648496e+65*cos(theta)**17 + 1.8387847798608e+64*cos(theta)**15 - 4.54608904839614e+62*cos(theta)**13 + 8.20821633738192e+60*cos(theta)**11 - 1.02859853851904e+59*cos(theta)**9 + 8.31377354887413e+56*cos(theta)**7 - 3.86687141808099e+54*cos(theta)**5 + 8.45772401155072e+51*cos(theta)**3 - 5.4860912507356e+48*cos(theta))*sin(24*phi)

#@torch.jit.script
def Yl99_m_minus_23(theta, phi):
    return 7.77642052910099e-46*(1.0 - cos(theta)**2)**11.5*(1.77667105155373e+73*cos(theta)**76 - 2.57031091214627e+74*cos(theta)**74 + 1.7801050701813e+75*cos(theta)**72 - 7.85828766732884e+75*cos(theta)**70 + 2.48400061735591e+76*cos(theta)**68 - 5.98788720247277e+76*cos(theta)**66 + 1.14474314164921e+77*cos(theta)**64 - 1.78208662051336e+77*cos(theta)**62 + 2.30186188482975e+77*cos(theta)**60 - 2.50110223213546e+77*cos(theta)**58 + 2.309677089229e+77*cos(theta)**56 - 1.82686323441842e+77*cos(theta)**54 + 1.24487680402512e+77*cos(theta)**52 - 7.33973606997471e+76*cos(theta)**50 + 3.75571290130285e+76*cos(theta)**48 - 1.67118112531346e+76*cos(theta)**46 + 6.47332509243798e+75*cos(theta)**44 - 2.18316061941046e+75*cos(theta)**42 + 6.40661654162373e+74*cos(theta)**40 - 1.63359297236565e+74*cos(theta)**38 + 3.61137062758821e+73*cos(theta)**36 - 6.90070820558256e+72*cos(theta)**34 + 1.13527780156358e+72*cos(theta)**32 - 1.60016422158436e+71*cos(theta)**30 + 1.92072692160375e+70*cos(theta)**28 - 1.94908664796299e+69*cos(theta)**26 + 1.65738660541071e+68*cos(theta)**24 - 1.1684258061133e+67*cos(theta)**22 + 6.7409181121921e+65*cos(theta)**20 - 3.13224368138053e+64*cos(theta)**18 + 1.149240487413e+63*cos(theta)**16 - 3.2472064631401e+61*cos(theta)**14 + 6.8401802811516e+59*cos(theta)**12 - 1.02859853851904e+58*cos(theta)**10 + 1.03922169360927e+56*cos(theta)**8 - 6.44478569680165e+53*cos(theta)**6 + 2.11443100288768e+51*cos(theta)**4 - 2.7430456253678e+48*cos(theta)**2 + 5.86873261738939e+44)*sin(23*phi)

#@torch.jit.script
def Yl99_m_minus_22(theta, phi):
    return 7.53711281864287e-44*(1.0 - cos(theta)**2)**11*(2.30736500201784e+71*cos(theta)**77 - 3.42708121619502e+72*cos(theta)**75 + 2.43850009613877e+73*cos(theta)**73 - 1.10680107990547e+74*cos(theta)**71 + 3.60000089471871e+74*cos(theta)**69 - 8.93714507831756e+74*cos(theta)**67 + 1.76114329484493e+75*cos(theta)**65 - 2.82870892144977e+75*cos(theta)**63 + 3.7735440734914e+75*cos(theta)**61 - 4.23915632565332e+75*cos(theta)**59 + 4.05206506882281e+75*cos(theta)**57 - 3.3215695171244e+75*cos(theta)**55 + 2.34882415853797e+75*cos(theta)**53 - 1.43916393528916e+75*cos(theta)**51 + 7.66472020674051e+74*cos(theta)**49 - 3.55570452194353e+74*cos(theta)**47 + 1.43851668720844e+74*cos(theta)**45 - 5.0771177195592e+73*cos(theta)**43 + 1.56258940039603e+73*cos(theta)**41 - 4.18869992914268e+72*cos(theta)**39 + 9.7604611556438e+71*cos(theta)**37 - 1.97163091588073e+71*cos(theta)**35 + 3.44023576231389e+70*cos(theta)**33 - 5.16182006962697e+69*cos(theta)**31 + 6.62319628139222e+68*cos(theta)**29 - 7.21883943689998e+67*cos(theta)**27 + 6.62954642164284e+66*cos(theta)**25 - 5.0801122004926e+65*cos(theta)**23 + 3.20996100580576e+64*cos(theta)**21 - 1.64854930598975e+63*cos(theta)**19 + 6.76023816125294e+61*cos(theta)**17 - 2.16480430876007e+60*cos(theta)**15 + 5.26167713934739e+58*cos(theta)**13 - 9.35089580471852e+56*cos(theta)**11 + 1.15469077067696e+55*cos(theta)**9 - 9.20683670971664e+52*cos(theta)**7 + 4.22886200577536e+50*cos(theta)**5 - 9.14348541789267e+47*cos(theta)**3 + 5.86873261738939e+44*cos(theta))*sin(22*phi)

#@torch.jit.script
def Yl99_m_minus_21(theta, phi):
    return 7.32225758404669e-42*(1.0 - cos(theta)**2)**10.5*(2.95816025899723e+69*cos(theta)**78 - 4.50931738973029e+70*cos(theta)**76 + 3.29527040018752e+71*cos(theta)**74 - 1.53722372209093e+72*cos(theta)**72 + 5.14285842102673e+72*cos(theta)**70 - 1.31428604092905e+73*cos(theta)**68 + 2.66839893158323e+73*cos(theta)**66 - 4.41985768976527e+73*cos(theta)**64 + 6.08636140885709e+73*cos(theta)**62 - 7.06526054275553e+73*cos(theta)**60 + 6.98631908417726e+73*cos(theta)**58 - 5.93137413772214e+73*cos(theta)**56 + 4.3496743676629e+73*cos(theta)**54 - 2.76762295247915e+73*cos(theta)**52 + 1.5329440413481e+73*cos(theta)**50 - 7.40771775404902e+72*cos(theta)**48 + 3.12721018958357e+72*cos(theta)**46 - 1.15389039080891e+72*cos(theta)**44 + 3.72045095332389e+71*cos(theta)**42 - 1.04717498228567e+71*cos(theta)**40 + 2.56854240937995e+70*cos(theta)**38 - 5.47675254411314e+69*cos(theta)**36 + 1.01183404773938e+69*cos(theta)**34 - 1.61306877175843e+68*cos(theta)**32 + 2.20773209379741e+67*cos(theta)**30 - 2.57815694174999e+66*cos(theta)**28 + 2.54982554678571e+65*cos(theta)**26 - 2.11671341687192e+64*cos(theta)**24 + 1.45907318445716e+63*cos(theta)**22 - 8.24274652994877e+61*cos(theta)**20 + 3.75568786736275e+60*cos(theta)**18 - 1.35300269297504e+59*cos(theta)**16 + 3.75834081381956e+57*cos(theta)**14 - 7.79241317059877e+55*cos(theta)**12 + 1.15469077067696e+54*cos(theta)**10 - 1.15085458871458e+52*cos(theta)**8 + 7.04810334295893e+49*cos(theta)**6 - 2.28587135447317e+47*cos(theta)**4 + 2.93436630869469e+44*cos(theta)**2 - 6.21819518689276e+40)*sin(21*phi)

#@torch.jit.script
def Yl99_m_minus_20(theta, phi):
    return 7.12933744526927e-40*(1.0 - cos(theta)**2)**10*(3.74450665695852e+67*cos(theta)**79 - 5.85625635029908e+68*cos(theta)**77 + 4.39369386691669e+69*cos(theta)**75 - 2.10578592067251e+70*cos(theta)**73 + 7.24346256482638e+70*cos(theta)**71 - 1.90476237815805e+71*cos(theta)**69 + 3.98268497251228e+71*cos(theta)**67 - 6.79978106117734e+71*cos(theta)**65 + 9.66089112516999e+71*cos(theta)**63 - 1.15823943323861e+72*cos(theta)**61 + 1.18412187867411e+72*cos(theta)**59 - 1.04059195398634e+72*cos(theta)**57 + 7.90849885029619e+71*cos(theta)**55 - 5.22193009901727e+71*cos(theta)**53 + 3.00577263009432e+71*cos(theta)**51 - 1.51177913347939e+71*cos(theta)**49 + 6.65363870124163e+70*cos(theta)**47 - 2.56420086846424e+70*cos(theta)**45 + 8.65221151935788e+69*cos(theta)**43 - 2.55408532264798e+69*cos(theta)**41 + 6.5860061778973e+68*cos(theta)**39 - 1.48020339030085e+68*cos(theta)**37 + 2.89095442211251e+67*cos(theta)**35 - 4.88808718714675e+66*cos(theta)**33 + 7.12171643160454e+65*cos(theta)**31 - 8.89019635086205e+64*cos(theta)**29 + 9.44379832142855e+63*cos(theta)**27 - 8.46685366748766e+62*cos(theta)**25 + 6.34379645416159e+61*cos(theta)**23 - 3.9251173952137e+60*cos(theta)**21 + 1.97667782492776e+59*cos(theta)**19 - 7.95883937044142e+57*cos(theta)**17 + 2.50556054254637e+56*cos(theta)**15 - 5.99416397738367e+54*cos(theta)**13 + 1.0497188824336e+53*cos(theta)**11 - 1.27872732079398e+51*cos(theta)**9 + 1.00687190613699e+49*cos(theta)**7 - 4.57174270894633e+46*cos(theta)**5 + 9.78122102898232e+43*cos(theta)**3 - 6.21819518689276e+40*cos(theta))*sin(20*phi)

#@torch.jit.script
def Yl99_m_minus_19(theta, phi):
    return 6.95612928954815e-38*(1.0 - cos(theta)**2)**9.5*(4.68063332119814e+65*cos(theta)**80 - 7.5080209619219e+66*cos(theta)**78 + 5.78117614067986e+67*cos(theta)**76 - 2.84565664955744e+68*cos(theta)**74 + 1.006036467337e+69*cos(theta)**72 - 2.72108911165435e+69*cos(theta)**70 + 5.85688966545924e+69*cos(theta)**68 - 1.03026985775414e+70*cos(theta)**66 + 1.50951423830781e+70*cos(theta)**64 - 1.86812811812679e+70*cos(theta)**62 + 1.97353646445685e+70*cos(theta)**60 - 1.79412405859714e+70*cos(theta)**58 + 1.41223193755289e+70*cos(theta)**56 - 9.67024092410606e+69*cos(theta)**54 + 5.78033198095061e+69*cos(theta)**52 - 3.02355826695878e+69*cos(theta)**50 + 1.38617472942534e+69*cos(theta)**48 - 5.5743497140527e+68*cos(theta)**46 + 1.96641170894497e+68*cos(theta)**44 - 6.08115553011423e+67*cos(theta)**42 + 1.64650154447433e+67*cos(theta)**40 - 3.89527207973908e+66*cos(theta)**38 + 8.03042895031252e+65*cos(theta)**36 - 1.43767270210199e+65*cos(theta)**34 + 2.22553638487642e+64*cos(theta)**32 - 2.96339878362068e+63*cos(theta)**30 + 3.37278511479591e+62*cos(theta)**28 - 3.25648217980295e+61*cos(theta)**26 + 2.64324852256733e+60*cos(theta)**24 - 1.78414427055168e+59*cos(theta)**22 + 9.88338912463881e+57*cos(theta)**20 - 4.42157742802301e+56*cos(theta)**18 + 1.56597533909148e+55*cos(theta)**16 - 4.28154569813119e+53*cos(theta)**14 + 8.74765735361335e+51*cos(theta)**12 - 1.27872732079398e+50*cos(theta)**10 + 1.25858988267124e+48*cos(theta)**8 - 7.61957118157722e+45*cos(theta)**6 + 2.44530525724558e+43*cos(theta)**4 - 3.10909759344638e+40*cos(theta)**2 + 6.53171763329072e+36)*sin(19*phi)

#@torch.jit.script
def Yl99_m_minus_18(theta, phi):
    return 6.8006614986693e-36*(1.0 - cos(theta)**2)**9*(5.77855965580018e+63*cos(theta)**81 - 9.50382400243278e+64*cos(theta)**79 + 7.5080209619219e+65*cos(theta)**77 - 3.79420886607659e+66*cos(theta)**75 + 1.37813214703698e+67*cos(theta)**73 - 3.83251987556951e+67*cos(theta)**71 + 8.48824589196991e+67*cos(theta)**69 - 1.5377162056032e+68*cos(theta)**67 + 2.32232959739663e+68*cos(theta)**65 - 2.96528272718539e+68*cos(theta)**63 + 3.23530567943746e+68*cos(theta)**61 - 3.04088823491041e+68*cos(theta)**59 + 2.47759989044367e+68*cos(theta)**57 - 1.75822562256474e+68*cos(theta)**55 + 1.09062867565106e+68*cos(theta)**53 - 5.92854562148781e+67*cos(theta)**51 + 2.82892801923539e+67*cos(theta)**49 - 1.18603185405377e+67*cos(theta)**47 + 4.36980379765549e+66*cos(theta)**45 - 1.41422221630564e+66*cos(theta)**43 + 4.01585742554713e+65*cos(theta)**41 - 9.98787712753609e+64*cos(theta)**39 + 2.17038620278717e+64*cos(theta)**37 - 4.10763629171996e+63*cos(theta)**35 + 6.74404965114066e+62*cos(theta)**33 - 9.55935091490543e+61*cos(theta)**31 + 1.16302934992962e+61*cos(theta)**29 - 1.20610451103813e+60*cos(theta)**27 + 1.05729940902693e+59*cos(theta)**25 - 7.75714900239861e+57*cos(theta)**23 + 4.70637577363753e+56*cos(theta)**21 - 2.32714601474895e+55*cos(theta)**19 + 9.21161964171461e+53*cos(theta)**17 - 2.85436379875413e+52*cos(theta)**15 + 6.72896719508719e+50*cos(theta)**13 - 1.16247938253998e+49*cos(theta)**11 + 1.39843320296804e+47*cos(theta)**9 - 1.08851016879675e+45*cos(theta)**7 + 4.89061051449116e+42*cos(theta)**5 - 1.03636586448213e+40*cos(theta)**3 + 6.53171763329072e+36*cos(theta))*sin(18*phi)

#@torch.jit.script
def Yl99_m_minus_17(theta, phi):
    return 6.66117763977302e-34*(1.0 - cos(theta)**2)**8.5*(7.04702397048802e+61*cos(theta)**82 - 1.1879780003041e+63*cos(theta)**80 + 9.62566789989987e+63*cos(theta)**78 - 4.99238008694288e+64*cos(theta)**76 + 1.86234073923917e+65*cos(theta)**74 - 5.32294427162432e+65*cos(theta)**72 + 1.2126065559957e+66*cos(theta)**70 - 2.26134736118117e+66*cos(theta)**68 + 3.51868120817672e+66*cos(theta)**66 - 4.63325426122717e+66*cos(theta)**64 + 5.21823496683462e+66*cos(theta)**62 - 5.06814705818401e+66*cos(theta)**60 + 4.27172394904081e+66*cos(theta)**58 - 3.13968861172275e+66*cos(theta)**56 + 2.01968273268715e+66*cos(theta)**54 - 1.14010492720919e+66*cos(theta)**52 + 5.65785603847077e+65*cos(theta)**50 - 2.47089969594535e+65*cos(theta)**48 + 9.49957347316412e+64*cos(theta)**46 - 3.21414140069463e+64*cos(theta)**44 + 9.56156529892175e+63*cos(theta)**42 - 2.49696928188402e+63*cos(theta)**40 + 5.7115426389136e+62*cos(theta)**38 - 1.14101008103332e+62*cos(theta)**36 + 1.98354401504137e+61*cos(theta)**34 - 2.98729716090795e+60*cos(theta)**32 + 3.87676449976541e+59*cos(theta)**30 - 4.30751611085046e+58*cos(theta)**28 + 4.06653618856512e+57*cos(theta)**26 - 3.23214541766609e+56*cos(theta)**24 + 2.13926171528979e+55*cos(theta)**22 - 1.16357300737448e+54*cos(theta)**20 + 5.11756646761923e+52*cos(theta)**18 - 1.78397737422133e+51*cos(theta)**16 + 4.80640513934799e+49*cos(theta)**14 - 9.68732818783317e+47*cos(theta)**12 + 1.39843320296804e+46*cos(theta)**10 - 1.36063771099593e+44*cos(theta)**8 + 8.15101752415193e+41*cos(theta)**6 - 2.59091466120532e+39*cos(theta)**4 + 3.26585881664536e+36*cos(theta)**2 - 6.80812761443685e+32)*sin(17*phi)

#@torch.jit.script
def Yl99_m_minus_16(theta, phi):
    return 6.53610554166651e-32*(1.0 - cos(theta)**2)**8*(8.49039032588918e+59*cos(theta)**83 - 1.46663950654827e+61*cos(theta)**81 + 1.21843897467087e+62*cos(theta)**79 - 6.48361050252323e+62*cos(theta)**77 + 2.48312098565222e+63*cos(theta)**75 - 7.29170448167715e+63*cos(theta)**73 + 1.70789655774042e+64*cos(theta)**71 - 3.2773150162046e+64*cos(theta)**69 + 5.25176299727868e+64*cos(theta)**67 - 7.12808347881103e+64*cos(theta)**65 + 8.28291264576924e+64*cos(theta)**63 - 8.30843780030165e+64*cos(theta)**61 + 7.24021008312001e+64*cos(theta)**59 - 5.50822563460131e+64*cos(theta)**57 + 3.67215042306754e+64*cos(theta)**55 - 2.15114137209282e+64*cos(theta)**53 + 1.10938353695505e+64*cos(theta)**51 - 5.04265244070479e+63*cos(theta)**49 + 2.02118584535407e+63*cos(theta)**47 - 7.14253644598806e+62*cos(theta)**45 + 2.22361983695855e+62*cos(theta)**43 - 6.09016898020494e+61*cos(theta)**41 + 1.46449811254195e+61*cos(theta)**39 - 3.08381102981979e+60*cos(theta)**37 + 5.66726861440392e+59*cos(theta)**35 - 9.05241563911499e+58*cos(theta)**33 + 1.25056919347271e+58*cos(theta)**31 - 1.48535038305188e+57*cos(theta)**29 + 1.50612451428338e+56*cos(theta)**27 - 1.29285816706644e+55*cos(theta)**25 + 9.30113789256428e+53*cos(theta)**23 - 5.54082384464037e+52*cos(theta)**21 + 2.69345603558907e+51*cos(theta)**19 - 1.04939845542431e+50*cos(theta)**17 + 3.20427009289866e+48*cos(theta)**15 - 7.45179091371782e+46*cos(theta)**13 + 1.27130291178913e+45*cos(theta)**11 - 1.51181967888437e+43*cos(theta)**9 + 1.16443107487885e+41*cos(theta)**7 - 5.18182932241064e+38*cos(theta)**5 + 1.08861960554845e+36*cos(theta)**3 - 6.80812761443685e+32*cos(theta))*sin(16*phi)

#@torch.jit.script
def Yl99_m_minus_15(theta, phi):
    return 6.4240308747423e-30*(1.0 - cos(theta)**2)**7.5*(1.01076075308205e+58*cos(theta)**84 - 1.78858476408325e+59*cos(theta)**82 + 1.52304871833859e+60*cos(theta)**80 - 8.31232115708106e+60*cos(theta)**78 + 3.26726445480555e+61*cos(theta)**76 - 9.85365470496913e+61*cos(theta)**74 + 2.37207855241726e+62*cos(theta)**72 - 4.681878594578e+62*cos(theta)**70 + 7.723180878351e+62*cos(theta)**68 - 1.0800126483047e+63*cos(theta)**66 + 1.29420510090144e+63*cos(theta)**64 - 1.34007061295188e+63*cos(theta)**62 + 1.20670168052e+63*cos(theta)**60 - 9.4969407493126e+62*cos(theta)**58 + 6.55741146976346e+62*cos(theta)**56 - 3.98359513350522e+62*cos(theta)**54 + 2.13342987875972e+62*cos(theta)**52 - 1.00853048814096e+62*cos(theta)**50 + 4.21080384448764e+61*cos(theta)**48 - 1.55272531434523e+61*cos(theta)**46 + 5.05368144763306e+60*cos(theta)**44 - 1.45004023338213e+60*cos(theta)**42 + 3.66124528135487e+59*cos(theta)**40 - 8.11529218373629e+58*cos(theta)**38 + 1.57424128177887e+58*cos(theta)**36 - 2.662475187975e+57*cos(theta)**34 + 3.90802872960223e+56*cos(theta)**32 - 4.95116794350628e+55*cos(theta)**30 + 5.37901612244063e+54*cos(theta)**28 - 4.97253141179398e+53*cos(theta)**26 + 3.87547412190178e+52*cos(theta)**24 - 2.51855629301835e+51*cos(theta)**22 + 1.34672801779453e+50*cos(theta)**20 - 5.82999141902395e+48*cos(theta)**18 + 2.00266880806166e+47*cos(theta)**16 - 5.32270779551273e+45*cos(theta)**14 + 1.05941909315761e+44*cos(theta)**12 - 1.51181967888437e+42*cos(theta)**10 + 1.45553884359856e+40*cos(theta)**8 - 8.63638220401773e+37*cos(theta)**6 + 2.72154901387113e+35*cos(theta)**4 - 3.40406380721843e+32*cos(theta)**2 + 7.04775115366134e+28)*sin(15*phi)

#@torch.jit.script
def Yl99_m_minus_14(theta, phi):
    return 6.32367451143506e-28*(1.0 - cos(theta)**2)**7*(1.18913029774358e+56*cos(theta)**85 - 2.15492140250995e+57*cos(theta)**83 + 1.88030705967727e+58*cos(theta)**81 - 1.05219255152925e+59*cos(theta)**79 + 4.24320059065656e+59*cos(theta)**77 - 1.31382062732922e+60*cos(theta)**75 + 3.24942267454419e+60*cos(theta)**73 - 6.59419520363098e+60*cos(theta)**71 + 1.11930157657261e+61*cos(theta)**69 - 1.61195917657418e+61*cos(theta)**67 + 1.99108477061761e+61*cos(theta)**65 - 2.12709621103473e+61*cos(theta)**63 + 1.9781994762623e+61*cos(theta)**61 - 1.60965097445976e+61*cos(theta)**59 + 1.15042306487078e+61*cos(theta)**57 - 7.24290024273676e+60*cos(theta)**55 + 4.02533939388626e+60*cos(theta)**53 - 1.9775107610607e+60*cos(theta)**51 + 8.59347723364824e+59*cos(theta)**49 - 3.3036708815856e+59*cos(theta)**47 + 1.12304032169624e+59*cos(theta)**45 - 3.37218658926076e+58*cos(theta)**43 + 8.92986653988993e+57*cos(theta)**41 - 2.08084414967597e+57*cos(theta)**39 + 4.25470616696991e+56*cos(theta)**37 - 7.60707196564285e+55*cos(theta)**35 + 1.18425113018249e+55*cos(theta)**33 - 1.59715094951815e+54*cos(theta)**31 + 1.85483314566918e+53*cos(theta)**29 - 1.84167830066444e+52*cos(theta)**27 + 1.55018964876071e+51*cos(theta)**25 - 1.09502447522537e+50*cos(theta)**23 + 6.41299056092635e+48*cos(theta)**21 - 3.0684165363284e+47*cos(theta)**19 + 1.17804047533039e+46*cos(theta)**17 - 3.54847186367515e+44*cos(theta)**15 + 8.14937763967391e+42*cos(theta)**13 - 1.37438152625852e+41*cos(theta)**11 + 1.61726538177618e+39*cos(theta)**9 - 1.23376888628825e+37*cos(theta)**7 + 5.44309802774226e+34*cos(theta)**5 - 1.13468793573948e+32*cos(theta)**3 + 7.04775115366134e+28*cos(theta))*sin(14*phi)

#@torch.jit.script
def Yl99_m_minus_13(theta, phi):
    return 6.23387307326385e-26*(1.0 - cos(theta)**2)**6.5*(1.38270964853905e+54*cos(theta)**86 - 2.56538262203565e+55*cos(theta)**84 + 2.29305738985033e+56*cos(theta)**82 - 1.31524068941156e+57*cos(theta)**80 + 5.440000757252e+57*cos(theta)**78 - 1.72871135174897e+58*cos(theta)**76 + 4.39111172235701e+58*cos(theta)**74 - 9.15860444948748e+58*cos(theta)**72 + 1.59900225224658e+59*cos(theta)**70 - 2.37052820084438e+59*cos(theta)**68 + 3.01679510699637e+59*cos(theta)**66 - 3.32358782974177e+59*cos(theta)**64 + 3.19064431655209e+59*cos(theta)**62 - 2.6827516240996e+59*cos(theta)**60 + 1.98348804288066e+59*cos(theta)**58 - 1.29337504334585e+59*cos(theta)**56 + 7.45433221090049e+58*cos(theta)**54 - 3.80290530973212e+58*cos(theta)**52 + 1.71869544672965e+58*cos(theta)**50 - 6.88264766996999e+57*cos(theta)**48 + 2.44139200368747e+57*cos(theta)**46 - 7.66406043013809e+56*cos(theta)**44 + 2.12615869997379e+56*cos(theta)**42 - 5.20211037418993e+55*cos(theta)**40 + 1.11965951762366e+55*cos(theta)**38 - 2.1130755460119e+54*cos(theta)**36 + 3.48309155936028e+53*cos(theta)**34 - 4.99109671724423e+52*cos(theta)**32 + 6.18277715223061e+51*cos(theta)**30 - 6.57742250237299e+50*cos(theta)**28 + 5.9622678798489e+49*cos(theta)**26 - 4.5626019801057e+48*cos(theta)**24 + 2.91499570951198e+47*cos(theta)**22 - 1.5342082681642e+46*cos(theta)**20 + 6.54466930739106e+44*cos(theta)**18 - 2.21779491479697e+43*cos(theta)**16 + 5.8209840283385e+41*cos(theta)**14 - 1.14531793854877e+40*cos(theta)**12 + 1.61726538177618e+38*cos(theta)**10 - 1.54221110786031e+36*cos(theta)**8 + 9.07183004623711e+33*cos(theta)**6 - 2.83671983934869e+31*cos(theta)**4 + 3.52387557683067e+28*cos(theta)**2 - 7.25226502743501e+24)*sin(13*phi)

#@torch.jit.script
def Yl99_m_minus_12(theta, phi):
    return 6.15356217585626e-24*(1.0 - cos(theta)**2)**6*(1.58932143510236e+52*cos(theta)**87 - 3.01809720239488e+53*cos(theta)**85 + 2.76271974680762e+54*cos(theta)**83 - 1.62375393754514e+55*cos(theta)**81 + 6.88607690791393e+55*cos(theta)**79 - 2.24507967759606e+56*cos(theta)**77 + 5.85481562980935e+56*cos(theta)**75 - 1.25460334924486e+57*cos(theta)**73 + 2.25211584823463e+57*cos(theta)**71 - 3.43554811716577e+57*cos(theta)**69 + 4.50267926417369e+57*cos(theta)**67 - 5.11321204575656e+57*cos(theta)**65 + 5.06451478817793e+57*cos(theta)**63 - 4.3979534821305e+57*cos(theta)**61 + 3.36184414047569e+57*cos(theta)**59 - 2.26907902341377e+57*cos(theta)**57 + 1.35533312925463e+57*cos(theta)**55 - 7.17529303723041e+56*cos(theta)**53 + 3.36999107201892e+56*cos(theta)**51 - 1.40462197346326e+56*cos(theta)**49 + 5.19445107167546e+55*cos(theta)**47 - 1.70312454003069e+55*cos(theta)**45 + 4.94455511621813e+54*cos(theta)**43 - 1.26880740833901e+54*cos(theta)**41 + 2.87092184006067e+53*cos(theta)**39 - 5.71101498922136e+52*cos(theta)**37 + 9.95169016960079e+51*cos(theta)**35 - 1.51245355068007e+51*cos(theta)**33 + 1.99444424265504e+50*cos(theta)**31 - 2.2680767249562e+49*cos(theta)**29 + 2.208247362907e+48*cos(theta)**27 - 1.82504079204228e+47*cos(theta)**25 + 1.26738943891825e+46*cos(theta)**23 - 7.30575365792476e+44*cos(theta)**21 + 3.44456279336371e+43*cos(theta)**19 - 1.30458524399822e+42*cos(theta)**17 + 3.88065601889234e+40*cos(theta)**15 - 8.81013798883666e+38*cos(theta)**13 + 1.47024125616016e+37*cos(theta)**11 - 1.71356789762256e+35*cos(theta)**9 + 1.29597572089102e+33*cos(theta)**7 - 5.67343967869738e+30*cos(theta)**5 + 1.17462519227689e+28*cos(theta)**3 - 7.25226502743501e+24*cos(theta))*sin(12*phi)

#@torch.jit.script
def Yl99_m_minus_11(theta, phi):
    return 6.08176196963013e-22*(1.0 - cos(theta)**2)**5.5*(1.80604708534359e+50*cos(theta)**88 - 3.50941535162195e+51*cos(theta)**86 + 3.28895207953288e+52*cos(theta)**84 - 1.98018772871358e+53*cos(theta)**82 + 8.60759613489241e+53*cos(theta)**80 - 2.87830727896931e+54*cos(theta)**78 + 7.70370477606493e+54*cos(theta)**76 - 1.69540993141197e+55*cos(theta)**74 + 3.12793867810365e+55*cos(theta)**72 - 4.90792588166539e+55*cos(theta)**70 + 6.6215871531966e+55*cos(theta)**68 - 7.74729097841903e+55*cos(theta)**66 + 7.91330435652801e+55*cos(theta)**64 - 7.093473358275e+55*cos(theta)**62 + 5.60307356745949e+55*cos(theta)**60 - 3.91220521278237e+55*cos(theta)**58 + 2.42023773081185e+55*cos(theta)**56 - 1.32875796985748e+55*cos(theta)**54 + 6.48075206157485e+54*cos(theta)**52 - 2.80924394692653e+54*cos(theta)**50 + 1.08217730659906e+54*cos(theta)**48 - 3.70244465224063e+53*cos(theta)**46 + 1.12376252641321e+53*cos(theta)**44 - 3.02097001985478e+52*cos(theta)**42 + 7.17730460015167e+51*cos(theta)**40 - 1.50289868137404e+51*cos(theta)**38 + 2.76435838044466e+50*cos(theta)**36 - 4.44839279611785e+49*cos(theta)**34 + 6.23263825829699e+48*cos(theta)**32 - 7.56025574985401e+47*cos(theta)**30 + 7.88659772466786e+46*cos(theta)**28 - 7.01938766170108e+45*cos(theta)**26 + 5.28078932882605e+44*cos(theta)**24 - 3.32079711723853e+43*cos(theta)**22 + 1.72228139668186e+42*cos(theta)**20 - 7.2476957999901e+40*cos(theta)**18 + 2.42541001180771e+39*cos(theta)**16 - 6.2929557063119e+37*cos(theta)**14 + 1.22520104680013e+36*cos(theta)**12 - 1.71356789762256e+34*cos(theta)**10 + 1.61996965111377e+32*cos(theta)**8 - 9.45573279782896e+29*cos(theta)**6 + 2.93656298069222e+27*cos(theta)**4 - 3.6261325137175e+24*cos(theta)**2 + 7.42451374635033e+20)*sin(11*phi)

#@torch.jit.script
def Yl99_m_minus_10(theta, phi):
    return 6.01756464472791e-20*(1.0 - cos(theta)**2)**5*(2.0292663880265e+48*cos(theta)**89 - 4.03381074899075e+49*cos(theta)**87 + 3.86935538768575e+50*cos(theta)**85 - 2.38576834784769e+51*cos(theta)**83 + 1.06266618949289e+52*cos(theta)**81 - 3.64342693540419e+52*cos(theta)**79 + 1.00048113974869e+53*cos(theta)**77 - 2.26054657521596e+53*cos(theta)**75 + 4.28484750425157e+53*cos(theta)**73 - 6.91257166431745e+53*cos(theta)**71 + 9.59650312057478e+53*cos(theta)**69 - 1.1563120863312e+54*cos(theta)**67 + 1.21743143946585e+54*cos(theta)**65 - 1.12594815210714e+54*cos(theta)**63 + 9.18536650403195e+53*cos(theta)**61 - 6.63085629285147e+53*cos(theta)**59 + 4.24603110668745e+53*cos(theta)**57 - 2.41592358155906e+53*cos(theta)**55 + 1.22278340784431e+53*cos(theta)**53 - 5.50832146456182e+52*cos(theta)**51 + 2.20852511550828e+52*cos(theta)**49 - 7.87754181327793e+51*cos(theta)**47 + 2.49725005869602e+51*cos(theta)**45 - 7.02551167408088e+50*cos(theta)**43 + 1.75056209759797e+50*cos(theta)**41 - 3.85358636249754e+49*cos(theta)**39 + 7.47123886606666e+48*cos(theta)**37 - 1.27096937031939e+48*cos(theta)**35 + 1.88867826009e+47*cos(theta)**33 - 2.43879217737226e+46*cos(theta)**31 + 2.71951645678202e+45*cos(theta)**29 - 2.59977320803744e+44*cos(theta)**27 + 2.11231573153042e+43*cos(theta)**25 - 1.44382483358197e+42*cos(theta)**23 + 8.20133998419932e+40*cos(theta)**21 - 3.81457673683689e+39*cos(theta)**19 + 1.42671177165159e+38*cos(theta)**17 - 4.19530380420793e+36*cos(theta)**15 + 9.42462343692411e+34*cos(theta)**13 - 1.5577889978387e+33*cos(theta)**11 + 1.7999662790153e+31*cos(theta)**9 - 1.35081897111842e+29*cos(theta)**7 + 5.87312596138445e+26*cos(theta)**5 - 1.20871083790583e+24*cos(theta)**3 + 7.42451374635033e+20*cos(theta))*sin(10*phi)

#@torch.jit.script
def Yl99_m_minus_9(theta, phi):
    return 5.96012362729694e-18*(1.0 - cos(theta)**2)**4.5*(2.25474043114056e+46*cos(theta)**90 - 4.58387585112586e+47*cos(theta)**88 + 4.49925045079738e+48*cos(theta)**86 - 2.84020041410439e+49*cos(theta)**84 + 1.29593437743035e+50*cos(theta)**82 - 4.55428366925524e+50*cos(theta)**80 + 1.28266812788294e+51*cos(theta)**78 - 2.97440338844206e+51*cos(theta)**76 + 5.79033446520482e+51*cos(theta)**74 - 9.60079397821868e+51*cos(theta)**72 + 1.37092901722497e+52*cos(theta)**70 - 1.70045895048706e+52*cos(theta)**68 + 1.84459309009977e+52*cos(theta)**66 - 1.75929398766741e+52*cos(theta)**64 + 1.48151072645677e+52*cos(theta)**62 - 1.10514271547524e+52*cos(theta)**60 + 7.32074328739215e+51*cos(theta)**58 - 4.31414925278404e+51*cos(theta)**56 + 2.2644137182302e+51*cos(theta)**54 - 1.05929258933881e+51*cos(theta)**52 + 4.41705023101655e+50*cos(theta)**50 - 1.6411545444329e+50*cos(theta)**48 + 5.42880447542614e+49*cos(theta)**46 - 1.59670719865475e+49*cos(theta)**44 + 4.16800499428088e+48*cos(theta)**42 - 9.63396590624385e+47*cos(theta)**40 + 1.96611549107017e+47*cos(theta)**38 - 3.53047047310941e+46*cos(theta)**36 + 5.55493605908823e+45*cos(theta)**34 - 7.62122555428832e+44*cos(theta)**32 + 9.06505485594007e+43*cos(theta)**30 - 9.28490431441942e+42*cos(theta)**28 + 8.12429127511699e+41*cos(theta)**26 - 6.01593680659153e+40*cos(theta)**24 + 3.72788181099969e+39*cos(theta)**22 - 1.90728836841845e+38*cos(theta)**20 + 7.92617650917552e+36*cos(theta)**18 - 2.62206487762996e+35*cos(theta)**16 + 6.73187388351722e+33*cos(theta)**14 - 1.29815749819891e+32*cos(theta)**12 + 1.7999662790153e+30*cos(theta)**10 - 1.68852371389803e+28*cos(theta)**8 + 9.78854326897408e+25*cos(theta)**6 - 3.02177709476459e+23*cos(theta)**4 + 3.71225687317517e+20*cos(theta)**2 - 7.56831166804315e+16)*sin(9*phi)

#@torch.jit.script
def Yl99_m_minus_8(theta, phi):
    return 5.90864424261924e-16*(1.0 - cos(theta)**2)**4*(2.4777367375171e+44*cos(theta)**91 - 5.15042230463579e+45*cos(theta)**89 + 5.17155224229584e+46*cos(theta)**87 - 3.34141225188752e+47*cos(theta)**85 + 1.56136671979561e+48*cos(theta)**83 - 5.62257243117931e+48*cos(theta)**81 + 1.62363054162397e+49*cos(theta)**79 - 3.86286154343124e+49*cos(theta)**77 + 7.72044595360643e+49*cos(theta)**75 - 1.31517725729023e+50*cos(theta)**73 + 1.93088593975348e+50*cos(theta)**71 - 2.46443326157545e+50*cos(theta)**69 + 2.75312401507428e+50*cos(theta)**67 - 2.70660613487294e+50*cos(theta)**65 + 2.35160432770915e+50*cos(theta)**63 - 1.81170936963155e+50*cos(theta)**61 + 1.24080394701562e+50*cos(theta)**59 - 7.56868289962112e+49*cos(theta)**57 + 4.11711585132764e+49*cos(theta)**55 - 1.99866526290342e+49*cos(theta)**53 + 8.66088280591481e+48*cos(theta)**51 - 3.34929498863857e+48*cos(theta)**49 + 1.15506478200556e+48*cos(theta)**47 - 3.54823821923277e+47*cos(theta)**45 + 9.69303487042064e+46*cos(theta)**43 - 2.3497477820107e+46*cos(theta)**41 + 5.04132177197481e+45*cos(theta)**39 - 9.54181208948488e+44*cos(theta)**37 + 1.58712458831092e+44*cos(theta)**35 - 2.30946228917828e+43*cos(theta)**33 + 2.92421124385163e+42*cos(theta)**31 - 3.20169114290325e+41*cos(theta)**29 + 3.00899676856185e+40*cos(theta)**27 - 2.40637472263661e+39*cos(theta)**25 + 1.62081817869552e+38*cos(theta)**23 - 9.08232556389737e+36*cos(theta)**21 + 4.17167184693449e+35*cos(theta)**19 - 1.54239110448821e+34*cos(theta)**17 + 4.48791592234481e+32*cos(theta)**15 - 9.98582690922241e+30*cos(theta)**13 + 1.636332980923e+29*cos(theta)**11 - 1.8761374598867e+27*cos(theta)**9 + 1.39836332413915e+25*cos(theta)**7 - 6.04355418952917e+22*cos(theta)**5 + 1.23741895772506e+20*cos(theta)**3 - 7.56831166804315e+16*cos(theta))*sin(8*phi)

#@torch.jit.script
def Yl99_m_minus_7(theta, phi):
    return 5.86237566076914e-14*(1.0 - cos(theta)**2)**3.5*(2.69319210599684e+42*cos(theta)**92 - 5.72269144959533e+43*cos(theta)**90 + 5.87676391169981e+44*cos(theta)**88 - 3.88536308359014e+45*cos(theta)**86 + 1.85876990451858e+46*cos(theta)**84 - 6.85679564777965e+46*cos(theta)**82 + 2.02953817702997e+47*cos(theta)**80 - 4.95238659414262e+47*cos(theta)**78 + 1.01584815179032e+48*cos(theta)**76 - 1.77726656390572e+48*cos(theta)**74 + 2.68178602743539e+48*cos(theta)**72 - 3.52061894510778e+48*cos(theta)**70 + 4.04871178687395e+48*cos(theta)**68 - 4.10091838617112e+48*cos(theta)**66 + 3.67438176204555e+48*cos(theta)**64 - 2.9221118865025e+48*cos(theta)**62 + 2.06800657835937e+48*cos(theta)**60 - 1.30494532752088e+48*cos(theta)**58 + 7.35199259165651e+47*cos(theta)**56 - 3.70123196833966e+47*cos(theta)**54 + 1.66555438575285e+47*cos(theta)**52 - 6.69858997727715e+46*cos(theta)**50 + 2.40638496251159e+46*cos(theta)**48 - 7.71356134615819e+45*cos(theta)**46 + 2.20296247055015e+45*cos(theta)**44 - 5.59463757621594e+44*cos(theta)**42 + 1.2603304429937e+44*cos(theta)**40 - 2.51100318144339e+43*cos(theta)**38 + 4.40867941197478e+42*cos(theta)**36 - 6.792536144642e+41*cos(theta)**34 + 9.13816013703636e+40*cos(theta)**32 - 1.06723038096775e+40*cos(theta)**30 + 1.0746417030578e+39*cos(theta)**28 - 9.2552873947562e+37*cos(theta)**26 + 6.75340907789799e+36*cos(theta)**24 - 4.12832980177153e+35*cos(theta)**22 + 2.08583592346724e+34*cos(theta)**20 - 8.56883946937894e+32*cos(theta)**18 + 2.80494745146551e+31*cos(theta)**16 - 7.13273350658743e+29*cos(theta)**14 + 1.36361081743583e+28*cos(theta)**12 - 1.8761374598867e+26*cos(theta)**10 + 1.74795415517394e+24*cos(theta)**8 - 1.0072590315882e+22*cos(theta)**6 + 3.09354739431264e+19*cos(theta)**4 - 3.78415583402158e+16*cos(theta)**2 + 7688248342181.18)*sin(7*phi)

#@torch.jit.script
def Yl99_m_minus_6(theta, phi):
    return 5.82060397389043e-12*(1.0 - cos(theta)**2)**3*(2.89590549031919e+40*cos(theta)**93 - 6.28867192263222e+41*cos(theta)**91 + 6.60310551876384e+42*cos(theta)**89 - 4.46593457883924e+43*cos(theta)**87 + 2.18678812296303e+44*cos(theta)**85 - 8.26119957563813e+44*cos(theta)**83 + 2.50560268769132e+45*cos(theta)**81 - 6.26884379005395e+45*cos(theta)**79 + 1.3192833140134e+46*cos(theta)**77 - 2.36968875187429e+46*cos(theta)**75 + 3.67367948963751e+46*cos(theta)**73 - 4.95861823254617e+46*cos(theta)**71 + 5.8676982418463e+46*cos(theta)**69 - 6.12077371070316e+46*cos(theta)**67 + 5.65289501853162e+46*cos(theta)**65 - 4.63827283571825e+46*cos(theta)**63 + 3.39017471862191e+46*cos(theta)**61 - 2.21177174156082e+46*cos(theta)**59 + 1.28982326169412e+46*cos(theta)**57 - 6.72951266970847e+45*cos(theta)**55 + 3.14255544481669e+45*cos(theta)**53 - 1.31344901515238e+45*cos(theta)**51 + 4.9109897194114e+44*cos(theta)**49 - 1.64118326514004e+44*cos(theta)**47 + 4.8954721567781e+43*cos(theta)**45 - 1.30107850609673e+43*cos(theta)**43 + 3.07397669022854e+42*cos(theta)**41 - 6.43846969600869e+41*cos(theta)**39 + 1.1915349762094e+41*cos(theta)**37 - 1.94072461275486e+40*cos(theta)**35 + 2.76913943546556e+39*cos(theta)**33 - 3.44267864828306e+38*cos(theta)**31 + 3.70566104502691e+37*cos(theta)**29 - 3.42788422028007e+36*cos(theta)**27 + 2.7013636311592e+35*cos(theta)**25 - 1.79492600077023e+34*cos(theta)**23 + 9.93255201651068e+32*cos(theta)**21 - 4.50991551019944e+31*cos(theta)**19 + 1.64996908909736e+30*cos(theta)**17 - 4.75515567105829e+28*cos(theta)**15 + 1.04893139802756e+27*cos(theta)**13 - 1.70557950898791e+25*cos(theta)**11 + 1.9421712835266e+23*cos(theta)**9 - 1.43894147369742e+21*cos(theta)**7 + 6.18709478862528e+18*cos(theta)**5 - 1.26138527800719e+16*cos(theta)**3 + 7688248342181.18*cos(theta))*sin(6*phi)

#@torch.jit.script
def Yl99_m_minus_5(theta, phi):
    return 5.782646282006e-10*(1.0 - cos(theta)**2)**2.5*(3.08075052161616e+38*cos(theta)**94 - 6.83551295938285e+39*cos(theta)**92 + 7.3367839097376e+40*cos(theta)**90 - 5.07492565777186e+41*cos(theta)**88 + 2.54277688716632e+42*cos(theta)**86 - 9.83476139956921e+42*cos(theta)**84 + 3.0556130337699e+43*cos(theta)**82 - 7.83605473756744e+43*cos(theta)**80 + 1.69138886411975e+44*cos(theta)**78 - 3.11801151562406e+44*cos(theta)**76 + 4.9644317427534e+44*cos(theta)**74 - 6.88696976742523e+44*cos(theta)**72 + 8.38242605978043e+44*cos(theta)**70 - 9.00113780985759e+44*cos(theta)**68 + 8.56499245232064e+44*cos(theta)**66 - 7.24730130580977e+44*cos(theta)**64 + 5.46802373971276e+44*cos(theta)**62 - 3.6862862359347e+44*cos(theta)**60 + 2.22383320981746e+44*cos(theta)**58 - 1.20169869101937e+44*cos(theta)**56 + 5.81954712003091e+43*cos(theta)**54 - 2.52586349067766e+43*cos(theta)**52 + 9.8219794388228e+42*cos(theta)**50 - 3.41913180237509e+42*cos(theta)**48 + 1.06423307756046e+42*cos(theta)**46 - 2.9569966047653e+41*cos(theta)**44 + 7.31899211959176e+40*cos(theta)**42 - 1.60961742400217e+40*cos(theta)**40 + 3.13561835844579e+39*cos(theta)**38 - 5.39090170209682e+38*cos(theta)**36 + 8.1445277513693e+37*cos(theta)**34 - 1.07583707758846e+37*cos(theta)**32 + 1.2352203483423e+36*cos(theta)**30 - 1.22424436438574e+35*cos(theta)**28 + 1.03898601198431e+34*cos(theta)**26 - 7.47885833654263e+32*cos(theta)**24 + 4.51479637114122e+31*cos(theta)**22 - 2.25495775509972e+30*cos(theta)**20 + 9.16649493942976e+28*cos(theta)**18 - 2.97197229441143e+27*cos(theta)**16 + 7.49236712876831e+25*cos(theta)**14 - 1.42131625748992e+24*cos(theta)**12 + 1.9421712835266e+22*cos(theta)**10 - 1.79867684212178e+20*cos(theta)**8 + 1.03118246477088e+18*cos(theta)**6 - 3.15346319501798e+15*cos(theta)**4 + 3844124171090.59*cos(theta)**2 - 778951199.815722)*sin(5*phi)

#@torch.jit.script
def Yl99_m_minus_4(theta, phi):
    return 5.74784568743144e-8*(1.0 - cos(theta)**2)**2*(3.24289528591174e+36*cos(theta)**95 - 7.35001393482027e+37*cos(theta)**93 + 8.06239990081055e+38*cos(theta)**91 - 5.70216366041782e+39*cos(theta)**89 + 2.92273205421416e+40*cos(theta)**87 - 1.15703075289049e+41*cos(theta)**85 + 3.68146148646976e+41*cos(theta)**83 - 9.67414165131782e+41*cos(theta)**81 + 2.14099856217689e+42*cos(theta)**79 - 4.04936560470658e+42*cos(theta)**77 + 6.6192423236712e+42*cos(theta)**75 - 9.43420516085648e+42*cos(theta)**73 + 1.18062338870147e+43*cos(theta)**71 - 1.30451272606632e+43*cos(theta)**69 + 1.27835708243592e+43*cos(theta)**67 - 1.11496943166304e+43*cos(theta)**65 + 8.67940276144882e+42*cos(theta)**63 - 6.04309219005688e+42*cos(theta)**61 + 3.76920883019908e+42*cos(theta)**59 - 2.10824331757784e+42*cos(theta)**57 + 1.05809947636926e+42*cos(theta)**55 - 4.76578017108992e+41*cos(theta)**53 + 1.9258783213378e+41*cos(theta)**51 - 6.97782000484711e+40*cos(theta)**49 + 2.26432569693714e+40*cos(theta)**47 - 6.5711035661451e+39*cos(theta)**45 + 1.70209119060274e+39*cos(theta)**43 - 3.92589615610286e+38*cos(theta)**41 + 8.04004707293793e+37*cos(theta)**39 - 1.45700046002617e+37*cos(theta)**37 + 2.32700792896266e+36*cos(theta)**35 - 3.26011235632866e+35*cos(theta)**33 + 3.98458176884614e+34*cos(theta)**31 - 4.22153229098531e+33*cos(theta)**29 + 3.84809634068262e+32*cos(theta)**27 - 2.99154333461705e+31*cos(theta)**25 + 1.96295494397444e+30*cos(theta)**23 - 1.07378940719034e+29*cos(theta)**21 + 4.82447102075251e+27*cos(theta)**19 - 1.74821899671261e+26*cos(theta)**17 + 4.99491141917887e+24*cos(theta)**15 - 1.09332019806917e+23*cos(theta)**13 + 1.76561025775146e+21*cos(theta)**11 - 1.99852982457975e+19*cos(theta)**9 + 1.47311780681554e+17*cos(theta)**7 - 630692639003596.0*cos(theta)**5 + 1281374723696.86*cos(theta)**3 - 778951199.815722*cos(theta))*sin(4*phi)

#@torch.jit.script
def Yl99_m_minus_3(theta, phi):
    return 5.71556711709373e-6*(1.0 - cos(theta)**2)**1.5*(3.37801592282473e+34*cos(theta)**96 - 7.8191637604471e+35*cos(theta)**94 + 8.76347815305494e+36*cos(theta)**92 - 6.33573740046425e+37*cos(theta)**90 + 3.32128642524336e+38*cos(theta)**88 - 1.3453845963843e+39*cos(theta)**86 + 4.38269224579733e+39*cos(theta)**84 - 1.17977337211193e+40*cos(theta)**82 + 2.67624820272112e+40*cos(theta)**80 - 5.19149436500843e+40*cos(theta)**78 + 8.70952937325158e+40*cos(theta)**76 - 1.27489258930493e+41*cos(theta)**74 + 1.63975470652982e+41*cos(theta)**72 - 1.86358960866617e+41*cos(theta)**70 + 1.87993688593517e+41*cos(theta)**68 - 1.68934762373188e+41*cos(theta)**66 + 1.35615668147638e+41*cos(theta)**64 - 9.74692288718852e+40*cos(theta)**62 + 6.28201471699846e+40*cos(theta)**60 - 3.63490227168594e+40*cos(theta)**58 + 1.88946335065939e+40*cos(theta)**56 - 8.8255188353517e+39*cos(theta)**54 + 3.70361215641885e+39*cos(theta)**52 - 1.39556400096942e+39*cos(theta)**50 + 4.71734520195238e+38*cos(theta)**48 - 1.42850077524894e+38*cos(theta)**46 + 3.86838906955167e+37*cos(theta)**44 - 9.34737180024491e+36*cos(theta)**42 + 2.01001176823448e+36*cos(theta)**40 - 3.83421173691097e+35*cos(theta)**38 + 6.46391091378516e+34*cos(theta)**36 - 9.58856575390782e+33*cos(theta)**34 + 1.24518180276442e+33*cos(theta)**32 - 1.40717743032844e+32*cos(theta)**30 + 1.37432012167236e+31*cos(theta)**28 - 1.15059359023733e+30*cos(theta)**26 + 8.17897893322685e+28*cos(theta)**24 - 4.88086094177429e+27*cos(theta)**22 + 2.41223551037625e+26*cos(theta)**20 - 9.71232775951448e+24*cos(theta)**18 + 3.1218196369868e+23*cos(theta)**16 - 7.80942998620837e+21*cos(theta)**14 + 1.47134188145955e+20*cos(theta)**12 - 1.99852982457975e+18*cos(theta)**10 + 1.84139725851943e+16*cos(theta)**8 - 105115439833933.0*cos(theta)**6 + 320343680924.216*cos(theta)**4 - 389475599.907861*cos(theta)**2 + 78777.4271658295)*sin(3*phi)

#@torch.jit.script
def Yl99_m_minus_2(theta, phi):
    return 0.000568519390793499*(1.0 - cos(theta)**2)*(3.48249064208735e+32*cos(theta)**97 - 8.23069869520747e+33*cos(theta)**95 + 9.42309478823112e+34*cos(theta)**93 - 6.96234879171895e+35*cos(theta)**91 + 3.73178250027344e+36*cos(theta)**89 - 1.54641907630379e+37*cos(theta)**87 + 5.15610852446744e+37*cos(theta)**85 - 1.42141370133967e+38*cos(theta)**83 + 3.3040101268162e+38*cos(theta)**81 - 6.57151185444105e+38*cos(theta)**79 + 1.13110771081189e+39*cos(theta)**77 - 1.69985678573991e+39*cos(theta)**75 + 2.24623932401345e+39*cos(theta)**73 - 2.62477409671291e+39*cos(theta)**71 + 2.72454621150025e+39*cos(theta)**69 - 2.52141436377893e+39*cos(theta)**67 + 2.08639489457904e+39*cos(theta)**65 - 1.54713061701405e+39*cos(theta)**63 + 1.02983847819647e+39*cos(theta)**61 - 6.16085130794226e+38*cos(theta)**59 + 3.31484798361296e+38*cos(theta)**57 - 1.60463978824576e+38*cos(theta)**55 + 6.98794746494123e+37*cos(theta)**53 - 2.73640000190083e+37*cos(theta)**51 + 9.62723510602527e+36*cos(theta)**49 - 3.03936335159348e+36*cos(theta)**47 + 8.59642015455927e+35*cos(theta)**45 - 2.17380739540579e+35*cos(theta)**43 + 4.90246772740117e+34*cos(theta)**41 - 9.83131214592556e+33*cos(theta)**39 + 1.74700294967166e+33*cos(theta)**37 - 2.73959021540223e+32*cos(theta)**35 + 3.77327819019521e+31*cos(theta)**33 - 4.53928203331754e+30*cos(theta)**31 + 4.73903490231849e+29*cos(theta)**29 - 4.26145774161973e+28*cos(theta)**27 + 3.27159157329074e+27*cos(theta)**25 - 2.12211345294534e+26*cos(theta)**23 + 1.14868357636964e+25*cos(theta)**21 - 5.11175145237604e+23*cos(theta)**19 + 1.83636449234517e+22*cos(theta)**17 - 5.20628665747225e+20*cos(theta)**15 + 1.13180144727658e+19*cos(theta)**13 - 1.8168452950725e+17*cos(theta)**11 + 2.04599695391048e+15*cos(theta)**9 - 15016491404847.5*cos(theta)**7 + 64068736184.8432*cos(theta)**5 - 129825199.969287*cos(theta)**3 + 78777.4271658295*cos(theta))*sin(2*phi)

#@torch.jit.script
def Yl99_m_minus_1(theta, phi):
    return 0.0565612510356328*(1.0 - cos(theta)**2)**0.5*(3.55356187968097e+30*cos(theta)**98 - 8.57364447417445e+31*cos(theta)**96 + 1.00245689236501e+33*cos(theta)**94 - 7.56777042578147e+33*cos(theta)**92 + 4.14642500030383e+34*cos(theta)**90 - 1.75729440489067e+35*cos(theta)**88 + 5.99547502845052e+35*cos(theta)**86 - 1.69215916826152e+36*cos(theta)**84 + 4.02928064245878e+36*cos(theta)**82 - 8.21438981805132e+36*cos(theta)**80 + 1.45013809078448e+37*cos(theta)**78 - 2.23665366544725e+37*cos(theta)**76 + 3.03545854596412e+37*cos(theta)**74 - 3.64551957876794e+37*cos(theta)**72 + 3.89220887357178e+37*cos(theta)**70 - 3.70796229967489e+37*cos(theta)**68 + 3.16120438572582e+37*cos(theta)**66 - 2.41739158908445e+37*cos(theta)**64 + 1.66102980354269e+37*cos(theta)**62 - 1.02680855132371e+37*cos(theta)**60 + 5.71525514416028e+36*cos(theta)**58 - 2.86542819329601e+36*cos(theta)**56 + 1.29406434535949e+36*cos(theta)**54 - 5.26230769596313e+35*cos(theta)**52 + 1.92544702120505e+35*cos(theta)**50 - 6.33200698248642e+34*cos(theta)**48 + 1.86878699012158e+34*cos(theta)**46 - 4.94047135319498e+33*cos(theta)**44 + 1.1672542208098e+33*cos(theta)**42 - 2.45782803648139e+32*cos(theta)**40 + 4.59737618334649e+31*cos(theta)**38 - 7.60997282056176e+30*cos(theta)**36 + 1.10978770299859e+30*cos(theta)**34 - 1.41852563541173e+29*cos(theta)**32 + 1.57967830077283e+28*cos(theta)**30 - 1.52194919343562e+27*cos(theta)**28 + 1.25830445126567e+26*cos(theta)**26 - 8.84213938727226e+24*cos(theta)**24 + 5.22128898349838e+23*cos(theta)**22 - 2.55587572618802e+22*cos(theta)**20 + 1.02020249574732e+21*cos(theta)**18 - 3.25392916092015e+19*cos(theta)**16 + 8.08429605197554e+17*cos(theta)**14 - 1.51403774589375e+16*cos(theta)**12 + 204599695391048.0*cos(theta)**10 - 1877061425605.94*cos(theta)**8 + 10678122697.4739*cos(theta)**6 - 32456299.9923218*cos(theta)**4 + 39388.7135829148*cos(theta)**2 - 7.95892373871788)*sin(phi)

#@torch.jit.script
def Yl99_m0(theta, phi):
    return 4.48745562168431e+29*cos(theta)**99 - 1.10500747313658e+31*cos(theta)**97 + 1.31920892177536e+32*cos(theta)**95 - 1.01731741549689e+33*cos(theta)**93 + 5.69644489986347e+33*cos(theta)**91 - 2.4684594566075e+34*cos(theta)**89 + 8.61540751521834e+34*cos(theta)**87 - 2.48882158412601e+35*cos(theta)**85 + 6.06905263342203e+35*cos(theta)**83 - 1.26783217382045e+36*cos(theta)**81 + 2.29484706322808e+36*cos(theta)**79 - 3.63144519866755e+36*cos(theta)**77 + 5.05981364347678e+36*cos(theta)**75 - 6.24321158766033e+36*cos(theta)**73 + 6.85345031427374e+36*cos(theta)**71 - 6.71827377947544e+36*cos(theta)**69 + 5.89860414919513e+36*cos(theta)**67 - 4.6494879764244e+36*cos(theta)**65 + 3.29616052861716e+36*cos(theta)**63 - 2.10441370133681e+36*cos(theta)**61 + 1.211030526241e+36*cos(theta)**59 - 6.28472317378934e+35*cos(theta)**57 + 2.94147160861225e+35*cos(theta)**55 - 1.24128597294379e+35*cos(theta)**53 + 4.7199008573856e+34*cos(theta)**51 - 1.61553653507829e+34*cos(theta)**49 + 4.97088164639475e+33*cos(theta)**47 - 1.37254739712713e+33*cos(theta)**45 + 3.39366114674291e+32*cos(theta)**43 - 7.49443877600599e+31*cos(theta)**41 + 1.47372656986209e+31*cos(theta)**39 - 2.57130065521028e+30*cos(theta)**37 + 3.96408851011585e+29*cos(theta)**35 - 5.37396368994972e+28*cos(theta)**33 + 6.37057213357309e+27*cos(theta)**31 - 6.56105435683607e+26*cos(theta)**29 + 5.82630811215102e+25*cos(theta)**27 - 4.42169545376218e+24*cos(theta)**25 + 2.83805869946225e+23*cos(theta)**23 - 1.52156993211263e+22*cos(theta)**21 + 6.71280852402629e+20*cos(theta)**19 - 2.39293362019699e+19*cos(theta)**17 + 6.7378669222938e+17*cos(theta)**15 - 1.4560115802446e+16*cos(theta)**13 + 232532561955525.0*cos(theta)**11 - 2607398757911.09*cos(theta)**9 + 19070775149.2887*cos(theta)**7 - 81152234.6778243*cos(theta)**5 + 164142.869493981*cos(theta)**3 - 99.5006281030398*cos(theta)

#@torch.jit.script
def Yl99_m1(theta, phi):
    return 0.0565612510356328*(1.0 - cos(theta)**2)**0.5*(3.55356187968097e+30*cos(theta)**98 - 8.57364447417445e+31*cos(theta)**96 + 1.00245689236501e+33*cos(theta)**94 - 7.56777042578147e+33*cos(theta)**92 + 4.14642500030383e+34*cos(theta)**90 - 1.75729440489067e+35*cos(theta)**88 + 5.99547502845052e+35*cos(theta)**86 - 1.69215916826152e+36*cos(theta)**84 + 4.02928064245878e+36*cos(theta)**82 - 8.21438981805132e+36*cos(theta)**80 + 1.45013809078448e+37*cos(theta)**78 - 2.23665366544725e+37*cos(theta)**76 + 3.03545854596412e+37*cos(theta)**74 - 3.64551957876794e+37*cos(theta)**72 + 3.89220887357178e+37*cos(theta)**70 - 3.70796229967489e+37*cos(theta)**68 + 3.16120438572582e+37*cos(theta)**66 - 2.41739158908445e+37*cos(theta)**64 + 1.66102980354269e+37*cos(theta)**62 - 1.02680855132371e+37*cos(theta)**60 + 5.71525514416028e+36*cos(theta)**58 - 2.86542819329601e+36*cos(theta)**56 + 1.29406434535949e+36*cos(theta)**54 - 5.26230769596313e+35*cos(theta)**52 + 1.92544702120505e+35*cos(theta)**50 - 6.33200698248642e+34*cos(theta)**48 + 1.86878699012158e+34*cos(theta)**46 - 4.94047135319498e+33*cos(theta)**44 + 1.1672542208098e+33*cos(theta)**42 - 2.45782803648139e+32*cos(theta)**40 + 4.59737618334649e+31*cos(theta)**38 - 7.60997282056176e+30*cos(theta)**36 + 1.10978770299859e+30*cos(theta)**34 - 1.41852563541173e+29*cos(theta)**32 + 1.57967830077283e+28*cos(theta)**30 - 1.52194919343562e+27*cos(theta)**28 + 1.25830445126567e+26*cos(theta)**26 - 8.84213938727226e+24*cos(theta)**24 + 5.22128898349838e+23*cos(theta)**22 - 2.55587572618802e+22*cos(theta)**20 + 1.02020249574732e+21*cos(theta)**18 - 3.25392916092015e+19*cos(theta)**16 + 8.08429605197554e+17*cos(theta)**14 - 1.51403774589375e+16*cos(theta)**12 + 204599695391048.0*cos(theta)**10 - 1877061425605.94*cos(theta)**8 + 10678122697.4739*cos(theta)**6 - 32456299.9923218*cos(theta)**4 + 39388.7135829148*cos(theta)**2 - 7.95892373871788)*cos(phi)

#@torch.jit.script
def Yl99_m2(theta, phi):
    return 0.000568519390793499*(1.0 - cos(theta)**2)*(3.48249064208735e+32*cos(theta)**97 - 8.23069869520747e+33*cos(theta)**95 + 9.42309478823112e+34*cos(theta)**93 - 6.96234879171895e+35*cos(theta)**91 + 3.73178250027344e+36*cos(theta)**89 - 1.54641907630379e+37*cos(theta)**87 + 5.15610852446744e+37*cos(theta)**85 - 1.42141370133967e+38*cos(theta)**83 + 3.3040101268162e+38*cos(theta)**81 - 6.57151185444105e+38*cos(theta)**79 + 1.13110771081189e+39*cos(theta)**77 - 1.69985678573991e+39*cos(theta)**75 + 2.24623932401345e+39*cos(theta)**73 - 2.62477409671291e+39*cos(theta)**71 + 2.72454621150025e+39*cos(theta)**69 - 2.52141436377893e+39*cos(theta)**67 + 2.08639489457904e+39*cos(theta)**65 - 1.54713061701405e+39*cos(theta)**63 + 1.02983847819647e+39*cos(theta)**61 - 6.16085130794226e+38*cos(theta)**59 + 3.31484798361296e+38*cos(theta)**57 - 1.60463978824576e+38*cos(theta)**55 + 6.98794746494123e+37*cos(theta)**53 - 2.73640000190083e+37*cos(theta)**51 + 9.62723510602527e+36*cos(theta)**49 - 3.03936335159348e+36*cos(theta)**47 + 8.59642015455927e+35*cos(theta)**45 - 2.17380739540579e+35*cos(theta)**43 + 4.90246772740117e+34*cos(theta)**41 - 9.83131214592556e+33*cos(theta)**39 + 1.74700294967166e+33*cos(theta)**37 - 2.73959021540223e+32*cos(theta)**35 + 3.77327819019521e+31*cos(theta)**33 - 4.53928203331754e+30*cos(theta)**31 + 4.73903490231849e+29*cos(theta)**29 - 4.26145774161973e+28*cos(theta)**27 + 3.27159157329074e+27*cos(theta)**25 - 2.12211345294534e+26*cos(theta)**23 + 1.14868357636964e+25*cos(theta)**21 - 5.11175145237604e+23*cos(theta)**19 + 1.83636449234517e+22*cos(theta)**17 - 5.20628665747225e+20*cos(theta)**15 + 1.13180144727658e+19*cos(theta)**13 - 1.8168452950725e+17*cos(theta)**11 + 2.04599695391048e+15*cos(theta)**9 - 15016491404847.5*cos(theta)**7 + 64068736184.8432*cos(theta)**5 - 129825199.969287*cos(theta)**3 + 78777.4271658295*cos(theta))*cos(2*phi)

#@torch.jit.script
def Yl99_m3(theta, phi):
    return 5.71556711709373e-6*(1.0 - cos(theta)**2)**1.5*(3.37801592282473e+34*cos(theta)**96 - 7.8191637604471e+35*cos(theta)**94 + 8.76347815305494e+36*cos(theta)**92 - 6.33573740046425e+37*cos(theta)**90 + 3.32128642524336e+38*cos(theta)**88 - 1.3453845963843e+39*cos(theta)**86 + 4.38269224579733e+39*cos(theta)**84 - 1.17977337211193e+40*cos(theta)**82 + 2.67624820272112e+40*cos(theta)**80 - 5.19149436500843e+40*cos(theta)**78 + 8.70952937325158e+40*cos(theta)**76 - 1.27489258930493e+41*cos(theta)**74 + 1.63975470652982e+41*cos(theta)**72 - 1.86358960866617e+41*cos(theta)**70 + 1.87993688593517e+41*cos(theta)**68 - 1.68934762373188e+41*cos(theta)**66 + 1.35615668147638e+41*cos(theta)**64 - 9.74692288718852e+40*cos(theta)**62 + 6.28201471699846e+40*cos(theta)**60 - 3.63490227168594e+40*cos(theta)**58 + 1.88946335065939e+40*cos(theta)**56 - 8.8255188353517e+39*cos(theta)**54 + 3.70361215641885e+39*cos(theta)**52 - 1.39556400096942e+39*cos(theta)**50 + 4.71734520195238e+38*cos(theta)**48 - 1.42850077524894e+38*cos(theta)**46 + 3.86838906955167e+37*cos(theta)**44 - 9.34737180024491e+36*cos(theta)**42 + 2.01001176823448e+36*cos(theta)**40 - 3.83421173691097e+35*cos(theta)**38 + 6.46391091378516e+34*cos(theta)**36 - 9.58856575390782e+33*cos(theta)**34 + 1.24518180276442e+33*cos(theta)**32 - 1.40717743032844e+32*cos(theta)**30 + 1.37432012167236e+31*cos(theta)**28 - 1.15059359023733e+30*cos(theta)**26 + 8.17897893322685e+28*cos(theta)**24 - 4.88086094177429e+27*cos(theta)**22 + 2.41223551037625e+26*cos(theta)**20 - 9.71232775951448e+24*cos(theta)**18 + 3.1218196369868e+23*cos(theta)**16 - 7.80942998620837e+21*cos(theta)**14 + 1.47134188145955e+20*cos(theta)**12 - 1.99852982457975e+18*cos(theta)**10 + 1.84139725851943e+16*cos(theta)**8 - 105115439833933.0*cos(theta)**6 + 320343680924.216*cos(theta)**4 - 389475599.907861*cos(theta)**2 + 78777.4271658295)*cos(3*phi)

#@torch.jit.script
def Yl99_m4(theta, phi):
    return 5.74784568743144e-8*(1.0 - cos(theta)**2)**2*(3.24289528591174e+36*cos(theta)**95 - 7.35001393482027e+37*cos(theta)**93 + 8.06239990081055e+38*cos(theta)**91 - 5.70216366041782e+39*cos(theta)**89 + 2.92273205421416e+40*cos(theta)**87 - 1.15703075289049e+41*cos(theta)**85 + 3.68146148646976e+41*cos(theta)**83 - 9.67414165131782e+41*cos(theta)**81 + 2.14099856217689e+42*cos(theta)**79 - 4.04936560470658e+42*cos(theta)**77 + 6.6192423236712e+42*cos(theta)**75 - 9.43420516085648e+42*cos(theta)**73 + 1.18062338870147e+43*cos(theta)**71 - 1.30451272606632e+43*cos(theta)**69 + 1.27835708243592e+43*cos(theta)**67 - 1.11496943166304e+43*cos(theta)**65 + 8.67940276144882e+42*cos(theta)**63 - 6.04309219005688e+42*cos(theta)**61 + 3.76920883019908e+42*cos(theta)**59 - 2.10824331757784e+42*cos(theta)**57 + 1.05809947636926e+42*cos(theta)**55 - 4.76578017108992e+41*cos(theta)**53 + 1.9258783213378e+41*cos(theta)**51 - 6.97782000484711e+40*cos(theta)**49 + 2.26432569693714e+40*cos(theta)**47 - 6.5711035661451e+39*cos(theta)**45 + 1.70209119060274e+39*cos(theta)**43 - 3.92589615610286e+38*cos(theta)**41 + 8.04004707293793e+37*cos(theta)**39 - 1.45700046002617e+37*cos(theta)**37 + 2.32700792896266e+36*cos(theta)**35 - 3.26011235632866e+35*cos(theta)**33 + 3.98458176884614e+34*cos(theta)**31 - 4.22153229098531e+33*cos(theta)**29 + 3.84809634068262e+32*cos(theta)**27 - 2.99154333461705e+31*cos(theta)**25 + 1.96295494397444e+30*cos(theta)**23 - 1.07378940719034e+29*cos(theta)**21 + 4.82447102075251e+27*cos(theta)**19 - 1.74821899671261e+26*cos(theta)**17 + 4.99491141917887e+24*cos(theta)**15 - 1.09332019806917e+23*cos(theta)**13 + 1.76561025775146e+21*cos(theta)**11 - 1.99852982457975e+19*cos(theta)**9 + 1.47311780681554e+17*cos(theta)**7 - 630692639003596.0*cos(theta)**5 + 1281374723696.86*cos(theta)**3 - 778951199.815722*cos(theta))*cos(4*phi)

#@torch.jit.script
def Yl99_m5(theta, phi):
    return 5.782646282006e-10*(1.0 - cos(theta)**2)**2.5*(3.08075052161616e+38*cos(theta)**94 - 6.83551295938285e+39*cos(theta)**92 + 7.3367839097376e+40*cos(theta)**90 - 5.07492565777186e+41*cos(theta)**88 + 2.54277688716632e+42*cos(theta)**86 - 9.83476139956921e+42*cos(theta)**84 + 3.0556130337699e+43*cos(theta)**82 - 7.83605473756744e+43*cos(theta)**80 + 1.69138886411975e+44*cos(theta)**78 - 3.11801151562406e+44*cos(theta)**76 + 4.9644317427534e+44*cos(theta)**74 - 6.88696976742523e+44*cos(theta)**72 + 8.38242605978043e+44*cos(theta)**70 - 9.00113780985759e+44*cos(theta)**68 + 8.56499245232064e+44*cos(theta)**66 - 7.24730130580977e+44*cos(theta)**64 + 5.46802373971276e+44*cos(theta)**62 - 3.6862862359347e+44*cos(theta)**60 + 2.22383320981746e+44*cos(theta)**58 - 1.20169869101937e+44*cos(theta)**56 + 5.81954712003091e+43*cos(theta)**54 - 2.52586349067766e+43*cos(theta)**52 + 9.8219794388228e+42*cos(theta)**50 - 3.41913180237509e+42*cos(theta)**48 + 1.06423307756046e+42*cos(theta)**46 - 2.9569966047653e+41*cos(theta)**44 + 7.31899211959176e+40*cos(theta)**42 - 1.60961742400217e+40*cos(theta)**40 + 3.13561835844579e+39*cos(theta)**38 - 5.39090170209682e+38*cos(theta)**36 + 8.1445277513693e+37*cos(theta)**34 - 1.07583707758846e+37*cos(theta)**32 + 1.2352203483423e+36*cos(theta)**30 - 1.22424436438574e+35*cos(theta)**28 + 1.03898601198431e+34*cos(theta)**26 - 7.47885833654263e+32*cos(theta)**24 + 4.51479637114122e+31*cos(theta)**22 - 2.25495775509972e+30*cos(theta)**20 + 9.16649493942976e+28*cos(theta)**18 - 2.97197229441143e+27*cos(theta)**16 + 7.49236712876831e+25*cos(theta)**14 - 1.42131625748992e+24*cos(theta)**12 + 1.9421712835266e+22*cos(theta)**10 - 1.79867684212178e+20*cos(theta)**8 + 1.03118246477088e+18*cos(theta)**6 - 3.15346319501798e+15*cos(theta)**4 + 3844124171090.59*cos(theta)**2 - 778951199.815722)*cos(5*phi)

#@torch.jit.script
def Yl99_m6(theta, phi):
    return 5.82060397389043e-12*(1.0 - cos(theta)**2)**3*(2.89590549031919e+40*cos(theta)**93 - 6.28867192263222e+41*cos(theta)**91 + 6.60310551876384e+42*cos(theta)**89 - 4.46593457883924e+43*cos(theta)**87 + 2.18678812296303e+44*cos(theta)**85 - 8.26119957563813e+44*cos(theta)**83 + 2.50560268769132e+45*cos(theta)**81 - 6.26884379005395e+45*cos(theta)**79 + 1.3192833140134e+46*cos(theta)**77 - 2.36968875187429e+46*cos(theta)**75 + 3.67367948963751e+46*cos(theta)**73 - 4.95861823254617e+46*cos(theta)**71 + 5.8676982418463e+46*cos(theta)**69 - 6.12077371070316e+46*cos(theta)**67 + 5.65289501853162e+46*cos(theta)**65 - 4.63827283571825e+46*cos(theta)**63 + 3.39017471862191e+46*cos(theta)**61 - 2.21177174156082e+46*cos(theta)**59 + 1.28982326169412e+46*cos(theta)**57 - 6.72951266970847e+45*cos(theta)**55 + 3.14255544481669e+45*cos(theta)**53 - 1.31344901515238e+45*cos(theta)**51 + 4.9109897194114e+44*cos(theta)**49 - 1.64118326514004e+44*cos(theta)**47 + 4.8954721567781e+43*cos(theta)**45 - 1.30107850609673e+43*cos(theta)**43 + 3.07397669022854e+42*cos(theta)**41 - 6.43846969600869e+41*cos(theta)**39 + 1.1915349762094e+41*cos(theta)**37 - 1.94072461275486e+40*cos(theta)**35 + 2.76913943546556e+39*cos(theta)**33 - 3.44267864828306e+38*cos(theta)**31 + 3.70566104502691e+37*cos(theta)**29 - 3.42788422028007e+36*cos(theta)**27 + 2.7013636311592e+35*cos(theta)**25 - 1.79492600077023e+34*cos(theta)**23 + 9.93255201651068e+32*cos(theta)**21 - 4.50991551019944e+31*cos(theta)**19 + 1.64996908909736e+30*cos(theta)**17 - 4.75515567105829e+28*cos(theta)**15 + 1.04893139802756e+27*cos(theta)**13 - 1.70557950898791e+25*cos(theta)**11 + 1.9421712835266e+23*cos(theta)**9 - 1.43894147369742e+21*cos(theta)**7 + 6.18709478862528e+18*cos(theta)**5 - 1.26138527800719e+16*cos(theta)**3 + 7688248342181.18*cos(theta))*cos(6*phi)

#@torch.jit.script
def Yl99_m7(theta, phi):
    return 5.86237566076914e-14*(1.0 - cos(theta)**2)**3.5*(2.69319210599684e+42*cos(theta)**92 - 5.72269144959533e+43*cos(theta)**90 + 5.87676391169981e+44*cos(theta)**88 - 3.88536308359014e+45*cos(theta)**86 + 1.85876990451858e+46*cos(theta)**84 - 6.85679564777965e+46*cos(theta)**82 + 2.02953817702997e+47*cos(theta)**80 - 4.95238659414262e+47*cos(theta)**78 + 1.01584815179032e+48*cos(theta)**76 - 1.77726656390572e+48*cos(theta)**74 + 2.68178602743539e+48*cos(theta)**72 - 3.52061894510778e+48*cos(theta)**70 + 4.04871178687395e+48*cos(theta)**68 - 4.10091838617112e+48*cos(theta)**66 + 3.67438176204555e+48*cos(theta)**64 - 2.9221118865025e+48*cos(theta)**62 + 2.06800657835937e+48*cos(theta)**60 - 1.30494532752088e+48*cos(theta)**58 + 7.35199259165651e+47*cos(theta)**56 - 3.70123196833966e+47*cos(theta)**54 + 1.66555438575285e+47*cos(theta)**52 - 6.69858997727715e+46*cos(theta)**50 + 2.40638496251159e+46*cos(theta)**48 - 7.71356134615819e+45*cos(theta)**46 + 2.20296247055015e+45*cos(theta)**44 - 5.59463757621594e+44*cos(theta)**42 + 1.2603304429937e+44*cos(theta)**40 - 2.51100318144339e+43*cos(theta)**38 + 4.40867941197478e+42*cos(theta)**36 - 6.792536144642e+41*cos(theta)**34 + 9.13816013703636e+40*cos(theta)**32 - 1.06723038096775e+40*cos(theta)**30 + 1.0746417030578e+39*cos(theta)**28 - 9.2552873947562e+37*cos(theta)**26 + 6.75340907789799e+36*cos(theta)**24 - 4.12832980177153e+35*cos(theta)**22 + 2.08583592346724e+34*cos(theta)**20 - 8.56883946937894e+32*cos(theta)**18 + 2.80494745146551e+31*cos(theta)**16 - 7.13273350658743e+29*cos(theta)**14 + 1.36361081743583e+28*cos(theta)**12 - 1.8761374598867e+26*cos(theta)**10 + 1.74795415517394e+24*cos(theta)**8 - 1.0072590315882e+22*cos(theta)**6 + 3.09354739431264e+19*cos(theta)**4 - 3.78415583402158e+16*cos(theta)**2 + 7688248342181.18)*cos(7*phi)

#@torch.jit.script
def Yl99_m8(theta, phi):
    return 5.90864424261924e-16*(1.0 - cos(theta)**2)**4*(2.4777367375171e+44*cos(theta)**91 - 5.15042230463579e+45*cos(theta)**89 + 5.17155224229584e+46*cos(theta)**87 - 3.34141225188752e+47*cos(theta)**85 + 1.56136671979561e+48*cos(theta)**83 - 5.62257243117931e+48*cos(theta)**81 + 1.62363054162397e+49*cos(theta)**79 - 3.86286154343124e+49*cos(theta)**77 + 7.72044595360643e+49*cos(theta)**75 - 1.31517725729023e+50*cos(theta)**73 + 1.93088593975348e+50*cos(theta)**71 - 2.46443326157545e+50*cos(theta)**69 + 2.75312401507428e+50*cos(theta)**67 - 2.70660613487294e+50*cos(theta)**65 + 2.35160432770915e+50*cos(theta)**63 - 1.81170936963155e+50*cos(theta)**61 + 1.24080394701562e+50*cos(theta)**59 - 7.56868289962112e+49*cos(theta)**57 + 4.11711585132764e+49*cos(theta)**55 - 1.99866526290342e+49*cos(theta)**53 + 8.66088280591481e+48*cos(theta)**51 - 3.34929498863857e+48*cos(theta)**49 + 1.15506478200556e+48*cos(theta)**47 - 3.54823821923277e+47*cos(theta)**45 + 9.69303487042064e+46*cos(theta)**43 - 2.3497477820107e+46*cos(theta)**41 + 5.04132177197481e+45*cos(theta)**39 - 9.54181208948488e+44*cos(theta)**37 + 1.58712458831092e+44*cos(theta)**35 - 2.30946228917828e+43*cos(theta)**33 + 2.92421124385163e+42*cos(theta)**31 - 3.20169114290325e+41*cos(theta)**29 + 3.00899676856185e+40*cos(theta)**27 - 2.40637472263661e+39*cos(theta)**25 + 1.62081817869552e+38*cos(theta)**23 - 9.08232556389737e+36*cos(theta)**21 + 4.17167184693449e+35*cos(theta)**19 - 1.54239110448821e+34*cos(theta)**17 + 4.48791592234481e+32*cos(theta)**15 - 9.98582690922241e+30*cos(theta)**13 + 1.636332980923e+29*cos(theta)**11 - 1.8761374598867e+27*cos(theta)**9 + 1.39836332413915e+25*cos(theta)**7 - 6.04355418952917e+22*cos(theta)**5 + 1.23741895772506e+20*cos(theta)**3 - 7.56831166804315e+16*cos(theta))*cos(8*phi)

#@torch.jit.script
def Yl99_m9(theta, phi):
    return 5.96012362729694e-18*(1.0 - cos(theta)**2)**4.5*(2.25474043114056e+46*cos(theta)**90 - 4.58387585112586e+47*cos(theta)**88 + 4.49925045079738e+48*cos(theta)**86 - 2.84020041410439e+49*cos(theta)**84 + 1.29593437743035e+50*cos(theta)**82 - 4.55428366925524e+50*cos(theta)**80 + 1.28266812788294e+51*cos(theta)**78 - 2.97440338844206e+51*cos(theta)**76 + 5.79033446520482e+51*cos(theta)**74 - 9.60079397821868e+51*cos(theta)**72 + 1.37092901722497e+52*cos(theta)**70 - 1.70045895048706e+52*cos(theta)**68 + 1.84459309009977e+52*cos(theta)**66 - 1.75929398766741e+52*cos(theta)**64 + 1.48151072645677e+52*cos(theta)**62 - 1.10514271547524e+52*cos(theta)**60 + 7.32074328739215e+51*cos(theta)**58 - 4.31414925278404e+51*cos(theta)**56 + 2.2644137182302e+51*cos(theta)**54 - 1.05929258933881e+51*cos(theta)**52 + 4.41705023101655e+50*cos(theta)**50 - 1.6411545444329e+50*cos(theta)**48 + 5.42880447542614e+49*cos(theta)**46 - 1.59670719865475e+49*cos(theta)**44 + 4.16800499428088e+48*cos(theta)**42 - 9.63396590624385e+47*cos(theta)**40 + 1.96611549107017e+47*cos(theta)**38 - 3.53047047310941e+46*cos(theta)**36 + 5.55493605908823e+45*cos(theta)**34 - 7.62122555428832e+44*cos(theta)**32 + 9.06505485594007e+43*cos(theta)**30 - 9.28490431441942e+42*cos(theta)**28 + 8.12429127511699e+41*cos(theta)**26 - 6.01593680659153e+40*cos(theta)**24 + 3.72788181099969e+39*cos(theta)**22 - 1.90728836841845e+38*cos(theta)**20 + 7.92617650917552e+36*cos(theta)**18 - 2.62206487762996e+35*cos(theta)**16 + 6.73187388351722e+33*cos(theta)**14 - 1.29815749819891e+32*cos(theta)**12 + 1.7999662790153e+30*cos(theta)**10 - 1.68852371389803e+28*cos(theta)**8 + 9.78854326897408e+25*cos(theta)**6 - 3.02177709476459e+23*cos(theta)**4 + 3.71225687317517e+20*cos(theta)**2 - 7.56831166804315e+16)*cos(9*phi)

#@torch.jit.script
def Yl99_m10(theta, phi):
    return 6.01756464472791e-20*(1.0 - cos(theta)**2)**5*(2.0292663880265e+48*cos(theta)**89 - 4.03381074899075e+49*cos(theta)**87 + 3.86935538768575e+50*cos(theta)**85 - 2.38576834784769e+51*cos(theta)**83 + 1.06266618949289e+52*cos(theta)**81 - 3.64342693540419e+52*cos(theta)**79 + 1.00048113974869e+53*cos(theta)**77 - 2.26054657521596e+53*cos(theta)**75 + 4.28484750425157e+53*cos(theta)**73 - 6.91257166431745e+53*cos(theta)**71 + 9.59650312057478e+53*cos(theta)**69 - 1.1563120863312e+54*cos(theta)**67 + 1.21743143946585e+54*cos(theta)**65 - 1.12594815210714e+54*cos(theta)**63 + 9.18536650403195e+53*cos(theta)**61 - 6.63085629285147e+53*cos(theta)**59 + 4.24603110668745e+53*cos(theta)**57 - 2.41592358155906e+53*cos(theta)**55 + 1.22278340784431e+53*cos(theta)**53 - 5.50832146456182e+52*cos(theta)**51 + 2.20852511550828e+52*cos(theta)**49 - 7.87754181327793e+51*cos(theta)**47 + 2.49725005869602e+51*cos(theta)**45 - 7.02551167408088e+50*cos(theta)**43 + 1.75056209759797e+50*cos(theta)**41 - 3.85358636249754e+49*cos(theta)**39 + 7.47123886606666e+48*cos(theta)**37 - 1.27096937031939e+48*cos(theta)**35 + 1.88867826009e+47*cos(theta)**33 - 2.43879217737226e+46*cos(theta)**31 + 2.71951645678202e+45*cos(theta)**29 - 2.59977320803744e+44*cos(theta)**27 + 2.11231573153042e+43*cos(theta)**25 - 1.44382483358197e+42*cos(theta)**23 + 8.20133998419932e+40*cos(theta)**21 - 3.81457673683689e+39*cos(theta)**19 + 1.42671177165159e+38*cos(theta)**17 - 4.19530380420793e+36*cos(theta)**15 + 9.42462343692411e+34*cos(theta)**13 - 1.5577889978387e+33*cos(theta)**11 + 1.7999662790153e+31*cos(theta)**9 - 1.35081897111842e+29*cos(theta)**7 + 5.87312596138445e+26*cos(theta)**5 - 1.20871083790583e+24*cos(theta)**3 + 7.42451374635033e+20*cos(theta))*cos(10*phi)

#@torch.jit.script
def Yl99_m11(theta, phi):
    return 6.08176196963013e-22*(1.0 - cos(theta)**2)**5.5*(1.80604708534359e+50*cos(theta)**88 - 3.50941535162195e+51*cos(theta)**86 + 3.28895207953288e+52*cos(theta)**84 - 1.98018772871358e+53*cos(theta)**82 + 8.60759613489241e+53*cos(theta)**80 - 2.87830727896931e+54*cos(theta)**78 + 7.70370477606493e+54*cos(theta)**76 - 1.69540993141197e+55*cos(theta)**74 + 3.12793867810365e+55*cos(theta)**72 - 4.90792588166539e+55*cos(theta)**70 + 6.6215871531966e+55*cos(theta)**68 - 7.74729097841903e+55*cos(theta)**66 + 7.91330435652801e+55*cos(theta)**64 - 7.093473358275e+55*cos(theta)**62 + 5.60307356745949e+55*cos(theta)**60 - 3.91220521278237e+55*cos(theta)**58 + 2.42023773081185e+55*cos(theta)**56 - 1.32875796985748e+55*cos(theta)**54 + 6.48075206157485e+54*cos(theta)**52 - 2.80924394692653e+54*cos(theta)**50 + 1.08217730659906e+54*cos(theta)**48 - 3.70244465224063e+53*cos(theta)**46 + 1.12376252641321e+53*cos(theta)**44 - 3.02097001985478e+52*cos(theta)**42 + 7.17730460015167e+51*cos(theta)**40 - 1.50289868137404e+51*cos(theta)**38 + 2.76435838044466e+50*cos(theta)**36 - 4.44839279611785e+49*cos(theta)**34 + 6.23263825829699e+48*cos(theta)**32 - 7.56025574985401e+47*cos(theta)**30 + 7.88659772466786e+46*cos(theta)**28 - 7.01938766170108e+45*cos(theta)**26 + 5.28078932882605e+44*cos(theta)**24 - 3.32079711723853e+43*cos(theta)**22 + 1.72228139668186e+42*cos(theta)**20 - 7.2476957999901e+40*cos(theta)**18 + 2.42541001180771e+39*cos(theta)**16 - 6.2929557063119e+37*cos(theta)**14 + 1.22520104680013e+36*cos(theta)**12 - 1.71356789762256e+34*cos(theta)**10 + 1.61996965111377e+32*cos(theta)**8 - 9.45573279782896e+29*cos(theta)**6 + 2.93656298069222e+27*cos(theta)**4 - 3.6261325137175e+24*cos(theta)**2 + 7.42451374635033e+20)*cos(11*phi)

#@torch.jit.script
def Yl99_m12(theta, phi):
    return 6.15356217585626e-24*(1.0 - cos(theta)**2)**6*(1.58932143510236e+52*cos(theta)**87 - 3.01809720239488e+53*cos(theta)**85 + 2.76271974680762e+54*cos(theta)**83 - 1.62375393754514e+55*cos(theta)**81 + 6.88607690791393e+55*cos(theta)**79 - 2.24507967759606e+56*cos(theta)**77 + 5.85481562980935e+56*cos(theta)**75 - 1.25460334924486e+57*cos(theta)**73 + 2.25211584823463e+57*cos(theta)**71 - 3.43554811716577e+57*cos(theta)**69 + 4.50267926417369e+57*cos(theta)**67 - 5.11321204575656e+57*cos(theta)**65 + 5.06451478817793e+57*cos(theta)**63 - 4.3979534821305e+57*cos(theta)**61 + 3.36184414047569e+57*cos(theta)**59 - 2.26907902341377e+57*cos(theta)**57 + 1.35533312925463e+57*cos(theta)**55 - 7.17529303723041e+56*cos(theta)**53 + 3.36999107201892e+56*cos(theta)**51 - 1.40462197346326e+56*cos(theta)**49 + 5.19445107167546e+55*cos(theta)**47 - 1.70312454003069e+55*cos(theta)**45 + 4.94455511621813e+54*cos(theta)**43 - 1.26880740833901e+54*cos(theta)**41 + 2.87092184006067e+53*cos(theta)**39 - 5.71101498922136e+52*cos(theta)**37 + 9.95169016960079e+51*cos(theta)**35 - 1.51245355068007e+51*cos(theta)**33 + 1.99444424265504e+50*cos(theta)**31 - 2.2680767249562e+49*cos(theta)**29 + 2.208247362907e+48*cos(theta)**27 - 1.82504079204228e+47*cos(theta)**25 + 1.26738943891825e+46*cos(theta)**23 - 7.30575365792476e+44*cos(theta)**21 + 3.44456279336371e+43*cos(theta)**19 - 1.30458524399822e+42*cos(theta)**17 + 3.88065601889234e+40*cos(theta)**15 - 8.81013798883666e+38*cos(theta)**13 + 1.47024125616016e+37*cos(theta)**11 - 1.71356789762256e+35*cos(theta)**9 + 1.29597572089102e+33*cos(theta)**7 - 5.67343967869738e+30*cos(theta)**5 + 1.17462519227689e+28*cos(theta)**3 - 7.25226502743501e+24*cos(theta))*cos(12*phi)

#@torch.jit.script
def Yl99_m13(theta, phi):
    return 6.23387307326385e-26*(1.0 - cos(theta)**2)**6.5*(1.38270964853905e+54*cos(theta)**86 - 2.56538262203565e+55*cos(theta)**84 + 2.29305738985033e+56*cos(theta)**82 - 1.31524068941156e+57*cos(theta)**80 + 5.440000757252e+57*cos(theta)**78 - 1.72871135174897e+58*cos(theta)**76 + 4.39111172235701e+58*cos(theta)**74 - 9.15860444948748e+58*cos(theta)**72 + 1.59900225224658e+59*cos(theta)**70 - 2.37052820084438e+59*cos(theta)**68 + 3.01679510699637e+59*cos(theta)**66 - 3.32358782974177e+59*cos(theta)**64 + 3.19064431655209e+59*cos(theta)**62 - 2.6827516240996e+59*cos(theta)**60 + 1.98348804288066e+59*cos(theta)**58 - 1.29337504334585e+59*cos(theta)**56 + 7.45433221090049e+58*cos(theta)**54 - 3.80290530973212e+58*cos(theta)**52 + 1.71869544672965e+58*cos(theta)**50 - 6.88264766996999e+57*cos(theta)**48 + 2.44139200368747e+57*cos(theta)**46 - 7.66406043013809e+56*cos(theta)**44 + 2.12615869997379e+56*cos(theta)**42 - 5.20211037418993e+55*cos(theta)**40 + 1.11965951762366e+55*cos(theta)**38 - 2.1130755460119e+54*cos(theta)**36 + 3.48309155936028e+53*cos(theta)**34 - 4.99109671724423e+52*cos(theta)**32 + 6.18277715223061e+51*cos(theta)**30 - 6.57742250237299e+50*cos(theta)**28 + 5.9622678798489e+49*cos(theta)**26 - 4.5626019801057e+48*cos(theta)**24 + 2.91499570951198e+47*cos(theta)**22 - 1.5342082681642e+46*cos(theta)**20 + 6.54466930739106e+44*cos(theta)**18 - 2.21779491479697e+43*cos(theta)**16 + 5.8209840283385e+41*cos(theta)**14 - 1.14531793854877e+40*cos(theta)**12 + 1.61726538177618e+38*cos(theta)**10 - 1.54221110786031e+36*cos(theta)**8 + 9.07183004623711e+33*cos(theta)**6 - 2.83671983934869e+31*cos(theta)**4 + 3.52387557683067e+28*cos(theta)**2 - 7.25226502743501e+24)*cos(13*phi)

#@torch.jit.script
def Yl99_m14(theta, phi):
    return 6.32367451143506e-28*(1.0 - cos(theta)**2)**7*(1.18913029774358e+56*cos(theta)**85 - 2.15492140250995e+57*cos(theta)**83 + 1.88030705967727e+58*cos(theta)**81 - 1.05219255152925e+59*cos(theta)**79 + 4.24320059065656e+59*cos(theta)**77 - 1.31382062732922e+60*cos(theta)**75 + 3.24942267454419e+60*cos(theta)**73 - 6.59419520363098e+60*cos(theta)**71 + 1.11930157657261e+61*cos(theta)**69 - 1.61195917657418e+61*cos(theta)**67 + 1.99108477061761e+61*cos(theta)**65 - 2.12709621103473e+61*cos(theta)**63 + 1.9781994762623e+61*cos(theta)**61 - 1.60965097445976e+61*cos(theta)**59 + 1.15042306487078e+61*cos(theta)**57 - 7.24290024273676e+60*cos(theta)**55 + 4.02533939388626e+60*cos(theta)**53 - 1.9775107610607e+60*cos(theta)**51 + 8.59347723364824e+59*cos(theta)**49 - 3.3036708815856e+59*cos(theta)**47 + 1.12304032169624e+59*cos(theta)**45 - 3.37218658926076e+58*cos(theta)**43 + 8.92986653988993e+57*cos(theta)**41 - 2.08084414967597e+57*cos(theta)**39 + 4.25470616696991e+56*cos(theta)**37 - 7.60707196564285e+55*cos(theta)**35 + 1.18425113018249e+55*cos(theta)**33 - 1.59715094951815e+54*cos(theta)**31 + 1.85483314566918e+53*cos(theta)**29 - 1.84167830066444e+52*cos(theta)**27 + 1.55018964876071e+51*cos(theta)**25 - 1.09502447522537e+50*cos(theta)**23 + 6.41299056092635e+48*cos(theta)**21 - 3.0684165363284e+47*cos(theta)**19 + 1.17804047533039e+46*cos(theta)**17 - 3.54847186367515e+44*cos(theta)**15 + 8.14937763967391e+42*cos(theta)**13 - 1.37438152625852e+41*cos(theta)**11 + 1.61726538177618e+39*cos(theta)**9 - 1.23376888628825e+37*cos(theta)**7 + 5.44309802774226e+34*cos(theta)**5 - 1.13468793573948e+32*cos(theta)**3 + 7.04775115366134e+28*cos(theta))*cos(14*phi)

#@torch.jit.script
def Yl99_m15(theta, phi):
    return 6.4240308747423e-30*(1.0 - cos(theta)**2)**7.5*(1.01076075308205e+58*cos(theta)**84 - 1.78858476408325e+59*cos(theta)**82 + 1.52304871833859e+60*cos(theta)**80 - 8.31232115708106e+60*cos(theta)**78 + 3.26726445480555e+61*cos(theta)**76 - 9.85365470496913e+61*cos(theta)**74 + 2.37207855241726e+62*cos(theta)**72 - 4.681878594578e+62*cos(theta)**70 + 7.723180878351e+62*cos(theta)**68 - 1.0800126483047e+63*cos(theta)**66 + 1.29420510090144e+63*cos(theta)**64 - 1.34007061295188e+63*cos(theta)**62 + 1.20670168052e+63*cos(theta)**60 - 9.4969407493126e+62*cos(theta)**58 + 6.55741146976346e+62*cos(theta)**56 - 3.98359513350522e+62*cos(theta)**54 + 2.13342987875972e+62*cos(theta)**52 - 1.00853048814096e+62*cos(theta)**50 + 4.21080384448764e+61*cos(theta)**48 - 1.55272531434523e+61*cos(theta)**46 + 5.05368144763306e+60*cos(theta)**44 - 1.45004023338213e+60*cos(theta)**42 + 3.66124528135487e+59*cos(theta)**40 - 8.11529218373629e+58*cos(theta)**38 + 1.57424128177887e+58*cos(theta)**36 - 2.662475187975e+57*cos(theta)**34 + 3.90802872960223e+56*cos(theta)**32 - 4.95116794350628e+55*cos(theta)**30 + 5.37901612244063e+54*cos(theta)**28 - 4.97253141179398e+53*cos(theta)**26 + 3.87547412190178e+52*cos(theta)**24 - 2.51855629301835e+51*cos(theta)**22 + 1.34672801779453e+50*cos(theta)**20 - 5.82999141902395e+48*cos(theta)**18 + 2.00266880806166e+47*cos(theta)**16 - 5.32270779551273e+45*cos(theta)**14 + 1.05941909315761e+44*cos(theta)**12 - 1.51181967888437e+42*cos(theta)**10 + 1.45553884359856e+40*cos(theta)**8 - 8.63638220401773e+37*cos(theta)**6 + 2.72154901387113e+35*cos(theta)**4 - 3.40406380721843e+32*cos(theta)**2 + 7.04775115366134e+28)*cos(15*phi)

#@torch.jit.script
def Yl99_m16(theta, phi):
    return 6.53610554166651e-32*(1.0 - cos(theta)**2)**8*(8.49039032588918e+59*cos(theta)**83 - 1.46663950654827e+61*cos(theta)**81 + 1.21843897467087e+62*cos(theta)**79 - 6.48361050252323e+62*cos(theta)**77 + 2.48312098565222e+63*cos(theta)**75 - 7.29170448167715e+63*cos(theta)**73 + 1.70789655774042e+64*cos(theta)**71 - 3.2773150162046e+64*cos(theta)**69 + 5.25176299727868e+64*cos(theta)**67 - 7.12808347881103e+64*cos(theta)**65 + 8.28291264576924e+64*cos(theta)**63 - 8.30843780030165e+64*cos(theta)**61 + 7.24021008312001e+64*cos(theta)**59 - 5.50822563460131e+64*cos(theta)**57 + 3.67215042306754e+64*cos(theta)**55 - 2.15114137209282e+64*cos(theta)**53 + 1.10938353695505e+64*cos(theta)**51 - 5.04265244070479e+63*cos(theta)**49 + 2.02118584535407e+63*cos(theta)**47 - 7.14253644598806e+62*cos(theta)**45 + 2.22361983695855e+62*cos(theta)**43 - 6.09016898020494e+61*cos(theta)**41 + 1.46449811254195e+61*cos(theta)**39 - 3.08381102981979e+60*cos(theta)**37 + 5.66726861440392e+59*cos(theta)**35 - 9.05241563911499e+58*cos(theta)**33 + 1.25056919347271e+58*cos(theta)**31 - 1.48535038305188e+57*cos(theta)**29 + 1.50612451428338e+56*cos(theta)**27 - 1.29285816706644e+55*cos(theta)**25 + 9.30113789256428e+53*cos(theta)**23 - 5.54082384464037e+52*cos(theta)**21 + 2.69345603558907e+51*cos(theta)**19 - 1.04939845542431e+50*cos(theta)**17 + 3.20427009289866e+48*cos(theta)**15 - 7.45179091371782e+46*cos(theta)**13 + 1.27130291178913e+45*cos(theta)**11 - 1.51181967888437e+43*cos(theta)**9 + 1.16443107487885e+41*cos(theta)**7 - 5.18182932241064e+38*cos(theta)**5 + 1.08861960554845e+36*cos(theta)**3 - 6.80812761443685e+32*cos(theta))*cos(16*phi)

#@torch.jit.script
def Yl99_m17(theta, phi):
    return 6.66117763977302e-34*(1.0 - cos(theta)**2)**8.5*(7.04702397048802e+61*cos(theta)**82 - 1.1879780003041e+63*cos(theta)**80 + 9.62566789989987e+63*cos(theta)**78 - 4.99238008694288e+64*cos(theta)**76 + 1.86234073923917e+65*cos(theta)**74 - 5.32294427162432e+65*cos(theta)**72 + 1.2126065559957e+66*cos(theta)**70 - 2.26134736118117e+66*cos(theta)**68 + 3.51868120817672e+66*cos(theta)**66 - 4.63325426122717e+66*cos(theta)**64 + 5.21823496683462e+66*cos(theta)**62 - 5.06814705818401e+66*cos(theta)**60 + 4.27172394904081e+66*cos(theta)**58 - 3.13968861172275e+66*cos(theta)**56 + 2.01968273268715e+66*cos(theta)**54 - 1.14010492720919e+66*cos(theta)**52 + 5.65785603847077e+65*cos(theta)**50 - 2.47089969594535e+65*cos(theta)**48 + 9.49957347316412e+64*cos(theta)**46 - 3.21414140069463e+64*cos(theta)**44 + 9.56156529892175e+63*cos(theta)**42 - 2.49696928188402e+63*cos(theta)**40 + 5.7115426389136e+62*cos(theta)**38 - 1.14101008103332e+62*cos(theta)**36 + 1.98354401504137e+61*cos(theta)**34 - 2.98729716090795e+60*cos(theta)**32 + 3.87676449976541e+59*cos(theta)**30 - 4.30751611085046e+58*cos(theta)**28 + 4.06653618856512e+57*cos(theta)**26 - 3.23214541766609e+56*cos(theta)**24 + 2.13926171528979e+55*cos(theta)**22 - 1.16357300737448e+54*cos(theta)**20 + 5.11756646761923e+52*cos(theta)**18 - 1.78397737422133e+51*cos(theta)**16 + 4.80640513934799e+49*cos(theta)**14 - 9.68732818783317e+47*cos(theta)**12 + 1.39843320296804e+46*cos(theta)**10 - 1.36063771099593e+44*cos(theta)**8 + 8.15101752415193e+41*cos(theta)**6 - 2.59091466120532e+39*cos(theta)**4 + 3.26585881664536e+36*cos(theta)**2 - 6.80812761443685e+32)*cos(17*phi)

#@torch.jit.script
def Yl99_m18(theta, phi):
    return 6.8006614986693e-36*(1.0 - cos(theta)**2)**9*(5.77855965580018e+63*cos(theta)**81 - 9.50382400243278e+64*cos(theta)**79 + 7.5080209619219e+65*cos(theta)**77 - 3.79420886607659e+66*cos(theta)**75 + 1.37813214703698e+67*cos(theta)**73 - 3.83251987556951e+67*cos(theta)**71 + 8.48824589196991e+67*cos(theta)**69 - 1.5377162056032e+68*cos(theta)**67 + 2.32232959739663e+68*cos(theta)**65 - 2.96528272718539e+68*cos(theta)**63 + 3.23530567943746e+68*cos(theta)**61 - 3.04088823491041e+68*cos(theta)**59 + 2.47759989044367e+68*cos(theta)**57 - 1.75822562256474e+68*cos(theta)**55 + 1.09062867565106e+68*cos(theta)**53 - 5.92854562148781e+67*cos(theta)**51 + 2.82892801923539e+67*cos(theta)**49 - 1.18603185405377e+67*cos(theta)**47 + 4.36980379765549e+66*cos(theta)**45 - 1.41422221630564e+66*cos(theta)**43 + 4.01585742554713e+65*cos(theta)**41 - 9.98787712753609e+64*cos(theta)**39 + 2.17038620278717e+64*cos(theta)**37 - 4.10763629171996e+63*cos(theta)**35 + 6.74404965114066e+62*cos(theta)**33 - 9.55935091490543e+61*cos(theta)**31 + 1.16302934992962e+61*cos(theta)**29 - 1.20610451103813e+60*cos(theta)**27 + 1.05729940902693e+59*cos(theta)**25 - 7.75714900239861e+57*cos(theta)**23 + 4.70637577363753e+56*cos(theta)**21 - 2.32714601474895e+55*cos(theta)**19 + 9.21161964171461e+53*cos(theta)**17 - 2.85436379875413e+52*cos(theta)**15 + 6.72896719508719e+50*cos(theta)**13 - 1.16247938253998e+49*cos(theta)**11 + 1.39843320296804e+47*cos(theta)**9 - 1.08851016879675e+45*cos(theta)**7 + 4.89061051449116e+42*cos(theta)**5 - 1.03636586448213e+40*cos(theta)**3 + 6.53171763329072e+36*cos(theta))*cos(18*phi)

#@torch.jit.script
def Yl99_m19(theta, phi):
    return 6.95612928954815e-38*(1.0 - cos(theta)**2)**9.5*(4.68063332119814e+65*cos(theta)**80 - 7.5080209619219e+66*cos(theta)**78 + 5.78117614067986e+67*cos(theta)**76 - 2.84565664955744e+68*cos(theta)**74 + 1.006036467337e+69*cos(theta)**72 - 2.72108911165435e+69*cos(theta)**70 + 5.85688966545924e+69*cos(theta)**68 - 1.03026985775414e+70*cos(theta)**66 + 1.50951423830781e+70*cos(theta)**64 - 1.86812811812679e+70*cos(theta)**62 + 1.97353646445685e+70*cos(theta)**60 - 1.79412405859714e+70*cos(theta)**58 + 1.41223193755289e+70*cos(theta)**56 - 9.67024092410606e+69*cos(theta)**54 + 5.78033198095061e+69*cos(theta)**52 - 3.02355826695878e+69*cos(theta)**50 + 1.38617472942534e+69*cos(theta)**48 - 5.5743497140527e+68*cos(theta)**46 + 1.96641170894497e+68*cos(theta)**44 - 6.08115553011423e+67*cos(theta)**42 + 1.64650154447433e+67*cos(theta)**40 - 3.89527207973908e+66*cos(theta)**38 + 8.03042895031252e+65*cos(theta)**36 - 1.43767270210199e+65*cos(theta)**34 + 2.22553638487642e+64*cos(theta)**32 - 2.96339878362068e+63*cos(theta)**30 + 3.37278511479591e+62*cos(theta)**28 - 3.25648217980295e+61*cos(theta)**26 + 2.64324852256733e+60*cos(theta)**24 - 1.78414427055168e+59*cos(theta)**22 + 9.88338912463881e+57*cos(theta)**20 - 4.42157742802301e+56*cos(theta)**18 + 1.56597533909148e+55*cos(theta)**16 - 4.28154569813119e+53*cos(theta)**14 + 8.74765735361335e+51*cos(theta)**12 - 1.27872732079398e+50*cos(theta)**10 + 1.25858988267124e+48*cos(theta)**8 - 7.61957118157722e+45*cos(theta)**6 + 2.44530525724558e+43*cos(theta)**4 - 3.10909759344638e+40*cos(theta)**2 + 6.53171763329072e+36)*cos(19*phi)

#@torch.jit.script
def Yl99_m20(theta, phi):
    return 7.12933744526927e-40*(1.0 - cos(theta)**2)**10*(3.74450665695852e+67*cos(theta)**79 - 5.85625635029908e+68*cos(theta)**77 + 4.39369386691669e+69*cos(theta)**75 - 2.10578592067251e+70*cos(theta)**73 + 7.24346256482638e+70*cos(theta)**71 - 1.90476237815805e+71*cos(theta)**69 + 3.98268497251228e+71*cos(theta)**67 - 6.79978106117734e+71*cos(theta)**65 + 9.66089112516999e+71*cos(theta)**63 - 1.15823943323861e+72*cos(theta)**61 + 1.18412187867411e+72*cos(theta)**59 - 1.04059195398634e+72*cos(theta)**57 + 7.90849885029619e+71*cos(theta)**55 - 5.22193009901727e+71*cos(theta)**53 + 3.00577263009432e+71*cos(theta)**51 - 1.51177913347939e+71*cos(theta)**49 + 6.65363870124163e+70*cos(theta)**47 - 2.56420086846424e+70*cos(theta)**45 + 8.65221151935788e+69*cos(theta)**43 - 2.55408532264798e+69*cos(theta)**41 + 6.5860061778973e+68*cos(theta)**39 - 1.48020339030085e+68*cos(theta)**37 + 2.89095442211251e+67*cos(theta)**35 - 4.88808718714675e+66*cos(theta)**33 + 7.12171643160454e+65*cos(theta)**31 - 8.89019635086205e+64*cos(theta)**29 + 9.44379832142855e+63*cos(theta)**27 - 8.46685366748766e+62*cos(theta)**25 + 6.34379645416159e+61*cos(theta)**23 - 3.9251173952137e+60*cos(theta)**21 + 1.97667782492776e+59*cos(theta)**19 - 7.95883937044142e+57*cos(theta)**17 + 2.50556054254637e+56*cos(theta)**15 - 5.99416397738367e+54*cos(theta)**13 + 1.0497188824336e+53*cos(theta)**11 - 1.27872732079398e+51*cos(theta)**9 + 1.00687190613699e+49*cos(theta)**7 - 4.57174270894633e+46*cos(theta)**5 + 9.78122102898232e+43*cos(theta)**3 - 6.21819518689276e+40*cos(theta))*cos(20*phi)

#@torch.jit.script
def Yl99_m21(theta, phi):
    return 7.32225758404669e-42*(1.0 - cos(theta)**2)**10.5*(2.95816025899723e+69*cos(theta)**78 - 4.50931738973029e+70*cos(theta)**76 + 3.29527040018752e+71*cos(theta)**74 - 1.53722372209093e+72*cos(theta)**72 + 5.14285842102673e+72*cos(theta)**70 - 1.31428604092905e+73*cos(theta)**68 + 2.66839893158323e+73*cos(theta)**66 - 4.41985768976527e+73*cos(theta)**64 + 6.08636140885709e+73*cos(theta)**62 - 7.06526054275553e+73*cos(theta)**60 + 6.98631908417726e+73*cos(theta)**58 - 5.93137413772214e+73*cos(theta)**56 + 4.3496743676629e+73*cos(theta)**54 - 2.76762295247915e+73*cos(theta)**52 + 1.5329440413481e+73*cos(theta)**50 - 7.40771775404902e+72*cos(theta)**48 + 3.12721018958357e+72*cos(theta)**46 - 1.15389039080891e+72*cos(theta)**44 + 3.72045095332389e+71*cos(theta)**42 - 1.04717498228567e+71*cos(theta)**40 + 2.56854240937995e+70*cos(theta)**38 - 5.47675254411314e+69*cos(theta)**36 + 1.01183404773938e+69*cos(theta)**34 - 1.61306877175843e+68*cos(theta)**32 + 2.20773209379741e+67*cos(theta)**30 - 2.57815694174999e+66*cos(theta)**28 + 2.54982554678571e+65*cos(theta)**26 - 2.11671341687192e+64*cos(theta)**24 + 1.45907318445716e+63*cos(theta)**22 - 8.24274652994877e+61*cos(theta)**20 + 3.75568786736275e+60*cos(theta)**18 - 1.35300269297504e+59*cos(theta)**16 + 3.75834081381956e+57*cos(theta)**14 - 7.79241317059877e+55*cos(theta)**12 + 1.15469077067696e+54*cos(theta)**10 - 1.15085458871458e+52*cos(theta)**8 + 7.04810334295893e+49*cos(theta)**6 - 2.28587135447317e+47*cos(theta)**4 + 2.93436630869469e+44*cos(theta)**2 - 6.21819518689276e+40)*cos(21*phi)

#@torch.jit.script
def Yl99_m22(theta, phi):
    return 7.53711281864287e-44*(1.0 - cos(theta)**2)**11*(2.30736500201784e+71*cos(theta)**77 - 3.42708121619502e+72*cos(theta)**75 + 2.43850009613877e+73*cos(theta)**73 - 1.10680107990547e+74*cos(theta)**71 + 3.60000089471871e+74*cos(theta)**69 - 8.93714507831756e+74*cos(theta)**67 + 1.76114329484493e+75*cos(theta)**65 - 2.82870892144977e+75*cos(theta)**63 + 3.7735440734914e+75*cos(theta)**61 - 4.23915632565332e+75*cos(theta)**59 + 4.05206506882281e+75*cos(theta)**57 - 3.3215695171244e+75*cos(theta)**55 + 2.34882415853797e+75*cos(theta)**53 - 1.43916393528916e+75*cos(theta)**51 + 7.66472020674051e+74*cos(theta)**49 - 3.55570452194353e+74*cos(theta)**47 + 1.43851668720844e+74*cos(theta)**45 - 5.0771177195592e+73*cos(theta)**43 + 1.56258940039603e+73*cos(theta)**41 - 4.18869992914268e+72*cos(theta)**39 + 9.7604611556438e+71*cos(theta)**37 - 1.97163091588073e+71*cos(theta)**35 + 3.44023576231389e+70*cos(theta)**33 - 5.16182006962697e+69*cos(theta)**31 + 6.62319628139222e+68*cos(theta)**29 - 7.21883943689998e+67*cos(theta)**27 + 6.62954642164284e+66*cos(theta)**25 - 5.0801122004926e+65*cos(theta)**23 + 3.20996100580576e+64*cos(theta)**21 - 1.64854930598975e+63*cos(theta)**19 + 6.76023816125294e+61*cos(theta)**17 - 2.16480430876007e+60*cos(theta)**15 + 5.26167713934739e+58*cos(theta)**13 - 9.35089580471852e+56*cos(theta)**11 + 1.15469077067696e+55*cos(theta)**9 - 9.20683670971664e+52*cos(theta)**7 + 4.22886200577536e+50*cos(theta)**5 - 9.14348541789267e+47*cos(theta)**3 + 5.86873261738939e+44*cos(theta))*cos(22*phi)

#@torch.jit.script
def Yl99_m23(theta, phi):
    return 7.77642052910099e-46*(1.0 - cos(theta)**2)**11.5*(1.77667105155373e+73*cos(theta)**76 - 2.57031091214627e+74*cos(theta)**74 + 1.7801050701813e+75*cos(theta)**72 - 7.85828766732884e+75*cos(theta)**70 + 2.48400061735591e+76*cos(theta)**68 - 5.98788720247277e+76*cos(theta)**66 + 1.14474314164921e+77*cos(theta)**64 - 1.78208662051336e+77*cos(theta)**62 + 2.30186188482975e+77*cos(theta)**60 - 2.50110223213546e+77*cos(theta)**58 + 2.309677089229e+77*cos(theta)**56 - 1.82686323441842e+77*cos(theta)**54 + 1.24487680402512e+77*cos(theta)**52 - 7.33973606997471e+76*cos(theta)**50 + 3.75571290130285e+76*cos(theta)**48 - 1.67118112531346e+76*cos(theta)**46 + 6.47332509243798e+75*cos(theta)**44 - 2.18316061941046e+75*cos(theta)**42 + 6.40661654162373e+74*cos(theta)**40 - 1.63359297236565e+74*cos(theta)**38 + 3.61137062758821e+73*cos(theta)**36 - 6.90070820558256e+72*cos(theta)**34 + 1.13527780156358e+72*cos(theta)**32 - 1.60016422158436e+71*cos(theta)**30 + 1.92072692160375e+70*cos(theta)**28 - 1.94908664796299e+69*cos(theta)**26 + 1.65738660541071e+68*cos(theta)**24 - 1.1684258061133e+67*cos(theta)**22 + 6.7409181121921e+65*cos(theta)**20 - 3.13224368138053e+64*cos(theta)**18 + 1.149240487413e+63*cos(theta)**16 - 3.2472064631401e+61*cos(theta)**14 + 6.8401802811516e+59*cos(theta)**12 - 1.02859853851904e+58*cos(theta)**10 + 1.03922169360927e+56*cos(theta)**8 - 6.44478569680165e+53*cos(theta)**6 + 2.11443100288768e+51*cos(theta)**4 - 2.7430456253678e+48*cos(theta)**2 + 5.86873261738939e+44)*cos(23*phi)

#@torch.jit.script
def Yl99_m24(theta, phi):
    return 8.04304292014539e-48*(1.0 - cos(theta)**2)**12*(1.35026999918084e+75*cos(theta)**75 - 1.90203007498824e+76*cos(theta)**73 + 1.28167565053054e+77*cos(theta)**71 - 5.50080136713019e+77*cos(theta)**69 + 1.68912041980202e+78*cos(theta)**67 - 3.95200555363202e+78*cos(theta)**65 + 7.32635610655491e+78*cos(theta)**63 - 1.10489370471828e+79*cos(theta)**61 + 1.38111713089785e+79*cos(theta)**59 - 1.45063929463857e+79*cos(theta)**57 + 1.29341916996824e+79*cos(theta)**55 - 9.86506146585947e+78*cos(theta)**53 + 6.47335938093064e+78*cos(theta)**51 - 3.66986803498736e+78*cos(theta)**49 + 1.80274219262537e+78*cos(theta)**47 - 7.68743317644191e+77*cos(theta)**45 + 2.84826304067271e+77*cos(theta)**43 - 9.16927460152392e+76*cos(theta)**41 + 2.56264661664949e+76*cos(theta)**39 - 6.20765329498946e+75*cos(theta)**37 + 1.30009342593175e+75*cos(theta)**35 - 2.34624078989807e+74*cos(theta)**33 + 3.63288896500346e+73*cos(theta)**31 - 4.80049266475308e+72*cos(theta)**29 + 5.37803538049049e+71*cos(theta)**27 - 5.06762528470379e+70*cos(theta)**25 + 3.9777278529857e+69*cos(theta)**23 - 2.57053677344925e+68*cos(theta)**21 + 1.34818362243842e+67*cos(theta)**19 - 5.63803862648496e+65*cos(theta)**17 + 1.8387847798608e+64*cos(theta)**15 - 4.54608904839614e+62*cos(theta)**13 + 8.20821633738192e+60*cos(theta)**11 - 1.02859853851904e+59*cos(theta)**9 + 8.31377354887413e+56*cos(theta)**7 - 3.86687141808099e+54*cos(theta)**5 + 8.45772401155072e+51*cos(theta)**3 - 5.4860912507356e+48*cos(theta))*cos(24*phi)

#@torch.jit.script
def Yl99_m25(theta, phi):
    return 8.34024698683431e-50*(1.0 - cos(theta)**2)**12.5*(1.01270249938563e+77*cos(theta)**74 - 1.38848195474141e+78*cos(theta)**72 + 9.0998971187668e+78*cos(theta)**70 - 3.79555294331983e+79*cos(theta)**68 + 1.13171068126735e+80*cos(theta)**66 - 2.56880360986082e+80*cos(theta)**64 + 4.61560434712959e+80*cos(theta)**62 - 6.73985159878152e+80*cos(theta)**60 + 8.14859107229733e+80*cos(theta)**58 - 8.26864397943983e+80*cos(theta)**56 + 7.11380543482533e+80*cos(theta)**54 - 5.22848257690552e+80*cos(theta)**52 + 3.30141328427463e+80*cos(theta)**50 - 1.79823533714381e+80*cos(theta)**48 + 8.47288830533923e+79*cos(theta)**46 - 3.45934492939886e+79*cos(theta)**44 + 1.22475310748927e+79*cos(theta)**42 - 3.75940258662481e+78*cos(theta)**40 + 9.99432180493302e+77*cos(theta)**38 - 2.2968317191461e+77*cos(theta)**36 + 4.55032699076114e+76*cos(theta)**34 - 7.74259460666363e+75*cos(theta)**32 + 1.12619557915107e+75*cos(theta)**30 - 1.39214287277839e+74*cos(theta)**28 + 1.45206955273243e+73*cos(theta)**26 - 1.26690632117595e+72*cos(theta)**24 + 9.14877406186712e+70*cos(theta)**22 - 5.39812722424343e+69*cos(theta)**20 + 2.561548882633e+68*cos(theta)**18 - 9.58466566502442e+66*cos(theta)**16 + 2.7581771697912e+65*cos(theta)**14 - 5.90991576291498e+63*cos(theta)**12 + 9.02903797112011e+61*cos(theta)**10 - 9.25738684667134e+59*cos(theta)**8 + 5.81964148421189e+57*cos(theta)**6 - 1.93343570904049e+55*cos(theta)**4 + 2.53731720346522e+52*cos(theta)**2 - 5.4860912507356e+48)*cos(25*phi)

#@torch.jit.script
def Yl99_m26(theta, phi):
    return 8.67177588978136e-52*(1.0 - cos(theta)**2)**13*(7.49399849545365e+78*cos(theta)**73 - 9.99707007413817e+79*cos(theta)**71 + 6.36992798313676e+80*cos(theta)**69 - 2.58097600145748e+81*cos(theta)**67 + 7.46929049636453e+81*cos(theta)**65 - 1.64403431031092e+82*cos(theta)**63 + 2.86167469522035e+82*cos(theta)**61 - 4.04391095926891e+82*cos(theta)**59 + 4.72618282193245e+82*cos(theta)**57 - 4.6304406284863e+82*cos(theta)**55 + 3.84145493480568e+82*cos(theta)**53 - 2.71881093999087e+82*cos(theta)**51 + 1.65070664213731e+82*cos(theta)**49 - 8.63152961829026e+81*cos(theta)**47 + 3.89752862045605e+81*cos(theta)**45 - 1.5221117689355e+81*cos(theta)**43 + 5.14396305145492e+80*cos(theta)**41 - 1.50376103464992e+80*cos(theta)**39 + 3.79784228587455e+79*cos(theta)**37 - 8.26859418892596e+78*cos(theta)**35 + 1.54711117685879e+78*cos(theta)**33 - 2.47763027413236e+77*cos(theta)**31 + 3.37858673745322e+76*cos(theta)**29 - 3.8980000437795e+75*cos(theta)**27 + 3.77538083710432e+74*cos(theta)**25 - 3.04057517082227e+73*cos(theta)**23 + 2.01273029361077e+72*cos(theta)**21 - 1.07962544484869e+71*cos(theta)**19 + 4.6107879887394e+69*cos(theta)**17 - 1.53354650640391e+68*cos(theta)**15 + 3.86144803770768e+66*cos(theta)**13 - 7.09189891549798e+64*cos(theta)**11 + 9.02903797112011e+62*cos(theta)**9 - 7.40590947733707e+60*cos(theta)**7 + 3.49178489052713e+58*cos(theta)**5 - 7.73374283616198e+55*cos(theta)**3 + 5.07463440693043e+52*cos(theta))*cos(26*phi)

#@torch.jit.script
def Yl99_m27(theta, phi):
    return 9.04193421481642e-54*(1.0 - cos(theta)**2)**13.5*(5.47061890168117e+80*cos(theta)**72 - 7.0979197526381e+81*cos(theta)**70 + 4.39525030836436e+82*cos(theta)**68 - 1.72925392097651e+83*cos(theta)**66 + 4.85503882263694e+83*cos(theta)**64 - 1.03574161549588e+84*cos(theta)**62 + 1.74562156408441e+84*cos(theta)**60 - 2.38590746596866e+84*cos(theta)**58 + 2.6939242085015e+84*cos(theta)**56 - 2.54674234566747e+84*cos(theta)**54 + 2.03597111544701e+84*cos(theta)**52 - 1.38659357939534e+84*cos(theta)**50 + 8.08846254647284e+83*cos(theta)**48 - 4.05681892059642e+83*cos(theta)**46 + 1.75388787920522e+83*cos(theta)**44 - 6.54508060642264e+82*cos(theta)**42 + 2.10902485109652e+82*cos(theta)**40 - 5.8646680351347e+81*cos(theta)**38 + 1.40520164577358e+81*cos(theta)**36 - 2.89400796612408e+80*cos(theta)**34 + 5.105466883634e+79*cos(theta)**32 - 7.68065384981032e+78*cos(theta)**30 + 9.79790153861434e+77*cos(theta)**28 - 1.05246001182047e+77*cos(theta)**26 + 9.4384520927608e+75*cos(theta)**24 - 6.99332289289123e+74*cos(theta)**22 + 4.22673361658261e+73*cos(theta)**20 - 2.0512883452125e+72*cos(theta)**18 + 7.83833958085697e+70*cos(theta)**16 - 2.30031975960586e+69*cos(theta)**14 + 5.01988244901999e+67*cos(theta)**12 - 7.80108880704778e+65*cos(theta)**10 + 8.1261341740081e+63*cos(theta)**8 - 5.18413663413595e+61*cos(theta)**6 + 1.74589244526357e+59*cos(theta)**4 - 2.32012285084859e+56*cos(theta)**2 + 5.07463440693043e+52)*cos(27*phi)

#@torch.jit.script
def Yl99_m28(theta, phi):
    return 9.45569018793983e-56*(1.0 - cos(theta)**2)**14*(3.93884560921044e+82*cos(theta)**71 - 4.96854382684667e+83*cos(theta)**69 + 2.98877020968777e+84*cos(theta)**67 - 1.1413075878445e+85*cos(theta)**65 + 3.10722484648764e+85*cos(theta)**63 - 6.42159801607446e+85*cos(theta)**61 + 1.04737293845065e+86*cos(theta)**59 - 1.38382633026182e+86*cos(theta)**57 + 1.50859755676084e+86*cos(theta)**55 - 1.37524086666043e+86*cos(theta)**53 + 1.05870498003244e+86*cos(theta)**51 - 6.93296789697672e+85*cos(theta)**49 + 3.88246202230696e+85*cos(theta)**47 - 1.86613670347436e+85*cos(theta)**45 + 7.71710666850297e+84*cos(theta)**43 - 2.74893385469751e+84*cos(theta)**41 + 8.43609940438607e+83*cos(theta)**39 - 2.22857385335119e+83*cos(theta)**37 + 5.0587259247849e+82*cos(theta)**35 - 9.83962708482189e+81*cos(theta)**33 + 1.63374940276288e+81*cos(theta)**31 - 2.3041961549431e+80*cos(theta)**29 + 2.74341243081202e+79*cos(theta)**27 - 2.73639603073321e+78*cos(theta)**25 + 2.26522850226259e+77*cos(theta)**23 - 1.53853103643607e+76*cos(theta)**21 + 8.45346723316522e+74*cos(theta)**19 - 3.69231902138251e+73*cos(theta)**17 + 1.25413433293712e+72*cos(theta)**15 - 3.22044766344821e+70*cos(theta)**13 + 6.02385893882398e+68*cos(theta)**11 - 7.80108880704778e+66*cos(theta)**9 + 6.50090733920648e+64*cos(theta)**7 - 3.11048198048157e+62*cos(theta)**5 + 6.98356978105427e+59*cos(theta)**3 - 4.64024570169719e+56*cos(theta))*cos(28*phi)

#@torch.jit.script
def Yl99_m29(theta, phi):
    return 9.91879866943503e-58*(1.0 - cos(theta)**2)**14.5*(2.79658038253941e+84*cos(theta)**70 - 3.4282952405242e+85*cos(theta)**68 + 2.0024760404908e+86*cos(theta)**66 - 7.41849932098925e+86*cos(theta)**64 + 1.95755165328722e+87*cos(theta)**62 - 3.91717478980542e+87*cos(theta)**60 + 6.17950033685882e+87*cos(theta)**58 - 7.88781008249238e+87*cos(theta)**56 + 8.29728656218461e+87*cos(theta)**54 - 7.28877659330029e+87*cos(theta)**52 + 5.39939539816547e+87*cos(theta)**50 - 3.39715426951859e+87*cos(theta)**48 + 1.82475715048427e+87*cos(theta)**46 - 8.3976151656346e+86*cos(theta)**44 + 3.31835586745628e+86*cos(theta)**42 - 1.12706288042598e+86*cos(theta)**40 + 3.29007876771057e+85*cos(theta)**38 - 8.24572325739939e+84*cos(theta)**36 + 1.77055407367471e+84*cos(theta)**34 - 3.24707693799122e+83*cos(theta)**32 + 5.06462314856493e+82*cos(theta)**30 - 6.68216884933498e+81*cos(theta)**28 + 7.40721356319244e+80*cos(theta)**26 - 6.84099007683303e+79*cos(theta)**24 + 5.21002555520396e+78*cos(theta)**22 - 3.23091517651575e+77*cos(theta)**20 + 1.60615877430139e+76*cos(theta)**18 - 6.27694233635027e+74*cos(theta)**16 + 1.88120149940567e+73*cos(theta)**14 - 4.18658196248267e+71*cos(theta)**12 + 6.62624483270638e+69*cos(theta)**10 - 7.020979926343e+67*cos(theta)**8 + 4.55063513744454e+65*cos(theta)**6 - 1.55524099024079e+63*cos(theta)**4 + 2.09507093431628e+60*cos(theta)**2 - 4.64024570169719e+56)*cos(29*phi)

#@torch.jit.script
def Yl99_m30(theta, phi):
    return 1.04379497062177e-59*(1.0 - cos(theta)**2)**15*(1.95760626777759e+86*cos(theta)**69 - 2.33124076355646e+87*cos(theta)**67 + 1.32163418672393e+88*cos(theta)**65 - 4.74783956543312e+88*cos(theta)**63 + 1.21368202503807e+89*cos(theta)**61 - 2.35030487388325e+89*cos(theta)**59 + 3.58411019537812e+89*cos(theta)**57 - 4.41717364619573e+89*cos(theta)**55 + 4.48053474357969e+89*cos(theta)**53 - 3.79016382851615e+89*cos(theta)**51 + 2.69969769908273e+89*cos(theta)**49 - 1.63063404936892e+89*cos(theta)**47 + 8.39388289222765e+88*cos(theta)**45 - 3.69495067287922e+88*cos(theta)**43 + 1.39370946433164e+88*cos(theta)**41 - 4.50825152170391e+87*cos(theta)**39 + 1.25022993173002e+87*cos(theta)**37 - 2.96846037266378e+86*cos(theta)**35 + 6.01988385049403e+85*cos(theta)**33 - 1.03906462015719e+85*cos(theta)**31 + 1.51938694456948e+84*cos(theta)**29 - 1.87100727781379e+83*cos(theta)**27 + 1.92587552643003e+82*cos(theta)**25 - 1.64183761843993e+81*cos(theta)**23 + 1.14620562214487e+80*cos(theta)**21 - 6.46183035303149e+78*cos(theta)**19 + 2.8910857937425e+77*cos(theta)**17 - 1.00431077381604e+76*cos(theta)**15 + 2.63368209916794e+74*cos(theta)**13 - 5.0238983549792e+72*cos(theta)**11 + 6.62624483270638e+70*cos(theta)**9 - 5.6167839410744e+68*cos(theta)**7 + 2.73038108246672e+66*cos(theta)**5 - 6.22096396096314e+63*cos(theta)**3 + 4.19014186863256e+60*cos(theta))*cos(30*phi)

#@torch.jit.script
def Yl99_m31(theta, phi):
    return 1.10209486381459e-61*(1.0 - cos(theta)**2)**15.5*(1.35074832476654e+88*cos(theta)**68 - 1.56193131158283e+89*cos(theta)**66 + 8.59062221370555e+89*cos(theta)**64 - 2.99113892622286e+90*cos(theta)**62 + 7.40346035273225e+90*cos(theta)**60 - 1.38667987559112e+91*cos(theta)**58 + 2.04294281136553e+91*cos(theta)**56 - 2.42944550540765e+91*cos(theta)**54 + 2.37468341409723e+91*cos(theta)**52 - 1.93298355254324e+91*cos(theta)**50 + 1.32285187255054e+91*cos(theta)**48 - 7.66398003203394e+90*cos(theta)**46 + 3.77724730150244e+90*cos(theta)**44 - 1.58882878933807e+90*cos(theta)**42 + 5.71420880375971e+89*cos(theta)**40 - 1.75821809346453e+89*cos(theta)**38 + 4.62585074740106e+88*cos(theta)**36 - 1.03896113043232e+88*cos(theta)**34 + 1.98656167066303e+87*cos(theta)**32 - 3.22110032248729e+86*cos(theta)**30 + 4.40622213925149e+85*cos(theta)**28 - 5.05171965009725e+84*cos(theta)**26 + 4.81468881607509e+83*cos(theta)**24 - 3.77622652241183e+82*cos(theta)**22 + 2.40703180650423e+81*cos(theta)**20 - 1.22774776707598e+80*cos(theta)**18 + 4.91484584936226e+78*cos(theta)**16 - 1.50646616072406e+77*cos(theta)**14 + 3.42378672891833e+75*cos(theta)**12 - 5.52628819047712e+73*cos(theta)**10 + 5.96362034943574e+71*cos(theta)**8 - 3.93174875875208e+69*cos(theta)**6 + 1.36519054123336e+67*cos(theta)**4 - 1.86628918828894e+64*cos(theta)**2 + 4.19014186863256e+60)*cos(31*phi)

#@torch.jit.script
def Yl99_m32(theta, phi):
    return 1.16769353100899e-63*(1.0 - cos(theta)**2)**16*(9.18508860841245e+89*cos(theta)**67 - 1.03087466564467e+91*cos(theta)**65 + 5.49799821677155e+91*cos(theta)**63 - 1.85450613425818e+92*cos(theta)**61 + 4.44207621163935e+92*cos(theta)**59 - 8.04274327842849e+92*cos(theta)**57 + 1.14404797436469e+93*cos(theta)**55 - 1.31190057292013e+93*cos(theta)**53 + 1.23483537533056e+93*cos(theta)**51 - 9.66491776271618e+92*cos(theta)**49 + 6.34968898824259e+92*cos(theta)**47 - 3.52543081473561e+92*cos(theta)**45 + 1.66198881266107e+92*cos(theta)**43 - 6.67308091521988e+91*cos(theta)**41 + 2.28568352150388e+91*cos(theta)**39 - 6.6812287551652e+90*cos(theta)**37 + 1.66530626906438e+90*cos(theta)**35 - 3.5324678434699e+89*cos(theta)**33 + 6.3569973461217e+88*cos(theta)**31 - 9.66330096746188e+87*cos(theta)**29 + 1.23374219899042e+87*cos(theta)**27 - 1.31344710902528e+86*cos(theta)**25 + 1.15552531585802e+85*cos(theta)**23 - 8.30769834930603e+83*cos(theta)**21 + 4.81406361300846e+82*cos(theta)**19 - 2.20994598073677e+81*cos(theta)**17 + 7.86375335897961e+79*cos(theta)**15 - 2.10905262501369e+78*cos(theta)**13 + 4.10854407470199e+76*cos(theta)**11 - 5.52628819047712e+74*cos(theta)**9 + 4.77089627954859e+72*cos(theta)**7 - 2.35904925525125e+70*cos(theta)**5 + 5.46076216493344e+67*cos(theta)**3 - 3.73257837657788e+64*cos(theta))*cos(32*phi)

#@torch.jit.script
def Yl99_m33(theta, phi):
    return 1.24166519402301e-65*(1.0 - cos(theta)**2)**16.5*(6.15400936763634e+91*cos(theta)**66 - 6.70068532669033e+92*cos(theta)**64 + 3.46373887656608e+93*cos(theta)**62 - 1.13124874189749e+94*cos(theta)**60 + 2.62082496486722e+94*cos(theta)**58 - 4.58436366870424e+94*cos(theta)**56 + 6.29226385900582e+94*cos(theta)**54 - 6.9530730364767e+94*cos(theta)**52 + 6.29766041418587e+94*cos(theta)**50 - 4.73580970373093e+94*cos(theta)**48 + 2.98435382447402e+94*cos(theta)**46 - 1.58644386663103e+94*cos(theta)**44 + 7.14655189444262e+93*cos(theta)**42 - 2.73596317524015e+93*cos(theta)**40 + 8.91416573386515e+92*cos(theta)**38 - 2.47205463941112e+92*cos(theta)**36 + 5.82857194172533e+91*cos(theta)**34 - 1.16571438834507e+91*cos(theta)**32 + 1.97066917729773e+90*cos(theta)**30 - 2.80235728056394e+89*cos(theta)**28 + 3.33110393727412e+88*cos(theta)**26 - 3.28361777256321e+87*cos(theta)**24 + 2.65770822647345e+86*cos(theta)**22 - 1.74461665335427e+85*cos(theta)**20 + 9.14672086471608e+83*cos(theta)**18 - 3.75690816725251e+82*cos(theta)**16 + 1.17956300384694e+81*cos(theta)**14 - 2.7417684125178e+79*cos(theta)**12 + 4.51939848217219e+77*cos(theta)**10 - 4.97365937142941e+75*cos(theta)**8 + 3.33962739568402e+73*cos(theta)**6 - 1.17952462762562e+71*cos(theta)**4 + 1.63822864948003e+68*cos(theta)**2 - 3.73257837657788e+64)*cos(33*phi)

#@torch.jit.script
def Yl99_m34(theta, phi):
    return 1.32527717733838e-67*(1.0 - cos(theta)**2)**17*(4.06164618263998e+93*cos(theta)**65 - 4.28843860908181e+94*cos(theta)**63 + 2.14751810347097e+95*cos(theta)**61 - 6.78749245138493e+95*cos(theta)**59 + 1.52007847962299e+96*cos(theta)**57 - 2.56724365447438e+96*cos(theta)**55 + 3.39782248386314e+96*cos(theta)**53 - 3.61559797896789e+96*cos(theta)**51 + 3.14883020709293e+96*cos(theta)**49 - 2.27318865779085e+96*cos(theta)**47 + 1.37280275925805e+96*cos(theta)**45 - 6.98035301317651e+95*cos(theta)**43 + 3.0015517956659e+95*cos(theta)**41 - 1.09438527009606e+95*cos(theta)**39 + 3.38738297886876e+94*cos(theta)**37 - 8.89939670188005e+93*cos(theta)**35 + 1.98171446018661e+93*cos(theta)**33 - 3.73028604270421e+92*cos(theta)**31 + 5.91200753189318e+91*cos(theta)**29 - 7.84660038557905e+90*cos(theta)**27 + 8.66087023691272e+89*cos(theta)**25 - 7.8806826541517e+88*cos(theta)**23 + 5.84695809824159e+87*cos(theta)**21 - 3.48923330670853e+86*cos(theta)**19 + 1.64640975564889e+85*cos(theta)**17 - 6.01105306760402e+83*cos(theta)**15 + 1.65138820538572e+82*cos(theta)**13 - 3.29012209502136e+80*cos(theta)**11 + 4.51939848217219e+78*cos(theta)**9 - 3.97892749714353e+76*cos(theta)**7 + 2.00377643741041e+74*cos(theta)**5 - 4.7180985105025e+71*cos(theta)**3 + 3.27645729896007e+68*cos(theta))*cos(34*phi)

#@torch.jit.script
def Yl99_m35(theta, phi):
    return 1.42003039891379e-69*(1.0 - cos(theta)**2)**17.5*(2.64007001871599e+95*cos(theta)**64 - 2.70171632372154e+96*cos(theta)**62 + 1.30998604311729e+97*cos(theta)**60 - 4.00462054631711e+97*cos(theta)**58 + 8.66444733385101e+97*cos(theta)**56 - 1.41198400996091e+98*cos(theta)**54 + 1.80084591644747e+98*cos(theta)**52 - 1.84395496927362e+98*cos(theta)**50 + 1.54292680147554e+98*cos(theta)**48 - 1.0683986691617e+98*cos(theta)**46 + 6.17761241666121e+97*cos(theta)**44 - 3.0015517956659e+97*cos(theta)**42 + 1.23063623622302e+97*cos(theta)**40 - 4.26810255337463e+96*cos(theta)**38 + 1.25333170218144e+96*cos(theta)**36 - 3.11478884565802e+95*cos(theta)**34 + 6.53965771861582e+94*cos(theta)**32 - 1.15638867323831e+94*cos(theta)**30 + 1.71448218424902e+93*cos(theta)**28 - 2.11858210410634e+92*cos(theta)**26 + 2.16521755922818e+91*cos(theta)**24 - 1.81255701045489e+90*cos(theta)**22 + 1.22786120063073e+89*cos(theta)**20 - 6.62954328274621e+87*cos(theta)**18 + 2.79889658460312e+86*cos(theta)**16 - 9.01657960140602e+84*cos(theta)**14 + 2.14680466700143e+83*cos(theta)**12 - 3.61913430452349e+81*cos(theta)**10 + 4.06745863395497e+79*cos(theta)**8 - 2.78524924800047e+77*cos(theta)**6 + 1.00188821870521e+75*cos(theta)**4 - 1.41542955315075e+72*cos(theta)**2 + 3.27645729896007e+68)*cos(35*phi)

#@torch.jit.script
def Yl99_m36(theta, phi):
    return 1.52770946836149e-71*(1.0 - cos(theta)**2)**18*(1.68964481197823e+97*cos(theta)**63 - 1.67506412070736e+98*cos(theta)**61 + 7.85991625870374e+98*cos(theta)**59 - 2.32267991686392e+99*cos(theta)**57 + 4.85209050695657e+99*cos(theta)**55 - 7.62471365378889e+99*cos(theta)**53 + 9.36439876552682e+99*cos(theta)**51 - 9.21977484636811e+99*cos(theta)**49 + 7.40604864708258e+99*cos(theta)**47 - 4.91463387814381e+99*cos(theta)**45 + 2.71814946333093e+99*cos(theta)**43 - 1.26065175417968e+99*cos(theta)**41 + 4.92254494489208e+98*cos(theta)**39 - 1.62187897028236e+98*cos(theta)**37 + 4.51199412785318e+97*cos(theta)**35 - 1.05902820752373e+97*cos(theta)**33 + 2.09269046995706e+96*cos(theta)**31 - 3.46916601971492e+95*cos(theta)**29 + 4.80055011589726e+94*cos(theta)**27 - 5.50831347067649e+93*cos(theta)**25 + 5.19652214214763e+92*cos(theta)**23 - 3.98762542300076e+91*cos(theta)**21 + 2.45572240126147e+90*cos(theta)**19 - 1.19331779089432e+89*cos(theta)**17 + 4.47823453536499e+87*cos(theta)**15 - 1.26232114419684e+86*cos(theta)**13 + 2.57616560040172e+84*cos(theta)**11 - 3.61913430452349e+82*cos(theta)**9 + 3.25396690716398e+80*cos(theta)**7 - 1.67114954880028e+78*cos(theta)**5 + 4.00755287482082e+75*cos(theta)**3 - 2.8308591063015e+72*cos(theta))*cos(36*phi)

#@torch.jit.script
def Yl99_m37(theta, phi):
    return 1.65044494316303e-73*(1.0 - cos(theta)**2)**18.5*(1.06447623154629e+99*cos(theta)**62 - 1.02178911363149e+100*cos(theta)**60 + 4.63735059263521e+100*cos(theta)**58 - 1.32392755261244e+101*cos(theta)**56 + 2.66864977882611e+101*cos(theta)**54 - 4.04109823650811e+101*cos(theta)**52 + 4.77584337041868e+101*cos(theta)**50 - 4.51768967472037e+101*cos(theta)**48 + 3.48084286412881e+101*cos(theta)**46 - 2.21158524516471e+101*cos(theta)**44 + 1.1688042692323e+101*cos(theta)**42 - 5.16867219213668e+100*cos(theta)**40 + 1.91979252850791e+100*cos(theta)**38 - 6.00095219004473e+99*cos(theta)**36 + 1.57919794474861e+99*cos(theta)**34 - 3.49479308482829e+98*cos(theta)**32 + 6.48734045686689e+97*cos(theta)**30 - 1.00605814571733e+97*cos(theta)**28 + 1.29614853129226e+96*cos(theta)**26 - 1.37707836766912e+95*cos(theta)**24 + 1.19520009269396e+94*cos(theta)**22 - 8.3740133883016e+92*cos(theta)**20 + 4.66587256239678e+91*cos(theta)**18 - 2.02864024452034e+90*cos(theta)**16 + 6.71735180304749e+88*cos(theta)**14 - 1.6410174874559e+87*cos(theta)**12 + 2.83378216044189e+85*cos(theta)**10 - 3.25722087407114e+83*cos(theta)**8 + 2.27777683501478e+81*cos(theta)**6 - 8.35574774400141e+78*cos(theta)**4 + 1.20226586244625e+76*cos(theta)**2 - 2.8308591063015e+72)*cos(37*phi)

#@torch.jit.script
def Yl99_m38(theta, phi):
    return 1.79079104109761e-75*(1.0 - cos(theta)**2)**19*(6.59975263558698e+100*cos(theta)**61 - 6.13073468178892e+101*cos(theta)**59 + 2.68966334372842e+102*cos(theta)**57 - 7.41399429462964e+102*cos(theta)**55 + 1.4410708805661e+103*cos(theta)**53 - 2.10137108298422e+103*cos(theta)**51 + 2.38792168520934e+103*cos(theta)**49 - 2.16849104386578e+103*cos(theta)**47 + 1.60118771749925e+103*cos(theta)**45 - 9.73097507872474e+102*cos(theta)**43 + 4.90897793077567e+102*cos(theta)**41 - 2.06746887685467e+102*cos(theta)**39 + 7.29521160833006e+101*cos(theta)**37 - 2.1603427884161e+101*cos(theta)**35 + 5.36927301214529e+100*cos(theta)**33 - 1.11833378714505e+100*cos(theta)**31 + 1.94620213706007e+99*cos(theta)**29 - 2.81696280800851e+98*cos(theta)**27 + 3.36998618135988e+97*cos(theta)**25 - 3.30498808240589e+96*cos(theta)**23 + 2.6294402039267e+95*cos(theta)**21 - 1.67480267766032e+94*cos(theta)**19 + 8.39857061231421e+92*cos(theta)**17 - 3.24582439123255e+91*cos(theta)**15 + 9.40429252426648e+89*cos(theta)**13 - 1.96922098494708e+88*cos(theta)**11 + 2.83378216044189e+86*cos(theta)**9 - 2.60577669925691e+84*cos(theta)**7 + 1.36666610100887e+82*cos(theta)**5 - 3.34229909760056e+79*cos(theta)**3 + 2.40453172489249e+76*cos(theta))*cos(38*phi)

#@torch.jit.script
def Yl99_m39(theta, phi):
    return 1.95182309428749e-77*(1.0 - cos(theta)**2)**19.5*(4.02584910770806e+102*cos(theta)**60 - 3.61713346225546e+103*cos(theta)**58 + 1.5331081059252e+104*cos(theta)**56 - 4.0776968620463e+104*cos(theta)**54 + 7.63767566700034e+104*cos(theta)**52 - 1.07169925232195e+105*cos(theta)**50 + 1.17008162575258e+105*cos(theta)**48 - 1.01919079061692e+105*cos(theta)**46 + 7.20534472874664e+104*cos(theta)**44 - 4.18431928385164e+104*cos(theta)**42 + 2.01268095161802e+104*cos(theta)**40 - 8.06312861973322e+103*cos(theta)**38 + 2.69922829508212e+103*cos(theta)**36 - 7.56119975945637e+102*cos(theta)**34 + 1.77186009400795e+102*cos(theta)**32 - 3.46683474014967e+101*cos(theta)**30 + 5.6439861974742e+100*cos(theta)**28 - 7.60579958162298e+99*cos(theta)**26 + 8.42496545339969e+98*cos(theta)**24 - 7.60147258953356e+97*cos(theta)**22 + 5.52182442824607e+96*cos(theta)**20 - 3.18212508755461e+95*cos(theta)**18 + 1.42775700409342e+94*cos(theta)**16 - 4.86873658684882e+92*cos(theta)**14 + 1.22255802815464e+91*cos(theta)**12 - 2.16614308344178e+89*cos(theta)**10 + 2.5504039443977e+87*cos(theta)**8 - 1.82404368947984e+85*cos(theta)**6 + 6.83333050504435e+82*cos(theta)**4 - 1.00268972928017e+80*cos(theta)**2 + 2.40453172489249e+76)*cos(39*phi)

#@torch.jit.script
def Yl99_m40(theta, phi):
    return 2.13726034077774e-79*(1.0 - cos(theta)**2)**20*(2.41550946462483e+104*cos(theta)**59 - 2.09793740810817e+105*cos(theta)**57 + 8.58540539318112e+105*cos(theta)**55 - 2.201956305505e+106*cos(theta)**53 + 3.97159134684017e+106*cos(theta)**51 - 5.35849626160976e+106*cos(theta)**49 + 5.61639180361237e+106*cos(theta)**47 - 4.68827763683781e+106*cos(theta)**45 + 3.17035168064852e+106*cos(theta)**43 - 1.75741409921769e+106*cos(theta)**41 + 8.05072380647209e+105*cos(theta)**39 - 3.06398887549862e+105*cos(theta)**37 + 9.71722186229564e+104*cos(theta)**35 - 2.57080791821516e+104*cos(theta)**33 + 5.66995230082542e+103*cos(theta)**31 - 1.0400504220449e+103*cos(theta)**29 + 1.58031613529278e+102*cos(theta)**27 - 1.97750789122198e+101*cos(theta)**25 + 2.02199170881593e+100*cos(theta)**23 - 1.67232396969738e+99*cos(theta)**21 + 1.10436488564921e+98*cos(theta)**19 - 5.72782515759829e+96*cos(theta)**17 + 2.28441120654947e+95*cos(theta)**15 - 6.81623122158835e+93*cos(theta)**13 + 1.46706963378557e+92*cos(theta)**11 - 2.16614308344178e+90*cos(theta)**9 + 2.04032315551816e+88*cos(theta)**7 - 1.0944262136879e+86*cos(theta)**5 + 2.73333220201774e+83*cos(theta)**3 - 2.00537945856034e+80*cos(theta))*cos(40*phi)

#@torch.jit.script
def Yl99_m41(theta, phi):
    return 2.35162139837282e-81*(1.0 - cos(theta)**2)**20.5*(1.42515058412865e+106*cos(theta)**58 - 1.19582432262166e+107*cos(theta)**56 + 4.72197296624962e+107*cos(theta)**54 - 1.16703684191765e+108*cos(theta)**52 + 2.02551158688849e+108*cos(theta)**50 - 2.62566316818878e+108*cos(theta)**48 + 2.63970414769781e+108*cos(theta)**46 - 2.10972493657702e+108*cos(theta)**44 + 1.36325122267886e+108*cos(theta)**42 - 7.20539780679252e+107*cos(theta)**40 + 3.13978228452412e+107*cos(theta)**38 - 1.13367588393449e+107*cos(theta)**36 + 3.40102765180347e+106*cos(theta)**34 - 8.48366613011004e+105*cos(theta)**32 + 1.75768521325588e+105*cos(theta)**30 - 3.01614622393021e+104*cos(theta)**28 + 4.26685356529049e+103*cos(theta)**26 - 4.94376972805494e+102*cos(theta)**24 + 4.65058093027663e+101*cos(theta)**22 - 3.5118803363645e+100*cos(theta)**20 + 2.09829328273351e+99*cos(theta)**18 - 9.7373027679171e+97*cos(theta)**16 + 3.4266168098242e+96*cos(theta)**14 - 8.86110058806485e+94*cos(theta)**12 + 1.61377659716413e+93*cos(theta)**10 - 1.9495287750976e+91*cos(theta)**8 + 1.42822620886271e+89*cos(theta)**6 - 5.47213106843952e+86*cos(theta)**4 + 8.19999660605322e+83*cos(theta)**2 - 2.00537945856034e+80)*cos(41*phi)

#@torch.jit.script
def Yl99_m42(theta, phi):
    return 2.60042211175638e-83*(1.0 - cos(theta)**2)**21*(8.26587338794618e+107*cos(theta)**57 - 6.69661620668127e+108*cos(theta)**55 + 2.54986540177479e+109*cos(theta)**53 - 6.06859157797179e+109*cos(theta)**51 + 1.01275579344424e+110*cos(theta)**49 - 1.26031832073062e+110*cos(theta)**47 + 1.21426390794099e+110*cos(theta)**45 - 9.28278972093887e+109*cos(theta)**43 + 5.72565513525123e+109*cos(theta)**41 - 2.88215912271701e+109*cos(theta)**39 + 1.19311726811916e+109*cos(theta)**37 - 4.08123318216417e+108*cos(theta)**35 + 1.15634940161318e+108*cos(theta)**33 - 2.71477316163521e+107*cos(theta)**31 + 5.27305563976764e+106*cos(theta)**29 - 8.44520942700459e+105*cos(theta)**27 + 1.10938192697553e+105*cos(theta)**25 - 1.18650473473319e+104*cos(theta)**23 + 1.02312780466086e+103*cos(theta)**21 - 7.02376067272901e+101*cos(theta)**19 + 3.77692790892031e+100*cos(theta)**17 - 1.55796844286674e+99*cos(theta)**15 + 4.79726353375388e+97*cos(theta)**13 - 1.06333207056778e+96*cos(theta)**11 + 1.61377659716413e+94*cos(theta)**9 - 1.55962302007808e+92*cos(theta)**7 + 8.56935725317628e+89*cos(theta)**5 - 2.18885242737581e+87*cos(theta)**3 + 1.63999932121064e+84*cos(theta))*cos(42*phi)

#@torch.jit.script
def Yl99_m43(theta, phi):
    return 2.89042862939312e-85*(1.0 - cos(theta)**2)**21.5*(4.71154783112932e+109*cos(theta)**56 - 3.6831389136747e+110*cos(theta)**54 + 1.35142866294064e+111*cos(theta)**52 - 3.09498170476561e+111*cos(theta)**50 + 4.9625033878768e+111*cos(theta)**48 - 5.92349610743389e+111*cos(theta)**46 + 5.46418758573447e+111*cos(theta)**44 - 3.99159958000372e+111*cos(theta)**42 + 2.347518605453e+111*cos(theta)**40 - 1.12404205785963e+111*cos(theta)**38 + 4.41453389204091e+110*cos(theta)**36 - 1.42843161375746e+110*cos(theta)**34 + 3.8159530253235e+109*cos(theta)**32 - 8.41579680106916e+108*cos(theta)**30 + 1.52918613553262e+108*cos(theta)**28 - 2.28020654529124e+107*cos(theta)**26 + 2.77345481743882e+106*cos(theta)**24 - 2.72896088988633e+105*cos(theta)**22 + 2.1485683897878e+104*cos(theta)**20 - 1.33451452781851e+103*cos(theta)**18 + 6.42077744516454e+101*cos(theta)**16 - 2.3369526643001e+100*cos(theta)**14 + 6.23644259388004e+98*cos(theta)**12 - 1.16966527762456e+97*cos(theta)**10 + 1.45239893744772e+95*cos(theta)**8 - 1.09173611405466e+93*cos(theta)**6 + 4.28467862658814e+90*cos(theta)**4 - 6.56655728212742e+87*cos(theta)**2 + 1.63999932121064e+84)*cos(43*phi)

#@torch.jit.script
def Yl99_m44(theta, phi):
    return 3.22998286183248e-87*(1.0 - cos(theta)**2)**22*(2.63846678543242e+111*cos(theta)**55 - 1.98889501338434e+112*cos(theta)**53 + 7.02742904729133e+112*cos(theta)**51 - 1.54749085238281e+113*cos(theta)**49 + 2.38200162618086e+113*cos(theta)**47 - 2.72480820941959e+113*cos(theta)**45 + 2.40424253772317e+113*cos(theta)**43 - 1.67647182360156e+113*cos(theta)**41 + 9.39007442181202e+112*cos(theta)**39 - 4.27135981986661e+112*cos(theta)**37 + 1.58923220113473e+112*cos(theta)**35 - 4.85666748677536e+111*cos(theta)**33 + 1.22110496810352e+111*cos(theta)**31 - 2.52473904032075e+110*cos(theta)**29 + 4.28172117949133e+109*cos(theta)**27 - 5.92853701775722e+108*cos(theta)**25 + 6.65629156185317e+107*cos(theta)**23 - 6.00371395774992e+106*cos(theta)**21 + 4.29713677957561e+105*cos(theta)**19 - 2.40212615007332e+104*cos(theta)**17 + 1.02732439122633e+103*cos(theta)**15 - 3.27173373002015e+101*cos(theta)**13 + 7.48373111265605e+99*cos(theta)**11 - 1.16966527762456e+98*cos(theta)**9 + 1.16191914995817e+96*cos(theta)**7 - 6.55041668432795e+93*cos(theta)**5 + 1.71387145063526e+91*cos(theta)**3 - 1.31331145642548e+88*cos(theta))*cos(44*phi)

#@torch.jit.script
def Yl99_m45(theta, phi):
    return 3.62942333534347e-89*(1.0 - cos(theta)**2)**22.5*(1.45115673198783e+113*cos(theta)**54 - 1.0541143570937e+114*cos(theta)**52 + 3.58398881411858e+114*cos(theta)**50 - 7.58270517667575e+114*cos(theta)**48 + 1.11954076430501e+115*cos(theta)**46 - 1.22616369423882e+115*cos(theta)**44 + 1.03382429122096e+115*cos(theta)**42 - 6.8735344767664e+114*cos(theta)**40 + 3.66212902450669e+114*cos(theta)**38 - 1.58040313335065e+114*cos(theta)**36 + 5.56231270397154e+113*cos(theta)**34 - 1.60270027063587e+113*cos(theta)**32 + 3.78542540112091e+112*cos(theta)**30 - 7.32174321693017e+111*cos(theta)**28 + 1.15606471846266e+111*cos(theta)**26 - 1.48213425443931e+110*cos(theta)**24 + 1.53094705922623e+109*cos(theta)**22 - 1.26077993112748e+108*cos(theta)**20 + 8.16455988119365e+106*cos(theta)**18 - 4.08361445512464e+105*cos(theta)**16 + 1.54098658683949e+104*cos(theta)**14 - 4.25325384902619e+102*cos(theta)**12 + 8.23210422392166e+100*cos(theta)**10 - 1.0526987498621e+99*cos(theta)**8 + 8.13343404970721e+96*cos(theta)**6 - 3.27520834216398e+94*cos(theta)**4 + 5.14161435190577e+91*cos(theta)**2 - 1.31331145642548e+88)*cos(45*phi)

#@torch.jit.script
def Yl99_m46(theta, phi):
    return 4.10163250481021e-91*(1.0 - cos(theta)**2)**23*(7.83624635273429e+114*cos(theta)**53 - 5.48139465688724e+115*cos(theta)**51 + 1.79199440705929e+116*cos(theta)**49 - 3.63969848480436e+116*cos(theta)**47 + 5.14988751580303e+116*cos(theta)**45 - 5.39512025465079e+116*cos(theta)**43 + 4.34206202312804e+116*cos(theta)**41 - 2.74941379070656e+116*cos(theta)**39 + 1.39160902931254e+116*cos(theta)**37 - 5.68945128006232e+115*cos(theta)**35 + 1.89118631935033e+115*cos(theta)**33 - 5.12864086603478e+114*cos(theta)**31 + 1.13562762033627e+114*cos(theta)**29 - 2.05008810074045e+113*cos(theta)**27 + 3.00576826800291e+112*cos(theta)**25 - 3.55712221065433e+111*cos(theta)**23 + 3.3680835302977e+110*cos(theta)**21 - 2.52155986225497e+109*cos(theta)**19 + 1.46962077861486e+108*cos(theta)**17 - 6.53378312819943e+106*cos(theta)**15 + 2.15738122157528e+105*cos(theta)**13 - 5.10390461883143e+103*cos(theta)**11 + 8.23210422392166e+101*cos(theta)**9 - 8.42158999889683e+99*cos(theta)**7 + 4.88006042982432e+97*cos(theta)**5 - 1.31008333686559e+95*cos(theta)**3 + 1.02832287038115e+92*cos(theta))*cos(46*phi)

#@torch.jit.script
def Yl99_m47(theta, phi):
    return 4.66275271320016e-93*(1.0 - cos(theta)**2)**23.5*(4.15321056694918e+116*cos(theta)**52 - 2.79551127501249e+117*cos(theta)**50 + 8.78077259459052e+117*cos(theta)**48 - 1.71065828785805e+118*cos(theta)**46 + 2.31744938211136e+118*cos(theta)**44 - 2.31990170949984e+118*cos(theta)**42 + 1.7802454294825e+118*cos(theta)**40 - 1.07227137837556e+118*cos(theta)**38 + 5.1489534084564e+117*cos(theta)**36 - 1.99130794802181e+117*cos(theta)**34 + 6.24091485385607e+116*cos(theta)**32 - 1.58987866847078e+116*cos(theta)**30 + 3.29332009897519e+115*cos(theta)**28 - 5.53523787199921e+114*cos(theta)**26 + 7.51442067000728e+113*cos(theta)**24 - 8.18138108450497e+112*cos(theta)**22 + 7.07297541362518e+111*cos(theta)**20 - 4.79096373828443e+110*cos(theta)**18 + 2.49835532364526e+109*cos(theta)**16 - 9.80067469229915e+107*cos(theta)**14 + 2.80459558804787e+106*cos(theta)**12 - 5.61429508071457e+104*cos(theta)**10 + 7.40889380152949e+102*cos(theta)**8 - 5.89511299922778e+100*cos(theta)**6 + 2.44003021491216e+98*cos(theta)**4 - 3.93025001059677e+95*cos(theta)**2 + 1.02832287038115e+92)*cos(47*phi)

#@torch.jit.script
def Yl99_m48(theta, phi):
    return 5.33312845438859e-95*(1.0 - cos(theta)**2)**24*(2.15966949481357e+118*cos(theta)**51 - 1.39775563750625e+119*cos(theta)**49 + 4.21477084540345e+119*cos(theta)**47 - 7.86902812414702e+119*cos(theta)**45 + 1.019677728129e+120*cos(theta)**43 - 9.74358717989932e+119*cos(theta)**41 + 7.12098171792999e+119*cos(theta)**39 - 4.07463123782712e+119*cos(theta)**37 + 1.8536232270443e+119*cos(theta)**35 - 6.77044702327416e+118*cos(theta)**33 + 1.99709275323394e+118*cos(theta)**31 - 4.76963600541235e+117*cos(theta)**29 + 9.22129627713053e+116*cos(theta)**27 - 1.43916184671979e+116*cos(theta)**25 + 1.80346096080175e+115*cos(theta)**23 - 1.79990383859109e+114*cos(theta)**21 + 1.41459508272504e+113*cos(theta)**19 - 8.62373472891198e+111*cos(theta)**17 + 3.99736851783241e+110*cos(theta)**15 - 1.37209445692188e+109*cos(theta)**13 + 3.36551470565744e+107*cos(theta)**11 - 5.61429508071457e+105*cos(theta)**9 + 5.92711504122359e+103*cos(theta)**7 - 3.53706779953667e+101*cos(theta)**5 + 9.76012085964865e+98*cos(theta)**3 - 7.86050002119354e+95*cos(theta))*cos(48*phi)

#@torch.jit.script
def Yl99_m49(theta, phi):
    return 6.13855425314236e-97*(1.0 - cos(theta)**2)**24.5*(1.10143144235492e+120*cos(theta)**50 - 6.8490026237806e+120*cos(theta)**48 + 1.98094229733962e+121*cos(theta)**46 - 3.54106265586616e+121*cos(theta)**44 + 4.3846142309547e+121*cos(theta)**42 - 3.99487074375872e+121*cos(theta)**40 + 2.7771828699927e+121*cos(theta)**38 - 1.50761355799603e+121*cos(theta)**36 + 6.48768129465507e+120*cos(theta)**34 - 2.23424751768047e+120*cos(theta)**32 + 6.19098753502522e+119*cos(theta)**30 - 1.38319444156958e+119*cos(theta)**28 + 2.48974999482524e+118*cos(theta)**26 - 3.59790461679949e+117*cos(theta)**24 + 4.14796020984402e+116*cos(theta)**22 - 3.7797980610413e+115*cos(theta)**20 + 2.68773065717757e+114*cos(theta)**18 - 1.46603490391504e+113*cos(theta)**16 + 5.99605277674862e+111*cos(theta)**14 - 1.78372279399844e+110*cos(theta)**12 + 3.70206617622319e+108*cos(theta)**10 - 5.05286557264311e+106*cos(theta)**8 + 4.14898052885651e+104*cos(theta)**6 - 1.76853389976834e+102*cos(theta)**4 + 2.92803625789459e+99*cos(theta)**2 - 7.86050002119354e+95)*cos(49*phi)

#@torch.jit.script
def Yl99_m50(theta, phi):
    return 7.11193800400767e-99*(1.0 - cos(theta)**2)**25*(5.50715721177461e+121*cos(theta)**49 - 3.28752125941469e+122*cos(theta)**47 + 9.11233456776225e+122*cos(theta)**45 - 1.55806756858111e+123*cos(theta)**43 + 1.84153797700097e+123*cos(theta)**41 - 1.59794829750349e+123*cos(theta)**39 + 1.05532949059722e+123*cos(theta)**37 - 5.42740880878572e+122*cos(theta)**35 + 2.20581164018272e+122*cos(theta)**33 - 7.14959205657752e+121*cos(theta)**31 + 1.85729626050757e+121*cos(theta)**29 - 3.87294443639482e+120*cos(theta)**27 + 6.47334998654564e+119*cos(theta)**25 - 8.63497108031877e+118*cos(theta)**23 + 9.12551246165684e+117*cos(theta)**21 - 7.55959612208259e+116*cos(theta)**19 + 4.83791518291962e+115*cos(theta)**17 - 2.34565584626406e+114*cos(theta)**15 + 8.39447388744806e+112*cos(theta)**13 - 2.14046735279813e+111*cos(theta)**11 + 3.70206617622319e+109*cos(theta)**9 - 4.04229245811449e+107*cos(theta)**7 + 2.48938831731391e+105*cos(theta)**5 - 7.07413559907334e+102*cos(theta)**3 + 5.85607251578919e+99*cos(theta))*cos(50*phi)

#@torch.jit.script
def Yl99_m51(theta, phi):
    return 8.29553294863174e-101*(1.0 - cos(theta)**2)**25.5*(2.69850703376956e+123*cos(theta)**48 - 1.5451349919249e+124*cos(theta)**46 + 4.10055055549301e+124*cos(theta)**44 - 6.69969054489877e+124*cos(theta)**42 + 7.55030570570399e+124*cos(theta)**40 - 6.23199836026361e+124*cos(theta)**38 + 3.90471911520973e+124*cos(theta)**36 - 1.899593083075e+124*cos(theta)**34 + 7.27917841260298e+123*cos(theta)**32 - 2.21637353753903e+123*cos(theta)**30 + 5.38615915547195e+122*cos(theta)**28 - 1.0456949978266e+122*cos(theta)**26 + 1.61833749663641e+121*cos(theta)**24 - 1.98604334847332e+120*cos(theta)**22 + 1.91635761694794e+119*cos(theta)**20 - 1.43632326319569e+118*cos(theta)**18 + 8.22445581096336e+116*cos(theta)**16 - 3.51848376939609e+115*cos(theta)**14 + 1.09128160536825e+114*cos(theta)**12 - 2.35451408807795e+112*cos(theta)**10 + 3.33185955860087e+110*cos(theta)**8 - 2.82960472068014e+108*cos(theta)**6 + 1.24469415865695e+106*cos(theta)**4 - 2.122240679722e+103*cos(theta)**2 + 5.85607251578919e+99)*cos(51*phi)

#@torch.jit.script
def Yl99_m52(theta, phi):
    return 9.74395344445452e-103*(1.0 - cos(theta)**2)**26*(1.29528337620939e+125*cos(theta)**47 - 7.10762096285456e+125*cos(theta)**45 + 1.80424224441693e+126*cos(theta)**43 - 2.81387002885749e+126*cos(theta)**41 + 3.02012228228159e+126*cos(theta)**39 - 2.36815937690017e+126*cos(theta)**37 + 1.4056988814755e+126*cos(theta)**35 - 6.45861648245501e+125*cos(theta)**33 + 2.32933709203296e+125*cos(theta)**31 - 6.64912061261709e+124*cos(theta)**29 + 1.50812456353214e+124*cos(theta)**27 - 2.71880699434917e+123*cos(theta)**25 + 3.88400999192738e+122*cos(theta)**23 - 4.3692953666413e+121*cos(theta)**21 + 3.83271523389587e+120*cos(theta)**19 - 2.58538187375225e+119*cos(theta)**17 + 1.31591292975414e+118*cos(theta)**15 - 4.92587727715452e+116*cos(theta)**13 + 1.3095379264419e+115*cos(theta)**11 - 2.35451408807795e+113*cos(theta)**9 + 2.66548764688069e+111*cos(theta)**7 - 1.69776283240809e+109*cos(theta)**5 + 4.97877663462782e+106*cos(theta)**3 - 4.244481359444e+103*cos(theta))*cos(52*phi)

#@torch.jit.script
def Yl99_m53(theta, phi):
    return 1.15282789706101e-104*(1.0 - cos(theta)**2)**26.5*(6.08783186818412e+126*cos(theta)**46 - 3.19842943328455e+127*cos(theta)**44 + 7.75824165099278e+127*cos(theta)**42 - 1.15368671183157e+128*cos(theta)**40 + 1.17784769008982e+128*cos(theta)**38 - 8.76218969453063e+127*cos(theta)**36 + 4.91994608516426e+127*cos(theta)**34 - 2.13134343921015e+127*cos(theta)**32 + 7.22094498530216e+126*cos(theta)**30 - 1.92824497765896e+126*cos(theta)**28 + 4.07193632153679e+125*cos(theta)**26 - 6.79701748587292e+124*cos(theta)**24 + 8.93322298143298e+123*cos(theta)**22 - 9.17552026994672e+122*cos(theta)**20 + 7.28215894440216e+121*cos(theta)**18 - 4.39514918537882e+120*cos(theta)**16 + 1.97386939463121e+119*cos(theta)**14 - 6.40364046030088e+117*cos(theta)**12 + 1.44049171908609e+116*cos(theta)**10 - 2.11906267927015e+114*cos(theta)**8 + 1.86584135281649e+112*cos(theta)**6 - 8.48881416204043e+109*cos(theta)**4 + 1.49363299038834e+107*cos(theta)**2 - 4.244481359444e+103)*cos(53*phi)

#@torch.jit.script
def Yl99_m54(theta, phi):
    return 1.37416804779811e-106*(1.0 - cos(theta)**2)**27*(2.8004026593647e+128*cos(theta)**45 - 1.4073089506452e+129*cos(theta)**43 + 3.25846149341697e+129*cos(theta)**41 - 4.61474684732628e+129*cos(theta)**39 + 4.47582122234132e+129*cos(theta)**37 - 3.15438829003103e+129*cos(theta)**35 + 1.67278166895585e+129*cos(theta)**33 - 6.82029900547249e+128*cos(theta)**31 + 2.16628349559065e+128*cos(theta)**29 - 5.39908593744508e+127*cos(theta)**27 + 1.05870344359957e+127*cos(theta)**25 - 1.6312841966095e+126*cos(theta)**23 + 1.96530905591525e+125*cos(theta)**21 - 1.83510405398934e+124*cos(theta)**19 + 1.31078860999239e+123*cos(theta)**17 - 7.03223869660611e+121*cos(theta)**15 + 2.76341715248369e+120*cos(theta)**13 - 7.68436855236106e+118*cos(theta)**11 + 1.44049171908609e+117*cos(theta)**9 - 1.69525014341612e+115*cos(theta)**7 + 1.11950481168989e+113*cos(theta)**5 - 3.39552566481617e+110*cos(theta)**3 + 2.98726598077669e+107*cos(theta))*cos(54*phi)

#@torch.jit.script
def Yl99_m55(theta, phi):
    return 1.65071929906738e-108*(1.0 - cos(theta)**2)**27.5*(1.26018119671411e+130*cos(theta)**44 - 6.05142848777437e+130*cos(theta)**42 + 1.33596921230096e+131*cos(theta)**40 - 1.79975127045725e+131*cos(theta)**38 + 1.65605385226629e+131*cos(theta)**36 - 1.10403590151086e+131*cos(theta)**34 + 5.5201795075543e+130*cos(theta)**32 - 2.11429269169647e+130*cos(theta)**30 + 6.28222213721288e+129*cos(theta)**28 - 1.45775320311017e+129*cos(theta)**26 + 2.64675860899891e+128*cos(theta)**24 - 3.75195365220185e+127*cos(theta)**22 + 4.12714901742204e+126*cos(theta)**20 - 3.48669770257975e+125*cos(theta)**18 + 2.22834063698706e+124*cos(theta)**16 - 1.05483580449092e+123*cos(theta)**14 + 3.59244229822879e+121*cos(theta)**12 - 8.45280540759716e+119*cos(theta)**10 + 1.29644254717748e+118*cos(theta)**8 - 1.18667510039129e+116*cos(theta)**6 + 5.59752405844946e+113*cos(theta)**4 - 1.01865769944485e+111*cos(theta)**2 + 2.98726598077669e+107)*cos(55*phi)

#@torch.jit.script
def Yl99_m56(theta, phi):
    return 1.99885385205305e-110*(1.0 - cos(theta)**2)**28*(5.5447972655421e+131*cos(theta)**43 - 2.54159996486524e+132*cos(theta)**41 + 5.34387684920383e+132*cos(theta)**39 - 6.83905482773754e+132*cos(theta)**37 + 5.96179386815864e+132*cos(theta)**35 - 3.75372206513692e+132*cos(theta)**33 + 1.76645744241738e+132*cos(theta)**31 - 6.34287807508942e+131*cos(theta)**29 + 1.75902219841961e+131*cos(theta)**27 - 3.79015832808644e+130*cos(theta)**25 + 6.35222066159739e+129*cos(theta)**23 - 8.25429803484407e+128*cos(theta)**21 + 8.25429803484407e+127*cos(theta)**19 - 6.27605586464356e+126*cos(theta)**17 + 3.5653450191793e+125*cos(theta)**15 - 1.47677012628728e+124*cos(theta)**13 + 4.31093075787455e+122*cos(theta)**11 - 8.45280540759716e+120*cos(theta)**9 + 1.03715403774198e+119*cos(theta)**7 - 7.12005060234771e+116*cos(theta)**5 + 2.23900962337978e+114*cos(theta)**3 - 2.0373153988897e+111*cos(theta))*cos(56*phi)

#@torch.jit.script
def Yl99_m57(theta, phi):
    return 2.44053204516707e-112*(1.0 - cos(theta)**2)**28.5*(2.3842628241831e+133*cos(theta)**42 - 1.04205598559475e+134*cos(theta)**40 + 2.08411197118949e+134*cos(theta)**38 - 2.53045028626289e+134*cos(theta)**36 + 2.08662785385552e+134*cos(theta)**34 - 1.23872828149518e+134*cos(theta)**32 + 5.47601807149386e+133*cos(theta)**30 - 1.83943464177593e+133*cos(theta)**28 + 4.74935993573294e+132*cos(theta)**26 - 9.47539582021611e+131*cos(theta)**24 + 1.4610107521674e+131*cos(theta)**22 - 1.73340258731725e+130*cos(theta)**20 + 1.56831662662037e+129*cos(theta)**18 - 1.0669294969894e+128*cos(theta)**16 + 5.34801752876895e+126*cos(theta)**14 - 1.91980116417347e+125*cos(theta)**12 + 4.74202383366201e+123*cos(theta)**10 - 7.60752486683745e+121*cos(theta)**8 + 7.26007826419388e+119*cos(theta)**6 - 3.56002530117386e+117*cos(theta)**4 + 6.71702887013935e+114*cos(theta)**2 - 2.0373153988897e+111)*cos(57*phi)

#@torch.jit.script
def Yl99_m58(theta, phi):
    return 3.0054537081684e-114*(1.0 - cos(theta)**2)**29*(1.0013903861569e+135*cos(theta)**41 - 4.16822394237899e+135*cos(theta)**39 + 7.91962549052007e+135*cos(theta)**37 - 9.10962103054641e+135*cos(theta)**35 + 7.09453470310878e+135*cos(theta)**33 - 3.96393050078459e+135*cos(theta)**31 + 1.64280542144816e+135*cos(theta)**29 - 5.15041699697261e+134*cos(theta)**27 + 1.23483358329056e+134*cos(theta)**25 - 2.27409499685187e+133*cos(theta)**23 + 3.21422365476828e+132*cos(theta)**21 - 3.46680517463451e+131*cos(theta)**19 + 2.82296992791667e+130*cos(theta)**17 - 1.70708719518305e+129*cos(theta)**15 + 7.48722454027652e+127*cos(theta)**13 - 2.30376139700816e+126*cos(theta)**11 + 4.74202383366201e+124*cos(theta)**9 - 6.08601989346996e+122*cos(theta)**7 + 4.35604695851633e+120*cos(theta)**5 - 1.42401012046954e+118*cos(theta)**3 + 1.34340577402787e+115*cos(theta))*cos(58*phi)

#@torch.jit.script
def Yl99_m59(theta, phi):
    return 3.73413118522426e-116*(1.0 - cos(theta)**2)**29.5*(4.1057005832433e+136*cos(theta)**40 - 1.6256073375278e+137*cos(theta)**38 + 2.93026143149243e+137*cos(theta)**36 - 3.18836736069124e+137*cos(theta)**34 + 2.3411964520259e+137*cos(theta)**32 - 1.22881845524322e+137*cos(theta)**30 + 4.76413572219966e+136*cos(theta)**28 - 1.3906125891826e+136*cos(theta)**26 + 3.08708395822641e+135*cos(theta)**24 - 5.23041849275929e+134*cos(theta)**22 + 6.74986967501339e+133*cos(theta)**20 - 6.58692983180557e+132*cos(theta)**18 + 4.79904887745834e+131*cos(theta)**16 - 2.56063079277457e+130*cos(theta)**14 + 9.73339190235948e+128*cos(theta)**12 - 2.53413753670898e+127*cos(theta)**10 + 4.26782145029581e+125*cos(theta)**8 - 4.26021392542897e+123*cos(theta)**6 + 2.17802347925816e+121*cos(theta)**4 - 4.27203036140863e+118*cos(theta)**2 + 1.34340577402787e+115)*cos(59*phi)

#@torch.jit.script
def Yl99_m60(theta, phi):
    return 4.68231916352973e-118*(1.0 - cos(theta)**2)**30*(1.64228023329732e+138*cos(theta)**39 - 6.17730788260566e+138*cos(theta)**37 + 1.05489411533727e+139*cos(theta)**35 - 1.08404490263502e+139*cos(theta)**33 + 7.49182864648288e+138*cos(theta)**31 - 3.68645536572967e+138*cos(theta)**29 + 1.33395800221591e+138*cos(theta)**27 - 3.61559273187477e+137*cos(theta)**25 + 7.40900149974338e+136*cos(theta)**23 - 1.15069206840704e+136*cos(theta)**21 + 1.34997393500268e+135*cos(theta)**19 - 1.185647369725e+134*cos(theta)**17 + 7.67847820393335e+132*cos(theta)**15 - 3.5848831098844e+131*cos(theta)**13 + 1.16800702828314e+130*cos(theta)**11 - 2.53413753670898e+128*cos(theta)**9 + 3.41425716023665e+126*cos(theta)**7 - 2.55612835525738e+124*cos(theta)**5 + 8.71209391703266e+121*cos(theta)**3 - 8.54406072281725e+118*cos(theta))*cos(60*phi)

#@torch.jit.script
def Yl99_m61(theta, phi):
    return 5.92746118269603e-120*(1.0 - cos(theta)**2)**30.5*(6.40489290985955e+139*cos(theta)**38 - 2.28560391656409e+140*cos(theta)**36 + 3.69212940368046e+140*cos(theta)**34 - 3.57734817869557e+140*cos(theta)**32 + 2.32246688040969e+140*cos(theta)**30 - 1.0690720560616e+140*cos(theta)**28 + 3.60168660598294e+139*cos(theta)**26 - 9.03898182968693e+138*cos(theta)**24 + 1.70407034494098e+138*cos(theta)**22 - 2.41645334365479e+137*cos(theta)**20 + 2.56495047650509e+136*cos(theta)**18 - 2.0156005285325e+135*cos(theta)**16 + 1.15177173059e+134*cos(theta)**14 - 4.66034804284972e+132*cos(theta)**12 + 1.28480773111145e+131*cos(theta)**10 - 2.28072378303808e+129*cos(theta)**8 + 2.38998001216565e+127*cos(theta)**6 - 1.27806417762869e+125*cos(theta)**4 + 2.6136281751098e+122*cos(theta)**2 - 8.54406072281725e+118)*cos(61*phi)

#@torch.jit.script
def Yl99_m62(theta, phi):
    return 7.57816369635642e-122*(1.0 - cos(theta)**2)**31*(2.43385930574663e+141*cos(theta)**37 - 8.22817409963074e+141*cos(theta)**35 + 1.25532399725136e+142*cos(theta)**33 - 1.14475141718258e+142*cos(theta)**31 + 6.96740064122908e+141*cos(theta)**29 - 2.99340175697249e+141*cos(theta)**27 + 9.36438517555566e+140*cos(theta)**25 - 2.16935563912486e+140*cos(theta)**23 + 3.74895475887015e+139*cos(theta)**21 - 4.83290668730959e+138*cos(theta)**19 + 4.61691085770916e+137*cos(theta)**17 - 3.22496084565201e+136*cos(theta)**15 + 1.612480422826e+135*cos(theta)**13 - 5.59241765141966e+133*cos(theta)**11 + 1.28480773111145e+132*cos(theta)**9 - 1.82457902643046e+130*cos(theta)**7 + 1.43398800729939e+128*cos(theta)**5 - 5.11225671051476e+125*cos(theta)**3 + 5.2272563502196e+122*cos(theta))*cos(62*phi)

#@torch.jit.script
def Yl99_m63(theta, phi):
    return 9.78826261906186e-124*(1.0 - cos(theta)**2)**31.5*(9.00527943126253e+142*cos(theta)**36 - 2.87986093487076e+143*cos(theta)**34 + 4.14256919092947e+143*cos(theta)**32 - 3.54872939326601e+143*cos(theta)**30 + 2.02054618595643e+143*cos(theta)**28 - 8.08218474382573e+142*cos(theta)**26 + 2.34109629388891e+142*cos(theta)**24 - 4.98951796998718e+141*cos(theta)**22 + 7.87280499362732e+140*cos(theta)**20 - 9.18252270588822e+139*cos(theta)**18 + 7.84874845810557e+138*cos(theta)**16 - 4.83744126847801e+137*cos(theta)**14 + 2.0962245496738e+136*cos(theta)**12 - 6.15165941656163e+134*cos(theta)**10 + 1.15632695800031e+133*cos(theta)**8 - 1.27720531850132e+131*cos(theta)**6 + 7.16994003649696e+128*cos(theta)**4 - 1.53367701315443e+126*cos(theta)**2 + 5.2272563502196e+122)*cos(63*phi)

#@torch.jit.script
def Yl99_m64(theta, phi):
    return 1.27779316393445e-125*(1.0 - cos(theta)**2)**32*(3.24190059525451e+144*cos(theta)**35 - 9.79152717856058e+144*cos(theta)**33 + 1.32562214109743e+145*cos(theta)**31 - 1.0646188179798e+145*cos(theta)**29 + 5.65752932067801e+144*cos(theta)**27 - 2.10136803339469e+144*cos(theta)**25 + 5.61863110533339e+143*cos(theta)**23 - 1.09769395339718e+143*cos(theta)**21 + 1.57456099872546e+142*cos(theta)**19 - 1.65285408705988e+141*cos(theta)**17 + 1.25579975329689e+140*cos(theta)**15 - 6.77241777586921e+138*cos(theta)**13 + 2.51546945960856e+137*cos(theta)**11 - 6.15165941656163e+135*cos(theta)**9 + 9.25061566400245e+133*cos(theta)**7 - 7.66323191100795e+131*cos(theta)**5 + 2.86797601459878e+129*cos(theta)**3 - 3.06735402630886e+126*cos(theta))*cos(64*phi)

#@torch.jit.script
def Yl99_m65(theta, phi):
    return 1.68657094430387e-127*(1.0 - cos(theta)**2)**32.5*(1.13466520833908e+146*cos(theta)**34 - 3.23120396892499e+146*cos(theta)**32 + 4.10942863740204e+146*cos(theta)**30 - 3.08739457214143e+146*cos(theta)**28 + 1.52753291658306e+146*cos(theta)**26 - 5.25342008348672e+145*cos(theta)**24 + 1.29228515422668e+145*cos(theta)**22 - 2.30515730213408e+144*cos(theta)**20 + 2.99166589757838e+143*cos(theta)**18 - 2.80985194800179e+142*cos(theta)**16 + 1.88369962994534e+141*cos(theta)**14 - 8.80414310862998e+139*cos(theta)**12 + 2.76701640556942e+138*cos(theta)**10 - 5.53649347490547e+136*cos(theta)**8 + 6.47543096480172e+134*cos(theta)**6 - 3.83161595550397e+132*cos(theta)**4 + 8.60392804379635e+129*cos(theta)**2 - 3.06735402630886e+126)*cos(65*phi)

#@torch.jit.script
def Yl99_m66(theta, phi):
    return 2.25176561747111e-129*(1.0 - cos(theta)**2)**33*(3.85786170835287e+147*cos(theta)**33 - 1.033985270056e+148*cos(theta)**31 + 1.23282859122061e+148*cos(theta)**29 - 8.644704801996e+147*cos(theta)**27 + 3.97158558311596e+147*cos(theta)**25 - 1.26082082003681e+147*cos(theta)**23 + 2.8430273392987e+146*cos(theta)**21 - 4.61031460426816e+145*cos(theta)**19 + 5.38499861564109e+144*cos(theta)**17 - 4.49576311680287e+143*cos(theta)**15 + 2.63717948192347e+142*cos(theta)**13 - 1.0564971730356e+141*cos(theta)**11 + 2.76701640556942e+139*cos(theta)**9 - 4.42919477992437e+137*cos(theta)**7 + 3.88525857888103e+135*cos(theta)**5 - 1.53264638220159e+133*cos(theta)**3 + 1.72078560875927e+130*cos(theta))*cos(66*phi)

#@torch.jit.script
def Yl99_m67(theta, phi):
    return 3.0423709780951e-131*(1.0 - cos(theta)**2)**33.5*(1.27309436375645e+149*cos(theta)**32 - 3.20535433717359e+149*cos(theta)**30 + 3.57520291453977e+149*cos(theta)**28 - 2.33407029653892e+149*cos(theta)**26 + 9.92896395778991e+148*cos(theta)**24 - 2.89988788608467e+148*cos(theta)**22 + 5.97035741252726e+147*cos(theta)**20 - 8.7595977481095e+146*cos(theta)**18 + 9.15449764658984e+145*cos(theta)**16 - 6.74364467520431e+144*cos(theta)**14 + 3.42833332650051e+143*cos(theta)**12 - 1.16214689033916e+142*cos(theta)**10 + 2.49031476501248e+140*cos(theta)**8 - 3.10043634594706e+138*cos(theta)**6 + 1.94262928944051e+136*cos(theta)**4 - 4.59793914660477e+133*cos(theta)**2 + 1.72078560875927e+130)*cos(67*phi)

#@torch.jit.script
def Yl99_m68(theta, phi):
    return 4.16177833298225e-133*(1.0 - cos(theta)**2)**34*(4.07390196402063e+150*cos(theta)**31 - 9.61606301152077e+150*cos(theta)**29 + 1.00105681607114e+151*cos(theta)**27 - 6.06858277100119e+150*cos(theta)**25 + 2.38295134986958e+150*cos(theta)**23 - 6.37975334938628e+149*cos(theta)**21 + 1.19407148250545e+149*cos(theta)**19 - 1.57672759465971e+148*cos(theta)**17 + 1.46471962345438e+147*cos(theta)**15 - 9.44110254528603e+145*cos(theta)**13 + 4.11399999180062e+144*cos(theta)**11 - 1.16214689033916e+143*cos(theta)**9 + 1.99225181200998e+141*cos(theta)**7 - 1.86026180756824e+139*cos(theta)**5 + 7.77051715776206e+136*cos(theta)**3 - 9.19587829320954e+133*cos(theta))*cos(68*phi)

#@torch.jit.script
def Yl99_m69(theta, phi):
    return 5.76691376224479e-135*(1.0 - cos(theta)**2)**34.5*(1.26290960884639e+152*cos(theta)**30 - 2.78865827334102e+152*cos(theta)**28 + 2.70285340339207e+152*cos(theta)**26 - 1.5171456927503e+152*cos(theta)**24 + 5.48078810470003e+151*cos(theta)**22 - 1.33974820337112e+151*cos(theta)**20 + 2.26873581676036e+150*cos(theta)**18 - 2.68043691092151e+149*cos(theta)**16 + 2.19707943518156e+148*cos(theta)**14 - 1.22734333088718e+147*cos(theta)**12 + 4.52539999098068e+145*cos(theta)**10 - 1.04593220130524e+144*cos(theta)**8 + 1.39457626840699e+142*cos(theta)**6 - 9.30130903784118e+139*cos(theta)**4 + 2.33115514732862e+137*cos(theta)**2 - 9.19587829320954e+133)*cos(69*phi)

#@torch.jit.script
def Yl99_m70(theta, phi):
    return 8.09915065325245e-137*(1.0 - cos(theta)**2)**35*(3.78872882653918e+153*cos(theta)**29 - 7.80824316535486e+153*cos(theta)**27 + 7.02741884881938e+153*cos(theta)**25 - 3.64114966260071e+153*cos(theta)**23 + 1.20577338303401e+153*cos(theta)**21 - 2.67949640674224e+152*cos(theta)**19 + 4.08372447016865e+151*cos(theta)**17 - 4.28869905747441e+150*cos(theta)**15 + 3.07591120925419e+149*cos(theta)**13 - 1.47281199706462e+148*cos(theta)**11 + 4.52539999098068e+146*cos(theta)**9 - 8.36745761044193e+144*cos(theta)**7 + 8.36745761044193e+142*cos(theta)**5 - 3.72052361513647e+140*cos(theta)**3 + 4.66231029465724e+137*cos(theta))*cos(70*phi)

#@torch.jit.script
def Yl99_m71(theta, phi):
    return 1.15349580057704e-138*(1.0 - cos(theta)**2)**35.5*(1.09873135969636e+155*cos(theta)**28 - 2.10822565464581e+155*cos(theta)**26 + 1.75685471220484e+155*cos(theta)**24 - 8.37464422398164e+154*cos(theta)**22 + 2.53212410437141e+154*cos(theta)**20 - 5.09104317281025e+153*cos(theta)**18 + 6.9423315992867e+152*cos(theta)**16 - 6.43304858621162e+151*cos(theta)**14 + 3.99868457203044e+150*cos(theta)**12 - 1.62009319677108e+149*cos(theta)**10 + 4.07285999188261e+147*cos(theta)**8 - 5.85722032730935e+145*cos(theta)**6 + 4.18372880522096e+143*cos(theta)**4 - 1.11615708454094e+141*cos(theta)**2 + 4.66231029465724e+137)*cos(71*phi)

#@torch.jit.script
def Yl99_m72(theta, phi):
    return 1.66701284747427e-140*(1.0 - cos(theta)**2)**36*(3.07644780714982e+156*cos(theta)**27 - 5.48138670207912e+156*cos(theta)**25 + 4.21645130929163e+156*cos(theta)**23 - 1.84242172927596e+156*cos(theta)**21 + 5.06424820874283e+155*cos(theta)**19 - 9.16387771105845e+154*cos(theta)**17 + 1.11077305588587e+154*cos(theta)**15 - 9.00626802069626e+152*cos(theta)**13 + 4.79842148643653e+151*cos(theta)**11 - 1.62009319677108e+150*cos(theta)**9 + 3.25828799350609e+148*cos(theta)**7 - 3.51433219638561e+146*cos(theta)**5 + 1.67349152208839e+144*cos(theta)**3 - 2.23231416908188e+141*cos(theta))*cos(72*phi)

#@torch.jit.script
def Yl99_m73(theta, phi):
    return 2.4462049540253e-142*(1.0 - cos(theta)**2)**36.5*(8.30640907930451e+157*cos(theta)**26 - 1.37034667551978e+158*cos(theta)**24 + 9.69783801137074e+157*cos(theta)**22 - 3.86908563147952e+157*cos(theta)**20 + 9.62207159661137e+156*cos(theta)**18 - 1.55785921087994e+156*cos(theta)**16 + 1.66615958382881e+155*cos(theta)**14 - 1.17081484269051e+154*cos(theta)**12 + 5.27826363508019e+152*cos(theta)**10 - 1.45808387709397e+151*cos(theta)**8 + 2.28080159545426e+149*cos(theta)**6 - 1.75716609819281e+147*cos(theta)**4 + 5.02047456626516e+144*cos(theta)**2 - 2.23231416908188e+141)*cos(73*phi)

#@torch.jit.script
def Yl99_m74(theta, phi):
    return 3.64739766562535e-144*(1.0 - cos(theta)**2)**37*(2.15966636061917e+159*cos(theta)**25 - 3.28883202124747e+159*cos(theta)**23 + 2.13352436250156e+159*cos(theta)**21 - 7.73817126295904e+158*cos(theta)**19 + 1.73197288739005e+158*cos(theta)**17 - 2.4925747374079e+157*cos(theta)**15 + 2.33262341736033e+156*cos(theta)**13 - 1.40497781122862e+155*cos(theta)**11 + 5.27826363508019e+153*cos(theta)**9 - 1.16646710167518e+152*cos(theta)**7 + 1.36848095727256e+150*cos(theta)**5 - 7.02866439277122e+147*cos(theta)**3 + 1.00409491325303e+145*cos(theta))*cos(74*phi)

#@torch.jit.script
def Yl99_m75(theta, phi):
    return 5.53017006892967e-146*(1.0 - cos(theta)**2)**37.5*(5.39916590154793e+160*cos(theta)**24 - 7.56431364886918e+160*cos(theta)**22 + 4.48040116125328e+160*cos(theta)**20 - 1.47025253996222e+160*cos(theta)**18 + 2.94435390856308e+159*cos(theta)**16 - 3.73886210611185e+158*cos(theta)**14 + 3.03241044256843e+157*cos(theta)**12 - 1.54547559235148e+156*cos(theta)**10 + 4.75043727157217e+154*cos(theta)**8 - 8.16526971172625e+152*cos(theta)**6 + 6.84240478636278e+150*cos(theta)**4 - 2.10859931783137e+148*cos(theta)**2 + 1.00409491325303e+145)*cos(75*phi)

#@torch.jit.script
def Yl99_m76(theta, phi):
    return 8.53323767495941e-148*(1.0 - cos(theta)**2)**38*(1.2957998163715e+162*cos(theta)**23 - 1.66414900275122e+162*cos(theta)**21 + 8.96080232250657e+161*cos(theta)**19 - 2.64645457193199e+161*cos(theta)**17 + 4.71096625370093e+160*cos(theta)**15 - 5.23440694855658e+159*cos(theta)**13 + 3.63889253108212e+158*cos(theta)**11 - 1.54547559235148e+157*cos(theta)**9 + 3.80034981725773e+155*cos(theta)**7 - 4.89916182703575e+153*cos(theta)**5 + 2.73696191454511e+151*cos(theta)**3 - 4.21719863566273e+148*cos(theta))*cos(76*phi)

#@torch.jit.script
def Yl99_m77(theta, phi):
    return 1.34120014040935e-149*(1.0 - cos(theta)**2)**38.5*(2.98033957765446e+163*cos(theta)**22 - 3.49471290577756e+163*cos(theta)**20 + 1.70255244127625e+163*cos(theta)**18 - 4.49897277228438e+162*cos(theta)**16 + 7.06644938055139e+161*cos(theta)**14 - 6.80472903312356e+160*cos(theta)**12 + 4.00278178419033e+159*cos(theta)**10 - 1.39092803311633e+158*cos(theta)**8 + 2.66024487208041e+156*cos(theta)**6 - 2.44958091351788e+154*cos(theta)**4 + 8.21088574363534e+151*cos(theta)**2 - 4.21719863566273e+148)*cos(77*phi)

#@torch.jit.script
def Yl99_m78(theta, phi):
    return 2.14929296232254e-151*(1.0 - cos(theta)**2)**39*(6.5567470708398e+164*cos(theta)**21 - 6.98942581155512e+164*cos(theta)**19 + 3.06459439429725e+164*cos(theta)**17 - 7.19835643565502e+163*cos(theta)**15 + 9.89302913277194e+162*cos(theta)**13 - 8.16567483974827e+161*cos(theta)**11 + 4.00278178419033e+160*cos(theta)**9 - 1.11274242649306e+159*cos(theta)**7 + 1.59614692324825e+157*cos(theta)**5 - 9.79832365407151e+154*cos(theta)**3 + 1.64217714872707e+152*cos(theta))*cos(78*phi)

#@torch.jit.script
def Yl99_m79(theta, phi):
    return 3.51540987303224e-153*(1.0 - cos(theta)**2)**39.5*(1.37691688487636e+166*cos(theta)**20 - 1.32799090419547e+166*cos(theta)**18 + 5.20981047030532e+165*cos(theta)**16 - 1.07975346534825e+165*cos(theta)**14 + 1.28609378726035e+164*cos(theta)**12 - 8.9822423237231e+162*cos(theta)**10 + 3.6025036057713e+161*cos(theta)**8 - 7.78919698545145e+159*cos(theta)**6 + 7.98073461624124e+157*cos(theta)**4 - 2.93949709622145e+155*cos(theta)**2 + 1.64217714872707e+152)*cos(79*phi)

#@torch.jit.script
def Yl99_m80(theta, phi):
    return 5.87535962893411e-155*(1.0 - cos(theta)**2)**40*(2.75383376975272e+167*cos(theta)**19 - 2.39038362755185e+167*cos(theta)**17 + 8.33569675248851e+166*cos(theta)**15 - 1.51165485148755e+166*cos(theta)**13 + 1.54331254471242e+165*cos(theta)**11 - 8.9822423237231e+163*cos(theta)**9 + 2.88200288461704e+162*cos(theta)**7 - 4.67351819127087e+160*cos(theta)**5 + 3.1922938464965e+158*cos(theta)**3 - 5.8789941924429e+155*cos(theta))*cos(80*phi)

#@torch.jit.script
def Yl99_m81(theta, phi):
    return 1.00466529833358e-156*(1.0 - cos(theta)**2)**40.5*(5.23228416253016e+168*cos(theta)**18 - 4.06365216683815e+168*cos(theta)**16 + 1.25035451287328e+168*cos(theta)**14 - 1.96515130693382e+167*cos(theta)**12 + 1.69764379918367e+166*cos(theta)**10 - 8.08401809135079e+164*cos(theta)**8 + 2.01740201923193e+163*cos(theta)**6 - 2.33675909563544e+161*cos(theta)**4 + 9.57688153948949e+158*cos(theta)**2 - 5.8789941924429e+155)*cos(81*phi)

#@torch.jit.script
def Yl99_m82(theta, phi):
    return 1.76013452531153e-158*(1.0 - cos(theta)**2)**41*(9.41811149255429e+169*cos(theta)**17 - 6.50184346694104e+169*cos(theta)**15 + 1.75049631802259e+169*cos(theta)**13 - 2.35818156832058e+168*cos(theta)**11 + 1.69764379918367e+167*cos(theta)**9 - 6.46721447308063e+165*cos(theta)**7 + 1.21044121153916e+164*cos(theta)**5 - 9.34703638254174e+161*cos(theta)**3 + 1.9153763078979e+159*cos(theta))*cos(82*phi)

#@torch.jit.script
def Yl99_m83(theta, phi):
    return 3.16435869605775e-160*(1.0 - cos(theta)**2)**41.5*(1.60107895373423e+171*cos(theta)**16 - 9.75276520041155e+170*cos(theta)**14 + 2.27564521342936e+170*cos(theta)**12 - 2.59399972515264e+169*cos(theta)**10 + 1.5278794192653e+168*cos(theta)**8 - 4.52705013115644e+166*cos(theta)**6 + 6.05220605769578e+164*cos(theta)**4 - 2.80411091476252e+162*cos(theta)**2 + 1.9153763078979e+159)*cos(83*phi)

#@torch.jit.script
def Yl99_m84(theta, phi):
    return 5.84790314263991e-162*(1.0 - cos(theta)**2)**42*(2.56172632597477e+172*cos(theta)**15 - 1.36538712805762e+172*cos(theta)**13 + 2.73077425611524e+171*cos(theta)**11 - 2.59399972515264e+170*cos(theta)**9 + 1.22230353541224e+169*cos(theta)**7 - 2.71623007869387e+167*cos(theta)**5 + 2.42088242307831e+165*cos(theta)**3 - 5.60822182952505e+162*cos(theta))*cos(84*phi)

#@torch.jit.script
def Yl99_m85(theta, phi):
    return 1.11312933942709e-163*(1.0 - cos(theta)**2)**42.5*(3.84258948896215e+173*cos(theta)**14 - 1.7750032664749e+173*cos(theta)**12 + 3.00385168172676e+172*cos(theta)**10 - 2.33459975263738e+171*cos(theta)**8 + 8.55612474788568e+169*cos(theta)**6 - 1.35811503934693e+168*cos(theta)**4 + 7.26264726923493e+165*cos(theta)**2 - 5.60822182952505e+162)*cos(85*phi)

#@torch.jit.script
def Yl99_m86(theta, phi):
    return 2.18723651588537e-165*(1.0 - cos(theta)**2)**43*(5.37962528454701e+174*cos(theta)**13 - 2.13000391976988e+174*cos(theta)**11 + 3.00385168172676e+173*cos(theta)**9 - 1.8676798021099e+172*cos(theta)**7 + 5.13367484873141e+170*cos(theta)**5 - 5.43246015738773e+168*cos(theta)**3 + 1.45252945384699e+166*cos(theta))*cos(86*phi)

#@torch.jit.script
def Yl99_m87(theta, phi):
    return 4.44802889237332e-167*(1.0 - cos(theta)**2)**43.5*(6.99351286991112e+175*cos(theta)**12 - 2.34300431174687e+175*cos(theta)**10 + 2.70346651355408e+174*cos(theta)**8 - 1.30737586147693e+173*cos(theta)**6 + 2.5668374243657e+171*cos(theta)**4 - 1.62973804721632e+169*cos(theta)**2 + 1.45252945384699e+166)*cos(87*phi)

#@torch.jit.script
def Yl99_m88(theta, phi):
    return 9.38979635152534e-169*(1.0 - cos(theta)**2)**44*(8.39221544389334e+176*cos(theta)**11 - 2.34300431174687e+176*cos(theta)**9 + 2.16277321084327e+175*cos(theta)**7 - 7.84425516886159e+173*cos(theta)**5 + 1.02673496974628e+172*cos(theta)**3 - 3.25947609443264e+169*cos(theta))*cos(88*phi)

#@torch.jit.script
def Yl99_m89(theta, phi):
    return 2.06481385679361e-170*(1.0 - cos(theta)**2)**44.5*(9.23143698828267e+177*cos(theta)**10 - 2.10870388057218e+177*cos(theta)**8 + 1.51394124759029e+176*cos(theta)**6 - 3.92212758443079e+174*cos(theta)**4 + 3.08020490923884e+172*cos(theta)**2 - 3.25947609443264e+169)*cos(89*phi)

#@torch.jit.script
def Yl99_m90(theta, phi):
    return 4.74952309675375e-172*(1.0 - cos(theta)**2)**45*(9.23143698828267e+178*cos(theta)**9 - 1.68696310445775e+178*cos(theta)**7 + 9.08364748554172e+176*cos(theta)**5 - 1.56885103377232e+175*cos(theta)**3 + 6.16040981847769e+172*cos(theta))*cos(90*phi)

#@torch.jit.script
def Yl99_m91(theta, phi):
    return 1.1485554020146e-173*(1.0 - cos(theta)**2)**45.5*(8.30829328945441e+179*cos(theta)**8 - 1.18087417312042e+179*cos(theta)**6 + 4.54182374277086e+177*cos(theta)**4 - 4.70655310131695e+175*cos(theta)**2 + 6.16040981847769e+172)*cos(91*phi)

#@torch.jit.script
def Yl99_m92(theta, phi):
    return 2.93826032991311e-175*(1.0 - cos(theta)**2)**46*(6.64663463156353e+180*cos(theta)**7 - 7.08524503872254e+179*cos(theta)**5 + 1.81672949710834e+178*cos(theta)**3 - 9.41310620263391e+175*cos(theta))*cos(92*phi)

#@torch.jit.script
def Yl99_m93(theta, phi):
    return 8.01476212697188e-177*(1.0 - cos(theta)**2)**46.5*(4.65264424209447e+181*cos(theta)**6 - 3.54262251936127e+180*cos(theta)**4 + 5.45018849132503e+178*cos(theta)**2 - 9.41310620263391e+175)*cos(93*phi)

#@torch.jit.script
def Yl99_m94(theta, phi):
    return 2.35524644856989e-178*(1.0 - cos(theta)**2)**47*(2.79158654525668e+182*cos(theta)**5 - 1.41704900774451e+181*cos(theta)**3 + 1.09003769826501e+179*cos(theta))*cos(94*phi)

#@torch.jit.script
def Yl99_m95(theta, phi):
    return 7.56224059519393e-180*(1.0 - cos(theta)**2)**47.5*(1.39579327262834e+183*cos(theta)**4 - 4.25114702323352e+181*cos(theta)**2 + 1.09003769826501e+179)*cos(95*phi)

#@torch.jit.script
def Yl99_m96(theta, phi):
    return 2.70771648564159e-181*(1.0 - cos(theta)**2)**48*(5.58317309051336e+183*cos(theta)**3 - 8.50229404646705e+181*cos(theta))*cos(96*phi)

#@torch.jit.script
def Yl99_m97(theta, phi):
    return 1.11664345848169e-182*(1.0 - cos(theta)**2)**48.5*(1.67495192715401e+184*cos(theta)**2 - 8.50229404646705e+181)*cos(97*phi)

#@torch.jit.script
def Yl99_m98(theta, phi):
    return 18.8451135102262*(1.0 - cos(theta)**2)**49*cos(98*phi)*cos(theta)

#@torch.jit.script
def Yl99_m99(theta, phi):
    return 1.339263900061*(1.0 - cos(theta)**2)**49.5*cos(99*phi)

#@torch.jit.script
def Yl100_m_minus_100(theta, phi):
    return 1.34260788504189*(1.0 - cos(theta)**2)**50*sin(100*phi)

#@torch.jit.script
def Yl100_m_minus_99(theta, phi):
    return 18.9873427997529*(1.0 - cos(theta)**2)**49.5*sin(99*phi)*cos(theta)

#@torch.jit.script
def Yl100_m_minus_98(theta, phi):
    return 5.68224962145241e-185*(1.0 - cos(theta)**2)**49*(3.33315433503648e+186*cos(theta)**2 - 1.67495192715401e+184)*sin(98*phi)

#@torch.jit.script
def Yl100_m_minus_97(theta, phi):
    return 1.38488442448223e-183*(1.0 - cos(theta)**2)**48.5*(1.11105144501216e+186*cos(theta)**3 - 1.67495192715401e+184*cos(theta))*sin(97*phi)

#@torch.jit.script
def Yl100_m_minus_96(theta, phi):
    return 3.88755583485137e-182*(1.0 - cos(theta)**2)**48*(2.7776286125304e+185*cos(theta)**4 - 8.37475963577004e+183*cos(theta)**2 + 2.12557351161676e+181)*sin(96*phi)

#@torch.jit.script
def Yl100_m_minus_95(theta, phi):
    return 1.21699747582751e-180*(1.0 - cos(theta)**2)**47.5*(5.55525722506079e+184*cos(theta)**5 - 2.79158654525668e+183*cos(theta)**3 + 2.12557351161676e+181*cos(theta))*sin(95*phi)

#@torch.jit.script
def Yl100_m_minus_94(theta, phi):
    return 4.16277184303861e-179*(1.0 - cos(theta)**2)**47*(9.25876204176799e+183*cos(theta)**6 - 6.9789663631417e+182*cos(theta)**4 + 1.06278675580838e+181*cos(theta)**2 - 1.81672949710834e+178)*sin(94*phi)

#@torch.jit.script
def Yl100_m_minus_93(theta, phi):
    return 1.53402519759458e-177*(1.0 - cos(theta)**2)**46.5*(1.32268029168114e+183*cos(theta)**7 - 1.39579327262834e+182*cos(theta)**5 + 3.54262251936127e+180*cos(theta)**3 - 1.81672949710834e+178*cos(theta))*sin(93*phi)

#@torch.jit.script
def Yl100_m_minus_92(theta, phi):
    return 6.02776262454342e-176*(1.0 - cos(theta)**2)**46*(1.65335036460143e+182*cos(theta)**8 - 2.32632212104723e+181*cos(theta)**6 + 8.85655629840317e+179*cos(theta)**4 - 9.08364748554172e+177*cos(theta)**2 + 1.17663827532924e+175)*sin(92*phi)

#@torch.jit.script
def Yl100_m_minus_91(theta, phi):
    return 2.50569386920174e-174*(1.0 - cos(theta)**2)**45.5*(1.83705596066825e+181*cos(theta)**9 - 3.32331731578176e+180*cos(theta)**7 + 1.77131125968064e+179*cos(theta)**5 - 3.02788249518057e+177*cos(theta)**3 + 1.17663827532924e+175*cos(theta))*sin(91*phi)

#@torch.jit.script
def Yl100_m_minus_90(theta, phi):
    return 1.09507709196003e-172*(1.0 - cos(theta)**2)**45*(1.83705596066825e+180*cos(theta)**10 - 4.1541466447272e+179*cos(theta)**8 + 2.95218543280106e+178*cos(theta)**6 - 7.56970623795143e+176*cos(theta)**4 + 5.88319137664619e+174*cos(theta)**2 - 6.16040981847769e+171)*sin(90*phi)

#@torch.jit.script
def Yl100_m_minus_89(theta, phi):
    return 5.00631113698649e-171*(1.0 - cos(theta)**2)**44.5*(1.67005087333477e+179*cos(theta)**11 - 4.61571849414134e+178*cos(theta)**9 + 4.21740776114437e+177*cos(theta)**7 - 1.51394124759029e+176*cos(theta)**5 + 1.9610637922154e+174*cos(theta)**3 - 6.16040981847769e+171*cos(theta))*sin(89*phi)

#@torch.jit.script
def Yl100_m_minus_88(theta, phi):
    return 2.38418176577027e-169*(1.0 - cos(theta)**2)**44*(1.39170906111231e+178*cos(theta)**12 - 4.61571849414134e+177*cos(theta)**10 + 5.27175970143046e+176*cos(theta)**8 - 2.52323541265048e+175*cos(theta)**6 + 4.90265948053849e+173*cos(theta)**4 - 3.08020490923884e+171*cos(theta)**2 + 2.71623007869387e+168)*sin(88*phi)

#@torch.jit.script
def Yl100_m_minus_87(theta, phi):
    return 1.17866384774513e-167*(1.0 - cos(theta)**2)**43.5*(1.07054543162486e+177*cos(theta)**13 - 4.19610772194667e+176*cos(theta)**11 + 5.85751077936718e+175*cos(theta)**9 - 3.60462201807211e+174*cos(theta)**7 + 9.80531896107698e+172*cos(theta)**5 - 1.02673496974628e+171*cos(theta)**3 + 2.71623007869387e+168*cos(theta))*sin(87*phi)

#@torch.jit.script
def Yl100_m_minus_86(theta, phi):
    return 6.03079802674505e-166*(1.0 - cos(theta)**2)**43*(7.64675308303468e+175*cos(theta)**14 - 3.49675643495556e+175*cos(theta)**12 + 5.85751077936718e+174*cos(theta)**10 - 4.50577752259014e+173*cos(theta)**8 + 1.63421982684616e+172*cos(theta)**6 - 2.5668374243657e+170*cos(theta)**4 + 1.35811503934693e+168*cos(theta)**2 - 1.03752103846213e+165)*sin(86*phi)

#@torch.jit.script
def Yl100_m_minus_85(theta, phi):
    return 3.18549469159664e-164*(1.0 - cos(theta)**2)**42.5*(5.09783538868979e+174*cos(theta)**15 - 2.68981264227351e+174*cos(theta)**13 + 5.32500979942471e+173*cos(theta)**11 - 5.0064194695446e+172*cos(theta)**9 + 2.33459975263738e+171*cos(theta)**7 - 5.13367484873141e+169*cos(theta)**5 + 4.52705013115644e+167*cos(theta)**3 - 1.03752103846213e+165*cos(theta))*sin(85*phi)

#@torch.jit.script
def Yl100_m_minus_84(theta, phi):
    return 1.7330964841394e-162*(1.0 - cos(theta)**2)**42*(3.18614711793112e+173*cos(theta)**16 - 1.92129474448108e+173*cos(theta)**14 + 4.43750816618726e+172*cos(theta)**12 - 5.0064194695446e+171*cos(theta)**10 + 2.91824969079672e+170*cos(theta)**8 - 8.55612474788568e+168*cos(theta)**6 + 1.13176253278911e+167*cos(theta)**4 - 5.18760519231067e+164*cos(theta)**2 + 3.50513864345315e+161)*sin(84*phi)

#@torch.jit.script
def Yl100_m_minus_83(theta, phi):
    return 9.69295314555688e-161*(1.0 - cos(theta)**2)**41.5*(1.8742041870183e+172*cos(theta)**17 - 1.28086316298738e+172*cos(theta)**15 + 3.41346782014404e+171*cos(theta)**13 - 4.55129042685872e+170*cos(theta)**11 + 3.2424996564408e+169*cos(theta)**9 - 1.22230353541224e+168*cos(theta)**7 + 2.26352506557822e+166*cos(theta)**5 - 1.72920173077022e+164*cos(theta)**3 + 3.50513864345315e+161*cos(theta))*sin(83*phi)

#@torch.jit.script
def Yl100_m_minus_82(theta, phi):
    return 5.56311337477837e-159*(1.0 - cos(theta)**2)**41*(1.0412245483435e+171*cos(theta)**18 - 8.00539476867115e+170*cos(theta)**16 + 2.43819130010289e+170*cos(theta)**14 - 3.79274202238227e+169*cos(theta)**12 + 3.2424996564408e+168*cos(theta)**10 - 1.5278794192653e+167*cos(theta)**8 + 3.7725417759637e+165*cos(theta)**6 - 4.32300432692556e+163*cos(theta)**4 + 1.75256932172658e+161*cos(theta)**2 - 1.06409794883217e+158)*sin(82*phi)

#@torch.jit.script
def Yl100_m_minus_81(theta, phi):
    return 3.27137556380441e-157*(1.0 - cos(theta)**2)**40.5*(5.48012920180791e+169*cos(theta)**19 - 4.70905574627715e+169*cos(theta)**17 + 1.62546086673526e+169*cos(theta)**15 - 2.91749386337098e+168*cos(theta)**13 + 2.94772696040073e+167*cos(theta)**11 - 1.69764379918367e+166*cos(theta)**9 + 5.38934539423386e+164*cos(theta)**7 - 8.64600865385111e+162*cos(theta)**5 + 5.84189773908859e+160*cos(theta)**3 - 1.06409794883217e+158*cos(theta))*sin(81*phi)

#@torch.jit.script
def Yl100_m_minus_80(theta, phi):
    return 1.96827007922269e-155*(1.0 - cos(theta)**2)**40*(2.74006460090395e+168*cos(theta)**20 - 2.61614208126508e+168*cos(theta)**18 + 1.01591304170954e+168*cos(theta)**16 - 2.08392418812213e+167*cos(theta)**14 + 2.45643913366727e+166*cos(theta)**12 - 1.69764379918367e+165*cos(theta)**10 + 6.73668174279232e+163*cos(theta)**8 - 1.44100144230852e+162*cos(theta)**6 + 1.46047443477215e+160*cos(theta)**4 - 5.32048974416083e+157*cos(theta)**2 + 2.93949709622145e+154)*sin(80*phi)

#@torch.jit.script
def Yl100_m_minus_79(theta, phi):
    return 1.21012599575438e-153*(1.0 - cos(theta)**2)**39.5*(1.30479266709712e+167*cos(theta)**21 - 1.37691688487636e+167*cos(theta)**19 + 5.97595906887963e+166*cos(theta)**17 - 1.38928279208142e+166*cos(theta)**15 + 1.88956856435944e+165*cos(theta)**13 - 1.54331254471242e+164*cos(theta)**11 + 7.48520193643592e+162*cos(theta)**9 - 2.05857348901217e+161*cos(theta)**7 + 2.92094886954429e+159*cos(theta)**5 - 1.77349658138694e+157*cos(theta)**3 + 2.93949709622145e+154*cos(theta))*sin(79*phi)

#@torch.jit.script
def Yl100_m_minus_78(theta, phi):
    return 7.59396246831315e-152*(1.0 - cos(theta)**2)**39*(5.93087575953237e+165*cos(theta)**22 - 6.88458442438179e+165*cos(theta)**20 + 3.31997726048868e+165*cos(theta)**18 - 8.68301745050886e+164*cos(theta)**16 + 1.34969183168532e+164*cos(theta)**14 - 1.28609378726035e+163*cos(theta)**12 + 7.48520193643592e+161*cos(theta)**10 - 2.57321686126521e+160*cos(theta)**8 + 4.86824811590716e+158*cos(theta)**6 - 4.43374145346736e+156*cos(theta)**4 + 1.46974854811073e+154*cos(theta)**2 - 7.46444158512304e+150)*sin(78*phi)

#@torch.jit.script
def Yl100_m_minus_77(theta, phi):
    return 4.85894927820603e-150*(1.0 - cos(theta)**2)**38.5*(2.57864163457929e+164*cos(theta)**23 - 3.2783735354199e+164*cos(theta)**21 + 1.74735645288878e+164*cos(theta)**19 - 5.10765732382874e+163*cos(theta)**17 + 8.99794554456877e+162*cos(theta)**15 - 9.89302913277194e+161*cos(theta)**13 + 6.80472903312356e+160*cos(theta)**11 - 2.85912984585024e+159*cos(theta)**9 + 6.95464016558165e+157*cos(theta)**7 - 8.86748290693471e+155*cos(theta)**5 + 4.89916182703575e+153*cos(theta)**3 - 7.46444158512304e+150*cos(theta))*sin(77*phi)

#@torch.jit.script
def Yl100_m_minus_76(theta, phi):
    return 3.16690196562167e-148*(1.0 - cos(theta)**2)**38*(1.07443401440804e+163*cos(theta)**24 - 1.49016978882723e+163*cos(theta)**22 + 8.7367822644439e+162*cos(theta)**20 - 2.83758740212708e+162*cos(theta)**18 + 5.62371596535548e+161*cos(theta)**16 - 7.06644938055139e+160*cos(theta)**14 + 5.67060752760297e+159*cos(theta)**12 - 2.85912984585024e+158*cos(theta)**10 + 8.69330020697707e+156*cos(theta)**8 - 1.47791381782245e+155*cos(theta)**6 + 1.22479045675894e+153*cos(theta)**4 - 3.73222079256152e+150*cos(theta)**2 + 1.75716609819281e+147)*sin(76*phi)

#@torch.jit.script
def Yl100_m_minus_75(theta, phi):
    return 2.10068511356121e-146*(1.0 - cos(theta)**2)**37.5*(4.29773605763215e+161*cos(theta)**25 - 6.47899908185751e+161*cos(theta)**23 + 4.16037250687805e+161*cos(theta)**21 - 1.49346705375109e+161*cos(theta)**19 + 3.30806821491499e+160*cos(theta)**17 - 4.71096625370093e+159*cos(theta)**15 + 4.36200579046382e+158*cos(theta)**13 - 2.59920895077294e+157*cos(theta)**11 + 9.65922245219674e+155*cos(theta)**9 - 2.11130545403207e+154*cos(theta)**7 + 2.44958091351788e+152*cos(theta)**5 - 1.24407359752051e+150*cos(theta)**3 + 1.75716609819281e+147*cos(theta))*sin(75*phi)

#@torch.jit.script
def Yl100_m_minus_74(theta, phi):
    return 1.41698957850213e-144*(1.0 - cos(theta)**2)**37*(1.6529754067816e+160*cos(theta)**26 - 2.69958295077396e+160*cos(theta)**24 + 1.89107841221729e+160*cos(theta)**22 - 7.46733526875547e+159*cos(theta)**20 + 1.83781567495277e+159*cos(theta)**18 - 2.94435390856308e+158*cos(theta)**16 + 3.11571842175987e+157*cos(theta)**14 - 2.16600745897745e+156*cos(theta)**12 + 9.65922245219674e+154*cos(theta)**10 - 2.63913181754009e+153*cos(theta)**8 + 4.08263485586313e+151*cos(theta)**6 - 3.11018399380127e+149*cos(theta)**4 + 8.78583049096403e+146*cos(theta)**2 - 3.86190351251166e+143)*sin(74*phi)

#@torch.jit.script
def Yl100_m_minus_73(theta, phi):
    return 9.71232401092137e-143*(1.0 - cos(theta)**2)**36.5*(6.12213113622813e+158*cos(theta)**27 - 1.07983318030959e+159*cos(theta)**25 + 8.22208005311867e+158*cos(theta)**23 - 3.55587393750261e+158*cos(theta)**21 + 9.6727140786988e+157*cos(theta)**19 - 1.73197288739005e+157*cos(theta)**17 + 2.07714561450658e+156*cos(theta)**15 - 1.66615958382881e+155*cos(theta)**13 + 8.78111132017886e+153*cos(theta)**11 - 2.93236868615566e+152*cos(theta)**9 + 5.8323355083759e+150*cos(theta)**7 - 6.22036798760253e+148*cos(theta)**5 + 2.92861016365468e+146*cos(theta)**3 - 3.86190351251166e+143*cos(theta))*sin(73*phi)

#@torch.jit.script
def Yl100_m_minus_72(theta, phi):
    return 6.75966587477127e-141*(1.0 - cos(theta)**2)**36*(2.18647540579576e+157*cos(theta)**28 - 4.15320453965225e+157*cos(theta)**26 + 3.42586668879945e+157*cos(theta)**24 - 1.61630633522846e+157*cos(theta)**22 + 4.8363570393494e+156*cos(theta)**20 - 9.62207159661137e+155*cos(theta)**18 + 1.29821600906661e+155*cos(theta)**16 - 1.19011398844915e+154*cos(theta)**14 + 7.31759276681571e+152*cos(theta)**12 - 2.93236868615566e+151*cos(theta)**10 + 7.29041938546987e+149*cos(theta)**8 - 1.03672799793376e+148*cos(theta)**6 + 7.32152540913669e+145*cos(theta)**4 - 1.93095175625583e+143*cos(theta)**2 + 7.97255060386387e+139)*sin(72*phi)

#@torch.jit.script
def Yl100_m_minus_71(theta, phi):
    return 4.77406636631576e-139*(1.0 - cos(theta)**2)**35.5*(7.53957036481297e+155*cos(theta)**29 - 1.53822390357491e+156*cos(theta)**27 + 1.37034667551978e+156*cos(theta)**25 - 7.02741884881938e+155*cos(theta)**23 + 2.30302716159495e+155*cos(theta)**21 - 5.06424820874283e+154*cos(theta)**19 + 7.63656475921537e+153*cos(theta)**17 - 7.93409325632766e+152*cos(theta)**15 + 5.62891751293516e+151*cos(theta)**13 - 2.66578971468696e+150*cos(theta)**11 + 8.10046598385541e+148*cos(theta)**9 - 1.48103999704822e+147*cos(theta)**7 + 1.46430508182734e+145*cos(theta)**5 - 6.4365058541861e+142*cos(theta)**3 + 7.97255060386387e+139*cos(theta))*sin(71*phi)

#@torch.jit.script
def Yl100_m_minus_70(theta, phi):
    return 3.41937816871774e-137*(1.0 - cos(theta)**2)**35*(2.51319012160432e+154*cos(theta)**30 - 5.49365679848182e+154*cos(theta)**28 + 5.27056413661453e+154*cos(theta)**26 - 2.92809118700807e+154*cos(theta)**24 + 1.04683052799771e+154*cos(theta)**22 - 2.53212410437141e+153*cos(theta)**20 + 4.24253597734187e+152*cos(theta)**18 - 4.95880828520479e+151*cos(theta)**16 + 4.02065536638226e+150*cos(theta)**14 - 2.2214914289058e+149*cos(theta)**12 + 8.10046598385541e+147*cos(theta)**10 - 1.85129999631028e+146*cos(theta)**8 + 2.44050846971223e+144*cos(theta)**6 - 1.60912646354652e+142*cos(theta)**4 + 3.98627530193194e+139*cos(theta)**2 - 1.55410343155241e+136)*sin(70*phi)

#@torch.jit.script
def Yl100_m_minus_69(theta, phi):
    return 2.48228956832009e-135*(1.0 - cos(theta)**2)**34.5*(8.10706490840105e+152*cos(theta)**31 - 1.89436441326959e+153*cos(theta)**29 + 1.95206079133872e+153*cos(theta)**27 - 1.17123647480323e+153*cos(theta)**25 + 4.55143707825089e+152*cos(theta)**23 - 1.20577338303401e+152*cos(theta)**21 + 2.2329136722852e+151*cos(theta)**19 - 2.91694605012046e+150*cos(theta)**17 + 2.68043691092151e+149*cos(theta)**15 - 1.70883956069677e+148*cos(theta)**13 + 7.3640599853231e+146*cos(theta)**11 - 2.05699999590031e+145*cos(theta)**9 + 3.48644067101747e+143*cos(theta)**7 - 3.21825292709305e+141*cos(theta)**5 + 1.32875843397731e+139*cos(theta)**3 - 1.55410343155241e+136*cos(theta))*sin(69*phi)

#@torch.jit.script
def Yl100_m_minus_68(theta, phi):
    return 1.82545353809288e-133*(1.0 - cos(theta)**2)**34*(2.53345778387533e+151*cos(theta)**32 - 6.31454804423197e+151*cos(theta)**30 + 6.97164568335256e+151*cos(theta)**28 - 4.50475567232011e+151*cos(theta)**26 + 1.89643211593787e+151*cos(theta)**24 - 5.48078810470003e+150*cos(theta)**22 + 1.1164568361426e+150*cos(theta)**20 - 1.62052558340026e+149*cos(theta)**18 + 1.67527306932594e+148*cos(theta)**16 - 1.22059968621198e+147*cos(theta)**14 + 6.13671665443592e+145*cos(theta)**12 - 2.05699999590031e+144*cos(theta)**10 + 4.35805083877184e+142*cos(theta)**8 - 5.36375487848842e+140*cos(theta)**6 + 3.32189608494328e+138*cos(theta)**4 - 7.77051715776206e+135*cos(theta)**2 + 2.87371196662798e+132)*sin(68*phi)

#@torch.jit.script
def Yl100_m_minus_67(theta, phi):
    return 1.35919695981912e-131*(1.0 - cos(theta)**2)**33.5*(7.6771447996222e+149*cos(theta)**33 - 2.03695098201031e+150*cos(theta)**31 + 2.40401575288019e+150*cos(theta)**29 - 1.66842802678523e+150*cos(theta)**27 + 7.58572846375149e+149*cos(theta)**25 - 2.38295134986958e+149*cos(theta)**23 + 5.31646112448856e+148*cos(theta)**21 - 8.52908201789609e+147*cos(theta)**19 + 9.85454746662319e+146*cos(theta)**17 - 8.1373312414132e+145*cos(theta)**15 + 4.72055127264301e+144*cos(theta)**13 - 1.86999999627301e+143*cos(theta)**11 + 4.84227870974649e+141*cos(theta)**9 - 7.66250696926917e+139*cos(theta)**7 + 6.64379216988656e+137*cos(theta)**5 - 2.59017238592069e+135*cos(theta)**3 + 2.87371196662798e+132*cos(theta))*sin(67*phi)

#@torch.jit.script
def Yl100_m_minus_66(theta, phi):
    return 1.02418895622595e-129*(1.0 - cos(theta)**2)**33*(2.25798376459477e+148*cos(theta)**34 - 6.36547181878223e+148*cos(theta)**32 + 8.01338584293397e+148*cos(theta)**30 - 5.95867152423296e+148*cos(theta)**28 + 2.91758787067365e+148*cos(theta)**26 - 9.92896395778991e+147*cos(theta)**24 + 2.41657323840389e+147*cos(theta)**22 - 4.26454100894805e+146*cos(theta)**20 + 5.47474859256844e+145*cos(theta)**18 - 5.08583202588325e+144*cos(theta)**16 + 3.37182233760215e+143*cos(theta)**14 - 1.55833333022751e+142*cos(theta)**12 + 4.84227870974649e+140*cos(theta)**10 - 9.57813371158646e+138*cos(theta)**8 + 1.10729869498109e+137*cos(theta)**6 - 6.47543096480172e+134*cos(theta)**4 + 1.43685598331399e+132*cos(theta)**2 - 5.06113414340962e+128)*sin(66*phi)

#@torch.jit.script
def Yl100_m_minus_65(theta, phi):
    return 7.80671194223321e-128*(1.0 - cos(theta)**2)**32.5*(6.45138218455647e+146*cos(theta)**35 - 1.92893085417643e+147*cos(theta)**33 + 2.58496317513999e+147*cos(theta)**31 - 2.05471431870102e+147*cos(theta)**29 + 1.0805881002495e+147*cos(theta)**27 - 3.97158558311596e+146*cos(theta)**25 + 1.05068401669734e+146*cos(theta)**23 - 2.03073381378478e+145*cos(theta)**21 + 2.8814466276676e+144*cos(theta)**19 - 2.99166589757838e+143*cos(theta)**17 + 2.24788155840144e+142*cos(theta)**15 - 1.19871794632885e+141*cos(theta)**13 + 4.40207155431499e+139*cos(theta)**11 - 1.06423707906516e+138*cos(theta)**9 + 1.58185527854442e+136*cos(theta)**7 - 1.29508619296034e+134*cos(theta)**5 + 4.78951994437997e+131*cos(theta)**3 - 5.06113414340962e+128*cos(theta))*sin(65*phi)

#@torch.jit.script
def Yl100_m_minus_64(theta, phi):
    return 6.01674183435769e-126*(1.0 - cos(theta)**2)**32*(1.79205060682124e+145*cos(theta)**36 - 5.67332604169539e+145*cos(theta)**34 + 8.07800992231247e+145*cos(theta)**32 - 6.8490477290034e+145*cos(theta)**30 + 3.85924321517678e+145*cos(theta)**28 - 1.52753291658306e+145*cos(theta)**26 + 4.37785006957227e+144*cos(theta)**24 - 9.23060824447629e+143*cos(theta)**22 + 1.4407233138338e+143*cos(theta)**20 - 1.66203660976577e+142*cos(theta)**18 + 1.4049259740009e+141*cos(theta)**16 - 8.56227104520608e+139*cos(theta)**14 + 3.66839296192916e+138*cos(theta)**12 - 1.06423707906516e+137*cos(theta)**10 + 1.97731909818052e+135*cos(theta)**8 - 2.15847698826724e+133*cos(theta)**6 + 1.19737998609499e+131*cos(theta)**4 - 2.53056707170481e+128*cos(theta)**2 + 8.52042785085794e+124)*sin(64*phi)

#@torch.jit.script
def Yl100_m_minus_63(theta, phi):
    return 4.68688355097872e-124*(1.0 - cos(theta)**2)**31.5*(4.84338001843579e+143*cos(theta)**37 - 1.62095029762725e+144*cos(theta)**35 + 2.44788179464014e+144*cos(theta)**33 - 2.20937023516239e+144*cos(theta)**31 + 1.33077352247475e+144*cos(theta)**29 - 5.65752932067801e+143*cos(theta)**27 + 1.75114002782891e+143*cos(theta)**25 - 4.013307932381e+142*cos(theta)**23 + 6.86058720873238e+141*cos(theta)**21 - 8.74756110403035e+140*cos(theta)**19 + 8.26427043529939e+139*cos(theta)**17 - 5.70818069680405e+138*cos(theta)**15 + 2.82184073994551e+137*cos(theta)**13 - 9.67488253695602e+135*cos(theta)**11 + 2.19702122020058e+134*cos(theta)**9 - 3.08353855466748e+132*cos(theta)**7 + 2.39475997218998e+130*cos(theta)**5 - 8.43522357234936e+127*cos(theta)**3 + 8.52042785085794e+124*cos(theta))*sin(63*phi)

#@torch.jit.script
def Yl100_m_minus_62(theta, phi):
    return 3.68866966184522e-122*(1.0 - cos(theta)**2)**31*(1.27457368906205e+142*cos(theta)**38 - 4.50263971563126e+142*cos(theta)**36 + 7.19965233717689e+142*cos(theta)**34 - 6.90428198488246e+142*cos(theta)**32 + 4.43591174158251e+142*cos(theta)**30 - 2.02054618595643e+142*cos(theta)**28 + 6.73515395318811e+141*cos(theta)**26 - 1.67221163849208e+141*cos(theta)**24 + 3.11844873124199e+140*cos(theta)**22 - 4.37378055201518e+139*cos(theta)**20 + 4.59126135294411e+138*cos(theta)**18 - 3.56761293550253e+137*cos(theta)**16 + 2.0156005285325e+136*cos(theta)**14 - 8.06240211413002e+134*cos(theta)**12 + 2.19702122020058e+133*cos(theta)**10 - 3.85442319333435e+131*cos(theta)**8 + 3.99126662031664e+129*cos(theta)**6 - 2.10880589308734e+127*cos(theta)**4 + 4.26021392542897e+124*cos(theta)**2 - 1.37559377637358e+121)*sin(62*phi)

#@torch.jit.script
def Yl100_m_minus_61(theta, phi):
    return 2.93197035314659e-120*(1.0 - cos(theta)**2)**30.5*(3.26813766426167e+140*cos(theta)**39 - 1.21692965287331e+141*cos(theta)**37 + 2.05704352490768e+141*cos(theta)**35 - 2.09220666208559e+141*cos(theta)**33 + 1.43093927147823e+141*cos(theta)**31 - 6.96740064122907e+140*cos(theta)**29 + 2.49450146414374e+140*cos(theta)**27 - 6.68884655396832e+139*cos(theta)**25 + 1.35584727445304e+139*cos(theta)**23 - 2.08275264381675e+138*cos(theta)**21 + 2.41645334365479e+137*cos(theta)**19 - 2.09859584441325e+136*cos(theta)**17 + 1.34373368568834e+135*cos(theta)**15 - 6.20184778010001e+133*cos(theta)**13 + 1.99729201836417e+132*cos(theta)**11 - 4.28269243703817e+130*cos(theta)**9 + 5.7018094575952e+128*cos(theta)**7 - 4.21761178617468e+126*cos(theta)**5 + 1.42007130847632e+124*cos(theta)**3 - 1.37559377637358e+121*cos(theta))*sin(61*phi)

#@torch.jit.script
def Yl100_m_minus_60(theta, phi):
    return 2.3528947910424e-118*(1.0 - cos(theta)**2)**30*(8.17034416065417e+138*cos(theta)**40 - 3.20244645492977e+139*cos(theta)**38 + 5.71400979141023e+139*cos(theta)**36 - 6.1535490061341e+139*cos(theta)**34 + 4.47168522336947e+139*cos(theta)**32 - 2.32246688040969e+139*cos(theta)**30 + 8.90893380051337e+138*cos(theta)**28 - 2.57263328998782e+138*cos(theta)**26 + 5.64936364355433e+137*cos(theta)**24 - 9.46705747189432e+136*cos(theta)**22 + 1.2082266718274e+136*cos(theta)**20 - 1.16588658022959e+135*cos(theta)**18 + 8.3983355355521e+133*cos(theta)**16 - 4.42989127150001e+132*cos(theta)**14 + 1.66441001530347e+131*cos(theta)**12 - 4.28269243703817e+129*cos(theta)**10 + 7.127261821994e+127*cos(theta)**8 - 7.0293529769578e+125*cos(theta)**6 + 3.55017827119081e+123*cos(theta)**4 - 6.87796888186789e+120*cos(theta)**2 + 2.13601518070431e+117)*sin(60*phi)

#@torch.jit.script
def Yl100_m_minus_59(theta, phi):
    return 1.90569953479049e-116*(1.0 - cos(theta)**2)**29.5*(1.99276686845224e+137*cos(theta)**41 - 8.2114011664866e+137*cos(theta)**39 + 1.54432697065141e+138*cos(theta)**37 - 1.75815685889546e+138*cos(theta)**35 + 1.35505612829378e+138*cos(theta)**33 - 7.49182864648288e+137*cos(theta)**31 + 3.07204613810806e+137*cos(theta)**29 - 9.52827144439932e+136*cos(theta)**27 + 2.25974545742173e+136*cos(theta)**25 - 4.11611194430188e+135*cos(theta)**23 + 5.75346034203522e+134*cos(theta)**21 - 6.13624515910308e+133*cos(theta)**19 + 4.94019737385418e+132*cos(theta)**17 - 2.95326084766667e+131*cos(theta)**15 + 1.28031539638729e+130*cos(theta)**13 - 3.89335676094379e+128*cos(theta)**11 + 7.91917980221555e+126*cos(theta)**9 - 1.00419328242254e+125*cos(theta)**7 + 7.10035654238162e+122*cos(theta)**5 - 2.29265629395596e+120*cos(theta)**3 + 2.13601518070431e+117*cos(theta))*sin(59*phi)

#@torch.jit.script
def Yl100_m_minus_58(theta, phi):
    return 1.55731919038657e-114*(1.0 - cos(theta)**2)**29*(4.74468302012437e+135*cos(theta)**42 - 2.05285029162165e+136*cos(theta)**40 + 4.06401834381951e+136*cos(theta)**38 - 4.88376905248738e+136*cos(theta)**36 + 3.98545920086405e+136*cos(theta)**34 - 2.3411964520259e+136*cos(theta)**32 + 1.02401537936935e+136*cos(theta)**30 - 3.40295408728547e+135*cos(theta)**28 + 8.69132868239128e+134*cos(theta)**26 - 1.71504664345912e+134*cos(theta)**24 + 2.61520924637965e+133*cos(theta)**22 - 3.06812257955154e+132*cos(theta)**20 + 2.74455409658565e+131*cos(theta)**18 - 1.84578802979167e+130*cos(theta)**16 + 9.1451099741949e+128*cos(theta)**14 - 3.24446396745316e+127*cos(theta)**12 + 7.91917980221555e+125*cos(theta)**10 - 1.25524160302818e+124*cos(theta)**8 + 1.1833927570636e+122*cos(theta)**6 - 5.73164073488991e+119*cos(theta)**4 + 1.06800759035216e+117*cos(theta)**2 - 3.19858517625683e+113)*sin(58*phi)

#@torch.jit.script
def Yl100_m_minus_57(theta, phi):
    return 1.283631619847e-112*(1.0 - cos(theta)**2)**28.5*(1.10341465584288e+134*cos(theta)**43 - 5.00695193078451e+134*cos(theta)**41 + 1.04205598559475e+135*cos(theta)**39 - 1.31993758175335e+135*cos(theta)**37 + 1.1387026288183e+135*cos(theta)**35 - 7.09453470310878e+134*cos(theta)**33 + 3.30327541732049e+134*cos(theta)**31 - 1.17343244389154e+134*cos(theta)**29 + 3.21901062310788e+133*cos(theta)**27 - 6.86018657383646e+132*cos(theta)**25 + 1.13704749842593e+132*cos(theta)**23 - 1.4610107521674e+131*cos(theta)**21 + 1.44450215609771e+130*cos(theta)**19 - 1.08575766458334e+129*cos(theta)**17 + 6.0967399827966e+127*cos(theta)**15 - 2.49574151342551e+126*cos(theta)**13 + 7.1992543656505e+124*cos(theta)**11 - 1.39471289225353e+123*cos(theta)**9 + 1.69056108151943e+121*cos(theta)**7 - 1.14632814697798e+119*cos(theta)**5 + 3.56002530117386e+116*cos(theta)**3 - 3.19858517625683e+113*cos(theta))*sin(57*phi)

#@torch.jit.script
def Yl100_m_minus_56(theta, phi):
    return 1.06688244974945e-110*(1.0 - cos(theta)**2)**28*(2.50776058146108e+132*cos(theta)**44 - 1.19213141209155e+133*cos(theta)**42 + 2.60513996398687e+133*cos(theta)**40 - 3.47351995198249e+133*cos(theta)**38 + 3.16306285782861e+133*cos(theta)**36 - 2.08662785385552e+133*cos(theta)**34 + 1.03227356791265e+133*cos(theta)**32 - 3.91144147963847e+132*cos(theta)**30 + 1.14964665110996e+132*cos(theta)**28 - 2.63853329762941e+131*cos(theta)**26 + 4.73769791010806e+130*cos(theta)**24 - 6.64095796439727e+129*cos(theta)**22 + 7.22251078048856e+128*cos(theta)**20 - 6.03198702546297e+127*cos(theta)**18 + 3.81046248924787e+126*cos(theta)**16 - 1.78267250958965e+125*cos(theta)**14 + 5.99937863804209e+123*cos(theta)**12 - 1.39471289225353e+122*cos(theta)**10 + 2.11320135189929e+120*cos(theta)**8 - 1.91054691162997e+118*cos(theta)**6 + 8.90006325293464e+115*cos(theta)**4 - 1.59929258812842e+113*cos(theta)**2 + 4.63026227020387e+109)*sin(56*phi)

#@torch.jit.script
def Yl100_m_minus_55(theta, phi):
    return 8.93892157607132e-109*(1.0 - cos(theta)**2)**27.5*(5.57280129213574e+130*cos(theta)**45 - 2.77239863277105e+131*cos(theta)**43 + 6.35399991216309e+131*cos(theta)**41 - 8.90646141533971e+131*cos(theta)**39 + 8.54881853467193e+131*cos(theta)**37 - 5.96179386815864e+131*cos(theta)**35 + 3.12810172094744e+131*cos(theta)**33 - 1.26175531601241e+131*cos(theta)**31 + 3.96429879693089e+130*cos(theta)**29 - 9.77234554677559e+129*cos(theta)**27 + 1.89507916404322e+129*cos(theta)**25 - 2.88737302799881e+128*cos(theta)**23 + 3.4392908478517e+127*cos(theta)**21 - 3.17473001340157e+126*cos(theta)**19 + 2.24144852308698e+125*cos(theta)**17 - 1.18844833972643e+124*cos(theta)**15 + 4.61490664464776e+122*cos(theta)**13 - 1.26792081113957e+121*cos(theta)**11 + 2.34800150211032e+119*cos(theta)**9 - 2.72935273089996e+117*cos(theta)**7 + 1.78001265058693e+115*cos(theta)**5 - 5.33097529376139e+112*cos(theta)**3 + 4.63026227020387e+109*cos(theta))*sin(55*phi)

#@torch.jit.script
def Yl100_m_minus_54(theta, phi):
    return 7.54796524942109e-107*(1.0 - cos(theta)**2)**27*(1.21147854176864e+129*cos(theta)**46 - 6.30090598357056e+129*cos(theta)**44 + 1.51285712194359e+130*cos(theta)**42 - 2.22661535383493e+130*cos(theta)**40 + 2.24968908807156e+130*cos(theta)**38 - 1.65605385226629e+130*cos(theta)**36 + 9.20029917925716e+129*cos(theta)**34 - 3.94298536253878e+129*cos(theta)**32 + 1.3214329323103e+129*cos(theta)**30 - 3.49012340956271e+128*cos(theta)**28 + 7.28876601555086e+127*cos(theta)**26 - 1.20307209499951e+127*cos(theta)**24 + 1.56331402175077e+126*cos(theta)**22 - 1.58736500670078e+125*cos(theta)**20 + 1.24524917949277e+124*cos(theta)**18 - 7.4278021232902e+122*cos(theta)**16 + 3.29636188903411e+121*cos(theta)**14 - 1.05660067594965e+120*cos(theta)**12 + 2.34800150211032e+118*cos(theta)**10 - 3.41169091362494e+116*cos(theta)**8 + 2.96668775097821e+114*cos(theta)**6 - 1.33274382344035e+112*cos(theta)**4 + 2.31513113510193e+109*cos(theta)**2 - 6.49405647994933e+105)*sin(54*phi)

#@torch.jit.script
def Yl100_m_minus_53(theta, phi):
    return 6.42153984137775e-105*(1.0 - cos(theta)**2)**26.5*(2.57761391865668e+127*cos(theta)**47 - 1.40020132968235e+128*cos(theta)**45 + 3.51827237661301e+128*cos(theta)**43 - 5.43076915569495e+128*cos(theta)**41 + 5.76843355915785e+128*cos(theta)**39 - 4.47582122234132e+128*cos(theta)**37 + 2.62865690835919e+128*cos(theta)**35 - 1.19484404925418e+128*cos(theta)**33 + 4.26268687842031e+127*cos(theta)**31 - 1.20349083088369e+127*cos(theta)**29 + 2.69954296872254e+126*cos(theta)**27 - 4.81228837999802e+125*cos(theta)**25 + 6.79701748587292e+124*cos(theta)**23 - 7.55888098428944e+123*cos(theta)**21 + 6.55394304996194e+122*cos(theta)**19 - 4.3692953666413e+121*cos(theta)**17 + 2.19757459268941e+120*cos(theta)**15 - 8.12769750730496e+118*cos(theta)**13 + 2.13454682010029e+117*cos(theta)**11 - 3.79076768180549e+115*cos(theta)**9 + 4.2381253585403e+113*cos(theta)**7 - 2.66548764688069e+111*cos(theta)**5 + 7.71710378367312e+108*cos(theta)**3 - 6.49405647994933e+105*cos(theta))*sin(53*phi)

#@torch.jit.script
def Yl100_m_minus_52(theta, phi):
    return 5.50307606138827e-103*(1.0 - cos(theta)**2)**26*(5.37002899720142e+125*cos(theta)**48 - 3.04391593409206e+126*cos(theta)**46 + 7.99607358321138e+126*cos(theta)**44 - 1.29304027516546e+127*cos(theta)**42 + 1.44210838978946e+127*cos(theta)**40 - 1.17784769008982e+127*cos(theta)**38 + 7.30182474544219e+126*cos(theta)**36 - 3.51424720368876e+126*cos(theta)**34 + 1.33208964950635e+126*cos(theta)**32 - 4.01163610294565e+125*cos(theta)**30 + 9.64122488829478e+124*cos(theta)**28 - 1.85088014615309e+124*cos(theta)**26 + 2.83209061911372e+123*cos(theta)**24 - 3.43585499285884e+122*cos(theta)**22 + 3.27697152498097e+121*cos(theta)**20 - 2.42738631480072e+120*cos(theta)**18 + 1.37348412043088e+119*cos(theta)**16 - 5.80549821950355e+117*cos(theta)**14 + 1.77878901675024e+116*cos(theta)**12 - 3.79076768180549e+114*cos(theta)**10 + 5.29765669817538e+112*cos(theta)**8 - 4.44247941146782e+110*cos(theta)**6 + 1.92927594591828e+108*cos(theta)**4 - 3.24702823997466e+105*cos(theta)**2 + 8.84266949884168e+101)*sin(52*phi)

#@torch.jit.script
def Yl100_m_minus_51(theta, phi):
    return 4.74925347851153e-101*(1.0 - cos(theta)**2)**25.5*(1.09592428514315e+124*cos(theta)**49 - 6.47641688104694e+124*cos(theta)**47 + 1.77690524071364e+125*cos(theta)**45 - 3.00707040736154e+125*cos(theta)**43 + 3.51733753607186e+125*cos(theta)**41 - 3.02012228228159e+125*cos(theta)**39 + 1.97346614741681e+125*cos(theta)**37 - 1.00407062962536e+125*cos(theta)**35 + 4.03663530153438e+124*cos(theta)**33 - 1.29407616224053e+124*cos(theta)**31 + 3.32456030630855e+123*cos(theta)**29 - 6.85511165241884e+122*cos(theta)**27 + 1.13283624764549e+122*cos(theta)**25 - 1.49384999689515e+121*cos(theta)**23 + 1.56046263094332e+120*cos(theta)**21 - 1.27757174463196e+119*cos(theta)**19 + 8.07931835547577e+117*cos(theta)**17 - 3.8703321463357e+116*cos(theta)**15 + 1.36829924365403e+115*cos(theta)**13 - 3.446152438005e+113*cos(theta)**11 + 5.88628522019487e+111*cos(theta)**9 - 6.34639915923975e+109*cos(theta)**7 + 3.85855189183656e+107*cos(theta)**5 - 1.08234274665822e+105*cos(theta)**3 + 8.84266949884168e+101*cos(theta))*sin(51*phi)

#@torch.jit.script
def Yl100_m_minus_50(theta, phi):
    return 4.12666130126779e-99*(1.0 - cos(theta)**2)**25*(2.19184857028629e+122*cos(theta)**50 - 1.34925351688478e+123*cos(theta)**48 + 3.86283747981226e+123*cos(theta)**46 - 6.83425092582169e+123*cos(theta)**44 + 8.37461318112347e+123*cos(theta)**42 - 7.55030570570399e+123*cos(theta)**40 + 5.19333196688634e+123*cos(theta)**38 - 2.78908508229266e+123*cos(theta)**36 + 1.18724567692188e+123*cos(theta)**34 - 4.04398800700166e+122*cos(theta)**32 + 1.10818676876952e+122*cos(theta)**30 - 2.44825416157816e+121*cos(theta)**28 + 4.35706249094418e+120*cos(theta)**26 - 6.22437498706311e+119*cos(theta)**24 + 7.09301195883327e+118*cos(theta)**22 - 6.38785872315979e+117*cos(theta)**20 + 4.48851019748654e+116*cos(theta)**18 - 2.41895759145981e+115*cos(theta)**16 + 9.77356602610025e+113*cos(theta)**14 - 2.8717936983375e+112*cos(theta)**12 + 5.88628522019487e+110*cos(theta)**10 - 7.93299894904969e+108*cos(theta)**8 + 6.4309198197276e+106*cos(theta)**6 - 2.70585686664555e+104*cos(theta)**4 + 4.42133474942084e+101*cos(theta)**2 - 1.17121450315784e+98)*sin(50*phi)

#@torch.jit.script
def Yl100_m_minus_49(theta, phi):
    return 3.60935453010183e-97*(1.0 - cos(theta)**2)**24.5*(4.29774229467901e+120*cos(theta)**51 - 2.7535786058873e+121*cos(theta)**49 + 8.21880314853672e+121*cos(theta)**47 - 1.51872242796038e+122*cos(theta)**45 + 1.94758446072639e+122*cos(theta)**43 - 1.84153797700097e+122*cos(theta)**41 + 1.33162358125291e+122*cos(theta)**39 - 7.53806778998017e+121*cos(theta)**37 + 3.39213050549108e+121*cos(theta)**35 - 1.22545091121262e+121*cos(theta)**33 + 3.57479602828876e+120*cos(theta)**31 - 8.44225572957985e+119*cos(theta)**29 + 1.61372684849784e+119*cos(theta)**27 - 2.48974999482524e+118*cos(theta)**25 + 3.08391824297099e+117*cos(theta)**23 - 3.04183748721895e+116*cos(theta)**21 + 2.36237378815081e+115*cos(theta)**19 - 1.42291623027048e+114*cos(theta)**17 + 6.51571068406683e+112*cos(theta)**15 - 2.20907207564423e+111*cos(theta)**13 + 5.35116838199533e+109*cos(theta)**11 - 8.81444327672187e+107*cos(theta)**9 + 9.18702831389657e+105*cos(theta)**7 - 5.41171373329111e+103*cos(theta)**5 + 1.47377824980695e+101*cos(theta)**3 - 1.17121450315784e+98*cos(theta))*sin(49*phi)

#@torch.jit.script
def Yl100_m_minus_48(theta, phi):
    return 3.17705218843653e-95*(1.0 - cos(theta)**2)**24*(8.26488902822886e+118*cos(theta)**52 - 5.50715721177461e+119*cos(theta)**50 + 1.71225065594515e+120*cos(theta)**48 - 3.30157049556603e+120*cos(theta)**46 + 4.4263283198327e+120*cos(theta)**44 - 4.3846142309547e+120*cos(theta)**42 + 3.32905895313227e+120*cos(theta)**40 - 1.98370204999478e+120*cos(theta)**38 + 9.42258473747522e+119*cos(theta)**36 - 3.60426738591948e+119*cos(theta)**34 + 1.11712375884024e+119*cos(theta)**32 - 2.81408524319328e+118*cos(theta)**30 + 5.76331017320658e+117*cos(theta)**28 - 9.57596151855863e+116*cos(theta)**26 + 1.28496593457125e+116*cos(theta)**24 - 1.38265340328134e+115*cos(theta)**22 + 1.1811868940754e+114*cos(theta)**20 - 7.90509016816932e+112*cos(theta)**18 + 4.07231917754177e+111*cos(theta)**16 - 1.57790862546016e+110*cos(theta)**14 + 4.45930698499611e+108*cos(theta)**12 - 8.81444327672187e+106*cos(theta)**10 + 1.14837853923707e+105*cos(theta)**8 - 9.01952288881851e+102*cos(theta)**6 + 3.68444562451736e+100*cos(theta)**4 - 5.85607251578919e+97*cos(theta)**2 + 1.5116346194603e+94)*sin(48*phi)

#@torch.jit.script
def Yl100_m_minus_47(theta, phi):
    return 2.81379945642078e-93*(1.0 - cos(theta)**2)**23.5*(1.55941302419412e+117*cos(theta)**53 - 1.07983474740679e+118*cos(theta)**51 + 3.49438909376561e+118*cos(theta)**49 - 7.02461807567241e+118*cos(theta)**47 + 9.83628515518378e+118*cos(theta)**45 - 1.019677728129e+119*cos(theta)**43 + 8.11965598324944e+118*cos(theta)**41 - 5.08641551280713e+118*cos(theta)**39 + 2.54664452364195e+118*cos(theta)**37 - 1.02979068169128e+118*cos(theta)**35 + 3.38522351163708e+117*cos(theta)**33 - 9.07769433288156e+116*cos(theta)**31 + 1.98734833558848e+116*cos(theta)**29 - 3.54665241428097e+115*cos(theta)**27 + 5.13986373828498e+114*cos(theta)**25 - 6.01153653600582e+113*cos(theta)**23 + 5.62469949559717e+112*cos(theta)**21 - 4.16057377272069e+111*cos(theta)**19 + 2.39548186914222e+110*cos(theta)**17 - 1.05193908364011e+109*cos(theta)**15 + 3.4302361423047e+107*cos(theta)**13 - 8.01313025156534e+105*cos(theta)**11 + 1.27597615470786e+104*cos(theta)**9 - 1.28850326983122e+102*cos(theta)**7 + 7.36889124903473e+99*cos(theta)**5 - 1.95202417192973e+97*cos(theta)**3 + 1.5116346194603e+94*cos(theta))*sin(47*phi)

#@torch.jit.script
def Yl100_m_minus_46(theta, phi):
    return 2.50696741243304e-91*(1.0 - cos(theta)**2)**23*(2.88780189665579e+115*cos(theta)**54 - 2.07660528347459e+116*cos(theta)**52 + 6.98877818753123e+116*cos(theta)**50 - 1.46346209909842e+117*cos(theta)**48 + 2.13832285982256e+117*cos(theta)**46 - 2.31744938211136e+117*cos(theta)**44 + 1.9332514245832e+117*cos(theta)**42 - 1.27160387820178e+117*cos(theta)**40 + 6.70169611484724e+116*cos(theta)**38 - 2.86052967136467e+116*cos(theta)**36 + 9.95653974010906e+115*cos(theta)**34 - 2.83677947902549e+115*cos(theta)**32 + 6.62449445196159e+114*cos(theta)**30 - 1.26666157652892e+114*cos(theta)**28 + 1.97687066857115e+113*cos(theta)**26 - 2.50480689000243e+112*cos(theta)**24 + 2.5566815889078e+111*cos(theta)**22 - 2.08028688636035e+110*cos(theta)**20 + 1.33082326063457e+109*cos(theta)**18 - 6.57461927275068e+107*cos(theta)**16 + 2.45016867307479e+106*cos(theta)**14 - 6.67760854297112e+104*cos(theta)**12 + 1.27597615470786e+103*cos(theta)**10 - 1.61062908728902e+101*cos(theta)**8 + 1.22814854150579e+99*cos(theta)**6 - 4.88006042982432e+96*cos(theta)**4 + 7.55817309730148e+93*cos(theta)**2 - 1.90430161181695e+90)*sin(46*phi)

#@torch.jit.script
def Yl100_m_minus_45(theta, phi):
    return 2.24650019862496e-89*(1.0 - cos(theta)**2)**22.5*(5.25054890301052e+113*cos(theta)**55 - 3.91812317636715e+114*cos(theta)**53 + 1.37034866422181e+115*cos(theta)**51 - 2.98665734509881e+115*cos(theta)**49 + 4.54962310600545e+115*cos(theta)**47 - 5.14988751580303e+115*cos(theta)**45 + 4.49593354554232e+115*cos(theta)**43 - 3.10147287366289e+115*cos(theta)**41 + 1.7183836191916e+115*cos(theta)**39 - 7.73116127395856e+114*cos(theta)**37 + 2.84472564003116e+114*cos(theta)**35 - 8.59630145159239e+113*cos(theta)**33 + 2.13693369418116e+113*cos(theta)**31 - 4.3677985397549e+112*cos(theta)**29 + 7.32174321693017e+111*cos(theta)**27 - 1.00192275600097e+111*cos(theta)**25 + 1.11160069082948e+110*cos(theta)**23 - 9.90612803028736e+108*cos(theta)**21 + 7.00433295070824e+107*cos(theta)**19 - 3.86742310161805e+106*cos(theta)**17 + 1.63344578204986e+105*cos(theta)**15 - 5.13662195613163e+103*cos(theta)**13 + 1.15997832246169e+102*cos(theta)**11 - 1.78958787476558e+100*cos(theta)**9 + 1.75449791643684e+98*cos(theta)**7 - 9.76012085964865e+95*cos(theta)**5 + 2.51939103243383e+93*cos(theta)**3 - 1.90430161181695e+90*cos(theta))*sin(45*phi)

#@torch.jit.script
def Yl100_m_minus_44(theta, phi):
    return 2.0243447511841e-87*(1.0 - cos(theta)**2)**22*(9.37598018394736e+111*cos(theta)**56 - 7.25578365993916e+112*cos(theta)**54 + 2.63528589273425e+113*cos(theta)**52 - 5.97331469019763e+113*cos(theta)**50 + 9.47838147084468e+113*cos(theta)**48 - 1.11954076430501e+114*cos(theta)**46 + 1.02180307853235e+114*cos(theta)**44 - 7.38445922300687e+113*cos(theta)**42 + 4.295959047979e+113*cos(theta)**40 - 2.03451612472594e+113*cos(theta)**38 + 7.90201566675323e+112*cos(theta)**36 - 2.5283239563507e+112*cos(theta)**34 + 6.67791779431612e+111*cos(theta)**32 - 1.45593284658497e+111*cos(theta)**30 + 2.61490829176078e+110*cos(theta)**28 - 3.8535490615422e+109*cos(theta)**26 + 4.63166954512283e+108*cos(theta)**24 - 4.50278546831244e+107*cos(theta)**22 + 3.50216647535412e+106*cos(theta)**20 - 2.1485683897878e+105*cos(theta)**18 + 1.02090361378116e+104*cos(theta)**16 - 3.66901568295116e+102*cos(theta)**14 + 9.66648602051406e+100*cos(theta)**12 - 1.78958787476558e+99*cos(theta)**10 + 2.19312239554605e+97*cos(theta)**8 - 1.62668680994144e+95*cos(theta)**6 + 6.29847758108457e+92*cos(theta)**4 - 9.52150805908476e+89*cos(theta)**2 + 2.34519902933122e+86)*sin(44*phi)

#@torch.jit.script
def Yl100_m_minus_43(theta, phi):
    return 1.83401612536192e-85*(1.0 - cos(theta)**2)**21.5*(1.64490880420129e+110*cos(theta)**57 - 1.31923339271621e+111*cos(theta)**55 + 4.97223753346085e+111*cos(theta)**53 - 1.17123817454855e+112*cos(theta)**51 + 1.93436356547851e+112*cos(theta)**49 - 2.38200162618086e+112*cos(theta)**47 + 2.27067350784966e+112*cos(theta)**45 - 1.71731609837369e+112*cos(theta)**43 + 1.04779488975098e+112*cos(theta)**41 - 5.21670801211779e+111*cos(theta)**39 + 2.1356799099333e+111*cos(theta)**37 - 7.22378273243058e+110*cos(theta)**35 + 2.02361145282307e+110*cos(theta)**33 - 4.69655756962892e+109*cos(theta)**31 + 9.01692514400267e+108*cos(theta)**29 - 1.42724039316378e+108*cos(theta)**27 + 1.85266781804913e+107*cos(theta)**25 - 1.95773281230976e+106*cos(theta)**23 + 1.6676983215972e+105*cos(theta)**21 - 1.13082546830937e+104*cos(theta)**19 + 6.0053153751833e+102*cos(theta)**17 - 2.44601045530078e+101*cos(theta)**15 + 7.43575847731851e+99*cos(theta)**13 - 1.62689806796871e+98*cos(theta)**11 + 2.43680266171783e+96*cos(theta)**9 - 2.32383829991634e+94*cos(theta)**7 + 1.25969551621691e+92*cos(theta)**5 - 3.17383601969492e+89*cos(theta)**3 + 2.34519902933122e+86*cos(theta))*sin(43*phi)

#@torch.jit.script
def Yl100_m_minus_42(theta, phi):
    return 1.67026417186738e-83*(1.0 - cos(theta)**2)**21*(2.83604966241602e+108*cos(theta)**58 - 2.35577391556466e+109*cos(theta)**56 + 9.20784728418675e+109*cos(theta)**54 - 2.25238110490107e+110*cos(theta)**52 + 3.86872713095701e+110*cos(theta)**50 - 4.9625033878768e+110*cos(theta)**48 + 4.93624675619491e+110*cos(theta)**46 - 3.90299113266748e+110*cos(theta)**44 + 2.49474973750232e+110*cos(theta)**42 - 1.30417700302945e+110*cos(theta)**40 + 5.62021028929817e+109*cos(theta)**38 - 2.00660631456405e+109*cos(theta)**36 + 5.95179839065608e+108*cos(theta)**34 - 1.46767424050904e+108*cos(theta)**32 + 3.00564171466756e+107*cos(theta)**30 - 5.09728711844206e+106*cos(theta)**28 + 7.12564545403512e+105*cos(theta)**26 - 8.15722005129065e+104*cos(theta)**24 + 7.58044691635091e+103*cos(theta)**22 - 5.65412734154685e+102*cos(theta)**20 + 3.33628631954628e+101*cos(theta)**18 - 1.52875653456298e+100*cos(theta)**16 + 5.31125605522751e+98*cos(theta)**14 - 1.35574838997392e+97*cos(theta)**12 + 2.43680266171783e+95*cos(theta)**10 - 2.90479787489543e+93*cos(theta)**8 + 2.09949252702819e+91*cos(theta)**6 - 7.9345900492373e+88*cos(theta)**4 + 1.17259951466561e+86*cos(theta)**2 - 2.82758503657008e+82)*sin(42*phi)

#@torch.jit.script
def Yl100_m_minus_41(theta, phi):
    return 1.52881643696148e-81*(1.0 - cos(theta)**2)**20.5*(4.80686383460342e+106*cos(theta)**59 - 4.13293669397309e+107*cos(theta)**57 + 1.67415405167032e+108*cos(theta)**55 - 4.24977566962465e+108*cos(theta)**53 + 7.58573947246473e+108*cos(theta)**51 - 1.01275579344424e+109*cos(theta)**49 + 1.05026526727551e+109*cos(theta)**47 - 8.67331362814996e+108*cos(theta)**45 + 5.80174357558679e+108*cos(theta)**43 - 3.18091951958402e+108*cos(theta)**41 + 1.4410795613585e+108*cos(theta)**39 - 5.42326030963257e+107*cos(theta)**37 + 1.70051382590174e+107*cos(theta)**35 - 4.44749769851223e+106*cos(theta)**33 + 9.69561843441148e+105*cos(theta)**31 - 1.75768521325588e+105*cos(theta)**29 + 2.63912794593893e+104*cos(theta)**27 - 3.26288802051626e+103*cos(theta)**25 + 3.29584648536996e+102*cos(theta)**23 - 2.69244159121279e+101*cos(theta)**21 + 1.75594016818225e+100*cos(theta)**19 - 8.99268549742932e+98*cos(theta)**17 + 3.54083737015167e+97*cos(theta)**15 - 1.04288337690302e+96*cos(theta)**13 + 2.21527514701621e+94*cos(theta)**11 - 3.22755319432826e+92*cos(theta)**9 + 2.9992750386117e+90*cos(theta)**7 - 1.58691800984746e+88*cos(theta)**5 + 3.90866504888537e+85*cos(theta)**3 - 2.82758503657008e+82*cos(theta))*sin(41*phi)

#@torch.jit.script
def Yl100_m_minus_40(theta, phi):
    return 1.40617873132947e-79*(1.0 - cos(theta)**2)**20*(8.01143972433903e+104*cos(theta)**60 - 7.12575292064326e+105*cos(theta)**58 + 2.98956080655414e+106*cos(theta)**56 - 7.86995494374936e+106*cos(theta)**54 + 1.45879605239706e+107*cos(theta)**52 - 2.02551158688849e+107*cos(theta)**50 + 2.18805264015732e+107*cos(theta)**48 - 1.88550296264129e+107*cos(theta)**46 + 1.31857808536064e+107*cos(theta)**44 - 7.57361790377147e+106*cos(theta)**42 + 3.60269890339626e+106*cos(theta)**40 - 1.42717376569278e+106*cos(theta)**38 + 4.72364951639371e+105*cos(theta)**36 - 1.30808755838595e+105*cos(theta)**34 + 3.02988076075359e+104*cos(theta)**32 - 5.85895071085294e+103*cos(theta)**30 + 9.42545694978191e+102*cos(theta)**28 - 1.25495693096779e+102*cos(theta)**26 + 1.37326936890415e+101*cos(theta)**24 - 1.2238370869149e+100*cos(theta)**22 + 8.77970084091126e+98*cos(theta)**20 - 4.99593638746073e+97*cos(theta)**18 + 2.2130233563448e+96*cos(theta)**16 - 7.44916697787869e+94*cos(theta)**14 + 1.84606262251351e+93*cos(theta)**12 - 3.22755319432826e+91*cos(theta)**10 + 3.74909379826462e+89*cos(theta)**8 - 2.64486334974577e+87*cos(theta)**6 + 9.77166262221342e+84*cos(theta)**4 - 1.41379251828504e+82*cos(theta)**2 + 3.34229909760056e+78)*sin(40*phi)

#@torch.jit.script
def Yl100_m_minus_39(theta, phi):
    return 1.29947958247701e-77*(1.0 - cos(theta)**2)**19.5*(1.31335077448181e+103*cos(theta)**61 - 1.20775473231242e+104*cos(theta)**59 + 5.24484352027042e+104*cos(theta)**57 - 1.43090089886352e+105*cos(theta)**55 + 2.75244538188125e+105*cos(theta)**53 - 3.97159134684017e+105*cos(theta)**51 + 4.46541355134147e+105*cos(theta)**49 - 4.01170843115169e+105*cos(theta)**47 + 2.93017352302363e+105*cos(theta)**45 - 1.76130648924918e+105*cos(theta)**43 + 8.78707049608844e+104*cos(theta)**41 - 3.65941991203277e+104*cos(theta)**39 + 1.27666203145776e+104*cos(theta)**37 - 3.73739302395986e+103*cos(theta)**35 + 9.18145685076844e+102*cos(theta)**33 - 1.88998410027514e+102*cos(theta)**31 + 3.25015756889031e+101*cos(theta)**29 - 4.64798863321405e+100*cos(theta)**27 + 5.4930774756166e+99*cos(theta)**25 - 5.32103081267349e+98*cos(theta)**23 + 4.18080992424346e+97*cos(theta)**21 - 2.6294402039267e+96*cos(theta)**19 + 1.3017784449087e+95*cos(theta)**17 - 4.9661113185858e+93*cos(theta)**15 + 1.42004817116424e+92*cos(theta)**13 - 2.93413926757114e+90*cos(theta)**11 + 4.16565977584958e+88*cos(theta)**9 - 3.77837621392252e+86*cos(theta)**7 + 1.95433252444268e+84*cos(theta)**5 - 4.7126417276168e+81*cos(theta)**3 + 3.34229909760056e+78*cos(theta))*sin(39*phi)

#@torch.jit.script
def Yl100_m_minus_38(theta, phi):
    return 1.20634826823338e-75*(1.0 - cos(theta)**2)**19*(2.11830770077711e+101*cos(theta)**62 - 2.01292455385403e+102*cos(theta)**60 + 9.04283365563866e+102*cos(theta)**58 - 2.555180176542e+103*cos(theta)**56 + 5.09712107755788e+103*cos(theta)**54 - 7.63767566700033e+103*cos(theta)**52 + 8.93082710268293e+103*cos(theta)**50 - 8.35772589823269e+103*cos(theta)**48 + 6.36994244135573e+103*cos(theta)**46 - 4.00296929374813e+103*cos(theta)**44 + 2.09215964192582e+103*cos(theta)**42 - 9.14854978008193e+102*cos(theta)**40 + 3.35963692488884e+102*cos(theta)**38 - 1.03816472887774e+102*cos(theta)**36 + 2.70042848552013e+101*cos(theta)**34 - 5.90620031335982e+100*cos(theta)**32 + 1.08338585629677e+100*cos(theta)**30 - 1.65999594043359e+99*cos(theta)**28 + 2.11272210600638e+98*cos(theta)**26 - 2.21709617194729e+97*cos(theta)**24 + 1.90036814738339e+96*cos(theta)**22 - 1.31472010196335e+95*cos(theta)**20 + 7.23210247171502e+93*cos(theta)**18 - 3.10381957411612e+92*cos(theta)**16 + 1.01432012226017e+91*cos(theta)**14 - 2.44511605630929e+89*cos(theta)**12 + 4.16565977584958e+87*cos(theta)**10 - 4.72297026740316e+85*cos(theta)**8 + 3.25722087407114e+83*cos(theta)**6 - 1.1781604319042e+81*cos(theta)**4 + 1.67114954880028e+78*cos(theta)**2 - 3.87827697563305e+74)*sin(38*phi)

#@torch.jit.script
def Yl100_m_minus_37(theta, phi):
    return 1.12481868753504e-73*(1.0 - cos(theta)**2)**18.5*(3.36239317583668e+99*cos(theta)**63 - 3.29987631779349e+100*cos(theta)**61 + 1.53268367044723e+101*cos(theta)**59 - 4.48277223954737e+101*cos(theta)**57 + 9.26749286828705e+101*cos(theta)**55 - 1.4410708805661e+102*cos(theta)**53 + 1.75114256915352e+102*cos(theta)**51 - 1.7056583465781e+102*cos(theta)**49 + 1.35530690241611e+102*cos(theta)**47 - 8.8954873194403e+101*cos(theta)**45 + 4.86548753936237e+101*cos(theta)**43 - 2.23135360489803e+101*cos(theta)**41 + 8.61445365356113e+100*cos(theta)**39 - 2.80585061858848e+100*cos(theta)**37 + 7.71550995862894e+99*cos(theta)**35 - 1.7897576707151e+99*cos(theta)**33 + 3.49479308482829e+98*cos(theta)**31 - 5.72412393252961e+97*cos(theta)**29 + 7.82489668891253e+96*cos(theta)**27 - 8.86838468778915e+95*cos(theta)**25 + 8.26247020601473e+94*cos(theta)**23 - 6.26057191411119e+93*cos(theta)**21 + 3.80636972195527e+92*cos(theta)**19 - 1.82577622006831e+91*cos(theta)**17 + 6.76213414840114e+89*cos(theta)**15 - 1.8808585048533e+88*cos(theta)**13 + 3.78696343259053e+86*cos(theta)**11 - 5.24774474155906e+84*cos(theta)**9 + 4.65317267724449e+82*cos(theta)**7 - 2.3563208638084e+80*cos(theta)**5 + 5.57049849600094e+77*cos(theta)**3 - 3.87827697563305e+74*cos(theta))*sin(37*phi)

#@torch.jit.script
def Yl100_m_minus_36(theta, phi):
    return 1.05325321532538e-71*(1.0 - cos(theta)**2)**18*(5.25373933724482e+97*cos(theta)**64 - 5.32238115773143e+98*cos(theta)**62 + 2.55447278407872e+99*cos(theta)**60 - 7.72891765439201e+99*cos(theta)**58 + 1.65490944076554e+100*cos(theta)**56 - 2.66864977882611e+100*cos(theta)**54 + 3.36758186375676e+100*cos(theta)**52 - 3.4113166931562e+100*cos(theta)**50 + 2.82355604670023e+100*cos(theta)**48 - 1.93380159118267e+100*cos(theta)**46 + 1.10579262258236e+100*cos(theta)**44 - 5.31274667832864e+99*cos(theta)**42 + 2.15361341339028e+99*cos(theta)**40 - 7.38381741733812e+98*cos(theta)**38 + 2.14319721073026e+98*cos(theta)**36 - 5.26399314916205e+97*cos(theta)**34 + 1.09212283900884e+97*cos(theta)**32 - 1.9080413108432e+96*cos(theta)**30 + 2.79460596032591e+95*cos(theta)**28 - 3.41091718761121e+94*cos(theta)**26 + 3.44269591917281e+93*cos(theta)**24 - 2.84571450641418e+92*cos(theta)**22 + 1.90318486097764e+91*cos(theta)**20 - 1.01432012226017e+90*cos(theta)**18 + 4.22633384275071e+88*cos(theta)**16 - 1.3434703606095e+87*cos(theta)**14 + 3.15580286049211e+85*cos(theta)**12 - 5.24774474155906e+83*cos(theta)**10 + 5.81646584655561e+81*cos(theta)**8 - 3.92720143968066e+79*cos(theta)**6 + 1.39262462400023e+77*cos(theta)**4 - 1.93913848781653e+74*cos(theta)**2 + 4.42321735359609e+70)*sin(36*phi)

#@torch.jit.script
def Yl100_m_minus_35(theta, phi):
    return 9.90282093478634e-70*(1.0 - cos(theta)**2)**17.5*(8.08267590345357e+95*cos(theta)**65 - 8.44822405989117e+96*cos(theta)**63 + 4.18766030176839e+97*cos(theta)**61 - 1.30998604311729e+98*cos(theta)**59 + 2.9033498960799e+98*cos(theta)**57 - 4.85209050695657e+98*cos(theta)**55 + 6.35392804482408e+98*cos(theta)**53 - 6.68885626109059e+98*cos(theta)**51 + 5.76235927898007e+98*cos(theta)**49 - 4.11447147060143e+98*cos(theta)**47 + 2.45731693907191e+98*cos(theta)**45 - 1.23552248333224e+98*cos(theta)**43 + 5.25271564241533e+97*cos(theta)**41 - 1.89328651726618e+97*cos(theta)**39 + 5.79242489386557e+96*cos(theta)**37 - 1.50399804261773e+96*cos(theta)**35 + 3.30946314851164e+95*cos(theta)**33 - 6.15497197046195e+94*cos(theta)**31 + 9.63657227698588e+93*cos(theta)**29 - 1.26330266207823e+93*cos(theta)**27 + 1.37707836766912e+92*cos(theta)**25 - 1.23726717670182e+91*cos(theta)**23 + 9.06278505227446e+89*cos(theta)**21 - 5.33852695926406e+88*cos(theta)**19 + 2.48607873102983e+87*cos(theta)**17 - 8.95646907072998e+85*cos(theta)**15 + 2.42754066191701e+84*cos(theta)**13 - 4.77067703778096e+82*cos(theta)**11 + 6.46273982950623e+80*cos(theta)**9 - 5.61028777097238e+78*cos(theta)**7 + 2.78524924800047e+76*cos(theta)**5 - 6.46379495938842e+73*cos(theta)**3 + 4.42321735359609e+70*cos(theta))*sin(35*phi)

#@torch.jit.script
def Yl100_m_minus_34(theta, phi):
    return 9.34754959642367e-68*(1.0 - cos(theta)**2)**17*(1.22464786415963e+94*cos(theta)**66 - 1.32003500935799e+95*cos(theta)**64 + 6.75429080930385e+95*cos(theta)**62 - 2.18331007186215e+96*cos(theta)**60 + 5.00577568289638e+96*cos(theta)**58 - 8.66444733385101e+96*cos(theta)**56 + 1.17665334163409e+97*cos(theta)**54 - 1.28631851174819e+97*cos(theta)**52 + 1.15247185579601e+97*cos(theta)**50 - 8.57181556375298e+96*cos(theta)**48 + 5.34199334580849e+96*cos(theta)**46 - 2.80800564393692e+96*cos(theta)**44 + 1.25064658152746e+96*cos(theta)**42 - 4.73321629316546e+95*cos(theta)**40 + 1.52432234049094e+95*cos(theta)**38 - 4.1777723406048e+94*cos(theta)**36 + 9.7337151426813e+93*cos(theta)**34 - 1.92342874076936e+93*cos(theta)**32 + 3.21219075899529e+92*cos(theta)**30 - 4.51179522170795e+91*cos(theta)**28 + 5.29645526026586e+90*cos(theta)**26 - 5.15527990292424e+89*cos(theta)**24 + 4.11944775103384e+88*cos(theta)**22 - 2.66926347963203e+87*cos(theta)**20 + 1.38115485057213e+86*cos(theta)**18 - 5.59779316920624e+84*cos(theta)**16 + 1.733957615655e+83*cos(theta)**14 - 3.9755641981508e+81*cos(theta)**12 + 6.46273982950623e+79*cos(theta)**10 - 7.01285971371547e+77*cos(theta)**8 + 4.64208208000078e+75*cos(theta)**6 - 1.6159487398471e+73*cos(theta)**4 + 2.21160867679805e+70*cos(theta)**2 - 4.96432924084859e+66)*sin(34*phi)

#@torch.jit.script
def Yl100_m_minus_33(theta, phi):
    return 8.85701904752573e-66*(1.0 - cos(theta)**2)**16.5*(1.82783263307408e+92*cos(theta)**67 - 2.03082309131999e+93*cos(theta)**65 + 1.07210965227045e+94*cos(theta)**63 - 3.57919683911828e+94*cos(theta)**61 + 8.48436556423116e+94*cos(theta)**59 - 1.52007847962299e+95*cos(theta)**57 + 2.13936971206198e+95*cos(theta)**55 - 2.42701605990225e+95*cos(theta)**53 + 2.25974873685493e+95*cos(theta)**51 - 1.74935011505163e+95*cos(theta)**49 + 1.13659432889542e+95*cos(theta)**47 - 6.24001254208203e+94*cos(theta)**45 + 2.90848042215688e+94*cos(theta)**43 - 1.15444299833304e+94*cos(theta)**41 + 3.90851882177164e+93*cos(theta)**39 - 1.12912765962292e+93*cos(theta)**37 + 2.78106146933751e+92*cos(theta)**35 - 5.82857194172533e+91*cos(theta)**33 + 1.03619056741784e+91*cos(theta)**31 - 1.55579145576136e+90*cos(theta)**29 + 1.96165009639476e+89*cos(theta)**27 - 2.0621119611697e+88*cos(theta)**25 + 1.79106423957993e+87*cos(theta)**23 - 1.27107784744382e+86*cos(theta)**21 + 7.26923605564278e+84*cos(theta)**19 - 3.29281951129779e+83*cos(theta)**17 + 1.15597174377e+82*cos(theta)**15 - 3.05812630626985e+80*cos(theta)**13 + 5.87521802682385e+78*cos(theta)**11 - 7.79206634857274e+76*cos(theta)**9 + 6.63154582857255e+74*cos(theta)**7 - 3.23189747969421e+72*cos(theta)**5 + 7.37202892266015e+69*cos(theta)**3 - 4.96432924084859e+66*cos(theta))*sin(33*phi)

#@torch.jit.script
def Yl100_m_minus_32(theta, phi):
    return 8.42302045750848e-64*(1.0 - cos(theta)**2)**16*(2.68798916628541e+90*cos(theta)**68 - 3.07700468381817e+91*cos(theta)**66 + 1.67517133167258e+92*cos(theta)**64 - 5.77289812761013e+92*cos(theta)**62 + 1.41406092737186e+93*cos(theta)**60 - 2.62082496486722e+93*cos(theta)**58 + 3.82030305725353e+93*cos(theta)**56 - 4.49447418500416e+93*cos(theta)**54 + 4.34567064779794e+93*cos(theta)**52 - 3.49870023010326e+93*cos(theta)**50 + 2.36790485186547e+93*cos(theta)**48 - 1.35652446567001e+93*cos(theta)**46 + 6.61018277762927e+92*cos(theta)**44 - 2.74867380555485e+92*cos(theta)**42 + 9.77129705442911e+91*cos(theta)**40 - 2.97138857795505e+91*cos(theta)**38 + 7.72517074815976e+90*cos(theta)**36 - 1.71428586521333e+90*cos(theta)**34 + 3.23809552318074e+89*cos(theta)**32 - 5.18597151920454e+88*cos(theta)**30 + 7.00589320140986e+87*cos(theta)**28 - 7.93119985065267e+86*cos(theta)**26 + 7.46276766491638e+85*cos(theta)**24 - 5.7776265792901e+84*cos(theta)**22 + 3.63461802782139e+83*cos(theta)**20 - 1.82934417294322e+82*cos(theta)**18 + 7.22482339856252e+80*cos(theta)**16 - 2.18437593304989e+79*cos(theta)**14 + 4.89601502235321e+77*cos(theta)**12 - 7.79206634857274e+75*cos(theta)**10 + 8.28943228571568e+73*cos(theta)**8 - 5.38649579949035e+71*cos(theta)**6 + 1.84300723066504e+69*cos(theta)**4 - 2.48216462042429e+66*cos(theta)**2 + 5.48908584790865e+62)*sin(32*phi)

#@torch.jit.script
def Yl100_m_minus_31(theta, phi):
    return 8.03858052270573e-62*(1.0 - cos(theta)**2)**15.5*(3.8956364728774e+88*cos(theta)**69 - 4.59254430420622e+89*cos(theta)**67 + 2.57718666411167e+90*cos(theta)**65 - 9.16333036128592e+90*cos(theta)**63 + 2.31813266782272e+91*cos(theta)**61 - 4.44207621163935e+91*cos(theta)**59 + 6.70228606535708e+91*cos(theta)**57 - 8.17177124546211e+91*cos(theta)**55 + 8.19937858075083e+91*cos(theta)**53 - 6.86019652961423e+91*cos(theta)**51 + 4.83245888135809e+91*cos(theta)**49 - 2.88622226738299e+91*cos(theta)**47 + 1.46892950613984e+91*cos(theta)**45 - 6.39226466408106e+90*cos(theta)**43 + 2.3832431840071e+90*cos(theta)**41 - 7.61894507167961e+89*cos(theta)**39 + 2.08788398598913e+89*cos(theta)**37 - 4.89795961489524e+88*cos(theta)**35 + 9.81241067630527e+87*cos(theta)**33 - 1.67289403845308e+87*cos(theta)**31 + 2.41582524186547e+86*cos(theta)**29 - 2.93748142616766e+85*cos(theta)**27 + 2.98510706596655e+84*cos(theta)**25 - 2.51201155621309e+83*cos(theta)**23 + 1.73077048943876e+82*cos(theta)**21 - 9.62812722601692e+80*cos(theta)**19 + 4.24989611680148e+79*cos(theta)**17 - 1.45625062203326e+78*cos(theta)**15 + 3.76616540181016e+76*cos(theta)**13 - 7.08369668052068e+74*cos(theta)**11 + 9.21048031746187e+72*cos(theta)**9 - 7.69499399927193e+70*cos(theta)**7 + 3.68601446133007e+68*cos(theta)**5 - 8.27388206808098e+65*cos(theta)**3 + 5.48908584790865e+62*cos(theta))*sin(31*phi)

#@torch.jit.script
def Yl100_m_minus_30(theta, phi):
    return 7.69775411038583e-60*(1.0 - cos(theta)**2)**15*(5.56519496125343e+86*cos(theta)**70 - 6.75374162383268e+87*cos(theta)**68 + 3.90482827895707e+88*cos(theta)**66 - 1.43177036895092e+89*cos(theta)**64 + 3.73892365777858e+89*cos(theta)**62 - 7.40346035273225e+89*cos(theta)**60 + 1.1555665629926e+90*cos(theta)**58 - 1.45924486526109e+90*cos(theta)**56 + 1.51840344087978e+90*cos(theta)**54 - 1.31926856338735e+90*cos(theta)**52 + 9.66491776271618e+89*cos(theta)**50 - 6.01296305704791e+89*cos(theta)**48 + 3.19332501334748e+89*cos(theta)**46 - 1.45278742365479e+89*cos(theta)**44 + 5.67438853335024e+88*cos(theta)**42 - 1.9047362679199e+88*cos(theta)**40 + 5.49443154207664e+87*cos(theta)**38 - 1.3605443374709e+87*cos(theta)**36 + 2.88600314008979e+86*cos(theta)**34 - 5.22779387016587e+85*cos(theta)**32 + 8.05275080621823e+84*cos(theta)**30 - 1.04910050934559e+84*cos(theta)**28 + 1.14811810229483e+83*cos(theta)**26 - 1.04667148175545e+82*cos(theta)**24 + 7.86713858835798e+80*cos(theta)**22 - 4.81406361300846e+79*cos(theta)**20 + 2.36105339822305e+78*cos(theta)**18 - 9.10156638770788e+76*cos(theta)**16 + 2.69011814415011e+75*cos(theta)**14 - 5.90308056710056e+73*cos(theta)**12 + 9.21048031746187e+71*cos(theta)**10 - 9.61874249908991e+69*cos(theta)**8 + 6.14335743555012e+67*cos(theta)**6 - 2.06847051702024e+65*cos(theta)**4 + 2.74454292395433e+62*cos(theta)**2 - 5.98591695518937e+58)*sin(30*phi)

#@torch.jit.script
def Yl100_m_minus_29(theta, phi):
    return 7.39545476164089e-58*(1.0 - cos(theta)**2)**14.5*(7.83830276232878e+84*cos(theta)**71 - 9.78803133888794e+85*cos(theta)**69 + 5.82810190889115e+86*cos(theta)**67 - 2.20272364453988e+87*cos(theta)**65 + 5.9347994567914e+87*cos(theta)**63 - 1.21368202503807e+88*cos(theta)**61 + 1.95858739490271e+88*cos(theta)**59 - 2.56007871098437e+88*cos(theta)**57 + 2.76073352887233e+88*cos(theta)**55 - 2.48918596865538e+88*cos(theta)**53 + 1.89508191425808e+88*cos(theta)**51 - 1.22713531776488e+88*cos(theta)**49 + 6.79430853903718e+87*cos(theta)**47 - 3.22841649701063e+87*cos(theta)**45 + 1.31962524031401e+87*cos(theta)**43 - 4.64569821443879e+86*cos(theta)**41 + 1.40882860053247e+86*cos(theta)**39 - 3.67714685802946e+85*cos(theta)**37 + 8.24572325739939e+84*cos(theta)**35 - 1.58417996065632e+84*cos(theta)**33 + 2.59766155039298e+83*cos(theta)**31 - 3.61758796326066e+82*cos(theta)**29 + 4.25228926775862e+81*cos(theta)**27 - 4.18668592702181e+80*cos(theta)**25 + 3.42049503841651e+79*cos(theta)**23 - 2.29241124428974e+78*cos(theta)**21 + 1.24265968327529e+77*cos(theta)**19 - 5.35386258100464e+75*cos(theta)**17 + 1.79341209610008e+74*cos(theta)**15 - 4.54083120546197e+72*cos(theta)**13 + 8.37316392496534e+70*cos(theta)**11 - 1.06874916656555e+69*cos(theta)**9 + 8.77622490792875e+66*cos(theta)**7 - 4.13694103404049e+64*cos(theta)**5 + 9.14847641318109e+61*cos(theta)**3 - 5.98591695518937e+58*cos(theta))*sin(29*phi)

#@torch.jit.script
def Yl100_m_minus_28(theta, phi):
    return 7.12731557116112e-56*(1.0 - cos(theta)**2)**14*(1.08865316143455e+83*cos(theta)**72 - 1.39829019126971e+84*cos(theta)**70 + 8.57073810131051e+84*cos(theta)**68 - 3.33746006748467e+85*cos(theta)**66 + 9.27312415123656e+85*cos(theta)**64 - 1.95755165328722e+86*cos(theta)**62 + 3.26431232483785e+86*cos(theta)**60 - 4.41392881204202e+86*cos(theta)**58 + 4.92988130155774e+86*cos(theta)**56 - 4.60960364565812e+86*cos(theta)**54 + 3.64438829665014e+86*cos(theta)**52 - 2.45427063552976e+86*cos(theta)**50 + 1.41548094563275e+86*cos(theta)**48 - 7.01829673263181e+85*cos(theta)**46 + 2.99914827344093e+85*cos(theta)**44 - 1.10611862248543e+85*cos(theta)**42 + 3.52207150133118e+84*cos(theta)**40 - 9.67670225797225e+83*cos(theta)**38 + 2.29047868261094e+83*cos(theta)**36 - 4.65935282545978e+82*cos(theta)**34 + 8.11769234497806e+81*cos(theta)**32 - 1.20586265442022e+81*cos(theta)**30 + 1.51867473848522e+80*cos(theta)**28 - 1.61026381808531e+79*cos(theta)**26 + 1.42520626600688e+78*cos(theta)**24 - 1.04200511104079e+77*cos(theta)**22 + 6.21329841637644e+75*cos(theta)**20 - 2.97436810055813e+74*cos(theta)**18 + 1.12088256006255e+73*cos(theta)**16 - 3.24345086104427e+71*cos(theta)**14 + 6.97763660413778e+69*cos(theta)**12 - 1.06874916656555e+68*cos(theta)**10 + 1.09702811349109e+66*cos(theta)**8 - 6.89490172340081e+63*cos(theta)**6 + 2.28711910329527e+61*cos(theta)**4 - 2.99295847759469e+58*cos(theta)**2 + 6.44478569680165e+54)*sin(28*phi)

#@torch.jit.script
def Yl100_m_minus_27(theta, phi):
    return 6.8895745371725e-54*(1.0 - cos(theta)**2)**13.5*(1.49130570059528e+81*cos(theta)**73 - 1.96942280460522e+82*cos(theta)**71 + 1.24213595671167e+83*cos(theta)**69 - 4.98128368281295e+83*cos(theta)**67 + 1.42663448480562e+84*cos(theta)**65 - 3.10722484648764e+84*cos(theta)**63 + 5.35133168006205e+84*cos(theta)**61 - 7.48123527464748e+84*cos(theta)**59 + 8.64891456413638e+84*cos(theta)**57 - 8.38109753756021e+84*cos(theta)**55 + 6.87620433330216e+84*cos(theta)**53 - 4.81229536378384e+84*cos(theta)**51 + 2.8887366237403e+84*cos(theta)**49 - 1.49325462396422e+84*cos(theta)**47 + 6.66477394097984e+83*cos(theta)**45 - 2.57236888950099e+83*cos(theta)**43 + 8.59041829592971e+82*cos(theta)**41 - 2.48120570717237e+82*cos(theta)**39 + 6.19048292597552e+81*cos(theta)**37 - 1.33124366441708e+81*cos(theta)**35 + 2.45990677120547e+80*cos(theta)**33 - 3.88987953038781e+79*cos(theta)**31 + 5.23680944305249e+78*cos(theta)**29 - 5.96394006698264e+77*cos(theta)**27 + 5.70082506402752e+76*cos(theta)**25 - 4.53045700452519e+75*cos(theta)**23 + 2.95871353160783e+74*cos(theta)**21 - 1.5654568950306e+73*cos(theta)**19 + 6.59342682389734e+71*cos(theta)**17 - 2.16230057402951e+70*cos(theta)**15 + 5.36741277241368e+68*cos(theta)**13 - 9.71590151423223e+66*cos(theta)**11 + 1.21892012610122e+65*cos(theta)**9 - 9.8498596048583e+62*cos(theta)**7 + 4.57423820659054e+60*cos(theta)**5 - 9.97652825864895e+57*cos(theta)**3 + 6.44478569680165e+54*cos(theta))*sin(27*phi)

#@torch.jit.script
def Yl100_m_minus_26(theta, phi):
    return 6.6789796988462e-52*(1.0 - cos(theta)**2)**13*(2.0152779737774e+79*cos(theta)**74 - 2.73530945084058e+80*cos(theta)**72 + 1.77447993815953e+81*cos(theta)**70 - 7.32541718060727e+81*cos(theta)**68 + 2.16156740122064e+82*cos(theta)**66 - 4.85503882263694e+82*cos(theta)**64 + 8.63118012913234e+82*cos(theta)**62 - 1.24687254577458e+83*cos(theta)**60 + 1.49119216623041e+83*cos(theta)**58 - 1.49662456027861e+83*cos(theta)**56 + 1.27337117283373e+83*cos(theta)**54 - 9.25441416112277e+82*cos(theta)**52 + 5.7774732474806e+82*cos(theta)**50 - 3.11094713325878e+82*cos(theta)**48 + 1.44886390021301e+82*cos(theta)**46 - 5.84629293068407e+81*cos(theta)**44 + 2.04533768950707e+81*cos(theta)**42 - 6.20301426793093e+80*cos(theta)**40 + 1.62907445420408e+80*cos(theta)**38 - 3.69789906782522e+79*cos(theta)**36 + 7.23501991531021e+78*cos(theta)**34 - 1.21558735324619e+78*cos(theta)**32 + 1.74560314768416e+77*cos(theta)**30 - 2.12997859535094e+76*cos(theta)**28 + 2.19262502462597e+75*cos(theta)**26 - 1.88769041855216e+74*cos(theta)**24 + 1.34486978709447e+73*cos(theta)**22 - 7.82728447515298e+71*cos(theta)**20 + 3.66301490216519e+70*cos(theta)**18 - 1.35143785876844e+69*cos(theta)**16 + 3.83386626600977e+67*cos(theta)**14 - 8.09658459519353e+65*cos(theta)**12 + 1.21892012610122e+64*cos(theta)**10 - 1.23123245060729e+62*cos(theta)**8 + 7.62373034431757e+59*cos(theta)**6 - 2.49413206466224e+57*cos(theta)**4 + 3.22239284840082e+54*cos(theta)**2 - 6.8576140634195e+50)*sin(26*phi)

#@torch.jit.script
def Yl100_m_minus_25(theta, phi):
    return 6.49271033372286e-50*(1.0 - cos(theta)**2)**12.5*(2.68703729836987e+77*cos(theta)**75 - 3.74699924772683e+78*cos(theta)**73 + 2.49926751853454e+79*cos(theta)**71 - 1.06165466385613e+80*cos(theta)**69 + 3.22622000182186e+80*cos(theta)**67 - 7.46929049636453e+80*cos(theta)**65 + 1.37002859192577e+81*cos(theta)**63 - 2.04405335372882e+81*cos(theta)**61 + 2.52744434954307e+81*cos(theta)**59 - 2.6256571232958e+81*cos(theta)**57 + 2.31522031424315e+81*cos(theta)**55 - 1.74611587945713e+81*cos(theta)**53 + 1.13283789166286e+81*cos(theta)**51 - 6.34887170052813e+80*cos(theta)**49 + 3.08268914938938e+80*cos(theta)**47 - 1.29917620681868e+80*cos(theta)**45 + 4.75659927792343e+79*cos(theta)**43 - 1.51293030925145e+79*cos(theta)**41 + 4.17711398513867e+78*cos(theta)**39 - 9.99432180493302e+77*cos(theta)**37 + 2.06714854723149e+77*cos(theta)**35 - 3.68359804013997e+76*cos(theta)**33 + 5.63097789575537e+75*cos(theta)**31 - 7.34475377707222e+74*cos(theta)**29 + 8.12083342454063e+73*cos(theta)**27 - 7.55076167420864e+72*cos(theta)**25 + 5.84725994388899e+71*cos(theta)**23 - 3.72727832150142e+70*cos(theta)**21 + 1.92790258008694e+69*cos(theta)**19 - 7.94963446334379e+67*cos(theta)**17 + 2.55591084400651e+66*cos(theta)**15 - 6.22814199630271e+64*cos(theta)**13 + 1.10810920554656e+63*cos(theta)**11 - 1.36803605623032e+61*cos(theta)**9 + 1.08910433490251e+59*cos(theta)**7 - 4.98826412932448e+56*cos(theta)**5 + 1.07413094946694e+54*cos(theta)**3 - 6.8576140634195e+50*cos(theta))*sin(25*phi)

#@torch.jit.script
def Yl100_m_minus_24(theta, phi):
    return 6.32831123632127e-48*(1.0 - cos(theta)**2)**12*(3.53557539259193e+75*cos(theta)**76 - 5.06351249692814e+76*cos(theta)**74 + 3.47120488685353e+77*cos(theta)**72 - 1.51664951979447e+78*cos(theta)**70 + 4.74444117914979e+78*cos(theta)**68 - 1.13171068126735e+79*cos(theta)**66 + 2.14066967488401e+79*cos(theta)**64 - 3.29686024794971e+79*cos(theta)**62 + 4.21240724923845e+79*cos(theta)**60 - 4.52699504016518e+79*cos(theta)**58 + 4.13432198971991e+79*cos(theta)**56 - 3.2335479249206e+79*cos(theta)**54 + 2.17853440704397e+79*cos(theta)**52 - 1.26977434010563e+79*cos(theta)**50 + 6.42226906122788e+78*cos(theta)**48 - 2.82429610177974e+78*cos(theta)**46 + 1.08104529043714e+78*cos(theta)**44 - 3.60221502202725e+77*cos(theta)**42 + 1.04427849628467e+77*cos(theta)**40 - 2.63008468550869e+76*cos(theta)**38 + 5.74207929786525e+75*cos(theta)**36 - 1.08341118827646e+75*cos(theta)**34 + 1.75968059242355e+74*cos(theta)**32 - 2.44825125902407e+73*cos(theta)**30 + 2.90029765162165e+72*cos(theta)**28 - 2.90413910546486e+71*cos(theta)**26 + 2.43635830995374e+70*cos(theta)**24 - 1.69421741886428e+69*cos(theta)**22 + 9.6395129004347e+67*cos(theta)**20 - 4.41646359074655e+66*cos(theta)**18 + 1.59744427750407e+65*cos(theta)**16 - 4.44867285450194e+63*cos(theta)**14 + 9.23424337955466e+61*cos(theta)**12 - 1.36803605623032e+60*cos(theta)**10 + 1.36138041862814e+58*cos(theta)**8 - 8.31377354887413e+55*cos(theta)**6 + 2.68532737366735e+53*cos(theta)**4 - 3.42880703170975e+50*cos(theta)**2 + 7.21854111938895e+46)*sin(24*phi)

#@torch.jit.script
def Yl100_m_minus_23(theta, phi):
    return 6.18363768824311e-46*(1.0 - cos(theta)**2)**11.5*(4.5916563540155e+73*cos(theta)**77 - 6.75134999590419e+74*cos(theta)**75 + 4.75507518747059e+75*cos(theta)**73 - 2.13612608421756e+76*cos(theta)**71 + 6.87600170891274e+76*cos(theta)**69 - 1.68912041980202e+77*cos(theta)**67 + 3.29333796136002e+77*cos(theta)**65 - 5.23311150468208e+77*cos(theta)**63 + 6.90558565448926e+77*cos(theta)**61 - 7.67287294943251e+77*cos(theta)**59 + 7.25319647319283e+77*cos(theta)**57 - 5.87917804531019e+77*cos(theta)**55 + 4.11044227744144e+77*cos(theta)**53 - 2.48975360805025e+77*cos(theta)**51 + 1.31066715535263e+77*cos(theta)**49 - 6.00914064208456e+76*cos(theta)**47 + 2.4023228676381e+76*cos(theta)**45 - 8.37724423727268e+75*cos(theta)**43 + 2.54702072264553e+75*cos(theta)**41 - 6.74380688591972e+74*cos(theta)**39 + 1.55191332374736e+74*cos(theta)**37 - 3.09546053793275e+73*cos(theta)**35 + 5.33236543158652e+72*cos(theta)**33 - 7.89758470652927e+71*cos(theta)**31 + 1.00010263849023e+71*cos(theta)**29 - 1.0756070760981e+70*cos(theta)**27 + 9.74543323981497e+68*cos(theta)**25 - 7.36616269071427e+67*cos(theta)**23 + 4.59024423830224e+66*cos(theta)**21 - 2.32445452144555e+65*cos(theta)**19 + 9.39673104414159e+63*cos(theta)**17 - 2.96578190300129e+62*cos(theta)**15 + 7.10326413811897e+60*cos(theta)**13 - 1.24366914202756e+59*cos(theta)**11 + 1.51264490958682e+57*cos(theta)**9 - 1.18768193555345e+55*cos(theta)**7 + 5.37065474733471e+52*cos(theta)**5 - 1.14293567723658e+50*cos(theta)**3 + 7.21854111938895e+46*cos(theta))*sin(23*phi)

#@torch.jit.script
def Yl100_m_minus_22(theta, phi):
    return 6.0568091956117e-44*(1.0 - cos(theta)**2)**11*(5.88673891540448e+71*cos(theta)**78 - 8.88335525776867e+72*cos(theta)**76 + 6.42577728036567e+73*cos(theta)**74 - 2.9668417836355e+74*cos(theta)**72 + 9.82285958416105e+74*cos(theta)**70 - 2.48400061735591e+75*cos(theta)**68 + 4.98990600206064e+75*cos(theta)**66 - 8.17673672606575e+75*cos(theta)**64 + 1.11380413782085e+76*cos(theta)**62 - 1.27881215823875e+76*cos(theta)**60 + 1.25055111606773e+76*cos(theta)**58 - 1.04985322237682e+76*cos(theta)**56 + 7.61193014341008e+75*cos(theta)**54 - 4.78798770778893e+75*cos(theta)**52 + 2.62133431070526e+75*cos(theta)**50 - 1.25190430043428e+75*cos(theta)**48 + 5.22244101660456e+74*cos(theta)**46 - 1.9039191448347e+74*cos(theta)**44 + 6.06433505391794e+73*cos(theta)**42 - 1.68595172147993e+73*cos(theta)**40 + 4.08398243091412e+72*cos(theta)**38 - 8.59850149425763e+71*cos(theta)**36 + 1.56834277399604e+71*cos(theta)**34 - 2.4679952207904e+70*cos(theta)**32 + 3.33367546163409e+69*cos(theta)**30 - 3.84145384320749e+68*cos(theta)**28 + 3.74824355377499e+67*cos(theta)**26 - 3.06923445446428e+66*cos(theta)**24 + 2.08647465377375e+65*cos(theta)**22 - 1.16222726072278e+64*cos(theta)**20 + 5.22040613563422e+62*cos(theta)**18 - 1.85361368937581e+61*cos(theta)**16 + 5.07376009865641e+59*cos(theta)**14 - 1.03639095168964e+58*cos(theta)**12 + 1.51264490958682e+56*cos(theta)**10 - 1.48460241944181e+54*cos(theta)**8 + 8.95109124555784e+51*cos(theta)**6 - 2.85733919309146e+49*cos(theta)**4 + 3.60927055969447e+46*cos(theta)**2 - 7.52401617614024e+42)*sin(22*phi)

#@torch.jit.script
def Yl100_m_minus_21(theta, phi):
    return 5.94617043901084e-42*(1.0 - cos(theta)**2)**10.5*(7.45156824734745e+69*cos(theta)**79 - 1.15368250100892e+71*cos(theta)**77 + 8.56770304048755e+71*cos(theta)**75 - 4.06416682689794e+72*cos(theta)**73 + 1.38350134988184e+73*cos(theta)**71 - 3.60000089471871e+73*cos(theta)**69 + 7.44762089859797e+73*cos(theta)**67 - 1.25795949631781e+74*cos(theta)**65 + 1.76794307590611e+74*cos(theta)**63 - 2.09641337416189e+74*cos(theta)**61 + 2.11957816282666e+74*cos(theta)**59 - 1.84184775855582e+74*cos(theta)**57 + 1.38398729880183e+74*cos(theta)**55 - 9.03393907129988e+73*cos(theta)**53 + 5.13987119746128e+73*cos(theta)**51 - 2.55490673558017e+73*cos(theta)**49 + 1.11115766310735e+73*cos(theta)**47 - 4.230931432966e+72*cos(theta)**45 + 1.41031047765533e+72*cos(theta)**43 - 4.11207736946324e+71*cos(theta)**41 + 1.04717498228567e+71*cos(theta)**39 - 2.32391932277233e+70*cos(theta)**37 + 4.48097935427439e+69*cos(theta)**35 - 7.47877339633453e+68*cos(theta)**33 + 1.07537918117229e+68*cos(theta)**31 - 1.32463925627844e+67*cos(theta)**29 + 1.38823835325e+66*cos(theta)**27 - 1.22769378178571e+65*cos(theta)**25 + 9.07162892945107e+63*cos(theta)**23 - 5.53441552725131e+62*cos(theta)**21 + 2.74758217664959e+61*cos(theta)**19 - 1.09036099375047e+60*cos(theta)**17 + 3.3825067324376e+58*cos(theta)**15 - 7.97223808992028e+56*cos(theta)**13 + 1.37513173598802e+55*cos(theta)**11 - 1.64955824382423e+53*cos(theta)**9 + 1.27872732079398e+51*cos(theta)**7 - 5.71467838618292e+48*cos(theta)**5 + 1.20309018656482e+46*cos(theta)**3 - 7.52401617614024e+42*cos(theta))*sin(21*phi)

#@torch.jit.script
def Yl100_m_minus_20(theta, phi):
    return 5.85025817526833e-40*(1.0 - cos(theta)**2)**10*(9.31446030918431e+67*cos(theta)**80 - 1.47908012949861e+69*cos(theta)**78 + 1.12732934743257e+70*cos(theta)**76 - 5.49211733364587e+70*cos(theta)**74 + 1.92152965261366e+71*cos(theta)**72 - 5.14285842102673e+71*cos(theta)**70 + 1.09523836744088e+72*cos(theta)**68 - 1.90599923684516e+72*cos(theta)**66 + 2.76241105610329e+72*cos(theta)**64 - 3.3813118938095e+72*cos(theta)**62 + 3.53263027137777e+72*cos(theta)**60 - 3.17559958371694e+72*cos(theta)**58 + 2.47140589071756e+72*cos(theta)**56 - 1.67295167987035e+72*cos(theta)**54 + 9.88436768742555e+71*cos(theta)**52 - 5.10981347116034e+71*cos(theta)**50 + 2.31491179814032e+71*cos(theta)**48 - 9.19767702818696e+70*cos(theta)**46 + 3.2052510855803e+70*cos(theta)**44 - 9.79066040348391e+69*cos(theta)**42 + 2.61793745571418e+69*cos(theta)**40 - 6.11557716519035e+68*cos(theta)**38 + 1.24471648729844e+68*cos(theta)**36 - 2.19963923421604e+67*cos(theta)**34 + 3.36055994116339e+66*cos(theta)**32 - 4.41546418759482e+65*cos(theta)**30 + 4.95799411874999e+64*cos(theta)**28 - 4.72189916071427e+63*cos(theta)**26 + 3.77984538727128e+62*cos(theta)**24 - 2.51564342147787e+61*cos(theta)**22 + 1.37379108832479e+60*cos(theta)**20 - 6.05756107639153e+58*cos(theta)**18 + 2.1140667077735e+57*cos(theta)**16 - 5.69445577851449e+55*cos(theta)**14 + 1.14594311332335e+54*cos(theta)**12 - 1.64955824382423e+52*cos(theta)**10 + 1.59840915099247e+50*cos(theta)**8 - 9.52446397697153e+47*cos(theta)**6 + 3.00772546641206e+45*cos(theta)**4 - 3.76200808807012e+42*cos(theta)**2 + 7.77274398361595e+38)*sin(20*phi)

#@torch.jit.script
def Yl100_m_minus_19(theta, phi):
    return 5.76777306568225e-38*(1.0 - cos(theta)**2)**9.5*(1.14993337150424e+66*cos(theta)**81 - 1.87225332847926e+67*cos(theta)**79 + 1.46406408757477e+68*cos(theta)**77 - 7.32282311152782e+68*cos(theta)**75 + 2.63223240084064e+69*cos(theta)**73 - 7.24346256482638e+69*cos(theta)**71 + 1.58730198179837e+70*cos(theta)**69 - 2.84477498036592e+70*cos(theta)**67 + 4.24986316323584e+70*cos(theta)**65 - 5.36716173620555e+70*cos(theta)**63 + 5.79119716619306e+70*cos(theta)**61 - 5.38237217579142e+70*cos(theta)**59 + 4.33579980827642e+70*cos(theta)**57 - 3.041730327037e+70*cos(theta)**55 + 1.86497503536331e+70*cos(theta)**53 - 1.00192421003144e+70*cos(theta)**51 + 4.7243097921231e+69*cos(theta)**49 - 1.95695255918872e+69*cos(theta)**47 + 7.12278019017845e+68*cos(theta)**45 - 2.27689776825207e+68*cos(theta)**43 + 6.38521330661994e+67*cos(theta)**41 - 1.56809670902317e+67*cos(theta)**39 + 3.36409861432011e+66*cos(theta)**37 - 6.28468352633154e+65*cos(theta)**35 + 1.01835149732224e+65*cos(theta)**33 - 1.42434328632091e+64*cos(theta)**31 + 1.70965314439655e+63*cos(theta)**29 - 1.74885154100529e+62*cos(theta)**27 + 1.51193815490851e+61*cos(theta)**25 - 1.0937580093382e+60*cos(theta)**23 + 6.54186232535616e+58*cos(theta)**21 - 3.18819004020607e+57*cos(theta)**19 + 1.24356865163147e+56*cos(theta)**17 - 3.79630385234299e+54*cos(theta)**15 + 8.81494702556422e+52*cos(theta)**13 - 1.49959840347657e+51*cos(theta)**11 + 1.77601016776941e+49*cos(theta)**9 - 1.36063771099593e+47*cos(theta)**7 + 6.01545093282412e+44*cos(theta)**5 - 1.25400269602337e+42*cos(theta)**3 + 7.77274398361595e+38*cos(theta))*sin(19*phi)

#@torch.jit.script
def Yl100_m_minus_18(theta, phi):
    return 5.69755559417275e-36*(1.0 - cos(theta)**2)**9*(1.40235777012712e+64*cos(theta)**82 - 2.34031666059907e+65*cos(theta)**80 + 1.87700524048047e+66*cos(theta)**78 - 9.63529356779977e+66*cos(theta)**76 + 3.55707081194681e+67*cos(theta)**74 - 1.006036467337e+68*cos(theta)**72 + 2.26757425971196e+68*cos(theta)**70 - 4.18349261818517e+68*cos(theta)**68 + 6.43918661096339e+68*cos(theta)**66 - 8.38619021282117e+68*cos(theta)**64 + 9.34064059063397e+68*cos(theta)**62 - 8.97062029298569e+68*cos(theta)**60 + 7.47551691082141e+68*cos(theta)**58 - 5.43166129828035e+68*cos(theta)**56 + 3.45365747289502e+68*cos(theta)**54 - 1.92677732698354e+68*cos(theta)**52 + 9.44861958424619e+67*cos(theta)**50 - 4.07698449830982e+67*cos(theta)**48 + 1.54843047612575e+67*cos(theta)**46 - 5.17476765511835e+66*cos(theta)**44 + 1.52028888252856e+66*cos(theta)**42 - 3.92024177255792e+65*cos(theta)**40 + 8.85289109031608e+64*cos(theta)**38 - 1.74574542398098e+64*cos(theta)**36 + 2.99515146271247e+63*cos(theta)**34 - 4.45107276975284e+62*cos(theta)**32 + 5.69884381465516e+61*cos(theta)**30 - 6.24589836073317e+60*cos(theta)**28 + 5.81514674964812e+59*cos(theta)**26 - 4.55732503890918e+58*cos(theta)**24 + 2.9735737842528e+57*cos(theta)**22 - 1.59409502010303e+56*cos(theta)**20 + 6.90871473128596e+54*cos(theta)**18 - 2.37268990771437e+53*cos(theta)**16 + 6.29639073254587e+51*cos(theta)**14 - 1.24966533623048e+50*cos(theta)**12 + 1.77601016776941e+48*cos(theta)**10 - 1.70079713874492e+46*cos(theta)**8 + 1.00257515547069e+44*cos(theta)**6 - 3.13500674005843e+41*cos(theta)**4 + 3.88637199180798e+38*cos(theta)**2 - 7.96550930889112e+34)*sin(18*phi)

#@torch.jit.script
def Yl100_m_minus_17(theta, phi):
    return 5.63856539111379e-34*(1.0 - cos(theta)**2)**8.5*(1.68958767485195e+62*cos(theta)**83 - 2.88927982790009e+63*cos(theta)**81 + 2.3759560006082e+64*cos(theta)**79 - 1.25133682698698e+65*cos(theta)**77 + 4.74276108259574e+65*cos(theta)**75 - 1.37813214703698e+66*cos(theta)**73 + 3.19376656297459e+66*cos(theta)**71 - 6.06303277997851e+66*cos(theta)**69 + 9.61072628501998e+66*cos(theta)**67 - 1.2901831096648e+67*cos(theta)**65 + 1.48264136359269e+67*cos(theta)**63 - 1.47059349065339e+67*cos(theta)**61 + 1.267036764546e+67*cos(theta)**59 - 9.52923034786026e+66*cos(theta)**57 + 6.27937722344549e+66*cos(theta)**55 - 3.63542891883686e+66*cos(theta)**53 + 1.85267050671494e+66*cos(theta)**51 - 8.3203765271629e+65*cos(theta)**49 + 3.29453292792713e+65*cos(theta)**47 - 1.14994836780408e+65*cos(theta)**45 + 3.53555554076409e+64*cos(theta)**43 - 9.56156529892175e+63*cos(theta)**41 + 2.26997207444002e+63*cos(theta)**39 - 4.71823087562428e+62*cos(theta)**37 + 8.55757560774992e+61*cos(theta)**35 - 1.34880993022813e+61*cos(theta)**33 + 1.83833671440489e+60*cos(theta)**31 - 2.15375805542523e+59*cos(theta)**29 + 2.15375805542523e+58*cos(theta)**27 - 1.82293001556367e+57*cos(theta)**25 + 1.29285816706644e+56*cos(theta)**23 - 7.5909286671573e+54*cos(theta)**21 + 3.63616564804524e+53*cos(theta)**19 - 1.39569994571433e+52*cos(theta)**17 + 4.19759382169725e+50*cos(theta)**15 - 9.61281027869599e+48*cos(theta)**13 + 1.61455469797219e+47*cos(theta)**11 - 1.88977459860546e+45*cos(theta)**9 + 1.43225022210098e+43*cos(theta)**7 - 6.27001348011687e+40*cos(theta)**5 + 1.29545733060266e+38*cos(theta)**3 - 7.96550930889112e+34*cos(theta))*sin(17*phi)

#@torch.jit.script
def Yl100_m_minus_16(theta, phi):
    return 5.58986340186811e-32*(1.0 - cos(theta)**2)**8*(2.01141389863327e+60*cos(theta)**84 - 3.52351198524401e+61*cos(theta)**82 + 2.96994500076024e+62*cos(theta)**80 - 1.60427798331664e+63*cos(theta)**78 + 6.24047510867861e+63*cos(theta)**76 - 1.86234073923917e+64*cos(theta)**74 + 4.43578689302027e+64*cos(theta)**72 - 8.6614753999693e+64*cos(theta)**70 + 1.41334210073823e+65*cos(theta)**68 - 1.95482289343151e+65*cos(theta)**66 + 2.31662713061358e+65*cos(theta)**64 - 2.37192498492483e+65*cos(theta)**62 + 2.11172794091e+65*cos(theta)**60 - 1.64297074963108e+65*cos(theta)**58 + 1.12131736132955e+65*cos(theta)**56 - 6.73227577562382e+64*cos(theta)**54 + 3.56282789752873e+64*cos(theta)**52 - 1.66407530543258e+64*cos(theta)**50 + 6.86361026651485e+63*cos(theta)**48 - 2.49988775609582e+63*cos(theta)**46 + 8.03535350173656e+62*cos(theta)**44 - 2.27656316640994e+62*cos(theta)**42 + 5.67493018610005e+61*cos(theta)**40 - 1.24163970411165e+61*cos(theta)**38 + 2.37710433548609e+60*cos(theta)**36 - 3.96708803008274e+59*cos(theta)**34 + 5.74480223251528e+58*cos(theta)**32 - 7.1791935180841e+57*cos(theta)**30 + 7.69199305509011e+56*cos(theta)**28 - 7.01126929062952e+55*cos(theta)**26 + 5.38690902944348e+54*cos(theta)**24 - 3.45042212143514e+53*cos(theta)**22 + 1.81808282402262e+52*cos(theta)**20 - 7.75388858730186e+50*cos(theta)**18 + 2.62349613856078e+49*cos(theta)**16 - 6.86629305621142e+47*cos(theta)**14 + 1.34546224831016e+46*cos(theta)**12 - 1.88977459860546e+44*cos(theta)**10 + 1.79031277762623e+42*cos(theta)**8 - 1.04500224668614e+40*cos(theta)**6 + 3.23864332650665e+37*cos(theta)**4 - 3.98275465444556e+34*cos(theta)**2 + 8.10491382671054e+30)*sin(16*phi)

#@torch.jit.script
def Yl100_m_minus_15(theta, phi):
    return 5.55059643926874e-30*(1.0 - cos(theta)**2)**7.5*(2.36636929250973e+58*cos(theta)**85 - 4.24519516294459e+59*cos(theta)**83 + 3.66659876637067e+60*cos(theta)**81 - 2.03073162445145e+61*cos(theta)**79 + 8.10451312815403e+61*cos(theta)**77 - 2.48312098565222e+62*cos(theta)**75 + 6.07642040139763e+62*cos(theta)**73 - 1.21992611267173e+63*cos(theta)**71 + 2.04832188512787e+63*cos(theta)**69 - 2.91764610959927e+63*cos(theta)**67 + 3.56404173940551e+63*cos(theta)**65 - 3.76496029353147e+63*cos(theta)**63 + 3.46184908345902e+63*cos(theta)**61 - 2.78469618581539e+63*cos(theta)**59 + 1.96722344092904e+63*cos(theta)**57 - 1.22405014102251e+63*cos(theta)**55 + 6.72231678779006e+62*cos(theta)**53 - 3.26289275575016e+62*cos(theta)**51 + 1.40073678908466e+62*cos(theta)**49 - 5.31891011935281e+61*cos(theta)**47 + 1.78563411149701e+61*cos(theta)**45 - 5.2943329451394e+60*cos(theta)**43 + 1.38412931368294e+60*cos(theta)**41 - 3.18369154900424e+59*cos(theta)**39 + 6.42460631212456e+58*cos(theta)**37 - 1.13345372288078e+58*cos(theta)**35 + 1.74084916136827e+57*cos(theta)**33 - 2.31586887680132e+56*cos(theta)**31 + 2.65241139830693e+55*cos(theta)**29 - 2.59676640393686e+54*cos(theta)**27 + 2.15476361177739e+53*cos(theta)**25 - 1.50018353105876e+52*cos(theta)**23 + 8.65753725725057e+50*cos(theta)**21 - 4.08099399331677e+49*cos(theta)**19 + 1.54323302268281e+48*cos(theta)**17 - 4.57752870414095e+46*cos(theta)**15 + 1.03497096023859e+45*cos(theta)**13 - 1.71797690782315e+43*cos(theta)**11 + 1.9892364195847e+41*cos(theta)**9 - 1.49286035240878e+39*cos(theta)**7 + 6.4772866530133e+36*cos(theta)**5 - 1.32758488481519e+34*cos(theta)**3 + 8.10491382671054e+30*cos(theta))*sin(15*phi)

#@torch.jit.script
def Yl100_m_minus_14(theta, phi):
    return 5.51998374114227e-28*(1.0 - cos(theta)**2)**7*(2.75159220059271e+56*cos(theta)**86 - 5.05380376541023e+57*cos(theta)**84 + 4.47146191020814e+58*cos(theta)**82 - 2.53841453056431e+59*cos(theta)**80 + 1.03904014463513e+60*cos(theta)**78 - 3.26726445480555e+60*cos(theta)**76 + 8.21137892080761e+60*cos(theta)**74 - 1.69434182315518e+61*cos(theta)**72 + 2.92617412161125e+61*cos(theta)**70 - 4.29065604352833e+61*cos(theta)**68 + 5.4000632415235e+61*cos(theta)**66 - 5.88275045864292e+61*cos(theta)**64 + 5.58362755396616e+61*cos(theta)**62 - 4.64116030969232e+61*cos(theta)**60 + 3.39176455332593e+61*cos(theta)**58 - 2.18580382325449e+61*cos(theta)**56 + 1.24487347922038e+61*cos(theta)**54 - 6.274793761058e+60*cos(theta)**52 + 2.80147357816933e+60*cos(theta)**50 - 1.10810627486517e+60*cos(theta)**48 + 3.88181328586307e+59*cos(theta)**46 - 1.20325748753168e+59*cos(theta)**44 + 3.29554598495938e+58*cos(theta)**42 - 7.95922887251059e+57*cos(theta)**40 + 1.69068587161173e+57*cos(theta)**38 - 3.14848256355773e+56*cos(theta)**36 + 5.12014459225961e+55*cos(theta)**34 - 7.23709024000413e+54*cos(theta)**32 + 8.84137132768978e+53*cos(theta)**30 - 9.27416572834592e+52*cos(theta)**28 + 8.28755235298997e+51*cos(theta)**26 - 6.25076471274481e+50*cos(theta)**24 + 3.93524420784117e+49*cos(theta)**22 - 2.04049699665838e+48*cos(theta)**20 + 8.57351679268229e+46*cos(theta)**18 - 2.86095544008809e+45*cos(theta)**16 + 7.3926497159899e+43*cos(theta)**14 - 1.43164742318596e+42*cos(theta)**12 + 1.9892364195847e+40*cos(theta)**10 - 1.86607544051097e+38*cos(theta)**8 + 1.07954777550222e+36*cos(theta)**6 - 3.31896221203797e+33*cos(theta)**4 + 4.05245691335527e+30*cos(theta)**2 - 8.19505948100156e+26)*sin(14*phi)

#@torch.jit.script
def Yl100_m_minus_13(theta, phi):
    return 5.49730522113833e-26*(1.0 - cos(theta)**2)**6.5*(3.16274965585369e+54*cos(theta)**87 - 5.94565148871792e+55*cos(theta)**85 + 5.38730350627486e+56*cos(theta)**83 - 3.13384509946211e+57*cos(theta)**81 + 1.31524068941156e+58*cos(theta)**79 - 4.24320059065656e+58*cos(theta)**77 + 1.09485052277435e+59*cos(theta)**75 - 2.32101619610299e+59*cos(theta)**73 + 4.12137200226936e+59*cos(theta)**71 - 6.21834209207005e+59*cos(theta)**69 + 8.0597958828709e+59*cos(theta)**67 - 9.05038532098911e+59*cos(theta)**65 + 8.86290087931137e+59*cos(theta)**63 - 7.60845952408576e+59*cos(theta)**61 + 5.74875348021344e+59*cos(theta)**59 - 3.83474354956928e+59*cos(theta)**57 + 2.26340632585524e+59*cos(theta)**55 - 1.18392335114302e+59*cos(theta)**53 + 5.49308544739084e+58*cos(theta)**51 - 2.26144137727585e+58*cos(theta)**49 + 8.25917720396399e+57*cos(theta)**47 - 2.67390552784818e+57*cos(theta)**45 + 7.66406043013809e+56*cos(theta)**43 - 1.94127533475868e+56*cos(theta)**41 + 4.33509197849161e+55*cos(theta)**39 - 8.50941233393982e+54*cos(theta)**37 + 1.46289845493132e+54*cos(theta)**35 - 2.1930576484861e+53*cos(theta)**33 + 2.8520552669967e+52*cos(theta)**31 - 3.19798818218825e+51*cos(theta)**29 + 3.06946383444073e+50*cos(theta)**27 - 2.50030588509793e+49*cos(theta)**25 + 1.71097574253964e+48*cos(theta)**23 - 9.71665236503992e+46*cos(theta)**21 + 4.51237725930647e+45*cos(theta)**19 - 1.6829149647577e+44*cos(theta)**17 + 4.92843314399327e+42*cos(theta)**15 - 1.10126724860458e+41*cos(theta)**13 + 1.808396745077e+39*cos(theta)**11 - 2.0734171561233e+37*cos(theta)**9 + 1.54221110786031e+35*cos(theta)**7 - 6.63792442407593e+32*cos(theta)**5 + 1.35081897111842e+30*cos(theta)**3 - 8.19505948100156e+26*cos(theta))*sin(13*phi)

#@torch.jit.script
def Yl100_m_minus_12(theta, phi):
    return 5.48189115653224e-24*(1.0 - cos(theta)**2)**6*(3.59403369983374e+52*cos(theta)**88 - 6.91354824269525e+53*cos(theta)**86 + 6.41345655508912e+54*cos(theta)**84 - 3.82176231641721e+55*cos(theta)**82 + 1.64405086176445e+56*cos(theta)**80 - 5.440000757252e+56*cos(theta)**78 + 1.44059279312414e+57*cos(theta)**76 - 3.13650837311215e+57*cos(theta)**74 + 5.72412778092967e+57*cos(theta)**72 - 8.88334584581435e+57*cos(theta)**70 + 1.18526410042219e+58*cos(theta)**68 - 1.37127050318017e+58*cos(theta)**66 + 1.3848282623924e+58*cos(theta)**64 - 1.22717089098157e+58*cos(theta)**62 + 9.58125580035573e+57*cos(theta)**60 - 6.6116268096022e+57*cos(theta)**58 + 4.04179701045578e+57*cos(theta)**56 - 2.19245065026485e+57*cos(theta)**54 + 1.0563625860367e+57*cos(theta)**52 - 4.52288275455171e+56*cos(theta)**50 + 1.7206619174925e+56*cos(theta)**48 - 5.81283810401778e+55*cos(theta)**46 + 1.74183191594048e+55*cos(theta)**44 - 4.62208413037781e+54*cos(theta)**42 + 1.0837729946229e+54*cos(theta)**40 - 2.23931903524732e+53*cos(theta)**38 + 4.06360681925366e+52*cos(theta)**36 - 6.45016955437088e+51*cos(theta)**34 + 8.91267270936469e+50*cos(theta)**32 - 1.06599606072942e+50*cos(theta)**30 + 1.09623708372883e+49*cos(theta)**28 - 9.61656109653048e+47*cos(theta)**26 + 7.12906559391516e+46*cos(theta)**24 - 4.41666016592724e+45*cos(theta)**22 + 2.25618862965323e+44*cos(theta)**20 - 9.34952758198723e+42*cos(theta)**18 + 3.08027071499579e+41*cos(theta)**16 - 7.86619463288987e+39*cos(theta)**14 + 1.50699728756416e+38*cos(theta)**12 - 2.0734171561233e+36*cos(theta)**10 + 1.92776388482539e+34*cos(theta)**8 - 1.10632073734599e+32*cos(theta)**6 + 3.37704742779606e+29*cos(theta)**4 - 4.09752974050078e+26*cos(theta)**2 + 8.24121025844887e+22)*sin(12*phi)

#@torch.jit.script
def Yl100_m_minus_11(theta, phi):
    return 5.47311310261169e-22*(1.0 - cos(theta)**2)**5.5*(4.03824011217274e+50*cos(theta)**89 - 7.94660717551178e+51*cos(theta)**87 + 7.5452430059872e+52*cos(theta)**85 - 4.60453291134604e+53*cos(theta)**83 + 2.02969242193142e+54*cos(theta)**81 - 6.88607690791393e+54*cos(theta)**79 + 1.87089973133005e+55*cos(theta)**77 - 4.18201116414953e+55*cos(theta)**75 + 7.84127093278037e+55*cos(theta)**73 - 1.25117547124146e+56*cos(theta)**71 + 1.71777405858289e+56*cos(theta)**69 - 2.04667239280622e+56*cos(theta)**67 + 2.13050501906523e+56*cos(theta)**65 - 1.94789030314536e+56*cos(theta)**63 + 1.57069767218946e+56*cos(theta)**61 - 1.1206147134919e+56*cos(theta)**59 + 7.09087194816804e+55*cos(theta)**57 - 3.98627390957245e+55*cos(theta)**55 + 1.99313695478623e+55*cos(theta)**53 - 8.86839755794453e+54*cos(theta)**51 + 3.51155493365816e+54*cos(theta)**49 - 1.23677406468463e+54*cos(theta)**47 + 3.87073759097884e+53*cos(theta)**45 - 1.07490328613438e+53*cos(theta)**43 + 2.64334876737293e+52*cos(theta)**41 - 5.74184368012134e+51*cos(theta)**39 + 1.0982721133118e+51*cos(theta)**37 - 1.84290558696311e+50*cos(theta)**35 + 2.7008099119287e+49*cos(theta)**33 - 3.43869697009489e+48*cos(theta)**31 + 3.78012787492701e+47*cos(theta)**29 - 3.56168929501129e+46*cos(theta)**27 + 2.85162623756606e+45*cos(theta)**25 - 1.92028702866402e+44*cos(theta)**23 + 1.07437553793011e+43*cos(theta)**21 - 4.92080399051959e+41*cos(theta)**19 + 1.81192394999752e+40*cos(theta)**17 - 5.24412975525991e+38*cos(theta)**15 + 1.15922868274167e+37*cos(theta)**13 - 1.88492468738482e+35*cos(theta)**11 + 2.14195987202821e+33*cos(theta)**9 - 1.58045819620856e+31*cos(theta)**7 + 6.75409485559212e+28*cos(theta)**5 - 1.36584324683359e+26*cos(theta)**3 + 8.24121025844887e+22*cos(theta))*sin(11*phi)

#@torch.jit.script
def Yl100_m_minus_10(theta, phi):
    return 5.47037586157896e-20*(1.0 - cos(theta)**2)**5*(4.48693345796971e+48*cos(theta)**90 - 9.03023542671794e+49*cos(theta)**88 + 8.77353837905489e+50*cos(theta)**86 - 5.48158679922147e+51*cos(theta)**84 + 2.47523466089198e+52*cos(theta)**82 - 8.60759613489241e+52*cos(theta)**80 + 2.39858939914109e+53*cos(theta)**78 - 5.50264626861781e+53*cos(theta)**76 + 1.05963120713248e+54*cos(theta)**74 - 1.73774371005758e+54*cos(theta)**72 + 2.45396294083269e+54*cos(theta)**70 - 3.00981234236209e+54*cos(theta)**68 + 3.2280379076746e+54*cos(theta)**66 - 3.04357859866462e+54*cos(theta)**64 + 2.53338334224107e+54*cos(theta)**62 - 1.86769118915316e+54*cos(theta)**60 + 1.22256412899449e+54*cos(theta)**58 - 7.11834626709366e+53*cos(theta)**56 + 3.69099436071523e+53*cos(theta)**54 - 1.70546106883549e+53*cos(theta)**52 + 7.02310986731632e+52*cos(theta)**50 - 2.57661263475965e+52*cos(theta)**48 + 8.41464693691051e+51*cos(theta)**46 - 2.44296201394176e+51*cos(theta)**44 + 6.29368754136412e+50*cos(theta)**42 - 1.43546092003033e+50*cos(theta)**40 + 2.89018977187316e+49*cos(theta)**38 - 5.11918218600864e+48*cos(theta)**36 + 7.94355856449616e+47*cos(theta)**34 - 1.07459280315465e+47*cos(theta)**32 + 1.26004262497567e+46*cos(theta)**30 - 1.27203189107546e+45*cos(theta)**28 + 1.09677932214079e+44*cos(theta)**26 - 8.00119595276674e+42*cos(theta)**24 + 4.8835251724096e+41*cos(theta)**22 - 2.4604019952598e+40*cos(theta)**20 + 1.00662441666529e+39*cos(theta)**18 - 3.27758109703745e+37*cos(theta)**16 + 8.28020487672618e+35*cos(theta)**14 - 1.57077057282068e+34*cos(theta)**12 + 2.14195987202821e+32*cos(theta)**10 - 1.97557274526069e+30*cos(theta)**8 + 1.12568247593202e+28*cos(theta)**6 - 3.41460811708398e+25*cos(theta)**4 + 4.12060512922444e+22*cos(theta)**2 - 8.24945971816704e+18)*sin(10*phi)

#@torch.jit.script
def Yl100_m_minus_9(theta, phi):
    return 5.47311036605445e-18*(1.0 - cos(theta)**2)**4.5*(4.93069610765902e+46*cos(theta)**91 - 1.01463319401325e+48*cos(theta)**89 + 1.00845268724769e+49*cos(theta)**87 - 6.44892564614291e+49*cos(theta)**85 + 2.98221043480961e+50*cos(theta)**83 - 1.06266618949289e+51*cos(theta)**81 + 3.03618911283683e+51*cos(theta)**79 - 7.1462938553478e+51*cos(theta)**77 + 1.41284160950998e+52*cos(theta)**75 - 2.38047083569532e+52*cos(theta)**73 + 3.45628583215872e+52*cos(theta)**71 - 4.36204687298854e+52*cos(theta)**69 + 4.81796702638e+52*cos(theta)**67 - 4.68242861333018e+52*cos(theta)**65 + 4.02124340038265e+52*cos(theta)**63 - 3.06178883467732e+52*cos(theta)**61 + 2.07214259151608e+52*cos(theta)**59 - 1.24883267843749e+52*cos(theta)**57 + 6.71089883766406e+51*cos(theta)**55 - 3.2178510732745e+51*cos(theta)**53 + 1.37708036614045e+51*cos(theta)**51 - 5.25839313216256e+50*cos(theta)**49 + 1.79035041210862e+50*cos(theta)**47 - 5.42880447542614e+49*cos(theta)**45 + 1.46364826543352e+49*cos(theta)**43 - 3.50112419519594e+48*cos(theta)**41 + 7.41074300480296e+47*cos(theta)**39 - 1.38356275297531e+47*cos(theta)**37 + 2.26958816128462e+46*cos(theta)**35 - 3.25634182774137e+45*cos(theta)**33 + 4.06465362895377e+44*cos(theta)**31 - 4.38631686577745e+43*cos(theta)**29 + 4.0621456375585e+42*cos(theta)**27 - 3.20047838110669e+41*cos(theta)**25 + 2.12327181409113e+40*cos(theta)**23 - 1.17161999774276e+39*cos(theta)**21 + 5.2980232456068e+37*cos(theta)**19 - 1.92798888061026e+36*cos(theta)**17 + 5.52013658448412e+34*cos(theta)**15 - 1.20828505601591e+33*cos(theta)**13 + 1.94723624729837e+31*cos(theta)**11 - 2.19508082806744e+29*cos(theta)**9 + 1.60811782276003e+27*cos(theta)**7 - 6.82921623416796e+24*cos(theta)**5 + 1.37353504307481e+22*cos(theta)**3 - 8.24945971816704e+18*cos(theta))*sin(9*phi)

#@torch.jit.script
def Yl100_m_minus_8(theta, phi):
    return 5.48076736441476e-16*(1.0 - cos(theta)**2)**4*(5.35945229093372e+44*cos(theta)**92 - 1.12737021557028e+46*cos(theta)**90 + 1.14596896278146e+47*cos(theta)**88 - 7.49875075132896e+47*cos(theta)**86 + 3.55025051763049e+48*cos(theta)**84 - 1.29593437743035e+49*cos(theta)**82 + 3.79523639104604e+49*cos(theta)**80 - 9.16191519916385e+49*cos(theta)**78 + 1.85900211777629e+50*cos(theta)**76 - 3.21685248066935e+50*cos(theta)**74 + 4.80039698910934e+50*cos(theta)**72 - 6.23149553284077e+50*cos(theta)**70 + 7.08524562702941e+50*cos(theta)**68 - 7.09458880807604e+50*cos(theta)**66 + 6.28319281309789e+50*cos(theta)**64 - 4.93836908818922e+50*cos(theta)**62 + 3.45357098586014e+50*cos(theta)**60 - 2.15315979040946e+50*cos(theta)**58 + 1.19837479244001e+50*cos(theta)**56 - 5.95898346902685e+49*cos(theta)**54 + 2.64823147334703e+49*cos(theta)**52 - 1.05167862643251e+49*cos(theta)**50 + 3.72989669189296e+48*cos(theta)**48 - 1.1801748859622e+48*cos(theta)**46 + 3.32647333053072e+47*cos(theta)**44 - 8.33600998856175e+46*cos(theta)**42 + 1.85268575120074e+46*cos(theta)**40 - 3.64095461309291e+45*cos(theta)**38 + 6.30441155912394e+44*cos(theta)**36 - 9.57747596394522e+43*cos(theta)**34 + 1.27020425904805e+43*cos(theta)**32 - 1.46210562192582e+42*cos(theta)**30 + 1.45076629912803e+41*cos(theta)**28 - 1.23095322350257e+40*cos(theta)**26 + 8.84696589204637e+38*cos(theta)**24 - 5.32554544428527e+37*cos(theta)**22 + 2.6490116228034e+36*cos(theta)**20 - 1.07110493367237e+35*cos(theta)**18 + 3.45008536530257e+33*cos(theta)**16 - 8.63060754297079e+31*cos(theta)**14 + 1.62269687274864e+30*cos(theta)**12 - 2.19508082806744e+28*cos(theta)**10 + 2.01014727845003e+26*cos(theta)**8 - 1.13820270569466e+24*cos(theta)**6 + 3.43383760768703e+21*cos(theta)**4 - 4.12472985908352e+18*cos(theta)**2 + 822642572613386.0)*sin(8*phi)

#@torch.jit.script
def Yl100_m_minus_7(theta, phi):
    return 5.49281181825906e-14*(1.0 - cos(theta)**2)**3.5*(5.76285192573518e+42*cos(theta)**93 - 1.23886836875855e+44*cos(theta)**91 + 1.28760557615895e+45*cos(theta)**89 - 8.61925373715973e+45*cos(theta)**87 + 4.1767653148594e+46*cos(theta)**85 - 1.56136671979561e+47*cos(theta)**83 + 4.68547702598276e+47*cos(theta)**81 - 1.15973610115998e+48*cos(theta)**79 + 2.41428846464453e+48*cos(theta)**77 - 4.28913664089246e+48*cos(theta)**75 + 6.57588628645115e+48*cos(theta)**73 - 8.77675427160672e+48*cos(theta)**71 + 1.0268471923231e+49*cos(theta)**69 - 1.05889385195165e+49*cos(theta)**67 + 9.66645048168907e+48*cos(theta)**65 - 7.83868109236385e+48*cos(theta)**63 + 5.66159178009859e+48*cos(theta)**61 - 3.64942337357535e+48*cos(theta)**59 + 2.10241191656142e+48*cos(theta)**57 - 1.08345153982306e+48*cos(theta)**55 + 4.99666315725854e+47*cos(theta)**53 - 2.06211495378924e+47*cos(theta)**51 + 7.61203406508767e+46*cos(theta)**49 - 2.51101039566426e+46*cos(theta)**47 + 7.39216295673494e+45*cos(theta)**45 - 1.93860697408413e+45*cos(theta)**43 + 4.51874573463595e+44*cos(theta)**41 - 9.3357810592126e+43*cos(theta)**39 + 1.70389501597944e+43*cos(theta)**37 - 2.73642170398435e+42*cos(theta)**35 + 3.84910381529713e+41*cos(theta)**33 - 4.7164697481478e+40*cos(theta)**31 + 5.00264241078633e+39*cos(theta)**29 - 4.5590860129725e+38*cos(theta)**27 + 3.53878635681855e+37*cos(theta)**25 - 2.3154545409936e+36*cos(theta)**23 + 1.26143410609686e+35*cos(theta)**21 - 5.6373943877493e+33*cos(theta)**19 + 2.02946197958975e+32*cos(theta)**17 - 5.75373836198053e+30*cos(theta)**15 + 1.2482283636528e+29*cos(theta)**13 - 1.99552802551585e+27*cos(theta)**11 + 2.23349697605559e+25*cos(theta)**9 - 1.62600386527809e+23*cos(theta)**7 + 6.86767521537406e+20*cos(theta)**5 - 1.37490995302784e+18*cos(theta)**3 + 822642572613386.0*cos(theta))*sin(7*phi)

#@torch.jit.script
def Yl100_m_minus_6(theta, phi):
    return 5.50871794199858e-12*(1.0 - cos(theta)**2)**3*(6.13069353801615e+40*cos(theta)**94 - 1.34659605299842e+42*cos(theta)**92 + 1.43067286239883e+43*cos(theta)**90 - 9.79460651949969e+43*cos(theta)**88 + 4.85670385448767e+44*cos(theta)**86 - 1.85876990451858e+45*cos(theta)**84 + 5.71399637314971e+45*cos(theta)**82 - 1.44967012644998e+46*cos(theta)**80 + 3.09524162133914e+46*cos(theta)**78 - 5.64360084327956e+46*cos(theta)**76 + 8.88633281952858e+46*cos(theta)**74 - 1.21899364883427e+47*cos(theta)**72 + 1.46692456046157e+47*cos(theta)**70 - 1.55719684110536e+47*cos(theta)**68 + 1.46461370934683e+47*cos(theta)**66 - 1.22479392068185e+47*cos(theta)**64 + 9.13159964532031e+46*cos(theta)**62 - 6.08237228929225e+46*cos(theta)**60 + 3.62484813200245e+46*cos(theta)**58 - 1.93473489254119e+46*cos(theta)**56 + 9.25307992084915e+45*cos(theta)**54 - 3.96560568036392e+45*cos(theta)**52 + 1.52240681301753e+45*cos(theta)**50 - 5.23127165763388e+44*cos(theta)**48 + 1.60699194711629e+44*cos(theta)**46 - 4.40592494110029e+43*cos(theta)**44 + 1.07589184157999e+43*cos(theta)**42 - 2.33394526480315e+42*cos(theta)**40 + 4.48393425257748e+41*cos(theta)**38 - 7.60117139995652e+40*cos(theta)**36 + 1.13208935744033e+40*cos(theta)**34 - 1.47389679629619e+39*cos(theta)**32 + 1.66754747026211e+38*cos(theta)**30 - 1.62824500463304e+37*cos(theta)**28 + 1.36107167569944e+36*cos(theta)**26 - 9.64772725413999e+34*cos(theta)**24 + 5.73379139134935e+33*cos(theta)**22 - 2.81869719387465e+32*cos(theta)**20 + 1.12747887754986e+31*cos(theta)**18 - 3.59608647623783e+29*cos(theta)**16 + 8.91591688323429e+27*cos(theta)**14 - 1.66294002126321e+26*cos(theta)**12 + 2.23349697605559e+24*cos(theta)**10 - 2.03250483159761e+22*cos(theta)**8 + 1.14461253589568e+20*cos(theta)**6 - 3.4372748825696e+17*cos(theta)**4 + 411321286306693.0*cos(theta)**2 - 81789875980.6509)*sin(6*phi)

#@torch.jit.script
def Yl100_m_minus_5(theta, phi):
    return 5.52796483147718e-10*(1.0 - cos(theta)**2)**2.5*(6.45336161896437e+38*cos(theta)**95 - 1.44795274515959e+40*cos(theta)**93 + 1.57216798065806e+41*cos(theta)**91 - 1.10051758646064e+42*cos(theta)**89 + 5.58241822354905e+42*cos(theta)**87 - 2.18678812296303e+43*cos(theta)**85 + 6.88433297969844e+43*cos(theta)**83 - 1.7897162054938e+44*cos(theta)**81 + 3.91802736878372e+44*cos(theta)**79 - 7.3293517445189e+44*cos(theta)**77 + 1.18484437593714e+45*cos(theta)**75 - 1.6698543134716e+45*cos(theta)**73 + 2.06609093022757e+45*cos(theta)**71 - 2.25680701609473e+45*cos(theta)**69 + 2.18599061096542e+45*cos(theta)**67 - 1.88429833951054e+45*cos(theta)**65 + 1.44946026116195e+45*cos(theta)**63 - 9.97110211359385e+44*cos(theta)**61 + 6.1438103932245e+44*cos(theta)**59 - 3.39427174130033e+44*cos(theta)**57 + 1.68237816742712e+44*cos(theta)**55 - 7.48227486861117e+43*cos(theta)**53 + 2.9851113980736e+43*cos(theta)**51 - 1.06760646074161e+43*cos(theta)**49 + 3.41913180237509e+42*cos(theta)**47 - 9.79094431355621e+41*cos(theta)**45 + 2.50207405018602e+41*cos(theta)**43 - 5.69254942634915e+40*cos(theta)**41 + 1.14972673143012e+40*cos(theta)**39 - 2.0543706486369e+39*cos(theta)**37 + 3.23454102125809e+38*cos(theta)**35 - 4.46635392817026e+37*cos(theta)**33 + 5.37918538794229e+36*cos(theta)**31 - 5.61463794701047e+35*cos(theta)**29 + 5.04100620629423e+34*cos(theta)**27 - 3.859090901656e+33*cos(theta)**25 + 2.49295277884754e+32*cos(theta)**23 - 1.34223675898793e+31*cos(theta)**21 + 5.93409935552558e+29*cos(theta)**19 - 2.11534498602225e+28*cos(theta)**17 + 5.94394458882286e+26*cos(theta)**15 - 1.27918463174093e+25*cos(theta)**13 + 2.03045179641418e+23*cos(theta)**11 - 2.25833870177512e+21*cos(theta)**9 + 1.63516076556525e+19*cos(theta)**7 - 6.8745497651392e+16*cos(theta)**5 + 137107095435564.0*cos(theta)**3 - 81789875980.6509*cos(theta))*sin(5*phi)

#@torch.jit.script
def Yl100_m_minus_4(theta, phi):
    return 5.55003264309976e-8*(1.0 - cos(theta)**2)**2*(6.72225168642122e+36*cos(theta)**96 - 1.54037526080808e+38*cos(theta)**94 + 1.70887823984571e+39*cos(theta)**92 - 1.2227973182896e+40*cos(theta)**90 + 6.34365707221483e+40*cos(theta)**88 - 2.54277688716632e+41*cos(theta)**86 + 8.195634499641e+41*cos(theta)**84 - 2.18258073840707e+42*cos(theta)**82 + 4.89753421097965e+42*cos(theta)**80 - 9.39660480066526e+42*cos(theta)**78 + 1.55900575781203e+43*cos(theta)**76 - 2.25655988306973e+43*cos(theta)**74 + 2.86957073642718e+43*cos(theta)**72 - 3.22401002299247e+43*cos(theta)**70 + 3.21469207494914e+43*cos(theta)**68 - 2.85499748410688e+43*cos(theta)**66 + 2.26478165806555e+43*cos(theta)**64 - 1.60824227638611e+43*cos(theta)**62 + 1.02396839887075e+43*cos(theta)**60 - 5.85219265741436e+42*cos(theta)**58 + 3.00424672754843e+42*cos(theta)**56 - 1.38560645715022e+42*cos(theta)**54 + 5.74059884244922e+41*cos(theta)**52 - 2.13521292148322e+41*cos(theta)**50 + 7.1231912549481e+40*cos(theta)**48 - 2.12846615512091e+40*cos(theta)**46 + 5.68653193224096e+39*cos(theta)**44 - 1.35536891103551e+39*cos(theta)**42 + 2.87431682857531e+38*cos(theta)**40 - 5.40623854904447e+37*cos(theta)**38 + 8.98483617016137e+36*cos(theta)**36 - 1.31363350828537e+36*cos(theta)**34 + 1.68099543373196e+35*cos(theta)**32 - 1.87154598233682e+34*cos(theta)**30 + 1.8003593593908e+33*cos(theta)**28 - 1.48426573140615e+32*cos(theta)**26 + 1.03873032451981e+31*cos(theta)**24 - 6.10107617721786e+29*cos(theta)**22 + 2.96704967776279e+28*cos(theta)**20 - 1.17519165890125e+27*cos(theta)**18 + 3.71496536801429e+25*cos(theta)**16 - 9.1370330838638e+23*cos(theta)**14 + 1.69204316367848e+22*cos(theta)**12 - 2.25833870177512e+20*cos(theta)**10 + 2.04395095695657e+18*cos(theta)**8 - 1.14575829418987e+16*cos(theta)**6 + 34276773858891.1*cos(theta)**4 - 40894937990.3254*cos(theta)**2 + 8114074.99808044)*sin(4*phi)

#@torch.jit.script
def Yl100_m_minus_3(theta, phi):
    return 5.57439929750823e-6*(1.0 - cos(theta)**2)**1.5*(6.93015637775383e+34*cos(theta)**97 - 1.62144764295587e+36*cos(theta)**95 + 1.83750348370507e+37*cos(theta)**93 - 1.34373331680176e+38*cos(theta)**91 + 7.12770457552228e+38*cos(theta)**89 - 2.92273205421416e+39*cos(theta)**87 + 9.64192294075412e+39*cos(theta)**85 - 2.6296153474784e+40*cos(theta)**83 + 6.04633853207364e+40*cos(theta)**81 - 1.18944364565383e+41*cos(theta)**79 + 2.02468280235329e+41*cos(theta)**77 - 3.00874651075963e+41*cos(theta)**75 + 3.93091881702353e+41*cos(theta)**73 - 4.54085918731334e+41*cos(theta)**71 + 4.65897402166542e+41*cos(theta)**69 - 4.26119027478639e+41*cos(theta)**67 + 3.484279473947e+41*cos(theta)**65 - 2.55276551807318e+41*cos(theta)**63 + 1.67863671946024e+41*cos(theta)**61 - 9.91897060578705e+40*cos(theta)**59 + 5.27060829394461e+40*cos(theta)**57 - 2.51928446754585e+40*cos(theta)**55 + 1.08313185706589e+40*cos(theta)**53 - 4.18669200290827e+39*cos(theta)**51 + 1.45371250100982e+39*cos(theta)**49 - 4.52865139387429e+38*cos(theta)**47 + 1.26367376272021e+38*cos(theta)**45 - 3.1520207233384e+37*cos(theta)**43 + 7.01052885018368e+36*cos(theta)**41 - 1.3862150125755e+36*cos(theta)**39 + 2.42833410004361e+35*cos(theta)**37 - 3.75323859510106e+34*cos(theta)**35 + 5.09392555676353e+33*cos(theta)**33 - 6.03724510431233e+32*cos(theta)**31 + 6.20813572203723e+31*cos(theta)**29 - 5.49728048668945e+30*cos(theta)**27 + 4.15492129807924e+29*cos(theta)**25 - 2.65264181618168e+28*cos(theta)**23 + 1.41288079893466e+27*cos(theta)**21 - 6.18521925737501e+25*cos(theta)**19 + 2.18527374589076e+24*cos(theta)**17 - 6.09135538924253e+22*cos(theta)**15 + 1.30157166436806e+21*cos(theta)**13 - 2.05303518343193e+19*cos(theta)**11 + 2.27105661884063e+17*cos(theta)**9 - 1.63679756312838e+15*cos(theta)**7 + 6855354771778.22*cos(theta)**5 - 13631645996.7751*cos(theta)**3 + 8114074.99808044*cos(theta))*sin(3*phi)

#@torch.jit.script
def Yl100_m_minus_2(theta, phi):
    return 0.000560053769265274*(1.0 - cos(theta)**2)*(7.07158814056514e+32*cos(theta)**98 - 1.68900796141237e+34*cos(theta)**96 + 1.95479094011177e+35*cos(theta)**94 - 1.46057969217582e+36*cos(theta)**92 + 7.91967175058031e+36*cos(theta)**90 - 3.32128642524336e+37*cos(theta)**88 + 1.12115383032025e+38*cos(theta)**86 - 3.13049446128381e+38*cos(theta)**84 + 7.37358357569956e+38*cos(theta)**82 - 1.48680455706729e+39*cos(theta)**80 + 2.59574718250422e+39*cos(theta)**78 - 3.95887698784163e+39*cos(theta)**76 + 5.31205245543721e+39*cos(theta)**74 - 6.30674887126853e+39*cos(theta)**72 + 6.65567717380774e+39*cos(theta)**70 - 6.26645628645057e+39*cos(theta)**68 + 5.27921132416213e+39*cos(theta)**66 - 3.98869612198935e+39*cos(theta)**64 + 2.70747857977459e+39*cos(theta)**62 - 1.65316176763117e+39*cos(theta)**60 + 9.08725567921484e+38*cos(theta)**58 - 4.49872226347473e+38*cos(theta)**56 + 2.00579973530721e+38*cos(theta)**54 - 8.05133077482359e+37*cos(theta)**52 + 2.90742500201963e+37*cos(theta)**50 - 9.43469040390476e+36*cos(theta)**48 + 2.74711687547872e+36*cos(theta)**46 - 7.16368346213272e+35*cos(theta)**44 + 1.66917353575802e+35*cos(theta)**42 - 3.46553753143876e+34*cos(theta)**40 + 6.39035289485162e+33*cos(theta)**38 - 1.04256627641696e+33*cos(theta)**36 + 1.4982133990481e+32*cos(theta)**34 - 1.8866390950976e+31*cos(theta)**32 + 2.06937857401241e+30*cos(theta)**30 - 1.96331445953195e+29*cos(theta)**28 + 1.5980466531074e+28*cos(theta)**26 - 1.10526742340903e+27*cos(theta)**24 + 6.42218544970301e+25*cos(theta)**22 - 3.0926096286875e+24*cos(theta)**20 + 1.21404096993931e+23*cos(theta)**18 - 3.80709711827658e+21*cos(theta)**16 + 9.29694045977187e+19*cos(theta)**14 - 1.71086265285994e+18*cos(theta)**12 + 2.27105661884063e+16*cos(theta)**10 - 204599695391048.0*cos(theta)**8 + 1142559128629.7*cos(theta)**6 - 3407911499.19379*cos(theta)**4 + 4057037.49904022*cos(theta)**2 - 803.851297610506)*sin(2*phi)

#@torch.jit.script
def Yl100_m_minus_1(theta, phi):
    return 0.0562791342033643*(1.0 - cos(theta)**2)**0.5*(7.14301832380317e+30*cos(theta)**99 - 1.74124532104368e+32*cos(theta)**97 + 2.05767467380187e+33*cos(theta)**95 - 1.57051579803852e+34*cos(theta)**93 + 8.70293598964869e+34*cos(theta)**91 - 3.73178250027344e+35*cos(theta)**89 + 1.28868256358649e+36*cos(theta)**87 - 3.68293466033389e+36*cos(theta)**85 + 8.88383563337296e+36*cos(theta)**83 - 1.83556118156455e+37*cos(theta)**81 + 3.28575592722053e+37*cos(theta)**79 - 5.1413986855086e+37*cos(theta)**77 + 7.08273660724961e+37*cos(theta)**75 - 8.63938201543634e+37*cos(theta)**73 + 9.37419320254612e+37*cos(theta)**71 - 9.08182070500082e+37*cos(theta)**69 + 7.87941988680914e+37*cos(theta)**67 - 6.13645557229131e+37*cos(theta)**65 + 4.29758504726125e+37*cos(theta)**63 - 2.71010125841176e+37*cos(theta)**61 + 1.54021282698557e+37*cos(theta)**59 - 7.89249519907848e+36*cos(theta)**57 + 3.64690860964946e+36*cos(theta)**55 - 1.51911901411766e+36*cos(theta)**53 + 5.70083333729339e+35*cos(theta)**51 - 1.92544702120505e+35*cos(theta)**49 + 5.84492952229515e+34*cos(theta)**47 - 1.59192965825172e+34*cos(theta)**45 + 3.88179892036749e+33*cos(theta)**43 - 8.45253056448478e+32*cos(theta)**41 + 1.63855202432093e+32*cos(theta)**39 - 2.81774669301881e+31*cos(theta)**37 + 4.28060971156599e+30*cos(theta)**35 - 5.71708816696243e+29*cos(theta)**33 + 6.67541475487874e+28*cos(theta)**31 - 6.77004986045499e+27*cos(theta)**29 + 5.91869130780518e+26*cos(theta)**27 - 4.42106969363613e+25*cos(theta)**25 + 2.79225454334914e+24*cos(theta)**23 - 1.47267125175595e+23*cos(theta)**21 + 6.38968931547005e+21*cos(theta)**19 - 2.23946889310387e+20*cos(theta)**17 + 6.19796030651458e+18*cos(theta)**15 - 1.31604819450765e+17*cos(theta)**13 + 2.06459692621875e+15*cos(theta)**11 - 22733299487894.2*cos(theta)**9 + 163222732661.386*cos(theta)**7 - 681582299.838757*cos(theta)**5 + 1352345.83301341*cos(theta)**3 - 803.851297610506*cos(theta))*sin(phi)

#@torch.jit.script
def Yl100_m0(theta, phi):
    return 8.9747990562769e+29*cos(theta)**100 - 2.23242489088295e+31*cos(theta)**98 + 2.6930750016159e+32*cos(theta)**96 - 2.09921743715701e+33*cos(theta)**94 + 1.18855951007944e+34*cos(theta)**92 - 5.20974880543722e+34*cos(theta)**90 + 1.83995096699965e+35*cos(theta)**88 - 5.38069694551159e+35*cos(theta)**86 + 1.32881400917871e+36*cos(theta)**84 - 2.81253529811595e+36*cos(theta)**82 + 5.16045841162601e+36*cos(theta)**80 - 8.28189364181726e+36*cos(theta)**78 + 1.1709287479462e+37*cos(theta)**76 - 1.46687777215238e+37*cos(theta)**74 + 1.63585337018314e+37*cos(theta)**72 - 1.63011353379654e+37*cos(theta)**70 + 1.45588912134565e+37*cos(theta)**68 - 1.1681984566486e+37*cos(theta)**66 + 8.43698885357326e+36*cos(theta)**64 - 5.49207927956206e+36*cos(theta)**62 + 3.22531736573039e+36*cos(theta)**60 - 1.70973696835663e+36*cos(theta)**58 + 8.18238334885208e+35*cos(theta)**56 - 3.53460599080847e+35*cos(theta)**54 + 1.37745674641801e+35*cos(theta)**52 - 4.83843084966961e+34*cos(theta)**50 + 1.52996329139011e+34*cos(theta)**48 - 4.34819499291519e+33*cos(theta)**46 + 1.10846842799685e+33*cos(theta)**44 - 2.52860171903791e+32*cos(theta)**42 + 5.14687016570129e+31*cos(theta)**40 - 9.31668305696682e+30*cos(theta)**38 + 1.49398453217328e+30*cos(theta)**36 - 2.11270539903293e+29*cos(theta)**34 + 2.62102549504085e+28*cos(theta)**32 - 2.83539508296676e+27*cos(theta)**30 + 2.65589332706835e+26*cos(theta)**28 - 2.13647090366426e+25*cos(theta)**26 + 1.46179588145449e+24*cos(theta)**24 - 8.41058293269628e+22*cos(theta)**22 + 4.01414185424141e+21*cos(theta)**20 - 1.56320342755865e+20*cos(theta)**18 + 4.86711689899215e+18*cos(theta)**16 - 1.18110015749051e+17*cos(theta)**14 + 2.16170785059607e+15*cos(theta)**12 - 28563106734602.7*cos(theta)**10 + 256350180107.124*cos(theta)**8 - 1427282768.54235*cos(theta)**6 + 4247865.38256652*cos(theta)**4 - 5049.96875280347*cos(theta)**2 + 0.999993812436331

#@torch.jit.script
def Yl100_m1(theta, phi):
    return 0.0562791342033643*(1.0 - cos(theta)**2)**0.5*(7.14301832380317e+30*cos(theta)**99 - 1.74124532104368e+32*cos(theta)**97 + 2.05767467380187e+33*cos(theta)**95 - 1.57051579803852e+34*cos(theta)**93 + 8.70293598964869e+34*cos(theta)**91 - 3.73178250027344e+35*cos(theta)**89 + 1.28868256358649e+36*cos(theta)**87 - 3.68293466033389e+36*cos(theta)**85 + 8.88383563337296e+36*cos(theta)**83 - 1.83556118156455e+37*cos(theta)**81 + 3.28575592722053e+37*cos(theta)**79 - 5.1413986855086e+37*cos(theta)**77 + 7.08273660724961e+37*cos(theta)**75 - 8.63938201543634e+37*cos(theta)**73 + 9.37419320254612e+37*cos(theta)**71 - 9.08182070500082e+37*cos(theta)**69 + 7.87941988680914e+37*cos(theta)**67 - 6.13645557229131e+37*cos(theta)**65 + 4.29758504726125e+37*cos(theta)**63 - 2.71010125841176e+37*cos(theta)**61 + 1.54021282698557e+37*cos(theta)**59 - 7.89249519907848e+36*cos(theta)**57 + 3.64690860964946e+36*cos(theta)**55 - 1.51911901411766e+36*cos(theta)**53 + 5.70083333729339e+35*cos(theta)**51 - 1.92544702120505e+35*cos(theta)**49 + 5.84492952229515e+34*cos(theta)**47 - 1.59192965825172e+34*cos(theta)**45 + 3.88179892036749e+33*cos(theta)**43 - 8.45253056448478e+32*cos(theta)**41 + 1.63855202432093e+32*cos(theta)**39 - 2.81774669301881e+31*cos(theta)**37 + 4.28060971156599e+30*cos(theta)**35 - 5.71708816696243e+29*cos(theta)**33 + 6.67541475487874e+28*cos(theta)**31 - 6.77004986045499e+27*cos(theta)**29 + 5.91869130780518e+26*cos(theta)**27 - 4.42106969363613e+25*cos(theta)**25 + 2.79225454334914e+24*cos(theta)**23 - 1.47267125175595e+23*cos(theta)**21 + 6.38968931547005e+21*cos(theta)**19 - 2.23946889310387e+20*cos(theta)**17 + 6.19796030651458e+18*cos(theta)**15 - 1.31604819450765e+17*cos(theta)**13 + 2.06459692621875e+15*cos(theta)**11 - 22733299487894.2*cos(theta)**9 + 163222732661.386*cos(theta)**7 - 681582299.838757*cos(theta)**5 + 1352345.83301341*cos(theta)**3 - 803.851297610506*cos(theta))*cos(phi)

#@torch.jit.script
def Yl100_m2(theta, phi):
    return 0.000560053769265274*(1.0 - cos(theta)**2)*(7.07158814056514e+32*cos(theta)**98 - 1.68900796141237e+34*cos(theta)**96 + 1.95479094011177e+35*cos(theta)**94 - 1.46057969217582e+36*cos(theta)**92 + 7.91967175058031e+36*cos(theta)**90 - 3.32128642524336e+37*cos(theta)**88 + 1.12115383032025e+38*cos(theta)**86 - 3.13049446128381e+38*cos(theta)**84 + 7.37358357569956e+38*cos(theta)**82 - 1.48680455706729e+39*cos(theta)**80 + 2.59574718250422e+39*cos(theta)**78 - 3.95887698784163e+39*cos(theta)**76 + 5.31205245543721e+39*cos(theta)**74 - 6.30674887126853e+39*cos(theta)**72 + 6.65567717380774e+39*cos(theta)**70 - 6.26645628645057e+39*cos(theta)**68 + 5.27921132416213e+39*cos(theta)**66 - 3.98869612198935e+39*cos(theta)**64 + 2.70747857977459e+39*cos(theta)**62 - 1.65316176763117e+39*cos(theta)**60 + 9.08725567921484e+38*cos(theta)**58 - 4.49872226347473e+38*cos(theta)**56 + 2.00579973530721e+38*cos(theta)**54 - 8.05133077482359e+37*cos(theta)**52 + 2.90742500201963e+37*cos(theta)**50 - 9.43469040390476e+36*cos(theta)**48 + 2.74711687547872e+36*cos(theta)**46 - 7.16368346213272e+35*cos(theta)**44 + 1.66917353575802e+35*cos(theta)**42 - 3.46553753143876e+34*cos(theta)**40 + 6.39035289485162e+33*cos(theta)**38 - 1.04256627641696e+33*cos(theta)**36 + 1.4982133990481e+32*cos(theta)**34 - 1.8866390950976e+31*cos(theta)**32 + 2.06937857401241e+30*cos(theta)**30 - 1.96331445953195e+29*cos(theta)**28 + 1.5980466531074e+28*cos(theta)**26 - 1.10526742340903e+27*cos(theta)**24 + 6.42218544970301e+25*cos(theta)**22 - 3.0926096286875e+24*cos(theta)**20 + 1.21404096993931e+23*cos(theta)**18 - 3.80709711827658e+21*cos(theta)**16 + 9.29694045977187e+19*cos(theta)**14 - 1.71086265285994e+18*cos(theta)**12 + 2.27105661884063e+16*cos(theta)**10 - 204599695391048.0*cos(theta)**8 + 1142559128629.7*cos(theta)**6 - 3407911499.19379*cos(theta)**4 + 4057037.49904022*cos(theta)**2 - 803.851297610506)*cos(2*phi)

#@torch.jit.script
def Yl100_m3(theta, phi):
    return 5.57439929750823e-6*(1.0 - cos(theta)**2)**1.5*(6.93015637775383e+34*cos(theta)**97 - 1.62144764295587e+36*cos(theta)**95 + 1.83750348370507e+37*cos(theta)**93 - 1.34373331680176e+38*cos(theta)**91 + 7.12770457552228e+38*cos(theta)**89 - 2.92273205421416e+39*cos(theta)**87 + 9.64192294075412e+39*cos(theta)**85 - 2.6296153474784e+40*cos(theta)**83 + 6.04633853207364e+40*cos(theta)**81 - 1.18944364565383e+41*cos(theta)**79 + 2.02468280235329e+41*cos(theta)**77 - 3.00874651075963e+41*cos(theta)**75 + 3.93091881702353e+41*cos(theta)**73 - 4.54085918731334e+41*cos(theta)**71 + 4.65897402166542e+41*cos(theta)**69 - 4.26119027478639e+41*cos(theta)**67 + 3.484279473947e+41*cos(theta)**65 - 2.55276551807318e+41*cos(theta)**63 + 1.67863671946024e+41*cos(theta)**61 - 9.91897060578705e+40*cos(theta)**59 + 5.27060829394461e+40*cos(theta)**57 - 2.51928446754585e+40*cos(theta)**55 + 1.08313185706589e+40*cos(theta)**53 - 4.18669200290827e+39*cos(theta)**51 + 1.45371250100982e+39*cos(theta)**49 - 4.52865139387429e+38*cos(theta)**47 + 1.26367376272021e+38*cos(theta)**45 - 3.1520207233384e+37*cos(theta)**43 + 7.01052885018368e+36*cos(theta)**41 - 1.3862150125755e+36*cos(theta)**39 + 2.42833410004361e+35*cos(theta)**37 - 3.75323859510106e+34*cos(theta)**35 + 5.09392555676353e+33*cos(theta)**33 - 6.03724510431233e+32*cos(theta)**31 + 6.20813572203723e+31*cos(theta)**29 - 5.49728048668945e+30*cos(theta)**27 + 4.15492129807924e+29*cos(theta)**25 - 2.65264181618168e+28*cos(theta)**23 + 1.41288079893466e+27*cos(theta)**21 - 6.18521925737501e+25*cos(theta)**19 + 2.18527374589076e+24*cos(theta)**17 - 6.09135538924253e+22*cos(theta)**15 + 1.30157166436806e+21*cos(theta)**13 - 2.05303518343193e+19*cos(theta)**11 + 2.27105661884063e+17*cos(theta)**9 - 1.63679756312838e+15*cos(theta)**7 + 6855354771778.22*cos(theta)**5 - 13631645996.7751*cos(theta)**3 + 8114074.99808044*cos(theta))*cos(3*phi)

#@torch.jit.script
def Yl100_m4(theta, phi):
    return 5.55003264309976e-8*(1.0 - cos(theta)**2)**2*(6.72225168642122e+36*cos(theta)**96 - 1.54037526080808e+38*cos(theta)**94 + 1.70887823984571e+39*cos(theta)**92 - 1.2227973182896e+40*cos(theta)**90 + 6.34365707221483e+40*cos(theta)**88 - 2.54277688716632e+41*cos(theta)**86 + 8.195634499641e+41*cos(theta)**84 - 2.18258073840707e+42*cos(theta)**82 + 4.89753421097965e+42*cos(theta)**80 - 9.39660480066526e+42*cos(theta)**78 + 1.55900575781203e+43*cos(theta)**76 - 2.25655988306973e+43*cos(theta)**74 + 2.86957073642718e+43*cos(theta)**72 - 3.22401002299247e+43*cos(theta)**70 + 3.21469207494914e+43*cos(theta)**68 - 2.85499748410688e+43*cos(theta)**66 + 2.26478165806555e+43*cos(theta)**64 - 1.60824227638611e+43*cos(theta)**62 + 1.02396839887075e+43*cos(theta)**60 - 5.85219265741436e+42*cos(theta)**58 + 3.00424672754843e+42*cos(theta)**56 - 1.38560645715022e+42*cos(theta)**54 + 5.74059884244922e+41*cos(theta)**52 - 2.13521292148322e+41*cos(theta)**50 + 7.1231912549481e+40*cos(theta)**48 - 2.12846615512091e+40*cos(theta)**46 + 5.68653193224096e+39*cos(theta)**44 - 1.35536891103551e+39*cos(theta)**42 + 2.87431682857531e+38*cos(theta)**40 - 5.40623854904447e+37*cos(theta)**38 + 8.98483617016137e+36*cos(theta)**36 - 1.31363350828537e+36*cos(theta)**34 + 1.68099543373196e+35*cos(theta)**32 - 1.87154598233682e+34*cos(theta)**30 + 1.8003593593908e+33*cos(theta)**28 - 1.48426573140615e+32*cos(theta)**26 + 1.03873032451981e+31*cos(theta)**24 - 6.10107617721786e+29*cos(theta)**22 + 2.96704967776279e+28*cos(theta)**20 - 1.17519165890125e+27*cos(theta)**18 + 3.71496536801429e+25*cos(theta)**16 - 9.1370330838638e+23*cos(theta)**14 + 1.69204316367848e+22*cos(theta)**12 - 2.25833870177512e+20*cos(theta)**10 + 2.04395095695657e+18*cos(theta)**8 - 1.14575829418987e+16*cos(theta)**6 + 34276773858891.1*cos(theta)**4 - 40894937990.3254*cos(theta)**2 + 8114074.99808044)*cos(4*phi)

#@torch.jit.script
def Yl100_m5(theta, phi):
    return 5.52796483147718e-10*(1.0 - cos(theta)**2)**2.5*(6.45336161896437e+38*cos(theta)**95 - 1.44795274515959e+40*cos(theta)**93 + 1.57216798065806e+41*cos(theta)**91 - 1.10051758646064e+42*cos(theta)**89 + 5.58241822354905e+42*cos(theta)**87 - 2.18678812296303e+43*cos(theta)**85 + 6.88433297969844e+43*cos(theta)**83 - 1.7897162054938e+44*cos(theta)**81 + 3.91802736878372e+44*cos(theta)**79 - 7.3293517445189e+44*cos(theta)**77 + 1.18484437593714e+45*cos(theta)**75 - 1.6698543134716e+45*cos(theta)**73 + 2.06609093022757e+45*cos(theta)**71 - 2.25680701609473e+45*cos(theta)**69 + 2.18599061096542e+45*cos(theta)**67 - 1.88429833951054e+45*cos(theta)**65 + 1.44946026116195e+45*cos(theta)**63 - 9.97110211359385e+44*cos(theta)**61 + 6.1438103932245e+44*cos(theta)**59 - 3.39427174130033e+44*cos(theta)**57 + 1.68237816742712e+44*cos(theta)**55 - 7.48227486861117e+43*cos(theta)**53 + 2.9851113980736e+43*cos(theta)**51 - 1.06760646074161e+43*cos(theta)**49 + 3.41913180237509e+42*cos(theta)**47 - 9.79094431355621e+41*cos(theta)**45 + 2.50207405018602e+41*cos(theta)**43 - 5.69254942634915e+40*cos(theta)**41 + 1.14972673143012e+40*cos(theta)**39 - 2.0543706486369e+39*cos(theta)**37 + 3.23454102125809e+38*cos(theta)**35 - 4.46635392817026e+37*cos(theta)**33 + 5.37918538794229e+36*cos(theta)**31 - 5.61463794701047e+35*cos(theta)**29 + 5.04100620629423e+34*cos(theta)**27 - 3.859090901656e+33*cos(theta)**25 + 2.49295277884754e+32*cos(theta)**23 - 1.34223675898793e+31*cos(theta)**21 + 5.93409935552558e+29*cos(theta)**19 - 2.11534498602225e+28*cos(theta)**17 + 5.94394458882286e+26*cos(theta)**15 - 1.27918463174093e+25*cos(theta)**13 + 2.03045179641418e+23*cos(theta)**11 - 2.25833870177512e+21*cos(theta)**9 + 1.63516076556525e+19*cos(theta)**7 - 6.8745497651392e+16*cos(theta)**5 + 137107095435564.0*cos(theta)**3 - 81789875980.6509*cos(theta))*cos(5*phi)

#@torch.jit.script
def Yl100_m6(theta, phi):
    return 5.50871794199858e-12*(1.0 - cos(theta)**2)**3*(6.13069353801615e+40*cos(theta)**94 - 1.34659605299842e+42*cos(theta)**92 + 1.43067286239883e+43*cos(theta)**90 - 9.79460651949969e+43*cos(theta)**88 + 4.85670385448767e+44*cos(theta)**86 - 1.85876990451858e+45*cos(theta)**84 + 5.71399637314971e+45*cos(theta)**82 - 1.44967012644998e+46*cos(theta)**80 + 3.09524162133914e+46*cos(theta)**78 - 5.64360084327956e+46*cos(theta)**76 + 8.88633281952858e+46*cos(theta)**74 - 1.21899364883427e+47*cos(theta)**72 + 1.46692456046157e+47*cos(theta)**70 - 1.55719684110536e+47*cos(theta)**68 + 1.46461370934683e+47*cos(theta)**66 - 1.22479392068185e+47*cos(theta)**64 + 9.13159964532031e+46*cos(theta)**62 - 6.08237228929225e+46*cos(theta)**60 + 3.62484813200245e+46*cos(theta)**58 - 1.93473489254119e+46*cos(theta)**56 + 9.25307992084915e+45*cos(theta)**54 - 3.96560568036392e+45*cos(theta)**52 + 1.52240681301753e+45*cos(theta)**50 - 5.23127165763388e+44*cos(theta)**48 + 1.60699194711629e+44*cos(theta)**46 - 4.40592494110029e+43*cos(theta)**44 + 1.07589184157999e+43*cos(theta)**42 - 2.33394526480315e+42*cos(theta)**40 + 4.48393425257748e+41*cos(theta)**38 - 7.60117139995652e+40*cos(theta)**36 + 1.13208935744033e+40*cos(theta)**34 - 1.47389679629619e+39*cos(theta)**32 + 1.66754747026211e+38*cos(theta)**30 - 1.62824500463304e+37*cos(theta)**28 + 1.36107167569944e+36*cos(theta)**26 - 9.64772725413999e+34*cos(theta)**24 + 5.73379139134935e+33*cos(theta)**22 - 2.81869719387465e+32*cos(theta)**20 + 1.12747887754986e+31*cos(theta)**18 - 3.59608647623783e+29*cos(theta)**16 + 8.91591688323429e+27*cos(theta)**14 - 1.66294002126321e+26*cos(theta)**12 + 2.23349697605559e+24*cos(theta)**10 - 2.03250483159761e+22*cos(theta)**8 + 1.14461253589568e+20*cos(theta)**6 - 3.4372748825696e+17*cos(theta)**4 + 411321286306693.0*cos(theta)**2 - 81789875980.6509)*cos(6*phi)

#@torch.jit.script
def Yl100_m7(theta, phi):
    return 5.49281181825906e-14*(1.0 - cos(theta)**2)**3.5*(5.76285192573518e+42*cos(theta)**93 - 1.23886836875855e+44*cos(theta)**91 + 1.28760557615895e+45*cos(theta)**89 - 8.61925373715973e+45*cos(theta)**87 + 4.1767653148594e+46*cos(theta)**85 - 1.56136671979561e+47*cos(theta)**83 + 4.68547702598276e+47*cos(theta)**81 - 1.15973610115998e+48*cos(theta)**79 + 2.41428846464453e+48*cos(theta)**77 - 4.28913664089246e+48*cos(theta)**75 + 6.57588628645115e+48*cos(theta)**73 - 8.77675427160672e+48*cos(theta)**71 + 1.0268471923231e+49*cos(theta)**69 - 1.05889385195165e+49*cos(theta)**67 + 9.66645048168907e+48*cos(theta)**65 - 7.83868109236385e+48*cos(theta)**63 + 5.66159178009859e+48*cos(theta)**61 - 3.64942337357535e+48*cos(theta)**59 + 2.10241191656142e+48*cos(theta)**57 - 1.08345153982306e+48*cos(theta)**55 + 4.99666315725854e+47*cos(theta)**53 - 2.06211495378924e+47*cos(theta)**51 + 7.61203406508767e+46*cos(theta)**49 - 2.51101039566426e+46*cos(theta)**47 + 7.39216295673494e+45*cos(theta)**45 - 1.93860697408413e+45*cos(theta)**43 + 4.51874573463595e+44*cos(theta)**41 - 9.3357810592126e+43*cos(theta)**39 + 1.70389501597944e+43*cos(theta)**37 - 2.73642170398435e+42*cos(theta)**35 + 3.84910381529713e+41*cos(theta)**33 - 4.7164697481478e+40*cos(theta)**31 + 5.00264241078633e+39*cos(theta)**29 - 4.5590860129725e+38*cos(theta)**27 + 3.53878635681855e+37*cos(theta)**25 - 2.3154545409936e+36*cos(theta)**23 + 1.26143410609686e+35*cos(theta)**21 - 5.6373943877493e+33*cos(theta)**19 + 2.02946197958975e+32*cos(theta)**17 - 5.75373836198053e+30*cos(theta)**15 + 1.2482283636528e+29*cos(theta)**13 - 1.99552802551585e+27*cos(theta)**11 + 2.23349697605559e+25*cos(theta)**9 - 1.62600386527809e+23*cos(theta)**7 + 6.86767521537406e+20*cos(theta)**5 - 1.37490995302784e+18*cos(theta)**3 + 822642572613386.0*cos(theta))*cos(7*phi)

#@torch.jit.script
def Yl100_m8(theta, phi):
    return 5.48076736441476e-16*(1.0 - cos(theta)**2)**4*(5.35945229093372e+44*cos(theta)**92 - 1.12737021557028e+46*cos(theta)**90 + 1.14596896278146e+47*cos(theta)**88 - 7.49875075132896e+47*cos(theta)**86 + 3.55025051763049e+48*cos(theta)**84 - 1.29593437743035e+49*cos(theta)**82 + 3.79523639104604e+49*cos(theta)**80 - 9.16191519916385e+49*cos(theta)**78 + 1.85900211777629e+50*cos(theta)**76 - 3.21685248066935e+50*cos(theta)**74 + 4.80039698910934e+50*cos(theta)**72 - 6.23149553284077e+50*cos(theta)**70 + 7.08524562702941e+50*cos(theta)**68 - 7.09458880807604e+50*cos(theta)**66 + 6.28319281309789e+50*cos(theta)**64 - 4.93836908818922e+50*cos(theta)**62 + 3.45357098586014e+50*cos(theta)**60 - 2.15315979040946e+50*cos(theta)**58 + 1.19837479244001e+50*cos(theta)**56 - 5.95898346902685e+49*cos(theta)**54 + 2.64823147334703e+49*cos(theta)**52 - 1.05167862643251e+49*cos(theta)**50 + 3.72989669189296e+48*cos(theta)**48 - 1.1801748859622e+48*cos(theta)**46 + 3.32647333053072e+47*cos(theta)**44 - 8.33600998856175e+46*cos(theta)**42 + 1.85268575120074e+46*cos(theta)**40 - 3.64095461309291e+45*cos(theta)**38 + 6.30441155912394e+44*cos(theta)**36 - 9.57747596394522e+43*cos(theta)**34 + 1.27020425904805e+43*cos(theta)**32 - 1.46210562192582e+42*cos(theta)**30 + 1.45076629912803e+41*cos(theta)**28 - 1.23095322350257e+40*cos(theta)**26 + 8.84696589204637e+38*cos(theta)**24 - 5.32554544428527e+37*cos(theta)**22 + 2.6490116228034e+36*cos(theta)**20 - 1.07110493367237e+35*cos(theta)**18 + 3.45008536530257e+33*cos(theta)**16 - 8.63060754297079e+31*cos(theta)**14 + 1.62269687274864e+30*cos(theta)**12 - 2.19508082806744e+28*cos(theta)**10 + 2.01014727845003e+26*cos(theta)**8 - 1.13820270569466e+24*cos(theta)**6 + 3.43383760768703e+21*cos(theta)**4 - 4.12472985908352e+18*cos(theta)**2 + 822642572613386.0)*cos(8*phi)

#@torch.jit.script
def Yl100_m9(theta, phi):
    return 5.47311036605445e-18*(1.0 - cos(theta)**2)**4.5*(4.93069610765902e+46*cos(theta)**91 - 1.01463319401325e+48*cos(theta)**89 + 1.00845268724769e+49*cos(theta)**87 - 6.44892564614291e+49*cos(theta)**85 + 2.98221043480961e+50*cos(theta)**83 - 1.06266618949289e+51*cos(theta)**81 + 3.03618911283683e+51*cos(theta)**79 - 7.1462938553478e+51*cos(theta)**77 + 1.41284160950998e+52*cos(theta)**75 - 2.38047083569532e+52*cos(theta)**73 + 3.45628583215872e+52*cos(theta)**71 - 4.36204687298854e+52*cos(theta)**69 + 4.81796702638e+52*cos(theta)**67 - 4.68242861333018e+52*cos(theta)**65 + 4.02124340038265e+52*cos(theta)**63 - 3.06178883467732e+52*cos(theta)**61 + 2.07214259151608e+52*cos(theta)**59 - 1.24883267843749e+52*cos(theta)**57 + 6.71089883766406e+51*cos(theta)**55 - 3.2178510732745e+51*cos(theta)**53 + 1.37708036614045e+51*cos(theta)**51 - 5.25839313216256e+50*cos(theta)**49 + 1.79035041210862e+50*cos(theta)**47 - 5.42880447542614e+49*cos(theta)**45 + 1.46364826543352e+49*cos(theta)**43 - 3.50112419519594e+48*cos(theta)**41 + 7.41074300480296e+47*cos(theta)**39 - 1.38356275297531e+47*cos(theta)**37 + 2.26958816128462e+46*cos(theta)**35 - 3.25634182774137e+45*cos(theta)**33 + 4.06465362895377e+44*cos(theta)**31 - 4.38631686577745e+43*cos(theta)**29 + 4.0621456375585e+42*cos(theta)**27 - 3.20047838110669e+41*cos(theta)**25 + 2.12327181409113e+40*cos(theta)**23 - 1.17161999774276e+39*cos(theta)**21 + 5.2980232456068e+37*cos(theta)**19 - 1.92798888061026e+36*cos(theta)**17 + 5.52013658448412e+34*cos(theta)**15 - 1.20828505601591e+33*cos(theta)**13 + 1.94723624729837e+31*cos(theta)**11 - 2.19508082806744e+29*cos(theta)**9 + 1.60811782276003e+27*cos(theta)**7 - 6.82921623416796e+24*cos(theta)**5 + 1.37353504307481e+22*cos(theta)**3 - 8.24945971816704e+18*cos(theta))*cos(9*phi)

#@torch.jit.script
def Yl100_m10(theta, phi):
    return 5.47037586157896e-20*(1.0 - cos(theta)**2)**5*(4.48693345796971e+48*cos(theta)**90 - 9.03023542671794e+49*cos(theta)**88 + 8.77353837905489e+50*cos(theta)**86 - 5.48158679922147e+51*cos(theta)**84 + 2.47523466089198e+52*cos(theta)**82 - 8.60759613489241e+52*cos(theta)**80 + 2.39858939914109e+53*cos(theta)**78 - 5.50264626861781e+53*cos(theta)**76 + 1.05963120713248e+54*cos(theta)**74 - 1.73774371005758e+54*cos(theta)**72 + 2.45396294083269e+54*cos(theta)**70 - 3.00981234236209e+54*cos(theta)**68 + 3.2280379076746e+54*cos(theta)**66 - 3.04357859866462e+54*cos(theta)**64 + 2.53338334224107e+54*cos(theta)**62 - 1.86769118915316e+54*cos(theta)**60 + 1.22256412899449e+54*cos(theta)**58 - 7.11834626709366e+53*cos(theta)**56 + 3.69099436071523e+53*cos(theta)**54 - 1.70546106883549e+53*cos(theta)**52 + 7.02310986731632e+52*cos(theta)**50 - 2.57661263475965e+52*cos(theta)**48 + 8.41464693691051e+51*cos(theta)**46 - 2.44296201394176e+51*cos(theta)**44 + 6.29368754136412e+50*cos(theta)**42 - 1.43546092003033e+50*cos(theta)**40 + 2.89018977187316e+49*cos(theta)**38 - 5.11918218600864e+48*cos(theta)**36 + 7.94355856449616e+47*cos(theta)**34 - 1.07459280315465e+47*cos(theta)**32 + 1.26004262497567e+46*cos(theta)**30 - 1.27203189107546e+45*cos(theta)**28 + 1.09677932214079e+44*cos(theta)**26 - 8.00119595276674e+42*cos(theta)**24 + 4.8835251724096e+41*cos(theta)**22 - 2.4604019952598e+40*cos(theta)**20 + 1.00662441666529e+39*cos(theta)**18 - 3.27758109703745e+37*cos(theta)**16 + 8.28020487672618e+35*cos(theta)**14 - 1.57077057282068e+34*cos(theta)**12 + 2.14195987202821e+32*cos(theta)**10 - 1.97557274526069e+30*cos(theta)**8 + 1.12568247593202e+28*cos(theta)**6 - 3.41460811708398e+25*cos(theta)**4 + 4.12060512922444e+22*cos(theta)**2 - 8.24945971816704e+18)*cos(10*phi)

#@torch.jit.script
def Yl100_m11(theta, phi):
    return 5.47311310261169e-22*(1.0 - cos(theta)**2)**5.5*(4.03824011217274e+50*cos(theta)**89 - 7.94660717551178e+51*cos(theta)**87 + 7.5452430059872e+52*cos(theta)**85 - 4.60453291134604e+53*cos(theta)**83 + 2.02969242193142e+54*cos(theta)**81 - 6.88607690791393e+54*cos(theta)**79 + 1.87089973133005e+55*cos(theta)**77 - 4.18201116414953e+55*cos(theta)**75 + 7.84127093278037e+55*cos(theta)**73 - 1.25117547124146e+56*cos(theta)**71 + 1.71777405858289e+56*cos(theta)**69 - 2.04667239280622e+56*cos(theta)**67 + 2.13050501906523e+56*cos(theta)**65 - 1.94789030314536e+56*cos(theta)**63 + 1.57069767218946e+56*cos(theta)**61 - 1.1206147134919e+56*cos(theta)**59 + 7.09087194816804e+55*cos(theta)**57 - 3.98627390957245e+55*cos(theta)**55 + 1.99313695478623e+55*cos(theta)**53 - 8.86839755794453e+54*cos(theta)**51 + 3.51155493365816e+54*cos(theta)**49 - 1.23677406468463e+54*cos(theta)**47 + 3.87073759097884e+53*cos(theta)**45 - 1.07490328613438e+53*cos(theta)**43 + 2.64334876737293e+52*cos(theta)**41 - 5.74184368012134e+51*cos(theta)**39 + 1.0982721133118e+51*cos(theta)**37 - 1.84290558696311e+50*cos(theta)**35 + 2.7008099119287e+49*cos(theta)**33 - 3.43869697009489e+48*cos(theta)**31 + 3.78012787492701e+47*cos(theta)**29 - 3.56168929501129e+46*cos(theta)**27 + 2.85162623756606e+45*cos(theta)**25 - 1.92028702866402e+44*cos(theta)**23 + 1.07437553793011e+43*cos(theta)**21 - 4.92080399051959e+41*cos(theta)**19 + 1.81192394999752e+40*cos(theta)**17 - 5.24412975525991e+38*cos(theta)**15 + 1.15922868274167e+37*cos(theta)**13 - 1.88492468738482e+35*cos(theta)**11 + 2.14195987202821e+33*cos(theta)**9 - 1.58045819620856e+31*cos(theta)**7 + 6.75409485559212e+28*cos(theta)**5 - 1.36584324683359e+26*cos(theta)**3 + 8.24121025844887e+22*cos(theta))*cos(11*phi)

#@torch.jit.script
def Yl100_m12(theta, phi):
    return 5.48189115653224e-24*(1.0 - cos(theta)**2)**6*(3.59403369983374e+52*cos(theta)**88 - 6.91354824269525e+53*cos(theta)**86 + 6.41345655508912e+54*cos(theta)**84 - 3.82176231641721e+55*cos(theta)**82 + 1.64405086176445e+56*cos(theta)**80 - 5.440000757252e+56*cos(theta)**78 + 1.44059279312414e+57*cos(theta)**76 - 3.13650837311215e+57*cos(theta)**74 + 5.72412778092967e+57*cos(theta)**72 - 8.88334584581435e+57*cos(theta)**70 + 1.18526410042219e+58*cos(theta)**68 - 1.37127050318017e+58*cos(theta)**66 + 1.3848282623924e+58*cos(theta)**64 - 1.22717089098157e+58*cos(theta)**62 + 9.58125580035573e+57*cos(theta)**60 - 6.6116268096022e+57*cos(theta)**58 + 4.04179701045578e+57*cos(theta)**56 - 2.19245065026485e+57*cos(theta)**54 + 1.0563625860367e+57*cos(theta)**52 - 4.52288275455171e+56*cos(theta)**50 + 1.7206619174925e+56*cos(theta)**48 - 5.81283810401778e+55*cos(theta)**46 + 1.74183191594048e+55*cos(theta)**44 - 4.62208413037781e+54*cos(theta)**42 + 1.0837729946229e+54*cos(theta)**40 - 2.23931903524732e+53*cos(theta)**38 + 4.06360681925366e+52*cos(theta)**36 - 6.45016955437088e+51*cos(theta)**34 + 8.91267270936469e+50*cos(theta)**32 - 1.06599606072942e+50*cos(theta)**30 + 1.09623708372883e+49*cos(theta)**28 - 9.61656109653048e+47*cos(theta)**26 + 7.12906559391516e+46*cos(theta)**24 - 4.41666016592724e+45*cos(theta)**22 + 2.25618862965323e+44*cos(theta)**20 - 9.34952758198723e+42*cos(theta)**18 + 3.08027071499579e+41*cos(theta)**16 - 7.86619463288987e+39*cos(theta)**14 + 1.50699728756416e+38*cos(theta)**12 - 2.0734171561233e+36*cos(theta)**10 + 1.92776388482539e+34*cos(theta)**8 - 1.10632073734599e+32*cos(theta)**6 + 3.37704742779606e+29*cos(theta)**4 - 4.09752974050078e+26*cos(theta)**2 + 8.24121025844887e+22)*cos(12*phi)

#@torch.jit.script
def Yl100_m13(theta, phi):
    return 5.49730522113833e-26*(1.0 - cos(theta)**2)**6.5*(3.16274965585369e+54*cos(theta)**87 - 5.94565148871792e+55*cos(theta)**85 + 5.38730350627486e+56*cos(theta)**83 - 3.13384509946211e+57*cos(theta)**81 + 1.31524068941156e+58*cos(theta)**79 - 4.24320059065656e+58*cos(theta)**77 + 1.09485052277435e+59*cos(theta)**75 - 2.32101619610299e+59*cos(theta)**73 + 4.12137200226936e+59*cos(theta)**71 - 6.21834209207005e+59*cos(theta)**69 + 8.0597958828709e+59*cos(theta)**67 - 9.05038532098911e+59*cos(theta)**65 + 8.86290087931137e+59*cos(theta)**63 - 7.60845952408576e+59*cos(theta)**61 + 5.74875348021344e+59*cos(theta)**59 - 3.83474354956928e+59*cos(theta)**57 + 2.26340632585524e+59*cos(theta)**55 - 1.18392335114302e+59*cos(theta)**53 + 5.49308544739084e+58*cos(theta)**51 - 2.26144137727585e+58*cos(theta)**49 + 8.25917720396399e+57*cos(theta)**47 - 2.67390552784818e+57*cos(theta)**45 + 7.66406043013809e+56*cos(theta)**43 - 1.94127533475868e+56*cos(theta)**41 + 4.33509197849161e+55*cos(theta)**39 - 8.50941233393982e+54*cos(theta)**37 + 1.46289845493132e+54*cos(theta)**35 - 2.1930576484861e+53*cos(theta)**33 + 2.8520552669967e+52*cos(theta)**31 - 3.19798818218825e+51*cos(theta)**29 + 3.06946383444073e+50*cos(theta)**27 - 2.50030588509793e+49*cos(theta)**25 + 1.71097574253964e+48*cos(theta)**23 - 9.71665236503992e+46*cos(theta)**21 + 4.51237725930647e+45*cos(theta)**19 - 1.6829149647577e+44*cos(theta)**17 + 4.92843314399327e+42*cos(theta)**15 - 1.10126724860458e+41*cos(theta)**13 + 1.808396745077e+39*cos(theta)**11 - 2.0734171561233e+37*cos(theta)**9 + 1.54221110786031e+35*cos(theta)**7 - 6.63792442407593e+32*cos(theta)**5 + 1.35081897111842e+30*cos(theta)**3 - 8.19505948100156e+26*cos(theta))*cos(13*phi)

#@torch.jit.script
def Yl100_m14(theta, phi):
    return 5.51998374114227e-28*(1.0 - cos(theta)**2)**7*(2.75159220059271e+56*cos(theta)**86 - 5.05380376541023e+57*cos(theta)**84 + 4.47146191020814e+58*cos(theta)**82 - 2.53841453056431e+59*cos(theta)**80 + 1.03904014463513e+60*cos(theta)**78 - 3.26726445480555e+60*cos(theta)**76 + 8.21137892080761e+60*cos(theta)**74 - 1.69434182315518e+61*cos(theta)**72 + 2.92617412161125e+61*cos(theta)**70 - 4.29065604352833e+61*cos(theta)**68 + 5.4000632415235e+61*cos(theta)**66 - 5.88275045864292e+61*cos(theta)**64 + 5.58362755396616e+61*cos(theta)**62 - 4.64116030969232e+61*cos(theta)**60 + 3.39176455332593e+61*cos(theta)**58 - 2.18580382325449e+61*cos(theta)**56 + 1.24487347922038e+61*cos(theta)**54 - 6.274793761058e+60*cos(theta)**52 + 2.80147357816933e+60*cos(theta)**50 - 1.10810627486517e+60*cos(theta)**48 + 3.88181328586307e+59*cos(theta)**46 - 1.20325748753168e+59*cos(theta)**44 + 3.29554598495938e+58*cos(theta)**42 - 7.95922887251059e+57*cos(theta)**40 + 1.69068587161173e+57*cos(theta)**38 - 3.14848256355773e+56*cos(theta)**36 + 5.12014459225961e+55*cos(theta)**34 - 7.23709024000413e+54*cos(theta)**32 + 8.84137132768978e+53*cos(theta)**30 - 9.27416572834592e+52*cos(theta)**28 + 8.28755235298997e+51*cos(theta)**26 - 6.25076471274481e+50*cos(theta)**24 + 3.93524420784117e+49*cos(theta)**22 - 2.04049699665838e+48*cos(theta)**20 + 8.57351679268229e+46*cos(theta)**18 - 2.86095544008809e+45*cos(theta)**16 + 7.3926497159899e+43*cos(theta)**14 - 1.43164742318596e+42*cos(theta)**12 + 1.9892364195847e+40*cos(theta)**10 - 1.86607544051097e+38*cos(theta)**8 + 1.07954777550222e+36*cos(theta)**6 - 3.31896221203797e+33*cos(theta)**4 + 4.05245691335527e+30*cos(theta)**2 - 8.19505948100156e+26)*cos(14*phi)

#@torch.jit.script
def Yl100_m15(theta, phi):
    return 5.55059643926874e-30*(1.0 - cos(theta)**2)**7.5*(2.36636929250973e+58*cos(theta)**85 - 4.24519516294459e+59*cos(theta)**83 + 3.66659876637067e+60*cos(theta)**81 - 2.03073162445145e+61*cos(theta)**79 + 8.10451312815403e+61*cos(theta)**77 - 2.48312098565222e+62*cos(theta)**75 + 6.07642040139763e+62*cos(theta)**73 - 1.21992611267173e+63*cos(theta)**71 + 2.04832188512787e+63*cos(theta)**69 - 2.91764610959927e+63*cos(theta)**67 + 3.56404173940551e+63*cos(theta)**65 - 3.76496029353147e+63*cos(theta)**63 + 3.46184908345902e+63*cos(theta)**61 - 2.78469618581539e+63*cos(theta)**59 + 1.96722344092904e+63*cos(theta)**57 - 1.22405014102251e+63*cos(theta)**55 + 6.72231678779006e+62*cos(theta)**53 - 3.26289275575016e+62*cos(theta)**51 + 1.40073678908466e+62*cos(theta)**49 - 5.31891011935281e+61*cos(theta)**47 + 1.78563411149701e+61*cos(theta)**45 - 5.2943329451394e+60*cos(theta)**43 + 1.38412931368294e+60*cos(theta)**41 - 3.18369154900424e+59*cos(theta)**39 + 6.42460631212456e+58*cos(theta)**37 - 1.13345372288078e+58*cos(theta)**35 + 1.74084916136827e+57*cos(theta)**33 - 2.31586887680132e+56*cos(theta)**31 + 2.65241139830693e+55*cos(theta)**29 - 2.59676640393686e+54*cos(theta)**27 + 2.15476361177739e+53*cos(theta)**25 - 1.50018353105876e+52*cos(theta)**23 + 8.65753725725057e+50*cos(theta)**21 - 4.08099399331677e+49*cos(theta)**19 + 1.54323302268281e+48*cos(theta)**17 - 4.57752870414095e+46*cos(theta)**15 + 1.03497096023859e+45*cos(theta)**13 - 1.71797690782315e+43*cos(theta)**11 + 1.9892364195847e+41*cos(theta)**9 - 1.49286035240878e+39*cos(theta)**7 + 6.4772866530133e+36*cos(theta)**5 - 1.32758488481519e+34*cos(theta)**3 + 8.10491382671054e+30*cos(theta))*cos(15*phi)

#@torch.jit.script
def Yl100_m16(theta, phi):
    return 5.58986340186811e-32*(1.0 - cos(theta)**2)**8*(2.01141389863327e+60*cos(theta)**84 - 3.52351198524401e+61*cos(theta)**82 + 2.96994500076024e+62*cos(theta)**80 - 1.60427798331664e+63*cos(theta)**78 + 6.24047510867861e+63*cos(theta)**76 - 1.86234073923917e+64*cos(theta)**74 + 4.43578689302027e+64*cos(theta)**72 - 8.6614753999693e+64*cos(theta)**70 + 1.41334210073823e+65*cos(theta)**68 - 1.95482289343151e+65*cos(theta)**66 + 2.31662713061358e+65*cos(theta)**64 - 2.37192498492483e+65*cos(theta)**62 + 2.11172794091e+65*cos(theta)**60 - 1.64297074963108e+65*cos(theta)**58 + 1.12131736132955e+65*cos(theta)**56 - 6.73227577562382e+64*cos(theta)**54 + 3.56282789752873e+64*cos(theta)**52 - 1.66407530543258e+64*cos(theta)**50 + 6.86361026651485e+63*cos(theta)**48 - 2.49988775609582e+63*cos(theta)**46 + 8.03535350173656e+62*cos(theta)**44 - 2.27656316640994e+62*cos(theta)**42 + 5.67493018610005e+61*cos(theta)**40 - 1.24163970411165e+61*cos(theta)**38 + 2.37710433548609e+60*cos(theta)**36 - 3.96708803008274e+59*cos(theta)**34 + 5.74480223251528e+58*cos(theta)**32 - 7.1791935180841e+57*cos(theta)**30 + 7.69199305509011e+56*cos(theta)**28 - 7.01126929062952e+55*cos(theta)**26 + 5.38690902944348e+54*cos(theta)**24 - 3.45042212143514e+53*cos(theta)**22 + 1.81808282402262e+52*cos(theta)**20 - 7.75388858730186e+50*cos(theta)**18 + 2.62349613856078e+49*cos(theta)**16 - 6.86629305621142e+47*cos(theta)**14 + 1.34546224831016e+46*cos(theta)**12 - 1.88977459860546e+44*cos(theta)**10 + 1.79031277762623e+42*cos(theta)**8 - 1.04500224668614e+40*cos(theta)**6 + 3.23864332650665e+37*cos(theta)**4 - 3.98275465444556e+34*cos(theta)**2 + 8.10491382671054e+30)*cos(16*phi)

#@torch.jit.script
def Yl100_m17(theta, phi):
    return 5.63856539111379e-34*(1.0 - cos(theta)**2)**8.5*(1.68958767485195e+62*cos(theta)**83 - 2.88927982790009e+63*cos(theta)**81 + 2.3759560006082e+64*cos(theta)**79 - 1.25133682698698e+65*cos(theta)**77 + 4.74276108259574e+65*cos(theta)**75 - 1.37813214703698e+66*cos(theta)**73 + 3.19376656297459e+66*cos(theta)**71 - 6.06303277997851e+66*cos(theta)**69 + 9.61072628501998e+66*cos(theta)**67 - 1.2901831096648e+67*cos(theta)**65 + 1.48264136359269e+67*cos(theta)**63 - 1.47059349065339e+67*cos(theta)**61 + 1.267036764546e+67*cos(theta)**59 - 9.52923034786026e+66*cos(theta)**57 + 6.27937722344549e+66*cos(theta)**55 - 3.63542891883686e+66*cos(theta)**53 + 1.85267050671494e+66*cos(theta)**51 - 8.3203765271629e+65*cos(theta)**49 + 3.29453292792713e+65*cos(theta)**47 - 1.14994836780408e+65*cos(theta)**45 + 3.53555554076409e+64*cos(theta)**43 - 9.56156529892175e+63*cos(theta)**41 + 2.26997207444002e+63*cos(theta)**39 - 4.71823087562428e+62*cos(theta)**37 + 8.55757560774992e+61*cos(theta)**35 - 1.34880993022813e+61*cos(theta)**33 + 1.83833671440489e+60*cos(theta)**31 - 2.15375805542523e+59*cos(theta)**29 + 2.15375805542523e+58*cos(theta)**27 - 1.82293001556367e+57*cos(theta)**25 + 1.29285816706644e+56*cos(theta)**23 - 7.5909286671573e+54*cos(theta)**21 + 3.63616564804524e+53*cos(theta)**19 - 1.39569994571433e+52*cos(theta)**17 + 4.19759382169725e+50*cos(theta)**15 - 9.61281027869599e+48*cos(theta)**13 + 1.61455469797219e+47*cos(theta)**11 - 1.88977459860546e+45*cos(theta)**9 + 1.43225022210098e+43*cos(theta)**7 - 6.27001348011687e+40*cos(theta)**5 + 1.29545733060266e+38*cos(theta)**3 - 7.96550930889112e+34*cos(theta))*cos(17*phi)

#@torch.jit.script
def Yl100_m18(theta, phi):
    return 5.69755559417275e-36*(1.0 - cos(theta)**2)**9*(1.40235777012712e+64*cos(theta)**82 - 2.34031666059907e+65*cos(theta)**80 + 1.87700524048047e+66*cos(theta)**78 - 9.63529356779977e+66*cos(theta)**76 + 3.55707081194681e+67*cos(theta)**74 - 1.006036467337e+68*cos(theta)**72 + 2.26757425971196e+68*cos(theta)**70 - 4.18349261818517e+68*cos(theta)**68 + 6.43918661096339e+68*cos(theta)**66 - 8.38619021282117e+68*cos(theta)**64 + 9.34064059063397e+68*cos(theta)**62 - 8.97062029298569e+68*cos(theta)**60 + 7.47551691082141e+68*cos(theta)**58 - 5.43166129828035e+68*cos(theta)**56 + 3.45365747289502e+68*cos(theta)**54 - 1.92677732698354e+68*cos(theta)**52 + 9.44861958424619e+67*cos(theta)**50 - 4.07698449830982e+67*cos(theta)**48 + 1.54843047612575e+67*cos(theta)**46 - 5.17476765511835e+66*cos(theta)**44 + 1.52028888252856e+66*cos(theta)**42 - 3.92024177255792e+65*cos(theta)**40 + 8.85289109031608e+64*cos(theta)**38 - 1.74574542398098e+64*cos(theta)**36 + 2.99515146271247e+63*cos(theta)**34 - 4.45107276975284e+62*cos(theta)**32 + 5.69884381465516e+61*cos(theta)**30 - 6.24589836073317e+60*cos(theta)**28 + 5.81514674964812e+59*cos(theta)**26 - 4.55732503890918e+58*cos(theta)**24 + 2.9735737842528e+57*cos(theta)**22 - 1.59409502010303e+56*cos(theta)**20 + 6.90871473128596e+54*cos(theta)**18 - 2.37268990771437e+53*cos(theta)**16 + 6.29639073254587e+51*cos(theta)**14 - 1.24966533623048e+50*cos(theta)**12 + 1.77601016776941e+48*cos(theta)**10 - 1.70079713874492e+46*cos(theta)**8 + 1.00257515547069e+44*cos(theta)**6 - 3.13500674005843e+41*cos(theta)**4 + 3.88637199180798e+38*cos(theta)**2 - 7.96550930889112e+34)*cos(18*phi)

#@torch.jit.script
def Yl100_m19(theta, phi):
    return 5.76777306568225e-38*(1.0 - cos(theta)**2)**9.5*(1.14993337150424e+66*cos(theta)**81 - 1.87225332847926e+67*cos(theta)**79 + 1.46406408757477e+68*cos(theta)**77 - 7.32282311152782e+68*cos(theta)**75 + 2.63223240084064e+69*cos(theta)**73 - 7.24346256482638e+69*cos(theta)**71 + 1.58730198179837e+70*cos(theta)**69 - 2.84477498036592e+70*cos(theta)**67 + 4.24986316323584e+70*cos(theta)**65 - 5.36716173620555e+70*cos(theta)**63 + 5.79119716619306e+70*cos(theta)**61 - 5.38237217579142e+70*cos(theta)**59 + 4.33579980827642e+70*cos(theta)**57 - 3.041730327037e+70*cos(theta)**55 + 1.86497503536331e+70*cos(theta)**53 - 1.00192421003144e+70*cos(theta)**51 + 4.7243097921231e+69*cos(theta)**49 - 1.95695255918872e+69*cos(theta)**47 + 7.12278019017845e+68*cos(theta)**45 - 2.27689776825207e+68*cos(theta)**43 + 6.38521330661994e+67*cos(theta)**41 - 1.56809670902317e+67*cos(theta)**39 + 3.36409861432011e+66*cos(theta)**37 - 6.28468352633154e+65*cos(theta)**35 + 1.01835149732224e+65*cos(theta)**33 - 1.42434328632091e+64*cos(theta)**31 + 1.70965314439655e+63*cos(theta)**29 - 1.74885154100529e+62*cos(theta)**27 + 1.51193815490851e+61*cos(theta)**25 - 1.0937580093382e+60*cos(theta)**23 + 6.54186232535616e+58*cos(theta)**21 - 3.18819004020607e+57*cos(theta)**19 + 1.24356865163147e+56*cos(theta)**17 - 3.79630385234299e+54*cos(theta)**15 + 8.81494702556422e+52*cos(theta)**13 - 1.49959840347657e+51*cos(theta)**11 + 1.77601016776941e+49*cos(theta)**9 - 1.36063771099593e+47*cos(theta)**7 + 6.01545093282412e+44*cos(theta)**5 - 1.25400269602337e+42*cos(theta)**3 + 7.77274398361595e+38*cos(theta))*cos(19*phi)

#@torch.jit.script
def Yl100_m20(theta, phi):
    return 5.85025817526833e-40*(1.0 - cos(theta)**2)**10*(9.31446030918431e+67*cos(theta)**80 - 1.47908012949861e+69*cos(theta)**78 + 1.12732934743257e+70*cos(theta)**76 - 5.49211733364587e+70*cos(theta)**74 + 1.92152965261366e+71*cos(theta)**72 - 5.14285842102673e+71*cos(theta)**70 + 1.09523836744088e+72*cos(theta)**68 - 1.90599923684516e+72*cos(theta)**66 + 2.76241105610329e+72*cos(theta)**64 - 3.3813118938095e+72*cos(theta)**62 + 3.53263027137777e+72*cos(theta)**60 - 3.17559958371694e+72*cos(theta)**58 + 2.47140589071756e+72*cos(theta)**56 - 1.67295167987035e+72*cos(theta)**54 + 9.88436768742555e+71*cos(theta)**52 - 5.10981347116034e+71*cos(theta)**50 + 2.31491179814032e+71*cos(theta)**48 - 9.19767702818696e+70*cos(theta)**46 + 3.2052510855803e+70*cos(theta)**44 - 9.79066040348391e+69*cos(theta)**42 + 2.61793745571418e+69*cos(theta)**40 - 6.11557716519035e+68*cos(theta)**38 + 1.24471648729844e+68*cos(theta)**36 - 2.19963923421604e+67*cos(theta)**34 + 3.36055994116339e+66*cos(theta)**32 - 4.41546418759482e+65*cos(theta)**30 + 4.95799411874999e+64*cos(theta)**28 - 4.72189916071427e+63*cos(theta)**26 + 3.77984538727128e+62*cos(theta)**24 - 2.51564342147787e+61*cos(theta)**22 + 1.37379108832479e+60*cos(theta)**20 - 6.05756107639153e+58*cos(theta)**18 + 2.1140667077735e+57*cos(theta)**16 - 5.69445577851449e+55*cos(theta)**14 + 1.14594311332335e+54*cos(theta)**12 - 1.64955824382423e+52*cos(theta)**10 + 1.59840915099247e+50*cos(theta)**8 - 9.52446397697153e+47*cos(theta)**6 + 3.00772546641206e+45*cos(theta)**4 - 3.76200808807012e+42*cos(theta)**2 + 7.77274398361595e+38)*cos(20*phi)

#@torch.jit.script
def Yl100_m21(theta, phi):
    return 5.94617043901084e-42*(1.0 - cos(theta)**2)**10.5*(7.45156824734745e+69*cos(theta)**79 - 1.15368250100892e+71*cos(theta)**77 + 8.56770304048755e+71*cos(theta)**75 - 4.06416682689794e+72*cos(theta)**73 + 1.38350134988184e+73*cos(theta)**71 - 3.60000089471871e+73*cos(theta)**69 + 7.44762089859797e+73*cos(theta)**67 - 1.25795949631781e+74*cos(theta)**65 + 1.76794307590611e+74*cos(theta)**63 - 2.09641337416189e+74*cos(theta)**61 + 2.11957816282666e+74*cos(theta)**59 - 1.84184775855582e+74*cos(theta)**57 + 1.38398729880183e+74*cos(theta)**55 - 9.03393907129988e+73*cos(theta)**53 + 5.13987119746128e+73*cos(theta)**51 - 2.55490673558017e+73*cos(theta)**49 + 1.11115766310735e+73*cos(theta)**47 - 4.230931432966e+72*cos(theta)**45 + 1.41031047765533e+72*cos(theta)**43 - 4.11207736946324e+71*cos(theta)**41 + 1.04717498228567e+71*cos(theta)**39 - 2.32391932277233e+70*cos(theta)**37 + 4.48097935427439e+69*cos(theta)**35 - 7.47877339633453e+68*cos(theta)**33 + 1.07537918117229e+68*cos(theta)**31 - 1.32463925627844e+67*cos(theta)**29 + 1.38823835325e+66*cos(theta)**27 - 1.22769378178571e+65*cos(theta)**25 + 9.07162892945107e+63*cos(theta)**23 - 5.53441552725131e+62*cos(theta)**21 + 2.74758217664959e+61*cos(theta)**19 - 1.09036099375047e+60*cos(theta)**17 + 3.3825067324376e+58*cos(theta)**15 - 7.97223808992028e+56*cos(theta)**13 + 1.37513173598802e+55*cos(theta)**11 - 1.64955824382423e+53*cos(theta)**9 + 1.27872732079398e+51*cos(theta)**7 - 5.71467838618292e+48*cos(theta)**5 + 1.20309018656482e+46*cos(theta)**3 - 7.52401617614024e+42*cos(theta))*cos(21*phi)

#@torch.jit.script
def Yl100_m22(theta, phi):
    return 6.0568091956117e-44*(1.0 - cos(theta)**2)**11*(5.88673891540448e+71*cos(theta)**78 - 8.88335525776867e+72*cos(theta)**76 + 6.42577728036567e+73*cos(theta)**74 - 2.9668417836355e+74*cos(theta)**72 + 9.82285958416105e+74*cos(theta)**70 - 2.48400061735591e+75*cos(theta)**68 + 4.98990600206064e+75*cos(theta)**66 - 8.17673672606575e+75*cos(theta)**64 + 1.11380413782085e+76*cos(theta)**62 - 1.27881215823875e+76*cos(theta)**60 + 1.25055111606773e+76*cos(theta)**58 - 1.04985322237682e+76*cos(theta)**56 + 7.61193014341008e+75*cos(theta)**54 - 4.78798770778893e+75*cos(theta)**52 + 2.62133431070526e+75*cos(theta)**50 - 1.25190430043428e+75*cos(theta)**48 + 5.22244101660456e+74*cos(theta)**46 - 1.9039191448347e+74*cos(theta)**44 + 6.06433505391794e+73*cos(theta)**42 - 1.68595172147993e+73*cos(theta)**40 + 4.08398243091412e+72*cos(theta)**38 - 8.59850149425763e+71*cos(theta)**36 + 1.56834277399604e+71*cos(theta)**34 - 2.4679952207904e+70*cos(theta)**32 + 3.33367546163409e+69*cos(theta)**30 - 3.84145384320749e+68*cos(theta)**28 + 3.74824355377499e+67*cos(theta)**26 - 3.06923445446428e+66*cos(theta)**24 + 2.08647465377375e+65*cos(theta)**22 - 1.16222726072278e+64*cos(theta)**20 + 5.22040613563422e+62*cos(theta)**18 - 1.85361368937581e+61*cos(theta)**16 + 5.07376009865641e+59*cos(theta)**14 - 1.03639095168964e+58*cos(theta)**12 + 1.51264490958682e+56*cos(theta)**10 - 1.48460241944181e+54*cos(theta)**8 + 8.95109124555784e+51*cos(theta)**6 - 2.85733919309146e+49*cos(theta)**4 + 3.60927055969447e+46*cos(theta)**2 - 7.52401617614024e+42)*cos(22*phi)

#@torch.jit.script
def Yl100_m23(theta, phi):
    return 6.18363768824311e-46*(1.0 - cos(theta)**2)**11.5*(4.5916563540155e+73*cos(theta)**77 - 6.75134999590419e+74*cos(theta)**75 + 4.75507518747059e+75*cos(theta)**73 - 2.13612608421756e+76*cos(theta)**71 + 6.87600170891274e+76*cos(theta)**69 - 1.68912041980202e+77*cos(theta)**67 + 3.29333796136002e+77*cos(theta)**65 - 5.23311150468208e+77*cos(theta)**63 + 6.90558565448926e+77*cos(theta)**61 - 7.67287294943251e+77*cos(theta)**59 + 7.25319647319283e+77*cos(theta)**57 - 5.87917804531019e+77*cos(theta)**55 + 4.11044227744144e+77*cos(theta)**53 - 2.48975360805025e+77*cos(theta)**51 + 1.31066715535263e+77*cos(theta)**49 - 6.00914064208456e+76*cos(theta)**47 + 2.4023228676381e+76*cos(theta)**45 - 8.37724423727268e+75*cos(theta)**43 + 2.54702072264553e+75*cos(theta)**41 - 6.74380688591972e+74*cos(theta)**39 + 1.55191332374736e+74*cos(theta)**37 - 3.09546053793275e+73*cos(theta)**35 + 5.33236543158652e+72*cos(theta)**33 - 7.89758470652927e+71*cos(theta)**31 + 1.00010263849023e+71*cos(theta)**29 - 1.0756070760981e+70*cos(theta)**27 + 9.74543323981497e+68*cos(theta)**25 - 7.36616269071427e+67*cos(theta)**23 + 4.59024423830224e+66*cos(theta)**21 - 2.32445452144555e+65*cos(theta)**19 + 9.39673104414159e+63*cos(theta)**17 - 2.96578190300129e+62*cos(theta)**15 + 7.10326413811897e+60*cos(theta)**13 - 1.24366914202756e+59*cos(theta)**11 + 1.51264490958682e+57*cos(theta)**9 - 1.18768193555345e+55*cos(theta)**7 + 5.37065474733471e+52*cos(theta)**5 - 1.14293567723658e+50*cos(theta)**3 + 7.21854111938895e+46*cos(theta))*cos(23*phi)

#@torch.jit.script
def Yl100_m24(theta, phi):
    return 6.32831123632127e-48*(1.0 - cos(theta)**2)**12*(3.53557539259193e+75*cos(theta)**76 - 5.06351249692814e+76*cos(theta)**74 + 3.47120488685353e+77*cos(theta)**72 - 1.51664951979447e+78*cos(theta)**70 + 4.74444117914979e+78*cos(theta)**68 - 1.13171068126735e+79*cos(theta)**66 + 2.14066967488401e+79*cos(theta)**64 - 3.29686024794971e+79*cos(theta)**62 + 4.21240724923845e+79*cos(theta)**60 - 4.52699504016518e+79*cos(theta)**58 + 4.13432198971991e+79*cos(theta)**56 - 3.2335479249206e+79*cos(theta)**54 + 2.17853440704397e+79*cos(theta)**52 - 1.26977434010563e+79*cos(theta)**50 + 6.42226906122788e+78*cos(theta)**48 - 2.82429610177974e+78*cos(theta)**46 + 1.08104529043714e+78*cos(theta)**44 - 3.60221502202725e+77*cos(theta)**42 + 1.04427849628467e+77*cos(theta)**40 - 2.63008468550869e+76*cos(theta)**38 + 5.74207929786525e+75*cos(theta)**36 - 1.08341118827646e+75*cos(theta)**34 + 1.75968059242355e+74*cos(theta)**32 - 2.44825125902407e+73*cos(theta)**30 + 2.90029765162165e+72*cos(theta)**28 - 2.90413910546486e+71*cos(theta)**26 + 2.43635830995374e+70*cos(theta)**24 - 1.69421741886428e+69*cos(theta)**22 + 9.6395129004347e+67*cos(theta)**20 - 4.41646359074655e+66*cos(theta)**18 + 1.59744427750407e+65*cos(theta)**16 - 4.44867285450194e+63*cos(theta)**14 + 9.23424337955466e+61*cos(theta)**12 - 1.36803605623032e+60*cos(theta)**10 + 1.36138041862814e+58*cos(theta)**8 - 8.31377354887413e+55*cos(theta)**6 + 2.68532737366735e+53*cos(theta)**4 - 3.42880703170975e+50*cos(theta)**2 + 7.21854111938895e+46)*cos(24*phi)

#@torch.jit.script
def Yl100_m25(theta, phi):
    return 6.49271033372286e-50*(1.0 - cos(theta)**2)**12.5*(2.68703729836987e+77*cos(theta)**75 - 3.74699924772683e+78*cos(theta)**73 + 2.49926751853454e+79*cos(theta)**71 - 1.06165466385613e+80*cos(theta)**69 + 3.22622000182186e+80*cos(theta)**67 - 7.46929049636453e+80*cos(theta)**65 + 1.37002859192577e+81*cos(theta)**63 - 2.04405335372882e+81*cos(theta)**61 + 2.52744434954307e+81*cos(theta)**59 - 2.6256571232958e+81*cos(theta)**57 + 2.31522031424315e+81*cos(theta)**55 - 1.74611587945713e+81*cos(theta)**53 + 1.13283789166286e+81*cos(theta)**51 - 6.34887170052813e+80*cos(theta)**49 + 3.08268914938938e+80*cos(theta)**47 - 1.29917620681868e+80*cos(theta)**45 + 4.75659927792343e+79*cos(theta)**43 - 1.51293030925145e+79*cos(theta)**41 + 4.17711398513867e+78*cos(theta)**39 - 9.99432180493302e+77*cos(theta)**37 + 2.06714854723149e+77*cos(theta)**35 - 3.68359804013997e+76*cos(theta)**33 + 5.63097789575537e+75*cos(theta)**31 - 7.34475377707222e+74*cos(theta)**29 + 8.12083342454063e+73*cos(theta)**27 - 7.55076167420864e+72*cos(theta)**25 + 5.84725994388899e+71*cos(theta)**23 - 3.72727832150142e+70*cos(theta)**21 + 1.92790258008694e+69*cos(theta)**19 - 7.94963446334379e+67*cos(theta)**17 + 2.55591084400651e+66*cos(theta)**15 - 6.22814199630271e+64*cos(theta)**13 + 1.10810920554656e+63*cos(theta)**11 - 1.36803605623032e+61*cos(theta)**9 + 1.08910433490251e+59*cos(theta)**7 - 4.98826412932448e+56*cos(theta)**5 + 1.07413094946694e+54*cos(theta)**3 - 6.8576140634195e+50*cos(theta))*cos(25*phi)

#@torch.jit.script
def Yl100_m26(theta, phi):
    return 6.6789796988462e-52*(1.0 - cos(theta)**2)**13*(2.0152779737774e+79*cos(theta)**74 - 2.73530945084058e+80*cos(theta)**72 + 1.77447993815953e+81*cos(theta)**70 - 7.32541718060727e+81*cos(theta)**68 + 2.16156740122064e+82*cos(theta)**66 - 4.85503882263694e+82*cos(theta)**64 + 8.63118012913234e+82*cos(theta)**62 - 1.24687254577458e+83*cos(theta)**60 + 1.49119216623041e+83*cos(theta)**58 - 1.49662456027861e+83*cos(theta)**56 + 1.27337117283373e+83*cos(theta)**54 - 9.25441416112277e+82*cos(theta)**52 + 5.7774732474806e+82*cos(theta)**50 - 3.11094713325878e+82*cos(theta)**48 + 1.44886390021301e+82*cos(theta)**46 - 5.84629293068407e+81*cos(theta)**44 + 2.04533768950707e+81*cos(theta)**42 - 6.20301426793093e+80*cos(theta)**40 + 1.62907445420408e+80*cos(theta)**38 - 3.69789906782522e+79*cos(theta)**36 + 7.23501991531021e+78*cos(theta)**34 - 1.21558735324619e+78*cos(theta)**32 + 1.74560314768416e+77*cos(theta)**30 - 2.12997859535094e+76*cos(theta)**28 + 2.19262502462597e+75*cos(theta)**26 - 1.88769041855216e+74*cos(theta)**24 + 1.34486978709447e+73*cos(theta)**22 - 7.82728447515298e+71*cos(theta)**20 + 3.66301490216519e+70*cos(theta)**18 - 1.35143785876844e+69*cos(theta)**16 + 3.83386626600977e+67*cos(theta)**14 - 8.09658459519353e+65*cos(theta)**12 + 1.21892012610122e+64*cos(theta)**10 - 1.23123245060729e+62*cos(theta)**8 + 7.62373034431757e+59*cos(theta)**6 - 2.49413206466224e+57*cos(theta)**4 + 3.22239284840082e+54*cos(theta)**2 - 6.8576140634195e+50)*cos(26*phi)

#@torch.jit.script
def Yl100_m27(theta, phi):
    return 6.8895745371725e-54*(1.0 - cos(theta)**2)**13.5*(1.49130570059528e+81*cos(theta)**73 - 1.96942280460522e+82*cos(theta)**71 + 1.24213595671167e+83*cos(theta)**69 - 4.98128368281295e+83*cos(theta)**67 + 1.42663448480562e+84*cos(theta)**65 - 3.10722484648764e+84*cos(theta)**63 + 5.35133168006205e+84*cos(theta)**61 - 7.48123527464748e+84*cos(theta)**59 + 8.64891456413638e+84*cos(theta)**57 - 8.38109753756021e+84*cos(theta)**55 + 6.87620433330216e+84*cos(theta)**53 - 4.81229536378384e+84*cos(theta)**51 + 2.8887366237403e+84*cos(theta)**49 - 1.49325462396422e+84*cos(theta)**47 + 6.66477394097984e+83*cos(theta)**45 - 2.57236888950099e+83*cos(theta)**43 + 8.59041829592971e+82*cos(theta)**41 - 2.48120570717237e+82*cos(theta)**39 + 6.19048292597552e+81*cos(theta)**37 - 1.33124366441708e+81*cos(theta)**35 + 2.45990677120547e+80*cos(theta)**33 - 3.88987953038781e+79*cos(theta)**31 + 5.23680944305249e+78*cos(theta)**29 - 5.96394006698264e+77*cos(theta)**27 + 5.70082506402752e+76*cos(theta)**25 - 4.53045700452519e+75*cos(theta)**23 + 2.95871353160783e+74*cos(theta)**21 - 1.5654568950306e+73*cos(theta)**19 + 6.59342682389734e+71*cos(theta)**17 - 2.16230057402951e+70*cos(theta)**15 + 5.36741277241368e+68*cos(theta)**13 - 9.71590151423223e+66*cos(theta)**11 + 1.21892012610122e+65*cos(theta)**9 - 9.8498596048583e+62*cos(theta)**7 + 4.57423820659054e+60*cos(theta)**5 - 9.97652825864895e+57*cos(theta)**3 + 6.44478569680165e+54*cos(theta))*cos(27*phi)

#@torch.jit.script
def Yl100_m28(theta, phi):
    return 7.12731557116112e-56*(1.0 - cos(theta)**2)**14*(1.08865316143455e+83*cos(theta)**72 - 1.39829019126971e+84*cos(theta)**70 + 8.57073810131051e+84*cos(theta)**68 - 3.33746006748467e+85*cos(theta)**66 + 9.27312415123656e+85*cos(theta)**64 - 1.95755165328722e+86*cos(theta)**62 + 3.26431232483785e+86*cos(theta)**60 - 4.41392881204202e+86*cos(theta)**58 + 4.92988130155774e+86*cos(theta)**56 - 4.60960364565812e+86*cos(theta)**54 + 3.64438829665014e+86*cos(theta)**52 - 2.45427063552976e+86*cos(theta)**50 + 1.41548094563275e+86*cos(theta)**48 - 7.01829673263181e+85*cos(theta)**46 + 2.99914827344093e+85*cos(theta)**44 - 1.10611862248543e+85*cos(theta)**42 + 3.52207150133118e+84*cos(theta)**40 - 9.67670225797225e+83*cos(theta)**38 + 2.29047868261094e+83*cos(theta)**36 - 4.65935282545978e+82*cos(theta)**34 + 8.11769234497806e+81*cos(theta)**32 - 1.20586265442022e+81*cos(theta)**30 + 1.51867473848522e+80*cos(theta)**28 - 1.61026381808531e+79*cos(theta)**26 + 1.42520626600688e+78*cos(theta)**24 - 1.04200511104079e+77*cos(theta)**22 + 6.21329841637644e+75*cos(theta)**20 - 2.97436810055813e+74*cos(theta)**18 + 1.12088256006255e+73*cos(theta)**16 - 3.24345086104427e+71*cos(theta)**14 + 6.97763660413778e+69*cos(theta)**12 - 1.06874916656555e+68*cos(theta)**10 + 1.09702811349109e+66*cos(theta)**8 - 6.89490172340081e+63*cos(theta)**6 + 2.28711910329527e+61*cos(theta)**4 - 2.99295847759469e+58*cos(theta)**2 + 6.44478569680165e+54)*cos(28*phi)

#@torch.jit.script
def Yl100_m29(theta, phi):
    return 7.39545476164089e-58*(1.0 - cos(theta)**2)**14.5*(7.83830276232878e+84*cos(theta)**71 - 9.78803133888794e+85*cos(theta)**69 + 5.82810190889115e+86*cos(theta)**67 - 2.20272364453988e+87*cos(theta)**65 + 5.9347994567914e+87*cos(theta)**63 - 1.21368202503807e+88*cos(theta)**61 + 1.95858739490271e+88*cos(theta)**59 - 2.56007871098437e+88*cos(theta)**57 + 2.76073352887233e+88*cos(theta)**55 - 2.48918596865538e+88*cos(theta)**53 + 1.89508191425808e+88*cos(theta)**51 - 1.22713531776488e+88*cos(theta)**49 + 6.79430853903718e+87*cos(theta)**47 - 3.22841649701063e+87*cos(theta)**45 + 1.31962524031401e+87*cos(theta)**43 - 4.64569821443879e+86*cos(theta)**41 + 1.40882860053247e+86*cos(theta)**39 - 3.67714685802946e+85*cos(theta)**37 + 8.24572325739939e+84*cos(theta)**35 - 1.58417996065632e+84*cos(theta)**33 + 2.59766155039298e+83*cos(theta)**31 - 3.61758796326066e+82*cos(theta)**29 + 4.25228926775862e+81*cos(theta)**27 - 4.18668592702181e+80*cos(theta)**25 + 3.42049503841651e+79*cos(theta)**23 - 2.29241124428974e+78*cos(theta)**21 + 1.24265968327529e+77*cos(theta)**19 - 5.35386258100464e+75*cos(theta)**17 + 1.79341209610008e+74*cos(theta)**15 - 4.54083120546197e+72*cos(theta)**13 + 8.37316392496534e+70*cos(theta)**11 - 1.06874916656555e+69*cos(theta)**9 + 8.77622490792875e+66*cos(theta)**7 - 4.13694103404049e+64*cos(theta)**5 + 9.14847641318109e+61*cos(theta)**3 - 5.98591695518937e+58*cos(theta))*cos(29*phi)

#@torch.jit.script
def Yl100_m30(theta, phi):
    return 7.69775411038583e-60*(1.0 - cos(theta)**2)**15*(5.56519496125343e+86*cos(theta)**70 - 6.75374162383268e+87*cos(theta)**68 + 3.90482827895707e+88*cos(theta)**66 - 1.43177036895092e+89*cos(theta)**64 + 3.73892365777858e+89*cos(theta)**62 - 7.40346035273225e+89*cos(theta)**60 + 1.1555665629926e+90*cos(theta)**58 - 1.45924486526109e+90*cos(theta)**56 + 1.51840344087978e+90*cos(theta)**54 - 1.31926856338735e+90*cos(theta)**52 + 9.66491776271618e+89*cos(theta)**50 - 6.01296305704791e+89*cos(theta)**48 + 3.19332501334748e+89*cos(theta)**46 - 1.45278742365479e+89*cos(theta)**44 + 5.67438853335024e+88*cos(theta)**42 - 1.9047362679199e+88*cos(theta)**40 + 5.49443154207664e+87*cos(theta)**38 - 1.3605443374709e+87*cos(theta)**36 + 2.88600314008979e+86*cos(theta)**34 - 5.22779387016587e+85*cos(theta)**32 + 8.05275080621823e+84*cos(theta)**30 - 1.04910050934559e+84*cos(theta)**28 + 1.14811810229483e+83*cos(theta)**26 - 1.04667148175545e+82*cos(theta)**24 + 7.86713858835798e+80*cos(theta)**22 - 4.81406361300846e+79*cos(theta)**20 + 2.36105339822305e+78*cos(theta)**18 - 9.10156638770788e+76*cos(theta)**16 + 2.69011814415011e+75*cos(theta)**14 - 5.90308056710056e+73*cos(theta)**12 + 9.21048031746187e+71*cos(theta)**10 - 9.61874249908991e+69*cos(theta)**8 + 6.14335743555012e+67*cos(theta)**6 - 2.06847051702024e+65*cos(theta)**4 + 2.74454292395433e+62*cos(theta)**2 - 5.98591695518937e+58)*cos(30*phi)

#@torch.jit.script
def Yl100_m31(theta, phi):
    return 8.03858052270573e-62*(1.0 - cos(theta)**2)**15.5*(3.8956364728774e+88*cos(theta)**69 - 4.59254430420622e+89*cos(theta)**67 + 2.57718666411167e+90*cos(theta)**65 - 9.16333036128592e+90*cos(theta)**63 + 2.31813266782272e+91*cos(theta)**61 - 4.44207621163935e+91*cos(theta)**59 + 6.70228606535708e+91*cos(theta)**57 - 8.17177124546211e+91*cos(theta)**55 + 8.19937858075083e+91*cos(theta)**53 - 6.86019652961423e+91*cos(theta)**51 + 4.83245888135809e+91*cos(theta)**49 - 2.88622226738299e+91*cos(theta)**47 + 1.46892950613984e+91*cos(theta)**45 - 6.39226466408106e+90*cos(theta)**43 + 2.3832431840071e+90*cos(theta)**41 - 7.61894507167961e+89*cos(theta)**39 + 2.08788398598913e+89*cos(theta)**37 - 4.89795961489524e+88*cos(theta)**35 + 9.81241067630527e+87*cos(theta)**33 - 1.67289403845308e+87*cos(theta)**31 + 2.41582524186547e+86*cos(theta)**29 - 2.93748142616766e+85*cos(theta)**27 + 2.98510706596655e+84*cos(theta)**25 - 2.51201155621309e+83*cos(theta)**23 + 1.73077048943876e+82*cos(theta)**21 - 9.62812722601692e+80*cos(theta)**19 + 4.24989611680148e+79*cos(theta)**17 - 1.45625062203326e+78*cos(theta)**15 + 3.76616540181016e+76*cos(theta)**13 - 7.08369668052068e+74*cos(theta)**11 + 9.21048031746187e+72*cos(theta)**9 - 7.69499399927193e+70*cos(theta)**7 + 3.68601446133007e+68*cos(theta)**5 - 8.27388206808098e+65*cos(theta)**3 + 5.48908584790865e+62*cos(theta))*cos(31*phi)

#@torch.jit.script
def Yl100_m32(theta, phi):
    return 8.42302045750848e-64*(1.0 - cos(theta)**2)**16*(2.68798916628541e+90*cos(theta)**68 - 3.07700468381817e+91*cos(theta)**66 + 1.67517133167258e+92*cos(theta)**64 - 5.77289812761013e+92*cos(theta)**62 + 1.41406092737186e+93*cos(theta)**60 - 2.62082496486722e+93*cos(theta)**58 + 3.82030305725353e+93*cos(theta)**56 - 4.49447418500416e+93*cos(theta)**54 + 4.34567064779794e+93*cos(theta)**52 - 3.49870023010326e+93*cos(theta)**50 + 2.36790485186547e+93*cos(theta)**48 - 1.35652446567001e+93*cos(theta)**46 + 6.61018277762927e+92*cos(theta)**44 - 2.74867380555485e+92*cos(theta)**42 + 9.77129705442911e+91*cos(theta)**40 - 2.97138857795505e+91*cos(theta)**38 + 7.72517074815976e+90*cos(theta)**36 - 1.71428586521333e+90*cos(theta)**34 + 3.23809552318074e+89*cos(theta)**32 - 5.18597151920454e+88*cos(theta)**30 + 7.00589320140986e+87*cos(theta)**28 - 7.93119985065267e+86*cos(theta)**26 + 7.46276766491638e+85*cos(theta)**24 - 5.7776265792901e+84*cos(theta)**22 + 3.63461802782139e+83*cos(theta)**20 - 1.82934417294322e+82*cos(theta)**18 + 7.22482339856252e+80*cos(theta)**16 - 2.18437593304989e+79*cos(theta)**14 + 4.89601502235321e+77*cos(theta)**12 - 7.79206634857274e+75*cos(theta)**10 + 8.28943228571568e+73*cos(theta)**8 - 5.38649579949035e+71*cos(theta)**6 + 1.84300723066504e+69*cos(theta)**4 - 2.48216462042429e+66*cos(theta)**2 + 5.48908584790865e+62)*cos(32*phi)

#@torch.jit.script
def Yl100_m33(theta, phi):
    return 8.85701904752573e-66*(1.0 - cos(theta)**2)**16.5*(1.82783263307408e+92*cos(theta)**67 - 2.03082309131999e+93*cos(theta)**65 + 1.07210965227045e+94*cos(theta)**63 - 3.57919683911828e+94*cos(theta)**61 + 8.48436556423116e+94*cos(theta)**59 - 1.52007847962299e+95*cos(theta)**57 + 2.13936971206198e+95*cos(theta)**55 - 2.42701605990225e+95*cos(theta)**53 + 2.25974873685493e+95*cos(theta)**51 - 1.74935011505163e+95*cos(theta)**49 + 1.13659432889542e+95*cos(theta)**47 - 6.24001254208203e+94*cos(theta)**45 + 2.90848042215688e+94*cos(theta)**43 - 1.15444299833304e+94*cos(theta)**41 + 3.90851882177164e+93*cos(theta)**39 - 1.12912765962292e+93*cos(theta)**37 + 2.78106146933751e+92*cos(theta)**35 - 5.82857194172533e+91*cos(theta)**33 + 1.03619056741784e+91*cos(theta)**31 - 1.55579145576136e+90*cos(theta)**29 + 1.96165009639476e+89*cos(theta)**27 - 2.0621119611697e+88*cos(theta)**25 + 1.79106423957993e+87*cos(theta)**23 - 1.27107784744382e+86*cos(theta)**21 + 7.26923605564278e+84*cos(theta)**19 - 3.29281951129779e+83*cos(theta)**17 + 1.15597174377e+82*cos(theta)**15 - 3.05812630626985e+80*cos(theta)**13 + 5.87521802682385e+78*cos(theta)**11 - 7.79206634857274e+76*cos(theta)**9 + 6.63154582857255e+74*cos(theta)**7 - 3.23189747969421e+72*cos(theta)**5 + 7.37202892266015e+69*cos(theta)**3 - 4.96432924084859e+66*cos(theta))*cos(33*phi)

#@torch.jit.script
def Yl100_m34(theta, phi):
    return 9.34754959642367e-68*(1.0 - cos(theta)**2)**17*(1.22464786415963e+94*cos(theta)**66 - 1.32003500935799e+95*cos(theta)**64 + 6.75429080930385e+95*cos(theta)**62 - 2.18331007186215e+96*cos(theta)**60 + 5.00577568289638e+96*cos(theta)**58 - 8.66444733385101e+96*cos(theta)**56 + 1.17665334163409e+97*cos(theta)**54 - 1.28631851174819e+97*cos(theta)**52 + 1.15247185579601e+97*cos(theta)**50 - 8.57181556375298e+96*cos(theta)**48 + 5.34199334580849e+96*cos(theta)**46 - 2.80800564393692e+96*cos(theta)**44 + 1.25064658152746e+96*cos(theta)**42 - 4.73321629316546e+95*cos(theta)**40 + 1.52432234049094e+95*cos(theta)**38 - 4.1777723406048e+94*cos(theta)**36 + 9.7337151426813e+93*cos(theta)**34 - 1.92342874076936e+93*cos(theta)**32 + 3.21219075899529e+92*cos(theta)**30 - 4.51179522170795e+91*cos(theta)**28 + 5.29645526026586e+90*cos(theta)**26 - 5.15527990292424e+89*cos(theta)**24 + 4.11944775103384e+88*cos(theta)**22 - 2.66926347963203e+87*cos(theta)**20 + 1.38115485057213e+86*cos(theta)**18 - 5.59779316920624e+84*cos(theta)**16 + 1.733957615655e+83*cos(theta)**14 - 3.9755641981508e+81*cos(theta)**12 + 6.46273982950623e+79*cos(theta)**10 - 7.01285971371547e+77*cos(theta)**8 + 4.64208208000078e+75*cos(theta)**6 - 1.6159487398471e+73*cos(theta)**4 + 2.21160867679805e+70*cos(theta)**2 - 4.96432924084859e+66)*cos(34*phi)

#@torch.jit.script
def Yl100_m35(theta, phi):
    return 9.90282093478634e-70*(1.0 - cos(theta)**2)**17.5*(8.08267590345357e+95*cos(theta)**65 - 8.44822405989117e+96*cos(theta)**63 + 4.18766030176839e+97*cos(theta)**61 - 1.30998604311729e+98*cos(theta)**59 + 2.9033498960799e+98*cos(theta)**57 - 4.85209050695657e+98*cos(theta)**55 + 6.35392804482408e+98*cos(theta)**53 - 6.68885626109059e+98*cos(theta)**51 + 5.76235927898007e+98*cos(theta)**49 - 4.11447147060143e+98*cos(theta)**47 + 2.45731693907191e+98*cos(theta)**45 - 1.23552248333224e+98*cos(theta)**43 + 5.25271564241533e+97*cos(theta)**41 - 1.89328651726618e+97*cos(theta)**39 + 5.79242489386557e+96*cos(theta)**37 - 1.50399804261773e+96*cos(theta)**35 + 3.30946314851164e+95*cos(theta)**33 - 6.15497197046195e+94*cos(theta)**31 + 9.63657227698588e+93*cos(theta)**29 - 1.26330266207823e+93*cos(theta)**27 + 1.37707836766912e+92*cos(theta)**25 - 1.23726717670182e+91*cos(theta)**23 + 9.06278505227446e+89*cos(theta)**21 - 5.33852695926406e+88*cos(theta)**19 + 2.48607873102983e+87*cos(theta)**17 - 8.95646907072998e+85*cos(theta)**15 + 2.42754066191701e+84*cos(theta)**13 - 4.77067703778096e+82*cos(theta)**11 + 6.46273982950623e+80*cos(theta)**9 - 5.61028777097238e+78*cos(theta)**7 + 2.78524924800047e+76*cos(theta)**5 - 6.46379495938842e+73*cos(theta)**3 + 4.42321735359609e+70*cos(theta))*cos(35*phi)

#@torch.jit.script
def Yl100_m36(theta, phi):
    return 1.05325321532538e-71*(1.0 - cos(theta)**2)**18*(5.25373933724482e+97*cos(theta)**64 - 5.32238115773143e+98*cos(theta)**62 + 2.55447278407872e+99*cos(theta)**60 - 7.72891765439201e+99*cos(theta)**58 + 1.65490944076554e+100*cos(theta)**56 - 2.66864977882611e+100*cos(theta)**54 + 3.36758186375676e+100*cos(theta)**52 - 3.4113166931562e+100*cos(theta)**50 + 2.82355604670023e+100*cos(theta)**48 - 1.93380159118267e+100*cos(theta)**46 + 1.10579262258236e+100*cos(theta)**44 - 5.31274667832864e+99*cos(theta)**42 + 2.15361341339028e+99*cos(theta)**40 - 7.38381741733812e+98*cos(theta)**38 + 2.14319721073026e+98*cos(theta)**36 - 5.26399314916205e+97*cos(theta)**34 + 1.09212283900884e+97*cos(theta)**32 - 1.9080413108432e+96*cos(theta)**30 + 2.79460596032591e+95*cos(theta)**28 - 3.41091718761121e+94*cos(theta)**26 + 3.44269591917281e+93*cos(theta)**24 - 2.84571450641418e+92*cos(theta)**22 + 1.90318486097764e+91*cos(theta)**20 - 1.01432012226017e+90*cos(theta)**18 + 4.22633384275071e+88*cos(theta)**16 - 1.3434703606095e+87*cos(theta)**14 + 3.15580286049211e+85*cos(theta)**12 - 5.24774474155906e+83*cos(theta)**10 + 5.81646584655561e+81*cos(theta)**8 - 3.92720143968066e+79*cos(theta)**6 + 1.39262462400023e+77*cos(theta)**4 - 1.93913848781653e+74*cos(theta)**2 + 4.42321735359609e+70)*cos(36*phi)

#@torch.jit.script
def Yl100_m37(theta, phi):
    return 1.12481868753504e-73*(1.0 - cos(theta)**2)**18.5*(3.36239317583668e+99*cos(theta)**63 - 3.29987631779349e+100*cos(theta)**61 + 1.53268367044723e+101*cos(theta)**59 - 4.48277223954737e+101*cos(theta)**57 + 9.26749286828705e+101*cos(theta)**55 - 1.4410708805661e+102*cos(theta)**53 + 1.75114256915352e+102*cos(theta)**51 - 1.7056583465781e+102*cos(theta)**49 + 1.35530690241611e+102*cos(theta)**47 - 8.8954873194403e+101*cos(theta)**45 + 4.86548753936237e+101*cos(theta)**43 - 2.23135360489803e+101*cos(theta)**41 + 8.61445365356113e+100*cos(theta)**39 - 2.80585061858848e+100*cos(theta)**37 + 7.71550995862894e+99*cos(theta)**35 - 1.7897576707151e+99*cos(theta)**33 + 3.49479308482829e+98*cos(theta)**31 - 5.72412393252961e+97*cos(theta)**29 + 7.82489668891253e+96*cos(theta)**27 - 8.86838468778915e+95*cos(theta)**25 + 8.26247020601473e+94*cos(theta)**23 - 6.26057191411119e+93*cos(theta)**21 + 3.80636972195527e+92*cos(theta)**19 - 1.82577622006831e+91*cos(theta)**17 + 6.76213414840114e+89*cos(theta)**15 - 1.8808585048533e+88*cos(theta)**13 + 3.78696343259053e+86*cos(theta)**11 - 5.24774474155906e+84*cos(theta)**9 + 4.65317267724449e+82*cos(theta)**7 - 2.3563208638084e+80*cos(theta)**5 + 5.57049849600094e+77*cos(theta)**3 - 3.87827697563305e+74*cos(theta))*cos(37*phi)

#@torch.jit.script
def Yl100_m38(theta, phi):
    return 1.20634826823338e-75*(1.0 - cos(theta)**2)**19*(2.11830770077711e+101*cos(theta)**62 - 2.01292455385403e+102*cos(theta)**60 + 9.04283365563866e+102*cos(theta)**58 - 2.555180176542e+103*cos(theta)**56 + 5.09712107755788e+103*cos(theta)**54 - 7.63767566700033e+103*cos(theta)**52 + 8.93082710268293e+103*cos(theta)**50 - 8.35772589823269e+103*cos(theta)**48 + 6.36994244135573e+103*cos(theta)**46 - 4.00296929374813e+103*cos(theta)**44 + 2.09215964192582e+103*cos(theta)**42 - 9.14854978008193e+102*cos(theta)**40 + 3.35963692488884e+102*cos(theta)**38 - 1.03816472887774e+102*cos(theta)**36 + 2.70042848552013e+101*cos(theta)**34 - 5.90620031335982e+100*cos(theta)**32 + 1.08338585629677e+100*cos(theta)**30 - 1.65999594043359e+99*cos(theta)**28 + 2.11272210600638e+98*cos(theta)**26 - 2.21709617194729e+97*cos(theta)**24 + 1.90036814738339e+96*cos(theta)**22 - 1.31472010196335e+95*cos(theta)**20 + 7.23210247171502e+93*cos(theta)**18 - 3.10381957411612e+92*cos(theta)**16 + 1.01432012226017e+91*cos(theta)**14 - 2.44511605630929e+89*cos(theta)**12 + 4.16565977584958e+87*cos(theta)**10 - 4.72297026740316e+85*cos(theta)**8 + 3.25722087407114e+83*cos(theta)**6 - 1.1781604319042e+81*cos(theta)**4 + 1.67114954880028e+78*cos(theta)**2 - 3.87827697563305e+74)*cos(38*phi)

#@torch.jit.script
def Yl100_m39(theta, phi):
    return 1.29947958247701e-77*(1.0 - cos(theta)**2)**19.5*(1.31335077448181e+103*cos(theta)**61 - 1.20775473231242e+104*cos(theta)**59 + 5.24484352027042e+104*cos(theta)**57 - 1.43090089886352e+105*cos(theta)**55 + 2.75244538188125e+105*cos(theta)**53 - 3.97159134684017e+105*cos(theta)**51 + 4.46541355134147e+105*cos(theta)**49 - 4.01170843115169e+105*cos(theta)**47 + 2.93017352302363e+105*cos(theta)**45 - 1.76130648924918e+105*cos(theta)**43 + 8.78707049608844e+104*cos(theta)**41 - 3.65941991203277e+104*cos(theta)**39 + 1.27666203145776e+104*cos(theta)**37 - 3.73739302395986e+103*cos(theta)**35 + 9.18145685076844e+102*cos(theta)**33 - 1.88998410027514e+102*cos(theta)**31 + 3.25015756889031e+101*cos(theta)**29 - 4.64798863321405e+100*cos(theta)**27 + 5.4930774756166e+99*cos(theta)**25 - 5.32103081267349e+98*cos(theta)**23 + 4.18080992424346e+97*cos(theta)**21 - 2.6294402039267e+96*cos(theta)**19 + 1.3017784449087e+95*cos(theta)**17 - 4.9661113185858e+93*cos(theta)**15 + 1.42004817116424e+92*cos(theta)**13 - 2.93413926757114e+90*cos(theta)**11 + 4.16565977584958e+88*cos(theta)**9 - 3.77837621392252e+86*cos(theta)**7 + 1.95433252444268e+84*cos(theta)**5 - 4.7126417276168e+81*cos(theta)**3 + 3.34229909760056e+78*cos(theta))*cos(39*phi)

#@torch.jit.script
def Yl100_m40(theta, phi):
    return 1.40617873132947e-79*(1.0 - cos(theta)**2)**20*(8.01143972433903e+104*cos(theta)**60 - 7.12575292064326e+105*cos(theta)**58 + 2.98956080655414e+106*cos(theta)**56 - 7.86995494374936e+106*cos(theta)**54 + 1.45879605239706e+107*cos(theta)**52 - 2.02551158688849e+107*cos(theta)**50 + 2.18805264015732e+107*cos(theta)**48 - 1.88550296264129e+107*cos(theta)**46 + 1.31857808536064e+107*cos(theta)**44 - 7.57361790377147e+106*cos(theta)**42 + 3.60269890339626e+106*cos(theta)**40 - 1.42717376569278e+106*cos(theta)**38 + 4.72364951639371e+105*cos(theta)**36 - 1.30808755838595e+105*cos(theta)**34 + 3.02988076075359e+104*cos(theta)**32 - 5.85895071085294e+103*cos(theta)**30 + 9.42545694978191e+102*cos(theta)**28 - 1.25495693096779e+102*cos(theta)**26 + 1.37326936890415e+101*cos(theta)**24 - 1.2238370869149e+100*cos(theta)**22 + 8.77970084091126e+98*cos(theta)**20 - 4.99593638746073e+97*cos(theta)**18 + 2.2130233563448e+96*cos(theta)**16 - 7.44916697787869e+94*cos(theta)**14 + 1.84606262251351e+93*cos(theta)**12 - 3.22755319432826e+91*cos(theta)**10 + 3.74909379826462e+89*cos(theta)**8 - 2.64486334974577e+87*cos(theta)**6 + 9.77166262221342e+84*cos(theta)**4 - 1.41379251828504e+82*cos(theta)**2 + 3.34229909760056e+78)*cos(40*phi)

#@torch.jit.script
def Yl100_m41(theta, phi):
    return 1.52881643696148e-81*(1.0 - cos(theta)**2)**20.5*(4.80686383460342e+106*cos(theta)**59 - 4.13293669397309e+107*cos(theta)**57 + 1.67415405167032e+108*cos(theta)**55 - 4.24977566962465e+108*cos(theta)**53 + 7.58573947246473e+108*cos(theta)**51 - 1.01275579344424e+109*cos(theta)**49 + 1.05026526727551e+109*cos(theta)**47 - 8.67331362814996e+108*cos(theta)**45 + 5.80174357558679e+108*cos(theta)**43 - 3.18091951958402e+108*cos(theta)**41 + 1.4410795613585e+108*cos(theta)**39 - 5.42326030963257e+107*cos(theta)**37 + 1.70051382590174e+107*cos(theta)**35 - 4.44749769851223e+106*cos(theta)**33 + 9.69561843441148e+105*cos(theta)**31 - 1.75768521325588e+105*cos(theta)**29 + 2.63912794593893e+104*cos(theta)**27 - 3.26288802051626e+103*cos(theta)**25 + 3.29584648536996e+102*cos(theta)**23 - 2.69244159121279e+101*cos(theta)**21 + 1.75594016818225e+100*cos(theta)**19 - 8.99268549742932e+98*cos(theta)**17 + 3.54083737015167e+97*cos(theta)**15 - 1.04288337690302e+96*cos(theta)**13 + 2.21527514701621e+94*cos(theta)**11 - 3.22755319432826e+92*cos(theta)**9 + 2.9992750386117e+90*cos(theta)**7 - 1.58691800984746e+88*cos(theta)**5 + 3.90866504888537e+85*cos(theta)**3 - 2.82758503657008e+82*cos(theta))*cos(41*phi)

#@torch.jit.script
def Yl100_m42(theta, phi):
    return 1.67026417186738e-83*(1.0 - cos(theta)**2)**21*(2.83604966241602e+108*cos(theta)**58 - 2.35577391556466e+109*cos(theta)**56 + 9.20784728418675e+109*cos(theta)**54 - 2.25238110490107e+110*cos(theta)**52 + 3.86872713095701e+110*cos(theta)**50 - 4.9625033878768e+110*cos(theta)**48 + 4.93624675619491e+110*cos(theta)**46 - 3.90299113266748e+110*cos(theta)**44 + 2.49474973750232e+110*cos(theta)**42 - 1.30417700302945e+110*cos(theta)**40 + 5.62021028929817e+109*cos(theta)**38 - 2.00660631456405e+109*cos(theta)**36 + 5.95179839065608e+108*cos(theta)**34 - 1.46767424050904e+108*cos(theta)**32 + 3.00564171466756e+107*cos(theta)**30 - 5.09728711844206e+106*cos(theta)**28 + 7.12564545403512e+105*cos(theta)**26 - 8.15722005129065e+104*cos(theta)**24 + 7.58044691635091e+103*cos(theta)**22 - 5.65412734154685e+102*cos(theta)**20 + 3.33628631954628e+101*cos(theta)**18 - 1.52875653456298e+100*cos(theta)**16 + 5.31125605522751e+98*cos(theta)**14 - 1.35574838997392e+97*cos(theta)**12 + 2.43680266171783e+95*cos(theta)**10 - 2.90479787489543e+93*cos(theta)**8 + 2.09949252702819e+91*cos(theta)**6 - 7.9345900492373e+88*cos(theta)**4 + 1.17259951466561e+86*cos(theta)**2 - 2.82758503657008e+82)*cos(42*phi)

#@torch.jit.script
def Yl100_m43(theta, phi):
    return 1.83401612536192e-85*(1.0 - cos(theta)**2)**21.5*(1.64490880420129e+110*cos(theta)**57 - 1.31923339271621e+111*cos(theta)**55 + 4.97223753346085e+111*cos(theta)**53 - 1.17123817454855e+112*cos(theta)**51 + 1.93436356547851e+112*cos(theta)**49 - 2.38200162618086e+112*cos(theta)**47 + 2.27067350784966e+112*cos(theta)**45 - 1.71731609837369e+112*cos(theta)**43 + 1.04779488975098e+112*cos(theta)**41 - 5.21670801211779e+111*cos(theta)**39 + 2.1356799099333e+111*cos(theta)**37 - 7.22378273243058e+110*cos(theta)**35 + 2.02361145282307e+110*cos(theta)**33 - 4.69655756962892e+109*cos(theta)**31 + 9.01692514400267e+108*cos(theta)**29 - 1.42724039316378e+108*cos(theta)**27 + 1.85266781804913e+107*cos(theta)**25 - 1.95773281230976e+106*cos(theta)**23 + 1.6676983215972e+105*cos(theta)**21 - 1.13082546830937e+104*cos(theta)**19 + 6.0053153751833e+102*cos(theta)**17 - 2.44601045530078e+101*cos(theta)**15 + 7.43575847731851e+99*cos(theta)**13 - 1.62689806796871e+98*cos(theta)**11 + 2.43680266171783e+96*cos(theta)**9 - 2.32383829991634e+94*cos(theta)**7 + 1.25969551621691e+92*cos(theta)**5 - 3.17383601969492e+89*cos(theta)**3 + 2.34519902933122e+86*cos(theta))*cos(43*phi)

#@torch.jit.script
def Yl100_m44(theta, phi):
    return 2.0243447511841e-87*(1.0 - cos(theta)**2)**22*(9.37598018394736e+111*cos(theta)**56 - 7.25578365993916e+112*cos(theta)**54 + 2.63528589273425e+113*cos(theta)**52 - 5.97331469019763e+113*cos(theta)**50 + 9.47838147084468e+113*cos(theta)**48 - 1.11954076430501e+114*cos(theta)**46 + 1.02180307853235e+114*cos(theta)**44 - 7.38445922300687e+113*cos(theta)**42 + 4.295959047979e+113*cos(theta)**40 - 2.03451612472594e+113*cos(theta)**38 + 7.90201566675323e+112*cos(theta)**36 - 2.5283239563507e+112*cos(theta)**34 + 6.67791779431612e+111*cos(theta)**32 - 1.45593284658497e+111*cos(theta)**30 + 2.61490829176078e+110*cos(theta)**28 - 3.8535490615422e+109*cos(theta)**26 + 4.63166954512283e+108*cos(theta)**24 - 4.50278546831244e+107*cos(theta)**22 + 3.50216647535412e+106*cos(theta)**20 - 2.1485683897878e+105*cos(theta)**18 + 1.02090361378116e+104*cos(theta)**16 - 3.66901568295116e+102*cos(theta)**14 + 9.66648602051406e+100*cos(theta)**12 - 1.78958787476558e+99*cos(theta)**10 + 2.19312239554605e+97*cos(theta)**8 - 1.62668680994144e+95*cos(theta)**6 + 6.29847758108457e+92*cos(theta)**4 - 9.52150805908476e+89*cos(theta)**2 + 2.34519902933122e+86)*cos(44*phi)

#@torch.jit.script
def Yl100_m45(theta, phi):
    return 2.24650019862496e-89*(1.0 - cos(theta)**2)**22.5*(5.25054890301052e+113*cos(theta)**55 - 3.91812317636715e+114*cos(theta)**53 + 1.37034866422181e+115*cos(theta)**51 - 2.98665734509881e+115*cos(theta)**49 + 4.54962310600545e+115*cos(theta)**47 - 5.14988751580303e+115*cos(theta)**45 + 4.49593354554232e+115*cos(theta)**43 - 3.10147287366289e+115*cos(theta)**41 + 1.7183836191916e+115*cos(theta)**39 - 7.73116127395856e+114*cos(theta)**37 + 2.84472564003116e+114*cos(theta)**35 - 8.59630145159239e+113*cos(theta)**33 + 2.13693369418116e+113*cos(theta)**31 - 4.3677985397549e+112*cos(theta)**29 + 7.32174321693017e+111*cos(theta)**27 - 1.00192275600097e+111*cos(theta)**25 + 1.11160069082948e+110*cos(theta)**23 - 9.90612803028736e+108*cos(theta)**21 + 7.00433295070824e+107*cos(theta)**19 - 3.86742310161805e+106*cos(theta)**17 + 1.63344578204986e+105*cos(theta)**15 - 5.13662195613163e+103*cos(theta)**13 + 1.15997832246169e+102*cos(theta)**11 - 1.78958787476558e+100*cos(theta)**9 + 1.75449791643684e+98*cos(theta)**7 - 9.76012085964865e+95*cos(theta)**5 + 2.51939103243383e+93*cos(theta)**3 - 1.90430161181695e+90*cos(theta))*cos(45*phi)

#@torch.jit.script
def Yl100_m46(theta, phi):
    return 2.50696741243304e-91*(1.0 - cos(theta)**2)**23*(2.88780189665579e+115*cos(theta)**54 - 2.07660528347459e+116*cos(theta)**52 + 6.98877818753123e+116*cos(theta)**50 - 1.46346209909842e+117*cos(theta)**48 + 2.13832285982256e+117*cos(theta)**46 - 2.31744938211136e+117*cos(theta)**44 + 1.9332514245832e+117*cos(theta)**42 - 1.27160387820178e+117*cos(theta)**40 + 6.70169611484724e+116*cos(theta)**38 - 2.86052967136467e+116*cos(theta)**36 + 9.95653974010906e+115*cos(theta)**34 - 2.83677947902549e+115*cos(theta)**32 + 6.62449445196159e+114*cos(theta)**30 - 1.26666157652892e+114*cos(theta)**28 + 1.97687066857115e+113*cos(theta)**26 - 2.50480689000243e+112*cos(theta)**24 + 2.5566815889078e+111*cos(theta)**22 - 2.08028688636035e+110*cos(theta)**20 + 1.33082326063457e+109*cos(theta)**18 - 6.57461927275068e+107*cos(theta)**16 + 2.45016867307479e+106*cos(theta)**14 - 6.67760854297112e+104*cos(theta)**12 + 1.27597615470786e+103*cos(theta)**10 - 1.61062908728902e+101*cos(theta)**8 + 1.22814854150579e+99*cos(theta)**6 - 4.88006042982432e+96*cos(theta)**4 + 7.55817309730148e+93*cos(theta)**2 - 1.90430161181695e+90)*cos(46*phi)

#@torch.jit.script
def Yl100_m47(theta, phi):
    return 2.81379945642078e-93*(1.0 - cos(theta)**2)**23.5*(1.55941302419412e+117*cos(theta)**53 - 1.07983474740679e+118*cos(theta)**51 + 3.49438909376561e+118*cos(theta)**49 - 7.02461807567241e+118*cos(theta)**47 + 9.83628515518378e+118*cos(theta)**45 - 1.019677728129e+119*cos(theta)**43 + 8.11965598324944e+118*cos(theta)**41 - 5.08641551280713e+118*cos(theta)**39 + 2.54664452364195e+118*cos(theta)**37 - 1.02979068169128e+118*cos(theta)**35 + 3.38522351163708e+117*cos(theta)**33 - 9.07769433288156e+116*cos(theta)**31 + 1.98734833558848e+116*cos(theta)**29 - 3.54665241428097e+115*cos(theta)**27 + 5.13986373828498e+114*cos(theta)**25 - 6.01153653600582e+113*cos(theta)**23 + 5.62469949559717e+112*cos(theta)**21 - 4.16057377272069e+111*cos(theta)**19 + 2.39548186914222e+110*cos(theta)**17 - 1.05193908364011e+109*cos(theta)**15 + 3.4302361423047e+107*cos(theta)**13 - 8.01313025156534e+105*cos(theta)**11 + 1.27597615470786e+104*cos(theta)**9 - 1.28850326983122e+102*cos(theta)**7 + 7.36889124903473e+99*cos(theta)**5 - 1.95202417192973e+97*cos(theta)**3 + 1.5116346194603e+94*cos(theta))*cos(47*phi)

#@torch.jit.script
def Yl100_m48(theta, phi):
    return 3.17705218843653e-95*(1.0 - cos(theta)**2)**24*(8.26488902822886e+118*cos(theta)**52 - 5.50715721177461e+119*cos(theta)**50 + 1.71225065594515e+120*cos(theta)**48 - 3.30157049556603e+120*cos(theta)**46 + 4.4263283198327e+120*cos(theta)**44 - 4.3846142309547e+120*cos(theta)**42 + 3.32905895313227e+120*cos(theta)**40 - 1.98370204999478e+120*cos(theta)**38 + 9.42258473747522e+119*cos(theta)**36 - 3.60426738591948e+119*cos(theta)**34 + 1.11712375884024e+119*cos(theta)**32 - 2.81408524319328e+118*cos(theta)**30 + 5.76331017320658e+117*cos(theta)**28 - 9.57596151855863e+116*cos(theta)**26 + 1.28496593457125e+116*cos(theta)**24 - 1.38265340328134e+115*cos(theta)**22 + 1.1811868940754e+114*cos(theta)**20 - 7.90509016816932e+112*cos(theta)**18 + 4.07231917754177e+111*cos(theta)**16 - 1.57790862546016e+110*cos(theta)**14 + 4.45930698499611e+108*cos(theta)**12 - 8.81444327672187e+106*cos(theta)**10 + 1.14837853923707e+105*cos(theta)**8 - 9.01952288881851e+102*cos(theta)**6 + 3.68444562451736e+100*cos(theta)**4 - 5.85607251578919e+97*cos(theta)**2 + 1.5116346194603e+94)*cos(48*phi)

#@torch.jit.script
def Yl100_m49(theta, phi):
    return 3.60935453010183e-97*(1.0 - cos(theta)**2)**24.5*(4.29774229467901e+120*cos(theta)**51 - 2.7535786058873e+121*cos(theta)**49 + 8.21880314853672e+121*cos(theta)**47 - 1.51872242796038e+122*cos(theta)**45 + 1.94758446072639e+122*cos(theta)**43 - 1.84153797700097e+122*cos(theta)**41 + 1.33162358125291e+122*cos(theta)**39 - 7.53806778998017e+121*cos(theta)**37 + 3.39213050549108e+121*cos(theta)**35 - 1.22545091121262e+121*cos(theta)**33 + 3.57479602828876e+120*cos(theta)**31 - 8.44225572957985e+119*cos(theta)**29 + 1.61372684849784e+119*cos(theta)**27 - 2.48974999482524e+118*cos(theta)**25 + 3.08391824297099e+117*cos(theta)**23 - 3.04183748721895e+116*cos(theta)**21 + 2.36237378815081e+115*cos(theta)**19 - 1.42291623027048e+114*cos(theta)**17 + 6.51571068406683e+112*cos(theta)**15 - 2.20907207564423e+111*cos(theta)**13 + 5.35116838199533e+109*cos(theta)**11 - 8.81444327672187e+107*cos(theta)**9 + 9.18702831389657e+105*cos(theta)**7 - 5.41171373329111e+103*cos(theta)**5 + 1.47377824980695e+101*cos(theta)**3 - 1.17121450315784e+98*cos(theta))*cos(49*phi)

#@torch.jit.script
def Yl100_m50(theta, phi):
    return 4.12666130126779e-99*(1.0 - cos(theta)**2)**25*(2.19184857028629e+122*cos(theta)**50 - 1.34925351688478e+123*cos(theta)**48 + 3.86283747981226e+123*cos(theta)**46 - 6.83425092582169e+123*cos(theta)**44 + 8.37461318112347e+123*cos(theta)**42 - 7.55030570570399e+123*cos(theta)**40 + 5.19333196688634e+123*cos(theta)**38 - 2.78908508229266e+123*cos(theta)**36 + 1.18724567692188e+123*cos(theta)**34 - 4.04398800700166e+122*cos(theta)**32 + 1.10818676876952e+122*cos(theta)**30 - 2.44825416157816e+121*cos(theta)**28 + 4.35706249094418e+120*cos(theta)**26 - 6.22437498706311e+119*cos(theta)**24 + 7.09301195883327e+118*cos(theta)**22 - 6.38785872315979e+117*cos(theta)**20 + 4.48851019748654e+116*cos(theta)**18 - 2.41895759145981e+115*cos(theta)**16 + 9.77356602610025e+113*cos(theta)**14 - 2.8717936983375e+112*cos(theta)**12 + 5.88628522019487e+110*cos(theta)**10 - 7.93299894904969e+108*cos(theta)**8 + 6.4309198197276e+106*cos(theta)**6 - 2.70585686664555e+104*cos(theta)**4 + 4.42133474942084e+101*cos(theta)**2 - 1.17121450315784e+98)*cos(50*phi)

#@torch.jit.script
def Yl100_m51(theta, phi):
    return 4.74925347851153e-101*(1.0 - cos(theta)**2)**25.5*(1.09592428514315e+124*cos(theta)**49 - 6.47641688104694e+124*cos(theta)**47 + 1.77690524071364e+125*cos(theta)**45 - 3.00707040736154e+125*cos(theta)**43 + 3.51733753607186e+125*cos(theta)**41 - 3.02012228228159e+125*cos(theta)**39 + 1.97346614741681e+125*cos(theta)**37 - 1.00407062962536e+125*cos(theta)**35 + 4.03663530153438e+124*cos(theta)**33 - 1.29407616224053e+124*cos(theta)**31 + 3.32456030630855e+123*cos(theta)**29 - 6.85511165241884e+122*cos(theta)**27 + 1.13283624764549e+122*cos(theta)**25 - 1.49384999689515e+121*cos(theta)**23 + 1.56046263094332e+120*cos(theta)**21 - 1.27757174463196e+119*cos(theta)**19 + 8.07931835547577e+117*cos(theta)**17 - 3.8703321463357e+116*cos(theta)**15 + 1.36829924365403e+115*cos(theta)**13 - 3.446152438005e+113*cos(theta)**11 + 5.88628522019487e+111*cos(theta)**9 - 6.34639915923975e+109*cos(theta)**7 + 3.85855189183656e+107*cos(theta)**5 - 1.08234274665822e+105*cos(theta)**3 + 8.84266949884168e+101*cos(theta))*cos(51*phi)

#@torch.jit.script
def Yl100_m52(theta, phi):
    return 5.50307606138827e-103*(1.0 - cos(theta)**2)**26*(5.37002899720142e+125*cos(theta)**48 - 3.04391593409206e+126*cos(theta)**46 + 7.99607358321138e+126*cos(theta)**44 - 1.29304027516546e+127*cos(theta)**42 + 1.44210838978946e+127*cos(theta)**40 - 1.17784769008982e+127*cos(theta)**38 + 7.30182474544219e+126*cos(theta)**36 - 3.51424720368876e+126*cos(theta)**34 + 1.33208964950635e+126*cos(theta)**32 - 4.01163610294565e+125*cos(theta)**30 + 9.64122488829478e+124*cos(theta)**28 - 1.85088014615309e+124*cos(theta)**26 + 2.83209061911372e+123*cos(theta)**24 - 3.43585499285884e+122*cos(theta)**22 + 3.27697152498097e+121*cos(theta)**20 - 2.42738631480072e+120*cos(theta)**18 + 1.37348412043088e+119*cos(theta)**16 - 5.80549821950355e+117*cos(theta)**14 + 1.77878901675024e+116*cos(theta)**12 - 3.79076768180549e+114*cos(theta)**10 + 5.29765669817538e+112*cos(theta)**8 - 4.44247941146782e+110*cos(theta)**6 + 1.92927594591828e+108*cos(theta)**4 - 3.24702823997466e+105*cos(theta)**2 + 8.84266949884168e+101)*cos(52*phi)

#@torch.jit.script
def Yl100_m53(theta, phi):
    return 6.42153984137775e-105*(1.0 - cos(theta)**2)**26.5*(2.57761391865668e+127*cos(theta)**47 - 1.40020132968235e+128*cos(theta)**45 + 3.51827237661301e+128*cos(theta)**43 - 5.43076915569495e+128*cos(theta)**41 + 5.76843355915785e+128*cos(theta)**39 - 4.47582122234132e+128*cos(theta)**37 + 2.62865690835919e+128*cos(theta)**35 - 1.19484404925418e+128*cos(theta)**33 + 4.26268687842031e+127*cos(theta)**31 - 1.20349083088369e+127*cos(theta)**29 + 2.69954296872254e+126*cos(theta)**27 - 4.81228837999802e+125*cos(theta)**25 + 6.79701748587292e+124*cos(theta)**23 - 7.55888098428944e+123*cos(theta)**21 + 6.55394304996194e+122*cos(theta)**19 - 4.3692953666413e+121*cos(theta)**17 + 2.19757459268941e+120*cos(theta)**15 - 8.12769750730496e+118*cos(theta)**13 + 2.13454682010029e+117*cos(theta)**11 - 3.79076768180549e+115*cos(theta)**9 + 4.2381253585403e+113*cos(theta)**7 - 2.66548764688069e+111*cos(theta)**5 + 7.71710378367312e+108*cos(theta)**3 - 6.49405647994933e+105*cos(theta))*cos(53*phi)

#@torch.jit.script
def Yl100_m54(theta, phi):
    return 7.54796524942109e-107*(1.0 - cos(theta)**2)**27*(1.21147854176864e+129*cos(theta)**46 - 6.30090598357056e+129*cos(theta)**44 + 1.51285712194359e+130*cos(theta)**42 - 2.22661535383493e+130*cos(theta)**40 + 2.24968908807156e+130*cos(theta)**38 - 1.65605385226629e+130*cos(theta)**36 + 9.20029917925716e+129*cos(theta)**34 - 3.94298536253878e+129*cos(theta)**32 + 1.3214329323103e+129*cos(theta)**30 - 3.49012340956271e+128*cos(theta)**28 + 7.28876601555086e+127*cos(theta)**26 - 1.20307209499951e+127*cos(theta)**24 + 1.56331402175077e+126*cos(theta)**22 - 1.58736500670078e+125*cos(theta)**20 + 1.24524917949277e+124*cos(theta)**18 - 7.4278021232902e+122*cos(theta)**16 + 3.29636188903411e+121*cos(theta)**14 - 1.05660067594965e+120*cos(theta)**12 + 2.34800150211032e+118*cos(theta)**10 - 3.41169091362494e+116*cos(theta)**8 + 2.96668775097821e+114*cos(theta)**6 - 1.33274382344035e+112*cos(theta)**4 + 2.31513113510193e+109*cos(theta)**2 - 6.49405647994933e+105)*cos(54*phi)

#@torch.jit.script
def Yl100_m55(theta, phi):
    return 8.93892157607132e-109*(1.0 - cos(theta)**2)**27.5*(5.57280129213574e+130*cos(theta)**45 - 2.77239863277105e+131*cos(theta)**43 + 6.35399991216309e+131*cos(theta)**41 - 8.90646141533971e+131*cos(theta)**39 + 8.54881853467193e+131*cos(theta)**37 - 5.96179386815864e+131*cos(theta)**35 + 3.12810172094744e+131*cos(theta)**33 - 1.26175531601241e+131*cos(theta)**31 + 3.96429879693089e+130*cos(theta)**29 - 9.77234554677559e+129*cos(theta)**27 + 1.89507916404322e+129*cos(theta)**25 - 2.88737302799881e+128*cos(theta)**23 + 3.4392908478517e+127*cos(theta)**21 - 3.17473001340157e+126*cos(theta)**19 + 2.24144852308698e+125*cos(theta)**17 - 1.18844833972643e+124*cos(theta)**15 + 4.61490664464776e+122*cos(theta)**13 - 1.26792081113957e+121*cos(theta)**11 + 2.34800150211032e+119*cos(theta)**9 - 2.72935273089996e+117*cos(theta)**7 + 1.78001265058693e+115*cos(theta)**5 - 5.33097529376139e+112*cos(theta)**3 + 4.63026227020387e+109*cos(theta))*cos(55*phi)

#@torch.jit.script
def Yl100_m56(theta, phi):
    return 1.06688244974945e-110*(1.0 - cos(theta)**2)**28*(2.50776058146108e+132*cos(theta)**44 - 1.19213141209155e+133*cos(theta)**42 + 2.60513996398687e+133*cos(theta)**40 - 3.47351995198249e+133*cos(theta)**38 + 3.16306285782861e+133*cos(theta)**36 - 2.08662785385552e+133*cos(theta)**34 + 1.03227356791265e+133*cos(theta)**32 - 3.91144147963847e+132*cos(theta)**30 + 1.14964665110996e+132*cos(theta)**28 - 2.63853329762941e+131*cos(theta)**26 + 4.73769791010806e+130*cos(theta)**24 - 6.64095796439727e+129*cos(theta)**22 + 7.22251078048856e+128*cos(theta)**20 - 6.03198702546297e+127*cos(theta)**18 + 3.81046248924787e+126*cos(theta)**16 - 1.78267250958965e+125*cos(theta)**14 + 5.99937863804209e+123*cos(theta)**12 - 1.39471289225353e+122*cos(theta)**10 + 2.11320135189929e+120*cos(theta)**8 - 1.91054691162997e+118*cos(theta)**6 + 8.90006325293464e+115*cos(theta)**4 - 1.59929258812842e+113*cos(theta)**2 + 4.63026227020387e+109)*cos(56*phi)

#@torch.jit.script
def Yl100_m57(theta, phi):
    return 1.283631619847e-112*(1.0 - cos(theta)**2)**28.5*(1.10341465584288e+134*cos(theta)**43 - 5.00695193078451e+134*cos(theta)**41 + 1.04205598559475e+135*cos(theta)**39 - 1.31993758175335e+135*cos(theta)**37 + 1.1387026288183e+135*cos(theta)**35 - 7.09453470310878e+134*cos(theta)**33 + 3.30327541732049e+134*cos(theta)**31 - 1.17343244389154e+134*cos(theta)**29 + 3.21901062310788e+133*cos(theta)**27 - 6.86018657383646e+132*cos(theta)**25 + 1.13704749842593e+132*cos(theta)**23 - 1.4610107521674e+131*cos(theta)**21 + 1.44450215609771e+130*cos(theta)**19 - 1.08575766458334e+129*cos(theta)**17 + 6.0967399827966e+127*cos(theta)**15 - 2.49574151342551e+126*cos(theta)**13 + 7.1992543656505e+124*cos(theta)**11 - 1.39471289225353e+123*cos(theta)**9 + 1.69056108151943e+121*cos(theta)**7 - 1.14632814697798e+119*cos(theta)**5 + 3.56002530117386e+116*cos(theta)**3 - 3.19858517625683e+113*cos(theta))*cos(57*phi)

#@torch.jit.script
def Yl100_m58(theta, phi):
    return 1.55731919038657e-114*(1.0 - cos(theta)**2)**29*(4.74468302012437e+135*cos(theta)**42 - 2.05285029162165e+136*cos(theta)**40 + 4.06401834381951e+136*cos(theta)**38 - 4.88376905248738e+136*cos(theta)**36 + 3.98545920086405e+136*cos(theta)**34 - 2.3411964520259e+136*cos(theta)**32 + 1.02401537936935e+136*cos(theta)**30 - 3.40295408728547e+135*cos(theta)**28 + 8.69132868239128e+134*cos(theta)**26 - 1.71504664345912e+134*cos(theta)**24 + 2.61520924637965e+133*cos(theta)**22 - 3.06812257955154e+132*cos(theta)**20 + 2.74455409658565e+131*cos(theta)**18 - 1.84578802979167e+130*cos(theta)**16 + 9.1451099741949e+128*cos(theta)**14 - 3.24446396745316e+127*cos(theta)**12 + 7.91917980221555e+125*cos(theta)**10 - 1.25524160302818e+124*cos(theta)**8 + 1.1833927570636e+122*cos(theta)**6 - 5.73164073488991e+119*cos(theta)**4 + 1.06800759035216e+117*cos(theta)**2 - 3.19858517625683e+113)*cos(58*phi)

#@torch.jit.script
def Yl100_m59(theta, phi):
    return 1.90569953479049e-116*(1.0 - cos(theta)**2)**29.5*(1.99276686845224e+137*cos(theta)**41 - 8.2114011664866e+137*cos(theta)**39 + 1.54432697065141e+138*cos(theta)**37 - 1.75815685889546e+138*cos(theta)**35 + 1.35505612829378e+138*cos(theta)**33 - 7.49182864648288e+137*cos(theta)**31 + 3.07204613810806e+137*cos(theta)**29 - 9.52827144439932e+136*cos(theta)**27 + 2.25974545742173e+136*cos(theta)**25 - 4.11611194430188e+135*cos(theta)**23 + 5.75346034203522e+134*cos(theta)**21 - 6.13624515910308e+133*cos(theta)**19 + 4.94019737385418e+132*cos(theta)**17 - 2.95326084766667e+131*cos(theta)**15 + 1.28031539638729e+130*cos(theta)**13 - 3.89335676094379e+128*cos(theta)**11 + 7.91917980221555e+126*cos(theta)**9 - 1.00419328242254e+125*cos(theta)**7 + 7.10035654238162e+122*cos(theta)**5 - 2.29265629395596e+120*cos(theta)**3 + 2.13601518070431e+117*cos(theta))*cos(59*phi)

#@torch.jit.script
def Yl100_m60(theta, phi):
    return 2.3528947910424e-118*(1.0 - cos(theta)**2)**30*(8.17034416065417e+138*cos(theta)**40 - 3.20244645492977e+139*cos(theta)**38 + 5.71400979141023e+139*cos(theta)**36 - 6.1535490061341e+139*cos(theta)**34 + 4.47168522336947e+139*cos(theta)**32 - 2.32246688040969e+139*cos(theta)**30 + 8.90893380051337e+138*cos(theta)**28 - 2.57263328998782e+138*cos(theta)**26 + 5.64936364355433e+137*cos(theta)**24 - 9.46705747189432e+136*cos(theta)**22 + 1.2082266718274e+136*cos(theta)**20 - 1.16588658022959e+135*cos(theta)**18 + 8.3983355355521e+133*cos(theta)**16 - 4.42989127150001e+132*cos(theta)**14 + 1.66441001530347e+131*cos(theta)**12 - 4.28269243703817e+129*cos(theta)**10 + 7.127261821994e+127*cos(theta)**8 - 7.0293529769578e+125*cos(theta)**6 + 3.55017827119081e+123*cos(theta)**4 - 6.87796888186789e+120*cos(theta)**2 + 2.13601518070431e+117)*cos(60*phi)

#@torch.jit.script
def Yl100_m61(theta, phi):
    return 2.93197035314659e-120*(1.0 - cos(theta)**2)**30.5*(3.26813766426167e+140*cos(theta)**39 - 1.21692965287331e+141*cos(theta)**37 + 2.05704352490768e+141*cos(theta)**35 - 2.09220666208559e+141*cos(theta)**33 + 1.43093927147823e+141*cos(theta)**31 - 6.96740064122907e+140*cos(theta)**29 + 2.49450146414374e+140*cos(theta)**27 - 6.68884655396832e+139*cos(theta)**25 + 1.35584727445304e+139*cos(theta)**23 - 2.08275264381675e+138*cos(theta)**21 + 2.41645334365479e+137*cos(theta)**19 - 2.09859584441325e+136*cos(theta)**17 + 1.34373368568834e+135*cos(theta)**15 - 6.20184778010001e+133*cos(theta)**13 + 1.99729201836417e+132*cos(theta)**11 - 4.28269243703817e+130*cos(theta)**9 + 5.7018094575952e+128*cos(theta)**7 - 4.21761178617468e+126*cos(theta)**5 + 1.42007130847632e+124*cos(theta)**3 - 1.37559377637358e+121*cos(theta))*cos(61*phi)

#@torch.jit.script
def Yl100_m62(theta, phi):
    return 3.68866966184522e-122*(1.0 - cos(theta)**2)**31*(1.27457368906205e+142*cos(theta)**38 - 4.50263971563126e+142*cos(theta)**36 + 7.19965233717689e+142*cos(theta)**34 - 6.90428198488246e+142*cos(theta)**32 + 4.43591174158251e+142*cos(theta)**30 - 2.02054618595643e+142*cos(theta)**28 + 6.73515395318811e+141*cos(theta)**26 - 1.67221163849208e+141*cos(theta)**24 + 3.11844873124199e+140*cos(theta)**22 - 4.37378055201518e+139*cos(theta)**20 + 4.59126135294411e+138*cos(theta)**18 - 3.56761293550253e+137*cos(theta)**16 + 2.0156005285325e+136*cos(theta)**14 - 8.06240211413002e+134*cos(theta)**12 + 2.19702122020058e+133*cos(theta)**10 - 3.85442319333435e+131*cos(theta)**8 + 3.99126662031664e+129*cos(theta)**6 - 2.10880589308734e+127*cos(theta)**4 + 4.26021392542897e+124*cos(theta)**2 - 1.37559377637358e+121)*cos(62*phi)

#@torch.jit.script
def Yl100_m63(theta, phi):
    return 4.68688355097872e-124*(1.0 - cos(theta)**2)**31.5*(4.84338001843579e+143*cos(theta)**37 - 1.62095029762725e+144*cos(theta)**35 + 2.44788179464014e+144*cos(theta)**33 - 2.20937023516239e+144*cos(theta)**31 + 1.33077352247475e+144*cos(theta)**29 - 5.65752932067801e+143*cos(theta)**27 + 1.75114002782891e+143*cos(theta)**25 - 4.013307932381e+142*cos(theta)**23 + 6.86058720873238e+141*cos(theta)**21 - 8.74756110403035e+140*cos(theta)**19 + 8.26427043529939e+139*cos(theta)**17 - 5.70818069680405e+138*cos(theta)**15 + 2.82184073994551e+137*cos(theta)**13 - 9.67488253695602e+135*cos(theta)**11 + 2.19702122020058e+134*cos(theta)**9 - 3.08353855466748e+132*cos(theta)**7 + 2.39475997218998e+130*cos(theta)**5 - 8.43522357234936e+127*cos(theta)**3 + 8.52042785085794e+124*cos(theta))*cos(63*phi)

#@torch.jit.script
def Yl100_m64(theta, phi):
    return 6.01674183435769e-126*(1.0 - cos(theta)**2)**32*(1.79205060682124e+145*cos(theta)**36 - 5.67332604169539e+145*cos(theta)**34 + 8.07800992231247e+145*cos(theta)**32 - 6.8490477290034e+145*cos(theta)**30 + 3.85924321517678e+145*cos(theta)**28 - 1.52753291658306e+145*cos(theta)**26 + 4.37785006957227e+144*cos(theta)**24 - 9.23060824447629e+143*cos(theta)**22 + 1.4407233138338e+143*cos(theta)**20 - 1.66203660976577e+142*cos(theta)**18 + 1.4049259740009e+141*cos(theta)**16 - 8.56227104520608e+139*cos(theta)**14 + 3.66839296192916e+138*cos(theta)**12 - 1.06423707906516e+137*cos(theta)**10 + 1.97731909818052e+135*cos(theta)**8 - 2.15847698826724e+133*cos(theta)**6 + 1.19737998609499e+131*cos(theta)**4 - 2.53056707170481e+128*cos(theta)**2 + 8.52042785085794e+124)*cos(64*phi)

#@torch.jit.script
def Yl100_m65(theta, phi):
    return 7.80671194223321e-128*(1.0 - cos(theta)**2)**32.5*(6.45138218455647e+146*cos(theta)**35 - 1.92893085417643e+147*cos(theta)**33 + 2.58496317513999e+147*cos(theta)**31 - 2.05471431870102e+147*cos(theta)**29 + 1.0805881002495e+147*cos(theta)**27 - 3.97158558311596e+146*cos(theta)**25 + 1.05068401669734e+146*cos(theta)**23 - 2.03073381378478e+145*cos(theta)**21 + 2.8814466276676e+144*cos(theta)**19 - 2.99166589757838e+143*cos(theta)**17 + 2.24788155840144e+142*cos(theta)**15 - 1.19871794632885e+141*cos(theta)**13 + 4.40207155431499e+139*cos(theta)**11 - 1.06423707906516e+138*cos(theta)**9 + 1.58185527854442e+136*cos(theta)**7 - 1.29508619296034e+134*cos(theta)**5 + 4.78951994437997e+131*cos(theta)**3 - 5.06113414340962e+128*cos(theta))*cos(65*phi)

#@torch.jit.script
def Yl100_m66(theta, phi):
    return 1.02418895622595e-129*(1.0 - cos(theta)**2)**33*(2.25798376459477e+148*cos(theta)**34 - 6.36547181878223e+148*cos(theta)**32 + 8.01338584293397e+148*cos(theta)**30 - 5.95867152423296e+148*cos(theta)**28 + 2.91758787067365e+148*cos(theta)**26 - 9.92896395778991e+147*cos(theta)**24 + 2.41657323840389e+147*cos(theta)**22 - 4.26454100894805e+146*cos(theta)**20 + 5.47474859256844e+145*cos(theta)**18 - 5.08583202588325e+144*cos(theta)**16 + 3.37182233760215e+143*cos(theta)**14 - 1.55833333022751e+142*cos(theta)**12 + 4.84227870974649e+140*cos(theta)**10 - 9.57813371158646e+138*cos(theta)**8 + 1.10729869498109e+137*cos(theta)**6 - 6.47543096480172e+134*cos(theta)**4 + 1.43685598331399e+132*cos(theta)**2 - 5.06113414340962e+128)*cos(66*phi)

#@torch.jit.script
def Yl100_m67(theta, phi):
    return 1.35919695981912e-131*(1.0 - cos(theta)**2)**33.5*(7.6771447996222e+149*cos(theta)**33 - 2.03695098201031e+150*cos(theta)**31 + 2.40401575288019e+150*cos(theta)**29 - 1.66842802678523e+150*cos(theta)**27 + 7.58572846375149e+149*cos(theta)**25 - 2.38295134986958e+149*cos(theta)**23 + 5.31646112448856e+148*cos(theta)**21 - 8.52908201789609e+147*cos(theta)**19 + 9.85454746662319e+146*cos(theta)**17 - 8.1373312414132e+145*cos(theta)**15 + 4.72055127264301e+144*cos(theta)**13 - 1.86999999627301e+143*cos(theta)**11 + 4.84227870974649e+141*cos(theta)**9 - 7.66250696926917e+139*cos(theta)**7 + 6.64379216988656e+137*cos(theta)**5 - 2.59017238592069e+135*cos(theta)**3 + 2.87371196662798e+132*cos(theta))*cos(67*phi)

#@torch.jit.script
def Yl100_m68(theta, phi):
    return 1.82545353809288e-133*(1.0 - cos(theta)**2)**34*(2.53345778387533e+151*cos(theta)**32 - 6.31454804423197e+151*cos(theta)**30 + 6.97164568335256e+151*cos(theta)**28 - 4.50475567232011e+151*cos(theta)**26 + 1.89643211593787e+151*cos(theta)**24 - 5.48078810470003e+150*cos(theta)**22 + 1.1164568361426e+150*cos(theta)**20 - 1.62052558340026e+149*cos(theta)**18 + 1.67527306932594e+148*cos(theta)**16 - 1.22059968621198e+147*cos(theta)**14 + 6.13671665443592e+145*cos(theta)**12 - 2.05699999590031e+144*cos(theta)**10 + 4.35805083877184e+142*cos(theta)**8 - 5.36375487848842e+140*cos(theta)**6 + 3.32189608494328e+138*cos(theta)**4 - 7.77051715776206e+135*cos(theta)**2 + 2.87371196662798e+132)*cos(68*phi)

#@torch.jit.script
def Yl100_m69(theta, phi):
    return 2.48228956832009e-135*(1.0 - cos(theta)**2)**34.5*(8.10706490840105e+152*cos(theta)**31 - 1.89436441326959e+153*cos(theta)**29 + 1.95206079133872e+153*cos(theta)**27 - 1.17123647480323e+153*cos(theta)**25 + 4.55143707825089e+152*cos(theta)**23 - 1.20577338303401e+152*cos(theta)**21 + 2.2329136722852e+151*cos(theta)**19 - 2.91694605012046e+150*cos(theta)**17 + 2.68043691092151e+149*cos(theta)**15 - 1.70883956069677e+148*cos(theta)**13 + 7.3640599853231e+146*cos(theta)**11 - 2.05699999590031e+145*cos(theta)**9 + 3.48644067101747e+143*cos(theta)**7 - 3.21825292709305e+141*cos(theta)**5 + 1.32875843397731e+139*cos(theta)**3 - 1.55410343155241e+136*cos(theta))*cos(69*phi)

#@torch.jit.script
def Yl100_m70(theta, phi):
    return 3.41937816871774e-137*(1.0 - cos(theta)**2)**35*(2.51319012160432e+154*cos(theta)**30 - 5.49365679848182e+154*cos(theta)**28 + 5.27056413661453e+154*cos(theta)**26 - 2.92809118700807e+154*cos(theta)**24 + 1.04683052799771e+154*cos(theta)**22 - 2.53212410437141e+153*cos(theta)**20 + 4.24253597734187e+152*cos(theta)**18 - 4.95880828520479e+151*cos(theta)**16 + 4.02065536638226e+150*cos(theta)**14 - 2.2214914289058e+149*cos(theta)**12 + 8.10046598385541e+147*cos(theta)**10 - 1.85129999631028e+146*cos(theta)**8 + 2.44050846971223e+144*cos(theta)**6 - 1.60912646354652e+142*cos(theta)**4 + 3.98627530193194e+139*cos(theta)**2 - 1.55410343155241e+136)*cos(70*phi)

#@torch.jit.script
def Yl100_m71(theta, phi):
    return 4.77406636631576e-139*(1.0 - cos(theta)**2)**35.5*(7.53957036481297e+155*cos(theta)**29 - 1.53822390357491e+156*cos(theta)**27 + 1.37034667551978e+156*cos(theta)**25 - 7.02741884881938e+155*cos(theta)**23 + 2.30302716159495e+155*cos(theta)**21 - 5.06424820874283e+154*cos(theta)**19 + 7.63656475921537e+153*cos(theta)**17 - 7.93409325632766e+152*cos(theta)**15 + 5.62891751293516e+151*cos(theta)**13 - 2.66578971468696e+150*cos(theta)**11 + 8.10046598385541e+148*cos(theta)**9 - 1.48103999704822e+147*cos(theta)**7 + 1.46430508182734e+145*cos(theta)**5 - 6.4365058541861e+142*cos(theta)**3 + 7.97255060386387e+139*cos(theta))*cos(71*phi)

#@torch.jit.script
def Yl100_m72(theta, phi):
    return 6.75966587477127e-141*(1.0 - cos(theta)**2)**36*(2.18647540579576e+157*cos(theta)**28 - 4.15320453965225e+157*cos(theta)**26 + 3.42586668879945e+157*cos(theta)**24 - 1.61630633522846e+157*cos(theta)**22 + 4.8363570393494e+156*cos(theta)**20 - 9.62207159661137e+155*cos(theta)**18 + 1.29821600906661e+155*cos(theta)**16 - 1.19011398844915e+154*cos(theta)**14 + 7.31759276681571e+152*cos(theta)**12 - 2.93236868615566e+151*cos(theta)**10 + 7.29041938546987e+149*cos(theta)**8 - 1.03672799793376e+148*cos(theta)**6 + 7.32152540913669e+145*cos(theta)**4 - 1.93095175625583e+143*cos(theta)**2 + 7.97255060386387e+139)*cos(72*phi)

#@torch.jit.script
def Yl100_m73(theta, phi):
    return 9.71232401092137e-143*(1.0 - cos(theta)**2)**36.5*(6.12213113622813e+158*cos(theta)**27 - 1.07983318030959e+159*cos(theta)**25 + 8.22208005311867e+158*cos(theta)**23 - 3.55587393750261e+158*cos(theta)**21 + 9.6727140786988e+157*cos(theta)**19 - 1.73197288739005e+157*cos(theta)**17 + 2.07714561450658e+156*cos(theta)**15 - 1.66615958382881e+155*cos(theta)**13 + 8.78111132017886e+153*cos(theta)**11 - 2.93236868615566e+152*cos(theta)**9 + 5.8323355083759e+150*cos(theta)**7 - 6.22036798760253e+148*cos(theta)**5 + 2.92861016365468e+146*cos(theta)**3 - 3.86190351251166e+143*cos(theta))*cos(73*phi)

#@torch.jit.script
def Yl100_m74(theta, phi):
    return 1.41698957850213e-144*(1.0 - cos(theta)**2)**37*(1.6529754067816e+160*cos(theta)**26 - 2.69958295077396e+160*cos(theta)**24 + 1.89107841221729e+160*cos(theta)**22 - 7.46733526875547e+159*cos(theta)**20 + 1.83781567495277e+159*cos(theta)**18 - 2.94435390856308e+158*cos(theta)**16 + 3.11571842175987e+157*cos(theta)**14 - 2.16600745897745e+156*cos(theta)**12 + 9.65922245219674e+154*cos(theta)**10 - 2.63913181754009e+153*cos(theta)**8 + 4.08263485586313e+151*cos(theta)**6 - 3.11018399380127e+149*cos(theta)**4 + 8.78583049096403e+146*cos(theta)**2 - 3.86190351251166e+143)*cos(74*phi)

#@torch.jit.script
def Yl100_m75(theta, phi):
    return 2.10068511356121e-146*(1.0 - cos(theta)**2)**37.5*(4.29773605763215e+161*cos(theta)**25 - 6.47899908185751e+161*cos(theta)**23 + 4.16037250687805e+161*cos(theta)**21 - 1.49346705375109e+161*cos(theta)**19 + 3.30806821491499e+160*cos(theta)**17 - 4.71096625370093e+159*cos(theta)**15 + 4.36200579046382e+158*cos(theta)**13 - 2.59920895077294e+157*cos(theta)**11 + 9.65922245219674e+155*cos(theta)**9 - 2.11130545403207e+154*cos(theta)**7 + 2.44958091351788e+152*cos(theta)**5 - 1.24407359752051e+150*cos(theta)**3 + 1.75716609819281e+147*cos(theta))*cos(75*phi)

#@torch.jit.script
def Yl100_m76(theta, phi):
    return 3.16690196562167e-148*(1.0 - cos(theta)**2)**38*(1.07443401440804e+163*cos(theta)**24 - 1.49016978882723e+163*cos(theta)**22 + 8.7367822644439e+162*cos(theta)**20 - 2.83758740212708e+162*cos(theta)**18 + 5.62371596535548e+161*cos(theta)**16 - 7.06644938055139e+160*cos(theta)**14 + 5.67060752760297e+159*cos(theta)**12 - 2.85912984585024e+158*cos(theta)**10 + 8.69330020697707e+156*cos(theta)**8 - 1.47791381782245e+155*cos(theta)**6 + 1.22479045675894e+153*cos(theta)**4 - 3.73222079256152e+150*cos(theta)**2 + 1.75716609819281e+147)*cos(76*phi)

#@torch.jit.script
def Yl100_m77(theta, phi):
    return 4.85894927820603e-150*(1.0 - cos(theta)**2)**38.5*(2.57864163457929e+164*cos(theta)**23 - 3.2783735354199e+164*cos(theta)**21 + 1.74735645288878e+164*cos(theta)**19 - 5.10765732382874e+163*cos(theta)**17 + 8.99794554456877e+162*cos(theta)**15 - 9.89302913277194e+161*cos(theta)**13 + 6.80472903312356e+160*cos(theta)**11 - 2.85912984585024e+159*cos(theta)**9 + 6.95464016558165e+157*cos(theta)**7 - 8.86748290693471e+155*cos(theta)**5 + 4.89916182703575e+153*cos(theta)**3 - 7.46444158512304e+150*cos(theta))*cos(77*phi)

#@torch.jit.script
def Yl100_m78(theta, phi):
    return 7.59396246831315e-152*(1.0 - cos(theta)**2)**39*(5.93087575953237e+165*cos(theta)**22 - 6.88458442438179e+165*cos(theta)**20 + 3.31997726048868e+165*cos(theta)**18 - 8.68301745050886e+164*cos(theta)**16 + 1.34969183168532e+164*cos(theta)**14 - 1.28609378726035e+163*cos(theta)**12 + 7.48520193643592e+161*cos(theta)**10 - 2.57321686126521e+160*cos(theta)**8 + 4.86824811590716e+158*cos(theta)**6 - 4.43374145346736e+156*cos(theta)**4 + 1.46974854811073e+154*cos(theta)**2 - 7.46444158512304e+150)*cos(78*phi)

#@torch.jit.script
def Yl100_m79(theta, phi):
    return 1.21012599575438e-153*(1.0 - cos(theta)**2)**39.5*(1.30479266709712e+167*cos(theta)**21 - 1.37691688487636e+167*cos(theta)**19 + 5.97595906887963e+166*cos(theta)**17 - 1.38928279208142e+166*cos(theta)**15 + 1.88956856435944e+165*cos(theta)**13 - 1.54331254471242e+164*cos(theta)**11 + 7.48520193643592e+162*cos(theta)**9 - 2.05857348901217e+161*cos(theta)**7 + 2.92094886954429e+159*cos(theta)**5 - 1.77349658138694e+157*cos(theta)**3 + 2.93949709622145e+154*cos(theta))*cos(79*phi)

#@torch.jit.script
def Yl100_m80(theta, phi):
    return 1.96827007922269e-155*(1.0 - cos(theta)**2)**40*(2.74006460090395e+168*cos(theta)**20 - 2.61614208126508e+168*cos(theta)**18 + 1.01591304170954e+168*cos(theta)**16 - 2.08392418812213e+167*cos(theta)**14 + 2.45643913366727e+166*cos(theta)**12 - 1.69764379918367e+165*cos(theta)**10 + 6.73668174279232e+163*cos(theta)**8 - 1.44100144230852e+162*cos(theta)**6 + 1.46047443477215e+160*cos(theta)**4 - 5.32048974416083e+157*cos(theta)**2 + 2.93949709622145e+154)*cos(80*phi)

#@torch.jit.script
def Yl100_m81(theta, phi):
    return 3.27137556380441e-157*(1.0 - cos(theta)**2)**40.5*(5.48012920180791e+169*cos(theta)**19 - 4.70905574627715e+169*cos(theta)**17 + 1.62546086673526e+169*cos(theta)**15 - 2.91749386337098e+168*cos(theta)**13 + 2.94772696040073e+167*cos(theta)**11 - 1.69764379918367e+166*cos(theta)**9 + 5.38934539423386e+164*cos(theta)**7 - 8.64600865385111e+162*cos(theta)**5 + 5.84189773908859e+160*cos(theta)**3 - 1.06409794883217e+158*cos(theta))*cos(81*phi)

#@torch.jit.script
def Yl100_m82(theta, phi):
    return 5.56311337477837e-159*(1.0 - cos(theta)**2)**41*(1.0412245483435e+171*cos(theta)**18 - 8.00539476867115e+170*cos(theta)**16 + 2.43819130010289e+170*cos(theta)**14 - 3.79274202238227e+169*cos(theta)**12 + 3.2424996564408e+168*cos(theta)**10 - 1.5278794192653e+167*cos(theta)**8 + 3.7725417759637e+165*cos(theta)**6 - 4.32300432692556e+163*cos(theta)**4 + 1.75256932172658e+161*cos(theta)**2 - 1.06409794883217e+158)*cos(82*phi)

#@torch.jit.script
def Yl100_m83(theta, phi):
    return 9.69295314555688e-161*(1.0 - cos(theta)**2)**41.5*(1.8742041870183e+172*cos(theta)**17 - 1.28086316298738e+172*cos(theta)**15 + 3.41346782014404e+171*cos(theta)**13 - 4.55129042685872e+170*cos(theta)**11 + 3.2424996564408e+169*cos(theta)**9 - 1.22230353541224e+168*cos(theta)**7 + 2.26352506557822e+166*cos(theta)**5 - 1.72920173077022e+164*cos(theta)**3 + 3.50513864345315e+161*cos(theta))*cos(83*phi)

#@torch.jit.script
def Yl100_m84(theta, phi):
    return 1.7330964841394e-162*(1.0 - cos(theta)**2)**42*(3.18614711793112e+173*cos(theta)**16 - 1.92129474448108e+173*cos(theta)**14 + 4.43750816618726e+172*cos(theta)**12 - 5.0064194695446e+171*cos(theta)**10 + 2.91824969079672e+170*cos(theta)**8 - 8.55612474788568e+168*cos(theta)**6 + 1.13176253278911e+167*cos(theta)**4 - 5.18760519231067e+164*cos(theta)**2 + 3.50513864345315e+161)*cos(84*phi)

#@torch.jit.script
def Yl100_m85(theta, phi):
    return 3.18549469159664e-164*(1.0 - cos(theta)**2)**42.5*(5.09783538868979e+174*cos(theta)**15 - 2.68981264227351e+174*cos(theta)**13 + 5.32500979942471e+173*cos(theta)**11 - 5.0064194695446e+172*cos(theta)**9 + 2.33459975263738e+171*cos(theta)**7 - 5.13367484873141e+169*cos(theta)**5 + 4.52705013115644e+167*cos(theta)**3 - 1.03752103846213e+165*cos(theta))*cos(85*phi)

#@torch.jit.script
def Yl100_m86(theta, phi):
    return 6.03079802674505e-166*(1.0 - cos(theta)**2)**43*(7.64675308303468e+175*cos(theta)**14 - 3.49675643495556e+175*cos(theta)**12 + 5.85751077936718e+174*cos(theta)**10 - 4.50577752259014e+173*cos(theta)**8 + 1.63421982684616e+172*cos(theta)**6 - 2.5668374243657e+170*cos(theta)**4 + 1.35811503934693e+168*cos(theta)**2 - 1.03752103846213e+165)*cos(86*phi)

#@torch.jit.script
def Yl100_m87(theta, phi):
    return 1.17866384774513e-167*(1.0 - cos(theta)**2)**43.5*(1.07054543162486e+177*cos(theta)**13 - 4.19610772194667e+176*cos(theta)**11 + 5.85751077936718e+175*cos(theta)**9 - 3.60462201807211e+174*cos(theta)**7 + 9.80531896107698e+172*cos(theta)**5 - 1.02673496974628e+171*cos(theta)**3 + 2.71623007869387e+168*cos(theta))*cos(87*phi)

#@torch.jit.script
def Yl100_m88(theta, phi):
    return 2.38418176577027e-169*(1.0 - cos(theta)**2)**44*(1.39170906111231e+178*cos(theta)**12 - 4.61571849414134e+177*cos(theta)**10 + 5.27175970143046e+176*cos(theta)**8 - 2.52323541265048e+175*cos(theta)**6 + 4.90265948053849e+173*cos(theta)**4 - 3.08020490923884e+171*cos(theta)**2 + 2.71623007869387e+168)*cos(88*phi)

#@torch.jit.script
def Yl100_m89(theta, phi):
    return 5.00631113698649e-171*(1.0 - cos(theta)**2)**44.5*(1.67005087333477e+179*cos(theta)**11 - 4.61571849414134e+178*cos(theta)**9 + 4.21740776114437e+177*cos(theta)**7 - 1.51394124759029e+176*cos(theta)**5 + 1.9610637922154e+174*cos(theta)**3 - 6.16040981847769e+171*cos(theta))*cos(89*phi)

#@torch.jit.script
def Yl100_m90(theta, phi):
    return 1.09507709196003e-172*(1.0 - cos(theta)**2)**45*(1.83705596066825e+180*cos(theta)**10 - 4.1541466447272e+179*cos(theta)**8 + 2.95218543280106e+178*cos(theta)**6 - 7.56970623795143e+176*cos(theta)**4 + 5.88319137664619e+174*cos(theta)**2 - 6.16040981847769e+171)*cos(90*phi)

#@torch.jit.script
def Yl100_m91(theta, phi):
    return 2.50569386920174e-174*(1.0 - cos(theta)**2)**45.5*(1.83705596066825e+181*cos(theta)**9 - 3.32331731578176e+180*cos(theta)**7 + 1.77131125968064e+179*cos(theta)**5 - 3.02788249518057e+177*cos(theta)**3 + 1.17663827532924e+175*cos(theta))*cos(91*phi)

#@torch.jit.script
def Yl100_m92(theta, phi):
    return 6.02776262454342e-176*(1.0 - cos(theta)**2)**46*(1.65335036460143e+182*cos(theta)**8 - 2.32632212104723e+181*cos(theta)**6 + 8.85655629840317e+179*cos(theta)**4 - 9.08364748554172e+177*cos(theta)**2 + 1.17663827532924e+175)*cos(92*phi)

#@torch.jit.script
def Yl100_m93(theta, phi):
    return 1.53402519759458e-177*(1.0 - cos(theta)**2)**46.5*(1.32268029168114e+183*cos(theta)**7 - 1.39579327262834e+182*cos(theta)**5 + 3.54262251936127e+180*cos(theta)**3 - 1.81672949710834e+178*cos(theta))*cos(93*phi)

#@torch.jit.script
def Yl100_m94(theta, phi):
    return 4.16277184303861e-179*(1.0 - cos(theta)**2)**47*(9.25876204176799e+183*cos(theta)**6 - 6.9789663631417e+182*cos(theta)**4 + 1.06278675580838e+181*cos(theta)**2 - 1.81672949710834e+178)*cos(94*phi)

#@torch.jit.script
def Yl100_m95(theta, phi):
    return 1.21699747582751e-180*(1.0 - cos(theta)**2)**47.5*(5.55525722506079e+184*cos(theta)**5 - 2.79158654525668e+183*cos(theta)**3 + 2.12557351161676e+181*cos(theta))*cos(95*phi)

#@torch.jit.script
def Yl100_m96(theta, phi):
    return 3.88755583485137e-182*(1.0 - cos(theta)**2)**48*(2.7776286125304e+185*cos(theta)**4 - 8.37475963577004e+183*cos(theta)**2 + 2.12557351161676e+181)*cos(96*phi)

#@torch.jit.script
def Yl100_m97(theta, phi):
    return 1.38488442448223e-183*(1.0 - cos(theta)**2)**48.5*(1.11105144501216e+186*cos(theta)**3 - 1.67495192715401e+184*cos(theta))*cos(97*phi)

#@torch.jit.script
def Yl100_m98(theta, phi):
    return 5.68224962145241e-185*(1.0 - cos(theta)**2)**49*(3.33315433503648e+186*cos(theta)**2 - 1.67495192715401e+184)*cos(98*phi)

#@torch.jit.script
def Yl100_m99(theta, phi):
    return 18.9873427997529*(1.0 - cos(theta)**2)**49.5*cos(99*phi)*cos(theta)

#@torch.jit.script
def Yl100_m100(theta, phi):
    return 1.34260788504189*(1.0 - cos(theta)**2)**50*cos(100*phi)
